Class: OCI::Adm::ApplicationDependencyManagementClientCompositeOperations
- Inherits:
-
Object
- Object
- OCI::Adm::ApplicationDependencyManagementClientCompositeOperations
- Defined in:
- lib/oci/adm/application_dependency_management_client_composite_operations.rb
Overview
This class provides a wrapper around ApplicationDependencyManagementClient and offers convenience methods for operations that would otherwise need to be chained together. For example, instead of performing an action on a resource (e.g. launching an instance, creating a load balancer) and then using a waiter to wait for the resource to enter a given state, you can call a single method in this class to accomplish the same functionality
Instance Attribute Summary collapse
-
#service_client ⇒ OCI::Adm::ApplicationDependencyManagementClient
readonly
The ApplicationDependencyManagementClient used to communicate with the service_client.
Instance Method Summary collapse
-
#change_knowledge_base_compartment_and_wait_for_state(knowledge_base_id, change_knowledge_base_compartment_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Adm::ApplicationDependencyManagementClient#change_knowledge_base_compartment and then waits for the Models::WorkRequest to enter the given state(s).
-
#create_knowledge_base_and_wait_for_state(create_knowledge_base_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Adm::ApplicationDependencyManagementClient#create_knowledge_base and then waits for the Models::WorkRequest to enter the given state(s).
-
#create_vulnerability_audit_and_wait_for_state(create_vulnerability_audit_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Adm::ApplicationDependencyManagementClient#create_vulnerability_audit and then waits for the Models::WorkRequest to enter the given state(s).
-
#delete_knowledge_base_and_wait_for_state(knowledge_base_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Adm::ApplicationDependencyManagementClient#delete_knowledge_base and then waits for the Models::WorkRequest to enter the given state(s).
-
#delete_vulnerability_audit_and_wait_for_state(vulnerability_audit_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Adm::ApplicationDependencyManagementClient#delete_vulnerability_audit and then waits for the Models::VulnerabilityAudit acted upon to enter the given state(s).
-
#initialize(service_client = OCI::Adm::ApplicationDependencyManagementClient.new) ⇒ ApplicationDependencyManagementClientCompositeOperations
constructor
Initializes a new ApplicationDependencyManagementClientCompositeOperations.
-
#update_knowledge_base_and_wait_for_state(knowledge_base_id, update_knowledge_base_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Adm::ApplicationDependencyManagementClient#update_knowledge_base and then waits for the Models::WorkRequest to enter the given state(s).
-
#update_vulnerability_audit_and_wait_for_state(vulnerability_audit_id, update_vulnerability_audit_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Adm::ApplicationDependencyManagementClient#update_vulnerability_audit and then waits for the Models::VulnerabilityAudit acted upon to enter the given state(s).
Constructor Details
#initialize(service_client = OCI::Adm::ApplicationDependencyManagementClient.new) ⇒ ApplicationDependencyManagementClientCompositeOperations
Initializes a new ApplicationDependencyManagementClientCompositeOperations
20 21 22 |
# File 'lib/oci/adm/application_dependency_management_client_composite_operations.rb', line 20 def initialize(service_client = OCI::Adm::ApplicationDependencyManagementClient.new) @service_client = service_client end |
Instance Attribute Details
#service_client ⇒ OCI::Adm::ApplicationDependencyManagementClient (readonly)
The OCI::Adm::ApplicationDependencyManagementClient used to communicate with the service_client
14 15 16 |
# File 'lib/oci/adm/application_dependency_management_client_composite_operations.rb', line 14 def service_client @service_client end |
Instance Method Details
#change_knowledge_base_compartment_and_wait_for_state(knowledge_base_id, change_knowledge_base_compartment_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Adm::ApplicationDependencyManagementClient#change_knowledge_base_compartment and then waits for the Models::WorkRequest to enter the given state(s).
40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/oci/adm/application_dependency_management_client_composite_operations.rb', line 40 def change_knowledge_base_compartment_and_wait_for_state(knowledge_base_id, change_knowledge_base_compartment_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) operation_result = @service_client.change_knowledge_base_compartment(knowledge_base_id, change_knowledge_base_compartment_details, base_operation_opts) use_util = OCI::Adm::Util.respond_to?(:wait_on_work_request) return operation_result if wait_for_states.empty? && !use_util lowered_wait_for_states = wait_for_states.map(&:downcase) wait_for_resource_id = operation_result.headers['opc-work-request-id'] begin if use_util waiter_result = OCI::Adm::Util.wait_on_work_request( @service_client, wait_for_resource_id, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) else waiter_result = @service_client.get_work_request(wait_for_resource_id).wait_until( eval_proc: ->(response) { response.data.respond_to?(:status) && lowered_wait_for_states.include?(response.data.status.downcase) }, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) end result_to_return = waiter_result return result_to_return rescue StandardError raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result]) end end |
#create_knowledge_base_and_wait_for_state(create_knowledge_base_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Adm::ApplicationDependencyManagementClient#create_knowledge_base and then waits for the Models::WorkRequest to enter the given state(s).
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/oci/adm/application_dependency_management_client_composite_operations.rb', line 89 def create_knowledge_base_and_wait_for_state(create_knowledge_base_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) operation_result = @service_client.create_knowledge_base(create_knowledge_base_details, base_operation_opts) use_util = OCI::Adm::Util.respond_to?(:wait_on_work_request) return operation_result if wait_for_states.empty? && !use_util lowered_wait_for_states = wait_for_states.map(&:downcase) wait_for_resource_id = operation_result.headers['opc-work-request-id'] begin if use_util waiter_result = OCI::Adm::Util.wait_on_work_request( @service_client, wait_for_resource_id, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) else waiter_result = @service_client.get_work_request(wait_for_resource_id).wait_until( eval_proc: ->(response) { response.data.respond_to?(:status) && lowered_wait_for_states.include?(response.data.status.downcase) }, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) end result_to_return = waiter_result return result_to_return rescue StandardError raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result]) end end |
#create_vulnerability_audit_and_wait_for_state(create_vulnerability_audit_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Adm::ApplicationDependencyManagementClient#create_vulnerability_audit and then waits for the Models::WorkRequest to enter the given state(s).
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/oci/adm/application_dependency_management_client_composite_operations.rb', line 138 def create_vulnerability_audit_and_wait_for_state(create_vulnerability_audit_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) operation_result = @service_client.create_vulnerability_audit(create_vulnerability_audit_details, base_operation_opts) use_util = OCI::Adm::Util.respond_to?(:wait_on_work_request) return operation_result if wait_for_states.empty? && !use_util lowered_wait_for_states = wait_for_states.map(&:downcase) wait_for_resource_id = operation_result.headers['opc-work-request-id'] begin if use_util waiter_result = OCI::Adm::Util.wait_on_work_request( @service_client, wait_for_resource_id, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) else waiter_result = @service_client.get_work_request(wait_for_resource_id).wait_until( eval_proc: ->(response) { response.data.respond_to?(:status) && lowered_wait_for_states.include?(response.data.status.downcase) }, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) end result_to_return = waiter_result return result_to_return rescue StandardError raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result]) end end |
#delete_knowledge_base_and_wait_for_state(knowledge_base_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Adm::ApplicationDependencyManagementClient#delete_knowledge_base and then waits for the Models::WorkRequest to enter the given state(s).
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/oci/adm/application_dependency_management_client_composite_operations.rb', line 187 def delete_knowledge_base_and_wait_for_state(knowledge_base_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) operation_result = @service_client.delete_knowledge_base(knowledge_base_id, base_operation_opts) use_util = OCI::Adm::Util.respond_to?(:wait_on_work_request) return operation_result if wait_for_states.empty? && !use_util lowered_wait_for_states = wait_for_states.map(&:downcase) wait_for_resource_id = operation_result.headers['opc-work-request-id'] begin if use_util waiter_result = OCI::Adm::Util.wait_on_work_request( @service_client, wait_for_resource_id, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) else waiter_result = @service_client.get_work_request(wait_for_resource_id).wait_until( eval_proc: ->(response) { response.data.respond_to?(:status) && lowered_wait_for_states.include?(response.data.status.downcase) }, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) end result_to_return = waiter_result return result_to_return rescue StandardError raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result]) end end |
#delete_vulnerability_audit_and_wait_for_state(vulnerability_audit_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Adm::ApplicationDependencyManagementClient#delete_vulnerability_audit and then waits for the Models::VulnerabilityAudit acted upon to enter the given state(s).
236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/oci/adm/application_dependency_management_client_composite_operations.rb', line 236 def delete_vulnerability_audit_and_wait_for_state(vulnerability_audit_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) initial_get_result = @service_client.get_vulnerability_audit(vulnerability_audit_id) operation_result = @service_client.delete_vulnerability_audit(vulnerability_audit_id, base_operation_opts) return operation_result if wait_for_states.empty? lowered_wait_for_states = wait_for_states.map(&:downcase) begin waiter_result = initial_get_result.wait_until( eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) }, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200, succeed_on_not_found: true ) result_to_return = waiter_result return result_to_return rescue StandardError raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result]) end end |
#update_knowledge_base_and_wait_for_state(knowledge_base_id, update_knowledge_base_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Adm::ApplicationDependencyManagementClient#update_knowledge_base and then waits for the Models::WorkRequest to enter the given state(s).
277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 |
# File 'lib/oci/adm/application_dependency_management_client_composite_operations.rb', line 277 def update_knowledge_base_and_wait_for_state(knowledge_base_id, update_knowledge_base_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) operation_result = @service_client.update_knowledge_base(knowledge_base_id, update_knowledge_base_details, base_operation_opts) use_util = OCI::Adm::Util.respond_to?(:wait_on_work_request) return operation_result if wait_for_states.empty? && !use_util lowered_wait_for_states = wait_for_states.map(&:downcase) wait_for_resource_id = operation_result.headers['opc-work-request-id'] begin if use_util waiter_result = OCI::Adm::Util.wait_on_work_request( @service_client, wait_for_resource_id, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) else waiter_result = @service_client.get_work_request(wait_for_resource_id).wait_until( eval_proc: ->(response) { response.data.respond_to?(:status) && lowered_wait_for_states.include?(response.data.status.downcase) }, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) end result_to_return = waiter_result return result_to_return rescue StandardError raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result]) end end |
#update_vulnerability_audit_and_wait_for_state(vulnerability_audit_id, update_vulnerability_audit_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Adm::ApplicationDependencyManagementClient#update_vulnerability_audit and then waits for the Models::VulnerabilityAudit acted upon to enter the given state(s).
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 |
# File 'lib/oci/adm/application_dependency_management_client_composite_operations.rb', line 327 def update_vulnerability_audit_and_wait_for_state(vulnerability_audit_id, update_vulnerability_audit_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) operation_result = @service_client.update_vulnerability_audit(vulnerability_audit_id, update_vulnerability_audit_details, base_operation_opts) return operation_result if wait_for_states.empty? lowered_wait_for_states = wait_for_states.map(&:downcase) wait_for_resource_id = operation_result.data.id begin waiter_result = @service_client.get_vulnerability_audit(wait_for_resource_id).wait_until( eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) }, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) result_to_return = waiter_result return result_to_return rescue StandardError raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result]) end end |