Class: OCI::Adm::Models::ApplicationDependency
- Inherits:
-
Object
- Object
- OCI::Adm::Models::ApplicationDependency
- Defined in:
- lib/oci/adm/models/application_dependency.rb
Overview
An Application Dependency resource creates a Vulnerability Audit.
Instance Attribute Summary collapse
-
#application_dependency_node_ids ⇒ Array<String>
**[Required]** List of (Application Dependencies) node identifiers on which this node depends.
-
#gav ⇒ String
**[Required]** Unique Group Artifact Version (GAV) identifier (Group:Artifact:Version), e.g.
-
#node_id ⇒ String
**[Required]** Unique identifier of an Application Dependency node, e.g.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ApplicationDependency
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ApplicationDependency
Initializes the object
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/oci/adm/models/application_dependency.rb', line 53 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.gav = attributes[:'gav'] if attributes[:'gav'] self.node_id = attributes[:'nodeId'] if attributes[:'nodeId'] raise 'You cannot provide both :nodeId and :node_id' if attributes.key?(:'nodeId') && attributes.key?(:'node_id') self.node_id = attributes[:'node_id'] if attributes[:'node_id'] self.application_dependency_node_ids = attributes[:'applicationDependencyNodeIds'] if attributes[:'applicationDependencyNodeIds'] raise 'You cannot provide both :applicationDependencyNodeIds and :application_dependency_node_ids' if attributes.key?(:'applicationDependencyNodeIds') && attributes.key?(:'application_dependency_node_ids') self.application_dependency_node_ids = attributes[:'application_dependency_node_ids'] if attributes[:'application_dependency_node_ids'] end |
Instance Attribute Details
#application_dependency_node_ids ⇒ Array<String>
**[Required]** List of (Application Dependencies) node identifiers on which this node depends.
20 21 22 |
# File 'lib/oci/adm/models/application_dependency.rb', line 20 def application_dependency_node_ids @application_dependency_node_ids end |
#gav ⇒ String
**[Required]** Unique Group Artifact Version (GAV) identifier (Group:Artifact:Version), e.g. org.graalvm.nativeimage:svm:21.1.0.
12 13 14 |
# File 'lib/oci/adm/models/application_dependency.rb', line 12 def gav @gav end |
#node_id ⇒ String
**[Required]** Unique identifier of an Application Dependency node, e.g. nodeId1.
16 17 18 |
# File 'lib/oci/adm/models/application_dependency.rb', line 16 def node_id @node_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
23 24 25 26 27 28 29 30 31 |
# File 'lib/oci/adm/models/application_dependency.rb', line 23 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'gav': :'gav', 'node_id': :'nodeId', 'application_dependency_node_ids': :'applicationDependencyNodeIds' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
34 35 36 37 38 39 40 41 42 |
# File 'lib/oci/adm/models/application_dependency.rb', line 34 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'gav': :'String', 'node_id': :'String', 'application_dependency_node_ids': :'Array<String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
81 82 83 84 85 86 87 88 |
# File 'lib/oci/adm/models/application_dependency.rb', line 81 def ==(other) return true if equal?(other) self.class == other.class && gav == other.gav && node_id == other.node_id && application_dependency_node_ids == other.application_dependency_node_ids end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/oci/adm/models/application_dependency.rb', line 113 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
93 94 95 |
# File 'lib/oci/adm/models/application_dependency.rb', line 93 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
102 103 104 |
# File 'lib/oci/adm/models/application_dependency.rb', line 102 def hash [gav, node_id, application_dependency_node_ids].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
146 147 148 149 150 151 152 153 154 155 |
# File 'lib/oci/adm/models/application_dependency.rb', line 146 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
140 141 142 |
# File 'lib/oci/adm/models/application_dependency.rb', line 140 def to_s to_hash.to_s end |