Class: OCI::Adm::Models::ApplicationDependencyVulnerabilitySummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/adm/models/application_dependency_vulnerability_summary.rb

Overview

An Application Dependency Vulnerability represents a single dependency in our application. An Application Dependency Vulnerability can be associated with eventual Vulnerabilities. Each Application Dependency is uniquely defined by a nodeId and lists eventual dependencies that this element depends on.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ApplicationDependencyVulnerabilitySummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/oci/adm/models/application_dependency_vulnerability_summary.rb', line 70

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.gav = attributes[:'gav'] if attributes[:'gav']

  self.node_id = attributes[:'nodeId'] if attributes[:'nodeId']

  raise 'You cannot provide both :nodeId and :node_id' if attributes.key?(:'nodeId') && attributes.key?(:'node_id')

  self.node_id = attributes[:'node_id'] if attributes[:'node_id']

  self.application_dependency_node_ids = attributes[:'applicationDependencyNodeIds'] if attributes[:'applicationDependencyNodeIds']

  raise 'You cannot provide both :applicationDependencyNodeIds and :application_dependency_node_ids' if attributes.key?(:'applicationDependencyNodeIds') && attributes.key?(:'application_dependency_node_ids')

  self.application_dependency_node_ids = attributes[:'application_dependency_node_ids'] if attributes[:'application_dependency_node_ids']

  self.vulnerabilities = attributes[:'vulnerabilities'] if attributes[:'vulnerabilities']

  self.is_found_in_knowledge_base = attributes[:'isFoundInKnowledgeBase'] unless attributes[:'isFoundInKnowledgeBase'].nil?

  raise 'You cannot provide both :isFoundInKnowledgeBase and :is_found_in_knowledge_base' if attributes.key?(:'isFoundInKnowledgeBase') && attributes.key?(:'is_found_in_knowledge_base')

  self.is_found_in_knowledge_base = attributes[:'is_found_in_knowledge_base'] unless attributes[:'is_found_in_knowledge_base'].nil?
end

Instance Attribute Details

#application_dependency_node_idsArray<String>

**[Required]** List of (Application Dependencies) node identifiers on which this node depends.

Returns:

  • (Array<String>)


23
24
25
# File 'lib/oci/adm/models/application_dependency_vulnerability_summary.rb', line 23

def application_dependency_node_ids
  @application_dependency_node_ids
end

#gavString

**[Required]** Unique Group Artifact Version (GAV) identifier (Group:Artifact:Version), e.g. org.graalvm.nativeimage:svm:21.1.0.

Returns:

  • (String)


15
16
17
# File 'lib/oci/adm/models/application_dependency_vulnerability_summary.rb', line 15

def gav
  @gav
end

#is_found_in_knowledge_baseBOOLEAN

**[Required]** Indicates if the artifact is found in the knowledge base.

Returns:

  • (BOOLEAN)


31
32
33
# File 'lib/oci/adm/models/application_dependency_vulnerability_summary.rb', line 31

def is_found_in_knowledge_base
  @is_found_in_knowledge_base
end

#node_idString

**[Required]** Unique identifier of an Application Dependency node, e.g. nodeId1.

Returns:

  • (String)


19
20
21
# File 'lib/oci/adm/models/application_dependency_vulnerability_summary.rb', line 19

def node_id
  @node_id
end

#vulnerabilitiesArray<OCI::Adm::Models::Vulnerability>

**[Required]** List of vulnerabilities for the Application Dependency.



27
28
29
# File 'lib/oci/adm/models/application_dependency_vulnerability_summary.rb', line 27

def vulnerabilities
  @vulnerabilities
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
43
44
# File 'lib/oci/adm/models/application_dependency_vulnerability_summary.rb', line 34

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'gav': :'gav',
    'node_id': :'nodeId',
    'application_dependency_node_ids': :'applicationDependencyNodeIds',
    'vulnerabilities': :'vulnerabilities',
    'is_found_in_knowledge_base': :'isFoundInKnowledgeBase'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



47
48
49
50
51
52
53
54
55
56
57
# File 'lib/oci/adm/models/application_dependency_vulnerability_summary.rb', line 47

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'gav': :'String',
    'node_id': :'String',
    'application_dependency_node_ids': :'Array<String>',
    'vulnerabilities': :'Array<OCI::Adm::Models::Vulnerability>',
    'is_found_in_knowledge_base': :'BOOLEAN'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



106
107
108
109
110
111
112
113
114
115
# File 'lib/oci/adm/models/application_dependency_vulnerability_summary.rb', line 106

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    gav == other.gav &&
    node_id == other.node_id &&
    application_dependency_node_ids == other.application_dependency_node_ids &&
    vulnerabilities == other.vulnerabilities &&
    is_found_in_knowledge_base == other.is_found_in_knowledge_base
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/oci/adm/models/application_dependency_vulnerability_summary.rb', line 140

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


120
121
122
# File 'lib/oci/adm/models/application_dependency_vulnerability_summary.rb', line 120

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



129
130
131
# File 'lib/oci/adm/models/application_dependency_vulnerability_summary.rb', line 129

def hash
  [gav, node_id, application_dependency_node_ids, vulnerabilities, is_found_in_knowledge_base].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



173
174
175
176
177
178
179
180
181
182
# File 'lib/oci/adm/models/application_dependency_vulnerability_summary.rb', line 173

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



167
168
169
# File 'lib/oci/adm/models/application_dependency_vulnerability_summary.rb', line 167

def to_s
  to_hash.to_s
end