Class: OCI::Adm::Models::Vulnerability
- Inherits:
-
Object
- Object
- OCI::Adm::Models::Vulnerability
- Defined in:
- lib/oci/adm/models/vulnerability.rb
Overview
A vulnerability is a weakness or error in an artifact. A vulnerability is a generalization of a CVE (every CVE is a vulnerability, but not every vulnerability has a CVE).
Instance Attribute Summary collapse
-
#cvss_v2_score ⇒ Float
**[Required]** Common Vulnerability Scoring System (CVSS) Version 2.
-
#cvss_v3_score ⇒ Float
**[Required]** Common Vulnerability Scoring System (CVSS) Version 3.
-
#id ⇒ String
**[Required]** Unique vulnerability identifier, e.g.
-
#is_ignored ⇒ BOOLEAN
**[Required]** Indicates if the vulnerability was ignored according to the audit configuration.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Vulnerability
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Vulnerability
Initializes the object
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/oci/adm/models/vulnerability.rb', line 63 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.cvss_v2_score = attributes[:'cvssV2Score'] if attributes[:'cvssV2Score'] raise 'You cannot provide both :cvssV2Score and :cvss_v2_score' if attributes.key?(:'cvssV2Score') && attributes.key?(:'cvss_v2_score') self.cvss_v2_score = attributes[:'cvss_v2_score'] if attributes[:'cvss_v2_score'] self.cvss_v3_score = attributes[:'cvssV3Score'] if attributes[:'cvssV3Score'] raise 'You cannot provide both :cvssV3Score and :cvss_v3_score' if attributes.key?(:'cvssV3Score') && attributes.key?(:'cvss_v3_score') self.cvss_v3_score = attributes[:'cvss_v3_score'] if attributes[:'cvss_v3_score'] self.is_ignored = attributes[:'isIgnored'] unless attributes[:'isIgnored'].nil? raise 'You cannot provide both :isIgnored and :is_ignored' if attributes.key?(:'isIgnored') && attributes.key?(:'is_ignored') self.is_ignored = attributes[:'is_ignored'] unless attributes[:'is_ignored'].nil? end |
Instance Attribute Details
#cvss_v2_score ⇒ Float
**[Required]** Common Vulnerability Scoring System (CVSS) Version 2.
19 20 21 |
# File 'lib/oci/adm/models/vulnerability.rb', line 19 def cvss_v2_score @cvss_v2_score end |
#cvss_v3_score ⇒ Float
**[Required]** Common Vulnerability Scoring System (CVSS) Version 3.
23 24 25 |
# File 'lib/oci/adm/models/vulnerability.rb', line 23 def cvss_v3_score @cvss_v3_score end |
#id ⇒ String
**[Required]** Unique vulnerability identifier, e.g. CVE-1999-0067.
15 16 17 |
# File 'lib/oci/adm/models/vulnerability.rb', line 15 def id @id end |
#is_ignored ⇒ BOOLEAN
**[Required]** Indicates if the vulnerability was ignored according to the audit configuration.
27 28 29 |
# File 'lib/oci/adm/models/vulnerability.rb', line 27 def is_ignored @is_ignored end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
30 31 32 33 34 35 36 37 38 39 |
# File 'lib/oci/adm/models/vulnerability.rb', line 30 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'cvss_v2_score': :'cvssV2Score', 'cvss_v3_score': :'cvssV3Score', 'is_ignored': :'isIgnored' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
42 43 44 45 46 47 48 49 50 51 |
# File 'lib/oci/adm/models/vulnerability.rb', line 42 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'cvss_v2_score': :'Float', 'cvss_v3_score': :'Float', 'is_ignored': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
97 98 99 100 101 102 103 104 105 |
# File 'lib/oci/adm/models/vulnerability.rb', line 97 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && cvss_v2_score == other.cvss_v2_score && cvss_v3_score == other.cvss_v3_score && is_ignored == other.is_ignored end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/oci/adm/models/vulnerability.rb', line 130 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
110 111 112 |
# File 'lib/oci/adm/models/vulnerability.rb', line 110 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
119 120 121 |
# File 'lib/oci/adm/models/vulnerability.rb', line 119 def hash [id, cvss_v2_score, cvss_v3_score, is_ignored].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
163 164 165 166 167 168 169 170 171 172 |
# File 'lib/oci/adm/models/vulnerability.rb', line 163 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
157 158 159 |
# File 'lib/oci/adm/models/vulnerability.rb', line 157 def to_s to_hash.to_s end |