Class: OCI::Adm::Models::VulnerabilityAuditConfiguration
- Inherits:
-
Object
- Object
- OCI::Adm::Models::VulnerabilityAuditConfiguration
- Defined in:
- lib/oci/adm/models/vulnerability_audit_configuration.rb
Overview
Configuration for a Vulnerability Audit type: object
Instance Attribute Summary collapse
-
#exclusions ⇒ Array<String>
Pattern to exclude artifacts from audit.
-
#max_permissible_cvss_v2_score ⇒ Float
The minimum CVSS V2 score for a vulnerability to be considered by the audit as failed.
-
#max_permissible_cvss_v3_score ⇒ Float
The minimum CVSS V3 score for a vulnerability to be considered by the audit as failed.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VulnerabilityAuditConfiguration
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ VulnerabilityAuditConfiguration
Initializes the object
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/oci/adm/models/vulnerability_audit_configuration.rb', line 55 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.max_permissible_cvss_v2_score = attributes[:'maxPermissibleCvssV2Score'] if attributes[:'maxPermissibleCvssV2Score'] self.max_permissible_cvss_v2_score = 0.0 if max_permissible_cvss_v2_score.nil? && !attributes.key?(:'maxPermissibleCvssV2Score') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :maxPermissibleCvssV2Score and :max_permissible_cvss_v2_score' if attributes.key?(:'maxPermissibleCvssV2Score') && attributes.key?(:'max_permissible_cvss_v2_score') self.max_permissible_cvss_v2_score = attributes[:'max_permissible_cvss_v2_score'] if attributes[:'max_permissible_cvss_v2_score'] self.max_permissible_cvss_v2_score = 0.0 if max_permissible_cvss_v2_score.nil? && !attributes.key?(:'maxPermissibleCvssV2Score') && !attributes.key?(:'max_permissible_cvss_v2_score') # rubocop:disable Style/StringLiterals self.max_permissible_cvss_v3_score = attributes[:'maxPermissibleCvssV3Score'] if attributes[:'maxPermissibleCvssV3Score'] self.max_permissible_cvss_v3_score = 0.0 if max_permissible_cvss_v3_score.nil? && !attributes.key?(:'maxPermissibleCvssV3Score') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :maxPermissibleCvssV3Score and :max_permissible_cvss_v3_score' if attributes.key?(:'maxPermissibleCvssV3Score') && attributes.key?(:'max_permissible_cvss_v3_score') self.max_permissible_cvss_v3_score = attributes[:'max_permissible_cvss_v3_score'] if attributes[:'max_permissible_cvss_v3_score'] self.max_permissible_cvss_v3_score = 0.0 if max_permissible_cvss_v3_score.nil? && !attributes.key?(:'maxPermissibleCvssV3Score') && !attributes.key?(:'max_permissible_cvss_v3_score') # rubocop:disable Style/StringLiterals self.exclusions = attributes[:'exclusions'] if attributes[:'exclusions'] end |
Instance Attribute Details
#exclusions ⇒ Array<String>
Pattern to exclude artifacts from audit.
22 23 24 |
# File 'lib/oci/adm/models/vulnerability_audit_configuration.rb', line 22 def exclusions @exclusions end |
#max_permissible_cvss_v2_score ⇒ Float
The minimum CVSS V2 score for a vulnerability to be considered by the audit as failed.
14 15 16 |
# File 'lib/oci/adm/models/vulnerability_audit_configuration.rb', line 14 def max_permissible_cvss_v2_score @max_permissible_cvss_v2_score end |
#max_permissible_cvss_v3_score ⇒ Float
The minimum CVSS V3 score for a vulnerability to be considered by the audit as failed.
18 19 20 |
# File 'lib/oci/adm/models/vulnerability_audit_configuration.rb', line 18 def max_permissible_cvss_v3_score @max_permissible_cvss_v3_score end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
25 26 27 28 29 30 31 32 33 |
# File 'lib/oci/adm/models/vulnerability_audit_configuration.rb', line 25 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'max_permissible_cvss_v2_score': :'maxPermissibleCvssV2Score', 'max_permissible_cvss_v3_score': :'maxPermissibleCvssV3Score', 'exclusions': :'exclusions' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
36 37 38 39 40 41 42 43 44 |
# File 'lib/oci/adm/models/vulnerability_audit_configuration.rb', line 36 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'max_permissible_cvss_v2_score': :'Float', 'max_permissible_cvss_v3_score': :'Float', 'exclusions': :'Array<String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
87 88 89 90 91 92 93 94 |
# File 'lib/oci/adm/models/vulnerability_audit_configuration.rb', line 87 def ==(other) return true if equal?(other) self.class == other.class && max_permissible_cvss_v2_score == other.max_permissible_cvss_v2_score && max_permissible_cvss_v3_score == other.max_permissible_cvss_v3_score && exclusions == other.exclusions end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/oci/adm/models/vulnerability_audit_configuration.rb', line 119 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
99 100 101 |
# File 'lib/oci/adm/models/vulnerability_audit_configuration.rb', line 99 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
108 109 110 |
# File 'lib/oci/adm/models/vulnerability_audit_configuration.rb', line 108 def hash [max_permissible_cvss_v2_score, max_permissible_cvss_v3_score, exclusions].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
152 153 154 155 156 157 158 159 160 161 |
# File 'lib/oci/adm/models/vulnerability_audit_configuration.rb', line 152 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
146 147 148 |
# File 'lib/oci/adm/models/vulnerability_audit_configuration.rb', line 146 def to_s to_hash.to_s end |