Class: OCI::Adm::Models::VulnerabilityAuditSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/adm/models/vulnerability_audit_summary.rb

Overview

Vulnerability Audit summary.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ VulnerabilityAuditSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :display_name (String)

    The value to assign to the #display_name property

  • :knowledge_base_id (String)

    The value to assign to the #knowledge_base_id property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :time_updated (DateTime)

    The value to assign to the #time_updated property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :max_observed_cvss_v2_score (Float)

    The value to assign to the #max_observed_cvss_v2_score property

  • :max_observed_cvss_v3_score (Float)

    The value to assign to the #max_observed_cvss_v3_score property

  • :vulnerable_artifacts_count (Integer)

    The value to assign to the #vulnerable_artifacts_count property

  • :is_success (BOOLEAN)

    The value to assign to the #is_success property

  • :build_type (String)

    The value to assign to the #build_type property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property

  • :system_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #system_tags property



143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/oci/adm/models/vulnerability_audit_summary.rb', line 143

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.knowledge_base_id = attributes[:'knowledgeBaseId'] if attributes[:'knowledgeBaseId']

  raise 'You cannot provide both :knowledgeBaseId and :knowledge_base_id' if attributes.key?(:'knowledgeBaseId') && attributes.key?(:'knowledge_base_id')

  self.knowledge_base_id = attributes[:'knowledge_base_id'] if attributes[:'knowledge_base_id']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.max_observed_cvss_v2_score = attributes[:'maxObservedCvssV2Score'] if attributes[:'maxObservedCvssV2Score']

  raise 'You cannot provide both :maxObservedCvssV2Score and :max_observed_cvss_v2_score' if attributes.key?(:'maxObservedCvssV2Score') && attributes.key?(:'max_observed_cvss_v2_score')

  self.max_observed_cvss_v2_score = attributes[:'max_observed_cvss_v2_score'] if attributes[:'max_observed_cvss_v2_score']

  self.max_observed_cvss_v3_score = attributes[:'maxObservedCvssV3Score'] if attributes[:'maxObservedCvssV3Score']

  raise 'You cannot provide both :maxObservedCvssV3Score and :max_observed_cvss_v3_score' if attributes.key?(:'maxObservedCvssV3Score') && attributes.key?(:'max_observed_cvss_v3_score')

  self.max_observed_cvss_v3_score = attributes[:'max_observed_cvss_v3_score'] if attributes[:'max_observed_cvss_v3_score']

  self.vulnerable_artifacts_count = attributes[:'vulnerableArtifactsCount'] if attributes[:'vulnerableArtifactsCount']

  raise 'You cannot provide both :vulnerableArtifactsCount and :vulnerable_artifacts_count' if attributes.key?(:'vulnerableArtifactsCount') && attributes.key?(:'vulnerable_artifacts_count')

  self.vulnerable_artifacts_count = attributes[:'vulnerable_artifacts_count'] if attributes[:'vulnerable_artifacts_count']

  self.is_success = attributes[:'isSuccess'] unless attributes[:'isSuccess'].nil?

  raise 'You cannot provide both :isSuccess and :is_success' if attributes.key?(:'isSuccess') && attributes.key?(:'is_success')

  self.is_success = attributes[:'is_success'] unless attributes[:'is_success'].nil?

  self.build_type = attributes[:'buildType'] if attributes[:'buildType']

  raise 'You cannot provide both :buildType and :build_type' if attributes.key?(:'buildType') && attributes.key?(:'build_type')

  self.build_type = attributes[:'build_type'] if attributes[:'build_type']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

  raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

  self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']
end

Instance Attribute Details

#build_typeString

Type of the build tool.

Returns:

  • (String)


52
53
54
# File 'lib/oci/adm/models/vulnerability_audit_summary.rb', line 52

def build_type
  @build_type
end

#compartment_idString

**[Required]** The Oracle Cloud identifier ([OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the compartment associated with the Vulnerability Audit.

Returns:

  • (String)


56
57
58
# File 'lib/oci/adm/models/vulnerability_audit_summary.rb', line 56

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


68
69
70
# File 'lib/oci/adm/models/vulnerability_audit_summary.rb', line 68

def defined_tags
  @defined_tags
end

#display_nameString

The name of the Vulnerability Audit.

Returns:

  • (String)


16
17
18
# File 'lib/oci/adm/models/vulnerability_audit_summary.rb', line 16

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`

Returns:

  • (Hash<String, String>)


62
63
64
# File 'lib/oci/adm/models/vulnerability_audit_summary.rb', line 62

def freeform_tags
  @freeform_tags
end

#idString

**[Required]** The Oracle Cloud identifier ([OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the Vulnerability Audit.

Returns:

  • (String)


12
13
14
# File 'lib/oci/adm/models/vulnerability_audit_summary.rb', line 12

def id
  @id
end

#is_successBOOLEAN

Indicates if an audit succeeded according to the configuration. The value is `null` if the audit is in the `CREATING` state.

Returns:

  • (BOOLEAN)


48
49
50
# File 'lib/oci/adm/models/vulnerability_audit_summary.rb', line 48

def is_success
  @is_success
end

#knowledge_base_idString

**[Required]** The Oracle Cloud identifier ([OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the Knowledge Base.

Returns:

  • (String)


20
21
22
# File 'lib/oci/adm/models/vulnerability_audit_summary.rb', line 20

def knowledge_base_id
  @knowledge_base_id
end

#lifecycle_stateString

**[Required]** The current lifecycle state of the Vulnerability Audit.

Returns:

  • (String)


32
33
34
# File 'lib/oci/adm/models/vulnerability_audit_summary.rb', line 32

def lifecycle_state
  @lifecycle_state
end

#max_observed_cvss_v2_scoreFloat

**[Required]** Maximum Common Vulnerability Scoring System Version 2 score of vulnerabilities.

Returns:

  • (Float)


36
37
38
# File 'lib/oci/adm/models/vulnerability_audit_summary.rb', line 36

def max_observed_cvss_v2_score
  @max_observed_cvss_v2_score
end

#max_observed_cvss_v3_scoreFloat

**[Required]** Maximum Common Vulnerability Scoring System Version 3 score of vulnerabilities.

Returns:

  • (Float)


40
41
42
# File 'lib/oci/adm/models/vulnerability_audit_summary.rb', line 40

def max_observed_cvss_v3_score
  @max_observed_cvss_v3_score
end

#system_tagsHash<String, Hash<String, Object>>

Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"free-tier-retained": "true"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


74
75
76
# File 'lib/oci/adm/models/vulnerability_audit_summary.rb', line 74

def system_tags
  @system_tags
end

#time_createdDateTime

**[Required]** The creation date and time of the Vulnerability Audit (formatted according to [RFC3339](datatracker.ietf.org/doc/html/rfc3339)).

Returns:

  • (DateTime)


24
25
26
# File 'lib/oci/adm/models/vulnerability_audit_summary.rb', line 24

def time_created
  @time_created
end

#time_updatedDateTime

**[Required]** The update date and time of the Vulnerability Audit (formatted according to [RFC3339](datatracker.ietf.org/doc/html/rfc3339)).

Returns:

  • (DateTime)


28
29
30
# File 'lib/oci/adm/models/vulnerability_audit_summary.rb', line 28

def time_updated
  @time_updated
end

#vulnerable_artifacts_countInteger

**[Required]** Count of vulnerable artifacts.

Returns:

  • (Integer)


44
45
46
# File 'lib/oci/adm/models/vulnerability_audit_summary.rb', line 44

def vulnerable_artifacts_count
  @vulnerable_artifacts_count
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/oci/adm/models/vulnerability_audit_summary.rb', line 77

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'display_name': :'displayName',
    'knowledge_base_id': :'knowledgeBaseId',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'lifecycle_state': :'lifecycleState',
    'max_observed_cvss_v2_score': :'maxObservedCvssV2Score',
    'max_observed_cvss_v3_score': :'maxObservedCvssV3Score',
    'vulnerable_artifacts_count': :'vulnerableArtifactsCount',
    'is_success': :'isSuccess',
    'build_type': :'buildType',
    'compartment_id': :'compartmentId',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/oci/adm/models/vulnerability_audit_summary.rb', line 100

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'display_name': :'String',
    'knowledge_base_id': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'lifecycle_state': :'String',
    'max_observed_cvss_v2_score': :'Float',
    'max_observed_cvss_v3_score': :'Float',
    'vulnerable_artifacts_count': :'Integer',
    'is_success': :'BOOLEAN',
    'build_type': :'String',
    'compartment_id': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
# File 'lib/oci/adm/models/vulnerability_audit_summary.rb', line 243

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    display_name == other.display_name &&
    knowledge_base_id == other.knowledge_base_id &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    lifecycle_state == other.lifecycle_state &&
    max_observed_cvss_v2_score == other.max_observed_cvss_v2_score &&
    max_observed_cvss_v3_score == other.max_observed_cvss_v3_score &&
    vulnerable_artifacts_count == other.vulnerable_artifacts_count &&
    is_success == other.is_success &&
    build_type == other.build_type &&
    compartment_id == other.compartment_id &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
# File 'lib/oci/adm/models/vulnerability_audit_summary.rb', line 287

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


267
268
269
# File 'lib/oci/adm/models/vulnerability_audit_summary.rb', line 267

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



276
277
278
# File 'lib/oci/adm/models/vulnerability_audit_summary.rb', line 276

def hash
  [id, display_name, knowledge_base_id, time_created, time_updated, lifecycle_state, max_observed_cvss_v2_score, max_observed_cvss_v3_score, vulnerable_artifacts_count, is_success, build_type, compartment_id, freeform_tags, defined_tags, system_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



320
321
322
323
324
325
326
327
328
329
# File 'lib/oci/adm/models/vulnerability_audit_summary.rb', line 320

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



314
315
316
# File 'lib/oci/adm/models/vulnerability_audit_summary.rb', line 314

def to_s
  to_hash.to_s
end