Class: OCI::Adm::Models::WorkRequestSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/adm/models/work_request_summary.rb

Overview

A summary of the status of a work request.

Constant Summary collapse

OPERATION_TYPE_ENUM =
[
  OPERATION_TYPE_CREATE_KNOWLEDGE_BASE = 'CREATE_KNOWLEDGE_BASE'.freeze,
  OPERATION_TYPE_DELETE_KNOWLEDGE_BASE = 'DELETE_KNOWLEDGE_BASE'.freeze,
  OPERATION_TYPE_MOVE_KNOWLEDGE_BASE = 'MOVE_KNOWLEDGE_BASE'.freeze,
  OPERATION_TYPE_UPDATE_KNOWLEDGE_BASE = 'UPDATE_KNOWLEDGE_BASE'.freeze,
  OPERATION_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
STATUS_ENUM =
[
  STATUS_ACCEPTED = 'ACCEPTED'.freeze,
  STATUS_IN_PROGRESS = 'IN_PROGRESS'.freeze,
  STATUS_WAITING = 'WAITING'.freeze,
  STATUS_FAILED = 'FAILED'.freeze,
  STATUS_SUCCEEDED = 'SUCCEEDED'.freeze,
  STATUS_CANCELING = 'CANCELING'.freeze,
  STATUS_CANCELED = 'CANCELED'.freeze,
  STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ WorkRequestSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :operation_type (String)

    The value to assign to the #operation_type property

  • :status (String)

    The value to assign to the #status property

  • :id (String)

    The value to assign to the #id property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :resources (Array<OCI::Adm::Models::WorkRequestResource>)

    The value to assign to the #resources property

  • :percent_complete (Float)

    The value to assign to the #percent_complete property

  • :time_accepted (DateTime)

    The value to assign to the #time_accepted property

  • :time_started (DateTime)

    The value to assign to the #time_started property

  • :time_finished (DateTime)

    The value to assign to the #time_finished property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/oci/adm/models/work_request_summary.rb', line 142

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.operation_type = attributes[:'operationType'] if attributes[:'operationType']

  raise 'You cannot provide both :operationType and :operation_type' if attributes.key?(:'operationType') && attributes.key?(:'operation_type')

  self.operation_type = attributes[:'operation_type'] if attributes[:'operation_type']

  self.status = attributes[:'status'] if attributes[:'status']

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.resources = attributes[:'resources'] if attributes[:'resources']

  self.percent_complete = attributes[:'percentComplete'] if attributes[:'percentComplete']

  raise 'You cannot provide both :percentComplete and :percent_complete' if attributes.key?(:'percentComplete') && attributes.key?(:'percent_complete')

  self.percent_complete = attributes[:'percent_complete'] if attributes[:'percent_complete']

  self.time_accepted = attributes[:'timeAccepted'] if attributes[:'timeAccepted']

  raise 'You cannot provide both :timeAccepted and :time_accepted' if attributes.key?(:'timeAccepted') && attributes.key?(:'time_accepted')

  self.time_accepted = attributes[:'time_accepted'] if attributes[:'time_accepted']

  self.time_started = attributes[:'timeStarted'] if attributes[:'timeStarted']

  raise 'You cannot provide both :timeStarted and :time_started' if attributes.key?(:'timeStarted') && attributes.key?(:'time_started')

  self.time_started = attributes[:'time_started'] if attributes[:'time_started']

  self.time_finished = attributes[:'timeFinished'] if attributes[:'timeFinished']

  raise 'You cannot provide both :timeFinished and :time_finished' if attributes.key?(:'timeFinished') && attributes.key?(:'time_finished')

  self.time_finished = attributes[:'time_finished'] if attributes[:'time_finished']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#compartment_idString

**[Required]** The ocid of the compartment that contains the work request. Work requests should be scoped to the same compartment as the resource the work request affects. If the work request affects multiple resources, and those resources are not in the same compartment, it is up to the service team to pick the primary resource whose compartment should be used

Returns:

  • (String)


48
49
50
# File 'lib/oci/adm/models/work_request_summary.rb', line 48

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

**[Required]** Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


85
86
87
# File 'lib/oci/adm/models/work_request_summary.rb', line 85

def defined_tags
  @defined_tags
end

#freeform_tagsHash<String, String>

**[Required]** Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`

Returns:

  • (Hash<String, String>)


79
80
81
# File 'lib/oci/adm/models/work_request_summary.rb', line 79

def freeform_tags
  @freeform_tags
end

#idString

**[Required]** The id of the work request.

Returns:

  • (String)


40
41
42
# File 'lib/oci/adm/models/work_request_summary.rb', line 40

def id
  @id
end

#operation_typeString

**[Required]** Type of the work request

Returns:

  • (String)


32
33
34
# File 'lib/oci/adm/models/work_request_summary.rb', line 32

def operation_type
  @operation_type
end

#percent_completeFloat

**[Required]** Percentage of the request completed.

Returns:

  • (Float)


56
57
58
# File 'lib/oci/adm/models/work_request_summary.rb', line 56

def percent_complete
  @percent_complete
end

#resourcesArray<OCI::Adm::Models::WorkRequestResource>

**[Required]** The resources affected by this work request.



52
53
54
# File 'lib/oci/adm/models/work_request_summary.rb', line 52

def resources
  @resources
end

#statusString

**[Required]** Status of current work request.

Returns:

  • (String)


36
37
38
# File 'lib/oci/adm/models/work_request_summary.rb', line 36

def status
  @status
end

#time_acceptedDateTime

**[Required]** The date and time the request was created, as described in [RFC 3339](tools.ietf.org/rfc/rfc3339), section 14.29.

Returns:

  • (DateTime)


62
63
64
# File 'lib/oci/adm/models/work_request_summary.rb', line 62

def time_accepted
  @time_accepted
end

#time_finishedDateTime

The date and time the object was finished, as described in [RFC 3339](tools.ietf.org/rfc/rfc3339).

Returns:

  • (DateTime)


73
74
75
# File 'lib/oci/adm/models/work_request_summary.rb', line 73

def time_finished
  @time_finished
end

#time_startedDateTime

The date and time the request was started, as described in [RFC 3339](tools.ietf.org/rfc/rfc3339), section 14.29.

Returns:

  • (DateTime)


68
69
70
# File 'lib/oci/adm/models/work_request_summary.rb', line 68

def time_started
  @time_started
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/oci/adm/models/work_request_summary.rb', line 88

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'operation_type': :'operationType',
    'status': :'status',
    'id': :'id',
    'compartment_id': :'compartmentId',
    'resources': :'resources',
    'percent_complete': :'percentComplete',
    'time_accepted': :'timeAccepted',
    'time_started': :'timeStarted',
    'time_finished': :'timeFinished',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/oci/adm/models/work_request_summary.rb', line 107

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'operation_type': :'String',
    'status': :'String',
    'id': :'String',
    'compartment_id': :'String',
    'resources': :'Array<OCI::Adm::Models::WorkRequestResource>',
    'percent_complete': :'Float',
    'time_accepted': :'DateTime',
    'time_started': :'DateTime',
    'time_finished': :'DateTime',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/oci/adm/models/work_request_summary.rb', line 236

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    operation_type == other.operation_type &&
    status == other.status &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    resources == other.resources &&
    percent_complete == other.percent_complete &&
    time_accepted == other.time_accepted &&
    time_started == other.time_started &&
    time_finished == other.time_finished &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
# File 'lib/oci/adm/models/work_request_summary.rb', line 276

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


256
257
258
# File 'lib/oci/adm/models/work_request_summary.rb', line 256

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



265
266
267
# File 'lib/oci/adm/models/work_request_summary.rb', line 265

def hash
  [operation_type, status, id, compartment_id, resources, percent_complete, time_accepted, time_started, time_finished, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



309
310
311
312
313
314
315
316
317
318
# File 'lib/oci/adm/models/work_request_summary.rb', line 309

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



303
304
305
# File 'lib/oci/adm/models/work_request_summary.rb', line 303

def to_s
  to_hash.to_s
end