Class: AiAnomalyDetection::Models::Anomaly

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/ai_anomaly_detection/models/anomaly.rb

Overview

An object to hold value information for each anomaly point

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Anomaly

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :signal_name (String)

    The value to assign to the #signal_name property

  • :actual_value (Float)

    The value to assign to the #actual_value property

  • :estimated_value (Float)

    The value to assign to the #estimated_value property

  • :imputed_value (Float)

    The value to assign to the #imputed_value property

  • :anomaly_score (Float)

    The value to assign to the #anomaly_score property



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/oci/ai_anomaly_detection/models/anomaly.rb', line 67

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.signal_name = attributes[:'signalName'] if attributes[:'signalName']

  raise 'You cannot provide both :signalName and :signal_name' if attributes.key?(:'signalName') && attributes.key?(:'signal_name')

  self.signal_name = attributes[:'signal_name'] if attributes[:'signal_name']

  self.actual_value = attributes[:'actualValue'] if attributes[:'actualValue']

  raise 'You cannot provide both :actualValue and :actual_value' if attributes.key?(:'actualValue') && attributes.key?(:'actual_value')

  self.actual_value = attributes[:'actual_value'] if attributes[:'actual_value']

  self.estimated_value = attributes[:'estimatedValue'] if attributes[:'estimatedValue']

  raise 'You cannot provide both :estimatedValue and :estimated_value' if attributes.key?(:'estimatedValue') && attributes.key?(:'estimated_value')

  self.estimated_value = attributes[:'estimated_value'] if attributes[:'estimated_value']

  self.imputed_value = attributes[:'imputedValue'] if attributes[:'imputedValue']

  raise 'You cannot provide both :imputedValue and :imputed_value' if attributes.key?(:'imputedValue') && attributes.key?(:'imputed_value')

  self.imputed_value = attributes[:'imputed_value'] if attributes[:'imputed_value']

  self.anomaly_score = attributes[:'anomalyScore'] if attributes[:'anomalyScore']

  raise 'You cannot provide both :anomalyScore and :anomaly_score' if attributes.key?(:'anomalyScore') && attributes.key?(:'anomaly_score')

  self.anomaly_score = attributes[:'anomaly_score'] if attributes[:'anomaly_score']
end

Instance Attribute Details

#actual_valueFloat

**[Required]** The actual value for the anomaly point at given signal and timestamp/row

Returns:

  • (Float)


16
17
18
# File 'lib/oci/ai_anomaly_detection/models/anomaly.rb', line 16

def actual_value
  @actual_value
end

#anomaly_scoreFloat

**[Required]** A significant score ranged from 0 to 1 to each anomaly point

Returns:

  • (Float)


28
29
30
# File 'lib/oci/ai_anomaly_detection/models/anomaly.rb', line 28

def anomaly_score
  @anomaly_score
end

#estimated_valueFloat

**[Required]** The estimated value for the anomaly point at given signal and timestamp/row

Returns:

  • (Float)


20
21
22
# File 'lib/oci/ai_anomaly_detection/models/anomaly.rb', line 20

def estimated_value
  @estimated_value
end

#imputed_valueFloat

The value imputed by one of IDP step for missing values in origin data

Returns:

  • (Float)


24
25
26
# File 'lib/oci/ai_anomaly_detection/models/anomaly.rb', line 24

def imputed_value
  @imputed_value
end

#signal_nameString

**[Required]** Name of a signal where current anomaly point belongs to

Returns:

  • (String)


12
13
14
# File 'lib/oci/ai_anomaly_detection/models/anomaly.rb', line 12

def signal_name
  @signal_name
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
40
41
# File 'lib/oci/ai_anomaly_detection/models/anomaly.rb', line 31

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'signal_name': :'signalName',
    'actual_value': :'actualValue',
    'estimated_value': :'estimatedValue',
    'imputed_value': :'imputedValue',
    'anomaly_score': :'anomalyScore'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



44
45
46
47
48
49
50
51
52
53
54
# File 'lib/oci/ai_anomaly_detection/models/anomaly.rb', line 44

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'signal_name': :'String',
    'actual_value': :'Float',
    'estimated_value': :'Float',
    'imputed_value': :'Float',
    'anomaly_score': :'Float'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



111
112
113
114
115
116
117
118
119
120
# File 'lib/oci/ai_anomaly_detection/models/anomaly.rb', line 111

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    signal_name == other.signal_name &&
    actual_value == other.actual_value &&
    estimated_value == other.estimated_value &&
    imputed_value == other.imputed_value &&
    anomaly_score == other.anomaly_score
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/oci/ai_anomaly_detection/models/anomaly.rb', line 145

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


125
126
127
# File 'lib/oci/ai_anomaly_detection/models/anomaly.rb', line 125

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



134
135
136
# File 'lib/oci/ai_anomaly_detection/models/anomaly.rb', line 134

def hash
  [signal_name, actual_value, estimated_value, imputed_value, anomaly_score].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



178
179
180
181
182
183
184
185
186
187
# File 'lib/oci/ai_anomaly_detection/models/anomaly.rb', line 178

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



172
173
174
# File 'lib/oci/ai_anomaly_detection/models/anomaly.rb', line 172

def to_s
  to_hash.to_s
end