Class: OCI::AiAnomalyDetection::Models::CreateDataAssetDetails
- Inherits:
-
Object
- Object
- OCI::AiAnomalyDetection::Models::CreateDataAssetDetails
- Defined in:
- lib/oci/ai_anomaly_detection/models/create_data_asset_details.rb
Overview
Parameters needed to create a new data asset.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The OCID for the data asset’s compartment.
-
#data_source_details ⇒ OCI::AiAnomalyDetection::Models::DataSourceDetails
This attribute is required.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
A short description of the Ai data asset.
-
#display_name ⇒ String
A user-friendly display name for the resource.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#private_endpoint_id ⇒ String
OCID of Private Endpoint.
-
#project_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the project to associate with the data asset.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateDataAssetDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateDataAssetDetails
Initializes the object
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/oci/ai_anomaly_detection/models/create_data_asset_details.rb', line 93 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.project_id = attributes[:'projectId'] if attributes[:'projectId'] raise 'You cannot provide both :projectId and :project_id' if attributes.key?(:'projectId') && attributes.key?(:'project_id') self.project_id = attributes[:'project_id'] if attributes[:'project_id'] self.description = attributes[:'description'] if attributes[:'description'] self.data_source_details = attributes[:'dataSourceDetails'] if attributes[:'dataSourceDetails'] raise 'You cannot provide both :dataSourceDetails and :data_source_details' if attributes.key?(:'dataSourceDetails') && attributes.key?(:'data_source_details') self.data_source_details = attributes[:'data_source_details'] if attributes[:'data_source_details'] self.private_endpoint_id = attributes[:'privateEndpointId'] if attributes[:'privateEndpointId'] raise 'You cannot provide both :privateEndpointId and :private_endpoint_id' if attributes.key?(:'privateEndpointId') && attributes.key?(:'private_endpoint_id') self.private_endpoint_id = attributes[:'private_endpoint_id'] if attributes[:'private_endpoint_id'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The OCID for the data asset’s compartment.
17 18 19 |
# File 'lib/oci/ai_anomaly_detection/models/create_data_asset_details.rb', line 17 def compartment_id @compartment_id end |
#data_source_details ⇒ OCI::AiAnomalyDetection::Models::DataSourceDetails
This attribute is required.
29 30 31 |
# File 'lib/oci/ai_anomaly_detection/models/create_data_asset_details.rb', line 29 def data_source_details @data_source_details end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
45 46 47 |
# File 'lib/oci/ai_anomaly_detection/models/create_data_asset_details.rb', line 45 def end |
#description ⇒ String
A short description of the Ai data asset
25 26 27 |
# File 'lib/oci/ai_anomaly_detection/models/create_data_asset_details.rb', line 25 def description @description end |
#display_name ⇒ String
A user-friendly display name for the resource. It does not have to be unique and can be modified. Avoid entering confidential information.
13 14 15 |
# File 'lib/oci/ai_anomaly_detection/models/create_data_asset_details.rb', line 13 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`
39 40 41 |
# File 'lib/oci/ai_anomaly_detection/models/create_data_asset_details.rb', line 39 def end |
#private_endpoint_id ⇒ String
OCID of Private Endpoint.
33 34 35 |
# File 'lib/oci/ai_anomaly_detection/models/create_data_asset_details.rb', line 33 def private_endpoint_id @private_endpoint_id end |
#project_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the project to associate with the data asset.
21 22 23 |
# File 'lib/oci/ai_anomaly_detection/models/create_data_asset_details.rb', line 21 def project_id @project_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/oci/ai_anomaly_detection/models/create_data_asset_details.rb', line 48 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'project_id': :'projectId', 'description': :'description', 'data_source_details': :'dataSourceDetails', 'private_endpoint_id': :'privateEndpointId', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/oci/ai_anomaly_detection/models/create_data_asset_details.rb', line 64 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'compartment_id': :'String', 'project_id': :'String', 'description': :'String', 'data_source_details': :'OCI::AiAnomalyDetection::Models::DataSourceDetails', 'private_endpoint_id': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/oci/ai_anomaly_detection/models/create_data_asset_details.rb', line 151 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && compartment_id == other.compartment_id && project_id == other.project_id && description == other.description && data_source_details == other.data_source_details && private_endpoint_id == other.private_endpoint_id && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/oci/ai_anomaly_detection/models/create_data_asset_details.rb', line 188 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
168 169 170 |
# File 'lib/oci/ai_anomaly_detection/models/create_data_asset_details.rb', line 168 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
177 178 179 |
# File 'lib/oci/ai_anomaly_detection/models/create_data_asset_details.rb', line 177 def hash [display_name, compartment_id, project_id, description, data_source_details, private_endpoint_id, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
221 222 223 224 225 226 227 228 229 230 |
# File 'lib/oci/ai_anomaly_detection/models/create_data_asset_details.rb', line 221 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
215 216 217 |
# File 'lib/oci/ai_anomaly_detection/models/create_data_asset_details.rb', line 215 def to_s to_hash.to_s end |