Class: AiAnomalyDetection::Models::DataAsset
- Inherits:
-
Object
- Object
- AiAnomalyDetection::Models::DataAsset
- Defined in:
- lib/oci/ai_anomaly_detection/models/data_asset.rb
Overview
Description of DataAsset.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The OCID of the compartment containing the DataAsset.
-
#data_source_details ⇒ OCI::AiAnomalyDetection::Models::DataSourceDetails
This attribute is required.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
A short description of the data asset.
-
#display_name ⇒ String
**[Required]** A user-friendly name.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
**[Required]** The Unique Oracle ID (OCID) that is immutable on creation.
-
#lifecycle_state ⇒ String
**[Required]** The lifecycle state of the Data Asset.
-
#private_endpoint_id ⇒ String
OCID of Private Endpoint.
-
#project_id ⇒ String
**[Required]** The Unique project id which is created at project creation that is immutable on creation.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys.
-
#time_created ⇒ DateTime
**[Required]** The time the the DataAsset was created.
-
#time_updated ⇒ DateTime
The time the the DataAsset was updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DataAsset
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DataAsset
Initializes the object
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/oci/ai_anomaly_detection/models/data_asset.rb', line 136 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.project_id = attributes[:'projectId'] if attributes[:'projectId'] raise 'You cannot provide both :projectId and :project_id' if attributes.key?(:'projectId') && attributes.key?(:'project_id') self.project_id = attributes[:'project_id'] if attributes[:'project_id'] self.data_source_details = attributes[:'dataSourceDetails'] if attributes[:'dataSourceDetails'] raise 'You cannot provide both :dataSourceDetails and :data_source_details' if attributes.key?(:'dataSourceDetails') && attributes.key?(:'data_source_details') self.data_source_details = attributes[:'data_source_details'] if attributes[:'data_source_details'] self.private_endpoint_id = attributes[:'privateEndpointId'] if attributes[:'privateEndpointId'] raise 'You cannot provide both :privateEndpointId and :private_endpoint_id' if attributes.key?(:'privateEndpointId') && attributes.key?(:'private_endpoint_id') self.private_endpoint_id = attributes[:'private_endpoint_id'] if attributes[:'private_endpoint_id'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The OCID of the compartment containing the DataAsset.
23 24 25 |
# File 'lib/oci/ai_anomaly_detection/models/data_asset.rb', line 23 def compartment_id @compartment_id end |
#data_source_details ⇒ OCI::AiAnomalyDetection::Models::DataSourceDetails
This attribute is required.
51 52 53 |
# File 'lib/oci/ai_anomaly_detection/models/data_asset.rb', line 51 def data_source_details @data_source_details end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
67 68 69 |
# File 'lib/oci/ai_anomaly_detection/models/data_asset.rb', line 67 def @defined_tags end |
#description ⇒ String
A short description of the data asset.
31 32 33 |
# File 'lib/oci/ai_anomaly_detection/models/data_asset.rb', line 31 def description @description end |
#display_name ⇒ String
**[Required]** A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
27 28 29 |
# File 'lib/oci/ai_anomaly_detection/models/data_asset.rb', line 27 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
61 62 63 |
# File 'lib/oci/ai_anomaly_detection/models/data_asset.rb', line 61 def @freeform_tags end |
#id ⇒ String
**[Required]** The Unique Oracle ID (OCID) that is immutable on creation.
19 20 21 |
# File 'lib/oci/ai_anomaly_detection/models/data_asset.rb', line 19 def id @id end |
#lifecycle_state ⇒ String
**[Required]** The lifecycle state of the Data Asset.
43 44 45 |
# File 'lib/oci/ai_anomaly_detection/models/data_asset.rb', line 43 def lifecycle_state @lifecycle_state end |
#private_endpoint_id ⇒ String
OCID of Private Endpoint.
55 56 57 |
# File 'lib/oci/ai_anomaly_detection/models/data_asset.rb', line 55 def private_endpoint_id @private_endpoint_id end |
#project_id ⇒ String
**[Required]** The Unique project id which is created at project creation that is immutable on creation.
47 48 49 |
# File 'lib/oci/ai_anomaly_detection/models/data_asset.rb', line 47 def project_id @project_id end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"free-tier-retained": "true"}`
73 74 75 |
# File 'lib/oci/ai_anomaly_detection/models/data_asset.rb', line 73 def @system_tags end |
#time_created ⇒ DateTime
**[Required]** The time the the DataAsset was created. An RFC3339 formatted datetime string
35 36 37 |
# File 'lib/oci/ai_anomaly_detection/models/data_asset.rb', line 35 def time_created @time_created end |
#time_updated ⇒ DateTime
The time the the DataAsset was updated. An RFC3339 formatted datetime string
39 40 41 |
# File 'lib/oci/ai_anomaly_detection/models/data_asset.rb', line 39 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/oci/ai_anomaly_detection/models/data_asset.rb', line 76 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'description': :'description', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'project_id': :'projectId', 'data_source_details': :'dataSourceDetails', 'private_endpoint_id': :'privateEndpointId', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/oci/ai_anomaly_detection/models/data_asset.rb', line 97 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'display_name': :'String', 'description': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'project_id': :'String', 'data_source_details': :'OCI::AiAnomalyDetection::Models::DataSourceDetails', 'private_endpoint_id': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/oci/ai_anomaly_detection/models/data_asset.rb', line 233 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && display_name == other.display_name && description == other.description && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && project_id == other.project_id && data_source_details == other.data_source_details && private_endpoint_id == other.private_endpoint_id && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/oci/ai_anomaly_detection/models/data_asset.rb', line 275 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
255 256 257 |
# File 'lib/oci/ai_anomaly_detection/models/data_asset.rb', line 255 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
264 265 266 |
# File 'lib/oci/ai_anomaly_detection/models/data_asset.rb', line 264 def hash [id, compartment_id, display_name, description, time_created, time_updated, lifecycle_state, project_id, data_source_details, private_endpoint_id, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
308 309 310 311 312 313 314 315 316 317 |
# File 'lib/oci/ai_anomaly_detection/models/data_asset.rb', line 308 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
302 303 304 |
# File 'lib/oci/ai_anomaly_detection/models/data_asset.rb', line 302 def to_s to_hash.to_s end |