Class: OCI::AiAnomalyDetection::Models::DataSourceDetailsATP
- Inherits:
-
DataSourceDetails
- Object
- DataSourceDetails
- OCI::AiAnomalyDetection::Models::DataSourceDetailsATP
- Defined in:
- lib/oci/ai_anomaly_detection/models/data_source_details_atp.rb
Overview
Data Source details for ATP
Constant Summary
Constants inherited from DataSourceDetails
OCI::AiAnomalyDetection::Models::DataSourceDetails::DATA_SOURCE_TYPE_ENUM
Instance Attribute Summary collapse
-
#atp_password_secret_id ⇒ String
atp db password Secret Id.
-
#atp_user_name ⇒ String
atp db user name.
-
#cwallet_file_secret_id ⇒ String
OCID of the secret containing the containers certificates of ATP wallet.
-
#database_name ⇒ String
atp database name.
-
#ewallet_file_secret_id ⇒ String
OCID of the secret containing the PDB’S certificates of ATP wallet.
-
#key_store_file_secret_id ⇒ String
OCID of the secret containing Keystore.jks file of the ATP wallet.
-
#ojdbc_file_secret_id ⇒ String
OCID of the secret that contains jdbc properties file of ATP wallet.
-
#table_name ⇒ String
atp database table name.
-
#tnsnames_file_secret_id ⇒ String
OCID of the secret that contains the tnsnames file of ATP wallet.
-
#truststore_file_secret_id ⇒ String
OCID of the secret containing truststore.jks file of the ATP wallet.
-
#wallet_password_secret_id ⇒ String
wallet password Secret ID in String format.
Attributes inherited from DataSourceDetails
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DataSourceDetailsATP
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from DataSourceDetails
Constructor Details
#initialize(attributes = {}) ⇒ DataSourceDetailsATP
Initializes the object
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/oci/ai_anomaly_detection/models/data_source_details_atp.rb', line 112 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['dataSourceType'] = 'ORACLE_ATP' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.wallet_password_secret_id = attributes[:'walletPasswordSecretId'] if attributes[:'walletPasswordSecretId'] raise 'You cannot provide both :walletPasswordSecretId and :wallet_password_secret_id' if attributes.key?(:'walletPasswordSecretId') && attributes.key?(:'wallet_password_secret_id') self.wallet_password_secret_id = attributes[:'wallet_password_secret_id'] if attributes[:'wallet_password_secret_id'] self.atp_user_name = attributes[:'atpUserName'] if attributes[:'atpUserName'] raise 'You cannot provide both :atpUserName and :atp_user_name' if attributes.key?(:'atpUserName') && attributes.key?(:'atp_user_name') self.atp_user_name = attributes[:'atp_user_name'] if attributes[:'atp_user_name'] self.atp_password_secret_id = attributes[:'atpPasswordSecretId'] if attributes[:'atpPasswordSecretId'] raise 'You cannot provide both :atpPasswordSecretId and :atp_password_secret_id' if attributes.key?(:'atpPasswordSecretId') && attributes.key?(:'atp_password_secret_id') self.atp_password_secret_id = attributes[:'atp_password_secret_id'] if attributes[:'atp_password_secret_id'] self.cwallet_file_secret_id = attributes[:'cwalletFileSecretId'] if attributes[:'cwalletFileSecretId'] raise 'You cannot provide both :cwalletFileSecretId and :cwallet_file_secret_id' if attributes.key?(:'cwalletFileSecretId') && attributes.key?(:'cwallet_file_secret_id') self.cwallet_file_secret_id = attributes[:'cwallet_file_secret_id'] if attributes[:'cwallet_file_secret_id'] self.ewallet_file_secret_id = attributes[:'ewalletFileSecretId'] if attributes[:'ewalletFileSecretId'] raise 'You cannot provide both :ewalletFileSecretId and :ewallet_file_secret_id' if attributes.key?(:'ewalletFileSecretId') && attributes.key?(:'ewallet_file_secret_id') self.ewallet_file_secret_id = attributes[:'ewallet_file_secret_id'] if attributes[:'ewallet_file_secret_id'] self.key_store_file_secret_id = attributes[:'keyStoreFileSecretId'] if attributes[:'keyStoreFileSecretId'] raise 'You cannot provide both :keyStoreFileSecretId and :key_store_file_secret_id' if attributes.key?(:'keyStoreFileSecretId') && attributes.key?(:'key_store_file_secret_id') self.key_store_file_secret_id = attributes[:'key_store_file_secret_id'] if attributes[:'key_store_file_secret_id'] self.ojdbc_file_secret_id = attributes[:'ojdbcFileSecretId'] if attributes[:'ojdbcFileSecretId'] raise 'You cannot provide both :ojdbcFileSecretId and :ojdbc_file_secret_id' if attributes.key?(:'ojdbcFileSecretId') && attributes.key?(:'ojdbc_file_secret_id') self.ojdbc_file_secret_id = attributes[:'ojdbc_file_secret_id'] if attributes[:'ojdbc_file_secret_id'] self.tnsnames_file_secret_id = attributes[:'tnsnamesFileSecretId'] if attributes[:'tnsnamesFileSecretId'] raise 'You cannot provide both :tnsnamesFileSecretId and :tnsnames_file_secret_id' if attributes.key?(:'tnsnamesFileSecretId') && attributes.key?(:'tnsnames_file_secret_id') self.tnsnames_file_secret_id = attributes[:'tnsnames_file_secret_id'] if attributes[:'tnsnames_file_secret_id'] self.truststore_file_secret_id = attributes[:'truststoreFileSecretId'] if attributes[:'truststoreFileSecretId'] raise 'You cannot provide both :truststoreFileSecretId and :truststore_file_secret_id' if attributes.key?(:'truststoreFileSecretId') && attributes.key?(:'truststore_file_secret_id') self.truststore_file_secret_id = attributes[:'truststore_file_secret_id'] if attributes[:'truststore_file_secret_id'] self.database_name = attributes[:'databaseName'] if attributes[:'databaseName'] raise 'You cannot provide both :databaseName and :database_name' if attributes.key?(:'databaseName') && attributes.key?(:'database_name') self.database_name = attributes[:'database_name'] if attributes[:'database_name'] self.table_name = attributes[:'tableName'] if attributes[:'tableName'] raise 'You cannot provide both :tableName and :table_name' if attributes.key?(:'tableName') && attributes.key?(:'table_name') self.table_name = attributes[:'table_name'] if attributes[:'table_name'] end |
Instance Attribute Details
#atp_password_secret_id ⇒ String
atp db password Secret Id
21 22 23 |
# File 'lib/oci/ai_anomaly_detection/models/data_source_details_atp.rb', line 21 def atp_password_secret_id @atp_password_secret_id end |
#atp_user_name ⇒ String
atp db user name
17 18 19 |
# File 'lib/oci/ai_anomaly_detection/models/data_source_details_atp.rb', line 17 def atp_user_name @atp_user_name end |
#cwallet_file_secret_id ⇒ String
OCID of the secret containing the containers certificates of ATP wallet
25 26 27 |
# File 'lib/oci/ai_anomaly_detection/models/data_source_details_atp.rb', line 25 def cwallet_file_secret_id @cwallet_file_secret_id end |
#database_name ⇒ String
atp database name
49 50 51 |
# File 'lib/oci/ai_anomaly_detection/models/data_source_details_atp.rb', line 49 def database_name @database_name end |
#ewallet_file_secret_id ⇒ String
OCID of the secret containing the PDB’S certificates of ATP wallet
29 30 31 |
# File 'lib/oci/ai_anomaly_detection/models/data_source_details_atp.rb', line 29 def ewallet_file_secret_id @ewallet_file_secret_id end |
#key_store_file_secret_id ⇒ String
OCID of the secret containing Keystore.jks file of the ATP wallet
33 34 35 |
# File 'lib/oci/ai_anomaly_detection/models/data_source_details_atp.rb', line 33 def key_store_file_secret_id @key_store_file_secret_id end |
#ojdbc_file_secret_id ⇒ String
OCID of the secret that contains jdbc properties file of ATP wallet
37 38 39 |
# File 'lib/oci/ai_anomaly_detection/models/data_source_details_atp.rb', line 37 def ojdbc_file_secret_id @ojdbc_file_secret_id end |
#table_name ⇒ String
atp database table name
53 54 55 |
# File 'lib/oci/ai_anomaly_detection/models/data_source_details_atp.rb', line 53 def table_name @table_name end |
#tnsnames_file_secret_id ⇒ String
OCID of the secret that contains the tnsnames file of ATP wallet
41 42 43 |
# File 'lib/oci/ai_anomaly_detection/models/data_source_details_atp.rb', line 41 def tnsnames_file_secret_id @tnsnames_file_secret_id end |
#truststore_file_secret_id ⇒ String
OCID of the secret containing truststore.jks file of the ATP wallet
45 46 47 |
# File 'lib/oci/ai_anomaly_detection/models/data_source_details_atp.rb', line 45 def truststore_file_secret_id @truststore_file_secret_id end |
#wallet_password_secret_id ⇒ String
wallet password Secret ID in String format
13 14 15 |
# File 'lib/oci/ai_anomaly_detection/models/data_source_details_atp.rb', line 13 def wallet_password_secret_id @wallet_password_secret_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/oci/ai_anomaly_detection/models/data_source_details_atp.rb', line 56 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'data_source_type': :'dataSourceType', 'wallet_password_secret_id': :'walletPasswordSecretId', 'atp_user_name': :'atpUserName', 'atp_password_secret_id': :'atpPasswordSecretId', 'cwallet_file_secret_id': :'cwalletFileSecretId', 'ewallet_file_secret_id': :'ewalletFileSecretId', 'key_store_file_secret_id': :'keyStoreFileSecretId', 'ojdbc_file_secret_id': :'ojdbcFileSecretId', 'tnsnames_file_secret_id': :'tnsnamesFileSecretId', 'truststore_file_secret_id': :'truststoreFileSecretId', 'database_name': :'databaseName', 'table_name': :'tableName' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/oci/ai_anomaly_detection/models/data_source_details_atp.rb', line 76 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'data_source_type': :'String', 'wallet_password_secret_id': :'String', 'atp_user_name': :'String', 'atp_password_secret_id': :'String', 'cwallet_file_secret_id': :'String', 'ewallet_file_secret_id': :'String', 'key_store_file_secret_id': :'String', 'ojdbc_file_secret_id': :'String', 'tnsnames_file_secret_id': :'String', 'truststore_file_secret_id': :'String', 'database_name': :'String', 'table_name': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/oci/ai_anomaly_detection/models/data_source_details_atp.rb', line 196 def ==(other) return true if equal?(other) self.class == other.class && data_source_type == other.data_source_type && wallet_password_secret_id == other.wallet_password_secret_id && atp_user_name == other.atp_user_name && atp_password_secret_id == other.atp_password_secret_id && cwallet_file_secret_id == other.cwallet_file_secret_id && ewallet_file_secret_id == other.ewallet_file_secret_id && key_store_file_secret_id == other.key_store_file_secret_id && ojdbc_file_secret_id == other.ojdbc_file_secret_id && tnsnames_file_secret_id == other.tnsnames_file_secret_id && truststore_file_secret_id == other.truststore_file_secret_id && database_name == other.database_name && table_name == other.table_name end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/oci/ai_anomaly_detection/models/data_source_details_atp.rb', line 237 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
217 218 219 |
# File 'lib/oci/ai_anomaly_detection/models/data_source_details_atp.rb', line 217 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
226 227 228 |
# File 'lib/oci/ai_anomaly_detection/models/data_source_details_atp.rb', line 226 def hash [data_source_type, wallet_password_secret_id, atp_user_name, atp_password_secret_id, cwallet_file_secret_id, ewallet_file_secret_id, key_store_file_secret_id, ojdbc_file_secret_id, tnsnames_file_secret_id, truststore_file_secret_id, database_name, table_name].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
270 271 272 273 274 275 276 277 278 279 |
# File 'lib/oci/ai_anomaly_detection/models/data_source_details_atp.rb', line 270 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
264 265 266 |
# File 'lib/oci/ai_anomaly_detection/models/data_source_details_atp.rb', line 264 def to_s to_hash.to_s end |