Class: OCI::AiAnomalyDetection::Models::DetectAnomaliesDetails
- Inherits:
-
Object
- Object
- OCI::AiAnomalyDetection::Models::DetectAnomaliesDetails
- Defined in:
- lib/oci/ai_anomaly_detection/models/detect_anomalies_details.rb
Overview
Base class for the DetectAnomalies call. It contains the identifier that will be used for deciding what type of request this is.
This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
EmbeddedDetectAnomaliesRequest, InlineDetectAnomaliesRequest
Constant Summary collapse
- REQUEST_TYPE_ENUM =
[ REQUEST_TYPE_INLINE = 'INLINE'.freeze, REQUEST_TYPE_BASE64_ENCODED = 'BASE64_ENCODED'.freeze ].freeze
Instance Attribute Summary collapse
-
#model_id ⇒ String
**[Required]** The OCID of the trained modelu3002.
-
#request_type ⇒ String
**[Required]** Type of request.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DetectAnomaliesDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DetectAnomaliesDetails
Initializes the object
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/oci/ai_anomaly_detection/models/detect_anomalies_details.rb', line 72 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.model_id = attributes[:'modelId'] if attributes[:'modelId'] raise 'You cannot provide both :modelId and :model_id' if attributes.key?(:'modelId') && attributes.key?(:'model_id') self.model_id = attributes[:'model_id'] if attributes[:'model_id'] self.request_type = attributes[:'requestType'] if attributes[:'requestType'] raise 'You cannot provide both :requestType and :request_type' if attributes.key?(:'requestType') && attributes.key?(:'request_type') self.request_type = attributes[:'request_type'] if attributes[:'request_type'] end |
Instance Attribute Details
#model_id ⇒ String
**[Required]** The OCID of the trained modelu3002
20 21 22 |
# File 'lib/oci/ai_anomaly_detection/models/detect_anomalies_details.rb', line 20 def model_id @model_id end |
#request_type ⇒ String
**[Required]** Type of request. This parameter will be filled autmatically by classes generated by the SDK. For raw curl request, user will have to provide this field.
26 27 28 |
# File 'lib/oci/ai_anomaly_detection/models/detect_anomalies_details.rb', line 26 def request_type @request_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 36 |
# File 'lib/oci/ai_anomaly_detection/models/detect_anomalies_details.rb', line 29 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_id': :'modelId', 'request_type': :'requestType' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
53 54 55 56 57 58 59 60 61 |
# File 'lib/oci/ai_anomaly_detection/models/detect_anomalies_details.rb', line 53 def self.get_subtype(object_hash) type = object_hash[:'requestType'] # rubocop:disable Style/SymbolLiteral return 'OCI::AiAnomalyDetection::Models::InlineDetectAnomaliesRequest' if type == 'INLINE' return 'OCI::AiAnomalyDetection::Models::EmbeddedDetectAnomaliesRequest' if type == 'BASE64_ENCODED' # TODO: Log a warning when the subtype is not found. 'OCI::AiAnomalyDetection::Models::DetectAnomaliesDetails' end |
.swagger_types ⇒ Object
Attribute type mapping.
39 40 41 42 43 44 45 46 |
# File 'lib/oci/ai_anomaly_detection/models/detect_anomalies_details.rb', line 39 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_id': :'String', 'request_type': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
106 107 108 109 110 111 112 |
# File 'lib/oci/ai_anomaly_detection/models/detect_anomalies_details.rb', line 106 def ==(other) return true if equal?(other) self.class == other.class && model_id == other.model_id && request_type == other.request_type end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/oci/ai_anomaly_detection/models/detect_anomalies_details.rb', line 137 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
117 118 119 |
# File 'lib/oci/ai_anomaly_detection/models/detect_anomalies_details.rb', line 117 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
126 127 128 |
# File 'lib/oci/ai_anomaly_detection/models/detect_anomalies_details.rb', line 126 def hash [model_id, request_type].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
170 171 172 173 174 175 176 177 178 179 |
# File 'lib/oci/ai_anomaly_detection/models/detect_anomalies_details.rb', line 170 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
164 165 166 |
# File 'lib/oci/ai_anomaly_detection/models/detect_anomalies_details.rb', line 164 def to_s to_hash.to_s end |