Class: OCI::AiAnomalyDetection::Models::EmbeddedDetectAnomaliesRequest
- Inherits:
-
DetectAnomaliesDetails
- Object
- DetectAnomaliesDetails
- OCI::AiAnomalyDetection::Models::EmbeddedDetectAnomaliesRequest
- Defined in:
- lib/oci/ai_anomaly_detection/models/embedded_detect_anomalies_request.rb
Overview
The request body when the user selects to provide byte data in detect call which is Base64 encoded. The default type of the data is CSV and can be JSON by setting the ‘contentType’.
Constant Summary collapse
- CONTENT_TYPE_ENUM =
[ CONTENT_TYPE_CSV = 'CSV'.freeze, CONTENT_TYPE_JSON = 'JSON'.freeze ].freeze
Constants inherited from DetectAnomaliesDetails
DetectAnomaliesDetails::REQUEST_TYPE_ENUM
Instance Attribute Summary collapse
-
#content ⇒ String
This attribute is required.
- #content_type ⇒ String
Attributes inherited from DetectAnomaliesDetails
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EmbeddedDetectAnomaliesRequest
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from DetectAnomaliesDetails
Constructor Details
#initialize(attributes = {}) ⇒ EmbeddedDetectAnomaliesRequest
Initializes the object
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/oci/ai_anomaly_detection/models/embedded_detect_anomalies_request.rb', line 58 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['requestType'] = 'BASE64_ENCODED' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.content_type = attributes[:'contentType'] if attributes[:'contentType'] self.content_type = "CSV" if content_type.nil? && !attributes.key?(:'contentType') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :contentType and :content_type' if attributes.key?(:'contentType') && attributes.key?(:'content_type') self.content_type = attributes[:'content_type'] if attributes[:'content_type'] self.content_type = "CSV" if content_type.nil? && !attributes.key?(:'contentType') && !attributes.key?(:'content_type') # rubocop:disable Style/StringLiterals self.content = attributes[:'content'] if attributes[:'content'] end |
Instance Attribute Details
#content ⇒ String
This attribute is required.
23 24 25 |
# File 'lib/oci/ai_anomaly_detection/models/embedded_detect_anomalies_request.rb', line 23 def content @content end |
#content_type ⇒ String
19 20 21 |
# File 'lib/oci/ai_anomaly_detection/models/embedded_detect_anomalies_request.rb', line 19 def content_type @content_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
26 27 28 29 30 31 32 33 34 35 |
# File 'lib/oci/ai_anomaly_detection/models/embedded_detect_anomalies_request.rb', line 26 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_id': :'modelId', 'request_type': :'requestType', 'content_type': :'contentType', 'content': :'content' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
38 39 40 41 42 43 44 45 46 47 |
# File 'lib/oci/ai_anomaly_detection/models/embedded_detect_anomalies_request.rb', line 38 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_id': :'String', 'request_type': :'String', 'content_type': :'String', 'content': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
94 95 96 97 98 99 100 101 102 |
# File 'lib/oci/ai_anomaly_detection/models/embedded_detect_anomalies_request.rb', line 94 def ==(other) return true if equal?(other) self.class == other.class && model_id == other.model_id && request_type == other.request_type && content_type == other.content_type && content == other.content end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/oci/ai_anomaly_detection/models/embedded_detect_anomalies_request.rb', line 127 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
107 108 109 |
# File 'lib/oci/ai_anomaly_detection/models/embedded_detect_anomalies_request.rb', line 107 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
116 117 118 |
# File 'lib/oci/ai_anomaly_detection/models/embedded_detect_anomalies_request.rb', line 116 def hash [model_id, request_type, content_type, content].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
160 161 162 163 164 165 166 167 168 169 |
# File 'lib/oci/ai_anomaly_detection/models/embedded_detect_anomalies_request.rb', line 160 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
154 155 156 |
# File 'lib/oci/ai_anomaly_detection/models/embedded_detect_anomalies_request.rb', line 154 def to_s to_hash.to_s end |