Class: OCI::AiAnomalyDetection::Models::InlineDetectAnomaliesRequest

Inherits:
DetectAnomaliesDetails show all
Defined in:
lib/oci/ai_anomaly_detection/models/inline_detect_anomalies_request.rb

Overview

This is the specialised JSON format that we accept as Training data, with an additional field for 'requestType' which is a required field used deciding whether it is an inline request or contains embedded data.

Constant Summary

Constants inherited from DetectAnomaliesDetails

DetectAnomaliesDetails::REQUEST_TYPE_ENUM

Instance Attribute Summary collapse

Attributes inherited from DetectAnomaliesDetails

#model_id, #request_type

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from DetectAnomaliesDetails

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ InlineDetectAnomaliesRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :model_id (String)

    The value to assign to the #model_id proprety

  • :signal_names (Array<String>)

    The value to assign to the #signal_names property

  • :data (Array<OCI::AiAnomalyDetection::Models::DataItem>)

    The value to assign to the #data property



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/oci/ai_anomaly_detection/models/inline_detect_anomalies_request.rb', line 55

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['requestType'] = 'INLINE'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.signal_names = attributes[:'signalNames'] if attributes[:'signalNames']

  raise 'You cannot provide both :signalNames and :signal_names' if attributes.key?(:'signalNames') && attributes.key?(:'signal_names')

  self.signal_names = attributes[:'signal_names'] if attributes[:'signal_names']

  self.data = attributes[:'data'] if attributes[:'data']
end

Instance Attribute Details

#dataArray<OCI::AiAnomalyDetection::Models::DataItem>

**[Required]** Array containing data.

Returns:

  • (Array<OCI::AiAnomalyDetection::Models::DataItem>)


20
21
22
# File 'lib/oci/ai_anomaly_detection/models/inline_detect_anomalies_request.rb', line 20

def data
  @data
end

#signal_namesArray<String>

**[Required]** List of signal names.

Returns:

  • (Array<String>)


16
17
18
# File 'lib/oci/ai_anomaly_detection/models/inline_detect_anomalies_request.rb', line 16

def signal_names
  @signal_names
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



23
24
25
26
27
28
29
30
31
32
# File 'lib/oci/ai_anomaly_detection/models/inline_detect_anomalies_request.rb', line 23

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'model_id': :'modelId',
    'request_type': :'requestType',
    'signal_names': :'signalNames',
    'data': :'data'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



35
36
37
38
39
40
41
42
43
44
# File 'lib/oci/ai_anomaly_detection/models/inline_detect_anomalies_request.rb', line 35

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'model_id': :'String',
    'request_type': :'String',
    'signal_names': :'Array<String>',
    'data': :'Array<OCI::AiAnomalyDetection::Models::DataItem>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



81
82
83
84
85
86
87
88
89
# File 'lib/oci/ai_anomaly_detection/models/inline_detect_anomalies_request.rb', line 81

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    model_id == other.model_id &&
    request_type == other.request_type &&
    signal_names == other.signal_names &&
    data == other.data
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/oci/ai_anomaly_detection/models/inline_detect_anomalies_request.rb', line 114

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


94
95
96
# File 'lib/oci/ai_anomaly_detection/models/inline_detect_anomalies_request.rb', line 94

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



103
104
105
# File 'lib/oci/ai_anomaly_detection/models/inline_detect_anomalies_request.rb', line 103

def hash
  [model_id, request_type, signal_names, data].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



147
148
149
150
151
152
153
154
155
156
# File 'lib/oci/ai_anomaly_detection/models/inline_detect_anomalies_request.rb', line 147

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



141
142
143
# File 'lib/oci/ai_anomaly_detection/models/inline_detect_anomalies_request.rb', line 141

def to_s
  to_hash.to_s
end