Class: AiAnomalyDetection::Models::Model
- Inherits:
-
Object
- Object
- AiAnomalyDetection::Models::Model
- Defined in:
- lib/oci/ai_anomaly_detection/models/model.rb
Overview
Description of Model.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The OCID for the model's compartment.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
A short description of the Model.
-
#display_name ⇒ String
**[Required]** A user-friendly display name for the resource.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
**[Required]** The OCID of the model that is immutable on creation.
-
#lifecycle_details ⇒ String
A message describing the current state in more detail.
-
#lifecycle_state ⇒ String
**[Required]** The state of the model.
-
#model_training_details ⇒ OCI::AiAnomalyDetection::Models::ModelTrainingDetails
This attribute is required.
-
#model_training_results ⇒ OCI::AiAnomalyDetection::Models::ModelTrainingResults
This attribute is required.
-
#project_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the project to associate with the model.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys.
-
#time_created ⇒ DateTime
**[Required]** The time the the Model was created.
-
#time_updated ⇒ DateTime
The time the Model was updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Model
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Model
Initializes the object
147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/oci/ai_anomaly_detection/models/model.rb', line 147 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.model_training_details = attributes[:'modelTrainingDetails'] if attributes[:'modelTrainingDetails'] raise 'You cannot provide both :modelTrainingDetails and :model_training_details' if attributes.key?(:'modelTrainingDetails') && attributes.key?(:'model_training_details') self.model_training_details = attributes[:'model_training_details'] if attributes[:'model_training_details'] self.model_training_results = attributes[:'modelTrainingResults'] if attributes[:'modelTrainingResults'] raise 'You cannot provide both :modelTrainingResults and :model_training_results' if attributes.key?(:'modelTrainingResults') && attributes.key?(:'model_training_results') self.model_training_results = attributes[:'model_training_results'] if attributes[:'model_training_results'] self.project_id = attributes[:'projectId'] if attributes[:'projectId'] raise 'You cannot provide both :projectId and :project_id' if attributes.key?(:'projectId') && attributes.key?(:'project_id') self.project_id = attributes[:'project_id'] if attributes[:'project_id'] self.description = attributes[:'description'] if attributes[:'description'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The OCID for the model's compartment.
31 32 33 |
# File 'lib/oci/ai_anomaly_detection/models/model.rb', line 31 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
75 76 77 |
# File 'lib/oci/ai_anomaly_detection/models/model.rb', line 75 def @defined_tags end |
#description ⇒ String
A short description of the Model.
47 48 49 |
# File 'lib/oci/ai_anomaly_detection/models/model.rb', line 47 def description @description end |
#display_name ⇒ String
**[Required]** A user-friendly display name for the resource. It does not have to be unique and can be modified. Avoid entering confidential information.
27 28 29 |
# File 'lib/oci/ai_anomaly_detection/models/model.rb', line 27 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
69 70 71 |
# File 'lib/oci/ai_anomaly_detection/models/model.rb', line 69 def @freeform_tags end |
#id ⇒ String
**[Required]** The OCID of the model that is immutable on creation.
23 24 25 |
# File 'lib/oci/ai_anomaly_detection/models/model.rb', line 23 def id @id end |
#lifecycle_details ⇒ String
A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
63 64 65 |
# File 'lib/oci/ai_anomaly_detection/models/model.rb', line 63 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
**[Required]** The state of the model.
59 60 61 |
# File 'lib/oci/ai_anomaly_detection/models/model.rb', line 59 def lifecycle_state @lifecycle_state end |
#model_training_details ⇒ OCI::AiAnomalyDetection::Models::ModelTrainingDetails
This attribute is required.
35 36 37 |
# File 'lib/oci/ai_anomaly_detection/models/model.rb', line 35 def model_training_details @model_training_details end |
#model_training_results ⇒ OCI::AiAnomalyDetection::Models::ModelTrainingResults
This attribute is required.
39 40 41 |
# File 'lib/oci/ai_anomaly_detection/models/model.rb', line 39 def model_training_results @model_training_results end |
#project_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the project to associate with the model.
43 44 45 |
# File 'lib/oci/ai_anomaly_detection/models/model.rb', line 43 def project_id @project_id end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"free-tier-retained": "true"}`
81 82 83 |
# File 'lib/oci/ai_anomaly_detection/models/model.rb', line 81 def @system_tags end |
#time_created ⇒ DateTime
**[Required]** The time the the Model was created. An RFC3339 formatted datetime string.
51 52 53 |
# File 'lib/oci/ai_anomaly_detection/models/model.rb', line 51 def time_created @time_created end |
#time_updated ⇒ DateTime
The time the Model was updated. An RFC3339 formatted datetime string.
55 56 57 |
# File 'lib/oci/ai_anomaly_detection/models/model.rb', line 55 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/oci/ai_anomaly_detection/models/model.rb', line 84 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'model_training_details': :'modelTrainingDetails', 'model_training_results': :'modelTrainingResults', 'project_id': :'projectId', 'description': :'description', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/oci/ai_anomaly_detection/models/model.rb', line 106 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'compartment_id': :'String', 'model_training_details': :'OCI::AiAnomalyDetection::Models::ModelTrainingDetails', 'model_training_results': :'OCI::AiAnomalyDetection::Models::ModelTrainingResults', 'project_id': :'String', 'description': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 |
# File 'lib/oci/ai_anomaly_detection/models/model.rb', line 250 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && compartment_id == other.compartment_id && model_training_details == other.model_training_details && model_training_results == other.model_training_results && project_id == other.project_id && description == other.description && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'lib/oci/ai_anomaly_detection/models/model.rb', line 293 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
273 274 275 |
# File 'lib/oci/ai_anomaly_detection/models/model.rb', line 273 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
282 283 284 |
# File 'lib/oci/ai_anomaly_detection/models/model.rb', line 282 def hash [id, display_name, compartment_id, model_training_details, model_training_results, project_id, description, time_created, time_updated, lifecycle_state, lifecycle_details, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
326 327 328 329 330 331 332 333 334 335 |
# File 'lib/oci/ai_anomaly_detection/models/model.rb', line 326 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
320 321 322 |
# File 'lib/oci/ai_anomaly_detection/models/model.rb', line 320 def to_s to_hash.to_s end |