Class: OCI::AiAnomalyDetection::Models::ModelTrainingDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/ai_anomaly_detection/models/model_training_details.rb

Overview

Specifies the details of the MSET model during the create call.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ModelTrainingDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :target_fap (Float)

    The value to assign to the #target_fap property

  • :training_fraction (Float)

    The value to assign to the #training_fraction property

  • :data_asset_ids (Array<String>)

    The value to assign to the #data_asset_ids property



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/oci/ai_anomaly_detection/models/model_training_details.rb', line 53

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.target_fap = attributes[:'targetFap'] if attributes[:'targetFap']
  self.target_fap = 0.01 if target_fap.nil? && !attributes.key?(:'targetFap') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :targetFap and :target_fap' if attributes.key?(:'targetFap') && attributes.key?(:'target_fap')

  self.target_fap = attributes[:'target_fap'] if attributes[:'target_fap']
  self.target_fap = 0.01 if target_fap.nil? && !attributes.key?(:'targetFap') && !attributes.key?(:'target_fap') # rubocop:disable Style/StringLiterals

  self.training_fraction = attributes[:'trainingFraction'] if attributes[:'trainingFraction']
  self.training_fraction = 0.7 if training_fraction.nil? && !attributes.key?(:'trainingFraction') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :trainingFraction and :training_fraction' if attributes.key?(:'trainingFraction') && attributes.key?(:'training_fraction')

  self.training_fraction = attributes[:'training_fraction'] if attributes[:'training_fraction']
  self.training_fraction = 0.7 if training_fraction.nil? && !attributes.key?(:'trainingFraction') && !attributes.key?(:'training_fraction') # rubocop:disable Style/StringLiterals

  self.data_asset_ids = attributes[:'dataAssetIds'] if attributes[:'dataAssetIds']

  raise 'You cannot provide both :dataAssetIds and :data_asset_ids' if attributes.key?(:'dataAssetIds') && attributes.key?(:'data_asset_ids')

  self.data_asset_ids = attributes[:'data_asset_ids'] if attributes[:'data_asset_ids']
end

Instance Attribute Details

#data_asset_idsArray<String>

**[Required]** The list of OCIDs of the data assets to train the model. The dataAssets have to be in the same project where the ai model would reside.

Returns:

  • (Array<String>)


20
21
22
# File 'lib/oci/ai_anomaly_detection/models/model_training_details.rb', line 20

def data_asset_ids
  @data_asset_ids
end

#target_fapFloat

A target model accuracy metric user provides as their requirement

Returns:

  • (Float)


12
13
14
# File 'lib/oci/ai_anomaly_detection/models/model_training_details.rb', line 12

def target_fap
  @target_fap
end

#training_fractionFloat

Fraction of total data that is used for training the model. The remaining is used for validation of the model.

Returns:

  • (Float)


16
17
18
# File 'lib/oci/ai_anomaly_detection/models/model_training_details.rb', line 16

def training_fraction
  @training_fraction
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



23
24
25
26
27
28
29
30
31
# File 'lib/oci/ai_anomaly_detection/models/model_training_details.rb', line 23

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'target_fap': :'targetFap',
    'training_fraction': :'trainingFraction',
    'data_asset_ids': :'dataAssetIds'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



34
35
36
37
38
39
40
41
42
# File 'lib/oci/ai_anomaly_detection/models/model_training_details.rb', line 34

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'target_fap': :'Float',
    'training_fraction': :'Float',
    'data_asset_ids': :'Array<String>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



89
90
91
92
93
94
95
96
# File 'lib/oci/ai_anomaly_detection/models/model_training_details.rb', line 89

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    target_fap == other.target_fap &&
    training_fraction == other.training_fraction &&
    data_asset_ids == other.data_asset_ids
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/oci/ai_anomaly_detection/models/model_training_details.rb', line 121

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


101
102
103
# File 'lib/oci/ai_anomaly_detection/models/model_training_details.rb', line 101

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



110
111
112
# File 'lib/oci/ai_anomaly_detection/models/model_training_details.rb', line 110

def hash
  [target_fap, training_fraction, data_asset_ids].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



154
155
156
157
158
159
160
161
162
163
# File 'lib/oci/ai_anomaly_detection/models/model_training_details.rb', line 154

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



148
149
150
# File 'lib/oci/ai_anomaly_detection/models/model_training_details.rb', line 148

def to_s
  to_hash.to_s
end