Class: OCI::AiAnomalyDetection::Models::ModelTrainingResults

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/ai_anomaly_detection/models/model_training_results.rb

Overview

Specifies the details for an Anomaly Detection model trained with MSET.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ModelTrainingResults

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/oci/ai_anomaly_detection/models/model_training_results.rb', line 73

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.fap = attributes[:'fap'] if attributes[:'fap']

  self.multivariate_fap = attributes[:'multivariateFap'] if attributes[:'multivariateFap']

  raise 'You cannot provide both :multivariateFap and :multivariate_fap' if attributes.key?(:'multivariateFap') && attributes.key?(:'multivariate_fap')

  self.multivariate_fap = attributes[:'multivariate_fap'] if attributes[:'multivariate_fap']

  self.is_training_goal_achieved = attributes[:'isTrainingGoalAchieved'] unless attributes[:'isTrainingGoalAchieved'].nil?

  raise 'You cannot provide both :isTrainingGoalAchieved and :is_training_goal_achieved' if attributes.key?(:'isTrainingGoalAchieved') && attributes.key?(:'is_training_goal_achieved')

  self.is_training_goal_achieved = attributes[:'is_training_goal_achieved'] unless attributes[:'is_training_goal_achieved'].nil?

  self.warning = attributes[:'warning'] if attributes[:'warning']

  self.signal_details = attributes[:'signalDetails'] if attributes[:'signalDetails']

  raise 'You cannot provide both :signalDetails and :signal_details' if attributes.key?(:'signalDetails') && attributes.key?(:'signal_details')

  self.signal_details = attributes[:'signal_details'] if attributes[:'signal_details']

  self.row_reduction_details = attributes[:'rowReductionDetails'] if attributes[:'rowReductionDetails']

  raise 'You cannot provide both :rowReductionDetails and :row_reduction_details' if attributes.key?(:'rowReductionDetails') && attributes.key?(:'row_reduction_details')

  self.row_reduction_details = attributes[:'row_reduction_details'] if attributes[:'row_reduction_details']
end

Instance Attribute Details

#fapFloat

**[Required]** The final-achieved model accuracy metric on individual value level

Returns:

  • (Float)


12
13
14
# File 'lib/oci/ai_anomaly_detection/models/model_training_results.rb', line 12

def fap
  @fap
end

#is_training_goal_achievedBOOLEAN

A boolean value to indicate if train goal/targetFap is achieved for trained model

Returns:

  • (BOOLEAN)


20
21
22
# File 'lib/oci/ai_anomaly_detection/models/model_training_results.rb', line 20

def is_training_goal_achieved
  @is_training_goal_achieved
end

#multivariate_fapFloat

The model accuracy metric on timestamp level.

Returns:

  • (Float)


16
17
18
# File 'lib/oci/ai_anomaly_detection/models/model_training_results.rb', line 16

def multivariate_fap
  @multivariate_fap
end

#row_reduction_detailsOCI::AiAnomalyDetection::Models::RowReductionDetails



31
32
33
# File 'lib/oci/ai_anomaly_detection/models/model_training_results.rb', line 31

def row_reduction_details
  @row_reduction_details
end

#signal_detailsArray<OCI::AiAnomalyDetection::Models::PerSignalDetails>

The list of signal details.



28
29
30
# File 'lib/oci/ai_anomaly_detection/models/model_training_results.rb', line 28

def signal_details
  @signal_details
end

#warningString

A warning message to explain the reason when targetFap cannot be achieved for trained model

Returns:

  • (String)


24
25
26
# File 'lib/oci/ai_anomaly_detection/models/model_training_results.rb', line 24

def warning
  @warning
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
43
44
45
# File 'lib/oci/ai_anomaly_detection/models/model_training_results.rb', line 34

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'fap': :'fap',
    'multivariate_fap': :'multivariateFap',
    'is_training_goal_achieved': :'isTrainingGoalAchieved',
    'warning': :'warning',
    'signal_details': :'signalDetails',
    'row_reduction_details': :'rowReductionDetails'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/oci/ai_anomaly_detection/models/model_training_results.rb', line 48

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'fap': :'Float',
    'multivariate_fap': :'Float',
    'is_training_goal_achieved': :'BOOLEAN',
    'warning': :'String',
    'signal_details': :'Array<OCI::AiAnomalyDetection::Models::PerSignalDetails>',
    'row_reduction_details': :'OCI::AiAnomalyDetection::Models::RowReductionDetails'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



115
116
117
118
119
120
121
122
123
124
125
# File 'lib/oci/ai_anomaly_detection/models/model_training_results.rb', line 115

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    fap == other.fap &&
    multivariate_fap == other.multivariate_fap &&
    is_training_goal_achieved == other.is_training_goal_achieved &&
    warning == other.warning &&
    signal_details == other.signal_details &&
    row_reduction_details == other.row_reduction_details
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/oci/ai_anomaly_detection/models/model_training_results.rb', line 150

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


130
131
132
# File 'lib/oci/ai_anomaly_detection/models/model_training_results.rb', line 130

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



139
140
141
# File 'lib/oci/ai_anomaly_detection/models/model_training_results.rb', line 139

def hash
  [fap, multivariate_fap, is_training_goal_achieved, warning, signal_details, row_reduction_details].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



183
184
185
186
187
188
189
190
191
192
# File 'lib/oci/ai_anomaly_detection/models/model_training_results.rb', line 183

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



177
178
179
# File 'lib/oci/ai_anomaly_detection/models/model_training_results.rb', line 177

def to_s
  to_hash.to_s
end