Class: OCI::AiLanguage::Models::HierarchicalEntity
- Inherits:
-
Object
- Object
- OCI::AiLanguage::Models::HierarchicalEntity
- Defined in:
- lib/oci/ai_language/models/hierarchical_entity.rb
Overview
Hierarchical entity object
Instance Attribute Summary collapse
-
#length ⇒ Integer
Length of entity text.
-
#offset ⇒ Integer
The number of Unicode code points preceding this entity in the submitted text.
-
#score ⇒ Float
Score or confidence for detected entity.
-
#sub_type ⇒ String
Sub-type of entity text like GPE for LOCATION type.
-
#text ⇒ String
Entity text like name of person, location, and so on.
-
#type ⇒ String
Type of entity text like PER, LOC.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ HierarchicalEntity
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ HierarchicalEntity
Initializes the object
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/oci/ai_language/models/hierarchical_entity.rb', line 74 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.offset = attributes[:'offset'] if attributes[:'offset'] self.length = attributes[:'length'] if attributes[:'length'] self.text = attributes[:'text'] if attributes[:'text'] self.type = attributes[:'type'] if attributes[:'type'] self.sub_type = attributes[:'subType'] if attributes[:'subType'] raise 'You cannot provide both :subType and :sub_type' if attributes.key?(:'subType') && attributes.key?(:'sub_type') self.sub_type = attributes[:'sub_type'] if attributes[:'sub_type'] self.score = attributes[:'score'] if attributes[:'score'] end |
Instance Attribute Details
#length ⇒ Integer
Length of entity text
16 17 18 |
# File 'lib/oci/ai_language/models/hierarchical_entity.rb', line 16 def length @length end |
#offset ⇒ Integer
The number of Unicode code points preceding this entity in the submitted text.
12 13 14 |
# File 'lib/oci/ai_language/models/hierarchical_entity.rb', line 12 def offset @offset end |
#score ⇒ Float
Score or confidence for detected entity.
32 33 34 |
# File 'lib/oci/ai_language/models/hierarchical_entity.rb', line 32 def score @score end |
#sub_type ⇒ String
Sub-type of entity text like GPE for LOCATION type
28 29 30 |
# File 'lib/oci/ai_language/models/hierarchical_entity.rb', line 28 def sub_type @sub_type end |
#text ⇒ String
Entity text like name of person, location, and so on.
20 21 22 |
# File 'lib/oci/ai_language/models/hierarchical_entity.rb', line 20 def text @text end |
#type ⇒ String
Type of entity text like PER, LOC.
24 25 26 |
# File 'lib/oci/ai_language/models/hierarchical_entity.rb', line 24 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/oci/ai_language/models/hierarchical_entity.rb', line 35 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'offset': :'offset', 'length': :'length', 'text': :'text', 'type': :'type', 'sub_type': :'subType', 'score': :'score' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/oci/ai_language/models/hierarchical_entity.rb', line 49 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'offset': :'Integer', 'length': :'Integer', 'text': :'String', 'type': :'String', 'sub_type': :'String', 'score': :'Float' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/oci/ai_language/models/hierarchical_entity.rb', line 104 def ==(other) return true if equal?(other) self.class == other.class && offset == other.offset && length == other.length && text == other.text && type == other.type && sub_type == other.sub_type && score == other.score end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/oci/ai_language/models/hierarchical_entity.rb', line 139 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
119 120 121 |
# File 'lib/oci/ai_language/models/hierarchical_entity.rb', line 119 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
128 129 130 |
# File 'lib/oci/ai_language/models/hierarchical_entity.rb', line 128 def hash [offset, length, text, type, sub_type, score].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
172 173 174 175 176 177 178 179 180 181 |
# File 'lib/oci/ai_language/models/hierarchical_entity.rb', line 172 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
166 167 168 |
# File 'lib/oci/ai_language/models/hierarchical_entity.rb', line 166 def to_s to_hash.to_s end |