Class: OCI::AiLanguage::Models::KeyPhraseDocument
- Inherits:
-
Object
- Object
- OCI::AiLanguage::Models::KeyPhraseDocument
- Defined in:
- lib/oci/ai_language/models/key_phrase_document.rb
Overview
The document details for keyPhrases detect call.
Instance Attribute Summary collapse
-
#key ⇒ String
[Required] Document Unique Identifier.
-
#language_code ⇒ String
Language code as per [ISO 639-1](en.wikipedia.org/wiki/List_of_ISO_639-1_codes) standard..
-
#text ⇒ String
[Required] Document text for detect keyPhrases.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ KeyPhraseDocument
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ KeyPhraseDocument
Initializes the object
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/oci/ai_language/models/key_phrase_document.rb', line 53 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.key = attributes[:'key'] if attributes[:'key'] self.text = attributes[:'text'] if attributes[:'text'] self.language_code = attributes[:'languageCode'] if attributes[:'languageCode'] raise 'You cannot provide both :languageCode and :language_code' if attributes.key?(:'languageCode') && attributes.key?(:'language_code') self.language_code = attributes[:'language_code'] if attributes[:'language_code'] end |
Instance Attribute Details
#key ⇒ String
[Required] Document Unique Identifier.
12 13 14 |
# File 'lib/oci/ai_language/models/key_phrase_document.rb', line 12 def key @key end |
#language_code ⇒ String
Language code as per [ISO 639-1](en.wikipedia.org/wiki/List_of_ISO_639-1_codes) standard..
20 21 22 |
# File 'lib/oci/ai_language/models/key_phrase_document.rb', line 20 def language_code @language_code end |
#text ⇒ String
[Required] Document text for detect keyPhrases.
16 17 18 |
# File 'lib/oci/ai_language/models/key_phrase_document.rb', line 16 def text @text end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
23 24 25 26 27 28 29 30 31 |
# File 'lib/oci/ai_language/models/key_phrase_document.rb', line 23 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'key': :'key', 'text': :'text', 'language_code': :'languageCode' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
34 35 36 37 38 39 40 41 42 |
# File 'lib/oci/ai_language/models/key_phrase_document.rb', line 34 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'key': :'String', 'text': :'String', 'language_code': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
77 78 79 80 81 82 83 84 |
# File 'lib/oci/ai_language/models/key_phrase_document.rb', line 77 def ==(other) return true if equal?(other) self.class == other.class && key == other.key && text == other.text && language_code == other.language_code end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/oci/ai_language/models/key_phrase_document.rb', line 109 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
89 90 91 |
# File 'lib/oci/ai_language/models/key_phrase_document.rb', line 89 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
98 99 100 |
# File 'lib/oci/ai_language/models/key_phrase_document.rb', line 98 def hash [key, text, language_code].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
142 143 144 145 146 147 148 149 150 151 |
# File 'lib/oci/ai_language/models/key_phrase_document.rb', line 142 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
136 137 138 |
# File 'lib/oci/ai_language/models/key_phrase_document.rb', line 136 def to_s to_hash.to_s end |