Class: OCI::AiLanguage::Models::SentimentDocumentResult

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/ai_language/models/sentiment_document_result.rb

Overview

The document response for sentiment detect call.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ SentimentDocumentResult

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/oci/ai_language/models/sentiment_document_result.rb', line 76

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.key = attributes[:'key'] if attributes[:'key']

  self.document_sentiment = attributes[:'documentSentiment'] if attributes[:'documentSentiment']

  raise 'You cannot provide both :documentSentiment and :document_sentiment' if attributes.key?(:'documentSentiment') && attributes.key?(:'document_sentiment')

  self.document_sentiment = attributes[:'document_sentiment'] if attributes[:'document_sentiment']

  self.document_scores = attributes[:'documentScores'] if attributes[:'documentScores']

  raise 'You cannot provide both :documentScores and :document_scores' if attributes.key?(:'documentScores') && attributes.key?(:'document_scores')

  self.document_scores = attributes[:'document_scores'] if attributes[:'document_scores']

  self.aspects = attributes[:'aspects'] if attributes[:'aspects']

  self.sentences = attributes[:'sentences'] if attributes[:'sentences']

  self.language_code = attributes[:'languageCode'] if attributes[:'languageCode']

  raise 'You cannot provide both :languageCode and :language_code' if attributes.key?(:'languageCode') && attributes.key?(:'language_code')

  self.language_code = attributes[:'language_code'] if attributes[:'language_code']
end

Instance Attribute Details

#aspectsArray<OCI::AiLanguage::Models::SentimentAspect>

[Required] List of detected aspects sentiment.



26
27
28
# File 'lib/oci/ai_language/models/sentiment_document_result.rb', line 26

def aspects
  @aspects
end

#document_scoresHash<String, Float>

Scores for each sentiment. Example: 1.0, "negative": 0.0

Returns:

  • (Hash<String, Float>)


22
23
24
# File 'lib/oci/ai_language/models/sentiment_document_result.rb', line 22

def document_scores
  @document_scores
end

#document_sentimentString

Document level sentiment.

Returns:

  • (String)


16
17
18
# File 'lib/oci/ai_language/models/sentiment_document_result.rb', line 16

def document_sentiment
  @document_sentiment
end

#keyString

[Required] Document Unique Identifier.

Returns:

  • (String)


12
13
14
# File 'lib/oci/ai_language/models/sentiment_document_result.rb', line 12

def key
  @key
end

#language_codeString

[Required] Language code as per [ISO 639-1](en.wikipedia.org/wiki/List_of_ISO_639-1_codes) standard.

Returns:

  • (String)


34
35
36
# File 'lib/oci/ai_language/models/sentiment_document_result.rb', line 34

def language_code
  @language_code
end

#sentencesArray<OCI::AiLanguage::Models::SentimentSentence>

List of detected sentences sentiment.



30
31
32
# File 'lib/oci/ai_language/models/sentiment_document_result.rb', line 30

def sentences
  @sentences
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
47
48
# File 'lib/oci/ai_language/models/sentiment_document_result.rb', line 37

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'key',
    'document_sentiment': :'documentSentiment',
    'document_scores': :'documentScores',
    'aspects': :'aspects',
    'sentences': :'sentences',
    'language_code': :'languageCode'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/oci/ai_language/models/sentiment_document_result.rb', line 51

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'String',
    'document_sentiment': :'String',
    'document_scores': :'Hash<String, Float>',
    'aspects': :'Array<OCI::AiLanguage::Models::SentimentAspect>',
    'sentences': :'Array<OCI::AiLanguage::Models::SentimentSentence>',
    'language_code': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



114
115
116
117
118
119
120
121
122
123
124
# File 'lib/oci/ai_language/models/sentiment_document_result.rb', line 114

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    key == other.key &&
    document_sentiment == other.document_sentiment &&
    document_scores == other.document_scores &&
    aspects == other.aspects &&
    sentences == other.sentences &&
    language_code == other.language_code
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/oci/ai_language/models/sentiment_document_result.rb', line 149

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


129
130
131
# File 'lib/oci/ai_language/models/sentiment_document_result.rb', line 129

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



138
139
140
# File 'lib/oci/ai_language/models/sentiment_document_result.rb', line 138

def hash
  [key, document_sentiment, document_scores, aspects, sentences, language_code].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



182
183
184
185
186
187
188
189
190
191
# File 'lib/oci/ai_language/models/sentiment_document_result.rb', line 182

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



176
177
178
# File 'lib/oci/ai_language/models/sentiment_document_result.rb', line 176

def to_s
  to_hash.to_s
end