Class: OCI::AiSpeech::Models::TranscriptionJob

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/ai_speech/models/transcription_job.rb

Overview

Description of Transcription Job.

Constant Summary collapse

ADDITIONAL_TRANSCRIPTION_FORMATS_ENUM =
[
  ADDITIONAL_TRANSCRIPTION_FORMATS_SRT = 'SRT'.freeze,
  ADDITIONAL_TRANSCRIPTION_FORMATS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_ACCEPTED = 'ACCEPTED'.freeze,
  LIFECYCLE_STATE_IN_PROGRESS = 'IN_PROGRESS'.freeze,
  LIFECYCLE_STATE_SUCCEEDED = 'SUCCEEDED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_CANCELING = 'CANCELING'.freeze,
  LIFECYCLE_STATE_CANCELED = 'CANCELED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ TranscriptionJob

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/oci/ai_speech/models/transcription_job.rb', line 214

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.description = attributes[:'description'] if attributes[:'description']

  self.model_details = attributes[:'modelDetails'] if attributes[:'modelDetails']

  raise 'You cannot provide both :modelDetails and :model_details' if attributes.key?(:'modelDetails') && attributes.key?(:'model_details')

  self.model_details = attributes[:'model_details'] if attributes[:'model_details']

  self.normalization = attributes[:'normalization'] if attributes[:'normalization']

  self.time_accepted = attributes[:'timeAccepted'] if attributes[:'timeAccepted']

  raise 'You cannot provide both :timeAccepted and :time_accepted' if attributes.key?(:'timeAccepted') && attributes.key?(:'time_accepted')

  self.time_accepted = attributes[:'time_accepted'] if attributes[:'time_accepted']

  self.time_started = attributes[:'timeStarted'] if attributes[:'timeStarted']

  raise 'You cannot provide both :timeStarted and :time_started' if attributes.key?(:'timeStarted') && attributes.key?(:'time_started')

  self.time_started = attributes[:'time_started'] if attributes[:'time_started']

  self.time_finished = attributes[:'timeFinished'] if attributes[:'timeFinished']

  raise 'You cannot provide both :timeFinished and :time_finished' if attributes.key?(:'timeFinished') && attributes.key?(:'time_finished')

  self.time_finished = attributes[:'time_finished'] if attributes[:'time_finished']

  self.total_tasks = attributes[:'totalTasks'] if attributes[:'totalTasks']

  raise 'You cannot provide both :totalTasks and :total_tasks' if attributes.key?(:'totalTasks') && attributes.key?(:'total_tasks')

  self.total_tasks = attributes[:'total_tasks'] if attributes[:'total_tasks']

  self.outstanding_tasks = attributes[:'outstandingTasks'] if attributes[:'outstandingTasks']

  raise 'You cannot provide both :outstandingTasks and :outstanding_tasks' if attributes.key?(:'outstandingTasks') && attributes.key?(:'outstanding_tasks')

  self.outstanding_tasks = attributes[:'outstanding_tasks'] if attributes[:'outstanding_tasks']

  self.successful_tasks = attributes[:'successfulTasks'] if attributes[:'successfulTasks']

  raise 'You cannot provide both :successfulTasks and :successful_tasks' if attributes.key?(:'successfulTasks') && attributes.key?(:'successful_tasks')

  self.successful_tasks = attributes[:'successful_tasks'] if attributes[:'successful_tasks']

  self.ttl_in_days = attributes[:'ttlInDays'] if attributes[:'ttlInDays']

  raise 'You cannot provide both :ttlInDays and :ttl_in_days' if attributes.key?(:'ttlInDays') && attributes.key?(:'ttl_in_days')

  self.ttl_in_days = attributes[:'ttl_in_days'] if attributes[:'ttl_in_days']

  self.percent_complete = attributes[:'percentComplete'] if attributes[:'percentComplete']

  raise 'You cannot provide both :percentComplete and :percent_complete' if attributes.key?(:'percentComplete') && attributes.key?(:'percent_complete')

  self.percent_complete = attributes[:'percent_complete'] if attributes[:'percent_complete']

  self.input_location = attributes[:'inputLocation'] if attributes[:'inputLocation']

  raise 'You cannot provide both :inputLocation and :input_location' if attributes.key?(:'inputLocation') && attributes.key?(:'input_location')

  self.input_location = attributes[:'input_location'] if attributes[:'input_location']

  self.output_location = attributes[:'outputLocation'] if attributes[:'outputLocation']

  raise 'You cannot provide both :outputLocation and :output_location' if attributes.key?(:'outputLocation') && attributes.key?(:'output_location')

  self.output_location = attributes[:'output_location'] if attributes[:'output_location']

  self.created_by = attributes[:'createdBy'] if attributes[:'createdBy']

  raise 'You cannot provide both :createdBy and :created_by' if attributes.key?(:'createdBy') && attributes.key?(:'created_by')

  self.created_by = attributes[:'created_by'] if attributes[:'created_by']

  self.additional_transcription_formats = attributes[:'additionalTranscriptionFormats'] if attributes[:'additionalTranscriptionFormats']

  raise 'You cannot provide both :additionalTranscriptionFormats and :additional_transcription_formats' if attributes.key?(:'additionalTranscriptionFormats') && attributes.key?(:'additional_transcription_formats')

  self.additional_transcription_formats = attributes[:'additional_transcription_formats'] if attributes[:'additional_transcription_formats']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

  raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

  self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']
end

Instance Attribute Details

#additional_transcription_formatsArray<String>

Transcription format. JSON format will always be provided in addition to any formats in this list.

Returns:

  • (Array<String>)


95
96
97
# File 'lib/oci/ai_speech/models/transcription_job.rb', line 95

def additional_transcription_formats
  @additional_transcription_formats
end

#compartment_idString

**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment where you want to create the job.

Returns:

  • (String)


36
37
38
# File 'lib/oci/ai_speech/models/transcription_job.rb', line 36

def compartment_id
  @compartment_id
end

#created_byString

The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the user who created the job.

Returns:

  • (String)


91
92
93
# File 'lib/oci/ai_speech/models/transcription_job.rb', line 91

def created_by
  @created_by
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


115
116
117
# File 'lib/oci/ai_speech/models/transcription_job.rb', line 115

def defined_tags
  @defined_tags
end

#descriptionString

A short description of the job.

Returns:

  • (String)


40
41
42
# File 'lib/oci/ai_speech/models/transcription_job.rb', line 40

def description
  @description
end

#display_nameString

A user-friendly display name for the job.

Returns:

  • (String)


32
33
34
# File 'lib/oci/ai_speech/models/transcription_job.rb', line 32

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`

Returns:

  • (Hash<String, String>)


109
110
111
# File 'lib/oci/ai_speech/models/transcription_job.rb', line 109

def freeform_tags
  @freeform_tags
end

#idString

Returns:

  • (String)


28
29
30
# File 'lib/oci/ai_speech/models/transcription_job.rb', line 28

def id
  @id
end

#input_locationOCI::AiSpeech::Models::InputLocation

This attribute is required.



83
84
85
# File 'lib/oci/ai_speech/models/transcription_job.rb', line 83

def input_location
  @input_location
end

#lifecycle_detailsString

A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.

Returns:

  • (String)


103
104
105
# File 'lib/oci/ai_speech/models/transcription_job.rb', line 103

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

The current state of the Job.

Returns:

  • (String)


99
100
101
# File 'lib/oci/ai_speech/models/transcription_job.rb', line 99

def lifecycle_state
  @lifecycle_state
end

#model_detailsOCI::AiSpeech::Models::TranscriptionModelDetails

This attribute is required.



44
45
46
# File 'lib/oci/ai_speech/models/transcription_job.rb', line 44

def model_details
  @model_details
end

#normalizationOCI::AiSpeech::Models::TranscriptionNormalization



47
48
49
# File 'lib/oci/ai_speech/models/transcription_job.rb', line 47

def normalization
  @normalization
end

#output_locationOCI::AiSpeech::Models::OutputLocation

This attribute is required.



87
88
89
# File 'lib/oci/ai_speech/models/transcription_job.rb', line 87

def output_location
  @output_location
end

#outstanding_tasksInteger

Total outstanding tasks in a job.

Returns:

  • (Integer)


67
68
69
# File 'lib/oci/ai_speech/models/transcription_job.rb', line 67

def outstanding_tasks
  @outstanding_tasks
end

#percent_completeInteger

How much progress the operation has made, vs the total amount of work that must be performed.

Returns:

  • (Integer)


79
80
81
# File 'lib/oci/ai_speech/models/transcription_job.rb', line 79

def percent_complete
  @percent_complete
end

#successful_tasksInteger

Total successful tasks in a job.

Returns:

  • (Integer)


71
72
73
# File 'lib/oci/ai_speech/models/transcription_job.rb', line 71

def successful_tasks
  @successful_tasks
end

#system_tagsHash<String, Hash<String, Object>>

Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"free-tier-retained": "true"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


121
122
123
# File 'lib/oci/ai_speech/models/transcription_job.rb', line 121

def system_tags
  @system_tags
end

#time_acceptedDateTime

Job accepted time.

Returns:

  • (DateTime)


51
52
53
# File 'lib/oci/ai_speech/models/transcription_job.rb', line 51

def time_accepted
  @time_accepted
end

#time_finishedDateTime

Job finished time.

Returns:

  • (DateTime)


59
60
61
# File 'lib/oci/ai_speech/models/transcription_job.rb', line 59

def time_finished
  @time_finished
end

#time_startedDateTime

Job started time.

Returns:

  • (DateTime)


55
56
57
# File 'lib/oci/ai_speech/models/transcription_job.rb', line 55

def time_started
  @time_started
end

#total_tasksInteger

Total tasks in a job.

Returns:

  • (Integer)


63
64
65
# File 'lib/oci/ai_speech/models/transcription_job.rb', line 63

def total_tasks
  @total_tasks
end

#ttl_in_daysInteger

Time to live duration in days for Job. Job will be available till max 90 days.

Returns:

  • (Integer)


75
76
77
# File 'lib/oci/ai_speech/models/transcription_job.rb', line 75

def ttl_in_days
  @ttl_in_days
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/oci/ai_speech/models/transcription_job.rb', line 124

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'display_name': :'displayName',
    'compartment_id': :'compartmentId',
    'description': :'description',
    'model_details': :'modelDetails',
    'normalization': :'normalization',
    'time_accepted': :'timeAccepted',
    'time_started': :'timeStarted',
    'time_finished': :'timeFinished',
    'total_tasks': :'totalTasks',
    'outstanding_tasks': :'outstandingTasks',
    'successful_tasks': :'successfulTasks',
    'ttl_in_days': :'ttlInDays',
    'percent_complete': :'percentComplete',
    'input_location': :'inputLocation',
    'output_location': :'outputLocation',
    'created_by': :'createdBy',
    'additional_transcription_formats': :'additionalTranscriptionFormats',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/oci/ai_speech/models/transcription_job.rb', line 155

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'display_name': :'String',
    'compartment_id': :'String',
    'description': :'String',
    'model_details': :'OCI::AiSpeech::Models::TranscriptionModelDetails',
    'normalization': :'OCI::AiSpeech::Models::TranscriptionNormalization',
    'time_accepted': :'DateTime',
    'time_started': :'DateTime',
    'time_finished': :'DateTime',
    'total_tasks': :'Integer',
    'outstanding_tasks': :'Integer',
    'successful_tasks': :'Integer',
    'ttl_in_days': :'Integer',
    'percent_complete': :'Integer',
    'input_location': :'OCI::AiSpeech::Models::InputLocation',
    'output_location': :'OCI::AiSpeech::Models::OutputLocation',
    'created_by': :'String',
    'additional_transcription_formats': :'Array<String>',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
# File 'lib/oci/ai_speech/models/transcription_job.rb', line 387

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    display_name == other.display_name &&
    compartment_id == other.compartment_id &&
    description == other.description &&
    model_details == other.model_details &&
    normalization == other.normalization &&
    time_accepted == other.time_accepted &&
    time_started == other.time_started &&
    time_finished == other.time_finished &&
    total_tasks == other.total_tasks &&
    outstanding_tasks == other.outstanding_tasks &&
    successful_tasks == other.successful_tasks &&
    ttl_in_days == other.ttl_in_days &&
    percent_complete == other.percent_complete &&
    input_location == other.input_location &&
    output_location == other.output_location &&
    created_by == other.created_by &&
    additional_transcription_formats == other.additional_transcription_formats &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
# File 'lib/oci/ai_speech/models/transcription_job.rb', line 439

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


419
420
421
# File 'lib/oci/ai_speech/models/transcription_job.rb', line 419

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



428
429
430
# File 'lib/oci/ai_speech/models/transcription_job.rb', line 428

def hash
  [id, display_name, compartment_id, description, model_details, normalization, time_accepted, time_started, time_finished, total_tasks, outstanding_tasks, successful_tasks, ttl_in_days, percent_complete, input_location, output_location, created_by, additional_transcription_formats, lifecycle_state, lifecycle_details, freeform_tags, defined_tags, system_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



472
473
474
475
476
477
478
479
480
481
# File 'lib/oci/ai_speech/models/transcription_job.rb', line 472

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



466
467
468
# File 'lib/oci/ai_speech/models/transcription_job.rb', line 466

def to_s
  to_hash.to_s
end