Class: OCI::AiSpeech::Models::TranscriptionJobSummary
- Inherits:
-
Object
- Object
- OCI::AiSpeech::Models::TranscriptionJobSummary
- Defined in:
- lib/oci/ai_speech/models/transcription_job_summary.rb
Overview
Summary of the Transcription Job.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment where you want to create the job.
-
#created_by ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the user who created the job.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
**[Required]** A user-friendly display name for the job.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the job.
-
#lifecycle_details ⇒ String
A message describing the current state in more detail.
-
#lifecycle_state ⇒ String
The current state of the Speech Job.
-
#outstanding_tasks ⇒ Integer
Total outstanding tasks in a job.
-
#percent_complete ⇒ Integer
How much progress the operation has made, vs the total amount of work that must be performed.
-
#successful_tasks ⇒ Integer
Total successful tasks in a job.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys.
-
#time_accepted ⇒ DateTime
Job accepted time.
-
#time_finished ⇒ DateTime
Job finished time.
-
#time_started ⇒ DateTime
Job started time.
-
#total_tasks ⇒ Integer
Total number of tasks in a job.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TranscriptionJobSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ TranscriptionJobSummary
Initializes the object
150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/oci/ai_speech/models/transcription_job_summary.rb', line 150 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.created_by = attributes[:'createdBy'] if attributes[:'createdBy'] raise 'You cannot provide both :createdBy and :created_by' if attributes.key?(:'createdBy') && attributes.key?(:'created_by') self.created_by = attributes[:'created_by'] if attributes[:'created_by'] self.percent_complete = attributes[:'percentComplete'] if attributes[:'percentComplete'] raise 'You cannot provide both :percentComplete and :percent_complete' if attributes.key?(:'percentComplete') && attributes.key?(:'percent_complete') self.percent_complete = attributes[:'percent_complete'] if attributes[:'percent_complete'] self.time_accepted = attributes[:'timeAccepted'] if attributes[:'timeAccepted'] raise 'You cannot provide both :timeAccepted and :time_accepted' if attributes.key?(:'timeAccepted') && attributes.key?(:'time_accepted') self.time_accepted = attributes[:'time_accepted'] if attributes[:'time_accepted'] self.time_started = attributes[:'timeStarted'] if attributes[:'timeStarted'] raise 'You cannot provide both :timeStarted and :time_started' if attributes.key?(:'timeStarted') && attributes.key?(:'time_started') self.time_started = attributes[:'time_started'] if attributes[:'time_started'] self.time_finished = attributes[:'timeFinished'] if attributes[:'timeFinished'] raise 'You cannot provide both :timeFinished and :time_finished' if attributes.key?(:'timeFinished') && attributes.key?(:'time_finished') self.time_finished = attributes[:'time_finished'] if attributes[:'time_finished'] self.total_tasks = attributes[:'totalTasks'] if attributes[:'totalTasks'] raise 'You cannot provide both :totalTasks and :total_tasks' if attributes.key?(:'totalTasks') && attributes.key?(:'total_tasks') self.total_tasks = attributes[:'total_tasks'] if attributes[:'total_tasks'] self.outstanding_tasks = attributes[:'outstandingTasks'] if attributes[:'outstandingTasks'] raise 'You cannot provide both :outstandingTasks and :outstanding_tasks' if attributes.key?(:'outstandingTasks') && attributes.key?(:'outstanding_tasks') self.outstanding_tasks = attributes[:'outstanding_tasks'] if attributes[:'outstanding_tasks'] self.successful_tasks = attributes[:'successfulTasks'] if attributes[:'successfulTasks'] raise 'You cannot provide both :successfulTasks and :successful_tasks' if attributes.key?(:'successfulTasks') && attributes.key?(:'successful_tasks') self.successful_tasks = attributes[:'successful_tasks'] if attributes[:'successful_tasks'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment where you want to create the job.
20 21 22 |
# File 'lib/oci/ai_speech/models/transcription_job_summary.rb', line 20 def compartment_id @compartment_id end |
#created_by ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the user who created the job.
24 25 26 |
# File 'lib/oci/ai_speech/models/transcription_job_summary.rb', line 24 def created_by @created_by end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
72 73 74 |
# File 'lib/oci/ai_speech/models/transcription_job_summary.rb', line 72 def @defined_tags end |
#display_name ⇒ String
**[Required]** A user-friendly display name for the job.
16 17 18 |
# File 'lib/oci/ai_speech/models/transcription_job_summary.rb', line 16 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
66 67 68 |
# File 'lib/oci/ai_speech/models/transcription_job_summary.rb', line 66 def @freeform_tags end |
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the job.
12 13 14 |
# File 'lib/oci/ai_speech/models/transcription_job_summary.rb', line 12 def id @id end |
#lifecycle_details ⇒ String
A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
60 61 62 |
# File 'lib/oci/ai_speech/models/transcription_job_summary.rb', line 60 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
The current state of the Speech Job.
56 57 58 |
# File 'lib/oci/ai_speech/models/transcription_job_summary.rb', line 56 def lifecycle_state @lifecycle_state end |
#outstanding_tasks ⇒ Integer
Total outstanding tasks in a job.
48 49 50 |
# File 'lib/oci/ai_speech/models/transcription_job_summary.rb', line 48 def outstanding_tasks @outstanding_tasks end |
#percent_complete ⇒ Integer
How much progress the operation has made, vs the total amount of work that must be performed.
28 29 30 |
# File 'lib/oci/ai_speech/models/transcription_job_summary.rb', line 28 def percent_complete @percent_complete end |
#successful_tasks ⇒ Integer
Total successful tasks in a job.
52 53 54 |
# File 'lib/oci/ai_speech/models/transcription_job_summary.rb', line 52 def successful_tasks @successful_tasks end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"free-tier-retained": "true"}`
78 79 80 |
# File 'lib/oci/ai_speech/models/transcription_job_summary.rb', line 78 def @system_tags end |
#time_accepted ⇒ DateTime
Job accepted time.
32 33 34 |
# File 'lib/oci/ai_speech/models/transcription_job_summary.rb', line 32 def time_accepted @time_accepted end |
#time_finished ⇒ DateTime
Job finished time.
40 41 42 |
# File 'lib/oci/ai_speech/models/transcription_job_summary.rb', line 40 def time_finished @time_finished end |
#time_started ⇒ DateTime
Job started time.
36 37 38 |
# File 'lib/oci/ai_speech/models/transcription_job_summary.rb', line 36 def time_started @time_started end |
#total_tasks ⇒ Integer
Total number of tasks in a job.
44 45 46 |
# File 'lib/oci/ai_speech/models/transcription_job_summary.rb', line 44 def total_tasks @total_tasks end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/oci/ai_speech/models/transcription_job_summary.rb', line 81 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'created_by': :'createdBy', 'percent_complete': :'percentComplete', 'time_accepted': :'timeAccepted', 'time_started': :'timeStarted', 'time_finished': :'timeFinished', 'total_tasks': :'totalTasks', 'outstanding_tasks': :'outstandingTasks', 'successful_tasks': :'successfulTasks', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/oci/ai_speech/models/transcription_job_summary.rb', line 105 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'compartment_id': :'String', 'created_by': :'String', 'percent_complete': :'Integer', 'time_accepted': :'DateTime', 'time_started': :'DateTime', 'time_finished': :'DateTime', 'total_tasks': :'Integer', 'outstanding_tasks': :'Integer', 'successful_tasks': :'Integer', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/oci/ai_speech/models/transcription_job_summary.rb', line 256 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && compartment_id == other.compartment_id && created_by == other.created_by && percent_complete == other.percent_complete && time_accepted == other.time_accepted && time_started == other.time_started && time_finished == other.time_finished && total_tasks == other.total_tasks && outstanding_tasks == other.outstanding_tasks && successful_tasks == other.successful_tasks && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 |
# File 'lib/oci/ai_speech/models/transcription_job_summary.rb', line 301 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
281 282 283 |
# File 'lib/oci/ai_speech/models/transcription_job_summary.rb', line 281 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
290 291 292 |
# File 'lib/oci/ai_speech/models/transcription_job_summary.rb', line 290 def hash [id, display_name, compartment_id, created_by, percent_complete, time_accepted, time_started, time_finished, total_tasks, outstanding_tasks, successful_tasks, lifecycle_state, lifecycle_details, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
334 335 336 337 338 339 340 341 342 343 |
# File 'lib/oci/ai_speech/models/transcription_job_summary.rb', line 334 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
328 329 330 |
# File 'lib/oci/ai_speech/models/transcription_job_summary.rb', line 328 def to_s to_hash.to_s end |