Class: OCI::AiSpeech::Models::TranscriptionModelDetails
- Inherits:
-
Object
- Object
- OCI::AiSpeech::Models::TranscriptionModelDetails
- Defined in:
- lib/oci/ai_speech/models/transcription_model_details.rb
Overview
Model details.
Constant Summary collapse
- DOMAIN_ENUM =
[ DOMAIN_GENERIC = 'GENERIC'.freeze, DOMAIN_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LANGUAGE_CODE_ENUM =
[ LANGUAGE_CODE_EN_US = 'en-US'.freeze, LANGUAGE_CODE_ES_ES = 'es-ES'.freeze, LANGUAGE_CODE_PT_BR = 'pt-BR'.freeze, LANGUAGE_CODE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#domain ⇒ String
Domain for input files.
-
#language_code ⇒ String
Locale value as per given in [datatracker.ietf.org/doc/html/rfc5646].
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TranscriptionModelDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ TranscriptionModelDetails
Initializes the object
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/oci/ai_speech/models/transcription_model_details.rb', line 59 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.domain = attributes[:'domain'] if attributes[:'domain'] self.domain = "GENERIC" if domain.nil? && !attributes.key?(:'domain') # rubocop:disable Style/StringLiterals self.language_code = attributes[:'languageCode'] if attributes[:'languageCode'] self.language_code = "en-US" if language_code.nil? && !attributes.key?(:'languageCode') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :languageCode and :language_code' if attributes.key?(:'languageCode') && attributes.key?(:'language_code') self.language_code = attributes[:'language_code'] if attributes[:'language_code'] self.language_code = "en-US" if language_code.nil? && !attributes.key?(:'languageCode') && !attributes.key?(:'language_code') # rubocop:disable Style/StringLiterals end |
Instance Attribute Details
#domain ⇒ String
Domain for input files.
25 26 27 |
# File 'lib/oci/ai_speech/models/transcription_model_details.rb', line 25 def domain @domain end |
#language_code ⇒ String
Locale value as per given in [datatracker.ietf.org/doc/html/rfc5646].
29 30 31 |
# File 'lib/oci/ai_speech/models/transcription_model_details.rb', line 29 def language_code @language_code end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 |
# File 'lib/oci/ai_speech/models/transcription_model_details.rb', line 32 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'domain': :'domain', 'language_code': :'languageCode' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
42 43 44 45 46 47 48 49 |
# File 'lib/oci/ai_speech/models/transcription_model_details.rb', line 42 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'domain': :'String', 'language_code': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
110 111 112 113 114 115 116 |
# File 'lib/oci/ai_speech/models/transcription_model_details.rb', line 110 def ==(other) return true if equal?(other) self.class == other.class && domain == other.domain && language_code == other.language_code end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/oci/ai_speech/models/transcription_model_details.rb', line 141 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
121 122 123 |
# File 'lib/oci/ai_speech/models/transcription_model_details.rb', line 121 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
130 131 132 |
# File 'lib/oci/ai_speech/models/transcription_model_details.rb', line 130 def hash [domain, language_code].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
174 175 176 177 178 179 180 181 182 183 |
# File 'lib/oci/ai_speech/models/transcription_model_details.rb', line 174 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
168 169 170 |
# File 'lib/oci/ai_speech/models/transcription_model_details.rb', line 168 def to_s to_hash.to_s end |