Class: OCI::AiSpeech::Models::TranscriptionTask

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/ai_speech/models/transcription_task.rb

Overview

Description of Transcription Task.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_ACCEPTED = 'ACCEPTED'.freeze,
  LIFECYCLE_STATE_IN_PROGRESS = 'IN_PROGRESS'.freeze,
  LIFECYCLE_STATE_SUCCEEDED = 'SUCCEEDED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_CANCELED = 'CANCELED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ TranscriptionTask

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/oci/ai_speech/models/transcription_task.rb', line 136

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.time_started = attributes[:'timeStarted'] if attributes[:'timeStarted']

  raise 'You cannot provide both :timeStarted and :time_started' if attributes.key?(:'timeStarted') && attributes.key?(:'time_started')

  self.time_started = attributes[:'time_started'] if attributes[:'time_started']

  self.time_finished = attributes[:'timeFinished'] if attributes[:'timeFinished']

  raise 'You cannot provide both :timeFinished and :time_finished' if attributes.key?(:'timeFinished') && attributes.key?(:'time_finished')

  self.time_finished = attributes[:'time_finished'] if attributes[:'time_finished']

  self.percent_complete = attributes[:'percentComplete'] if attributes[:'percentComplete']

  raise 'You cannot provide both :percentComplete and :percent_complete' if attributes.key?(:'percentComplete') && attributes.key?(:'percent_complete')

  self.percent_complete = attributes[:'percent_complete'] if attributes[:'percent_complete']

  self.ttl_in_days = attributes[:'ttlInDays'] if attributes[:'ttlInDays']

  raise 'You cannot provide both :ttlInDays and :ttl_in_days' if attributes.key?(:'ttlInDays') && attributes.key?(:'ttl_in_days')

  self.ttl_in_days = attributes[:'ttl_in_days'] if attributes[:'ttl_in_days']

  self.model_details = attributes[:'modelDetails'] if attributes[:'modelDetails']

  raise 'You cannot provide both :modelDetails and :model_details' if attributes.key?(:'modelDetails') && attributes.key?(:'model_details')

  self.model_details = attributes[:'model_details'] if attributes[:'model_details']

  self.audio_format_details = attributes[:'audioFormatDetails'] if attributes[:'audioFormatDetails']

  raise 'You cannot provide both :audioFormatDetails and :audio_format_details' if attributes.key?(:'audioFormatDetails') && attributes.key?(:'audio_format_details')

  self.audio_format_details = attributes[:'audio_format_details'] if attributes[:'audio_format_details']

  self.file_size_in_bytes = attributes[:'fileSizeInBytes'] if attributes[:'fileSizeInBytes']

  raise 'You cannot provide both :fileSizeInBytes and :file_size_in_bytes' if attributes.key?(:'fileSizeInBytes') && attributes.key?(:'file_size_in_bytes')

  self.file_size_in_bytes = attributes[:'file_size_in_bytes'] if attributes[:'file_size_in_bytes']

  self.file_duration_in_seconds = attributes[:'fileDurationInSeconds'] if attributes[:'fileDurationInSeconds']

  raise 'You cannot provide both :fileDurationInSeconds and :file_duration_in_seconds' if attributes.key?(:'fileDurationInSeconds') && attributes.key?(:'file_duration_in_seconds')

  self.file_duration_in_seconds = attributes[:'file_duration_in_seconds'] if attributes[:'file_duration_in_seconds']

  self.input_location = attributes[:'inputLocation'] if attributes[:'inputLocation']

  raise 'You cannot provide both :inputLocation and :input_location' if attributes.key?(:'inputLocation') && attributes.key?(:'input_location')

  self.input_location = attributes[:'input_location'] if attributes[:'input_location']

  self.output_location = attributes[:'outputLocation'] if attributes[:'outputLocation']

  raise 'You cannot provide both :outputLocation and :output_location' if attributes.key?(:'outputLocation') && attributes.key?(:'output_location')

  self.output_location = attributes[:'output_location'] if attributes[:'output_location']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']
end

Instance Attribute Details

#audio_format_detailsOCI::AiSpeech::Models::AudioFormatDetails



48
49
50
# File 'lib/oci/ai_speech/models/transcription_task.rb', line 48

def audio_format_details
  @audio_format_details
end

#display_nameString

A user-friendly display name for the task.

Returns:

  • (String)


26
27
28
# File 'lib/oci/ai_speech/models/transcription_task.rb', line 26

def display_name
  @display_name
end

#file_duration_in_secondsInteger

Duration of input file in Seconds.

Returns:

  • (Integer)


56
57
58
# File 'lib/oci/ai_speech/models/transcription_task.rb', line 56

def file_duration_in_seconds
  @file_duration_in_seconds
end

#file_size_in_bytesInteger

Size of input file in Bytes.

Returns:

  • (Integer)


52
53
54
# File 'lib/oci/ai_speech/models/transcription_task.rb', line 52

def file_size_in_bytes
  @file_size_in_bytes
end

#idString

Returns:

  • (String)


22
23
24
# File 'lib/oci/ai_speech/models/transcription_task.rb', line 22

def id
  @id
end

#input_locationOCI::AiSpeech::Models::ObjectLocation



59
60
61
# File 'lib/oci/ai_speech/models/transcription_task.rb', line 59

def input_location
  @input_location
end

#lifecycle_detailsString

A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.

Returns:

  • (String)


70
71
72
# File 'lib/oci/ai_speech/models/transcription_task.rb', line 70

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

The current state of the Task.

Returns:

  • (String)


66
67
68
# File 'lib/oci/ai_speech/models/transcription_task.rb', line 66

def lifecycle_state
  @lifecycle_state
end

#model_detailsOCI::AiSpeech::Models::TranscriptionModelDetails



45
46
47
# File 'lib/oci/ai_speech/models/transcription_task.rb', line 45

def model_details
  @model_details
end

#output_locationOCI::AiSpeech::Models::ObjectLocation



62
63
64
# File 'lib/oci/ai_speech/models/transcription_task.rb', line 62

def output_location
  @output_location
end

#percent_completeInteger

How much progress the operation has made, vs the total amount of work that must be performed.

Returns:

  • (Integer)


38
39
40
# File 'lib/oci/ai_speech/models/transcription_task.rb', line 38

def percent_complete
  @percent_complete
end

#time_finishedDateTime

Task finished time.

Returns:

  • (DateTime)


34
35
36
# File 'lib/oci/ai_speech/models/transcription_task.rb', line 34

def time_finished
  @time_finished
end

#time_startedDateTime

Task started time.

Returns:

  • (DateTime)


30
31
32
# File 'lib/oci/ai_speech/models/transcription_task.rb', line 30

def time_started
  @time_started
end

#ttl_in_daysInteger

Time to live duration in days for tasks. Task will be available till max 90 days.

Returns:

  • (Integer)


42
43
44
# File 'lib/oci/ai_speech/models/transcription_task.rb', line 42

def ttl_in_days
  @ttl_in_days
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/oci/ai_speech/models/transcription_task.rb', line 73

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'display_name': :'displayName',
    'time_started': :'timeStarted',
    'time_finished': :'timeFinished',
    'percent_complete': :'percentComplete',
    'ttl_in_days': :'ttlInDays',
    'model_details': :'modelDetails',
    'audio_format_details': :'audioFormatDetails',
    'file_size_in_bytes': :'fileSizeInBytes',
    'file_duration_in_seconds': :'fileDurationInSeconds',
    'input_location': :'inputLocation',
    'output_location': :'outputLocation',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/oci/ai_speech/models/transcription_task.rb', line 95

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'display_name': :'String',
    'time_started': :'DateTime',
    'time_finished': :'DateTime',
    'percent_complete': :'Integer',
    'ttl_in_days': :'Integer',
    'model_details': :'OCI::AiSpeech::Models::TranscriptionModelDetails',
    'audio_format_details': :'OCI::AiSpeech::Models::AudioFormatDetails',
    'file_size_in_bytes': :'Integer',
    'file_duration_in_seconds': :'Integer',
    'input_location': :'OCI::AiSpeech::Models::ObjectLocation',
    'output_location': :'OCI::AiSpeech::Models::ObjectLocation',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/oci/ai_speech/models/transcription_task.rb', line 243

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    display_name == other.display_name &&
    time_started == other.time_started &&
    time_finished == other.time_finished &&
    percent_complete == other.percent_complete &&
    ttl_in_days == other.ttl_in_days &&
    model_details == other.model_details &&
    audio_format_details == other.audio_format_details &&
    file_size_in_bytes == other.file_size_in_bytes &&
    file_duration_in_seconds == other.file_duration_in_seconds &&
    input_location == other.input_location &&
    output_location == other.output_location &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
# File 'lib/oci/ai_speech/models/transcription_task.rb', line 286

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


266
267
268
# File 'lib/oci/ai_speech/models/transcription_task.rb', line 266

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



275
276
277
# File 'lib/oci/ai_speech/models/transcription_task.rb', line 275

def hash
  [id, display_name, time_started, time_finished, percent_complete, ttl_in_days, model_details, audio_format_details, file_size_in_bytes, file_duration_in_seconds, input_location, output_location, lifecycle_state, lifecycle_details].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



319
320
321
322
323
324
325
326
327
328
# File 'lib/oci/ai_speech/models/transcription_task.rb', line 319

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



313
314
315
# File 'lib/oci/ai_speech/models/transcription_task.rb', line 313

def to_s
  to_hash.to_s
end