Class: OCI::AiSpeech::Models::TranscriptionTaskSummary
- Inherits:
-
Object
- Object
- OCI::AiSpeech::Models::TranscriptionTaskSummary
- Defined in:
- lib/oci/ai_speech/models/transcription_task_summary.rb
Overview
Summary of the Transcription Task.
Instance Attribute Summary collapse
-
#display_name ⇒ String
**[Required]** A user-friendly display name for the task.
-
#file_duration_in_seconds ⇒ Integer
Duration of input file in Seconds.
-
#file_size_in_bytes ⇒ Integer
Size of input file in Bytes.
-
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the task.
-
#lifecycle_details ⇒ String
A message describing the current state in more detail.
-
#lifecycle_state ⇒ String
The current state of the Speech Job.
-
#percent_complete ⇒ Integer
How much progress the operation has made, vs the total amount of work that must be performed.
-
#time_finished ⇒ DateTime
Job finished time.
-
#time_started ⇒ DateTime
Task started time.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TranscriptionTaskSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ TranscriptionTaskSummary
Initializes the object
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/oci/ai_speech/models/transcription_task_summary.rb', line 95 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.percent_complete = attributes[:'percentComplete'] if attributes[:'percentComplete'] raise 'You cannot provide both :percentComplete and :percent_complete' if attributes.key?(:'percentComplete') && attributes.key?(:'percent_complete') self.percent_complete = attributes[:'percent_complete'] if attributes[:'percent_complete'] self.file_size_in_bytes = attributes[:'fileSizeInBytes'] if attributes[:'fileSizeInBytes'] raise 'You cannot provide both :fileSizeInBytes and :file_size_in_bytes' if attributes.key?(:'fileSizeInBytes') && attributes.key?(:'file_size_in_bytes') self.file_size_in_bytes = attributes[:'file_size_in_bytes'] if attributes[:'file_size_in_bytes'] self.file_duration_in_seconds = attributes[:'fileDurationInSeconds'] if attributes[:'fileDurationInSeconds'] raise 'You cannot provide both :fileDurationInSeconds and :file_duration_in_seconds' if attributes.key?(:'fileDurationInSeconds') && attributes.key?(:'file_duration_in_seconds') self.file_duration_in_seconds = attributes[:'file_duration_in_seconds'] if attributes[:'file_duration_in_seconds'] self.time_started = attributes[:'timeStarted'] if attributes[:'timeStarted'] raise 'You cannot provide both :timeStarted and :time_started' if attributes.key?(:'timeStarted') && attributes.key?(:'time_started') self.time_started = attributes[:'time_started'] if attributes[:'time_started'] self.time_finished = attributes[:'timeFinished'] if attributes[:'timeFinished'] raise 'You cannot provide both :timeFinished and :time_finished' if attributes.key?(:'timeFinished') && attributes.key?(:'time_finished') self.time_finished = attributes[:'time_finished'] if attributes[:'time_finished'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] end |
Instance Attribute Details
#display_name ⇒ String
**[Required]** A user-friendly display name for the task.
16 17 18 |
# File 'lib/oci/ai_speech/models/transcription_task_summary.rb', line 16 def display_name @display_name end |
#file_duration_in_seconds ⇒ Integer
Duration of input file in Seconds.
28 29 30 |
# File 'lib/oci/ai_speech/models/transcription_task_summary.rb', line 28 def file_duration_in_seconds @file_duration_in_seconds end |
#file_size_in_bytes ⇒ Integer
Size of input file in Bytes.
24 25 26 |
# File 'lib/oci/ai_speech/models/transcription_task_summary.rb', line 24 def file_size_in_bytes @file_size_in_bytes end |
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the task.
12 13 14 |
# File 'lib/oci/ai_speech/models/transcription_task_summary.rb', line 12 def id @id end |
#lifecycle_details ⇒ String
A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
44 45 46 |
# File 'lib/oci/ai_speech/models/transcription_task_summary.rb', line 44 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
The current state of the Speech Job.
40 41 42 |
# File 'lib/oci/ai_speech/models/transcription_task_summary.rb', line 40 def lifecycle_state @lifecycle_state end |
#percent_complete ⇒ Integer
How much progress the operation has made, vs the total amount of work that must be performed.
20 21 22 |
# File 'lib/oci/ai_speech/models/transcription_task_summary.rb', line 20 def percent_complete @percent_complete end |
#time_finished ⇒ DateTime
Job finished time
36 37 38 |
# File 'lib/oci/ai_speech/models/transcription_task_summary.rb', line 36 def time_finished @time_finished end |
#time_started ⇒ DateTime
Task started time
32 33 34 |
# File 'lib/oci/ai_speech/models/transcription_task_summary.rb', line 32 def time_started @time_started end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/oci/ai_speech/models/transcription_task_summary.rb', line 47 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'percent_complete': :'percentComplete', 'file_size_in_bytes': :'fileSizeInBytes', 'file_duration_in_seconds': :'fileDurationInSeconds', 'time_started': :'timeStarted', 'time_finished': :'timeFinished', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/oci/ai_speech/models/transcription_task_summary.rb', line 64 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'percent_complete': :'Integer', 'file_size_in_bytes': :'Integer', 'file_duration_in_seconds': :'Integer', 'time_started': :'DateTime', 'time_finished': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_details': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/oci/ai_speech/models/transcription_task_summary.rb', line 159 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && percent_complete == other.percent_complete && file_size_in_bytes == other.file_size_in_bytes && file_duration_in_seconds == other.file_duration_in_seconds && time_started == other.time_started && time_finished == other.time_finished && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/oci/ai_speech/models/transcription_task_summary.rb', line 197 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
177 178 179 |
# File 'lib/oci/ai_speech/models/transcription_task_summary.rb', line 177 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
186 187 188 |
# File 'lib/oci/ai_speech/models/transcription_task_summary.rb', line 186 def hash [id, display_name, percent_complete, file_size_in_bytes, file_duration_in_seconds, time_started, time_finished, lifecycle_state, lifecycle_details].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
230 231 232 233 234 235 236 237 238 239 |
# File 'lib/oci/ai_speech/models/transcription_task_summary.rb', line 230 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
224 225 226 |
# File 'lib/oci/ai_speech/models/transcription_task_summary.rb', line 224 def to_s to_hash.to_s end |