Class: OCI::AiVision::Models::AnalyzeDocumentDetails
- Inherits:
-
Object
- Object
- OCI::AiVision::Models::AnalyzeDocumentDetails
- Defined in:
- lib/oci/ai_vision/models/analyze_document_details.rb
Overview
The details of how to analyze a document.
Constant Summary collapse
- LANGUAGE_ENUM =
[ LANGUAGE_ENG = 'ENG'.freeze, LANGUAGE_CES = 'CES'.freeze, LANGUAGE_DAN = 'DAN'.freeze, LANGUAGE_NLD = 'NLD'.freeze, LANGUAGE_FIN = 'FIN'.freeze, LANGUAGE_FRA = 'FRA'.freeze, LANGUAGE_DEU = 'DEU'.freeze, LANGUAGE_ELL = 'ELL'.freeze, LANGUAGE_HUN = 'HUN'.freeze, LANGUAGE_ITA = 'ITA'.freeze, LANGUAGE_NOR = 'NOR'.freeze, LANGUAGE_POL = 'POL'.freeze, LANGUAGE_POR = 'POR'.freeze, LANGUAGE_RON = 'RON'.freeze, LANGUAGE_RUS = 'RUS'.freeze, LANGUAGE_SLK = 'SLK'.freeze, LANGUAGE_SPA = 'SPA'.freeze, LANGUAGE_SWE = 'SWE'.freeze, LANGUAGE_TUR = 'TUR'.freeze, LANGUAGE_ARA = 'ARA'.freeze, LANGUAGE_CHI_SIM = 'CHI_SIM'.freeze, LANGUAGE_HIN = 'HIN'.freeze, LANGUAGE_JPN = 'JPN'.freeze, LANGUAGE_KOR = 'KOR'.freeze, LANGUAGE_OTHERS = 'OTHERS'.freeze ].freeze
- DOCUMENT_TYPE_ENUM =
[ DOCUMENT_TYPE_INVOICE = 'INVOICE'.freeze, DOCUMENT_TYPE_RECEIPT = 'RECEIPT'.freeze, DOCUMENT_TYPE_RESUME = 'RESUME'.freeze, DOCUMENT_TYPE_TAX_FORM = 'TAX_FORM'.freeze, DOCUMENT_TYPE_DRIVER_LICENSE = 'DRIVER_LICENSE'.freeze, DOCUMENT_TYPE_PASSPORT = 'PASSPORT'.freeze, DOCUMENT_TYPE_BANK_STATEMENT = 'BANK_STATEMENT'.freeze, DOCUMENT_TYPE_CHECK = 'CHECK'.freeze, DOCUMENT_TYPE_PAYSLIP = 'PAYSLIP'.freeze, DOCUMENT_TYPE_OTHERS = 'OTHERS'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
The OCID of the compartment that calls the API.
-
#document ⇒ OCI::AiVision::Models::DocumentDetails
This attribute is required.
-
#document_type ⇒ String
The document type.
-
#features ⇒ Array<OCI::AiVision::Models::DocumentFeature>
**[Required]** The types of document analysis requested.
-
#language ⇒ String
The document language, abbreviated according to ISO 639-2.
- #output_location ⇒ OCI::AiVision::Models::OutputLocation
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AnalyzeDocumentDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ AnalyzeDocumentDetails
Initializes the object
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/oci/ai_vision/models/analyze_document_details.rb', line 114 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.features = attributes[:'features'] if attributes[:'features'] self.document = attributes[:'document'] if attributes[:'document'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.output_location = attributes[:'outputLocation'] if attributes[:'outputLocation'] raise 'You cannot provide both :outputLocation and :output_location' if attributes.key?(:'outputLocation') && attributes.key?(:'output_location') self.output_location = attributes[:'output_location'] if attributes[:'output_location'] self.language = attributes[:'language'] if attributes[:'language'] self.document_type = attributes[:'documentType'] if attributes[:'documentType'] raise 'You cannot provide both :documentType and :document_type' if attributes.key?(:'documentType') && attributes.key?(:'document_type') self.document_type = attributes[:'document_type'] if attributes[:'document_type'] end |
Instance Attribute Details
#compartment_id ⇒ String
The OCID of the compartment that calls the API.
61 62 63 |
# File 'lib/oci/ai_vision/models/analyze_document_details.rb', line 61 def compartment_id @compartment_id end |
#document ⇒ OCI::AiVision::Models::DocumentDetails
This attribute is required.
57 58 59 |
# File 'lib/oci/ai_vision/models/analyze_document_details.rb', line 57 def document @document end |
#document_type ⇒ String
The document type.
72 73 74 |
# File 'lib/oci/ai_vision/models/analyze_document_details.rb', line 72 def document_type @document_type end |
#features ⇒ Array<OCI::AiVision::Models::DocumentFeature>
**[Required]** The types of document analysis requested.
53 54 55 |
# File 'lib/oci/ai_vision/models/analyze_document_details.rb', line 53 def features @features end |
#language ⇒ String
The document language, abbreviated according to ISO 639-2.
68 69 70 |
# File 'lib/oci/ai_vision/models/analyze_document_details.rb', line 68 def language @language end |
#output_location ⇒ OCI::AiVision::Models::OutputLocation
64 65 66 |
# File 'lib/oci/ai_vision/models/analyze_document_details.rb', line 64 def output_location @output_location end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/oci/ai_vision/models/analyze_document_details.rb', line 75 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'features': :'features', 'document': :'document', 'compartment_id': :'compartmentId', 'output_location': :'outputLocation', 'language': :'language', 'document_type': :'documentType' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/oci/ai_vision/models/analyze_document_details.rb', line 89 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'features': :'Array<OCI::AiVision::Models::DocumentFeature>', 'document': :'OCI::AiVision::Models::DocumentDetails', 'compartment_id': :'String', 'output_location': :'OCI::AiVision::Models::OutputLocation', 'language': :'String', 'document_type': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/oci/ai_vision/models/analyze_document_details.rb', line 168 def ==(other) return true if equal?(other) self.class == other.class && features == other.features && document == other.document && compartment_id == other.compartment_id && output_location == other.output_location && language == other.language && document_type == other.document_type end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/oci/ai_vision/models/analyze_document_details.rb', line 203 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
183 184 185 |
# File 'lib/oci/ai_vision/models/analyze_document_details.rb', line 183 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
192 193 194 |
# File 'lib/oci/ai_vision/models/analyze_document_details.rb', line 192 def hash [features, document, compartment_id, output_location, language, document_type].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
236 237 238 239 240 241 242 243 244 245 |
# File 'lib/oci/ai_vision/models/analyze_document_details.rb', line 236 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
230 231 232 |
# File 'lib/oci/ai_vision/models/analyze_document_details.rb', line 230 def to_s to_hash.to_s end |