Class: OCI::AiVision::Models::CreateDocumentJobDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/ai_vision/models/create_document_job_details.rb

Overview

Details about the batch document analysis.

Constant Summary collapse

LANGUAGE_ENUM =
[
  LANGUAGE_ENG = 'ENG'.freeze,
  LANGUAGE_CES = 'CES'.freeze,
  LANGUAGE_DAN = 'DAN'.freeze,
  LANGUAGE_NLD = 'NLD'.freeze,
  LANGUAGE_FIN = 'FIN'.freeze,
  LANGUAGE_FRA = 'FRA'.freeze,
  LANGUAGE_DEU = 'DEU'.freeze,
  LANGUAGE_ELL = 'ELL'.freeze,
  LANGUAGE_HUN = 'HUN'.freeze,
  LANGUAGE_ITA = 'ITA'.freeze,
  LANGUAGE_NOR = 'NOR'.freeze,
  LANGUAGE_POL = 'POL'.freeze,
  LANGUAGE_POR = 'POR'.freeze,
  LANGUAGE_RON = 'RON'.freeze,
  LANGUAGE_RUS = 'RUS'.freeze,
  LANGUAGE_SLK = 'SLK'.freeze,
  LANGUAGE_SPA = 'SPA'.freeze,
  LANGUAGE_SWE = 'SWE'.freeze,
  LANGUAGE_TUR = 'TUR'.freeze,
  LANGUAGE_ARA = 'ARA'.freeze,
  LANGUAGE_CHI_SIM = 'CHI_SIM'.freeze,
  LANGUAGE_HIN = 'HIN'.freeze,
  LANGUAGE_JPN = 'JPN'.freeze,
  LANGUAGE_KOR = 'KOR'.freeze,
  LANGUAGE_OTHERS = 'OTHERS'.freeze
].freeze
DOCUMENT_TYPE_ENUM =
[
  DOCUMENT_TYPE_INVOICE = 'INVOICE'.freeze,
  DOCUMENT_TYPE_RECEIPT = 'RECEIPT'.freeze,
  DOCUMENT_TYPE_RESUME = 'RESUME'.freeze,
  DOCUMENT_TYPE_TAX_FORM = 'TAX_FORM'.freeze,
  DOCUMENT_TYPE_DRIVER_LICENSE = 'DRIVER_LICENSE'.freeze,
  DOCUMENT_TYPE_PASSPORT = 'PASSPORT'.freeze,
  DOCUMENT_TYPE_BANK_STATEMENT = 'BANK_STATEMENT'.freeze,
  DOCUMENT_TYPE_CHECK = 'CHECK'.freeze,
  DOCUMENT_TYPE_PAYSLIP = 'PAYSLIP'.freeze,
  DOCUMENT_TYPE_OTHERS = 'OTHERS'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateDocumentJobDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/oci/ai_vision/models/create_document_job_details.rb', line 129

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.input_location = attributes[:'inputLocation'] if attributes[:'inputLocation']

  raise 'You cannot provide both :inputLocation and :input_location' if attributes.key?(:'inputLocation') && attributes.key?(:'input_location')

  self.input_location = attributes[:'input_location'] if attributes[:'input_location']

  self.features = attributes[:'features'] if attributes[:'features']

  self.output_location = attributes[:'outputLocation'] if attributes[:'outputLocation']

  raise 'You cannot provide both :outputLocation and :output_location' if attributes.key?(:'outputLocation') && attributes.key?(:'output_location')

  self.output_location = attributes[:'output_location'] if attributes[:'output_location']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.language = attributes[:'language'] if attributes[:'language']
  self.language = "ENG" if language.nil? && !attributes.key?(:'language') # rubocop:disable Style/StringLiterals

  self.document_type = attributes[:'documentType'] if attributes[:'documentType']

  raise 'You cannot provide both :documentType and :document_type' if attributes.key?(:'documentType') && attributes.key?(:'document_type')

  self.document_type = attributes[:'document_type'] if attributes[:'document_type']

  self.is_zip_output_enabled = attributes[:'isZipOutputEnabled'] unless attributes[:'isZipOutputEnabled'].nil?
  self.is_zip_output_enabled = false if is_zip_output_enabled.nil? && !attributes.key?(:'isZipOutputEnabled') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isZipOutputEnabled and :is_zip_output_enabled' if attributes.key?(:'isZipOutputEnabled') && attributes.key?(:'is_zip_output_enabled')

  self.is_zip_output_enabled = attributes[:'is_zip_output_enabled'] unless attributes[:'is_zip_output_enabled'].nil?
  self.is_zip_output_enabled = false if is_zip_output_enabled.nil? && !attributes.key?(:'isZipOutputEnabled') && !attributes.key?(:'is_zip_output_enabled') # rubocop:disable Style/StringLiterals
end

Instance Attribute Details

#compartment_idString

Compartment identifier from the requester.

Returns:

  • (String)


65
66
67
# File 'lib/oci/ai_vision/models/create_document_job_details.rb', line 65

def compartment_id
  @compartment_id
end

#display_nameString

Document job display name.

Returns:

  • (String)


69
70
71
# File 'lib/oci/ai_vision/models/create_document_job_details.rb', line 69

def display_name
  @display_name
end

#document_typeString

The type of documents.

Returns:

  • (String)


77
78
79
# File 'lib/oci/ai_vision/models/create_document_job_details.rb', line 77

def document_type
  @document_type
end

#featuresArray<OCI::AiVision::Models::DocumentFeature>

[Required] List of document analysis types requested.



57
58
59
# File 'lib/oci/ai_vision/models/create_document_job_details.rb', line 57

def features
  @features
end

#input_locationOCI::AiVision::Models::InputLocation

This attribute is required.



53
54
55
# File 'lib/oci/ai_vision/models/create_document_job_details.rb', line 53

def input_location
  @input_location
end

#is_zip_output_enabledBOOLEAN

Whether to generate a Zip file containing the results.

Returns:

  • (BOOLEAN)


81
82
83
# File 'lib/oci/ai_vision/models/create_document_job_details.rb', line 81

def is_zip_output_enabled
  @is_zip_output_enabled
end

#languageString

Language of the document, abbreviated according to ISO 639-2.

Returns:

  • (String)


73
74
75
# File 'lib/oci/ai_vision/models/create_document_job_details.rb', line 73

def language
  @language
end

#output_locationOCI::AiVision::Models::OutputLocation

This attribute is required.



61
62
63
# File 'lib/oci/ai_vision/models/create_document_job_details.rb', line 61

def output_location
  @output_location
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/oci/ai_vision/models/create_document_job_details.rb', line 84

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'input_location': :'inputLocation',
    'features': :'features',
    'output_location': :'outputLocation',
    'compartment_id': :'compartmentId',
    'display_name': :'displayName',
    'language': :'language',
    'document_type': :'documentType',
    'is_zip_output_enabled': :'isZipOutputEnabled'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/oci/ai_vision/models/create_document_job_details.rb', line 100

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'input_location': :'OCI::AiVision::Models::InputLocation',
    'features': :'Array<OCI::AiVision::Models::DocumentFeature>',
    'output_location': :'OCI::AiVision::Models::OutputLocation',
    'compartment_id': :'String',
    'display_name': :'String',
    'language': :'String',
    'document_type': :'String',
    'is_zip_output_enabled': :'BOOLEAN'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/oci/ai_vision/models/create_document_job_details.rb', line 202

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    input_location == other.input_location &&
    features == other.features &&
    output_location == other.output_location &&
    compartment_id == other.compartment_id &&
    display_name == other.display_name &&
    language == other.language &&
    document_type == other.document_type &&
    is_zip_output_enabled == other.is_zip_output_enabled
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/oci/ai_vision/models/create_document_job_details.rb', line 239

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


219
220
221
# File 'lib/oci/ai_vision/models/create_document_job_details.rb', line 219

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



228
229
230
# File 'lib/oci/ai_vision/models/create_document_job_details.rb', line 228

def hash
  [input_location, features, output_location, compartment_id, display_name, language, document_type, is_zip_output_enabled].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



272
273
274
275
276
277
278
279
280
281
# File 'lib/oci/ai_vision/models/create_document_job_details.rb', line 272

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



266
267
268
# File 'lib/oci/ai_vision/models/create_document_job_details.rb', line 266

def to_s
  to_hash.to_s
end