Class: OCI::AiVision::Models::CreateModelDetails
- Inherits:
-
Object
- Object
- OCI::AiVision::Models::CreateModelDetails
- Defined in:
- lib/oci/ai_vision/models/create_model_details.rb
Overview
Information needed to create a new model.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] Compartment identifier.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
Optional description of the model.
-
#display_name ⇒ String
Human-friendly name for the model, which can be changed.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#is_quick_mode ⇒ BOOLEAN
Set to true when experimenting with a new model type or dataset so model training is quick, with a predefined low number of passes through the training data.
-
#max_training_duration_in_hours ⇒ Float
Maximum model training duration in hours, expressed as a decimal fraction.
-
#model_type ⇒ String
[Required] What type of Vision model this is.
-
#model_version ⇒ String
Model version.
-
#project_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the project which contains the model.
- #testing_dataset ⇒ OCI::AiVision::Models::Dataset
-
#training_dataset ⇒ OCI::AiVision::Models::Dataset
This attribute is required.
- #validation_dataset ⇒ OCI::AiVision::Models::Dataset
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateModelDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateModelDetails
Initializes the object
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/oci/ai_vision/models/create_model_details.rb', line 125 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] self.display_name = "" if display_name.nil? && !attributes.key?(:'displayName') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.display_name = "" if display_name.nil? && !attributes.key?(:'displayName') && !attributes.key?(:'display_name') # rubocop:disable Style/StringLiterals self.description = attributes[:'description'] if attributes[:'description'] self.description = "The description of the Model." if description.nil? && !attributes.key?(:'description') # rubocop:disable Style/StringLiterals self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion'] raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version') self.model_version = attributes[:'model_version'] if attributes[:'model_version'] self.model_type = attributes[:'modelType'] if attributes[:'modelType'] raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type') self.model_type = attributes[:'model_type'] if attributes[:'model_type'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.is_quick_mode = attributes[:'isQuickMode'] unless attributes[:'isQuickMode'].nil? self.is_quick_mode = false if is_quick_mode.nil? && !attributes.key?(:'isQuickMode') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isQuickMode and :is_quick_mode' if attributes.key?(:'isQuickMode') && attributes.key?(:'is_quick_mode') self.is_quick_mode = attributes[:'is_quick_mode'] unless attributes[:'is_quick_mode'].nil? self.is_quick_mode = false if is_quick_mode.nil? && !attributes.key?(:'isQuickMode') && !attributes.key?(:'is_quick_mode') # rubocop:disable Style/StringLiterals self.max_training_duration_in_hours = attributes[:'maxTrainingDurationInHours'] if attributes[:'maxTrainingDurationInHours'] raise 'You cannot provide both :maxTrainingDurationInHours and :max_training_duration_in_hours' if attributes.key?(:'maxTrainingDurationInHours') && attributes.key?(:'max_training_duration_in_hours') self.max_training_duration_in_hours = attributes[:'max_training_duration_in_hours'] if attributes[:'max_training_duration_in_hours'] self.training_dataset = attributes[:'trainingDataset'] if attributes[:'trainingDataset'] raise 'You cannot provide both :trainingDataset and :training_dataset' if attributes.key?(:'trainingDataset') && attributes.key?(:'training_dataset') self.training_dataset = attributes[:'training_dataset'] if attributes[:'training_dataset'] self.testing_dataset = attributes[:'testingDataset'] if attributes[:'testingDataset'] raise 'You cannot provide both :testingDataset and :testing_dataset' if attributes.key?(:'testingDataset') && attributes.key?(:'testing_dataset') self.testing_dataset = attributes[:'testing_dataset'] if attributes[:'testing_dataset'] self.validation_dataset = attributes[:'validationDataset'] if attributes[:'validationDataset'] raise 'You cannot provide both :validationDataset and :validation_dataset' if attributes.key?(:'validationDataset') && attributes.key?(:'validation_dataset') self.validation_dataset = attributes[:'validation_dataset'] if attributes[:'validation_dataset'] self.project_id = attributes[:'projectId'] if attributes[:'projectId'] raise 'You cannot provide both :projectId and :project_id' if attributes.key?(:'projectId') && attributes.key?(:'project_id') self.project_id = attributes[:'project_id'] if attributes[:'project_id'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] Compartment identifier.
28 29 30 |
# File 'lib/oci/ai_vision/models/create_model_details.rb', line 28 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
62 63 64 |
# File 'lib/oci/ai_vision/models/create_model_details.rb', line 62 def end |
#description ⇒ String
Optional description of the model.
16 17 18 |
# File 'lib/oci/ai_vision/models/create_model_details.rb', line 16 def description @description end |
#display_name ⇒ String
Human-friendly name for the model, which can be changed.
12 13 14 |
# File 'lib/oci/ai_vision/models/create_model_details.rb', line 12 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`
56 57 58 |
# File 'lib/oci/ai_vision/models/create_model_details.rb', line 56 def end |
#is_quick_mode ⇒ BOOLEAN
Set to true when experimenting with a new model type or dataset so model training is quick, with a predefined low number of passes through the training data.
32 33 34 |
# File 'lib/oci/ai_vision/models/create_model_details.rb', line 32 def is_quick_mode @is_quick_mode end |
#max_training_duration_in_hours ⇒ Float
Maximum model training duration in hours, expressed as a decimal fraction.
36 37 38 |
# File 'lib/oci/ai_vision/models/create_model_details.rb', line 36 def max_training_duration_in_hours @max_training_duration_in_hours end |
#model_type ⇒ String
[Required] What type of Vision model this is.
24 25 26 |
# File 'lib/oci/ai_vision/models/create_model_details.rb', line 24 def model_type @model_type end |
#model_version ⇒ String
Model version
20 21 22 |
# File 'lib/oci/ai_vision/models/create_model_details.rb', line 20 def model_version @model_version end |
#project_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the project which contains the model.
50 51 52 |
# File 'lib/oci/ai_vision/models/create_model_details.rb', line 50 def project_id @project_id end |
#testing_dataset ⇒ OCI::AiVision::Models::Dataset
43 44 45 |
# File 'lib/oci/ai_vision/models/create_model_details.rb', line 43 def testing_dataset @testing_dataset end |
#training_dataset ⇒ OCI::AiVision::Models::Dataset
This attribute is required.
40 41 42 |
# File 'lib/oci/ai_vision/models/create_model_details.rb', line 40 def training_dataset @training_dataset end |
#validation_dataset ⇒ OCI::AiVision::Models::Dataset
46 47 48 |
# File 'lib/oci/ai_vision/models/create_model_details.rb', line 46 def validation_dataset @validation_dataset end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/oci/ai_vision/models/create_model_details.rb', line 65 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'description': :'description', 'model_version': :'modelVersion', 'model_type': :'modelType', 'compartment_id': :'compartmentId', 'is_quick_mode': :'isQuickMode', 'max_training_duration_in_hours': :'maxTrainingDurationInHours', 'training_dataset': :'trainingDataset', 'testing_dataset': :'testingDataset', 'validation_dataset': :'validationDataset', 'project_id': :'projectId', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/oci/ai_vision/models/create_model_details.rb', line 86 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'description': :'String', 'model_version': :'String', 'model_type': :'String', 'compartment_id': :'String', 'is_quick_mode': :'BOOLEAN', 'max_training_duration_in_hours': :'Float', 'training_dataset': :'OCI::AiVision::Models::Dataset', 'testing_dataset': :'OCI::AiVision::Models::Dataset', 'validation_dataset': :'OCI::AiVision::Models::Dataset', 'project_id': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 |
# File 'lib/oci/ai_vision/models/create_model_details.rb', line 218 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && description == other.description && model_version == other.model_version && model_type == other.model_type && compartment_id == other.compartment_id && is_quick_mode == other.is_quick_mode && max_training_duration_in_hours == other.max_training_duration_in_hours && training_dataset == other.training_dataset && testing_dataset == other.testing_dataset && validation_dataset == other.validation_dataset && project_id == other.project_id && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/oci/ai_vision/models/create_model_details.rb', line 260 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
240 241 242 |
# File 'lib/oci/ai_vision/models/create_model_details.rb', line 240 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
249 250 251 |
# File 'lib/oci/ai_vision/models/create_model_details.rb', line 249 def hash [display_name, description, model_version, model_type, compartment_id, is_quick_mode, max_training_duration_in_hours, training_dataset, testing_dataset, validation_dataset, project_id, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
293 294 295 296 297 298 299 300 301 302 |
# File 'lib/oci/ai_vision/models/create_model_details.rb', line 293 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
287 288 289 |
# File 'lib/oci/ai_vision/models/create_model_details.rb', line 287 def to_s to_hash.to_s end |