Class: OCI::AiVision::Models::DocumentJob

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/ai_vision/models/document_job.rb

Overview

Job details for a batch document analysis.

Constant Summary collapse

LANGUAGE_ENUM =
[
  LANGUAGE_ENG = 'ENG'.freeze,
  LANGUAGE_CES = 'CES'.freeze,
  LANGUAGE_DAN = 'DAN'.freeze,
  LANGUAGE_NLD = 'NLD'.freeze,
  LANGUAGE_FIN = 'FIN'.freeze,
  LANGUAGE_FRA = 'FRA'.freeze,
  LANGUAGE_DEU = 'DEU'.freeze,
  LANGUAGE_ELL = 'ELL'.freeze,
  LANGUAGE_HUN = 'HUN'.freeze,
  LANGUAGE_ITA = 'ITA'.freeze,
  LANGUAGE_NOR = 'NOR'.freeze,
  LANGUAGE_POL = 'POL'.freeze,
  LANGUAGE_POR = 'POR'.freeze,
  LANGUAGE_RON = 'RON'.freeze,
  LANGUAGE_RUS = 'RUS'.freeze,
  LANGUAGE_SLK = 'SLK'.freeze,
  LANGUAGE_SPA = 'SPA'.freeze,
  LANGUAGE_SWE = 'SWE'.freeze,
  LANGUAGE_TUR = 'TUR'.freeze,
  LANGUAGE_ARA = 'ARA'.freeze,
  LANGUAGE_CHI_SIM = 'CHI_SIM'.freeze,
  LANGUAGE_HIN = 'HIN'.freeze,
  LANGUAGE_JPN = 'JPN'.freeze,
  LANGUAGE_KOR = 'KOR'.freeze,
  LANGUAGE_OTHERS = 'OTHERS'.freeze,
  LANGUAGE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
DOCUMENT_TYPE_ENUM =
[
  DOCUMENT_TYPE_INVOICE = 'INVOICE'.freeze,
  DOCUMENT_TYPE_RECEIPT = 'RECEIPT'.freeze,
  DOCUMENT_TYPE_RESUME = 'RESUME'.freeze,
  DOCUMENT_TYPE_TAX_FORM = 'TAX_FORM'.freeze,
  DOCUMENT_TYPE_DRIVER_LICENSE = 'DRIVER_LICENSE'.freeze,
  DOCUMENT_TYPE_PASSPORT = 'PASSPORT'.freeze,
  DOCUMENT_TYPE_BANK_STATEMENT = 'BANK_STATEMENT'.freeze,
  DOCUMENT_TYPE_CHECK = 'CHECK'.freeze,
  DOCUMENT_TYPE_PAYSLIP = 'PAYSLIP'.freeze,
  DOCUMENT_TYPE_OTHERS = 'OTHERS'.freeze,
  DOCUMENT_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_SUCCEEDED = 'SUCCEEDED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_ACCEPTED = 'ACCEPTED'.freeze,
  LIFECYCLE_STATE_CANCELED = 'CANCELED'.freeze,
  LIFECYCLE_STATE_IN_PROGRESS = 'IN_PROGRESS'.freeze,
  LIFECYCLE_STATE_CANCELING = 'CANCELING'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_DETAILS_ENUM =
[
  LIFECYCLE_DETAILS_PARTIALLY_SUCCEEDED = 'PARTIALLY_SUCCEEDED'.freeze,
  LIFECYCLE_DETAILS_COMPLETELY_FAILED = 'COMPLETELY_FAILED'.freeze,
  LIFECYCLE_DETAILS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DocumentJob

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'lib/oci/ai_vision/models/document_job.rb', line 196

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.features = attributes[:'features'] if attributes[:'features']

  self.language = attributes[:'language'] if attributes[:'language']

  self.document_type = attributes[:'documentType'] if attributes[:'documentType']

  raise 'You cannot provide both :documentType and :document_type' if attributes.key?(:'documentType') && attributes.key?(:'document_type')

  self.document_type = attributes[:'document_type'] if attributes[:'document_type']

  self.input_location = attributes[:'inputLocation'] if attributes[:'inputLocation']

  raise 'You cannot provide both :inputLocation and :input_location' if attributes.key?(:'inputLocation') && attributes.key?(:'input_location')

  self.input_location = attributes[:'input_location'] if attributes[:'input_location']

  self.time_accepted = attributes[:'timeAccepted'] if attributes[:'timeAccepted']

  raise 'You cannot provide both :timeAccepted and :time_accepted' if attributes.key?(:'timeAccepted') && attributes.key?(:'time_accepted')

  self.time_accepted = attributes[:'time_accepted'] if attributes[:'time_accepted']

  self.time_started = attributes[:'timeStarted'] if attributes[:'timeStarted']

  raise 'You cannot provide both :timeStarted and :time_started' if attributes.key?(:'timeStarted') && attributes.key?(:'time_started')

  self.time_started = attributes[:'time_started'] if attributes[:'time_started']

  self.time_finished = attributes[:'timeFinished'] if attributes[:'timeFinished']

  raise 'You cannot provide both :timeFinished and :time_finished' if attributes.key?(:'timeFinished') && attributes.key?(:'time_finished')

  self.time_finished = attributes[:'time_finished'] if attributes[:'time_finished']

  self.percent_complete = attributes[:'percentComplete'] if attributes[:'percentComplete']

  raise 'You cannot provide both :percentComplete and :percent_complete' if attributes.key?(:'percentComplete') && attributes.key?(:'percent_complete')

  self.percent_complete = attributes[:'percent_complete'] if attributes[:'percent_complete']

  self.output_location = attributes[:'outputLocation'] if attributes[:'outputLocation']

  raise 'You cannot provide both :outputLocation and :output_location' if attributes.key?(:'outputLocation') && attributes.key?(:'output_location')

  self.output_location = attributes[:'output_location'] if attributes[:'output_location']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.is_zip_output_enabled = attributes[:'isZipOutputEnabled'] unless attributes[:'isZipOutputEnabled'].nil?
  self.is_zip_output_enabled = false if is_zip_output_enabled.nil? && !attributes.key?(:'isZipOutputEnabled') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isZipOutputEnabled and :is_zip_output_enabled' if attributes.key?(:'isZipOutputEnabled') && attributes.key?(:'is_zip_output_enabled')

  self.is_zip_output_enabled = attributes[:'is_zip_output_enabled'] unless attributes[:'is_zip_output_enabled'].nil?
  self.is_zip_output_enabled = false if is_zip_output_enabled.nil? && !attributes.key?(:'isZipOutputEnabled') && !attributes.key?(:'is_zip_output_enabled') # rubocop:disable Style/StringLiterals

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']
end

Instance Attribute Details

#compartment_idString

[Required] The OCID of the compartment that starts the job.

Returns:

  • (String)


76
77
78
# File 'lib/oci/ai_vision/models/document_job.rb', line 76

def compartment_id
  @compartment_id
end

#display_nameString

Document job display name.

Returns:

  • (String)


80
81
82
# File 'lib/oci/ai_vision/models/document_job.rb', line 80

def display_name
  @display_name
end

#document_typeString

The type of documents.

Returns:

  • (String)


92
93
94
# File 'lib/oci/ai_vision/models/document_job.rb', line 92

def document_type
  @document_type
end

#featuresArray<OCI::AiVision::Models::DocumentFeature>

[Required] List of document analysis types requested.



84
85
86
# File 'lib/oci/ai_vision/models/document_job.rb', line 84

def features
  @features
end

#idString

[Required] Job id.

Returns:

  • (String)


72
73
74
# File 'lib/oci/ai_vision/models/document_job.rb', line 72

def id
  @id
end

#input_locationOCI::AiVision::Models::InputLocation



95
96
97
# File 'lib/oci/ai_vision/models/document_job.rb', line 95

def input_location
  @input_location
end

#is_zip_output_enabledBOOLEAN

Whether to generate a Zip file containing the results.

Returns:

  • (BOOLEAN)


123
124
125
# File 'lib/oci/ai_vision/models/document_job.rb', line 123

def is_zip_output_enabled
  @is_zip_output_enabled
end

#languageString

Language of the document, abbreviated according to ISO 639-2.

Returns:

  • (String)


88
89
90
# File 'lib/oci/ai_vision/models/document_job.rb', line 88

def language
  @language
end

#lifecycle_detailsString

Detailed status of FAILED state.

Returns:

  • (String)


127
128
129
# File 'lib/oci/ai_vision/models/document_job.rb', line 127

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

[Required] The current state of the batch document job.

Returns:

  • (String)


119
120
121
# File 'lib/oci/ai_vision/models/document_job.rb', line 119

def lifecycle_state
  @lifecycle_state
end

#output_locationOCI::AiVision::Models::OutputLocation

This attribute is required.



115
116
117
# File 'lib/oci/ai_vision/models/document_job.rb', line 115

def output_location
  @output_location
end

#percent_completeFloat

How much progress the operation has made, vs the total amount of work that must be performed.

Returns:

  • (Float)


111
112
113
# File 'lib/oci/ai_vision/models/document_job.rb', line 111

def percent_complete
  @percent_complete
end

#time_acceptedDateTime

[Required] Job accepted time.

Returns:

  • (DateTime)


99
100
101
# File 'lib/oci/ai_vision/models/document_job.rb', line 99

def time_accepted
  @time_accepted
end

#time_finishedDateTime

Job finished time.

Returns:

  • (DateTime)


107
108
109
# File 'lib/oci/ai_vision/models/document_job.rb', line 107

def time_finished
  @time_finished
end

#time_startedDateTime

Job started time.

Returns:

  • (DateTime)


103
104
105
# File 'lib/oci/ai_vision/models/document_job.rb', line 103

def time_started
  @time_started
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/oci/ai_vision/models/document_job.rb', line 130

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'compartment_id': :'compartmentId',
    'display_name': :'displayName',
    'features': :'features',
    'language': :'language',
    'document_type': :'documentType',
    'input_location': :'inputLocation',
    'time_accepted': :'timeAccepted',
    'time_started': :'timeStarted',
    'time_finished': :'timeFinished',
    'percent_complete': :'percentComplete',
    'output_location': :'outputLocation',
    'lifecycle_state': :'lifecycleState',
    'is_zip_output_enabled': :'isZipOutputEnabled',
    'lifecycle_details': :'lifecycleDetails'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/oci/ai_vision/models/document_job.rb', line 153

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'compartment_id': :'String',
    'display_name': :'String',
    'features': :'Array<OCI::AiVision::Models::DocumentFeature>',
    'language': :'String',
    'document_type': :'String',
    'input_location': :'OCI::AiVision::Models::InputLocation',
    'time_accepted': :'DateTime',
    'time_started': :'DateTime',
    'time_finished': :'DateTime',
    'percent_complete': :'Float',
    'output_location': :'OCI::AiVision::Models::OutputLocation',
    'lifecycle_state': :'String',
    'is_zip_output_enabled': :'BOOLEAN',
    'lifecycle_details': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
# File 'lib/oci/ai_vision/models/document_job.rb', line 342

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    display_name == other.display_name &&
    features == other.features &&
    language == other.language &&
    document_type == other.document_type &&
    input_location == other.input_location &&
    time_accepted == other.time_accepted &&
    time_started == other.time_started &&
    time_finished == other.time_finished &&
    percent_complete == other.percent_complete &&
    output_location == other.output_location &&
    lifecycle_state == other.lifecycle_state &&
    is_zip_output_enabled == other.is_zip_output_enabled &&
    lifecycle_details == other.lifecycle_details
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
# File 'lib/oci/ai_vision/models/document_job.rb', line 386

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


366
367
368
# File 'lib/oci/ai_vision/models/document_job.rb', line 366

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



375
376
377
# File 'lib/oci/ai_vision/models/document_job.rb', line 375

def hash
  [id, compartment_id, display_name, features, language, document_type, input_location, time_accepted, time_started, time_finished, percent_complete, output_location, lifecycle_state, is_zip_output_enabled, lifecycle_details].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



419
420
421
422
423
424
425
426
427
428
# File 'lib/oci/ai_vision/models/document_job.rb', line 419

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



413
414
415
# File 'lib/oci/ai_vision/models/document_job.rb', line 413

def to_s
  to_hash.to_s
end