Class: OCI::AiVision::Models::FieldValue
- Inherits:
-
Object
- Object
- OCI::AiVision::Models::FieldValue
- Defined in:
- lib/oci/ai_vision/models/field_value.rb
Overview
Value of a form field. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
ValueArray, ValueDate, ValueInteger, ValueNumber, ValuePhoneNumber, ValueString, ValueTime
Constant Summary collapse
- VALUE_TYPE_ENUM =
[ VALUE_TYPE_STRING = 'STRING'.freeze, VALUE_TYPE_DATE = 'DATE'.freeze, VALUE_TYPE_TIME = 'TIME'.freeze, VALUE_TYPE_PHONE_NUMBER = 'PHONE_NUMBER'.freeze, VALUE_TYPE_NUMBER = 'NUMBER'.freeze, VALUE_TYPE_INTEGER = 'INTEGER'.freeze, VALUE_TYPE_ARRAY = 'ARRAY'.freeze, VALUE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#bounding_polygon ⇒ OCI::AiVision::Models::BoundingPolygon
This attribute is required.
-
#confidence ⇒ Float
[Required] Confidence score between 0 to 1.
-
#text ⇒ String
Detected text of a field.
-
#value_type ⇒ String
[Required] Type of data detected.
-
#word_indexes ⇒ Array<Integer>
[Required] Indexes of the words in the field value.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ FieldValue
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ FieldValue
Initializes the object
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/oci/ai_vision/models/field_value.rb', line 102 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.value_type = attributes[:'valueType'] if attributes[:'valueType'] raise 'You cannot provide both :valueType and :value_type' if attributes.key?(:'valueType') && attributes.key?(:'value_type') self.value_type = attributes[:'value_type'] if attributes[:'value_type'] self.text = attributes[:'text'] if attributes[:'text'] self.confidence = attributes[:'confidence'] if attributes[:'confidence'] self.bounding_polygon = attributes[:'boundingPolygon'] if attributes[:'boundingPolygon'] raise 'You cannot provide both :boundingPolygon and :bounding_polygon' if attributes.key?(:'boundingPolygon') && attributes.key?(:'bounding_polygon') self.bounding_polygon = attributes[:'bounding_polygon'] if attributes[:'bounding_polygon'] self.word_indexes = attributes[:'wordIndexes'] if attributes[:'wordIndexes'] raise 'You cannot provide both :wordIndexes and :word_indexes' if attributes.key?(:'wordIndexes') && attributes.key?(:'word_indexes') self.word_indexes = attributes[:'word_indexes'] if attributes[:'word_indexes'] end |
Instance Attribute Details
#bounding_polygon ⇒ OCI::AiVision::Models::BoundingPolygon
This attribute is required.
38 39 40 |
# File 'lib/oci/ai_vision/models/field_value.rb', line 38 def bounding_polygon @bounding_polygon end |
#confidence ⇒ Float
[Required] Confidence score between 0 to 1.
34 35 36 |
# File 'lib/oci/ai_vision/models/field_value.rb', line 34 def confidence @confidence end |
#text ⇒ String
Detected text of a field.
30 31 32 |
# File 'lib/oci/ai_vision/models/field_value.rb', line 30 def text @text end |
#value_type ⇒ String
[Required] Type of data detected.
26 27 28 |
# File 'lib/oci/ai_vision/models/field_value.rb', line 26 def value_type @value_type end |
#word_indexes ⇒ Array<Integer>
[Required] Indexes of the words in the field value.
42 43 44 |
# File 'lib/oci/ai_vision/models/field_value.rb', line 42 def word_indexes @word_indexes end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/oci/ai_vision/models/field_value.rb', line 45 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'value_type': :'valueType', 'text': :'text', 'confidence': :'confidence', 'bounding_polygon': :'boundingPolygon', 'word_indexes': :'wordIndexes' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/oci/ai_vision/models/field_value.rb', line 75 def self.get_subtype(object_hash) type = object_hash[:'valueType'] # rubocop:disable Style/SymbolLiteral return 'OCI::AiVision::Models::ValueTime' if type == 'TIME' return 'OCI::AiVision::Models::ValueInteger' if type == 'INTEGER' return 'OCI::AiVision::Models::ValueDate' if type == 'DATE' return 'OCI::AiVision::Models::ValueNumber' if type == 'NUMBER' return 'OCI::AiVision::Models::ValueString' if type == 'STRING' return 'OCI::AiVision::Models::ValuePhoneNumber' if type == 'PHONE_NUMBER' return 'OCI::AiVision::Models::ValueArray' if type == 'ARRAY' # TODO: Log a warning when the subtype is not found. 'OCI::AiVision::Models::FieldValue' end |
.swagger_types ⇒ Object
Attribute type mapping.
58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/oci/ai_vision/models/field_value.rb', line 58 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'value_type': :'String', 'text': :'String', 'confidence': :'Float', 'bounding_polygon': :'OCI::AiVision::Models::BoundingPolygon', 'word_indexes': :'Array<Integer>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
151 152 153 154 155 156 157 158 159 160 |
# File 'lib/oci/ai_vision/models/field_value.rb', line 151 def ==(other) return true if equal?(other) self.class == other.class && value_type == other.value_type && text == other.text && confidence == other.confidence && bounding_polygon == other.bounding_polygon && word_indexes == other.word_indexes end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/oci/ai_vision/models/field_value.rb', line 185 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
165 166 167 |
# File 'lib/oci/ai_vision/models/field_value.rb', line 165 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
174 175 176 |
# File 'lib/oci/ai_vision/models/field_value.rb', line 174 def hash [value_type, text, confidence, bounding_polygon, word_indexes].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
218 219 220 221 222 223 224 225 226 227 |
# File 'lib/oci/ai_vision/models/field_value.rb', line 218 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
212 213 214 |
# File 'lib/oci/ai_vision/models/field_value.rb', line 212 def to_s to_hash.to_s end |