Class: OCI::AiVision::Models::ImageFeature
- Inherits:
-
Object
- Object
- OCI::AiVision::Models::ImageFeature
- Defined in:
- lib/oci/ai_vision/models/image_feature.rb
Overview
Type of image analysis. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
ImageClassificationFeature, ImageObjectDetectionFeature, ImageTextDetectionFeature
Constant Summary collapse
- FEATURE_TYPE_ENUM =
[ FEATURE_TYPE_IMAGE_CLASSIFICATION = 'IMAGE_CLASSIFICATION'.freeze, FEATURE_TYPE_OBJECT_DETECTION = 'OBJECT_DETECTION'.freeze, FEATURE_TYPE_TEXT_DETECTION = 'TEXT_DETECTION'.freeze, FEATURE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#feature_type ⇒ String
[Required] Type of image analysis requested.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ImageFeature
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ImageFeature
Initializes the object
70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/oci/ai_vision/models/image_feature.rb', line 70 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.feature_type = attributes[:'featureType'] if attributes[:'featureType'] raise 'You cannot provide both :featureType and :feature_type' if attributes.key?(:'featureType') && attributes.key?(:'feature_type') self.feature_type = attributes[:'feature_type'] if attributes[:'feature_type'] end |
Instance Attribute Details
#feature_type ⇒ String
[Required] Type of image analysis requested. Allowed values are:
-
IMAGE_CLASSIFICATION: Label the image. -
OBJECT_DETECTION: Identify objects in the image with bounding boxes. -
TEXT_DETECTION: Recognize text in the image.
26 27 28 |
# File 'lib/oci/ai_vision/models/image_feature.rb', line 26 def feature_type @feature_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 |
# File 'lib/oci/ai_vision/models/image_feature.rb', line 29 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'feature_type': :'featureType' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
51 52 53 54 55 56 57 58 59 60 |
# File 'lib/oci/ai_vision/models/image_feature.rb', line 51 def self.get_subtype(object_hash) type = object_hash[:'featureType'] # rubocop:disable Style/SymbolLiteral return 'OCI::AiVision::Models::ImageTextDetectionFeature' if type == 'TEXT_DETECTION' return 'OCI::AiVision::Models::ImageObjectDetectionFeature' if type == 'OBJECT_DETECTION' return 'OCI::AiVision::Models::ImageClassificationFeature' if type == 'IMAGE_CLASSIFICATION' # TODO: Log a warning when the subtype is not found. 'OCI::AiVision::Models::ImageFeature' end |
.swagger_types ⇒ Object
Attribute type mapping.
38 39 40 41 42 43 44 |
# File 'lib/oci/ai_vision/models/image_feature.rb', line 38 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'feature_type': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
103 104 105 106 107 108 |
# File 'lib/oci/ai_vision/models/image_feature.rb', line 103 def ==(other) return true if equal?(other) self.class == other.class && feature_type == other.feature_type end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/oci/ai_vision/models/image_feature.rb', line 133 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
113 114 115 |
# File 'lib/oci/ai_vision/models/image_feature.rb', line 113 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
122 123 124 |
# File 'lib/oci/ai_vision/models/image_feature.rb', line 122 def hash [feature_type].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
166 167 168 169 170 171 172 173 174 175 |
# File 'lib/oci/ai_vision/models/image_feature.rb', line 166 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
160 161 162 |
# File 'lib/oci/ai_vision/models/image_feature.rb', line 160 def to_s to_hash.to_s end |