Class: OCI::AiVision::Models::ImageJob

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/ai_vision/models/image_job.rb

Overview

Job details for a batch image analysis.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_SUCCEEDED = 'SUCCEEDED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_ACCEPTED = 'ACCEPTED'.freeze,
  LIFECYCLE_STATE_CANCELED = 'CANCELED'.freeze,
  LIFECYCLE_STATE_IN_PROGRESS = 'IN_PROGRESS'.freeze,
  LIFECYCLE_STATE_CANCELING = 'CANCELING'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_DETAILS_ENUM =
[
  LIFECYCLE_DETAILS_PARTIALLY_SUCCEEDED = 'PARTIALLY_SUCCEEDED'.freeze,
  LIFECYCLE_DETAILS_COMPLETELY_FAILED = 'COMPLETELY_FAILED'.freeze,
  LIFECYCLE_DETAILS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ImageJob

Initializes the object

Options Hash (attributes):



139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/oci/ai_vision/models/image_job.rb', line 139

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.features = attributes[:'features'] if attributes[:'features']

  self.input_location = attributes[:'inputLocation'] if attributes[:'inputLocation']

  raise 'You cannot provide both :inputLocation and :input_location' if attributes.key?(:'inputLocation') && attributes.key?(:'input_location')

  self.input_location = attributes[:'input_location'] if attributes[:'input_location']

  self.time_accepted = attributes[:'timeAccepted'] if attributes[:'timeAccepted']

  raise 'You cannot provide both :timeAccepted and :time_accepted' if attributes.key?(:'timeAccepted') && attributes.key?(:'time_accepted')

  self.time_accepted = attributes[:'time_accepted'] if attributes[:'time_accepted']

  self.time_started = attributes[:'timeStarted'] if attributes[:'timeStarted']

  raise 'You cannot provide both :timeStarted and :time_started' if attributes.key?(:'timeStarted') && attributes.key?(:'time_started')

  self.time_started = attributes[:'time_started'] if attributes[:'time_started']

  self.time_finished = attributes[:'timeFinished'] if attributes[:'timeFinished']

  raise 'You cannot provide both :timeFinished and :time_finished' if attributes.key?(:'timeFinished') && attributes.key?(:'time_finished')

  self.time_finished = attributes[:'time_finished'] if attributes[:'time_finished']

  self.percent_complete = attributes[:'percentComplete'] if attributes[:'percentComplete']

  raise 'You cannot provide both :percentComplete and :percent_complete' if attributes.key?(:'percentComplete') && attributes.key?(:'percent_complete')

  self.percent_complete = attributes[:'percent_complete'] if attributes[:'percent_complete']

  self.output_location = attributes[:'outputLocation'] if attributes[:'outputLocation']

  raise 'You cannot provide both :outputLocation and :output_location' if attributes.key?(:'outputLocation') && attributes.key?(:'output_location')

  self.output_location = attributes[:'output_location'] if attributes[:'output_location']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.is_zip_output_enabled = attributes[:'isZipOutputEnabled'] unless attributes[:'isZipOutputEnabled'].nil?
  self.is_zip_output_enabled = false if is_zip_output_enabled.nil? && !attributes.key?(:'isZipOutputEnabled') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isZipOutputEnabled and :is_zip_output_enabled' if attributes.key?(:'isZipOutputEnabled') && attributes.key?(:'is_zip_output_enabled')

  self.is_zip_output_enabled = attributes[:'is_zip_output_enabled'] unless attributes[:'is_zip_output_enabled'].nil?
  self.is_zip_output_enabled = false if is_zip_output_enabled.nil? && !attributes.key?(:'isZipOutputEnabled') && !attributes.key?(:'is_zip_output_enabled') # rubocop:disable Style/StringLiterals
end

Instance Attribute Details

#compartment_idString

[Required] The OCID of the compartment that starts the job.



33
34
35
# File 'lib/oci/ai_vision/models/image_job.rb', line 33

def compartment_id
  @compartment_id
end

#display_nameString

Image job display name.



37
38
39
# File 'lib/oci/ai_vision/models/image_job.rb', line 37

def display_name
  @display_name
end

#featuresArray<OCI::AiVision::Models::ImageFeature>

[Required] List of document analysis types requested.



41
42
43
# File 'lib/oci/ai_vision/models/image_job.rb', line 41

def features
  @features
end

#idString

[Required] Job id



29
30
31
# File 'lib/oci/ai_vision/models/image_job.rb', line 29

def id
  @id
end

#input_locationOCI::AiVision::Models::InputLocation



44
45
46
# File 'lib/oci/ai_vision/models/image_job.rb', line 44

def input_location
  @input_location
end

#is_zip_output_enabledBOOLEAN

Whether to generate a Zip file containing the results.



76
77
78
# File 'lib/oci/ai_vision/models/image_job.rb', line 76

def is_zip_output_enabled
  @is_zip_output_enabled
end

#lifecycle_detailsString

Detailed status of FAILED state.



72
73
74
# File 'lib/oci/ai_vision/models/image_job.rb', line 72

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

[Required] The current state of the batch image job.



68
69
70
# File 'lib/oci/ai_vision/models/image_job.rb', line 68

def lifecycle_state
  @lifecycle_state
end

#output_locationOCI::AiVision::Models::OutputLocation

This attribute is required.



64
65
66
# File 'lib/oci/ai_vision/models/image_job.rb', line 64

def output_location
  @output_location
end

#percent_completeFloat

How much progress the operation has made, vs the total amount of work that must be performed.



60
61
62
# File 'lib/oci/ai_vision/models/image_job.rb', line 60

def percent_complete
  @percent_complete
end

#time_acceptedDateTime

[Required] Job accepted time.



48
49
50
# File 'lib/oci/ai_vision/models/image_job.rb', line 48

def time_accepted
  @time_accepted
end

#time_finishedDateTime

Job finished time.



56
57
58
# File 'lib/oci/ai_vision/models/image_job.rb', line 56

def time_finished
  @time_finished
end

#time_startedDateTime

Job started time.



52
53
54
# File 'lib/oci/ai_vision/models/image_job.rb', line 52

def time_started
  @time_started
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/oci/ai_vision/models/image_job.rb', line 79

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'compartment_id': :'compartmentId',
    'display_name': :'displayName',
    'features': :'features',
    'input_location': :'inputLocation',
    'time_accepted': :'timeAccepted',
    'time_started': :'timeStarted',
    'time_finished': :'timeFinished',
    'percent_complete': :'percentComplete',
    'output_location': :'outputLocation',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'is_zip_output_enabled': :'isZipOutputEnabled'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/oci/ai_vision/models/image_job.rb', line 100

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'compartment_id': :'String',
    'display_name': :'String',
    'features': :'Array<OCI::AiVision::Models::ImageFeature>',
    'input_location': :'OCI::AiVision::Models::InputLocation',
    'time_accepted': :'DateTime',
    'time_started': :'DateTime',
    'time_finished': :'DateTime',
    'percent_complete': :'Float',
    'output_location': :'OCI::AiVision::Models::OutputLocation',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'is_zip_output_enabled': :'BOOLEAN'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.



251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'lib/oci/ai_vision/models/image_job.rb', line 251

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    display_name == other.display_name &&
    features == other.features &&
    input_location == other.input_location &&
    time_accepted == other.time_accepted &&
    time_started == other.time_started &&
    time_finished == other.time_finished &&
    percent_complete == other.percent_complete &&
    output_location == other.output_location &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    is_zip_output_enabled == other.is_zip_output_enabled
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
# File 'lib/oci/ai_vision/models/image_job.rb', line 293

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method


273
274
275
# File 'lib/oci/ai_vision/models/image_job.rb', line 273

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.



282
283
284
# File 'lib/oci/ai_vision/models/image_job.rb', line 282

def hash
  [id, compartment_id, display_name, features, input_location, time_accepted, time_started, time_finished, percent_complete, output_location, lifecycle_state, lifecycle_details, is_zip_output_enabled].hash
end

#to_hashHash

Returns the object in the form of hash



326
327
328
329
330
331
332
333
334
335
# File 'lib/oci/ai_vision/models/image_job.rb', line 326

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



320
321
322
# File 'lib/oci/ai_vision/models/image_job.rb', line 320

def to_s
  to_hash.to_s
end