Class: OCI::AiVision::Models::Model

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/ai_vision/models/model.rb

Overview

Machine-learned Model.

Constant Summary collapse

MODEL_TYPE_ENUM =
[
  MODEL_TYPE_IMAGE_CLASSIFICATION = 'IMAGE_CLASSIFICATION'.freeze,
  MODEL_TYPE_OBJECT_DETECTION = 'OBJECT_DETECTION'.freeze,
  MODEL_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Model

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/oci/ai_vision/models/model.rb', line 242

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.model_type = attributes[:'modelType'] if attributes[:'modelType']

  raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type')

  self.model_type = attributes[:'model_type'] if attributes[:'model_type']

  self.is_quick_mode = attributes[:'isQuickMode'] unless attributes[:'isQuickMode'].nil?
  self.is_quick_mode = false if is_quick_mode.nil? && !attributes.key?(:'isQuickMode') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isQuickMode and :is_quick_mode' if attributes.key?(:'isQuickMode') && attributes.key?(:'is_quick_mode')

  self.is_quick_mode = attributes[:'is_quick_mode'] unless attributes[:'is_quick_mode'].nil?
  self.is_quick_mode = false if is_quick_mode.nil? && !attributes.key?(:'isQuickMode') && !attributes.key?(:'is_quick_mode') # rubocop:disable Style/StringLiterals

  self.max_training_duration_in_hours = attributes[:'maxTrainingDurationInHours'] if attributes[:'maxTrainingDurationInHours']

  raise 'You cannot provide both :maxTrainingDurationInHours and :max_training_duration_in_hours' if attributes.key?(:'maxTrainingDurationInHours') && attributes.key?(:'max_training_duration_in_hours')

  self.max_training_duration_in_hours = attributes[:'max_training_duration_in_hours'] if attributes[:'max_training_duration_in_hours']

  self.trained_duration_in_hours = attributes[:'trainedDurationInHours'] if attributes[:'trainedDurationInHours']

  raise 'You cannot provide both :trainedDurationInHours and :trained_duration_in_hours' if attributes.key?(:'trainedDurationInHours') && attributes.key?(:'trained_duration_in_hours')

  self.trained_duration_in_hours = attributes[:'trained_duration_in_hours'] if attributes[:'trained_duration_in_hours']

  self.training_dataset = attributes[:'trainingDataset'] if attributes[:'trainingDataset']

  raise 'You cannot provide both :trainingDataset and :training_dataset' if attributes.key?(:'trainingDataset') && attributes.key?(:'training_dataset')

  self.training_dataset = attributes[:'training_dataset'] if attributes[:'training_dataset']

  self.testing_dataset = attributes[:'testingDataset'] if attributes[:'testingDataset']

  raise 'You cannot provide both :testingDataset and :testing_dataset' if attributes.key?(:'testingDataset') && attributes.key?(:'testing_dataset')

  self.testing_dataset = attributes[:'testing_dataset'] if attributes[:'testing_dataset']

  self.validation_dataset = attributes[:'validationDataset'] if attributes[:'validationDataset']

  raise 'You cannot provide both :validationDataset and :validation_dataset' if attributes.key?(:'validationDataset') && attributes.key?(:'validation_dataset')

  self.validation_dataset = attributes[:'validation_dataset'] if attributes[:'validation_dataset']

  self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion']

  raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version')

  self.model_version = attributes[:'model_version'] if attributes[:'model_version']

  self.project_id = attributes[:'projectId'] if attributes[:'projectId']

  raise 'You cannot provide both :projectId and :project_id' if attributes.key?(:'projectId') && attributes.key?(:'project_id')

  self.project_id = attributes[:'project_id'] if attributes[:'project_id']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.precision = attributes[:'precision'] if attributes[:'precision']

  self.recall = attributes[:'recall'] if attributes[:'recall']

  self.average_precision = attributes[:'averagePrecision'] if attributes[:'averagePrecision']

  raise 'You cannot provide both :averagePrecision and :average_precision' if attributes.key?(:'averagePrecision') && attributes.key?(:'average_precision')

  self.average_precision = attributes[:'average_precision'] if attributes[:'average_precision']

  self.confidence_threshold = attributes[:'confidenceThreshold'] if attributes[:'confidenceThreshold']

  raise 'You cannot provide both :confidenceThreshold and :confidence_threshold' if attributes.key?(:'confidenceThreshold') && attributes.key?(:'confidence_threshold')

  self.confidence_threshold = attributes[:'confidence_threshold'] if attributes[:'confidence_threshold']

  self.total_image_count = attributes[:'totalImageCount'] if attributes[:'totalImageCount']

  raise 'You cannot provide both :totalImageCount and :total_image_count' if attributes.key?(:'totalImageCount') && attributes.key?(:'total_image_count')

  self.total_image_count = attributes[:'total_image_count'] if attributes[:'total_image_count']

  self.test_image_count = attributes[:'testImageCount'] if attributes[:'testImageCount']

  raise 'You cannot provide both :testImageCount and :test_image_count' if attributes.key?(:'testImageCount') && attributes.key?(:'test_image_count')

  self.test_image_count = attributes[:'test_image_count'] if attributes[:'test_image_count']

  self.metrics = attributes[:'metrics'] if attributes[:'metrics']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

  raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

  self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']
end

Instance Attribute Details

#average_precisionFloat

Mean average precision of the trained model.

Returns:

  • (Float)


103
104
105
# File 'lib/oci/ai_vision/models/model.rb', line 103

def average_precision
  @average_precision
end

#compartment_idString

[Required] Compartment identifier.

Returns:

  • (String)


41
42
43
# File 'lib/oci/ai_vision/models/model.rb', line 41

def compartment_id
  @compartment_id
end

#confidence_thresholdFloat

Intersection over union threshold used for calculating precision and recall.

Returns:

  • (Float)


107
108
109
# File 'lib/oci/ai_vision/models/model.rb', line 107

def confidence_threshold
  @confidence_threshold
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


131
132
133
# File 'lib/oci/ai_vision/models/model.rb', line 131

def defined_tags
  @defined_tags
end

#descriptionString

Optional description of the model.

Returns:

  • (String)


37
38
39
# File 'lib/oci/ai_vision/models/model.rb', line 37

def description
  @description
end

#display_nameString

Human-friendly name for the model, which can be changed.

Returns:

  • (String)


33
34
35
# File 'lib/oci/ai_vision/models/model.rb', line 33

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`

Returns:

  • (Hash<String, String>)


125
126
127
# File 'lib/oci/ai_vision/models/model.rb', line 125

def freeform_tags
  @freeform_tags
end

#idString

[Required] Unique identifier that is immutable after creation.

Returns:

  • (String)


29
30
31
# File 'lib/oci/ai_vision/models/model.rb', line 29

def id
  @id
end

#is_quick_modeBOOLEAN

Set to true when experimenting with a new model type or dataset so model training is quick, with a predefined low number of passes through the training data.

Returns:

  • (BOOLEAN)


49
50
51
# File 'lib/oci/ai_vision/models/model.rb', line 49

def is_quick_mode
  @is_quick_mode
end

#lifecycle_detailsString

A message describing the current state in more detail which can provide actionable information if training failed.

Returns:

  • (String)


91
92
93
# File 'lib/oci/ai_vision/models/model.rb', line 91

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

[Required] Current state of the model.

Returns:

  • (String)


87
88
89
# File 'lib/oci/ai_vision/models/model.rb', line 87

def lifecycle_state
  @lifecycle_state
end

#max_training_duration_in_hoursFloat

Maximum model training duration in hours, expressed as a decimal fraction.

Returns:

  • (Float)


53
54
55
# File 'lib/oci/ai_vision/models/model.rb', line 53

def max_training_duration_in_hours
  @max_training_duration_in_hours
end

#metricsString

Complete set of per-label metrics for successfully trained model.

Returns:

  • (String)


119
120
121
# File 'lib/oci/ai_vision/models/model.rb', line 119

def metrics
  @metrics
end

#model_typeString

[Required] What type of Vision model this is.

Returns:

  • (String)


45
46
47
# File 'lib/oci/ai_vision/models/model.rb', line 45

def model_type
  @model_type
end

#model_versionString

[Required] The version of the model.

Returns:

  • (String)


71
72
73
# File 'lib/oci/ai_vision/models/model.rb', line 71

def model_version
  @model_version
end

#precisionFloat

Precision of the trained model.

Returns:

  • (Float)


95
96
97
# File 'lib/oci/ai_vision/models/model.rb', line 95

def precision
  @precision
end

#project_idString

[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the project which contains the model.

Returns:

  • (String)


75
76
77
# File 'lib/oci/ai_vision/models/model.rb', line 75

def project_id
  @project_id
end

#recallFloat

Recall of the trained model.

Returns:

  • (Float)


99
100
101
# File 'lib/oci/ai_vision/models/model.rb', line 99

def recall
  @recall
end

#system_tagsHash<String, Hash<String, Object>>

Usage of system tag keys. These predefined keys are scoped to namespaces. Example: ‘{"free-tier-retained": "true"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


137
138
139
# File 'lib/oci/ai_vision/models/model.rb', line 137

def system_tags
  @system_tags
end

#test_image_countInteger

Number of images set aside for evaluating model performance metrics after training.

Returns:

  • (Integer)


115
116
117
# File 'lib/oci/ai_vision/models/model.rb', line 115

def test_image_count
  @test_image_count
end

#testing_datasetOCI::AiVision::Models::Dataset



64
65
66
# File 'lib/oci/ai_vision/models/model.rb', line 64

def testing_dataset
  @testing_dataset
end

#time_createdDateTime

[Required] When the model was created, as an RFC3339 datetime string.

Returns:

  • (DateTime)


79
80
81
# File 'lib/oci/ai_vision/models/model.rb', line 79

def time_created
  @time_created
end

#time_updatedDateTime

When the model was updated, as an RFC3339 datetime string.

Returns:

  • (DateTime)


83
84
85
# File 'lib/oci/ai_vision/models/model.rb', line 83

def time_updated
  @time_updated
end

#total_image_countInteger

Number of images in the dataset used to train, validate, and test the model.

Returns:

  • (Integer)


111
112
113
# File 'lib/oci/ai_vision/models/model.rb', line 111

def total_image_count
  @total_image_count
end

#trained_duration_in_hoursFloat

Total hours actually used for model training.

Returns:

  • (Float)


57
58
59
# File 'lib/oci/ai_vision/models/model.rb', line 57

def trained_duration_in_hours
  @trained_duration_in_hours
end

#training_datasetOCI::AiVision::Models::Dataset

This attribute is required.



61
62
63
# File 'lib/oci/ai_vision/models/model.rb', line 61

def training_dataset
  @training_dataset
end

#validation_datasetOCI::AiVision::Models::Dataset



67
68
69
# File 'lib/oci/ai_vision/models/model.rb', line 67

def validation_dataset
  @validation_dataset
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/oci/ai_vision/models/model.rb', line 140

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'display_name': :'displayName',
    'description': :'description',
    'compartment_id': :'compartmentId',
    'model_type': :'modelType',
    'is_quick_mode': :'isQuickMode',
    'max_training_duration_in_hours': :'maxTrainingDurationInHours',
    'trained_duration_in_hours': :'trainedDurationInHours',
    'training_dataset': :'trainingDataset',
    'testing_dataset': :'testingDataset',
    'validation_dataset': :'validationDataset',
    'model_version': :'modelVersion',
    'project_id': :'projectId',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'precision': :'precision',
    'recall': :'recall',
    'average_precision': :'averagePrecision',
    'confidence_threshold': :'confidenceThreshold',
    'total_image_count': :'totalImageCount',
    'test_image_count': :'testImageCount',
    'metrics': :'metrics',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/oci/ai_vision/models/model.rb', line 175

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'display_name': :'String',
    'description': :'String',
    'compartment_id': :'String',
    'model_type': :'String',
    'is_quick_mode': :'BOOLEAN',
    'max_training_duration_in_hours': :'Float',
    'trained_duration_in_hours': :'Float',
    'training_dataset': :'OCI::AiVision::Models::Dataset',
    'testing_dataset': :'OCI::AiVision::Models::Dataset',
    'validation_dataset': :'OCI::AiVision::Models::Dataset',
    'model_version': :'String',
    'project_id': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'precision': :'Float',
    'recall': :'Float',
    'average_precision': :'Float',
    'confidence_threshold': :'Float',
    'total_image_count': :'Integer',
    'test_image_count': :'Integer',
    'metrics': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
# File 'lib/oci/ai_vision/models/model.rb', line 426

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    display_name == other.display_name &&
    description == other.description &&
    compartment_id == other.compartment_id &&
    model_type == other.model_type &&
    is_quick_mode == other.is_quick_mode &&
    max_training_duration_in_hours == other.max_training_duration_in_hours &&
    trained_duration_in_hours == other.trained_duration_in_hours &&
    training_dataset == other.training_dataset &&
    testing_dataset == other.testing_dataset &&
    validation_dataset == other.validation_dataset &&
    model_version == other.model_version &&
    project_id == other.project_id &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    precision == other.precision &&
    recall == other.recall &&
    average_precision == other.average_precision &&
    confidence_threshold == other.confidence_threshold &&
    total_image_count == other.total_image_count &&
    test_image_count == other.test_image_count &&
    metrics == other.metrics &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
# File 'lib/oci/ai_vision/models/model.rb', line 482

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


462
463
464
# File 'lib/oci/ai_vision/models/model.rb', line 462

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



471
472
473
# File 'lib/oci/ai_vision/models/model.rb', line 471

def hash
  [id, display_name, description, compartment_id, model_type, is_quick_mode, max_training_duration_in_hours, trained_duration_in_hours, training_dataset, testing_dataset, validation_dataset, model_version, project_id, time_created, time_updated, lifecycle_state, lifecycle_details, precision, recall, average_precision, confidence_threshold, total_image_count, test_image_count, metrics, freeform_tags, defined_tags, system_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



515
516
517
518
519
520
521
522
523
524
# File 'lib/oci/ai_vision/models/model.rb', line 515

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



509
510
511
# File 'lib/oci/ai_vision/models/model.rb', line 509

def to_s
  to_hash.to_s
end