Class: OCI::AiVision::Models::ModelSummary
- Inherits:
-
Object
- Object
- OCI::AiVision::Models::ModelSummary
- Defined in:
- lib/oci/ai_vision/models/model_summary.rb
Overview
Metadata about the model.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] Compartment identifier.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
Optional description of the model.
-
#display_name ⇒ String
Human-friendly name for the model, which can be changed.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
[Required] Unique identifier that is immutable after creation.
-
#lifecycle_details ⇒ String
A message describing the current state in more detail which can provide actionable information if training failed.
-
#lifecycle_state ⇒ String
[Required] The current state of the model.
-
#model_type ⇒ String
[Required] What type of Vision model this is.
-
#model_version ⇒ String
[Required] The version of the model.
-
#precision ⇒ Float
Precision of the trained model.
-
#project_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the project which contains the model.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys.
- #testing_dataset ⇒ OCI::AiVision::Models::Dataset
-
#time_created ⇒ DateTime
[Required] When the model was created, as an RFC3339 datetime string.
-
#time_updated ⇒ DateTime
When the model was modified, as an RFC3339 datetime string.
- #training_dataset ⇒ OCI::AiVision::Models::Dataset
- #validation_dataset ⇒ OCI::AiVision::Models::Dataset
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ModelSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ModelSummary
Initializes the object
162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 |
# File 'lib/oci/ai_vision/models/model_summary.rb', line 162 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.model_type = attributes[:'modelType'] if attributes[:'modelType'] raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type') self.model_type = attributes[:'model_type'] if attributes[:'model_type'] self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion'] raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version') self.model_version = attributes[:'model_version'] if attributes[:'model_version'] self.project_id = attributes[:'projectId'] if attributes[:'projectId'] raise 'You cannot provide both :projectId and :project_id' if attributes.key?(:'projectId') && attributes.key?(:'project_id') self.project_id = attributes[:'project_id'] if attributes[:'project_id'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.precision = attributes[:'precision'] if attributes[:'precision'] self.training_dataset = attributes[:'trainingDataset'] if attributes[:'trainingDataset'] raise 'You cannot provide both :trainingDataset and :training_dataset' if attributes.key?(:'trainingDataset') && attributes.key?(:'training_dataset') self.training_dataset = attributes[:'training_dataset'] if attributes[:'training_dataset'] self.testing_dataset = attributes[:'testingDataset'] if attributes[:'testingDataset'] raise 'You cannot provide both :testingDataset and :testing_dataset' if attributes.key?(:'testingDataset') && attributes.key?(:'testing_dataset') self.testing_dataset = attributes[:'testing_dataset'] if attributes[:'testing_dataset'] self.validation_dataset = attributes[:'validationDataset'] if attributes[:'validationDataset'] raise 'You cannot provide both :validationDataset and :validation_dataset' if attributes.key?(:'validationDataset') && attributes.key?(:'validation_dataset') self.validation_dataset = attributes[:'validation_dataset'] if attributes[:'validation_dataset'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] Compartment identifier.
25 26 27 |
# File 'lib/oci/ai_vision/models/model_summary.rb', line 25 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
78 79 80 |
# File 'lib/oci/ai_vision/models/model_summary.rb', line 78 def end |
#description ⇒ String
Optional description of the model.
21 22 23 |
# File 'lib/oci/ai_vision/models/model_summary.rb', line 21 def description @description end |
#display_name ⇒ String
Human-friendly name for the model, which can be changed.
17 18 19 |
# File 'lib/oci/ai_vision/models/model_summary.rb', line 17 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`
72 73 74 |
# File 'lib/oci/ai_vision/models/model_summary.rb', line 72 def end |
#id ⇒ String
[Required] Unique identifier that is immutable after creation.
13 14 15 |
# File 'lib/oci/ai_vision/models/model_summary.rb', line 13 def id @id end |
#lifecycle_details ⇒ String
A message describing the current state in more detail which can provide actionable information if training failed.
53 54 55 |
# File 'lib/oci/ai_vision/models/model_summary.rb', line 53 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
[Required] The current state of the model.
49 50 51 |
# File 'lib/oci/ai_vision/models/model_summary.rb', line 49 def lifecycle_state @lifecycle_state end |
#model_type ⇒ String
[Required] What type of Vision model this is.
29 30 31 |
# File 'lib/oci/ai_vision/models/model_summary.rb', line 29 def model_type @model_type end |
#model_version ⇒ String
[Required] The version of the model.
33 34 35 |
# File 'lib/oci/ai_vision/models/model_summary.rb', line 33 def model_version @model_version end |
#precision ⇒ Float
Precision of the trained model.
57 58 59 |
# File 'lib/oci/ai_vision/models/model_summary.rb', line 57 def precision @precision end |
#project_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the project which contains the model.
37 38 39 |
# File 'lib/oci/ai_vision/models/model_summary.rb', line 37 def project_id @project_id end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys. These predefined keys are scoped to namespaces. Example: ‘{"free-tier-retained": "true"}`
84 85 86 |
# File 'lib/oci/ai_vision/models/model_summary.rb', line 84 def end |
#testing_dataset ⇒ OCI::AiVision::Models::Dataset
63 64 65 |
# File 'lib/oci/ai_vision/models/model_summary.rb', line 63 def testing_dataset @testing_dataset end |
#time_created ⇒ DateTime
[Required] When the model was created, as an RFC3339 datetime string.
41 42 43 |
# File 'lib/oci/ai_vision/models/model_summary.rb', line 41 def time_created @time_created end |
#time_updated ⇒ DateTime
When the model was modified, as an RFC3339 datetime string.
45 46 47 |
# File 'lib/oci/ai_vision/models/model_summary.rb', line 45 def time_updated @time_updated end |
#training_dataset ⇒ OCI::AiVision::Models::Dataset
60 61 62 |
# File 'lib/oci/ai_vision/models/model_summary.rb', line 60 def training_dataset @training_dataset end |
#validation_dataset ⇒ OCI::AiVision::Models::Dataset
66 67 68 |
# File 'lib/oci/ai_vision/models/model_summary.rb', line 66 def validation_dataset @validation_dataset end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/oci/ai_vision/models/model_summary.rb', line 87 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'description': :'description', 'compartment_id': :'compartmentId', 'model_type': :'modelType', 'model_version': :'modelVersion', 'project_id': :'projectId', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'precision': :'precision', 'training_dataset': :'trainingDataset', 'testing_dataset': :'testingDataset', 'validation_dataset': :'validationDataset', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/oci/ai_vision/models/model_summary.rb', line 113 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'description': :'String', 'compartment_id': :'String', 'model_type': :'String', 'model_version': :'String', 'project_id': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'precision': :'Float', 'training_dataset': :'OCI::AiVision::Models::Dataset', 'testing_dataset': :'OCI::AiVision::Models::Dataset', 'validation_dataset': :'OCI::AiVision::Models::Dataset', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 |
# File 'lib/oci/ai_vision/models/model_summary.rb', line 272 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && description == other.description && compartment_id == other.compartment_id && model_type == other.model_type && model_version == other.model_version && project_id == other.project_id && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && precision == other.precision && training_dataset == other.training_dataset && testing_dataset == other.testing_dataset && validation_dataset == other.validation_dataset && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 |
# File 'lib/oci/ai_vision/models/model_summary.rb', line 319 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
299 300 301 |
# File 'lib/oci/ai_vision/models/model_summary.rb', line 299 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
308 309 310 |
# File 'lib/oci/ai_vision/models/model_summary.rb', line 308 def hash [id, display_name, description, compartment_id, model_type, model_version, project_id, time_created, time_updated, lifecycle_state, lifecycle_details, precision, training_dataset, testing_dataset, validation_dataset, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
352 353 354 355 356 357 358 359 360 361 |
# File 'lib/oci/ai_vision/models/model_summary.rb', line 352 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
346 347 348 |
# File 'lib/oci/ai_vision/models/model_summary.rb', line 346 def to_s to_hash.to_s end |