Class: OCI::Analytics::Models::CreateAnalyticsInstanceDetails
- Inherits:
-
Object
- Object
- OCI::Analytics::Models::CreateAnalyticsInstanceDetails
- Defined in:
- lib/oci/analytics/models/create_analytics_instance_details.rb
Overview
Input payload to create an Anaytics instance.
Constant Summary collapse
- FEATURE_SET_ENUM =
[ FEATURE_SET_SELF_SERVICE_ANALYTICS = 'SELF_SERVICE_ANALYTICS'.freeze, FEATURE_SET_ENTERPRISE_ANALYTICS = 'ENTERPRISE_ANALYTICS'.freeze ].freeze
- LICENSE_TYPE_ENUM =
[ LICENSE_TYPE_LICENSE_INCLUDED = 'LICENSE_INCLUDED'.freeze, LICENSE_TYPE_BRING_YOUR_OWN_LICENSE = 'BRING_YOUR_OWN_LICENSE'.freeze ].freeze
Instance Attribute Summary collapse
-
#capacity ⇒ OCI::Analytics::Models::Capacity
This attribute is required.
-
#compartment_id ⇒ String
**[Required]** The OCID of the compartment.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
Optional description.
-
#email_notification ⇒ String
Email address receiving notifications.
-
#feature_set ⇒ String
**[Required]** Analytics feature set.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#idcs_access_token ⇒ String
IDCS access token identifying a stripe and service administrator user.
-
#kms_key_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the OCI Vault Key encrypting the customer data stored in this Analytics instance.
-
#license_type ⇒ String
**[Required]** The license used for the service.
-
#name ⇒ String
**[Required]** The name of the Analytics instance.
- #network_endpoint_details ⇒ OCI::Analytics::Models::NetworkEndpointDetails
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateAnalyticsInstanceDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateAnalyticsInstanceDetails
Initializes the object
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/oci/analytics/models/create_analytics_instance_details.rb', line 142 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.feature_set = attributes[:'featureSet'] if attributes[:'featureSet'] raise 'You cannot provide both :featureSet and :feature_set' if attributes.key?(:'featureSet') && attributes.key?(:'feature_set') self.feature_set = attributes[:'feature_set'] if attributes[:'feature_set'] self.capacity = attributes[:'capacity'] if attributes[:'capacity'] self.license_type = attributes[:'licenseType'] if attributes[:'licenseType'] raise 'You cannot provide both :licenseType and :license_type' if attributes.key?(:'licenseType') && attributes.key?(:'license_type') self.license_type = attributes[:'license_type'] if attributes[:'license_type'] self.email_notification = attributes[:'emailNotification'] if attributes[:'emailNotification'] raise 'You cannot provide both :emailNotification and :email_notification' if attributes.key?(:'emailNotification') && attributes.key?(:'email_notification') self.email_notification = attributes[:'email_notification'] if attributes[:'email_notification'] self.network_endpoint_details = attributes[:'networkEndpointDetails'] if attributes[:'networkEndpointDetails'] raise 'You cannot provide both :networkEndpointDetails and :network_endpoint_details' if attributes.key?(:'networkEndpointDetails') && attributes.key?(:'network_endpoint_details') self.network_endpoint_details = attributes[:'network_endpoint_details'] if attributes[:'network_endpoint_details'] self.idcs_access_token = attributes[:'idcsAccessToken'] if attributes[:'idcsAccessToken'] raise 'You cannot provide both :idcsAccessToken and :idcs_access_token' if attributes.key?(:'idcsAccessToken') && attributes.key?(:'idcs_access_token') self.idcs_access_token = attributes[:'idcs_access_token'] if attributes[:'idcs_access_token'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.kms_key_id = attributes[:'kmsKeyId'] if attributes[:'kmsKeyId'] raise 'You cannot provide both :kmsKeyId and :kms_key_id' if attributes.key?(:'kmsKeyId') && attributes.key?(:'kms_key_id') self.kms_key_id = attributes[:'kms_key_id'] if attributes[:'kms_key_id'] end |
Instance Attribute Details
#capacity ⇒ OCI::Analytics::Models::Capacity
This attribute is required.
43 44 45 |
# File 'lib/oci/analytics/models/create_analytics_instance_details.rb', line 43 def capacity @capacity end |
#compartment_id ⇒ String
**[Required]** The OCID of the compartment.
34 35 36 |
# File 'lib/oci/analytics/models/create_analytics_instance_details.rb', line 34 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: `{"CostCenter": "42"}`
69 70 71 |
# File 'lib/oci/analytics/models/create_analytics_instance_details.rb', line 69 def @defined_tags end |
#description ⇒ String
Optional description.
29 30 31 |
# File 'lib/oci/analytics/models/create_analytics_instance_details.rb', line 29 def description @description end |
#email_notification ⇒ String
Email address receiving notifications.
53 54 55 |
# File 'lib/oci/analytics/models/create_analytics_instance_details.rb', line 53 def email_notification @email_notification end |
#feature_set ⇒ String
**[Required]** Analytics feature set.
39 40 41 |
# File 'lib/oci/analytics/models/create_analytics_instance_details.rb', line 39 def feature_set @feature_set end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: `"Finance"`
77 78 79 |
# File 'lib/oci/analytics/models/create_analytics_instance_details.rb', line 77 def @freeform_tags end |
#idcs_access_token ⇒ String
IDCS access token identifying a stripe and service administrator user.
61 62 63 |
# File 'lib/oci/analytics/models/create_analytics_instance_details.rb', line 61 def idcs_access_token @idcs_access_token end |
#kms_key_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the OCI Vault Key encrypting the customer data stored in this Analytics instance. A null value indicates Oracle managed default encryption.
82 83 84 |
# File 'lib/oci/analytics/models/create_analytics_instance_details.rb', line 82 def kms_key_id @kms_key_id end |
#license_type ⇒ String
**[Required]** The license used for the service.
48 49 50 |
# File 'lib/oci/analytics/models/create_analytics_instance_details.rb', line 48 def license_type @license_type end |
#name ⇒ String
**[Required]** The name of the Analytics instance. This name must be unique in the tenancy and cannot be changed.
24 25 26 |
# File 'lib/oci/analytics/models/create_analytics_instance_details.rb', line 24 def name @name end |
#network_endpoint_details ⇒ OCI::Analytics::Models::NetworkEndpointDetails
56 57 58 |
# File 'lib/oci/analytics/models/create_analytics_instance_details.rb', line 56 def network_endpoint_details @network_endpoint_details end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/oci/analytics/models/create_analytics_instance_details.rb', line 85 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'description': :'description', 'compartment_id': :'compartmentId', 'feature_set': :'featureSet', 'capacity': :'capacity', 'license_type': :'licenseType', 'email_notification': :'emailNotification', 'network_endpoint_details': :'networkEndpointDetails', 'idcs_access_token': :'idcsAccessToken', 'defined_tags': :'definedTags', 'freeform_tags': :'freeformTags', 'kms_key_id': :'kmsKeyId' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/oci/analytics/models/create_analytics_instance_details.rb', line 105 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'description': :'String', 'compartment_id': :'String', 'feature_set': :'String', 'capacity': :'OCI::Analytics::Models::Capacity', 'license_type': :'String', 'email_notification': :'String', 'network_endpoint_details': :'OCI::Analytics::Models::NetworkEndpointDetails', 'idcs_access_token': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'freeform_tags': :'Hash<String, String>', 'kms_key_id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/oci/analytics/models/create_analytics_instance_details.rb', line 232 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && description == other.description && compartment_id == other.compartment_id && feature_set == other.feature_set && capacity == other.capacity && license_type == other.license_type && email_notification == other.email_notification && network_endpoint_details == other.network_endpoint_details && idcs_access_token == other.idcs_access_token && == other. && == other. && kms_key_id == other.kms_key_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/oci/analytics/models/create_analytics_instance_details.rb', line 273 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
253 254 255 |
# File 'lib/oci/analytics/models/create_analytics_instance_details.rb', line 253 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
262 263 264 |
# File 'lib/oci/analytics/models/create_analytics_instance_details.rb', line 262 def hash [name, description, compartment_id, feature_set, capacity, license_type, email_notification, network_endpoint_details, idcs_access_token, , , kms_key_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
306 307 308 309 310 311 312 313 314 315 |
# File 'lib/oci/analytics/models/create_analytics_instance_details.rb', line 306 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
300 301 302 |
# File 'lib/oci/analytics/models/create_analytics_instance_details.rb', line 300 def to_s to_hash.to_s end |