Class: OCI::Analytics::Models::CreateVanityUrlDetails
- Inherits:
-
Object
- Object
- OCI::Analytics::Models::CreateVanityUrlDetails
- Defined in:
- lib/oci/analytics/models/create_vanity_url_details.rb
Overview
Input payload to create a vanity url.
Instance Attribute Summary collapse
-
#ca_certificate ⇒ String
[Required] PEM CA certificate(s) for HTTPS connections.
-
#description ⇒ String
Optional description.
-
#hosts ⇒ Array<String>
[Required] List of fully qualified hostnames supported by this vanity URL definition (max of 3).
-
#passphrase ⇒ String
Passphrase for the PEM Private key (if any).
-
#private_key ⇒ String
[Required] PEM Private key for HTTPS connections.
-
#public_certificate ⇒ String
[Required] PEM certificate for HTTPS connections.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateVanityUrlDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateVanityUrlDetails
Initializes the object
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/oci/analytics/models/create_vanity_url_details.rb', line 81 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.description = attributes[:'description'] if attributes[:'description'] self.hosts = attributes[:'hosts'] if attributes[:'hosts'] self.passphrase = attributes[:'passphrase'] if attributes[:'passphrase'] self.private_key = attributes[:'privateKey'] if attributes[:'privateKey'] raise 'You cannot provide both :privateKey and :private_key' if attributes.key?(:'privateKey') && attributes.key?(:'private_key') self.private_key = attributes[:'private_key'] if attributes[:'private_key'] self.public_certificate = attributes[:'publicCertificate'] if attributes[:'publicCertificate'] raise 'You cannot provide both :publicCertificate and :public_certificate' if attributes.key?(:'publicCertificate') && attributes.key?(:'public_certificate') self.public_certificate = attributes[:'public_certificate'] if attributes[:'public_certificate'] self.ca_certificate = attributes[:'caCertificate'] if attributes[:'caCertificate'] raise 'You cannot provide both :caCertificate and :ca_certificate' if attributes.key?(:'caCertificate') && attributes.key?(:'ca_certificate') self.ca_certificate = attributes[:'ca_certificate'] if attributes[:'ca_certificate'] end |
Instance Attribute Details
#ca_certificate ⇒ String
[Required] PEM CA certificate(s) for HTTPS connections. This may include multiple PEM certificates.
39 40 41 |
# File 'lib/oci/analytics/models/create_vanity_url_details.rb', line 39 def ca_certificate @ca_certificate end |
#description ⇒ String
Optional description.
14 15 16 |
# File 'lib/oci/analytics/models/create_vanity_url_details.rb', line 14 def description @description end |
#hosts ⇒ Array<String>
[Required] List of fully qualified hostnames supported by this vanity URL definition (max of 3).
19 20 21 |
# File 'lib/oci/analytics/models/create_vanity_url_details.rb', line 19 def hosts @hosts end |
#passphrase ⇒ String
Passphrase for the PEM Private key (if any).
24 25 26 |
# File 'lib/oci/analytics/models/create_vanity_url_details.rb', line 24 def passphrase @passphrase end |
#private_key ⇒ String
[Required] PEM Private key for HTTPS connections.
29 30 31 |
# File 'lib/oci/analytics/models/create_vanity_url_details.rb', line 29 def private_key @private_key end |
#public_certificate ⇒ String
[Required] PEM certificate for HTTPS connections.
34 35 36 |
# File 'lib/oci/analytics/models/create_vanity_url_details.rb', line 34 def public_certificate @public_certificate end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/oci/analytics/models/create_vanity_url_details.rb', line 42 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'description': :'description', 'hosts': :'hosts', 'passphrase': :'passphrase', 'private_key': :'privateKey', 'public_certificate': :'publicCertificate', 'ca_certificate': :'caCertificate' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/oci/analytics/models/create_vanity_url_details.rb', line 56 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'description': :'String', 'hosts': :'Array<String>', 'passphrase': :'String', 'private_key': :'String', 'public_certificate': :'String', 'ca_certificate': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/oci/analytics/models/create_vanity_url_details.rb', line 119 def ==(other) return true if equal?(other) self.class == other.class && description == other.description && hosts == other.hosts && passphrase == other.passphrase && private_key == other.private_key && public_certificate == other.public_certificate && ca_certificate == other.ca_certificate end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/oci/analytics/models/create_vanity_url_details.rb', line 154 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
134 135 136 |
# File 'lib/oci/analytics/models/create_vanity_url_details.rb', line 134 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
143 144 145 |
# File 'lib/oci/analytics/models/create_vanity_url_details.rb', line 143 def hash [description, hosts, passphrase, private_key, public_certificate, ca_certificate].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
187 188 189 190 191 192 193 194 195 196 |
# File 'lib/oci/analytics/models/create_vanity_url_details.rb', line 187 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
181 182 183 |
# File 'lib/oci/analytics/models/create_vanity_url_details.rb', line 181 def to_s to_hash.to_s end |