Class: OCI::Analytics::Models::PrivateAccessChannel

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/analytics/models/private_access_channel.rb

Overview

Analytics Instance Private Access Channel model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PrivateAccessChannel

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/oci/analytics/models/private_access_channel.rb', line 92

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.key = attributes[:'key'] if attributes[:'key']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.vcn_id = attributes[:'vcnId'] if attributes[:'vcnId']

  raise 'You cannot provide both :vcnId and :vcn_id' if attributes.key?(:'vcnId') && attributes.key?(:'vcn_id')

  self.vcn_id = attributes[:'vcn_id'] if attributes[:'vcn_id']

  self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId']

  raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id')

  self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id']

  self.ip_address = attributes[:'ipAddress'] if attributes[:'ipAddress']

  raise 'You cannot provide both :ipAddress and :ip_address' if attributes.key?(:'ipAddress') && attributes.key?(:'ip_address')

  self.ip_address = attributes[:'ip_address'] if attributes[:'ip_address']

  self.egress_source_ip_addresses = attributes[:'egressSourceIpAddresses'] if attributes[:'egressSourceIpAddresses']

  raise 'You cannot provide both :egressSourceIpAddresses and :egress_source_ip_addresses' if attributes.key?(:'egressSourceIpAddresses') && attributes.key?(:'egress_source_ip_addresses')

  self.egress_source_ip_addresses = attributes[:'egress_source_ip_addresses'] if attributes[:'egress_source_ip_addresses']

  self.private_source_dns_zones = attributes[:'privateSourceDnsZones'] if attributes[:'privateSourceDnsZones']

  raise 'You cannot provide both :privateSourceDnsZones and :private_source_dns_zones' if attributes.key?(:'privateSourceDnsZones') && attributes.key?(:'private_source_dns_zones')

  self.private_source_dns_zones = attributes[:'private_source_dns_zones'] if attributes[:'private_source_dns_zones']
end

Instance Attribute Details

#display_nameString

[Required] Display Name of the Private Access Channel.

Returns:

  • (String)


19
20
21
# File 'lib/oci/analytics/models/private_access_channel.rb', line 19

def display_name
  @display_name
end

#egress_source_ip_addressesArray<String>

[Required] The list of IP addresses from the customer subnet connected to private access channel, used as a source Ip by Private Access Channel for network traffic from the AnalyticsInstance to Private Sources.

Returns:

  • (Array<String>)


40
41
42
# File 'lib/oci/analytics/models/private_access_channel.rb', line 40

def egress_source_ip_addresses
  @egress_source_ip_addresses
end

#ip_addressString

[Required] IP Address of the Private Access channel.

Returns:

  • (String)


34
35
36
# File 'lib/oci/analytics/models/private_access_channel.rb', line 34

def ip_address
  @ip_address
end

#keyString

[Required] Private Access Channel unique identifier key.

Returns:

  • (String)


14
15
16
# File 'lib/oci/analytics/models/private_access_channel.rb', line 14

def key
  @key
end

#private_source_dns_zonesArray<OCI::Analytics::Models::PrivateSourceDnsZone>

List of Private Source DNS zones registered with Private Access Channel, where datasource hostnames from these dns zones / domains will be resolved in the peered VCN for access from Analytics Instance. Min of 1 is required and Max of 30 Private Source DNS zones can be registered.



47
48
49
# File 'lib/oci/analytics/models/private_access_channel.rb', line 47

def private_source_dns_zones
  @private_source_dns_zones
end

#subnet_idString

[Required] OCID of the customer subnet connected to private access channel.

Returns:

  • (String)


29
30
31
# File 'lib/oci/analytics/models/private_access_channel.rb', line 29

def subnet_id
  @subnet_id
end

#vcn_idString

[Required] OCID of the customer VCN peered with private access channel.

Returns:

  • (String)


24
25
26
# File 'lib/oci/analytics/models/private_access_channel.rb', line 24

def vcn_id
  @vcn_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/oci/analytics/models/private_access_channel.rb', line 50

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'key',
    'display_name': :'displayName',
    'vcn_id': :'vcnId',
    'subnet_id': :'subnetId',
    'ip_address': :'ipAddress',
    'egress_source_ip_addresses': :'egressSourceIpAddresses',
    'private_source_dns_zones': :'privateSourceDnsZones'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/oci/analytics/models/private_access_channel.rb', line 65

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'String',
    'display_name': :'String',
    'vcn_id': :'String',
    'subnet_id': :'String',
    'ip_address': :'String',
    'egress_source_ip_addresses': :'Array<String>',
    'private_source_dns_zones': :'Array<OCI::Analytics::Models::PrivateSourceDnsZone>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/oci/analytics/models/private_access_channel.rb', line 144

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    key == other.key &&
    display_name == other.display_name &&
    vcn_id == other.vcn_id &&
    subnet_id == other.subnet_id &&
    ip_address == other.ip_address &&
    egress_source_ip_addresses == other.egress_source_ip_addresses &&
    private_source_dns_zones == other.private_source_dns_zones
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/oci/analytics/models/private_access_channel.rb', line 180

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


160
161
162
# File 'lib/oci/analytics/models/private_access_channel.rb', line 160

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



169
170
171
# File 'lib/oci/analytics/models/private_access_channel.rb', line 169

def hash
  [key, display_name, vcn_id, subnet_id, ip_address, egress_source_ip_addresses, private_source_dns_zones].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



213
214
215
216
217
218
219
220
221
222
# File 'lib/oci/analytics/models/private_access_channel.rb', line 213

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



207
208
209
# File 'lib/oci/analytics/models/private_access_channel.rb', line 207

def to_s
  to_hash.to_s
end