Class: OCI::Analytics::Models::PrivateEndpointDetails
- Inherits:
-
NetworkEndpointDetails
- Object
- NetworkEndpointDetails
- OCI::Analytics::Models::PrivateEndpointDetails
- Defined in:
- lib/oci/analytics/models/private_endpoint_details.rb
Overview
Private endpoint configuration details.
Constant Summary
Constants inherited from NetworkEndpointDetails
NetworkEndpointDetails::NETWORK_ENDPOINT_TYPE_ENUM
Instance Attribute Summary collapse
-
#subnet_id ⇒ String
**[Required]** The subnet OCID for the private endpoint.
-
#vcn_id ⇒ String
**[Required]** The VCN OCID for the private endpoint.
Attributes inherited from NetworkEndpointDetails
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PrivateEndpointDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from NetworkEndpointDetails
Constructor Details
#initialize(attributes = {}) ⇒ PrivateEndpointDetails
Initializes the object
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/oci/analytics/models/private_endpoint_details.rb', line 52 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['networkEndpointType'] = 'PRIVATE' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.vcn_id = attributes[:'vcnId'] if attributes[:'vcnId'] raise 'You cannot provide both :vcnId and :vcn_id' if attributes.key?(:'vcnId') && attributes.key?(:'vcn_id') self.vcn_id = attributes[:'vcn_id'] if attributes[:'vcn_id'] self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId'] raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id') self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id'] end |
Instance Attribute Details
#subnet_id ⇒ String
**[Required]** The subnet OCID for the private endpoint.
20 21 22 |
# File 'lib/oci/analytics/models/private_endpoint_details.rb', line 20 def subnet_id @subnet_id end |
#vcn_id ⇒ String
**[Required]** The VCN OCID for the private endpoint.
15 16 17 |
# File 'lib/oci/analytics/models/private_endpoint_details.rb', line 15 def vcn_id @vcn_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
23 24 25 26 27 28 29 30 31 |
# File 'lib/oci/analytics/models/private_endpoint_details.rb', line 23 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'network_endpoint_type': :'networkEndpointType', 'vcn_id': :'vcnId', 'subnet_id': :'subnetId' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
34 35 36 37 38 39 40 41 42 |
# File 'lib/oci/analytics/models/private_endpoint_details.rb', line 34 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'network_endpoint_type': :'String', 'vcn_id': :'String', 'subnet_id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
82 83 84 85 86 87 88 89 |
# File 'lib/oci/analytics/models/private_endpoint_details.rb', line 82 def ==(other) return true if equal?(other) self.class == other.class && network_endpoint_type == other.network_endpoint_type && vcn_id == other.vcn_id && subnet_id == other.subnet_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/oci/analytics/models/private_endpoint_details.rb', line 114 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
94 95 96 |
# File 'lib/oci/analytics/models/private_endpoint_details.rb', line 94 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
103 104 105 |
# File 'lib/oci/analytics/models/private_endpoint_details.rb', line 103 def hash [network_endpoint_type, vcn_id, subnet_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
147 148 149 150 151 152 153 154 155 156 |
# File 'lib/oci/analytics/models/private_endpoint_details.rb', line 147 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
141 142 143 |
# File 'lib/oci/analytics/models/private_endpoint_details.rb', line 141 def to_s to_hash.to_s end |