Class: OCI::Analytics::Models::PublicEndpointDetails
- Inherits:
-
NetworkEndpointDetails
- Object
- NetworkEndpointDetails
- OCI::Analytics::Models::PublicEndpointDetails
- Defined in:
- lib/oci/analytics/models/public_endpoint_details.rb
Overview
Public endpoint configuration details.
Constant Summary
Constants inherited from NetworkEndpointDetails
NetworkEndpointDetails::NETWORK_ENDPOINT_TYPE_ENUM
Instance Attribute Summary collapse
-
#whitelisted_ips ⇒ Array<String>
Source IP addresses or IP address ranges igress rules.
-
#whitelisted_vcns ⇒ Array<OCI::Analytics::Models::VirtualCloudNetwork>
Virtual Cloud Networks allowed to access this network endpoint.
Attributes inherited from NetworkEndpointDetails
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PublicEndpointDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from NetworkEndpointDetails
Constructor Details
#initialize(attributes = {}) ⇒ PublicEndpointDetails
Initializes the object
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/oci/analytics/models/public_endpoint_details.rb', line 52 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['networkEndpointType'] = 'PUBLIC' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.whitelisted_ips = attributes[:'whitelistedIps'] if attributes[:'whitelistedIps'] raise 'You cannot provide both :whitelistedIps and :whitelisted_ips' if attributes.key?(:'whitelistedIps') && attributes.key?(:'whitelisted_ips') self.whitelisted_ips = attributes[:'whitelisted_ips'] if attributes[:'whitelisted_ips'] self.whitelisted_vcns = attributes[:'whitelistedVcns'] if attributes[:'whitelistedVcns'] raise 'You cannot provide both :whitelistedVcns and :whitelisted_vcns' if attributes.key?(:'whitelistedVcns') && attributes.key?(:'whitelisted_vcns') self.whitelisted_vcns = attributes[:'whitelisted_vcns'] if attributes[:'whitelisted_vcns'] end |
Instance Attribute Details
#whitelisted_ips ⇒ Array<String>
Source IP addresses or IP address ranges igress rules.
15 16 17 |
# File 'lib/oci/analytics/models/public_endpoint_details.rb', line 15 def whitelisted_ips @whitelisted_ips end |
#whitelisted_vcns ⇒ Array<OCI::Analytics::Models::VirtualCloudNetwork>
Virtual Cloud Networks allowed to access this network endpoint.
20 21 22 |
# File 'lib/oci/analytics/models/public_endpoint_details.rb', line 20 def whitelisted_vcns @whitelisted_vcns end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
23 24 25 26 27 28 29 30 31 |
# File 'lib/oci/analytics/models/public_endpoint_details.rb', line 23 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'network_endpoint_type': :'networkEndpointType', 'whitelisted_ips': :'whitelistedIps', 'whitelisted_vcns': :'whitelistedVcns' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
34 35 36 37 38 39 40 41 42 |
# File 'lib/oci/analytics/models/public_endpoint_details.rb', line 34 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'network_endpoint_type': :'String', 'whitelisted_ips': :'Array<String>', 'whitelisted_vcns': :'Array<OCI::Analytics::Models::VirtualCloudNetwork>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
82 83 84 85 86 87 88 89 |
# File 'lib/oci/analytics/models/public_endpoint_details.rb', line 82 def ==(other) return true if equal?(other) self.class == other.class && network_endpoint_type == other.network_endpoint_type && whitelisted_ips == other.whitelisted_ips && whitelisted_vcns == other.whitelisted_vcns end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/oci/analytics/models/public_endpoint_details.rb', line 114 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
94 95 96 |
# File 'lib/oci/analytics/models/public_endpoint_details.rb', line 94 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
103 104 105 |
# File 'lib/oci/analytics/models/public_endpoint_details.rb', line 103 def hash [network_endpoint_type, whitelisted_ips, whitelisted_vcns].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
147 148 149 150 151 152 153 154 155 156 |
# File 'lib/oci/analytics/models/public_endpoint_details.rb', line 147 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
141 142 143 |
# File 'lib/oci/analytics/models/public_endpoint_details.rb', line 141 def to_s to_hash.to_s end |