Class: OCI::Analytics::Models::VanityUrlDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/analytics/models/vanity_url_details.rb

Overview

Vanity url configuration details.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ VanityUrlDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :key (String)

    The value to assign to the #key property

  • :description (String)

    The value to assign to the #description property

  • :urls (Array<String>)

    The value to assign to the #urls property

  • :hosts (Array<String>)

    The value to assign to the #hosts property

  • :public_certificate (String)

    The value to assign to the #public_certificate property



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/oci/analytics/models/vanity_url_details.rb', line 73

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.key = attributes[:'key'] if attributes[:'key']

  self.description = attributes[:'description'] if attributes[:'description']

  self.urls = attributes[:'urls'] if attributes[:'urls']

  self.hosts = attributes[:'hosts'] if attributes[:'hosts']

  self.public_certificate = attributes[:'publicCertificate'] if attributes[:'publicCertificate']

  raise 'You cannot provide both :publicCertificate and :public_certificate' if attributes.key?(:'publicCertificate') && attributes.key?(:'public_certificate')

  self.public_certificate = attributes[:'public_certificate'] if attributes[:'public_certificate']
end

Instance Attribute Details

#descriptionString

Description of the vanity url.

Returns:

  • (String)


19
20
21
# File 'lib/oci/analytics/models/vanity_url_details.rb', line 19

def description
  @description
end

#hostsArray<String>

List of fully qualified hostnames supported by this vanity URL definition (max of 3).

Returns:

  • (Array<String>)


29
30
31
# File 'lib/oci/analytics/models/vanity_url_details.rb', line 29

def hosts
  @hosts
end

#keyString

The vanity url unique identifier key.

Returns:

  • (String)


14
15
16
# File 'lib/oci/analytics/models/vanity_url_details.rb', line 14

def key
  @key
end

#public_certificateString

PEM certificate for HTTPS connections.

Returns:

  • (String)


34
35
36
# File 'lib/oci/analytics/models/vanity_url_details.rb', line 34

def public_certificate
  @public_certificate
end

#urlsArray<String>

List of urls supported by this vanity URL definition (max of 3).

Returns:

  • (Array<String>)


24
25
26
# File 'lib/oci/analytics/models/vanity_url_details.rb', line 24

def urls
  @urls
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
47
# File 'lib/oci/analytics/models/vanity_url_details.rb', line 37

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'key',
    'description': :'description',
    'urls': :'urls',
    'hosts': :'hosts',
    'public_certificate': :'publicCertificate'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



50
51
52
53
54
55
56
57
58
59
60
# File 'lib/oci/analytics/models/vanity_url_details.rb', line 50

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'String',
    'description': :'String',
    'urls': :'Array<String>',
    'hosts': :'Array<String>',
    'public_certificate': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



101
102
103
104
105
106
107
108
109
110
# File 'lib/oci/analytics/models/vanity_url_details.rb', line 101

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    key == other.key &&
    description == other.description &&
    urls == other.urls &&
    hosts == other.hosts &&
    public_certificate == other.public_certificate
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/oci/analytics/models/vanity_url_details.rb', line 135

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


115
116
117
# File 'lib/oci/analytics/models/vanity_url_details.rb', line 115

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



124
125
126
# File 'lib/oci/analytics/models/vanity_url_details.rb', line 124

def hash
  [key, description, urls, hosts, public_certificate].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



168
169
170
171
172
173
174
175
176
177
# File 'lib/oci/analytics/models/vanity_url_details.rb', line 168

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



162
163
164
# File 'lib/oci/analytics/models/vanity_url_details.rb', line 162

def to_s
  to_hash.to_s
end