Class: OCI::Analytics::Models::WorkRequest
- Inherits:
-
Object
- Object
- OCI::Analytics::Models::WorkRequest
- Defined in:
- lib/oci/analytics/models/work_request.rb
Overview
An asynchronous work request.
Constant Summary collapse
- OPERATION_TYPE_ENUM =
[ OPERATION_TYPE_CREATE_ANALYTICS_INSTANCE = 'CREATE_ANALYTICS_INSTANCE'.freeze, OPERATION_TYPE_DELETE_ANALYTICS_INSTANCE = 'DELETE_ANALYTICS_INSTANCE'.freeze, OPERATION_TYPE_START_ANALYTICS_INSTANCE = 'START_ANALYTICS_INSTANCE'.freeze, OPERATION_TYPE_STOP_ANALYTICS_INSTANCE = 'STOP_ANALYTICS_INSTANCE'.freeze, OPERATION_TYPE_SCALE_ANALYTICS_INSTANCE = 'SCALE_ANALYTICS_INSTANCE'.freeze, OPERATION_TYPE_CHANGE_ANALYTICS_INSTANCE_COMPARTMENT = 'CHANGE_ANALYTICS_INSTANCE_COMPARTMENT'.freeze, OPERATION_TYPE_CHANGE_ANALYTICS_INSTANCE_NETWORK_ENDPOINT = 'CHANGE_ANALYTICS_INSTANCE_NETWORK_ENDPOINT'.freeze, OPERATION_TYPE_CREATE_VANITY_URL = 'CREATE_VANITY_URL'.freeze, OPERATION_TYPE_UPDATE_VANITY_URL = 'UPDATE_VANITY_URL'.freeze, OPERATION_TYPE_DELETE_VANITY_URL = 'DELETE_VANITY_URL'.freeze, OPERATION_TYPE_CREATE_PRIVATE_ACCESS_CHANNEL = 'CREATE_PRIVATE_ACCESS_CHANNEL'.freeze, OPERATION_TYPE_UPDATE_PRIVATE_ACCESS_CHANNEL = 'UPDATE_PRIVATE_ACCESS_CHANNEL'.freeze, OPERATION_TYPE_DELETE_PRIVATE_ACCESS_CHANNEL = 'DELETE_PRIVATE_ACCESS_CHANNEL'.freeze, OPERATION_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- STATUS_ENUM =
[ STATUS_ACCEPTED = 'ACCEPTED'.freeze, STATUS_IN_PROGRESS = 'IN_PROGRESS'.freeze, STATUS_FAILED = 'FAILED'.freeze, STATUS_SUCCEEDED = 'SUCCEEDED'.freeze, STATUS_CANCELING = 'CANCELING'.freeze, STATUS_CANCELED = 'CANCELED'.freeze, STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The compartment OCID of this work request.
-
#id ⇒ String
[Required] The resource OCID.
-
#operation_type ⇒ String
[Required] The operation performed by the work request.
-
#percent_complete ⇒ Float
[Required] Percentage of the request completed.
-
#resources ⇒ Array<OCI::Analytics::Models::WorkRequestResource>
[Required] The resources this work request affects.
-
#status ⇒ String
[Required] The current status of the work request.
-
#time_accepted ⇒ DateTime
[Required] The time the work request was accepted, in the format defined by RFC3339.
-
#time_finished ⇒ DateTime
The time the work request was finished, in the format defined by RFC3339.
-
#time_started ⇒ DateTime
The time the work request was started, in the format defined by RFC3339.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WorkRequest
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ WorkRequest
Initializes the object
139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/oci/analytics/models/work_request.rb', line 139 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.operation_type = attributes[:'operationType'] if attributes[:'operationType'] raise 'You cannot provide both :operationType and :operation_type' if attributes.key?(:'operationType') && attributes.key?(:'operation_type') self.operation_type = attributes[:'operation_type'] if attributes[:'operation_type'] self.status = attributes[:'status'] if attributes[:'status'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.resources = attributes[:'resources'] if attributes[:'resources'] self.percent_complete = attributes[:'percentComplete'] if attributes[:'percentComplete'] raise 'You cannot provide both :percentComplete and :percent_complete' if attributes.key?(:'percentComplete') && attributes.key?(:'percent_complete') self.percent_complete = attributes[:'percent_complete'] if attributes[:'percent_complete'] self.time_accepted = attributes[:'timeAccepted'] if attributes[:'timeAccepted'] raise 'You cannot provide both :timeAccepted and :time_accepted' if attributes.key?(:'timeAccepted') && attributes.key?(:'time_accepted') self.time_accepted = attributes[:'time_accepted'] if attributes[:'time_accepted'] self.time_started = attributes[:'timeStarted'] if attributes[:'timeStarted'] raise 'You cannot provide both :timeStarted and :time_started' if attributes.key?(:'timeStarted') && attributes.key?(:'time_started') self.time_started = attributes[:'time_started'] if attributes[:'time_started'] self.time_finished = attributes[:'timeFinished'] if attributes[:'timeFinished'] raise 'You cannot provide both :timeFinished and :time_finished' if attributes.key?(:'timeFinished') && attributes.key?(:'time_finished') self.time_finished = attributes[:'time_finished'] if attributes[:'time_finished'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The compartment OCID of this work request.
57 58 59 |
# File 'lib/oci/analytics/models/work_request.rb', line 57 def compartment_id @compartment_id end |
#id ⇒ String
[Required] The resource OCID.
42 43 44 |
# File 'lib/oci/analytics/models/work_request.rb', line 42 def id @id end |
#operation_type ⇒ String
[Required] The operation performed by the work request.
47 48 49 |
# File 'lib/oci/analytics/models/work_request.rb', line 47 def operation_type @operation_type end |
#percent_complete ⇒ Float
[Required] Percentage of the request completed.
67 68 69 |
# File 'lib/oci/analytics/models/work_request.rb', line 67 def percent_complete @percent_complete end |
#resources ⇒ Array<OCI::Analytics::Models::WorkRequestResource>
[Required] The resources this work request affects.
62 63 64 |
# File 'lib/oci/analytics/models/work_request.rb', line 62 def resources @resources end |
#status ⇒ String
[Required] The current status of the work request.
52 53 54 |
# File 'lib/oci/analytics/models/work_request.rb', line 52 def status @status end |
#time_accepted ⇒ DateTime
[Required] The time the work request was accepted, in the format defined by RFC3339.
Example: 2016-08-25T21:10:29.600Z
74 75 76 |
# File 'lib/oci/analytics/models/work_request.rb', line 74 def time_accepted @time_accepted end |
#time_finished ⇒ DateTime
The time the work request was finished, in the format defined by RFC3339.
Example: 2016-08-25T21:10:29.600Z
88 89 90 |
# File 'lib/oci/analytics/models/work_request.rb', line 88 def time_finished @time_finished end |
#time_started ⇒ DateTime
The time the work request was started, in the format defined by RFC3339.
Example: 2016-08-25T21:10:29.600Z
81 82 83 |
# File 'lib/oci/analytics/models/work_request.rb', line 81 def time_started @time_started end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/oci/analytics/models/work_request.rb', line 91 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'operation_type': :'operationType', 'status': :'status', 'compartment_id': :'compartmentId', 'resources': :'resources', 'percent_complete': :'percentComplete', 'time_accepted': :'timeAccepted', 'time_started': :'timeStarted', 'time_finished': :'timeFinished' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/oci/analytics/models/work_request.rb', line 108 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'operation_type': :'String', 'status': :'String', 'compartment_id': :'String', 'resources': :'Array<OCI::Analytics::Models::WorkRequestResource>', 'percent_complete': :'Float', 'time_accepted': :'DateTime', 'time_started': :'DateTime', 'time_finished': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
221 222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/oci/analytics/models/work_request.rb', line 221 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && operation_type == other.operation_type && status == other.status && compartment_id == other.compartment_id && resources == other.resources && percent_complete == other.percent_complete && time_accepted == other.time_accepted && time_started == other.time_started && time_finished == other.time_finished end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/oci/analytics/models/work_request.rb', line 259 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
239 240 241 |
# File 'lib/oci/analytics/models/work_request.rb', line 239 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
248 249 250 |
# File 'lib/oci/analytics/models/work_request.rb', line 248 def hash [id, operation_type, status, compartment_id, resources, percent_complete, time_accepted, time_started, time_finished].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
292 293 294 295 296 297 298 299 300 301 |
# File 'lib/oci/analytics/models/work_request.rb', line 292 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
286 287 288 |
# File 'lib/oci/analytics/models/work_request.rb', line 286 def to_s to_hash.to_s end |