Class: OCI::Analytics::Models::WorkRequestResource
- Inherits:
-
Object
- Object
- OCI::Analytics::Models::WorkRequestResource
- Defined in:
- lib/oci/analytics/models/work_request_resource.rb
Overview
WorkRequestResource model.
Constant Summary collapse
- ACTION_RESULT_ENUM =
[ ACTION_RESULT_COMPARTMENT_CHANGED = 'COMPARTMENT_CHANGED'.freeze, ACTION_RESULT_CREATED = 'CREATED'.freeze, ACTION_RESULT_DELETED = 'DELETED'.freeze, ACTION_RESULT_STARTED = 'STARTED'.freeze, ACTION_RESULT_STOPPED = 'STOPPED'.freeze, ACTION_RESULT_SCALED = 'SCALED'.freeze, ACTION_RESULT_NETWORK_ENDPOINT_CHANGED = 'NETWORK_ENDPOINT_CHANGED'.freeze, ACTION_RESULT_VANITY_URL_CREATED = 'VANITY_URL_CREATED'.freeze, ACTION_RESULT_VANITY_URL_UPDATED = 'VANITY_URL_UPDATED'.freeze, ACTION_RESULT_VANITY_URL_DELETED = 'VANITY_URL_DELETED'.freeze, ACTION_RESULT_PRIVATE_ACCESS_CHANNEL_CREATED = 'PRIVATE_ACCESS_CHANNEL_CREATED'.freeze, ACTION_RESULT_PRIVATE_ACCESS_CHANNEL_UPDATED = 'PRIVATE_ACCESS_CHANNEL_UPDATED'.freeze, ACTION_RESULT_PRIVATE_ACCESS_CHANNEL_DELETED = 'PRIVATE_ACCESS_CHANNEL_DELETED'.freeze, ACTION_RESULT_NONE = 'NONE'.freeze, ACTION_RESULT_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- RESOURCE_TYPE_ENUM =
[ RESOURCE_TYPE_ANALYTICS_INSTANCE = 'ANALYTICS_INSTANCE'.freeze, RESOURCE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#action_result ⇒ String
[Required] The way in which this resource was affected by this work request.
-
#identifier ⇒ String
[Required] The OCID of the resource the work request is affecting.
-
#metadata ⇒ Hash<String, String>
Additional metadata of the resource.
-
#resource_type ⇒ String
[Required] The type of the resource the work request is affecting.
-
#resource_uri ⇒ String
[Required] The URI of the affected resource.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WorkRequestResource
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ WorkRequestResource
Initializes the object
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/oci/analytics/models/work_request_resource.rb', line 95 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.action_result = attributes[:'actionResult'] if attributes[:'actionResult'] raise 'You cannot provide both :actionResult and :action_result' if attributes.key?(:'actionResult') && attributes.key?(:'action_result') self.action_result = attributes[:'action_result'] if attributes[:'action_result'] self.resource_type = attributes[:'resourceType'] if attributes[:'resourceType'] raise 'You cannot provide both :resourceType and :resource_type' if attributes.key?(:'resourceType') && attributes.key?(:'resource_type') self.resource_type = attributes[:'resource_type'] if attributes[:'resource_type'] self.identifier = attributes[:'identifier'] if attributes[:'identifier'] self.resource_uri = attributes[:'resourceUri'] if attributes[:'resourceUri'] raise 'You cannot provide both :resourceUri and :resource_uri' if attributes.key?(:'resourceUri') && attributes.key?(:'resource_uri') self.resource_uri = attributes[:'resource_uri'] if attributes[:'resource_uri'] self. = attributes[:'metadata'] if attributes[:'metadata'] end |
Instance Attribute Details
#action_result ⇒ String
[Required] The way in which this resource was affected by this work request.
37 38 39 |
# File 'lib/oci/analytics/models/work_request_resource.rb', line 37 def action_result @action_result end |
#identifier ⇒ String
[Required] The OCID of the resource the work request is affecting.
46 47 48 |
# File 'lib/oci/analytics/models/work_request_resource.rb', line 46 def identifier @identifier end |
#metadata ⇒ Hash<String, String>
Additional metadata of the resource.
56 57 58 |
# File 'lib/oci/analytics/models/work_request_resource.rb', line 56 def end |
#resource_type ⇒ String
[Required] The type of the resource the work request is affecting.
42 43 44 |
# File 'lib/oci/analytics/models/work_request_resource.rb', line 42 def resource_type @resource_type end |
#resource_uri ⇒ String
[Required] The URI of the affected resource.
51 52 53 |
# File 'lib/oci/analytics/models/work_request_resource.rb', line 51 def resource_uri @resource_uri end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/oci/analytics/models/work_request_resource.rb', line 59 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'action_result': :'actionResult', 'resource_type': :'resourceType', 'identifier': :'identifier', 'resource_uri': :'resourceUri', 'metadata': :'metadata' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/oci/analytics/models/work_request_resource.rb', line 72 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'action_result': :'String', 'resource_type': :'String', 'identifier': :'String', 'resource_uri': :'String', 'metadata': :'Hash<String, String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
157 158 159 160 161 162 163 164 165 166 |
# File 'lib/oci/analytics/models/work_request_resource.rb', line 157 def ==(other) return true if equal?(other) self.class == other.class && action_result == other.action_result && resource_type == other.resource_type && identifier == other.identifier && resource_uri == other.resource_uri && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/oci/analytics/models/work_request_resource.rb', line 191 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
171 172 173 |
# File 'lib/oci/analytics/models/work_request_resource.rb', line 171 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
180 181 182 |
# File 'lib/oci/analytics/models/work_request_resource.rb', line 180 def hash [action_result, resource_type, identifier, resource_uri, ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
224 225 226 227 228 229 230 231 232 233 |
# File 'lib/oci/analytics/models/work_request_resource.rb', line 224 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
218 219 220 |
# File 'lib/oci/analytics/models/work_request_resource.rb', line 218 def to_s to_hash.to_s end |