Class: OCI::Analytics::Models::WorkRequestSummary
- Inherits:
-
Object
- Object
- OCI::Analytics::Models::WorkRequestSummary
- Defined in:
- lib/oci/analytics/models/work_request_summary.rb
Overview
An asynchronous work request.
Constant Summary collapse
- OPERATION_TYPE_ENUM =
[ OPERATION_TYPE_CREATE_ANALYTICS_INSTANCE = 'CREATE_ANALYTICS_INSTANCE'.freeze, OPERATION_TYPE_DELETE_ANALYTICS_INSTANCE = 'DELETE_ANALYTICS_INSTANCE'.freeze, OPERATION_TYPE_START_ANALYTICS_INSTANCE = 'START_ANALYTICS_INSTANCE'.freeze, OPERATION_TYPE_STOP_ANALYTICS_INSTANCE = 'STOP_ANALYTICS_INSTANCE'.freeze, OPERATION_TYPE_SCALE_ANALYTICS_INSTANCE = 'SCALE_ANALYTICS_INSTANCE'.freeze, OPERATION_TYPE_CHANGE_ANALYTICS_INSTANCE_COMPARTMENT = 'CHANGE_ANALYTICS_INSTANCE_COMPARTMENT'.freeze, OPERATION_TYPE_CHANGE_ANALYTICS_INSTANCE_NETWORK_ENDPOINT = 'CHANGE_ANALYTICS_INSTANCE_NETWORK_ENDPOINT'.freeze, OPERATION_TYPE_CREATE_VANITY_URL = 'CREATE_VANITY_URL'.freeze, OPERATION_TYPE_UPDATE_VANITY_URL = 'UPDATE_VANITY_URL'.freeze, OPERATION_TYPE_DELETE_VANITY_URL = 'DELETE_VANITY_URL'.freeze, OPERATION_TYPE_CREATE_PRIVATE_ACCESS_CHANNEL = 'CREATE_PRIVATE_ACCESS_CHANNEL'.freeze, OPERATION_TYPE_UPDATE_PRIVATE_ACCESS_CHANNEL = 'UPDATE_PRIVATE_ACCESS_CHANNEL'.freeze, OPERATION_TYPE_DELETE_PRIVATE_ACCESS_CHANNEL = 'DELETE_PRIVATE_ACCESS_CHANNEL'.freeze, OPERATION_TYPE_UPDATE_INSTANCE_ENCRYPTION_KEY = 'UPDATE_INSTANCE_ENCRYPTION_KEY'.freeze, OPERATION_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- STATUS_ENUM =
[ STATUS_ACCEPTED = 'ACCEPTED'.freeze, STATUS_IN_PROGRESS = 'IN_PROGRESS'.freeze, STATUS_FAILED = 'FAILED'.freeze, STATUS_SUCCEEDED = 'SUCCEEDED'.freeze, STATUS_CANCELING = 'CANCELING'.freeze, STATUS_CANCELED = 'CANCELED'.freeze, STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The compartment OCID of this work request.
-
#id ⇒ String
**[Required]** The resource OCID.
-
#operation_type ⇒ String
**[Required]** The operation performed by the work request.
-
#resources ⇒ Array<OCI::Analytics::Models::WorkRequestResource>
**[Required]** The resources this work request affects.
-
#status ⇒ String
**[Required]** The current status of the work request.
-
#time_accepted ⇒ DateTime
**[Required]** The time the work request was accepted, in the format defined by RFC3339.
-
#time_finished ⇒ DateTime
The time the work request was finished, in the format defined by RFC3339.
-
#time_started ⇒ DateTime
The time the work request was started, in the format defined by RFC3339.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WorkRequestSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ WorkRequestSummary
Initializes the object
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/oci/analytics/models/work_request_summary.rb', line 131 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.operation_type = attributes[:'operationType'] if attributes[:'operationType'] raise 'You cannot provide both :operationType and :operation_type' if attributes.key?(:'operationType') && attributes.key?(:'operation_type') self.operation_type = attributes[:'operation_type'] if attributes[:'operation_type'] self.status = attributes[:'status'] if attributes[:'status'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.resources = attributes[:'resources'] if attributes[:'resources'] self.time_accepted = attributes[:'timeAccepted'] if attributes[:'timeAccepted'] raise 'You cannot provide both :timeAccepted and :time_accepted' if attributes.key?(:'timeAccepted') && attributes.key?(:'time_accepted') self.time_accepted = attributes[:'time_accepted'] if attributes[:'time_accepted'] self.time_started = attributes[:'timeStarted'] if attributes[:'timeStarted'] raise 'You cannot provide both :timeStarted and :time_started' if attributes.key?(:'timeStarted') && attributes.key?(:'time_started') self.time_started = attributes[:'time_started'] if attributes[:'time_started'] self.time_finished = attributes[:'timeFinished'] if attributes[:'timeFinished'] raise 'You cannot provide both :timeFinished and :time_finished' if attributes.key?(:'timeFinished') && attributes.key?(:'time_finished') self.time_finished = attributes[:'time_finished'] if attributes[:'time_finished'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The compartment OCID of this work request.
57 58 59 |
# File 'lib/oci/analytics/models/work_request_summary.rb', line 57 def compartment_id @compartment_id end |
#id ⇒ String
**[Required]** The resource OCID.
42 43 44 |
# File 'lib/oci/analytics/models/work_request_summary.rb', line 42 def id @id end |
#operation_type ⇒ String
**[Required]** The operation performed by the work request.
47 48 49 |
# File 'lib/oci/analytics/models/work_request_summary.rb', line 47 def operation_type @operation_type end |
#resources ⇒ Array<OCI::Analytics::Models::WorkRequestResource>
**[Required]** The resources this work request affects.
62 63 64 |
# File 'lib/oci/analytics/models/work_request_summary.rb', line 62 def resources @resources end |
#status ⇒ String
**[Required]** The current status of the work request.
52 53 54 |
# File 'lib/oci/analytics/models/work_request_summary.rb', line 52 def status @status end |
#time_accepted ⇒ DateTime
**[Required]** The time the work request was accepted, in the format defined by RFC3339.
Example: `2016-08-25T21:10:29.600Z`
69 70 71 |
# File 'lib/oci/analytics/models/work_request_summary.rb', line 69 def time_accepted @time_accepted end |
#time_finished ⇒ DateTime
The time the work request was finished, in the format defined by RFC3339.
Example: `2016-08-25T21:10:29.600Z`
83 84 85 |
# File 'lib/oci/analytics/models/work_request_summary.rb', line 83 def time_finished @time_finished end |
#time_started ⇒ DateTime
The time the work request was started, in the format defined by RFC3339.
Example: `2016-08-25T21:10:29.600Z`
76 77 78 |
# File 'lib/oci/analytics/models/work_request_summary.rb', line 76 def time_started @time_started end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/oci/analytics/models/work_request_summary.rb', line 86 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'operation_type': :'operationType', 'status': :'status', 'compartment_id': :'compartmentId', 'resources': :'resources', 'time_accepted': :'timeAccepted', 'time_started': :'timeStarted', 'time_finished': :'timeFinished' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/oci/analytics/models/work_request_summary.rb', line 102 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'operation_type': :'String', 'status': :'String', 'compartment_id': :'String', 'resources': :'Array<OCI::Analytics::Models::WorkRequestResource>', 'time_accepted': :'DateTime', 'time_started': :'DateTime', 'time_finished': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/oci/analytics/models/work_request_summary.rb', line 207 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && operation_type == other.operation_type && status == other.status && compartment_id == other.compartment_id && resources == other.resources && time_accepted == other.time_accepted && time_started == other.time_started && time_finished == other.time_finished end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/oci/analytics/models/work_request_summary.rb', line 244 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
224 225 226 |
# File 'lib/oci/analytics/models/work_request_summary.rb', line 224 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
233 234 235 |
# File 'lib/oci/analytics/models/work_request_summary.rb', line 233 def hash [id, operation_type, status, compartment_id, resources, time_accepted, time_started, time_finished].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
277 278 279 280 281 282 283 284 285 286 |
# File 'lib/oci/analytics/models/work_request_summary.rb', line 277 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
271 272 273 |
# File 'lib/oci/analytics/models/work_request_summary.rb', line 271 def to_s to_hash.to_s end |