Class: OCI::AnnouncementsService::Models::AffectedResource
- Inherits:
-
Object
- Object
- OCI::AnnouncementsService::Models::AffectedResource
- Defined in:
- lib/oci/announcements_service/models/affected_resource.rb
Overview
The resource affected by the event described in the announcement.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Array<OCI::AnnouncementsService::Models::Property>
Additional properties associated with the resource.
-
#region ⇒ String
[Required] The region where the affected resource exists.
-
#resource_id ⇒ String
[Required] The OCID of the affected resource.
-
#resource_name ⇒ String
[Required] The friendly name of the resource.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AffectedResource
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ AffectedResource
Initializes the object
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/oci/announcements_service/models/affected_resource.rb', line 61 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.resource_id = attributes[:'resourceId'] if attributes[:'resourceId'] raise 'You cannot provide both :resourceId and :resource_id' if attributes.key?(:'resourceId') && attributes.key?(:'resource_id') self.resource_id = attributes[:'resource_id'] if attributes[:'resource_id'] self.resource_name = attributes[:'resourceName'] if attributes[:'resourceName'] raise 'You cannot provide both :resourceName and :resource_name' if attributes.key?(:'resourceName') && attributes.key?(:'resource_name') self.resource_name = attributes[:'resource_name'] if attributes[:'resource_name'] self.region = attributes[:'region'] if attributes[:'region'] self.additional_properties = attributes[:'additionalProperties'] if attributes[:'additionalProperties'] raise 'You cannot provide both :additionalProperties and :additional_properties' if attributes.key?(:'additionalProperties') && attributes.key?(:'additional_properties') self.additional_properties = attributes[:'additional_properties'] if attributes[:'additional_properties'] end |
Instance Attribute Details
#additional_properties ⇒ Array<OCI::AnnouncementsService::Models::Property>
Additional properties associated with the resource.
25 26 27 |
# File 'lib/oci/announcements_service/models/affected_resource.rb', line 25 def additional_properties @additional_properties end |
#region ⇒ String
[Required] The region where the affected resource exists.
21 22 23 |
# File 'lib/oci/announcements_service/models/affected_resource.rb', line 21 def region @region end |
#resource_id ⇒ String
[Required] The OCID of the affected resource.
13 14 15 |
# File 'lib/oci/announcements_service/models/affected_resource.rb', line 13 def resource_id @resource_id end |
#resource_name ⇒ String
[Required] The friendly name of the resource.
17 18 19 |
# File 'lib/oci/announcements_service/models/affected_resource.rb', line 17 def resource_name @resource_name end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 35 36 37 |
# File 'lib/oci/announcements_service/models/affected_resource.rb', line 28 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'resource_id': :'resourceId', 'resource_name': :'resourceName', 'region': :'region', 'additional_properties': :'additionalProperties' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
40 41 42 43 44 45 46 47 48 49 |
# File 'lib/oci/announcements_service/models/affected_resource.rb', line 40 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'resource_id': :'String', 'resource_name': :'String', 'region': :'String', 'additional_properties': :'Array<OCI::AnnouncementsService::Models::Property>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
95 96 97 98 99 100 101 102 103 |
# File 'lib/oci/announcements_service/models/affected_resource.rb', line 95 def ==(other) return true if equal?(other) self.class == other.class && resource_id == other.resource_id && resource_name == other.resource_name && region == other.region && additional_properties == other.additional_properties end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/oci/announcements_service/models/affected_resource.rb', line 128 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
108 109 110 |
# File 'lib/oci/announcements_service/models/affected_resource.rb', line 108 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
117 118 119 |
# File 'lib/oci/announcements_service/models/affected_resource.rb', line 117 def hash [resource_id, resource_name, region, additional_properties].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
161 162 163 164 165 166 167 168 169 170 |
# File 'lib/oci/announcements_service/models/affected_resource.rb', line 161 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
155 156 157 |
# File 'lib/oci/announcements_service/models/affected_resource.rb', line 155 def to_s to_hash.to_s end |