Class: AnnouncementsService::Models::Announcement

Inherits:
OCI::AnnouncementsService::Models::BaseAnnouncement show all
Defined in:
lib/oci/announcements_service/models/announcement.rb

Overview

A message about an impactful operational event.

Constant Summary

Constants inherited from OCI::AnnouncementsService::Models::BaseAnnouncement

OCI::AnnouncementsService::Models::BaseAnnouncement::ANNOUNCEMENT_TYPE_ENUM, OCI::AnnouncementsService::Models::BaseAnnouncement::LIFECYCLE_STATE_ENUM, OCI::AnnouncementsService::Models::BaseAnnouncement::PLATFORM_TYPE_ENUM, OCI::AnnouncementsService::Models::BaseAnnouncement::TIME_ONE_TYPE_ENUM, OCI::AnnouncementsService::Models::BaseAnnouncement::TIME_TWO_TYPE_ENUM

Instance Attribute Summary collapse

Attributes inherited from OCI::AnnouncementsService::Models::BaseAnnouncement

#affected_regions, #announcement_type, #environment_name, #id, #is_banner, #lifecycle_state, #platform_type, #reference_ticket_number, #services, #summary, #time_created, #time_one_title, #time_one_type, #time_one_value, #time_two_title, #time_two_type, #time_two_value, #time_updated, #type

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from OCI::AnnouncementsService::Models::BaseAnnouncement

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ Announcement

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/oci/announcements_service/models/announcement.rb', line 117

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['type'] = 'Announcement'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.description = attributes[:'description'] if attributes[:'description']

  self.additional_information = attributes[:'additionalInformation'] if attributes[:'additionalInformation']

  raise 'You cannot provide both :additionalInformation and :additional_information' if attributes.key?(:'additionalInformation') && attributes.key?(:'additional_information')

  self.additional_information = attributes[:'additional_information'] if attributes[:'additional_information']

  self.affected_resources = attributes[:'affectedResources'] if attributes[:'affectedResources']

  raise 'You cannot provide both :affectedResources and :affected_resources' if attributes.key?(:'affectedResources') && attributes.key?(:'affected_resources')

  self.affected_resources = attributes[:'affected_resources'] if attributes[:'affected_resources']
end

Instance Attribute Details

#additional_informationString

Additional information about the event, expressed by using Markdown language and included in the details view of an announcement. Additional information might include remediation steps or answers to frequently asked questions. Avoid entering confidential information.

Returns:

  • (String)


24
25
26
# File 'lib/oci/announcements_service/models/announcement.rb', line 24

def additional_information
  @additional_information
end

#affected_resourcesArray<OCI::AnnouncementsService::Models::AffectedResource>

The list of resources, if any, affected by the event described in the announcement.



28
29
30
# File 'lib/oci/announcements_service/models/announcement.rb', line 28

def affected_resources
  @affected_resources
end

#descriptionString

A detailed explanation of the event, expressed by using Markdown language. Avoid entering confidential information.

Returns:

  • (String)


17
18
19
# File 'lib/oci/announcements_service/models/announcement.rb', line 17

def description
  @description
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
# File 'lib/oci/announcements_service/models/announcement.rb', line 31

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'type': :'type',
    'reference_ticket_number': :'referenceTicketNumber',
    'summary': :'summary',
    'time_one_title': :'timeOneTitle',
    'time_one_type': :'timeOneType',
    'time_one_value': :'timeOneValue',
    'time_two_title': :'timeTwoTitle',
    'time_two_type': :'timeTwoType',
    'time_two_value': :'timeTwoValue',
    'services': :'services',
    'affected_regions': :'affectedRegions',
    'announcement_type': :'announcementType',
    'lifecycle_state': :'lifecycleState',
    'is_banner': :'isBanner',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'environment_name': :'environmentName',
    'platform_type': :'platformType',
    'description': :'description',
    'additional_information': :'additionalInformation',
    'affected_resources': :'affectedResources'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/oci/announcements_service/models/announcement.rb', line 61

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'type': :'String',
    'reference_ticket_number': :'String',
    'summary': :'String',
    'time_one_title': :'String',
    'time_one_type': :'String',
    'time_one_value': :'DateTime',
    'time_two_title': :'String',
    'time_two_type': :'String',
    'time_two_value': :'DateTime',
    'services': :'Array<String>',
    'affected_regions': :'Array<String>',
    'announcement_type': :'String',
    'lifecycle_state': :'String',
    'is_banner': :'BOOLEAN',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'environment_name': :'String',
    'platform_type': :'String',
    'description': :'String',
    'additional_information': :'String',
    'affected_resources': :'Array<OCI::AnnouncementsService::Models::AffectedResource>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/oci/announcements_service/models/announcement.rb', line 149

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    type == other.type &&
    reference_ticket_number == other.reference_ticket_number &&
    summary == other.summary &&
    time_one_title == other.time_one_title &&
    time_one_type == other.time_one_type &&
    time_one_value == other.time_one_value &&
    time_two_title == other.time_two_title &&
    time_two_type == other.time_two_type &&
    time_two_value == other.time_two_value &&
    services == other.services &&
    affected_regions == other.affected_regions &&
    announcement_type == other.announcement_type &&
    lifecycle_state == other.lifecycle_state &&
    is_banner == other.is_banner &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    environment_name == other.environment_name &&
    platform_type == other.platform_type &&
    description == other.description &&
    additional_information == other.additional_information &&
    affected_resources == other.affected_resources
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/oci/announcements_service/models/announcement.rb', line 200

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


180
181
182
# File 'lib/oci/announcements_service/models/announcement.rb', line 180

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



189
190
191
# File 'lib/oci/announcements_service/models/announcement.rb', line 189

def hash
  [id, type, reference_ticket_number, summary, time_one_title, time_one_type, time_one_value, time_two_title, time_two_type, time_two_value, services, affected_regions, announcement_type, lifecycle_state, is_banner, time_created, time_updated, environment_name, platform_type, description, additional_information, affected_resources].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



233
234
235
236
237
238
239
240
241
242
# File 'lib/oci/announcements_service/models/announcement.rb', line 233

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



227
228
229
# File 'lib/oci/announcements_service/models/announcement.rb', line 227

def to_s
  to_hash.to_s
end