Class: OCI::AnnouncementsService::Models::AnnouncementSubscription
- Inherits:
-
Object
- Object
- OCI::AnnouncementsService::Models::AnnouncementSubscription
- Defined in:
- lib/oci/announcements_service/models/announcement_subscription.rb
Overview
A subscription with the Announcements service to receive selected announcements in the format and delivery mechanisms supported by a corresponding topic endpoint configured in the Oracle Cloud Infrastructure Notifications service.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The OCID of the compartment that contains the announcement subscription.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
**[Required]** Defined tags for this resource.
-
#description ⇒ String
A description of the announcement subscription.
-
#display_name ⇒ String
**[Required]** A user-friendly name for the announcement subscription.
-
#filter_groups ⇒ Hash<String, OCI::AnnouncementsService::Models::FilterGroup>
A list of filter groups for the announcement subscription.
-
#freeform_tags ⇒ Hash<String, String>
**[Required]** Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the announcement subscription.
-
#lifecycle_details ⇒ String
A message describing the current lifecycle state in more detail.
-
#lifecycle_state ⇒ String
**[Required]** The current lifecycle state of the announcement subscription.
-
#ons_topic_id ⇒ String
**[Required]** The OCID of the Notifications service topic that is the target for publishing announcements that match the configured announcement subscription.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys.
-
#time_created ⇒ DateTime
**[Required]** The date and time that the announcement subscription was created, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.
-
#time_updated ⇒ DateTime
The date and time that the announcement subscription was updated, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AnnouncementSubscription
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ AnnouncementSubscription
Initializes the object
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/oci/announcements_service/models/announcement_subscription.rb', line 144 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.ons_topic_id = attributes[:'onsTopicId'] if attributes[:'onsTopicId'] raise 'You cannot provide both :onsTopicId and :ons_topic_id' if attributes.key?(:'onsTopicId') && attributes.key?(:'ons_topic_id') self.ons_topic_id = attributes[:'ons_topic_id'] if attributes[:'ons_topic_id'] self.filter_groups = attributes[:'filterGroups'] if attributes[:'filterGroups'] raise 'You cannot provide both :filterGroups and :filter_groups' if attributes.key?(:'filterGroups') && attributes.key?(:'filter_groups') self.filter_groups = attributes[:'filter_groups'] if attributes[:'filter_groups'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The OCID of the compartment that contains the announcement subscription.
34 35 36 |
# File 'lib/oci/announcements_service/models/announcement_subscription.rb', line 34 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
**[Required]** Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
75 76 77 |
# File 'lib/oci/announcements_service/models/announcement_subscription.rb', line 75 def @defined_tags end |
#description ⇒ String
A description of the announcement subscription. Avoid entering confidential information.
30 31 32 |
# File 'lib/oci/announcements_service/models/announcement_subscription.rb', line 30 def description @description end |
#display_name ⇒ String
**[Required]** A user-friendly name for the announcement subscription. Does not have to be unique, and it's changeable. Avoid entering confidential information.
26 27 28 |
# File 'lib/oci/announcements_service/models/announcement_subscription.rb', line 26 def display_name @display_name end |
#filter_groups ⇒ Hash<String, OCI::AnnouncementsService::Models::FilterGroup>
A list of filter groups for the announcement subscription. A filter group is a combination of multiple filters applied to announcements for matching purposes.
63 64 65 |
# File 'lib/oci/announcements_service/models/announcement_subscription.rb', line 63 def filter_groups @filter_groups end |
#freeform_tags ⇒ Hash<String, String>
**[Required]** Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
69 70 71 |
# File 'lib/oci/announcements_service/models/announcement_subscription.rb', line 69 def @freeform_tags end |
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the announcement subscription.
21 22 23 |
# File 'lib/oci/announcements_service/models/announcement_subscription.rb', line 21 def id @id end |
#lifecycle_details ⇒ String
A message describing the current lifecycle state in more detail. For example, details might provide required or recommended actions for a resource in a Failed state.
53 54 55 |
# File 'lib/oci/announcements_service/models/announcement_subscription.rb', line 53 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
**[Required]** The current lifecycle state of the announcement subscription.
48 49 50 |
# File 'lib/oci/announcements_service/models/announcement_subscription.rb', line 48 def lifecycle_state @lifecycle_state end |
#ons_topic_id ⇒ String
**[Required]** The OCID of the Notifications service topic that is the target for publishing announcements that match the configured announcement subscription.
58 59 60 |
# File 'lib/oci/announcements_service/models/announcement_subscription.rb', line 58 def ons_topic_id @ons_topic_id end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"free-tier-retained": "true"}`
81 82 83 |
# File 'lib/oci/announcements_service/models/announcement_subscription.rb', line 81 def @system_tags end |
#time_created ⇒ DateTime
**[Required]** The date and time that the announcement subscription was created, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.
39 40 41 |
# File 'lib/oci/announcements_service/models/announcement_subscription.rb', line 39 def time_created @time_created end |
#time_updated ⇒ DateTime
The date and time that the announcement subscription was updated, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.
44 45 46 |
# File 'lib/oci/announcements_service/models/announcement_subscription.rb', line 44 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/oci/announcements_service/models/announcement_subscription.rb', line 84 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'description': :'description', 'compartment_id': :'compartmentId', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'ons_topic_id': :'onsTopicId', 'filter_groups': :'filterGroups', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/oci/announcements_service/models/announcement_subscription.rb', line 105 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'description': :'String', 'compartment_id': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'ons_topic_id': :'String', 'filter_groups': :'Hash<String, OCI::AnnouncementsService::Models::FilterGroup>', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/oci/announcements_service/models/announcement_subscription.rb', line 241 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && description == other.description && compartment_id == other.compartment_id && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && ons_topic_id == other.ons_topic_id && filter_groups == other.filter_groups && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'lib/oci/announcements_service/models/announcement_subscription.rb', line 283 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
263 264 265 |
# File 'lib/oci/announcements_service/models/announcement_subscription.rb', line 263 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
272 273 274 |
# File 'lib/oci/announcements_service/models/announcement_subscription.rb', line 272 def hash [id, display_name, description, compartment_id, time_created, time_updated, lifecycle_state, lifecycle_details, ons_topic_id, filter_groups, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
316 317 318 319 320 321 322 323 324 325 |
# File 'lib/oci/announcements_service/models/announcement_subscription.rb', line 316 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
310 311 312 |
# File 'lib/oci/announcements_service/models/announcement_subscription.rb', line 310 def to_s to_hash.to_s end |