Class: OCI::AnnouncementsService::Models::AnnouncementSummary
- Inherits:
-
BaseAnnouncement
- Object
- BaseAnnouncement
- OCI::AnnouncementsService::Models::AnnouncementSummary
- Defined in:
- lib/oci/announcements_service/models/announcement_summary.rb
Overview
A summary representation of an announcement.
Constant Summary
Constants inherited from BaseAnnouncement
BaseAnnouncement::ANNOUNCEMENT_TYPE_ENUM, BaseAnnouncement::LIFECYCLE_STATE_ENUM, BaseAnnouncement::PLATFORM_TYPE_ENUM, BaseAnnouncement::TIME_ONE_TYPE_ENUM, BaseAnnouncement::TIME_TWO_TYPE_ENUM
Instance Attribute Summary
Attributes inherited from BaseAnnouncement
#affected_regions, #announcement_type, #environment_name, #id, #is_banner, #lifecycle_state, #platform_type, #reference_ticket_number, #services, #summary, #time_created, #time_one_title, #time_one_type, #time_one_value, #time_two_title, #time_two_type, #time_two_value, #time_updated, #type
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AnnouncementSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from BaseAnnouncement
Constructor Details
#initialize(attributes = {}) ⇒ AnnouncementSummary
Initializes the object
91 92 93 94 95 96 97 |
# File 'lib/oci/announcements_service/models/announcement_summary.rb', line 91 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['type'] = 'AnnouncementSummary' super(attributes) end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 |
# File 'lib/oci/announcements_service/models/announcement_summary.rb', line 14 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'type': :'type', 'reference_ticket_number': :'referenceTicketNumber', 'summary': :'summary', 'time_one_title': :'timeOneTitle', 'time_one_type': :'timeOneType', 'time_one_value': :'timeOneValue', 'time_two_title': :'timeTwoTitle', 'time_two_type': :'timeTwoType', 'time_two_value': :'timeTwoValue', 'services': :'services', 'affected_regions': :'affectedRegions', 'announcement_type': :'announcementType', 'lifecycle_state': :'lifecycleState', 'is_banner': :'isBanner', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'environment_name': :'environmentName', 'platform_type': :'platformType' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/oci/announcements_service/models/announcement_summary.rb', line 41 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'type': :'String', 'reference_ticket_number': :'String', 'summary': :'String', 'time_one_title': :'String', 'time_one_type': :'String', 'time_one_value': :'DateTime', 'time_two_title': :'String', 'time_two_type': :'String', 'time_two_value': :'DateTime', 'services': :'Array<String>', 'affected_regions': :'Array<String>', 'announcement_type': :'String', 'lifecycle_state': :'String', 'is_banner': :'BOOLEAN', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'environment_name': :'String', 'platform_type': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/oci/announcements_service/models/announcement_summary.rb', line 106 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && type == other.type && reference_ticket_number == other.reference_ticket_number && summary == other.summary && time_one_title == other.time_one_title && time_one_type == other.time_one_type && time_one_value == other.time_one_value && time_two_title == other.time_two_title && time_two_type == other.time_two_type && time_two_value == other.time_two_value && services == other.services && affected_regions == other.affected_regions && announcement_type == other.announcement_type && lifecycle_state == other.lifecycle_state && == other. && time_created == other.time_created && time_updated == other.time_updated && environment_name == other.environment_name && platform_type == other.platform_type end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/oci/announcements_service/models/announcement_summary.rb', line 154 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
134 135 136 |
# File 'lib/oci/announcements_service/models/announcement_summary.rb', line 134 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
143 144 145 |
# File 'lib/oci/announcements_service/models/announcement_summary.rb', line 143 def hash [id, type, reference_ticket_number, summary, time_one_title, time_one_type, time_one_value, time_two_title, time_two_type, time_two_value, services, affected_regions, announcement_type, lifecycle_state, , time_created, time_updated, environment_name, platform_type].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
187 188 189 190 191 192 193 194 195 196 |
# File 'lib/oci/announcements_service/models/announcement_summary.rb', line 187 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
181 182 183 |
# File 'lib/oci/announcements_service/models/announcement_summary.rb', line 181 def to_s to_hash.to_s end |