Class: OCI::AnnouncementsService::Models::BaseAnnouncementsPreferences

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/announcements_service/models/base_announcements_preferences.rb

Overview

The object that contains the announcement email preferences configured for the tenancy (root compartment). This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ BaseAnnouncementsPreferences

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :type (String)

    The value to assign to the #type property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :id (String)

    The value to assign to the #id property

  • :is_unsubscribed (BOOLEAN)

    The value to assign to the #is_unsubscribed property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :time_updated (DateTime)

    The value to assign to the #time_updated property

  • :preference_type (String)

    The value to assign to the #preference_type property



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/oci/announcements_service/models/base_announcements_preferences.rb', line 102

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.type = attributes[:'type'] if attributes[:'type']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.id = attributes[:'id'] if attributes[:'id']

  self.is_unsubscribed = attributes[:'isUnsubscribed'] unless attributes[:'isUnsubscribed'].nil?

  raise 'You cannot provide both :isUnsubscribed and :is_unsubscribed' if attributes.key?(:'isUnsubscribed') && attributes.key?(:'is_unsubscribed')

  self.is_unsubscribed = attributes[:'is_unsubscribed'] unless attributes[:'is_unsubscribed'].nil?

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.preference_type = attributes[:'preferenceType'] if attributes[:'preferenceType']

  raise 'You cannot provide both :preferenceType and :preference_type' if attributes.key?(:'preferenceType') && attributes.key?(:'preference_type')

  self.preference_type = attributes[:'preference_type'] if attributes[:'preference_type']
end

Instance Attribute Details

#compartment_idString

The OCID of the compartment for which the email preferences apply. Because announcements are specific to a tenancy, specify the tenancy by providing the root compartment OCID.

Returns:

  • (String)


19
20
21
# File 'lib/oci/announcements_service/models/base_announcements_preferences.rb', line 19

def compartment_id
  @compartment_id
end

#idString

The ID of the preferences.

Returns:

  • (String)


23
24
25
# File 'lib/oci/announcements_service/models/base_announcements_preferences.rb', line 23

def id
  @id
end

#is_unsubscribedBOOLEAN

A Boolean value to indicate whether the specified compartment chooses to not to receive informational announcements by email. (Manage preferences for receiving announcements by email by specifying the `preferenceType` attribute instead.)

Returns:

  • (BOOLEAN)


29
30
31
# File 'lib/oci/announcements_service/models/base_announcements_preferences.rb', line 29

def is_unsubscribed
  @is_unsubscribed
end

#preference_typeString

The string representing the user's preference regarding receiving announcements by email.

Returns:

  • (String)


41
42
43
# File 'lib/oci/announcements_service/models/base_announcements_preferences.rb', line 41

def preference_type
  @preference_type
end

#time_createdDateTime

When the preferences were set initially.

Returns:

  • (DateTime)


33
34
35
# File 'lib/oci/announcements_service/models/base_announcements_preferences.rb', line 33

def time_created
  @time_created
end

#time_updatedDateTime

When the preferences were last updated.

Returns:

  • (DateTime)


37
38
39
# File 'lib/oci/announcements_service/models/base_announcements_preferences.rb', line 37

def time_updated
  @time_updated
end

#typeString

**[Required]** The entity type, which specifies either an object or a summary object for announcement email preferences.

Returns:

  • (String)


13
14
15
# File 'lib/oci/announcements_service/models/base_announcements_preferences.rb', line 13

def type
  @type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



44
45
46
47
48
49
50
51
52
53
54
55
56
# File 'lib/oci/announcements_service/models/base_announcements_preferences.rb', line 44

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'type': :'type',
    'compartment_id': :'compartmentId',
    'id': :'id',
    'is_unsubscribed': :'isUnsubscribed',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'preference_type': :'preferenceType'
    # rubocop:enable Style/SymbolLiteral
  }
end

.get_subtype(object_hash) ⇒ Object

Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.



78
79
80
81
82
83
84
85
86
# File 'lib/oci/announcements_service/models/base_announcements_preferences.rb', line 78

def self.get_subtype(object_hash)
  type = object_hash[:'type'] # rubocop:disable Style/SymbolLiteral

  return 'OCI::AnnouncementsService::Models::AnnouncementsPreferencesSummary' if type == 'AnnouncementsPreferencesSummary'
  return 'OCI::AnnouncementsService::Models::AnnouncementsPreferences' if type == 'AnnouncementsPreferences'

  # TODO: Log a warning when the subtype is not found.
  'OCI::AnnouncementsService::Models::BaseAnnouncementsPreferences'
end

.swagger_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/oci/announcements_service/models/base_announcements_preferences.rb', line 59

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'type': :'String',
    'compartment_id': :'String',
    'id': :'String',
    'is_unsubscribed': :'BOOLEAN',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'preference_type': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/oci/announcements_service/models/base_announcements_preferences.rb', line 150

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    type == other.type &&
    compartment_id == other.compartment_id &&
    id == other.id &&
    is_unsubscribed == other.is_unsubscribed &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    preference_type == other.preference_type
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/oci/announcements_service/models/base_announcements_preferences.rb', line 186

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


166
167
168
# File 'lib/oci/announcements_service/models/base_announcements_preferences.rb', line 166

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



175
176
177
# File 'lib/oci/announcements_service/models/base_announcements_preferences.rb', line 175

def hash
  [type, compartment_id, id, is_unsubscribed, time_created, time_updated, preference_type].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



219
220
221
222
223
224
225
226
227
228
# File 'lib/oci/announcements_service/models/base_announcements_preferences.rb', line 219

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



213
214
215
# File 'lib/oci/announcements_service/models/base_announcements_preferences.rb', line 213

def to_s
  to_hash.to_s
end