Class: OCI::AnnouncementsService::Models::BaseCreateAnnouncementsPreferencesDetails
- Inherits:
-
Object
- Object
- OCI::AnnouncementsService::Models::BaseCreateAnnouncementsPreferencesDetails
- Defined in:
- lib/oci/announcements_service/models/base_create_announcements_preferences_details.rb
Overview
The model for the parameters of announcement email preferences configured for the tenancy (root compartment). This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
CreateAnnouncementsPreferencesDetails, UpdateAnnouncementsPreferencesDetails
Constant Summary collapse
- PREFERENCE_TYPE_ENUM =
[ PREFERENCE_TYPE_OPT_IN_TENANT_ANNOUNCEMENTS = 'OPT_IN_TENANT_ANNOUNCEMENTS'.freeze, PREFERENCE_TYPE_OPT_IN_TENANT_AND_INFORMATIONAL_ANNOUNCEMENTS = 'OPT_IN_TENANT_AND_INFORMATIONAL_ANNOUNCEMENTS'.freeze, PREFERENCE_TYPE_OPT_OUT_ALL_ANNOUNCEMENTS = 'OPT_OUT_ALL_ANNOUNCEMENTS'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
The OCID of the compartment for which you want to manage announcement email preferences.
-
#is_unsubscribed ⇒ BOOLEAN
A Boolean value to indicate whether the specified compartment chooses to not to receive informational announcements by email.
-
#preference_type ⇒ String
**[Required]** The string representing the user's preference, whether to opt in to only required announcements, to opt in to all announcements, including informational announcements, or to opt out of all announcements.
-
#type ⇒ String
**[Required]** The entity type, which specifies a model that either creates new announcement email preferences or updates existing preferences.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BaseCreateAnnouncementsPreferencesDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ BaseCreateAnnouncementsPreferencesDetails
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/oci/announcements_service/models/base_create_announcements_preferences_details.rb', line 88 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.type = attributes[:'type'] if attributes[:'type'] self.is_unsubscribed = attributes[:'isUnsubscribed'] unless attributes[:'isUnsubscribed'].nil? raise 'You cannot provide both :isUnsubscribed and :is_unsubscribed' if attributes.key?(:'isUnsubscribed') && attributes.key?(:'is_unsubscribed') self.is_unsubscribed = attributes[:'is_unsubscribed'] unless attributes[:'is_unsubscribed'].nil? self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.preference_type = attributes[:'preferenceType'] if attributes[:'preferenceType'] raise 'You cannot provide both :preferenceType and :preference_type' if attributes.key?(:'preferenceType') && attributes.key?(:'preference_type') self.preference_type = attributes[:'preference_type'] if attributes[:'preference_type'] end |
Instance Attribute Details
#compartment_id ⇒ String
The OCID of the compartment for which you want to manage announcement email preferences. (Specify the tenancy by providing the root compartment OCID.)
32 33 34 |
# File 'lib/oci/announcements_service/models/base_create_announcements_preferences_details.rb', line 32 def compartment_id @compartment_id end |
#is_unsubscribed ⇒ BOOLEAN
A Boolean value to indicate whether the specified compartment chooses to not to receive informational announcements by email. (Manage preferences for receiving announcements by email by specifying the `preferenceType` attribute instead.)
26 27 28 |
# File 'lib/oci/announcements_service/models/base_create_announcements_preferences_details.rb', line 26 def is_unsubscribed @is_unsubscribed end |
#preference_type ⇒ String
**[Required]** The string representing the user's preference, whether to opt in to only required announcements, to opt in to all announcements, including informational announcements, or to opt out of all announcements.
36 37 38 |
# File 'lib/oci/announcements_service/models/base_create_announcements_preferences_details.rb', line 36 def preference_type @preference_type end |
#type ⇒ String
**[Required]** The entity type, which specifies a model that either creates new announcement email preferences or updates existing preferences.
20 21 22 |
# File 'lib/oci/announcements_service/models/base_create_announcements_preferences_details.rb', line 20 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 48 |
# File 'lib/oci/announcements_service/models/base_create_announcements_preferences_details.rb', line 39 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'type': :'type', 'is_unsubscribed': :'isUnsubscribed', 'compartment_id': :'compartmentId', 'preference_type': :'preferenceType' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
67 68 69 70 71 72 73 74 75 |
# File 'lib/oci/announcements_service/models/base_create_announcements_preferences_details.rb', line 67 def self.get_subtype(object_hash) type = object_hash[:'type'] # rubocop:disable Style/SymbolLiteral return 'OCI::AnnouncementsService::Models::CreateAnnouncementsPreferencesDetails' if type == 'CreateAnnouncementsPreferencesDetails' return 'OCI::AnnouncementsService::Models::UpdateAnnouncementsPreferencesDetails' if type == 'UpdateAnnouncementsPreferencesDetails' # TODO: Log a warning when the subtype is not found. 'OCI::AnnouncementsService::Models::BaseCreateAnnouncementsPreferencesDetails' end |
.swagger_types ⇒ Object
Attribute type mapping.
51 52 53 54 55 56 57 58 59 60 |
# File 'lib/oci/announcements_service/models/base_create_announcements_preferences_details.rb', line 51 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'type': :'String', 'is_unsubscribed': :'BOOLEAN', 'compartment_id': :'String', 'preference_type': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
130 131 132 133 134 135 136 137 138 |
# File 'lib/oci/announcements_service/models/base_create_announcements_preferences_details.rb', line 130 def ==(other) return true if equal?(other) self.class == other.class && type == other.type && is_unsubscribed == other.is_unsubscribed && compartment_id == other.compartment_id && preference_type == other.preference_type end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/oci/announcements_service/models/base_create_announcements_preferences_details.rb', line 163 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
143 144 145 |
# File 'lib/oci/announcements_service/models/base_create_announcements_preferences_details.rb', line 143 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
152 153 154 |
# File 'lib/oci/announcements_service/models/base_create_announcements_preferences_details.rb', line 152 def hash [type, is_unsubscribed, compartment_id, preference_type].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
196 197 198 199 200 201 202 203 204 205 |
# File 'lib/oci/announcements_service/models/base_create_announcements_preferences_details.rb', line 196 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
190 191 192 |
# File 'lib/oci/announcements_service/models/base_create_announcements_preferences_details.rb', line 190 def to_s to_hash.to_s end |