Class: OCI::AnnouncementsService::Models::CreateAnnouncementSubscriptionDetails
- Inherits:
-
Object
- Object
- OCI::AnnouncementsService::Models::CreateAnnouncementSubscriptionDetails
- Defined in:
- lib/oci/announcements_service/models/create_announcement_subscription_details.rb
Overview
The details for creating a new announcement subscription.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment where you want to create the announcement subscription.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
A description of the announcement subscription.
-
#display_name ⇒ String
**[Required]** A user-friendly name for the announcement subscription.
-
#filter_groups ⇒ Hash<String, OCI::AnnouncementsService::Models::FilterGroupDetails>
A list of filter groups for the announcement subscription.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#ons_topic_id ⇒ String
**[Required]** The OCID of the Notifications service topic that is the target for publishing announcements that match the configured announcement subscription.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateAnnouncementSubscriptionDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateAnnouncementSubscriptionDetails
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/oci/announcements_service/models/create_announcement_subscription_details.rb', line 88 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.ons_topic_id = attributes[:'onsTopicId'] if attributes[:'onsTopicId'] raise 'You cannot provide both :onsTopicId and :ons_topic_id' if attributes.key?(:'onsTopicId') && attributes.key?(:'ons_topic_id') self.ons_topic_id = attributes[:'ons_topic_id'] if attributes[:'ons_topic_id'] self.filter_groups = attributes[:'filterGroups'] if attributes[:'filterGroups'] raise 'You cannot provide both :filterGroups and :filter_groups' if attributes.key?(:'filterGroups') && attributes.key?(:'filter_groups') self.filter_groups = attributes[:'filter_groups'] if attributes[:'filter_groups'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment where you want to create the announcement subscription.
21 22 23 |
# File 'lib/oci/announcements_service/models/create_announcement_subscription_details.rb', line 21 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
43 44 45 |
# File 'lib/oci/announcements_service/models/create_announcement_subscription_details.rb', line 43 def @defined_tags end |
#description ⇒ String
A description of the announcement subscription. Avoid entering confidential information.
16 17 18 |
# File 'lib/oci/announcements_service/models/create_announcement_subscription_details.rb', line 16 def description @description end |
#display_name ⇒ String
**[Required]** A user-friendly name for the announcement subscription. Does not have to be unique, and it's changeable. Avoid entering confidential information.
12 13 14 |
# File 'lib/oci/announcements_service/models/create_announcement_subscription_details.rb', line 12 def display_name @display_name end |
#filter_groups ⇒ Hash<String, OCI::AnnouncementsService::Models::FilterGroupDetails>
A list of filter groups for the announcement subscription. A filter group combines one or more filters that the Announcements service applies to announcements for matching purposes.
31 32 33 |
# File 'lib/oci/announcements_service/models/create_announcement_subscription_details.rb', line 31 def filter_groups @filter_groups end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
37 38 39 |
# File 'lib/oci/announcements_service/models/create_announcement_subscription_details.rb', line 37 def @freeform_tags end |
#ons_topic_id ⇒ String
**[Required]** The OCID of the Notifications service topic that is the target for publishing announcements that match the configured announcement subscription. The caller of the operation needs the ONS_TOPIC_PUBLISH permission for the targeted Notifications service topic. For more information about Notifications permissions, see [Details for Notifications](docs.cloud.oracle.com/Content/Identity/policyreference/notificationpolicyreference.htm).
26 27 28 |
# File 'lib/oci/announcements_service/models/create_announcement_subscription_details.rb', line 26 def ons_topic_id @ons_topic_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/oci/announcements_service/models/create_announcement_subscription_details.rb', line 46 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'description': :'description', 'compartment_id': :'compartmentId', 'ons_topic_id': :'onsTopicId', 'filter_groups': :'filterGroups', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/oci/announcements_service/models/create_announcement_subscription_details.rb', line 61 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'description': :'String', 'compartment_id': :'String', 'ons_topic_id': :'String', 'filter_groups': :'Hash<String, OCI::AnnouncementsService::Models::FilterGroupDetails>', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/oci/announcements_service/models/create_announcement_subscription_details.rb', line 140 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && description == other.description && compartment_id == other.compartment_id && ons_topic_id == other.ons_topic_id && filter_groups == other.filter_groups && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/oci/announcements_service/models/create_announcement_subscription_details.rb', line 176 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
156 157 158 |
# File 'lib/oci/announcements_service/models/create_announcement_subscription_details.rb', line 156 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
165 166 167 |
# File 'lib/oci/announcements_service/models/create_announcement_subscription_details.rb', line 165 def hash [display_name, description, compartment_id, ons_topic_id, filter_groups, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
209 210 211 212 213 214 215 216 217 218 |
# File 'lib/oci/announcements_service/models/create_announcement_subscription_details.rb', line 209 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
203 204 205 |
# File 'lib/oci/announcements_service/models/create_announcement_subscription_details.rb', line 203 def to_s to_hash.to_s end |