Class: OCI::Apigateway::Models::Api
- Inherits:
-
Object
- Object
- OCI::Apigateway::Models::Api
- Defined in:
- lib/oci/apigateway/models/api.rb
Overview
An API is simple container for an API Specification. For more information, see [API Gateway Concepts](docs.cloud.oracle.com/iaas/Content/APIGateway/Concepts/apigatewayconcepts.htm).
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment in which the resource is created.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
A user-friendly name.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the resource.
-
#lifecycle_details ⇒ String
A message describing the current lifecycleState in more detail.
-
#lifecycle_state ⇒ String
The current state of the API.
-
#specification_type ⇒ String
Type of API Specification file.
-
#time_created ⇒ DateTime
The time this resource was created.
-
#time_updated ⇒ DateTime
The time this resource was last updated.
-
#validation_results ⇒ Array<OCI::Apigateway::Models::ApiValidationResult>
Status of each feature available from the API.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Api
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Api
Initializes the object
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/oci/apigateway/models/api.rb', line 149 def initialize(attributes = {}) return unless attributes.is_a?(Hash) self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.specification_type = attributes[:'specificationType'] if attributes[:'specificationType'] raise 'You cannot provide both :specificationType and :specification_type' if attributes.key?(:'specificationType') && attributes.key?(:'specification_type') self.specification_type = attributes[:'specification_type'] if attributes[:'specification_type'] self.validation_results = attributes[:'validationResults'] if attributes[:'validationResults'] raise 'You cannot provide both :validationResults and :validation_results' if attributes.key?(:'validationResults') && attributes.key?(:'validation_results') self.validation_results = attributes[:'validation_results'] if attributes[:'validation_results'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment in which the resource is created.
39 40 41 |
# File 'lib/oci/apigateway/models/api.rb', line 39 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: `{"CostCenter": "42"}`
92 93 94 |
# File 'lib/oci/apigateway/models/api.rb', line 92 def @defined_tags end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
Example: `My new resource`
33 34 35 |
# File 'lib/oci/apigateway/models/api.rb', line 33 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: `"Finance"`
83 84 85 |
# File 'lib/oci/apigateway/models/api.rb', line 83 def @freeform_tags end |
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the resource.
25 26 27 |
# File 'lib/oci/apigateway/models/api.rb', line 25 def id @id end |
#lifecycle_details ⇒ String
A message describing the current lifecycleState in more detail. For ACTIVE state it describes if the document has been validated and the possible values are:
-
'New' for just updated API Specifications
-
'Validating' for a document which is being validated.
-
'Valid' the document has been validated without any errors or warnings
-
'Warning' the document has been validated and contains warnings
-
'Error' the document has been validated and contains errors
-
'Failed' the document validation failed
-
'Canceled' the document validation was canceled
For other states it may provide more details like actionable information.
66 67 68 |
# File 'lib/oci/apigateway/models/api.rb', line 66 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
The current state of the API.
51 52 53 |
# File 'lib/oci/apigateway/models/api.rb', line 51 def lifecycle_state @lifecycle_state end |
#specification_type ⇒ String
Type of API Specification file.
70 71 72 |
# File 'lib/oci/apigateway/models/api.rb', line 70 def specification_type @specification_type end |
#time_created ⇒ DateTime
The time this resource was created. An RFC3339 formatted datetime string.
43 44 45 |
# File 'lib/oci/apigateway/models/api.rb', line 43 def time_created @time_created end |
#time_updated ⇒ DateTime
The time this resource was last updated. An RFC3339 formatted datetime string.
47 48 49 |
# File 'lib/oci/apigateway/models/api.rb', line 47 def time_updated @time_updated end |
#validation_results ⇒ Array<OCI::Apigateway::Models::ApiValidationResult>
Status of each feature available from the API.
74 75 76 |
# File 'lib/oci/apigateway/models/api.rb', line 74 def validation_results @validation_results end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/oci/apigateway/models/api.rb', line 95 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'specification_type': :'specificationType', 'validation_results': :'validationResults', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/oci/apigateway/models/api.rb', line 114 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'compartment_id': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'specification_type': :'String', 'validation_results': :'Array<OCI::Apigateway::Models::ApiValidationResult>', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/oci/apigateway/models/api.rb', line 235 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && compartment_id == other.compartment_id && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && specification_type == other.specification_type && validation_results == other.validation_results && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/oci/apigateway/models/api.rb', line 275 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
255 256 257 |
# File 'lib/oci/apigateway/models/api.rb', line 255 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
264 265 266 |
# File 'lib/oci/apigateway/models/api.rb', line 264 def hash [id, display_name, compartment_id, time_created, time_updated, lifecycle_state, lifecycle_details, specification_type, validation_results, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
308 309 310 311 312 313 314 315 316 317 |
# File 'lib/oci/apigateway/models/api.rb', line 308 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
302 303 304 |
# File 'lib/oci/apigateway/models/api.rb', line 302 def to_s to_hash.to_s end |