Class: OCI::Apigateway::Models::ApiSpecificationRoute
- Inherits:
-
Object
- Object
- OCI::Apigateway::Models::ApiSpecificationRoute
- Defined in:
- lib/oci/apigateway/models/api_specification_route.rb
Overview
A single route that forwards requests to a particular backend and may contain some additional policies.
Constant Summary collapse
- METHODS_ENUM =
[ METHODS_ANY = 'ANY'.freeze, METHODS_HEAD = 'HEAD'.freeze, METHODS_GET = 'GET'.freeze, METHODS_POST = 'POST'.freeze, METHODS_PUT = 'PUT'.freeze, METHODS_PATCH = 'PATCH'.freeze, METHODS_DELETE = 'DELETE'.freeze, METHODS_OPTIONS = 'OPTIONS'.freeze, METHODS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#backend ⇒ OCI::Apigateway::Models::ApiSpecificationRouteBackend
This attribute is required.
- #logging_policies ⇒ OCI::Apigateway::Models::ApiSpecificationLoggingPolicies
-
#methods ⇒ Array<String>
A list of allowed methods on this route.
-
#path ⇒ String
[Required] A URL path pattern that must be matched on this route.
- #request_policies ⇒ OCI::Apigateway::Models::ApiSpecificationRouteRequestPolicies
- #response_policies ⇒ OCI::Apigateway::Models::ApiSpecificationRouteResponsePolicies
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ApiSpecificationRoute
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ApiSpecificationRoute
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/oci/apigateway/models/api_specification_route.rb', line 88 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.path = attributes[:'path'] if attributes[:'path'] self.methods = attributes[:'methods'] if attributes[:'methods'] self.request_policies = attributes[:'requestPolicies'] if attributes[:'requestPolicies'] raise 'You cannot provide both :requestPolicies and :request_policies' if attributes.key?(:'requestPolicies') && attributes.key?(:'request_policies') self.request_policies = attributes[:'request_policies'] if attributes[:'request_policies'] self.response_policies = attributes[:'responsePolicies'] if attributes[:'responsePolicies'] raise 'You cannot provide both :responsePolicies and :response_policies' if attributes.key?(:'responsePolicies') && attributes.key?(:'response_policies') self.response_policies = attributes[:'response_policies'] if attributes[:'response_policies'] self.logging_policies = attributes[:'loggingPolicies'] if attributes[:'loggingPolicies'] raise 'You cannot provide both :loggingPolicies and :logging_policies' if attributes.key?(:'loggingPolicies') && attributes.key?(:'logging_policies') self.logging_policies = attributes[:'logging_policies'] if attributes[:'logging_policies'] self.backend = attributes[:'backend'] if attributes[:'backend'] end |
Instance Attribute Details
#backend ⇒ OCI::Apigateway::Models::ApiSpecificationRouteBackend
This attribute is required.
46 47 48 |
# File 'lib/oci/apigateway/models/api_specification_route.rb', line 46 def backend @backend end |
#logging_policies ⇒ OCI::Apigateway::Models::ApiSpecificationLoggingPolicies
42 43 44 |
# File 'lib/oci/apigateway/models/api_specification_route.rb', line 42 def logging_policies @logging_policies end |
#methods ⇒ Array<String>
A list of allowed methods on this route.
33 34 35 |
# File 'lib/oci/apigateway/models/api_specification_route.rb', line 33 def methods @methods end |
#path ⇒ String
[Required] A URL path pattern that must be matched on this route. The path pattern may contain a subset of RFC 6570 identifiers to allow wildcard and parameterized matching.
28 29 30 |
# File 'lib/oci/apigateway/models/api_specification_route.rb', line 28 def path @path end |
#request_policies ⇒ OCI::Apigateway::Models::ApiSpecificationRouteRequestPolicies
36 37 38 |
# File 'lib/oci/apigateway/models/api_specification_route.rb', line 36 def request_policies @request_policies end |
#response_policies ⇒ OCI::Apigateway::Models::ApiSpecificationRouteResponsePolicies
39 40 41 |
# File 'lib/oci/apigateway/models/api_specification_route.rb', line 39 def response_policies @response_policies end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/oci/apigateway/models/api_specification_route.rb', line 49 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'path': :'path', 'methods': :'methods', 'request_policies': :'requestPolicies', 'response_policies': :'responsePolicies', 'logging_policies': :'loggingPolicies', 'backend': :'backend' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/oci/apigateway/models/api_specification_route.rb', line 63 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'path': :'String', 'methods': :'Array<String>', 'request_policies': :'OCI::Apigateway::Models::ApiSpecificationRouteRequestPolicies', 'response_policies': :'OCI::Apigateway::Models::ApiSpecificationRouteResponsePolicies', 'logging_policies': :'OCI::Apigateway::Models::ApiSpecificationLoggingPolicies', 'backend': :'OCI::Apigateway::Models::ApiSpecificationRouteBackend' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/oci/apigateway/models/api_specification_route.rb', line 146 def ==(other) return true if equal?(other) self.class == other.class && path == other.path && methods == other.methods && request_policies == other.request_policies && response_policies == other.response_policies && logging_policies == other.logging_policies && backend == other.backend end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/oci/apigateway/models/api_specification_route.rb', line 181 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
161 162 163 |
# File 'lib/oci/apigateway/models/api_specification_route.rb', line 161 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
170 171 172 |
# File 'lib/oci/apigateway/models/api_specification_route.rb', line 170 def hash [path, methods, request_policies, response_policies, logging_policies, backend].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
214 215 216 217 218 219 220 221 222 223 |
# File 'lib/oci/apigateway/models/api_specification_route.rb', line 214 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
208 209 210 |
# File 'lib/oci/apigateway/models/api_specification_route.rb', line 208 def to_s to_hash.to_s end |