Class: OCI::Apigateway::Models::ApiSpecificationRouteRequestPolicies
- Inherits:
-
Object
- Object
- OCI::Apigateway::Models::ApiSpecificationRouteRequestPolicies
- Defined in:
- lib/oci/apigateway/models/api_specification_route_request_policies.rb
Overview
Behavior applied to any requests received by the API on this route.
Instance Attribute Summary collapse
- #authorization ⇒ OCI::Apigateway::Models::RouteAuthorizationPolicy
- #body_validation ⇒ OCI::Apigateway::Models::BodyValidationRequestPolicy
- #cors ⇒ OCI::Apigateway::Models::CorsPolicy
- #header_transformations ⇒ OCI::Apigateway::Models::HeaderTransformationPolicy
- #header_validations ⇒ OCI::Apigateway::Models::HeaderValidationRequestPolicy
- #query_parameter_transformations ⇒ OCI::Apigateway::Models::QueryParameterTransformationPolicy
- #query_parameter_validations ⇒ OCI::Apigateway::Models::QueryParameterValidationRequestPolicy
- #response_cache_lookup ⇒ OCI::Apigateway::Models::ResponseCacheLookupPolicy
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ApiSpecificationRouteRequestPolicies
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ApiSpecificationRouteRequestPolicies
Initializes the object
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/oci/apigateway/models/api_specification_route_request_policies.rb', line 81 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self. = attributes[:'authorization'] if attributes[:'authorization'] self.cors = attributes[:'cors'] if attributes[:'cors'] self.query_parameter_validations = attributes[:'queryParameterValidations'] if attributes[:'queryParameterValidations'] raise 'You cannot provide both :queryParameterValidations and :query_parameter_validations' if attributes.key?(:'queryParameterValidations') && attributes.key?(:'query_parameter_validations') self.query_parameter_validations = attributes[:'query_parameter_validations'] if attributes[:'query_parameter_validations'] self.header_validations = attributes[:'headerValidations'] if attributes[:'headerValidations'] raise 'You cannot provide both :headerValidations and :header_validations' if attributes.key?(:'headerValidations') && attributes.key?(:'header_validations') self.header_validations = attributes[:'header_validations'] if attributes[:'header_validations'] self.body_validation = attributes[:'bodyValidation'] if attributes[:'bodyValidation'] raise 'You cannot provide both :bodyValidation and :body_validation' if attributes.key?(:'bodyValidation') && attributes.key?(:'body_validation') self.body_validation = attributes[:'body_validation'] if attributes[:'body_validation'] self.header_transformations = attributes[:'headerTransformations'] if attributes[:'headerTransformations'] raise 'You cannot provide both :headerTransformations and :header_transformations' if attributes.key?(:'headerTransformations') && attributes.key?(:'header_transformations') self.header_transformations = attributes[:'header_transformations'] if attributes[:'header_transformations'] self.query_parameter_transformations = attributes[:'queryParameterTransformations'] if attributes[:'queryParameterTransformations'] raise 'You cannot provide both :queryParameterTransformations and :query_parameter_transformations' if attributes.key?(:'queryParameterTransformations') && attributes.key?(:'query_parameter_transformations') self.query_parameter_transformations = attributes[:'query_parameter_transformations'] if attributes[:'query_parameter_transformations'] self.response_cache_lookup = attributes[:'responseCacheLookup'] if attributes[:'responseCacheLookup'] raise 'You cannot provide both :responseCacheLookup and :response_cache_lookup' if attributes.key?(:'responseCacheLookup') && attributes.key?(:'response_cache_lookup') self.response_cache_lookup = attributes[:'response_cache_lookup'] if attributes[:'response_cache_lookup'] end |
Instance Attribute Details
#authorization ⇒ OCI::Apigateway::Models::RouteAuthorizationPolicy
12 13 14 |
# File 'lib/oci/apigateway/models/api_specification_route_request_policies.rb', line 12 def @authorization end |
#body_validation ⇒ OCI::Apigateway::Models::BodyValidationRequestPolicy
24 25 26 |
# File 'lib/oci/apigateway/models/api_specification_route_request_policies.rb', line 24 def body_validation @body_validation end |
#cors ⇒ OCI::Apigateway::Models::CorsPolicy
15 16 17 |
# File 'lib/oci/apigateway/models/api_specification_route_request_policies.rb', line 15 def cors @cors end |
#header_transformations ⇒ OCI::Apigateway::Models::HeaderTransformationPolicy
27 28 29 |
# File 'lib/oci/apigateway/models/api_specification_route_request_policies.rb', line 27 def header_transformations @header_transformations end |
#header_validations ⇒ OCI::Apigateway::Models::HeaderValidationRequestPolicy
21 22 23 |
# File 'lib/oci/apigateway/models/api_specification_route_request_policies.rb', line 21 def header_validations @header_validations end |
#query_parameter_transformations ⇒ OCI::Apigateway::Models::QueryParameterTransformationPolicy
30 31 32 |
# File 'lib/oci/apigateway/models/api_specification_route_request_policies.rb', line 30 def query_parameter_transformations @query_parameter_transformations end |
#query_parameter_validations ⇒ OCI::Apigateway::Models::QueryParameterValidationRequestPolicy
18 19 20 |
# File 'lib/oci/apigateway/models/api_specification_route_request_policies.rb', line 18 def query_parameter_validations @query_parameter_validations end |
#response_cache_lookup ⇒ OCI::Apigateway::Models::ResponseCacheLookupPolicy
33 34 35 |
# File 'lib/oci/apigateway/models/api_specification_route_request_policies.rb', line 33 def response_cache_lookup @response_cache_lookup end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
36 37 38 39 40 41 42 43 44 45 46 47 48 49 |
# File 'lib/oci/apigateway/models/api_specification_route_request_policies.rb', line 36 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'authorization': :'authorization', 'cors': :'cors', 'query_parameter_validations': :'queryParameterValidations', 'header_validations': :'headerValidations', 'body_validation': :'bodyValidation', 'header_transformations': :'headerTransformations', 'query_parameter_transformations': :'queryParameterTransformations', 'response_cache_lookup': :'responseCacheLookup' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/oci/apigateway/models/api_specification_route_request_policies.rb', line 52 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'authorization': :'OCI::Apigateway::Models::RouteAuthorizationPolicy', 'cors': :'OCI::Apigateway::Models::CorsPolicy', 'query_parameter_validations': :'OCI::Apigateway::Models::QueryParameterValidationRequestPolicy', 'header_validations': :'OCI::Apigateway::Models::HeaderValidationRequestPolicy', 'body_validation': :'OCI::Apigateway::Models::BodyValidationRequestPolicy', 'header_transformations': :'OCI::Apigateway::Models::HeaderTransformationPolicy', 'query_parameter_transformations': :'OCI::Apigateway::Models::QueryParameterTransformationPolicy', 'response_cache_lookup': :'OCI::Apigateway::Models::ResponseCacheLookupPolicy' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/oci/apigateway/models/api_specification_route_request_policies.rb', line 135 def ==(other) return true if equal?(other) self.class == other.class && == other. && cors == other.cors && query_parameter_validations == other.query_parameter_validations && header_validations == other.header_validations && body_validation == other.body_validation && header_transformations == other.header_transformations && query_parameter_transformations == other.query_parameter_transformations && response_cache_lookup == other.response_cache_lookup end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/oci/apigateway/models/api_specification_route_request_policies.rb', line 172 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
152 153 154 |
# File 'lib/oci/apigateway/models/api_specification_route_request_policies.rb', line 152 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
161 162 163 |
# File 'lib/oci/apigateway/models/api_specification_route_request_policies.rb', line 161 def hash [, cors, query_parameter_validations, header_validations, body_validation, header_transformations, query_parameter_transformations, response_cache_lookup].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
205 206 207 208 209 210 211 212 213 214 |
# File 'lib/oci/apigateway/models/api_specification_route_request_policies.rb', line 205 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
199 200 201 |
# File 'lib/oci/apigateway/models/api_specification_route_request_policies.rb', line 199 def to_s to_hash.to_s end |