Class: OCI::Apigateway::Models::ApiSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/apigateway/models/api_summary.rb

Overview

A summary of the API.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ApiSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/oci/apigateway/models/api_summary.rb', line 148

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.specification_type = attributes[:'specificationType'] if attributes[:'specificationType']

  raise 'You cannot provide both :specificationType and :specification_type' if attributes.key?(:'specificationType') && attributes.key?(:'specification_type')

  self.specification_type = attributes[:'specification_type'] if attributes[:'specification_type']

  self.validation_results = attributes[:'validationResults'] if attributes[:'validationResults']

  raise 'You cannot provide both :validationResults and :validation_results' if attributes.key?(:'validationResults') && attributes.key?(:'validation_results')

  self.validation_results = attributes[:'validation_results'] if attributes[:'validation_results']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#compartment_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment in which the resource is created.

Returns:

  • (String)


38
39
40
# File 'lib/oci/apigateway/models/api_summary.rb', line 38

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: `{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


91
92
93
# File 'lib/oci/apigateway/models/api_summary.rb', line 91

def defined_tags
  @defined_tags
end

#display_nameString

A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.

Example: `My new resource`

Returns:

  • (String)


32
33
34
# File 'lib/oci/apigateway/models/api_summary.rb', line 32

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: `"Finance"`

Returns:

  • (Hash<String, String>)


82
83
84
# File 'lib/oci/apigateway/models/api_summary.rb', line 82

def freeform_tags
  @freeform_tags
end

#idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the resource.

Returns:

  • (String)


24
25
26
# File 'lib/oci/apigateway/models/api_summary.rb', line 24

def id
  @id
end

#lifecycle_detailsString

A message describing the current lifecycleState in more detail. For ACTIVE state it describes if the document has been validated and the possible values are:

  • 'New' for just updated API Specifications

  • 'Validating' for a document which is being validated.

  • 'Valid' the document has been validated without any errors or warnings

  • 'Warning' the document has been validated and contains warnings

  • 'Error' the document has been validated and contains errors

  • 'Failed' the document validation failed

  • 'Canceled' the document validation was canceled

For other states it may provide more details like actionable information.

Returns:

  • (String)


65
66
67
# File 'lib/oci/apigateway/models/api_summary.rb', line 65

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

The current state of the API.

Returns:

  • (String)


50
51
52
# File 'lib/oci/apigateway/models/api_summary.rb', line 50

def lifecycle_state
  @lifecycle_state
end

#specification_typeString

Type of API Specification file.

Returns:

  • (String)


69
70
71
# File 'lib/oci/apigateway/models/api_summary.rb', line 69

def specification_type
  @specification_type
end

#time_createdDateTime

The time this resource was created. An RFC3339 formatted datetime string.

Returns:

  • (DateTime)


42
43
44
# File 'lib/oci/apigateway/models/api_summary.rb', line 42

def time_created
  @time_created
end

#time_updatedDateTime

The time this resource was last updated. An RFC3339 formatted datetime string.

Returns:

  • (DateTime)


46
47
48
# File 'lib/oci/apigateway/models/api_summary.rb', line 46

def time_updated
  @time_updated
end

#validation_resultsArray<OCI::Apigateway::Models::ApiValidationResult>

Status of each feature available from the API.



73
74
75
# File 'lib/oci/apigateway/models/api_summary.rb', line 73

def validation_results
  @validation_results
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/oci/apigateway/models/api_summary.rb', line 94

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'display_name': :'displayName',
    'compartment_id': :'compartmentId',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'specification_type': :'specificationType',
    'validation_results': :'validationResults',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/oci/apigateway/models/api_summary.rb', line 113

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'display_name': :'String',
    'compartment_id': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'specification_type': :'String',
    'validation_results': :'Array<OCI::Apigateway::Models::ApiValidationResult>',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
# File 'lib/oci/apigateway/models/api_summary.rb', line 237

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    display_name == other.display_name &&
    compartment_id == other.compartment_id &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    specification_type == other.specification_type &&
    validation_results == other.validation_results &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/oci/apigateway/models/api_summary.rb', line 277

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


257
258
259
# File 'lib/oci/apigateway/models/api_summary.rb', line 257

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



266
267
268
# File 'lib/oci/apigateway/models/api_summary.rb', line 266

def hash
  [id, display_name, compartment_id, time_created, time_updated, lifecycle_state, lifecycle_details, specification_type, validation_results, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



310
311
312
313
314
315
316
317
318
319
# File 'lib/oci/apigateway/models/api_summary.rb', line 310

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



304
305
306
# File 'lib/oci/apigateway/models/api_summary.rb', line 304

def to_s
  to_hash.to_s
end