Class: OCI::Apigateway::Models::CreateApiDetails
- Inherits:
-
Object
- Object
- OCI::Apigateway::Models::CreateApiDetails
- Defined in:
- lib/oci/apigateway/models/create_api_details.rb
Overview
Information about the new API.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment in which the resource is created.
-
#content ⇒ String
API Specification content in json or yaml format.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
A user-friendly name.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateApiDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateApiDetails
Initializes the object
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/oci/apigateway/models/create_api_details.rb', line 83 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.content = attributes[:'content'] if attributes[:'content'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment in which the resource is created.
22 23 24 |
# File 'lib/oci/apigateway/models/create_api_details.rb', line 22 def compartment_id @compartment_id end |
#content ⇒ String
API Specification content in json or yaml format
44 45 46 |
# File 'lib/oci/apigateway/models/create_api_details.rb', line 44 def content @content end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: `{"CostCenter": "42"}`
40 41 42 |
# File 'lib/oci/apigateway/models/create_api_details.rb', line 40 def @defined_tags end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
Example: `My new resource`
16 17 18 |
# File 'lib/oci/apigateway/models/create_api_details.rb', line 16 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: `"Finance"`
31 32 33 |
# File 'lib/oci/apigateway/models/create_api_details.rb', line 31 def @freeform_tags end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/oci/apigateway/models/create_api_details.rb', line 47 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'content': :'content' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/oci/apigateway/models/create_api_details.rb', line 60 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'compartment_id': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'content': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
123 124 125 126 127 128 129 130 131 132 |
# File 'lib/oci/apigateway/models/create_api_details.rb', line 123 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && compartment_id == other.compartment_id && == other. && == other. && content == other.content end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/oci/apigateway/models/create_api_details.rb', line 157 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
137 138 139 |
# File 'lib/oci/apigateway/models/create_api_details.rb', line 137 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
146 147 148 |
# File 'lib/oci/apigateway/models/create_api_details.rb', line 146 def hash [display_name, compartment_id, , , content].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
190 191 192 193 194 195 196 197 198 199 |
# File 'lib/oci/apigateway/models/create_api_details.rb', line 190 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
184 185 186 |
# File 'lib/oci/apigateway/models/create_api_details.rb', line 184 def to_s to_hash.to_s end |