Class: OCI::Apigateway::Models::CreateCertificateDetails
- Inherits:
-
Object
- Object
- OCI::Apigateway::Models::CreateCertificateDetails
- Defined in:
- lib/oci/apigateway/models/create_certificate_details.rb
Overview
Information about a new certificate.
Instance Attribute Summary collapse
-
#certificate ⇒ String
**[Required]** The data of the leaf certificate in pem format.
-
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment in which the resource is created.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
A user-friendly name.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#intermediate_certificates ⇒ String
The intermediate certificate data associated with the certificate in pem format.
-
#private_key ⇒ String
**[Required]** The private key associated with the certificate in pem format.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateCertificateDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateCertificateDetails
Initializes the object
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/oci/apigateway/models/create_certificate_details.rb', line 97 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.private_key = attributes[:'privateKey'] if attributes[:'privateKey'] raise 'You cannot provide both :privateKey and :private_key' if attributes.key?(:'privateKey') && attributes.key?(:'private_key') self.private_key = attributes[:'private_key'] if attributes[:'private_key'] self.certificate = attributes[:'certificate'] if attributes[:'certificate'] self.intermediate_certificates = attributes[:'intermediateCertificates'] if attributes[:'intermediateCertificates'] raise 'You cannot provide both :intermediateCertificates and :intermediate_certificates' if attributes.key?(:'intermediateCertificates') && attributes.key?(:'intermediate_certificates') self.intermediate_certificates = attributes[:'intermediate_certificates'] if attributes[:'intermediate_certificates'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#certificate ⇒ String
**[Required]** The data of the leaf certificate in pem format.
30 31 32 |
# File 'lib/oci/apigateway/models/create_certificate_details.rb', line 30 def certificate @certificate end |
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment in which the resource is created.
22 23 24 |
# File 'lib/oci/apigateway/models/create_certificate_details.rb', line 22 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: `{"CostCenter": "42"}`
52 53 54 |
# File 'lib/oci/apigateway/models/create_certificate_details.rb', line 52 def @defined_tags end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
Example: `My new resource`
16 17 18 |
# File 'lib/oci/apigateway/models/create_certificate_details.rb', line 16 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: `"Finance"`
43 44 45 |
# File 'lib/oci/apigateway/models/create_certificate_details.rb', line 43 def @freeform_tags end |
#intermediate_certificates ⇒ String
The intermediate certificate data associated with the certificate in pem format.
34 35 36 |
# File 'lib/oci/apigateway/models/create_certificate_details.rb', line 34 def intermediate_certificates @intermediate_certificates end |
#private_key ⇒ String
**[Required]** The private key associated with the certificate in pem format.
26 27 28 |
# File 'lib/oci/apigateway/models/create_certificate_details.rb', line 26 def private_key @private_key end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/oci/apigateway/models/create_certificate_details.rb', line 55 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'private_key': :'privateKey', 'certificate': :'certificate', 'intermediate_certificates': :'intermediateCertificates', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/oci/apigateway/models/create_certificate_details.rb', line 70 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'compartment_id': :'String', 'private_key': :'String', 'certificate': :'String', 'intermediate_certificates': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/oci/apigateway/models/create_certificate_details.rb', line 149 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && compartment_id == other.compartment_id && private_key == other.private_key && certificate == other.certificate && intermediate_certificates == other.intermediate_certificates && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/oci/apigateway/models/create_certificate_details.rb', line 185 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
165 166 167 |
# File 'lib/oci/apigateway/models/create_certificate_details.rb', line 165 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
174 175 176 |
# File 'lib/oci/apigateway/models/create_certificate_details.rb', line 174 def hash [display_name, compartment_id, private_key, certificate, intermediate_certificates, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
218 219 220 221 222 223 224 225 226 227 |
# File 'lib/oci/apigateway/models/create_certificate_details.rb', line 218 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
212 213 214 |
# File 'lib/oci/apigateway/models/create_certificate_details.rb', line 212 def to_s to_hash.to_s end |