Class: OCI::Apigateway::Models::CreateGatewayDetails
- Inherits:
-
Object
- Object
- OCI::Apigateway::Models::CreateGatewayDetails
- Defined in:
- lib/oci/apigateway/models/create_gateway_details.rb
Overview
Information about the new gateway.
Instance Attribute Summary collapse
-
#ca_bundles ⇒ Array<OCI::Apigateway::Models::CaBundle>
An array of CA bundles that should be used on the Gateway for TLS validation.
-
#certificate_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the resource.
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment in which the resource is created.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
A user-friendly name.
-
#endpoint_type ⇒ String
[Required] Gateway endpoint type.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#network_security_group_ids ⇒ Array<String>
An array of Network Security Groups OCIDs associated with this API Gateway.
- #response_cache_details ⇒ OCI::Apigateway::Models::ResponseCacheDetails
-
#subnet_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the subnet in which related resources are created.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateGatewayDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateGatewayDetails
Initializes the object
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/oci/apigateway/models/create_gateway_details.rb', line 125 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.endpoint_type = attributes[:'endpointType'] if attributes[:'endpointType'] raise 'You cannot provide both :endpointType and :endpoint_type' if attributes.key?(:'endpointType') && attributes.key?(:'endpoint_type') self.endpoint_type = attributes[:'endpoint_type'] if attributes[:'endpoint_type'] self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId'] raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id') self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id'] self.network_security_group_ids = attributes[:'networkSecurityGroupIds'] if attributes[:'networkSecurityGroupIds'] raise 'You cannot provide both :networkSecurityGroupIds and :network_security_group_ids' if attributes.key?(:'networkSecurityGroupIds') && attributes.key?(:'network_security_group_ids') self.network_security_group_ids = attributes[:'network_security_group_ids'] if attributes[:'network_security_group_ids'] self.certificate_id = attributes[:'certificateId'] if attributes[:'certificateId'] raise 'You cannot provide both :certificateId and :certificate_id' if attributes.key?(:'certificateId') && attributes.key?(:'certificate_id') self.certificate_id = attributes[:'certificate_id'] if attributes[:'certificate_id'] self.response_cache_details = attributes[:'responseCacheDetails'] if attributes[:'responseCacheDetails'] raise 'You cannot provide both :responseCacheDetails and :response_cache_details' if attributes.key?(:'responseCacheDetails') && attributes.key?(:'response_cache_details') self.response_cache_details = attributes[:'response_cache_details'] if attributes[:'response_cache_details'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.ca_bundles = attributes[:'caBundles'] if attributes[:'caBundles'] raise 'You cannot provide both :caBundles and :ca_bundles' if attributes.key?(:'caBundles') && attributes.key?(:'ca_bundles') self.ca_bundles = attributes[:'ca_bundles'] if attributes[:'ca_bundles'] end |
Instance Attribute Details
#ca_bundles ⇒ Array<OCI::Apigateway::Models::CaBundle>
An array of CA bundles that should be used on the Gateway for TLS validation.
71 72 73 |
# File 'lib/oci/apigateway/models/create_gateway_details.rb', line 71 def ca_bundles @ca_bundles end |
#certificate_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the resource.
46 47 48 |
# File 'lib/oci/apigateway/models/create_gateway_details.rb', line 46 def certificate_id @certificate_id end |
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment in which the resource is created.
22 23 24 |
# File 'lib/oci/apigateway/models/create_gateway_details.rb', line 22 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
67 68 69 |
# File 'lib/oci/apigateway/models/create_gateway_details.rb', line 67 def @defined_tags end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
Example: ‘My new resource`
16 17 18 |
# File 'lib/oci/apigateway/models/create_gateway_details.rb', line 16 def display_name @display_name end |
#endpoint_type ⇒ String
[Required] Gateway endpoint type. PUBLIC will have a public ip address assigned to it, while PRIVATE will only be accessible on a private IP address on the subnet.
Example: PUBLIC or PRIVATE
30 31 32 |
# File 'lib/oci/apigateway/models/create_gateway_details.rb', line 30 def endpoint_type @endpoint_type end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
58 59 60 |
# File 'lib/oci/apigateway/models/create_gateway_details.rb', line 58 def @freeform_tags end |
#network_security_group_ids ⇒ Array<String>
An array of Network Security Groups OCIDs associated with this API Gateway.
41 42 43 |
# File 'lib/oci/apigateway/models/create_gateway_details.rb', line 41 def network_security_group_ids @network_security_group_ids end |
#response_cache_details ⇒ OCI::Apigateway::Models::ResponseCacheDetails
49 50 51 |
# File 'lib/oci/apigateway/models/create_gateway_details.rb', line 49 def response_cache_details @response_cache_details end |
#subnet_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the subnet in which related resources are created.
36 37 38 |
# File 'lib/oci/apigateway/models/create_gateway_details.rb', line 36 def subnet_id @subnet_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/oci/apigateway/models/create_gateway_details.rb', line 74 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'endpoint_type': :'endpointType', 'subnet_id': :'subnetId', 'network_security_group_ids': :'networkSecurityGroupIds', 'certificate_id': :'certificateId', 'response_cache_details': :'responseCacheDetails', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'ca_bundles': :'caBundles' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/oci/apigateway/models/create_gateway_details.rb', line 92 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'compartment_id': :'String', 'endpoint_type': :'String', 'subnet_id': :'String', 'network_security_group_ids': :'Array<String>', 'certificate_id': :'String', 'response_cache_details': :'OCI::Apigateway::Models::ResponseCacheDetails', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'ca_bundles': :'Array<OCI::Apigateway::Models::CaBundle>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/oci/apigateway/models/create_gateway_details.rb', line 199 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && compartment_id == other.compartment_id && endpoint_type == other.endpoint_type && subnet_id == other.subnet_id && network_security_group_ids == other.network_security_group_ids && certificate_id == other.certificate_id && response_cache_details == other.response_cache_details && == other. && == other. && ca_bundles == other.ca_bundles end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 |
# File 'lib/oci/apigateway/models/create_gateway_details.rb', line 238 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
218 219 220 |
# File 'lib/oci/apigateway/models/create_gateway_details.rb', line 218 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
227 228 229 |
# File 'lib/oci/apigateway/models/create_gateway_details.rb', line 227 def hash [display_name, compartment_id, endpoint_type, subnet_id, network_security_group_ids, certificate_id, response_cache_details, , , ca_bundles].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
271 272 273 274 275 276 277 278 279 280 |
# File 'lib/oci/apigateway/models/create_gateway_details.rb', line 271 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
265 266 267 |
# File 'lib/oci/apigateway/models/create_gateway_details.rb', line 265 def to_s to_hash.to_s end |