Class: OCI::Apigateway::Models::CreateSdkDetails
- Inherits:
-
Object
- Object
- OCI::Apigateway::Models::CreateSdkDetails
- Defined in:
- lib/oci/apigateway/models/create_sdk_details.rb
Overview
Information about the new SDK.
Instance Attribute Summary collapse
-
#api_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of API resource.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
A user-friendly name.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#parameters ⇒ Hash<String, String>
Additional optional configurations that can be passed to generate SDK Api.
-
#target_language ⇒ String
[Required] The string representing the target programming language for generating the SDK.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateSdkDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateSdkDetails
Initializes the object
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/oci/apigateway/models/create_sdk_details.rb', line 94 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.target_language = attributes[:'targetLanguage'] if attributes[:'targetLanguage'] raise 'You cannot provide both :targetLanguage and :target_language' if attributes.key?(:'targetLanguage') && attributes.key?(:'target_language') self.target_language = attributes[:'target_language'] if attributes[:'target_language'] self.api_id = attributes[:'apiId'] if attributes[:'apiId'] raise 'You cannot provide both :apiId and :api_id' if attributes.key?(:'apiId') && attributes.key?(:'api_id') self.api_id = attributes[:'api_id'] if attributes[:'api_id'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.parameters = attributes[:'parameters'] if attributes[:'parameters'] end |
Instance Attribute Details
#api_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of API resource
26 27 28 |
# File 'lib/oci/apigateway/models/create_sdk_details.rb', line 26 def api_id @api_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘{\“CostCenter\”: \“42\”}`
44 45 46 |
# File 'lib/oci/apigateway/models/create_sdk_details.rb', line 44 def @defined_tags end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
Example: ‘My new resource`
16 17 18 |
# File 'lib/oci/apigateway/models/create_sdk_details.rb', line 16 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘\“Finance\”`
35 36 37 |
# File 'lib/oci/apigateway/models/create_sdk_details.rb', line 35 def @freeform_tags end |
#parameters ⇒ Hash<String, String>
Additional optional configurations that can be passed to generate SDK Api. The applicable parameters are listed under \“parameters\” when \“/sdkLanguageTypes\” is called.
Example: ‘\“configValue\”`
52 53 54 |
# File 'lib/oci/apigateway/models/create_sdk_details.rb', line 52 def parameters @parameters end |
#target_language ⇒ String
[Required] The string representing the target programming language for generating the SDK.
21 22 23 |
# File 'lib/oci/apigateway/models/create_sdk_details.rb', line 21 def target_language @target_language end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/oci/apigateway/models/create_sdk_details.rb', line 55 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'target_language': :'targetLanguage', 'api_id': :'apiId', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'parameters': :'parameters' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/oci/apigateway/models/create_sdk_details.rb', line 69 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'target_language': :'String', 'api_id': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'parameters': :'Hash<String, String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/oci/apigateway/models/create_sdk_details.rb', line 140 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && target_language == other.target_language && api_id == other.api_id && == other. && == other. && parameters == other.parameters end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/oci/apigateway/models/create_sdk_details.rb', line 175 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
155 156 157 |
# File 'lib/oci/apigateway/models/create_sdk_details.rb', line 155 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
164 165 166 |
# File 'lib/oci/apigateway/models/create_sdk_details.rb', line 164 def hash [display_name, target_language, api_id, , , parameters].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
208 209 210 211 212 213 214 215 216 217 |
# File 'lib/oci/apigateway/models/create_sdk_details.rb', line 208 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
202 203 204 |
# File 'lib/oci/apigateway/models/create_sdk_details.rb', line 202 def to_s to_hash.to_s end |