Class: OCI::Apigateway::Models::Deployment
- Inherits:
-
Object
- Object
- OCI::Apigateway::Models::Deployment
- Defined in:
- lib/oci/apigateway/models/deployment.rb
Overview
A deployment deploys an API on a gateway. Avoid entering confidential information. For more information, see [API Gateway Concepts](docs.cloud.oracle.com/iaas/Content/APIGateway/Concepts/apigatewayconcepts.htm).
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment in which the resource is created.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
A user-friendly name.
-
#endpoint ⇒ String
[Required] The endpoint to access this deployment on the gateway.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#gateway_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the resource.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the resource.
-
#lifecycle_details ⇒ String
A message describing the current state in more detail.
-
#lifecycle_state ⇒ String
The current state of the deployment.
-
#path_prefix ⇒ String
[Required] A path on which to deploy all routes contained in the API deployment specification.
- #specification ⇒ OCI::Apigateway::Models::ApiSpecification
-
#time_created ⇒ DateTime
The time this resource was created.
-
#time_updated ⇒ DateTime
The time this resource was last updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Deployment
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Deployment
Initializes the object
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/oci/apigateway/models/deployment.rb', line 161 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.gateway_id = attributes[:'gatewayId'] if attributes[:'gatewayId'] raise 'You cannot provide both :gatewayId and :gateway_id' if attributes.key?(:'gatewayId') && attributes.key?(:'gateway_id') self.gateway_id = attributes[:'gateway_id'] if attributes[:'gateway_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.path_prefix = attributes[:'pathPrefix'] if attributes[:'pathPrefix'] raise 'You cannot provide both :pathPrefix and :path_prefix' if attributes.key?(:'pathPrefix') && attributes.key?(:'path_prefix') self.path_prefix = attributes[:'path_prefix'] if attributes[:'path_prefix'] self.endpoint = attributes[:'endpoint'] if attributes[:'endpoint'] self.specification = attributes[:'specification'] if attributes[:'specification'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment in which the resource is created.
46 47 48 |
# File 'lib/oci/apigateway/models/deployment.rb', line 46 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
98 99 100 |
# File 'lib/oci/apigateway/models/deployment.rb', line 98 def end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
Example: ‘My new resource`
40 41 42 |
# File 'lib/oci/apigateway/models/deployment.rb', line 40 def display_name @display_name end |
#endpoint ⇒ String
[Required] The endpoint to access this deployment on the gateway.
58 59 60 |
# File 'lib/oci/apigateway/models/deployment.rb', line 58 def endpoint @endpoint end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
89 90 91 |
# File 'lib/oci/apigateway/models/deployment.rb', line 89 def end |
#gateway_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the resource.
32 33 34 |
# File 'lib/oci/apigateway/models/deployment.rb', line 32 def gateway_id @gateway_id end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the resource.
27 28 29 |
# File 'lib/oci/apigateway/models/deployment.rb', line 27 def id @id end |
#lifecycle_details ⇒ String
A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in a Failed state.
80 81 82 |
# File 'lib/oci/apigateway/models/deployment.rb', line 80 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
The current state of the deployment.
73 74 75 |
# File 'lib/oci/apigateway/models/deployment.rb', line 73 def lifecycle_state @lifecycle_state end |
#path_prefix ⇒ String
[Required] A path on which to deploy all routes contained in the API deployment specification. For more information, see [Deploying an API on an API Gateway by Creating an API Deployment](docs.cloud.oracle.com/iaas/Content/APIGateway/Tasks/apigatewaycreatingdeployment.htm).
54 55 56 |
# File 'lib/oci/apigateway/models/deployment.rb', line 54 def path_prefix @path_prefix end |
#specification ⇒ OCI::Apigateway::Models::ApiSpecification
61 62 63 |
# File 'lib/oci/apigateway/models/deployment.rb', line 61 def specification @specification end |
#time_created ⇒ DateTime
The time this resource was created. An RFC3339 formatted datetime string.
65 66 67 |
# File 'lib/oci/apigateway/models/deployment.rb', line 65 def time_created @time_created end |
#time_updated ⇒ DateTime
The time this resource was last updated. An RFC3339 formatted datetime string.
69 70 71 |
# File 'lib/oci/apigateway/models/deployment.rb', line 69 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/oci/apigateway/models/deployment.rb', line 101 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'gateway_id': :'gatewayId', 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'path_prefix': :'pathPrefix', 'endpoint': :'endpoint', 'specification': :'specification', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/oci/apigateway/models/deployment.rb', line 122 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'gateway_id': :'String', 'display_name': :'String', 'compartment_id': :'String', 'path_prefix': :'String', 'endpoint': :'String', 'specification': :'OCI::Apigateway::Models::ApiSpecification', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/oci/apigateway/models/deployment.rb', line 254 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && gateway_id == other.gateway_id && display_name == other.display_name && compartment_id == other.compartment_id && path_prefix == other.path_prefix && endpoint == other.endpoint && specification == other.specification && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 |
# File 'lib/oci/apigateway/models/deployment.rb', line 296 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
276 277 278 |
# File 'lib/oci/apigateway/models/deployment.rb', line 276 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
285 286 287 |
# File 'lib/oci/apigateway/models/deployment.rb', line 285 def hash [id, gateway_id, display_name, compartment_id, path_prefix, endpoint, specification, time_created, time_updated, lifecycle_state, lifecycle_details, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
329 330 331 332 333 334 335 336 337 338 |
# File 'lib/oci/apigateway/models/deployment.rb', line 329 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
323 324 325 |
# File 'lib/oci/apigateway/models/deployment.rb', line 323 def to_s to_hash.to_s end |