Class: OCI::Apigateway::Models::EntitlementSummary
- Inherits:
-
Object
- Object
- OCI::Apigateway::Models::EntitlementSummary
- Defined in:
- lib/oci/apigateway/models/entitlement_summary.rb
Overview
A summary of an entitlement included in a usage plan.
Instance Attribute Summary collapse
-
#description ⇒ String
A user-friendly description.
-
#name ⇒ String
**[Required]** An entitlement name, unique within a usage plan.
- #quota ⇒ OCI::Apigateway::Models::Quota
- #rate_limit ⇒ OCI::Apigateway::Models::RateLimit
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EntitlementSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ EntitlementSummary
Initializes the object
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/oci/apigateway/models/entitlement_summary.rb', line 62 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.rate_limit = attributes[:'rateLimit'] if attributes[:'rateLimit'] raise 'You cannot provide both :rateLimit and :rate_limit' if attributes.key?(:'rateLimit') && attributes.key?(:'rate_limit') self.rate_limit = attributes[:'rate_limit'] if attributes[:'rate_limit'] self.quota = attributes[:'quota'] if attributes[:'quota'] end |
Instance Attribute Details
#description ⇒ String
A user-friendly description. To provide some insight about the resource. Avoid entering confidential information.
20 21 22 |
# File 'lib/oci/apigateway/models/entitlement_summary.rb', line 20 def description @description end |
#name ⇒ String
**[Required]** An entitlement name, unique within a usage plan.
14 15 16 |
# File 'lib/oci/apigateway/models/entitlement_summary.rb', line 14 def name @name end |
#quota ⇒ OCI::Apigateway::Models::Quota
26 27 28 |
# File 'lib/oci/apigateway/models/entitlement_summary.rb', line 26 def quota @quota end |
#rate_limit ⇒ OCI::Apigateway::Models::RateLimit
23 24 25 |
# File 'lib/oci/apigateway/models/entitlement_summary.rb', line 23 def rate_limit @rate_limit end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 36 37 38 |
# File 'lib/oci/apigateway/models/entitlement_summary.rb', line 29 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'description': :'description', 'rate_limit': :'rateLimit', 'quota': :'quota' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
41 42 43 44 45 46 47 48 49 50 |
# File 'lib/oci/apigateway/models/entitlement_summary.rb', line 41 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'description': :'String', 'rate_limit': :'OCI::Apigateway::Models::RateLimit', 'quota': :'OCI::Apigateway::Models::Quota' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
88 89 90 91 92 93 94 95 96 |
# File 'lib/oci/apigateway/models/entitlement_summary.rb', line 88 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && description == other.description && rate_limit == other.rate_limit && quota == other.quota end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/oci/apigateway/models/entitlement_summary.rb', line 121 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
101 102 103 |
# File 'lib/oci/apigateway/models/entitlement_summary.rb', line 101 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
110 111 112 |
# File 'lib/oci/apigateway/models/entitlement_summary.rb', line 110 def hash [name, description, rate_limit, quota].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
154 155 156 157 158 159 160 161 162 163 |
# File 'lib/oci/apigateway/models/entitlement_summary.rb', line 154 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
148 149 150 |
# File 'lib/oci/apigateway/models/entitlement_summary.rb', line 148 def to_s to_hash.to_s end |