Class: OCI::Apigateway::Models::FilterHeaderPolicy
- Inherits:
-
Object
- Object
- OCI::Apigateway::Models::FilterHeaderPolicy
- Defined in:
- lib/oci/apigateway/models/filter_header_policy.rb
Overview
Filter HTTP headers as they pass through the gateway. The gateway applies filters after other transformations, so any headers set or renamed must also be listed here when using an ALLOW type policy.
Constant Summary collapse
- TYPE_ENUM =
[ TYPE_ALLOW = 'ALLOW'.freeze, TYPE_BLOCK = 'BLOCK'.freeze, TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#items ⇒ Array<OCI::Apigateway::Models::FilterHeaderPolicyItem>
[Required] The list of headers.
-
#type ⇒ String
[Required] BLOCK drops any headers that are in the list of items, so it acts as an exclusion list.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ FilterHeaderPolicy
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ FilterHeaderPolicy
Initializes the object
58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/oci/apigateway/models/filter_header_policy.rb', line 58 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.type = attributes[:'type'] if attributes[:'type'] self.type = "BLOCK" if type.nil? && !attributes.key?(:'type') # rubocop:disable Style/StringLiterals self.items = attributes[:'items'] if attributes[:'items'] end |
Instance Attribute Details
#items ⇒ Array<OCI::Apigateway::Models::FilterHeaderPolicyItem>
[Required] The list of headers.
28 29 30 |
# File 'lib/oci/apigateway/models/filter_header_policy.rb', line 28 def items @items end |
#type ⇒ String
[Required] BLOCK drops any headers that are in the list of items, so it acts as an exclusion list. ALLOW permits only the headers in the list and removes all others, so it acts as an inclusion list.
23 24 25 |
# File 'lib/oci/apigateway/models/filter_header_policy.rb', line 23 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 |
# File 'lib/oci/apigateway/models/filter_header_policy.rb', line 31 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'type': :'type', 'items': :'items' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
41 42 43 44 45 46 47 48 |
# File 'lib/oci/apigateway/models/filter_header_policy.rb', line 41 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'type': :'String', 'items': :'Array<OCI::Apigateway::Models::FilterHeaderPolicyItem>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
90 91 92 93 94 95 96 |
# File 'lib/oci/apigateway/models/filter_header_policy.rb', line 90 def ==(other) return true if equal?(other) self.class == other.class && type == other.type && items == other.items end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/oci/apigateway/models/filter_header_policy.rb', line 121 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
101 102 103 |
# File 'lib/oci/apigateway/models/filter_header_policy.rb', line 101 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
110 111 112 |
# File 'lib/oci/apigateway/models/filter_header_policy.rb', line 110 def hash [type, items].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
154 155 156 157 158 159 160 161 162 163 |
# File 'lib/oci/apigateway/models/filter_header_policy.rb', line 154 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
148 149 150 |
# File 'lib/oci/apigateway/models/filter_header_policy.rb', line 148 def to_s to_hash.to_s end |