Class: OCI::Apigateway::Models::HeaderValidationRequestPolicy
- Inherits:
-
Object
- Object
- OCI::Apigateway::Models::HeaderValidationRequestPolicy
- Defined in:
- lib/oci/apigateway/models/header_validation_request_policy.rb
Overview
Validate the HTTP headers on the incoming API requests on a specific route.
Constant Summary collapse
- VALIDATION_MODE_ENUM =
[ VALIDATION_MODE_ENFORCING = 'ENFORCING'.freeze, VALIDATION_MODE_PERMISSIVE = 'PERMISSIVE'.freeze, VALIDATION_MODE_DISABLED = 'DISABLED'.freeze ].freeze
Instance Attribute Summary collapse
- #headers ⇒ Array<OCI::Apigateway::Models::HeaderValidationItem>
-
#validation_mode ⇒ String
Validation behavior mode.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ HeaderValidationRequestPolicy
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ HeaderValidationRequestPolicy
Initializes the object
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/oci/apigateway/models/header_validation_request_policy.rb', line 60 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.headers = attributes[:'headers'] if attributes[:'headers'] self.validation_mode = attributes[:'validationMode'] if attributes[:'validationMode'] self.validation_mode = "ENFORCING" if validation_mode.nil? && !attributes.key?(:'validationMode') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :validationMode and :validation_mode' if attributes.key?(:'validationMode') && attributes.key?(:'validation_mode') self.validation_mode = attributes[:'validation_mode'] if attributes[:'validation_mode'] self.validation_mode = "ENFORCING" if validation_mode.nil? && !attributes.key?(:'validationMode') && !attributes.key?(:'validation_mode') # rubocop:disable Style/StringLiterals end |
Instance Attribute Details
#headers ⇒ Array<OCI::Apigateway::Models::HeaderValidationItem>
17 18 19 |
# File 'lib/oci/apigateway/models/header_validation_request_policy.rb', line 17 def headers @headers end |
#validation_mode ⇒ String
Validation behavior mode.
In `ENFORCING` mode, upon a validation failure, the request will be rejected with a 4xx response and not sent to the backend.
In `PERMISSIVE` mode, the result of the validation will be exposed as metrics while the request will follow the normal path.
`DISABLED` type turns the validation off.
30 31 32 |
# File 'lib/oci/apigateway/models/header_validation_request_policy.rb', line 30 def validation_mode @validation_mode end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 |
# File 'lib/oci/apigateway/models/header_validation_request_policy.rb', line 33 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'headers': :'headers', 'validation_mode': :'validationMode' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
43 44 45 46 47 48 49 50 |
# File 'lib/oci/apigateway/models/header_validation_request_policy.rb', line 43 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'headers': :'Array<OCI::Apigateway::Models::HeaderValidationItem>', 'validation_mode': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
92 93 94 95 96 97 98 |
# File 'lib/oci/apigateway/models/header_validation_request_policy.rb', line 92 def ==(other) return true if equal?(other) self.class == other.class && headers == other.headers && validation_mode == other.validation_mode end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/oci/apigateway/models/header_validation_request_policy.rb', line 123 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
103 104 105 |
# File 'lib/oci/apigateway/models/header_validation_request_policy.rb', line 103 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
112 113 114 |
# File 'lib/oci/apigateway/models/header_validation_request_policy.rb', line 112 def hash [headers, validation_mode].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
156 157 158 159 160 161 162 163 164 165 |
# File 'lib/oci/apigateway/models/header_validation_request_policy.rb', line 156 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
150 151 152 |
# File 'lib/oci/apigateway/models/header_validation_request_policy.rb', line 150 def to_s to_hash.to_s end |