Class: OCI::Apigateway::Models::QueryParameterValidationRequestPolicy
- Inherits:
-
Object
- Object
- OCI::Apigateway::Models::QueryParameterValidationRequestPolicy
- Defined in:
- lib/oci/apigateway/models/query_parameter_validation_request_policy.rb
Overview
Validate the URL query parameters on the incoming API requests on a specific route.
Constant Summary collapse
- VALIDATION_MODE_ENUM =
[ VALIDATION_MODE_ENFORCING = 'ENFORCING'.freeze, VALIDATION_MODE_PERMISSIVE = 'PERMISSIVE'.freeze, VALIDATION_MODE_DISABLED = 'DISABLED'.freeze, VALIDATION_MODE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
- #parameters ⇒ Array<OCI::Apigateway::Models::QueryParameterValidationItem>
-
#validation_mode ⇒ String
Validation behavior mode.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ QueryParameterValidationRequestPolicy
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ QueryParameterValidationRequestPolicy
Initializes the object
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/oci/apigateway/models/query_parameter_validation_request_policy.rb', line 62 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.parameters = attributes[:'parameters'] if attributes[:'parameters'] self.validation_mode = attributes[:'validationMode'] if attributes[:'validationMode'] self.validation_mode = "ENFORCING" if validation_mode.nil? && !attributes.key?(:'validationMode') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :validationMode and :validation_mode' if attributes.key?(:'validationMode') && attributes.key?(:'validation_mode') self.validation_mode = attributes[:'validation_mode'] if attributes[:'validation_mode'] self.validation_mode = "ENFORCING" if validation_mode.nil? && !attributes.key?(:'validationMode') && !attributes.key?(:'validation_mode') # rubocop:disable Style/StringLiterals end |
Instance Attribute Details
#parameters ⇒ Array<OCI::Apigateway::Models::QueryParameterValidationItem>
19 20 21 |
# File 'lib/oci/apigateway/models/query_parameter_validation_request_policy.rb', line 19 def parameters @parameters end |
#validation_mode ⇒ String
Validation behavior mode.
In `ENFORCING` mode, upon a validation failure, the request will be rejected with a 4xx response and not sent to the backend.
In `PERMISSIVE` mode, the result of the validation will be exposed as metrics while the request will follow the normal path.
`DISABLED` type turns the validation off.
32 33 34 |
# File 'lib/oci/apigateway/models/query_parameter_validation_request_policy.rb', line 32 def validation_mode @validation_mode end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 |
# File 'lib/oci/apigateway/models/query_parameter_validation_request_policy.rb', line 35 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'parameters': :'parameters', 'validation_mode': :'validationMode' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
45 46 47 48 49 50 51 52 |
# File 'lib/oci/apigateway/models/query_parameter_validation_request_policy.rb', line 45 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'parameters': :'Array<OCI::Apigateway::Models::QueryParameterValidationItem>', 'validation_mode': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
99 100 101 102 103 104 105 |
# File 'lib/oci/apigateway/models/query_parameter_validation_request_policy.rb', line 99 def ==(other) return true if equal?(other) self.class == other.class && parameters == other.parameters && validation_mode == other.validation_mode end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/oci/apigateway/models/query_parameter_validation_request_policy.rb', line 130 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
110 111 112 |
# File 'lib/oci/apigateway/models/query_parameter_validation_request_policy.rb', line 110 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
119 120 121 |
# File 'lib/oci/apigateway/models/query_parameter_validation_request_policy.rb', line 119 def hash [parameters, validation_mode].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
163 164 165 166 167 168 169 170 171 172 |
# File 'lib/oci/apigateway/models/query_parameter_validation_request_policy.rb', line 163 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
157 158 159 |
# File 'lib/oci/apigateway/models/query_parameter_validation_request_policy.rb', line 157 def to_s to_hash.to_s end |