Class: OCI::Apigateway::Models::Quota
- Inherits:
-
Object
- Object
- OCI::Apigateway::Models::Quota
- Defined in:
- lib/oci/apigateway/models/quota.rb
Overview
Quota policy for a usage plan.
Constant Summary collapse
- UNIT_ENUM =
[ UNIT_MINUTE = 'MINUTE'.freeze, UNIT_HOUR = 'HOUR'.freeze, UNIT_DAY = 'DAY'.freeze, UNIT_WEEK = 'WEEK'.freeze, UNIT_MONTH = 'MONTH'.freeze, UNIT_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- RESET_POLICY_ENUM =
[ RESET_POLICY_CALENDAR = 'CALENDAR'.freeze, RESET_POLICY_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- OPERATION_ON_BREACH_ENUM =
[ OPERATION_ON_BREACH_REJECT = 'REJECT'.freeze, OPERATION_ON_BREACH_ALLOW = 'ALLOW'.freeze, OPERATION_ON_BREACH_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#operation_on_breach ⇒ String
**[Required]** What the usage plan will do when a quota is breached: `REJECT` will allow no further requests `ALLOW` will continue to allow further requests.
-
#reset_policy ⇒ String
**[Required]** The policy that controls when quotas will reset.
-
#unit ⇒ String
**[Required]** The unit of time over which quotas are calculated.
-
#value ⇒ Integer
**[Required]** The number of requests that can be made per time period.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Quota
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Quota
Initializes the object
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/oci/apigateway/models/quota.rb', line 90 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.value = attributes[:'value'] if attributes[:'value'] self.unit = attributes[:'unit'] if attributes[:'unit'] self.reset_policy = attributes[:'resetPolicy'] if attributes[:'resetPolicy'] raise 'You cannot provide both :resetPolicy and :reset_policy' if attributes.key?(:'resetPolicy') && attributes.key?(:'reset_policy') self.reset_policy = attributes[:'reset_policy'] if attributes[:'reset_policy'] self.operation_on_breach = attributes[:'operationOnBreach'] if attributes[:'operationOnBreach'] raise 'You cannot provide both :operationOnBreach and :operation_on_breach' if attributes.key?(:'operationOnBreach') && attributes.key?(:'operation_on_breach') self.operation_on_breach = attributes[:'operation_on_breach'] if attributes[:'operation_on_breach'] end |
Instance Attribute Details
#operation_on_breach ⇒ String
**[Required]** What the usage plan will do when a quota is breached: `REJECT` will allow no further requests `ALLOW` will continue to allow further requests
54 55 56 |
# File 'lib/oci/apigateway/models/quota.rb', line 54 def operation_on_breach @operation_on_breach end |
#reset_policy ⇒ String
**[Required]** The policy that controls when quotas will reset. Example: `CALENDAR`
47 48 49 |
# File 'lib/oci/apigateway/models/quota.rb', line 47 def reset_policy @reset_policy end |
#unit ⇒ String
**[Required]** The unit of time over which quotas are calculated. Example: `MINUTE` or `MONTH`
41 42 43 |
# File 'lib/oci/apigateway/models/quota.rb', line 41 def unit @unit end |
#value ⇒ Integer
**[Required]** The number of requests that can be made per time period.
35 36 37 |
# File 'lib/oci/apigateway/models/quota.rb', line 35 def value @value end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 |
# File 'lib/oci/apigateway/models/quota.rb', line 57 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'value': :'value', 'unit': :'unit', 'reset_policy': :'resetPolicy', 'operation_on_breach': :'operationOnBreach' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
69 70 71 72 73 74 75 76 77 78 |
# File 'lib/oci/apigateway/models/quota.rb', line 69 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'value': :'Integer', 'unit': :'String', 'reset_policy': :'String', 'operation_on_breach': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
159 160 161 162 163 164 165 166 167 |
# File 'lib/oci/apigateway/models/quota.rb', line 159 def ==(other) return true if equal?(other) self.class == other.class && value == other.value && unit == other.unit && reset_policy == other.reset_policy && operation_on_breach == other.operation_on_breach end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/oci/apigateway/models/quota.rb', line 192 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
172 173 174 |
# File 'lib/oci/apigateway/models/quota.rb', line 172 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
181 182 183 |
# File 'lib/oci/apigateway/models/quota.rb', line 181 def hash [value, unit, reset_policy, operation_on_breach].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
225 226 227 228 229 230 231 232 233 234 |
# File 'lib/oci/apigateway/models/quota.rb', line 225 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
219 220 221 |
# File 'lib/oci/apigateway/models/quota.rb', line 219 def to_s to_hash.to_s end |