Class: OCI::Apigateway::Models::SetQueryParameterPolicyItem
- Inherits:
-
Object
- Object
- OCI::Apigateway::Models::SetQueryParameterPolicyItem
- Defined in:
- lib/oci/apigateway/models/set_query_parameter_policy_item.rb
Overview
Set will add a new query parameter if it was not in the original request. If the parameter already exists on the request, you can choose to override, append, or skip it.
Constant Summary collapse
- IF_EXISTS_ENUM =
[ IF_EXISTS_OVERWRITE = 'OVERWRITE'.freeze, IF_EXISTS_APPEND = 'APPEND'.freeze, IF_EXISTS_SKIP = 'SKIP'.freeze, IF_EXISTS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#if_exists ⇒ String
If a query parameter with the same name already exists in the request, OVERWRITE will overwrite the value, APPEND will append to the existing value, or SKIP will keep the existing value.
-
#name ⇒ String
[Required] The case-sensitive name of the query parameter.
-
#values ⇒ Array<String>
[Required] A list of new values.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SetQueryParameterPolicyItem
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ SetQueryParameterPolicyItem
Initializes the object
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/oci/apigateway/models/set_query_parameter_policy_item.rb', line 68 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.values = attributes[:'values'] if attributes[:'values'] self.if_exists = attributes[:'ifExists'] if attributes[:'ifExists'] self.if_exists = "OVERWRITE" if if_exists.nil? && !attributes.key?(:'ifExists') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :ifExists and :if_exists' if attributes.key?(:'ifExists') && attributes.key?(:'if_exists') self.if_exists = attributes[:'if_exists'] if attributes[:'if_exists'] self.if_exists = "OVERWRITE" if if_exists.nil? && !attributes.key?(:'ifExists') && !attributes.key?(:'if_exists') # rubocop:disable Style/StringLiterals end |
Instance Attribute Details
#if_exists ⇒ String
If a query parameter with the same name already exists in the request, OVERWRITE will overwrite the value, APPEND will append to the existing value, or SKIP will keep the existing value.
35 36 37 |
# File 'lib/oci/apigateway/models/set_query_parameter_policy_item.rb', line 35 def if_exists @if_exists end |
#name ⇒ String
[Required] The case-sensitive name of the query parameter. This name must be unique across transformation policies.
23 24 25 |
# File 'lib/oci/apigateway/models/set_query_parameter_policy_item.rb', line 23 def name @name end |
#values ⇒ Array<String>
[Required] A list of new values. Each value can be a constant or may include one or more expressions enclosed within ${} delimiters.
29 30 31 |
# File 'lib/oci/apigateway/models/set_query_parameter_policy_item.rb', line 29 def values @values end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
38 39 40 41 42 43 44 45 46 |
# File 'lib/oci/apigateway/models/set_query_parameter_policy_item.rb', line 38 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'values': :'values', 'if_exists': :'ifExists' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
49 50 51 52 53 54 55 56 57 |
# File 'lib/oci/apigateway/models/set_query_parameter_policy_item.rb', line 49 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'values': :'Array<String>', 'if_exists': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
107 108 109 110 111 112 113 114 |
# File 'lib/oci/apigateway/models/set_query_parameter_policy_item.rb', line 107 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && values == other.values && if_exists == other.if_exists end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/oci/apigateway/models/set_query_parameter_policy_item.rb', line 139 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
119 120 121 |
# File 'lib/oci/apigateway/models/set_query_parameter_policy_item.rb', line 119 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
128 129 130 |
# File 'lib/oci/apigateway/models/set_query_parameter_policy_item.rb', line 128 def hash [name, values, if_exists].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
172 173 174 175 176 177 178 179 180 181 |
# File 'lib/oci/apigateway/models/set_query_parameter_policy_item.rb', line 172 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
166 167 168 |
# File 'lib/oci/apigateway/models/set_query_parameter_policy_item.rb', line 166 def to_s to_hash.to_s end |