Class: OCI::Apigateway::Models::UpdateGatewayDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/apigateway/models/update_gateway_details.rb

Overview

The information to be updated.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateGatewayDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/oci/apigateway/models/update_gateway_details.rb', line 96

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.network_security_group_ids = attributes[:'networkSecurityGroupIds'] if attributes[:'networkSecurityGroupIds']

  raise 'You cannot provide both :networkSecurityGroupIds and :network_security_group_ids' if attributes.key?(:'networkSecurityGroupIds') && attributes.key?(:'network_security_group_ids')

  self.network_security_group_ids = attributes[:'network_security_group_ids'] if attributes[:'network_security_group_ids']

  self.certificate_id = attributes[:'certificateId'] if attributes[:'certificateId']

  raise 'You cannot provide both :certificateId and :certificate_id' if attributes.key?(:'certificateId') && attributes.key?(:'certificate_id')

  self.certificate_id = attributes[:'certificate_id'] if attributes[:'certificate_id']

  self.response_cache_details = attributes[:'responseCacheDetails'] if attributes[:'responseCacheDetails']

  raise 'You cannot provide both :responseCacheDetails and :response_cache_details' if attributes.key?(:'responseCacheDetails') && attributes.key?(:'response_cache_details')

  self.response_cache_details = attributes[:'response_cache_details'] if attributes[:'response_cache_details']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.ca_bundles = attributes[:'caBundles'] if attributes[:'caBundles']

  raise 'You cannot provide both :caBundles and :ca_bundles' if attributes.key?(:'caBundles') && attributes.key?(:'ca_bundles')

  self.ca_bundles = attributes[:'ca_bundles'] if attributes[:'ca_bundles']
end

Instance Attribute Details

#ca_bundlesArray<OCI::Apigateway::Models::CaBundle>

An array of CA bundles that should be used on the Gateway for TLS validation.



51
52
53
# File 'lib/oci/apigateway/models/update_gateway_details.rb', line 51

def ca_bundles
  @ca_bundles
end

#certificate_idString

Returns:

  • (String)


26
27
28
# File 'lib/oci/apigateway/models/update_gateway_details.rb', line 26

def certificate_id
  @certificate_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: `{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


47
48
49
# File 'lib/oci/apigateway/models/update_gateway_details.rb', line 47

def defined_tags
  @defined_tags
end

#display_nameString

A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.

Example: `My new resource`

Returns:

  • (String)


16
17
18
# File 'lib/oci/apigateway/models/update_gateway_details.rb', line 16

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: `"Finance"`

Returns:

  • (Hash<String, String>)


38
39
40
# File 'lib/oci/apigateway/models/update_gateway_details.rb', line 38

def freeform_tags
  @freeform_tags
end

#network_security_group_idsArray<String>

An array of Network Security Groups OCIDs associated with this API Gateway.

Returns:

  • (Array<String>)


21
22
23
# File 'lib/oci/apigateway/models/update_gateway_details.rb', line 21

def network_security_group_ids
  @network_security_group_ids
end

#response_cache_detailsOCI::Apigateway::Models::ResponseCacheDetails



29
30
31
# File 'lib/oci/apigateway/models/update_gateway_details.rb', line 29

def response_cache_details
  @response_cache_details
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/oci/apigateway/models/update_gateway_details.rb', line 54

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'displayName',
    'network_security_group_ids': :'networkSecurityGroupIds',
    'certificate_id': :'certificateId',
    'response_cache_details': :'responseCacheDetails',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'ca_bundles': :'caBundles'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/oci/apigateway/models/update_gateway_details.rb', line 69

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'String',
    'network_security_group_ids': :'Array<String>',
    'certificate_id': :'String',
    'response_cache_details': :'OCI::Apigateway::Models::ResponseCacheDetails',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'ca_bundles': :'Array<OCI::Apigateway::Models::CaBundle>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/oci/apigateway/models/update_gateway_details.rb', line 152

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    display_name == other.display_name &&
    network_security_group_ids == other.network_security_group_ids &&
    certificate_id == other.certificate_id &&
    response_cache_details == other.response_cache_details &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    ca_bundles == other.ca_bundles
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/oci/apigateway/models/update_gateway_details.rb', line 188

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


168
169
170
# File 'lib/oci/apigateway/models/update_gateway_details.rb', line 168

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



177
178
179
# File 'lib/oci/apigateway/models/update_gateway_details.rb', line 177

def hash
  [display_name, network_security_group_ids, certificate_id, response_cache_details, freeform_tags, defined_tags, ca_bundles].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



221
222
223
224
225
226
227
228
229
230
# File 'lib/oci/apigateway/models/update_gateway_details.rb', line 221

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



215
216
217
# File 'lib/oci/apigateway/models/update_gateway_details.rb', line 215

def to_s
  to_hash.to_s
end