Class: OCI::Apigateway::Models::ValidationRequestPolicy

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/apigateway/models/validation_request_policy.rb

Overview

Top-level validation policy mixin (not directly used).

Constant Summary collapse

VALIDATION_MODE_ENUM =
[
  VALIDATION_MODE_ENFORCING = 'ENFORCING'.freeze,
  VALIDATION_MODE_PERMISSIVE = 'PERMISSIVE'.freeze,
  VALIDATION_MODE_DISABLED = 'DISABLED'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ValidationRequestPolicy

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :validation_mode (String)

    The value to assign to the #validation_mode property



54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/oci/apigateway/models/validation_request_policy.rb', line 54

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.validation_mode = attributes[:'validationMode'] if attributes[:'validationMode']
  self.validation_mode = "ENFORCING" if validation_mode.nil? && !attributes.key?(:'validationMode') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :validationMode and :validation_mode' if attributes.key?(:'validationMode') && attributes.key?(:'validation_mode')

  self.validation_mode = attributes[:'validation_mode'] if attributes[:'validation_mode']
  self.validation_mode = "ENFORCING" if validation_mode.nil? && !attributes.key?(:'validationMode') && !attributes.key?(:'validation_mode') # rubocop:disable Style/StringLiterals
end

Instance Attribute Details

#validation_modeString

Validation behavior mode.

In ENFORCING mode, upon a validation failure, the request will be rejected with a 4xx response and not sent to the backend.

In PERMISSIVE mode, the result of the validation will be exposed as metrics while the request will follow the normal path.

DISABLED type turns the validation off.

Returns:

  • (String)


27
28
29
# File 'lib/oci/apigateway/models/validation_request_policy.rb', line 27

def validation_mode
  @validation_mode
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



30
31
32
33
34
35
36
# File 'lib/oci/apigateway/models/validation_request_policy.rb', line 30

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'validation_mode': :'validationMode'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



39
40
41
42
43
44
45
# File 'lib/oci/apigateway/models/validation_request_policy.rb', line 39

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'validation_mode': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



84
85
86
87
88
89
# File 'lib/oci/apigateway/models/validation_request_policy.rb', line 84

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    validation_mode == other.validation_mode
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/oci/apigateway/models/validation_request_policy.rb', line 114

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


94
95
96
# File 'lib/oci/apigateway/models/validation_request_policy.rb', line 94

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



103
104
105
# File 'lib/oci/apigateway/models/validation_request_policy.rb', line 103

def hash
  [validation_mode].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



147
148
149
150
151
152
153
154
155
156
# File 'lib/oci/apigateway/models/validation_request_policy.rb', line 147

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



141
142
143
# File 'lib/oci/apigateway/models/validation_request_policy.rb', line 141

def to_s
  to_hash.to_s
end