Class: OCI::ApmConfig::ConfigClient

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/apm_config/config_client.rb

Overview

Use the Application Performance Monitoring Configuration API to query and set Application Performance Monitoring configuration. For more information, see [Application Performance Monitoring](docs.oracle.com/iaas/application-performance-monitoring/index.html).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) ⇒ ConfigClient

Creates a new ConfigClient. Notes:

If a config is not specified, then the global OCI.config will be used.

This client is not thread-safe

Either a region or an endpoint must be specified.  If an endpoint is specified, it will be used instead of the
  region. A region may be specified in the config or via or the region parameter. If specified in both, then the
  region parameter will be used.

Parameters:

  • config (Config) (defaults to: nil)

    A Config object.

  • region (String) (defaults to: nil)

    A region used to determine the service endpoint. This will usually correspond to a value in Regions::REGION_ENUM, but may be an arbitrary string.

  • endpoint (String) (defaults to: nil)

    The fully qualified endpoint URL

  • signer (OCI::BaseSigner) (defaults to: nil)

    A signer implementation which can be used by this client. If this is not provided then a signer will be constructed via the provided config. One use case of this parameter is instance principals authentication, so that the instance principals signer can be provided to the client

  • proxy_settings (OCI::ApiClientProxySettings) (defaults to: nil)

    If your environment requires you to use a proxy server for outgoing HTTP requests the details for the proxy can be provided in this parameter

  • retry_config (OCI::Retry::RetryConfig) (defaults to: nil)

    The retry configuration for this service client. This represents the default retry configuration to apply across all operations. This can be overridden on a per-operation basis. The default retry configuration value is nil, which means that an operation will not perform any retries



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/oci/apm_config/config_client.rb', line 54

def initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil)
  # If the signer is an InstancePrincipalsSecurityTokenSigner or SecurityTokenSigner and no config was supplied (they are self-sufficient signers)
  # then create a dummy config to pass to the ApiClient constructor. If customers wish to create a client which uses instance principals
  # and has config (either populated programmatically or loaded from a file), they must construct that config themselves and then
  # pass it to this constructor.
  #
  # If there is no signer (or the signer is not an instance principals signer) and no config was supplied, this is not valid
  # so try and load the config from the default file.
  config = OCI::Config.validate_and_build_config_with_signer(config, signer)

  signer = OCI::Signer.config_file_auth_builder(config) if signer.nil?

  @api_client = OCI::ApiClient.new(config, signer, proxy_settings: proxy_settings)
  @retry_config = retry_config

  if endpoint
    @endpoint = endpoint + '/20210201'
  else
    region ||= config.region
    region ||= signer.region if signer.respond_to?(:region)
    self.region = region
  end
  logger.info "ConfigClient endpoint set to '#{@endpoint}'." if logger
end

Instance Attribute Details

#api_clientOCI::ApiClient (readonly)

Client used to make HTTP requests.

Returns:



14
15
16
# File 'lib/oci/apm_config/config_client.rb', line 14

def api_client
  @api_client
end

#endpointString (readonly)

Fully qualified endpoint URL

Returns:

  • (String)


18
19
20
# File 'lib/oci/apm_config/config_client.rb', line 18

def endpoint
  @endpoint
end

#regionString

The region, which will usually correspond to a value in Regions::REGION_ENUM.

Returns:

  • (String)


28
29
30
# File 'lib/oci/apm_config/config_client.rb', line 28

def region
  @region
end

#retry_configOCI::Retry::RetryConfig (readonly)

The default retry configuration to apply to all operations in this service client. This can be overridden on a per-operation basis. The default retry configuration value is nil, which means that an operation will not perform any retries



24
25
26
# File 'lib/oci/apm_config/config_client.rb', line 24

def retry_config
  @retry_config
end

Instance Method Details

#create_config(apm_domain_id, create_config_details, opts = {}) ⇒ Response

Note:

Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/apmconfig/create_config.rb.html) to see an example of how to use create_config API.

Creates a new configuration item.

Parameters:

  • apm_domain_id (String)

    The APM Domain ID the request is intended for.

  • create_config_details (OCI::ApmConfig::Models::CreateConfigDetails)

    The configuration details of the new item.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :retry_config (OCI::Retry::RetryConfig)

    The retry configuration to apply to this operation. If no key is provided then the service-level retry configuration defined by #retry_config will be used. If an explicit nil value is provided then the operation will not retry

  • :opc_retry_token (String)

    A token that uniquely identifies a request so it can be retried in case of a timeout or server error without risk of executing that same action again. Retry tokens expire after 24 hours, but can be invalidated before then due to conflicting operations. For example, if a resource has been deleted and purged from the system, then a retry of the original creation request might be rejected.

  • :opc_request_id (String)

    Unique identifier for the request. If you need to contact Oracle about a particular request, please provide the request ID.

  • :opc_dry_run (String)

    Indicates that the request is a dry run, if set to "true". A dry run request does not modify the configuration item details and is used only to perform validation on the submitted data.

    (default to false)
    

Returns:



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/oci/apm_config/config_client.rb', line 123

def create_config(apm_domain_id, create_config_details, opts = {})
  logger.debug 'Calling operation ConfigClient#create_config.' if logger

  raise "Missing the required parameter 'apm_domain_id' when calling create_config." if apm_domain_id.nil?
  raise "Missing the required parameter 'create_config_details' when calling create_config." if create_config_details.nil?

  path = '/configs'
  operation_signing_strategy = :standard

  # rubocop:disable Style/NegatedIf
  # Query Params
  query_params = {}
  query_params[:apmDomainId] = apm_domain_id

  # Header Params
  header_params = {}
  header_params[:accept] = 'application/json'
  header_params[:'content-type'] = 'application/json'
  header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token]
  header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
  header_params[:'opc-dry-run'] = opts[:opc_dry_run] if opts[:opc_dry_run]
  # rubocop:enable Style/NegatedIf
  header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token

  post_body = @api_client.object_to_http_body(create_config_details)

  # rubocop:disable Metrics/BlockLength
  OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'ConfigClient#create_config') do
    @api_client.call_api(
      :POST,
      path,
      endpoint,
      header_params: header_params,
      query_params: query_params,
      operation_signing_strategy: operation_signing_strategy,
      body: post_body,
      return_type: 'OCI::ApmConfig::Models::Config'
    )
  end
  # rubocop:enable Metrics/BlockLength
end

#delete_config(apm_domain_id, config_id, opts = {}) ⇒ Response

Note:

Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/apmconfig/delete_config.rb.html) to see an example of how to use delete_config API.

Deletes the configuration item identified by the OCID.

Parameters:

Options Hash (opts):

  • :retry_config (OCI::Retry::RetryConfig)

    The retry configuration to apply to this operation. If no key is provided then the service-level retry configuration defined by #retry_config will be used. If an explicit nil value is provided then the operation will not retry

  • :if_match (String)

    For optimistic concurrency control. In the PUT or DELETE call for a resource, set the if-match parameter to the value of the etag from a previous GET or POST response for that resource. The resource will be updated or deleted only if the etag you provide matches the resource’s current etag value.

  • :opc_request_id (String)

    Unique identifier for the request. If you need to contact Oracle about a particular request, please provide the request ID.

Returns:

  • (Response)

    A Response object with data of type nil



192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/oci/apm_config/config_client.rb', line 192

def delete_config(apm_domain_id, config_id, opts = {})
  logger.debug 'Calling operation ConfigClient#delete_config.' if logger

  raise "Missing the required parameter 'apm_domain_id' when calling delete_config." if apm_domain_id.nil?
  raise "Missing the required parameter 'config_id' when calling delete_config." if config_id.nil?
  raise "Parameter value for 'config_id' must not be blank" if OCI::Internal::Util.blank_string?(config_id)

  path = '/configs/{configId}'.sub('{configId}', config_id.to_s)
  operation_signing_strategy = :standard

  # rubocop:disable Style/NegatedIf
  # Query Params
  query_params = {}
  query_params[:apmDomainId] = apm_domain_id

  # Header Params
  header_params = {}
  header_params[:accept] = 'application/json'
  header_params[:'content-type'] = 'application/json'
  header_params[:'if-match'] = opts[:if_match] if opts[:if_match]
  header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
  # rubocop:enable Style/NegatedIf

  post_body = nil

  # rubocop:disable Metrics/BlockLength
  OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'ConfigClient#delete_config') do
    @api_client.call_api(
      :DELETE,
      path,
      endpoint,
      header_params: header_params,
      query_params: query_params,
      operation_signing_strategy: operation_signing_strategy,
      body: post_body
    )
  end
  # rubocop:enable Metrics/BlockLength
end

#get_config(apm_domain_id, config_id, opts = {}) ⇒ Response

Note:

Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/apmconfig/get_config.rb.html) to see an example of how to use get_config API.

Gets the configuration item identified by the OCID.

Parameters:

Options Hash (opts):

  • :retry_config (OCI::Retry::RetryConfig)

    The retry configuration to apply to this operation. If no key is provided then the service-level retry configuration defined by #retry_config will be used. If an explicit nil value is provided then the operation will not retry

  • :opc_request_id (String)

    Unique identifier for the request. If you need to contact Oracle about a particular request, please provide the request ID.

Returns:



253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
# File 'lib/oci/apm_config/config_client.rb', line 253

def get_config(apm_domain_id, config_id, opts = {})
  logger.debug 'Calling operation ConfigClient#get_config.' if logger

  raise "Missing the required parameter 'apm_domain_id' when calling get_config." if apm_domain_id.nil?
  raise "Missing the required parameter 'config_id' when calling get_config." if config_id.nil?
  raise "Parameter value for 'config_id' must not be blank" if OCI::Internal::Util.blank_string?(config_id)

  path = '/configs/{configId}'.sub('{configId}', config_id.to_s)
  operation_signing_strategy = :standard

  # rubocop:disable Style/NegatedIf
  # Query Params
  query_params = {}
  query_params[:apmDomainId] = apm_domain_id

  # Header Params
  header_params = {}
  header_params[:accept] = 'application/json'
  header_params[:'content-type'] = 'application/json'
  header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
  # rubocop:enable Style/NegatedIf

  post_body = nil

  # rubocop:disable Metrics/BlockLength
  OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'ConfigClient#get_config') do
    @api_client.call_api(
      :GET,
      path,
      endpoint,
      header_params: header_params,
      query_params: query_params,
      operation_signing_strategy: operation_signing_strategy,
      body: post_body,
      return_type: 'OCI::ApmConfig::Models::Config'
    )
  end
  # rubocop:enable Metrics/BlockLength
end

#list_configs(apm_domain_id, opts = {}) ⇒ Response

Note:

Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/apmconfig/list_configs.rb.html) to see an example of how to use list_configs API.

Returns all configuration items, which can optionally be filtered by configuration type.

Parameters:

  • apm_domain_id (String)

    The APM Domain ID the request is intended for.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :retry_config (OCI::Retry::RetryConfig)

    The retry configuration to apply to this operation. If no key is provided then the service-level retry configuration defined by #retry_config will be used. If an explicit nil value is provided then the operation will not retry

  • :opc_request_id (String)

    Unique identifier for the request. If you need to contact Oracle about a particular request, please provide the request ID.

  • :config_type (String)

    A filter to match configuration items of a given type. Supported values are SPAN_FILTER, METRIC_GROUP, and APDEX.

  • :display_name (String)

    A filter to return resources that match the given display name.

  • :limit (Integer)

    The maximum number of items to return. (default to 100)

  • :page (String)

    The maximum number of results per page, or items to return in a paginated "List" call. For information on how pagination works, see [List Pagination](docs.cloud.oracle.com/iaas/Content/API/Concepts/usingapi.htm#nine). Example: 50

    (default to 50)
    
  • :sort_order (String)

    The sort order to use, either ascending (ASC) or descending (DESC). The displayName sort order is case-sensitive.

    (default to ASC)
    
  • :sort_by (String)

    The field to sort by. You can provide one "sortBy" value. The default order for displayName, timeCreated and timeUpdated is ascending. The displayName sort by is case-sensitive.

    (default to displayName)
    

    Allowed values are: displayName, timeCreated, timeUpdated

Returns:



328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
# File 'lib/oci/apm_config/config_client.rb', line 328

def list_configs(apm_domain_id, opts = {})
  logger.debug 'Calling operation ConfigClient#list_configs.' if logger

  raise "Missing the required parameter 'apm_domain_id' when calling list_configs." if apm_domain_id.nil?

  if opts[:sort_order] && !OCI::ApmConfig::Models::SORT_ORDERS_ENUM.include?(opts[:sort_order])
    raise 'Invalid value for "sort_order", must be one of the values in OCI::ApmConfig::Models::SORT_ORDERS_ENUM.'
  end

  if opts[:sort_by] && !%w[displayName timeCreated timeUpdated].include?(opts[:sort_by])
    raise 'Invalid value for "sort_by", must be one of displayName, timeCreated, timeUpdated.'
  end

  path = '/configs'
  operation_signing_strategy = :standard

  # rubocop:disable Style/NegatedIf
  # Query Params
  query_params = {}
  query_params[:apmDomainId] = apm_domain_id
  query_params[:configType] = opts[:config_type] if opts[:config_type]
  query_params[:displayName] = opts[:display_name] if opts[:display_name]
  query_params[:limit] = opts[:limit] if opts[:limit]
  query_params[:page] = opts[:page] if opts[:page]
  query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order]
  query_params[:sortBy] = opts[:sort_by] if opts[:sort_by]

  # Header Params
  header_params = {}
  header_params[:accept] = 'application/json'
  header_params[:'content-type'] = 'application/json'
  header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
  # rubocop:enable Style/NegatedIf

  post_body = nil

  # rubocop:disable Metrics/BlockLength
  OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'ConfigClient#list_configs') do
    @api_client.call_api(
      :GET,
      path,
      endpoint,
      header_params: header_params,
      query_params: query_params,
      operation_signing_strategy: operation_signing_strategy,
      body: post_body,
      return_type: 'OCI::ApmConfig::Models::ConfigCollection'
    )
  end
  # rubocop:enable Metrics/BlockLength
end

#loggerLogger

Returns The logger for this client. May be nil.

Returns:

  • (Logger)

    The logger for this client. May be nil.



93
94
95
# File 'lib/oci/apm_config/config_client.rb', line 93

def logger
  @api_client.config.logger
end

#update_config(apm_domain_id, config_id, update_config_details, opts = {}) ⇒ Response

Note:

Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/apmconfig/update_config.rb.html) to see an example of how to use update_config API.

Updates the details of the configuration item identified by the OCID.

Parameters:

Options Hash (opts):

  • :retry_config (OCI::Retry::RetryConfig)

    The retry configuration to apply to this operation. If no key is provided then the service-level retry configuration defined by #retry_config will be used. If an explicit nil value is provided then the operation will not retry

  • :if_match (String)

    For optimistic concurrency control. In the PUT or DELETE call for a resource, set the if-match parameter to the value of the etag from a previous GET or POST response for that resource. The resource will be updated or deleted only if the etag you provide matches the resource’s current etag value.

  • :opc_request_id (String)

    Unique identifier for the request. If you need to contact Oracle about a particular request, please provide the request ID.

  • :opc_dry_run (String)

    Indicates that the request is a dry run, if set to "true". A dry run request does not modify the configuration item details and is used only to perform validation on the submitted data.

    (default to false)
    

Returns:



411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/oci/apm_config/config_client.rb', line 411

def update_config(apm_domain_id, config_id, update_config_details, opts = {})
  logger.debug 'Calling operation ConfigClient#update_config.' if logger

  raise "Missing the required parameter 'apm_domain_id' when calling update_config." if apm_domain_id.nil?
  raise "Missing the required parameter 'config_id' when calling update_config." if config_id.nil?
  raise "Missing the required parameter 'update_config_details' when calling update_config." if update_config_details.nil?
  raise "Parameter value for 'config_id' must not be blank" if OCI::Internal::Util.blank_string?(config_id)

  path = '/configs/{configId}'.sub('{configId}', config_id.to_s)
  operation_signing_strategy = :standard

  # rubocop:disable Style/NegatedIf
  # Query Params
  query_params = {}
  query_params[:apmDomainId] = apm_domain_id

  # Header Params
  header_params = {}
  header_params[:accept] = 'application/json'
  header_params[:'content-type'] = 'application/json'
  header_params[:'if-match'] = opts[:if_match] if opts[:if_match]
  header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
  header_params[:'opc-dry-run'] = opts[:opc_dry_run] if opts[:opc_dry_run]
  # rubocop:enable Style/NegatedIf

  post_body = @api_client.object_to_http_body(update_config_details)

  # rubocop:disable Metrics/BlockLength
  OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'ConfigClient#update_config') do
    @api_client.call_api(
      :PUT,
      path,
      endpoint,
      header_params: header_params,
      query_params: query_params,
      operation_signing_strategy: operation_signing_strategy,
      body: post_body,
      return_type: 'OCI::ApmConfig::Models::Config'
    )
  end
  # rubocop:enable Metrics/BlockLength
end