Class: OCI::ApmConfig::Models::ApdexRules
- Defined in:
- lib/oci/apm_config/models/apdex_rules.rb
Overview
The set of Apdex rules to be used in Apdex computation. In the current version, only one rule set can exist in the configuration. This may change in the future.
Constant Summary
Constants inherited from Config
Instance Attribute Summary collapse
-
#display_name ⇒ String
The name by which this rule set can be displayed to the user.
- #rules ⇒ Array<OCI::ApmConfig::Models::Apdex>
Attributes inherited from Config
#config_type, #defined_tags, #freeform_tags, #id, #time_created, #time_updated
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ApdexRules
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from Config
Constructor Details
#initialize(attributes = {}) ⇒ ApdexRules
Initializes the object
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/oci/apm_config/models/apdex_rules.rb', line 65 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['configType'] = 'APDEX' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.rules = attributes[:'rules'] if attributes[:'rules'] end |
Instance Attribute Details
#display_name ⇒ String
The name by which this rule set can be displayed to the user.
15 16 17 |
# File 'lib/oci/apm_config/models/apdex_rules.rb', line 15 def display_name @display_name end |
#rules ⇒ Array<OCI::ApmConfig::Models::Apdex>
18 19 20 |
# File 'lib/oci/apm_config/models/apdex_rules.rb', line 18 def rules @rules end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
21 22 23 24 25 26 27 28 29 30 31 32 33 34 |
# File 'lib/oci/apm_config/models/apdex_rules.rb', line 21 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'config_type': :'configType', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'display_name': :'displayName', 'rules': :'rules' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/oci/apm_config/models/apdex_rules.rb', line 37 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'config_type': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'rules': :'Array<OCI::ApmConfig::Models::Apdex>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/oci/apm_config/models/apdex_rules.rb', line 91 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && config_type == other.config_type && time_created == other.time_created && time_updated == other.time_updated && == other. && == other. && display_name == other.display_name && rules == other.rules end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/oci/apm_config/models/apdex_rules.rb', line 128 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
108 109 110 |
# File 'lib/oci/apm_config/models/apdex_rules.rb', line 108 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
117 118 119 |
# File 'lib/oci/apm_config/models/apdex_rules.rb', line 117 def hash [id, config_type, time_created, time_updated, , , display_name, rules].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
161 162 163 164 165 166 167 168 169 170 |
# File 'lib/oci/apm_config/models/apdex_rules.rb', line 161 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
155 156 157 |
# File 'lib/oci/apm_config/models/apdex_rules.rb', line 155 def to_s to_hash.to_s end |