Class: OCI::ApmConfig::Models::ConfigSummary
- Inherits:
-
Object
- Object
- OCI::ApmConfig::Models::ConfigSummary
- Defined in:
- lib/oci/apm_config/models/config_summary.rb
Overview
A description of a configuration item. It specifes all the properties that define the configuration item.
This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
ApdexRulesSummary, MetricGroupSummary, OptionsSummary, SpanFilterSummary
Constant Summary collapse
- CONFIG_TYPE_ENUM =
[ CONFIG_TYPE_SPAN_FILTER = 'SPAN_FILTER'.freeze, CONFIG_TYPE_METRIC_GROUP = 'METRIC_GROUP'.freeze, CONFIG_TYPE_APDEX = 'APDEX'.freeze, CONFIG_TYPE_OPTIONS = 'OPTIONS'.freeze, CONFIG_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#config_type ⇒ String
**[Required]** The type of configuration item.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the configuration item.
-
#time_created ⇒ DateTime
The time the resource was created, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.
-
#time_updated ⇒ DateTime
The time the resource was updated, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ConfigSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ConfigSummary
Initializes the object
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/oci/apm_config/models/config_summary.rb', line 115 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.config_type = attributes[:'configType'] if attributes[:'configType'] raise 'You cannot provide both :configType and :config_type' if attributes.key?(:'configType') && attributes.key?(:'config_type') self.config_type = attributes[:'config_type'] if attributes[:'config_type'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#config_type ⇒ String
**[Required]** The type of configuration item.
29 30 31 |
# File 'lib/oci/apm_config/models/config_summary.rb', line 29 def config_type @config_type end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
55 56 57 |
# File 'lib/oci/apm_config/models/config_summary.rb', line 55 def @defined_tags end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
49 50 51 |
# File 'lib/oci/apm_config/models/config_summary.rb', line 49 def @freeform_tags end |
#id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the configuration item. An OCID is generated when the item is created.
25 26 27 |
# File 'lib/oci/apm_config/models/config_summary.rb', line 25 def id @id end |
#time_created ⇒ DateTime
The time the resource was created, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format. Example: `2020-02-12T22:47:12.613Z`
36 37 38 |
# File 'lib/oci/apm_config/models/config_summary.rb', line 36 def time_created @time_created end |
#time_updated ⇒ DateTime
The time the resource was updated, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format. Example: `2020-02-13T22:47:12.613Z`
43 44 45 |
# File 'lib/oci/apm_config/models/config_summary.rb', line 43 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/oci/apm_config/models/config_summary.rb', line 58 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'config_type': :'configType', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/oci/apm_config/models/config_summary.rb', line 90 def self.get_subtype(object_hash) type = object_hash[:'configType'] # rubocop:disable Style/SymbolLiteral return 'OCI::ApmConfig::Models::MetricGroupSummary' if type == 'METRIC_GROUP' return 'OCI::ApmConfig::Models::ApdexRulesSummary' if type == 'APDEX' return 'OCI::ApmConfig::Models::SpanFilterSummary' if type == 'SPAN_FILTER' return 'OCI::ApmConfig::Models::OptionsSummary' if type == 'OPTIONS' # TODO: Log a warning when the subtype is not found. 'OCI::ApmConfig::Models::ConfigSummary' end |
.swagger_types ⇒ Object
Attribute type mapping.
72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/oci/apm_config/models/config_summary.rb', line 72 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'config_type': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/oci/apm_config/models/config_summary.rb', line 174 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && config_type == other.config_type && time_created == other.time_created && time_updated == other.time_updated && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/oci/apm_config/models/config_summary.rb', line 209 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
189 190 191 |
# File 'lib/oci/apm_config/models/config_summary.rb', line 189 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
198 199 200 |
# File 'lib/oci/apm_config/models/config_summary.rb', line 198 def hash [id, config_type, time_created, time_updated, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
242 243 244 245 246 247 248 249 250 251 |
# File 'lib/oci/apm_config/models/config_summary.rb', line 242 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
236 237 238 |
# File 'lib/oci/apm_config/models/config_summary.rb', line 236 def to_s to_hash.to_s end |