Class: OCI::ApmConfig::Models::CreateMetricGroupDetails
- Inherits:
-
CreateConfigDetails
- Object
- CreateConfigDetails
- OCI::ApmConfig::Models::CreateMetricGroupDetails
- Defined in:
- lib/oci/apm_config/models/create_metric_group_details.rb
Overview
A metric group defines a set of metrics to collect from a span. It uses a span filter to specify which spans to process. The set is then published to a namespace, which is a product level subdivision of metrics.
Constant Summary
Constants inherited from CreateConfigDetails
OCI::ApmConfig::Models::CreateConfigDetails::CONFIG_TYPE_ENUM
Instance Attribute Summary collapse
-
#dimensions ⇒ Array<OCI::ApmConfig::Models::Dimension>
A list of dimensions for the metric.
-
#display_name ⇒ String
[Required] The name of the metric group.
-
#filter_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of a Span Filter.
-
#metrics ⇒ Array<OCI::ApmConfig::Models::Metric>
[Required] The list of metrics in this group.
-
#namespace ⇒ String
The namespace to which the metrics are published.
Attributes inherited from CreateConfigDetails
#config_type, #defined_tags, #freeform_tags
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateMetricGroupDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from CreateConfigDetails
Constructor Details
#initialize(attributes = {}) ⇒ CreateMetricGroupDetails
Initializes the object
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/oci/apm_config/models/create_metric_group_details.rb', line 82 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['configType'] = 'METRIC_GROUP' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.filter_id = attributes[:'filterId'] if attributes[:'filterId'] raise 'You cannot provide both :filterId and :filter_id' if attributes.key?(:'filterId') && attributes.key?(:'filter_id') self.filter_id = attributes[:'filter_id'] if attributes[:'filter_id'] self.namespace = attributes[:'namespace'] if attributes[:'namespace'] self.dimensions = attributes[:'dimensions'] if attributes[:'dimensions'] self.metrics = attributes[:'metrics'] if attributes[:'metrics'] end |
Instance Attribute Details
#dimensions ⇒ Array<OCI::ApmConfig::Models::Dimension>
A list of dimensions for the metric. This variable should not be used.
30 31 32 |
# File 'lib/oci/apm_config/models/create_metric_group_details.rb', line 30 def dimensions @dimensions end |
#display_name ⇒ String
[Required] The name of the metric group.
15 16 17 |
# File 'lib/oci/apm_config/models/create_metric_group_details.rb', line 15 def display_name @display_name end |
#filter_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of a Span Filter. The filterId is mandatory for the creation of MetricGroups. A filterId is generated when a Span Filter is created.
21 22 23 |
# File 'lib/oci/apm_config/models/create_metric_group_details.rb', line 21 def filter_id @filter_id end |
#metrics ⇒ Array<OCI::ApmConfig::Models::Metric>
[Required] The list of metrics in this group.
35 36 37 |
# File 'lib/oci/apm_config/models/create_metric_group_details.rb', line 35 def metrics @metrics end |
#namespace ⇒ String
The namespace to which the metrics are published. It must be one of several predefined namespaces.
26 27 28 |
# File 'lib/oci/apm_config/models/create_metric_group_details.rb', line 26 def namespace @namespace end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
38 39 40 41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/oci/apm_config/models/create_metric_group_details.rb', line 38 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'config_type': :'configType', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'display_name': :'displayName', 'filter_id': :'filterId', 'namespace': :'namespace', 'dimensions': :'dimensions', 'metrics': :'metrics' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/oci/apm_config/models/create_metric_group_details.rb', line 54 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'config_type': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'filter_id': :'String', 'namespace': :'String', 'dimensions': :'Array<OCI::ApmConfig::Models::Dimension>', 'metrics': :'Array<OCI::ApmConfig::Models::Metric>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/oci/apm_config/models/create_metric_group_details.rb', line 118 def ==(other) return true if equal?(other) self.class == other.class && config_type == other.config_type && == other. && == other. && display_name == other.display_name && filter_id == other.filter_id && namespace == other.namespace && dimensions == other.dimensions && metrics == other.metrics end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/oci/apm_config/models/create_metric_group_details.rb', line 155 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
135 136 137 |
# File 'lib/oci/apm_config/models/create_metric_group_details.rb', line 135 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
144 145 146 |
# File 'lib/oci/apm_config/models/create_metric_group_details.rb', line 144 def hash [config_type, , , display_name, filter_id, namespace, dimensions, metrics].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
188 189 190 191 192 193 194 195 196 197 |
# File 'lib/oci/apm_config/models/create_metric_group_details.rb', line 188 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
182 183 184 |
# File 'lib/oci/apm_config/models/create_metric_group_details.rb', line 182 def to_s to_hash.to_s end |