Class: OCI::ApmConfig::Models::SpanFilter

Inherits:
Config
  • Object
show all
Defined in:
lib/oci/apm_config/models/span_filter.rb

Overview

A span filter is a named setting that specifies filter criteria to match a subset of the spans.

Constant Summary

Constants inherited from Config

Config::CONFIG_TYPE_ENUM

Instance Attribute Summary collapse

Attributes inherited from Config

#config_type, #defined_tags, #freeform_tags, #id, #time_created, #time_updated

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Config

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ SpanFilter

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id proprety

  • :time_created (DateTime)

    The value to assign to the #time_created proprety

  • :time_updated (DateTime)

    The value to assign to the #time_updated proprety

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags proprety

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags proprety

  • :display_name (String)

    The value to assign to the #display_name property

  • :filter_text (String)

    The value to assign to the #filter_text property

  • :description (String)

    The value to assign to the #description property



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/oci/apm_config/models/span_filter.rb', line 72

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['configType'] = 'SPAN_FILTER'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.filter_text = attributes[:'filterText'] if attributes[:'filterText']

  raise 'You cannot provide both :filterText and :filter_text' if attributes.key?(:'filterText') && attributes.key?(:'filter_text')

  self.filter_text = attributes[:'filter_text'] if attributes[:'filter_text']

  self.description = attributes[:'description'] if attributes[:'description']
end

Instance Attribute Details

#descriptionString

An optional string that describes what the filter is intended or used for.

Returns:



22
23
24
# File 'lib/oci/apm_config/models/span_filter.rb', line 22

def description
  @description
end

#display_nameString

The name by which this filter can be displayed in the UI.

Returns:



13
14
15
# File 'lib/oci/apm_config/models/span_filter.rb', line 13

def display_name
  @display_name
end

#filter_textString

The string that defines the Span Filter expression.

Returns:



18
19
20
# File 'lib/oci/apm_config/models/span_filter.rb', line 18

def filter_text
  @filter_text
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
# File 'lib/oci/apm_config/models/span_filter.rb', line 25

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'config_type': :'configType',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'display_name': :'displayName',
    'filter_text': :'filterText',
    'description': :'description'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
# File 'lib/oci/apm_config/models/span_filter.rb', line 42

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'config_type': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'display_name': :'String',
    'filter_text': :'String',
    'description': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • the other object to be compared



104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/oci/apm_config/models/span_filter.rb', line 104

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    config_type == other.config_type &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    display_name == other.display_name &&
    filter_text == other.filter_text &&
    description == other.description
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/oci/apm_config/models/span_filter.rb', line 142

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • the other object to be compared

Returns:

See Also:

  • `==` method


122
123
124
# File 'lib/oci/apm_config/models/span_filter.rb', line 122

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • Hash code



131
132
133
# File 'lib/oci/apm_config/models/span_filter.rb', line 131

def hash
  [id, config_type, time_created, time_updated, freeform_tags, defined_tags, display_name, filter_text, description].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



175
176
177
178
179
180
181
182
183
184
# File 'lib/oci/apm_config/models/span_filter.rb', line 175

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



169
170
171
# File 'lib/oci/apm_config/models/span_filter.rb', line 169

def to_s
  to_hash.to_s
end