Class: OCI::ApmConfig::Models::UpdateConfigDetails
- Inherits:
-
Object
- Object
- OCI::ApmConfig::Models::UpdateConfigDetails
- Defined in:
- lib/oci/apm_config/models/update_config_details.rb
Overview
The request body used to update the Configuration entity. It must specify the data to update the item with.
This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
UpdateApdexRulesDetails, UpdateMetricGroupDetails, UpdateSpanFilterDetails
Constant Summary collapse
- CONFIG_TYPE_ENUM =
[ CONFIG_TYPE_SPAN_FILTER = 'SPAN_FILTER'.freeze, CONFIG_TYPE_METRIC_GROUP = 'METRIC_GROUP'.freeze, CONFIG_TYPE_APDEX = 'APDEX'.freeze ].freeze
Instance Attribute Summary collapse
-
#config_type ⇒ String
[Required] The type of configuration item.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateConfigDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateConfigDetails
Initializes the object
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/oci/apm_config/models/update_config_details.rb', line 82 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.config_type = attributes[:'configType'] if attributes[:'configType'] raise 'You cannot provide both :configType and :config_type' if attributes.key?(:'configType') && attributes.key?(:'config_type') self.config_type = attributes[:'config_type'] if attributes[:'config_type'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#config_type ⇒ String
[Required] The type of configuration item
20 21 22 |
# File 'lib/oci/apm_config/models/update_config_details.rb', line 20 def config_type @config_type end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
32 33 34 |
# File 'lib/oci/apm_config/models/update_config_details.rb', line 32 def end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`
26 27 28 |
# File 'lib/oci/apm_config/models/update_config_details.rb', line 26 def end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 |
# File 'lib/oci/apm_config/models/update_config_details.rb', line 35 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'config_type': :'configType', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
61 62 63 64 65 66 67 68 69 70 |
# File 'lib/oci/apm_config/models/update_config_details.rb', line 61 def self.get_subtype(object_hash) type = object_hash[:'configType'] # rubocop:disable Style/SymbolLiteral return 'OCI::ApmConfig::Models::UpdateMetricGroupDetails' if type == 'METRIC_GROUP' return 'OCI::ApmConfig::Models::UpdateApdexRulesDetails' if type == 'APDEX' return 'OCI::ApmConfig::Models::UpdateSpanFilterDetails' if type == 'SPAN_FILTER' # TODO: Log a warning when the subtype is not found. 'OCI::ApmConfig::Models::UpdateConfigDetails' end |
.swagger_types ⇒ Object
Attribute type mapping.
46 47 48 49 50 51 52 53 54 |
# File 'lib/oci/apm_config/models/update_config_details.rb', line 46 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'config_type': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
122 123 124 125 126 127 128 129 |
# File 'lib/oci/apm_config/models/update_config_details.rb', line 122 def ==(other) return true if equal?(other) self.class == other.class && config_type == other.config_type && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/oci/apm_config/models/update_config_details.rb', line 154 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
134 135 136 |
# File 'lib/oci/apm_config/models/update_config_details.rb', line 134 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
143 144 145 |
# File 'lib/oci/apm_config/models/update_config_details.rb', line 143 def hash [config_type, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
187 188 189 190 191 192 193 194 195 196 |
# File 'lib/oci/apm_config/models/update_config_details.rb', line 187 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
181 182 183 |
# File 'lib/oci/apm_config/models/update_config_details.rb', line 181 def to_s to_hash.to_s end |