Class: OCI::ApmControlPlane::Models::ApmDomain
- Inherits:
-
Object
- Object
- OCI::ApmControlPlane::Models::ApmDomain
- Defined in:
- lib/oci/apm_control_plane/models/apm_domain.rb
Overview
Details of an APM Domain.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The OCID of the compartment corresponding to the APM Domain.
-
#data_upload_endpoint ⇒ String
Where APM Agents upload their observations and metrics.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
Description of the APM Domain.
-
#display_name ⇒ String
[Required] APM Domain display name, can be updated.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
[Required] Unique identifier that is immutable on creation.
-
#is_free_tier ⇒ BOOLEAN
Indicates if this is an Always Free resource.
-
#lifecycle_state ⇒ String
The current lifecycle state of the APM Domain.
-
#time_created ⇒ DateTime
The time the the APM Domain was created.
-
#time_updated ⇒ DateTime
The time the APM Domain was updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ApmDomain
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ApmDomain
Initializes the object
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/oci/apm_control_plane/models/apm_domain.rb', line 123 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.data_upload_endpoint = attributes[:'dataUploadEndpoint'] if attributes[:'dataUploadEndpoint'] raise 'You cannot provide both :dataUploadEndpoint and :data_upload_endpoint' if attributes.key?(:'dataUploadEndpoint') && attributes.key?(:'data_upload_endpoint') self.data_upload_endpoint = attributes[:'data_upload_endpoint'] if attributes[:'data_upload_endpoint'] self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.is_free_tier = attributes[:'isFreeTier'] unless attributes[:'isFreeTier'].nil? raise 'You cannot provide both :isFreeTier and :is_free_tier' if attributes.key?(:'isFreeTier') && attributes.key?(:'is_free_tier') self.is_free_tier = attributes[:'is_free_tier'] unless attributes[:'is_free_tier'].nil? self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The OCID of the compartment corresponding to the APM Domain.
38 39 40 |
# File 'lib/oci/apm_control_plane/models/apm_domain.rb', line 38 def compartment_id @compartment_id end |
#data_upload_endpoint ⇒ String
Where APM Agents upload their observations and metrics.
22 23 24 |
# File 'lib/oci/apm_control_plane/models/apm_domain.rb', line 22 def data_upload_endpoint @data_upload_endpoint end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
66 67 68 |
# File 'lib/oci/apm_control_plane/models/apm_domain.rb', line 66 def end |
#description ⇒ String
Description of the APM Domain.
34 35 36 |
# File 'lib/oci/apm_control_plane/models/apm_domain.rb', line 34 def description @description end |
#display_name ⇒ String
[Required] APM Domain display name, can be updated.
30 31 32 |
# File 'lib/oci/apm_control_plane/models/apm_domain.rb', line 30 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`
60 61 62 |
# File 'lib/oci/apm_control_plane/models/apm_domain.rb', line 60 def end |
#id ⇒ String
[Required] Unique identifier that is immutable on creation.
26 27 28 |
# File 'lib/oci/apm_control_plane/models/apm_domain.rb', line 26 def id @id end |
#is_free_tier ⇒ BOOLEAN
Indicates if this is an Always Free resource.
46 47 48 |
# File 'lib/oci/apm_control_plane/models/apm_domain.rb', line 46 def is_free_tier @is_free_tier end |
#lifecycle_state ⇒ String
The current lifecycle state of the APM Domain.
42 43 44 |
# File 'lib/oci/apm_control_plane/models/apm_domain.rb', line 42 def lifecycle_state @lifecycle_state end |
#time_created ⇒ DateTime
The time the the APM Domain was created. An RFC3339 formatted datetime string
50 51 52 |
# File 'lib/oci/apm_control_plane/models/apm_domain.rb', line 50 def time_created @time_created end |
#time_updated ⇒ DateTime
The time the APM Domain was updated. An RFC3339 formatted datetime string
54 55 56 |
# File 'lib/oci/apm_control_plane/models/apm_domain.rb', line 54 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/oci/apm_control_plane/models/apm_domain.rb', line 69 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'data_upload_endpoint': :'dataUploadEndpoint', 'id': :'id', 'display_name': :'displayName', 'description': :'description', 'compartment_id': :'compartmentId', 'lifecycle_state': :'lifecycleState', 'is_free_tier': :'isFreeTier', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/oci/apm_control_plane/models/apm_domain.rb', line 88 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'data_upload_endpoint': :'String', 'id': :'String', 'display_name': :'String', 'description': :'String', 'compartment_id': :'String', 'lifecycle_state': :'String', 'is_free_tier': :'BOOLEAN', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/oci/apm_control_plane/models/apm_domain.rb', line 208 def ==(other) return true if equal?(other) self.class == other.class && data_upload_endpoint == other.data_upload_endpoint && id == other.id && display_name == other.display_name && description == other.description && compartment_id == other.compartment_id && lifecycle_state == other.lifecycle_state && is_free_tier == other.is_free_tier && time_created == other.time_created && time_updated == other.time_updated && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/oci/apm_control_plane/models/apm_domain.rb', line 248 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
228 229 230 |
# File 'lib/oci/apm_control_plane/models/apm_domain.rb', line 228 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
237 238 239 |
# File 'lib/oci/apm_control_plane/models/apm_domain.rb', line 237 def hash [data_upload_endpoint, id, display_name, description, compartment_id, lifecycle_state, is_free_tier, time_created, time_updated, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
281 282 283 284 285 286 287 288 289 290 |
# File 'lib/oci/apm_control_plane/models/apm_domain.rb', line 281 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
275 276 277 |
# File 'lib/oci/apm_control_plane/models/apm_domain.rb', line 275 def to_s to_hash.to_s end |