Class: OCI::ApmControlPlane::Models::WorkRequestResource

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/apm_control_plane/models/work_request_resource.rb

Overview

A resource created or operated on by a work request.

Constant Summary collapse

ACTION_TYPE_ENUM =
[
  ACTION_TYPE_CREATED = 'CREATED'.freeze,
  ACTION_TYPE_UPDATED = 'UPDATED'.freeze,
  ACTION_TYPE_DELETED = 'DELETED'.freeze,
  ACTION_TYPE_IN_PROGRESS = 'IN_PROGRESS'.freeze,
  ACTION_TYPE_RELATED = 'RELATED'.freeze,
  ACTION_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ WorkRequestResource

Initializes the object

Options Hash (attributes):

  • :entity_type (String)

    The value to assign to the #entity_type property

  • :action_type (String)

    The value to assign to the #action_type property

  • :identifier (String)

    The value to assign to the #identifier property

  • :entity_uri (String)

    The value to assign to the #entity_uri property

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/oci/apm_control_plane/models/work_request_resource.rb', line 74

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.entity_type = attributes[:'entityType'] if attributes[:'entityType']

  raise 'You cannot provide both :entityType and :entity_type' if attributes.key?(:'entityType') && attributes.key?(:'entity_type')

  self.entity_type = attributes[:'entity_type'] if attributes[:'entity_type']

  self.action_type = attributes[:'actionType'] if attributes[:'actionType']

  raise 'You cannot provide both :actionType and :action_type' if attributes.key?(:'actionType') && attributes.key?(:'action_type')

  self.action_type = attributes[:'action_type'] if attributes[:'action_type']

  self.identifier = attributes[:'identifier'] if attributes[:'identifier']

  self.entity_uri = attributes[:'entityUri'] if attributes[:'entityUri']

  raise 'You cannot provide both :entityUri and :entity_uri' if attributes.key?(:'entityUri') && attributes.key?(:'entity_uri')

  self.entity_uri = attributes[:'entity_uri'] if attributes[:'entity_uri']
end

Instance Attribute Details

#action_typeString

[Required] The way in which this resource is affected by the work tracked in the work request. A resource being created, updated, or deleted will remain in the IN_PROGRESS state until work is complete for that resource at which point it will transition to CREATED, UPDATED, or DELETED, respectively.

Returns:



30
31
32
# File 'lib/oci/apm_control_plane/models/work_request_resource.rb', line 30

def action_type
  @action_type
end

#entity_typeString

[Required] The resource type the work request affects.

Returns:



22
23
24
# File 'lib/oci/apm_control_plane/models/work_request_resource.rb', line 22

def entity_type
  @entity_type
end

#entity_uriString

The URI path that the user can do a GET on to access the resource metadata

Returns:



38
39
40
# File 'lib/oci/apm_control_plane/models/work_request_resource.rb', line 38

def entity_uri
  @entity_uri
end

#identifierString

[Required] The identifier of the resource the work request affects.

Returns:



34
35
36
# File 'lib/oci/apm_control_plane/models/work_request_resource.rb', line 34

def identifier
  @identifier
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



41
42
43
44
45
46
47
48
49
50
# File 'lib/oci/apm_control_plane/models/work_request_resource.rb', line 41

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'entity_type': :'entityType',
    'action_type': :'actionType',
    'identifier': :'identifier',
    'entity_uri': :'entityUri'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



53
54
55
56
57
58
59
60
61
62
# File 'lib/oci/apm_control_plane/models/work_request_resource.rb', line 53

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'entity_type': :'String',
    'action_type': :'String',
    'identifier': :'String',
    'entity_uri': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • the other object to be compared



121
122
123
124
125
126
127
128
129
# File 'lib/oci/apm_control_plane/models/work_request_resource.rb', line 121

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    entity_type == other.entity_type &&
    action_type == other.action_type &&
    identifier == other.identifier &&
    entity_uri == other.entity_uri
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
# File 'lib/oci/apm_control_plane/models/work_request_resource.rb', line 154

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method

Parameters:

  • the other object to be compared

Returns:



134
135
136
# File 'lib/oci/apm_control_plane/models/work_request_resource.rb', line 134

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • Hash code



143
144
145
# File 'lib/oci/apm_control_plane/models/work_request_resource.rb', line 143

def hash
  [entity_type, action_type, identifier, entity_uri].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



187
188
189
190
191
192
193
194
195
196
# File 'lib/oci/apm_control_plane/models/work_request_resource.rb', line 187

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



181
182
183
# File 'lib/oci/apm_control_plane/models/work_request_resource.rb', line 181

def to_s
  to_hash.to_s
end