Class: OCI::ApmSynthetics::ApmSyntheticClient
- Inherits:
-
Object
- Object
- OCI::ApmSynthetics::ApmSyntheticClient
- Defined in:
- lib/oci/apm_synthetics/apm_synthetic_client.rb
Overview
Use the Application Performance Monitoring Synthetic Monitoring API to query synthetic scripts and monitors. For more information, see [Application Performance Monitoring](docs.oracle.com/iaas/application-performance-monitoring/index.html).
Instance Attribute Summary collapse
-
#api_client ⇒ OCI::ApiClient
readonly
Client used to make HTTP requests.
-
#endpoint ⇒ String
readonly
Fully qualified endpoint URL.
-
#region ⇒ String
The region, which will usually correspond to a value in Regions::REGION_ENUM.
-
#retry_config ⇒ OCI::Retry::RetryConfig
readonly
The default retry configuration to apply to all operations in this service client.
Instance Method Summary collapse
-
#create_dedicated_vantage_point(apm_domain_id, create_dedicated_vantage_point_details, opts = {}) ⇒ Response
Registers a new dedicated vantage point.
-
#create_monitor(apm_domain_id, create_monitor_details, opts = {}) ⇒ Response
Creates a new monitor.
-
#create_script(apm_domain_id, create_script_details, opts = {}) ⇒ Response
Creates a new script.
-
#delete_dedicated_vantage_point(apm_domain_id, dedicated_vantage_point_id, opts = {}) ⇒ Response
Deregisters the specified dedicated vantage point.
-
#delete_monitor(apm_domain_id, monitor_id, opts = {}) ⇒ Response
Deletes the specified monitor.
-
#delete_script(apm_domain_id, script_id, opts = {}) ⇒ Response
Deletes the specified script.
-
#get_dedicated_vantage_point(apm_domain_id, dedicated_vantage_point_id, opts = {}) ⇒ Response
Gets the details of the dedicated vantage point identified by the OCID.
-
#get_monitor(apm_domain_id, monitor_id, opts = {}) ⇒ Response
Gets the configuration of the monitor identified by the OCID.
-
#get_monitor_result(apm_domain_id, monitor_id, vantage_point, result_type, result_content_type, execution_time, opts = {}) ⇒ Response
Gets the results for a specific execution of a monitor identified by OCID.
-
#get_script(apm_domain_id, script_id, opts = {}) ⇒ Response
Gets the configuration of the script identified by the OCID.
-
#initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) ⇒ ApmSyntheticClient
constructor
Creates a new ApmSyntheticClient.
-
#list_dedicated_vantage_points(apm_domain_id, opts = {}) ⇒ Response
Returns a list of dedicated vantage points.
-
#list_monitors(apm_domain_id, opts = {}) ⇒ Response
Returns a list of monitors.
-
#list_public_vantage_points(apm_domain_id, opts = {}) ⇒ Response
Returns a list of public vantage points.
-
#list_scripts(apm_domain_id, opts = {}) ⇒ Response
Returns a list of scripts.
-
#logger ⇒ Logger
The logger for this client.
-
#update_dedicated_vantage_point(apm_domain_id, dedicated_vantage_point_id, update_dedicated_vantage_point_details, opts = {}) ⇒ Response
Updates the dedicated vantage point.
-
#update_monitor(apm_domain_id, monitor_id, update_monitor_details, opts = {}) ⇒ Response
Updates the monitor.
-
#update_script(apm_domain_id, script_id, update_script_details, opts = {}) ⇒ Response
Updates the script.
Constructor Details
#initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) ⇒ ApmSyntheticClient
Creates a new ApmSyntheticClient. Notes:
If a config is not specified, then the global OCI.config will be used.
This client is not thread-safe
Either a region or an endpoint must be specified. If an endpoint is specified, it will be used instead of the
region. A region may be specified in the config or via or the region parameter. If specified in both, then the
region parameter will be used.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/oci/apm_synthetics/apm_synthetic_client.rb', line 53 def initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) # If the signer is an InstancePrincipalsSecurityTokenSigner or SecurityTokenSigner and no config was supplied (they are self-sufficient signers) # then create a dummy config to pass to the ApiClient constructor. If customers wish to create a client which uses instance principals # and has config (either populated programmatically or loaded from a file), they must construct that config themselves and then # pass it to this constructor. # # If there is no signer (or the signer is not an instance principals signer) and no config was supplied, this is not valid # so try and load the config from the default file. config = OCI::Config.validate_and_build_config_with_signer(config, signer) signer = OCI::Signer.config_file_auth_builder(config) if signer.nil? @api_client = OCI::ApiClient.new(config, signer, proxy_settings: proxy_settings) @retry_config = retry_config if endpoint @endpoint = endpoint + '/20200630' else region ||= config.region region ||= signer.region if signer.respond_to?(:region) self.region = region end logger.info "ApmSyntheticClient endpoint set to '#{@endpoint}'." if logger end |
Instance Attribute Details
#api_client ⇒ OCI::ApiClient (readonly)
Client used to make HTTP requests.
13 14 15 |
# File 'lib/oci/apm_synthetics/apm_synthetic_client.rb', line 13 def api_client @api_client end |
#endpoint ⇒ String (readonly)
Fully qualified endpoint URL
17 18 19 |
# File 'lib/oci/apm_synthetics/apm_synthetic_client.rb', line 17 def endpoint @endpoint end |
#region ⇒ String
The region, which will usually correspond to a value in Regions::REGION_ENUM.
27 28 29 |
# File 'lib/oci/apm_synthetics/apm_synthetic_client.rb', line 27 def region @region end |
#retry_config ⇒ OCI::Retry::RetryConfig (readonly)
The default retry configuration to apply to all operations in this service client. This can be overridden on a per-operation basis. The default retry configuration value is `nil`, which means that an operation will not perform any retries
23 24 25 |
# File 'lib/oci/apm_synthetics/apm_synthetic_client.rb', line 23 def retry_config @retry_config end |
Instance Method Details
#create_dedicated_vantage_point(apm_domain_id, create_dedicated_vantage_point_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/apmsynthetics/create_dedicated_vantage_point.rb.html) to see an example of how to use create_dedicated_vantage_point API.
Registers a new dedicated vantage point.
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/oci/apm_synthetics/apm_synthetic_client.rb', line 120 def create_dedicated_vantage_point(apm_domain_id, create_dedicated_vantage_point_details, opts = {}) logger.debug 'Calling operation ApmSyntheticClient#create_dedicated_vantage_point.' if logger raise "Missing the required parameter 'apm_domain_id' when calling create_dedicated_vantage_point." if apm_domain_id.nil? raise "Missing the required parameter 'create_dedicated_vantage_point_details' when calling create_dedicated_vantage_point." if create_dedicated_vantage_point_details.nil? path = '/dedicatedVantagePoints' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:apmDomainId] = apm_domain_id # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = @api_client.object_to_http_body(create_dedicated_vantage_point_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ApmSyntheticClient#create_dedicated_vantage_point') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::ApmSynthetics::Models::DedicatedVantagePoint' ) end # rubocop:enable Metrics/BlockLength end |
#create_monitor(apm_domain_id, create_monitor_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/apmsynthetics/create_monitor.rb.html) to see an example of how to use create_monitor API.
Creates a new monitor.
188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/oci/apm_synthetics/apm_synthetic_client.rb', line 188 def create_monitor(apm_domain_id, create_monitor_details, opts = {}) logger.debug 'Calling operation ApmSyntheticClient#create_monitor.' if logger raise "Missing the required parameter 'apm_domain_id' when calling create_monitor." if apm_domain_id.nil? raise "Missing the required parameter 'create_monitor_details' when calling create_monitor." if create_monitor_details.nil? path = '/monitors' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:apmDomainId] = apm_domain_id # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = @api_client.object_to_http_body(create_monitor_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ApmSyntheticClient#create_monitor') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::ApmSynthetics::Models::Monitor' ) end # rubocop:enable Metrics/BlockLength end |
#create_script(apm_domain_id, create_script_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/apmsynthetics/create_script.rb.html) to see an example of how to use create_script API.
Creates a new script.
256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/oci/apm_synthetics/apm_synthetic_client.rb', line 256 def create_script(apm_domain_id, create_script_details, opts = {}) logger.debug 'Calling operation ApmSyntheticClient#create_script.' if logger raise "Missing the required parameter 'apm_domain_id' when calling create_script." if apm_domain_id.nil? raise "Missing the required parameter 'create_script_details' when calling create_script." if create_script_details.nil? path = '/scripts' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:apmDomainId] = apm_domain_id # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = @api_client.object_to_http_body(create_script_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ApmSyntheticClient#create_script') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::ApmSynthetics::Models::Script' ) end # rubocop:enable Metrics/BlockLength end |
#delete_dedicated_vantage_point(apm_domain_id, dedicated_vantage_point_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/apmsynthetics/delete_dedicated_vantage_point.rb.html) to see an example of how to use delete_dedicated_vantage_point API.
Deregisters the specified dedicated vantage point.
323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 |
# File 'lib/oci/apm_synthetics/apm_synthetic_client.rb', line 323 def delete_dedicated_vantage_point(apm_domain_id, dedicated_vantage_point_id, opts = {}) logger.debug 'Calling operation ApmSyntheticClient#delete_dedicated_vantage_point.' if logger raise "Missing the required parameter 'apm_domain_id' when calling delete_dedicated_vantage_point." if apm_domain_id.nil? raise "Missing the required parameter 'dedicated_vantage_point_id' when calling delete_dedicated_vantage_point." if dedicated_vantage_point_id.nil? raise "Parameter value for 'dedicated_vantage_point_id' must not be blank" if OCI::Internal::Util.blank_string?(dedicated_vantage_point_id) path = '/dedicatedVantagePoints/{dedicatedVantagePointId}'.sub('{dedicatedVantagePointId}', dedicated_vantage_point_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:apmDomainId] = apm_domain_id # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ApmSyntheticClient#delete_dedicated_vantage_point') do @api_client.call_api( :DELETE, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#delete_monitor(apm_domain_id, monitor_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/apmsynthetics/delete_monitor.rb.html) to see an example of how to use delete_monitor API.
Deletes the specified monitor.
389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 |
# File 'lib/oci/apm_synthetics/apm_synthetic_client.rb', line 389 def delete_monitor(apm_domain_id, monitor_id, opts = {}) logger.debug 'Calling operation ApmSyntheticClient#delete_monitor.' if logger raise "Missing the required parameter 'apm_domain_id' when calling delete_monitor." if apm_domain_id.nil? raise "Missing the required parameter 'monitor_id' when calling delete_monitor." if monitor_id.nil? raise "Parameter value for 'monitor_id' must not be blank" if OCI::Internal::Util.blank_string?(monitor_id) path = '/monitors/{monitorId}'.sub('{monitorId}', monitor_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:apmDomainId] = apm_domain_id # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ApmSyntheticClient#delete_monitor') do @api_client.call_api( :DELETE, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#delete_script(apm_domain_id, script_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/apmsynthetics/delete_script.rb.html) to see an example of how to use delete_script API.
Deletes the specified script.
455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 |
# File 'lib/oci/apm_synthetics/apm_synthetic_client.rb', line 455 def delete_script(apm_domain_id, script_id, opts = {}) logger.debug 'Calling operation ApmSyntheticClient#delete_script.' if logger raise "Missing the required parameter 'apm_domain_id' when calling delete_script." if apm_domain_id.nil? raise "Missing the required parameter 'script_id' when calling delete_script." if script_id.nil? raise "Parameter value for 'script_id' must not be blank" if OCI::Internal::Util.blank_string?(script_id) path = '/scripts/{scriptId}'.sub('{scriptId}', script_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:apmDomainId] = apm_domain_id # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ApmSyntheticClient#delete_script') do @api_client.call_api( :DELETE, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#get_dedicated_vantage_point(apm_domain_id, dedicated_vantage_point_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/apmsynthetics/get_dedicated_vantage_point.rb.html) to see an example of how to use get_dedicated_vantage_point API.
Gets the details of the dedicated vantage point identified by the OCID.
515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 |
# File 'lib/oci/apm_synthetics/apm_synthetic_client.rb', line 515 def get_dedicated_vantage_point(apm_domain_id, dedicated_vantage_point_id, opts = {}) logger.debug 'Calling operation ApmSyntheticClient#get_dedicated_vantage_point.' if logger raise "Missing the required parameter 'apm_domain_id' when calling get_dedicated_vantage_point." if apm_domain_id.nil? raise "Missing the required parameter 'dedicated_vantage_point_id' when calling get_dedicated_vantage_point." if dedicated_vantage_point_id.nil? raise "Parameter value for 'dedicated_vantage_point_id' must not be blank" if OCI::Internal::Util.blank_string?(dedicated_vantage_point_id) path = '/dedicatedVantagePoints/{dedicatedVantagePointId}'.sub('{dedicatedVantagePointId}', dedicated_vantage_point_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:apmDomainId] = apm_domain_id # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ApmSyntheticClient#get_dedicated_vantage_point') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::ApmSynthetics::Models::DedicatedVantagePoint' ) end # rubocop:enable Metrics/BlockLength end |
#get_monitor(apm_domain_id, monitor_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/apmsynthetics/get_monitor.rb.html) to see an example of how to use get_monitor API.
Gets the configuration of the monitor identified by the OCID.
575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 |
# File 'lib/oci/apm_synthetics/apm_synthetic_client.rb', line 575 def get_monitor(apm_domain_id, monitor_id, opts = {}) logger.debug 'Calling operation ApmSyntheticClient#get_monitor.' if logger raise "Missing the required parameter 'apm_domain_id' when calling get_monitor." if apm_domain_id.nil? raise "Missing the required parameter 'monitor_id' when calling get_monitor." if monitor_id.nil? raise "Parameter value for 'monitor_id' must not be blank" if OCI::Internal::Util.blank_string?(monitor_id) path = '/monitors/{monitorId}'.sub('{monitorId}', monitor_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:apmDomainId] = apm_domain_id # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ApmSyntheticClient#get_monitor') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::ApmSynthetics::Models::Monitor' ) end # rubocop:enable Metrics/BlockLength end |
#get_monitor_result(apm_domain_id, monitor_id, vantage_point, result_type, result_content_type, execution_time, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/apmsynthetics/get_monitor_result.rb.html) to see an example of how to use get_monitor_result API.
Gets the results for a specific execution of a monitor identified by OCID. The results are in a HAR file, Screenshot, Console Log or Network details.
644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 |
# File 'lib/oci/apm_synthetics/apm_synthetic_client.rb', line 644 def get_monitor_result(apm_domain_id, monitor_id, vantage_point, result_type, result_content_type, execution_time, opts = {}) logger.debug 'Calling operation ApmSyntheticClient#get_monitor_result.' if logger raise "Missing the required parameter 'apm_domain_id' when calling get_monitor_result." if apm_domain_id.nil? raise "Missing the required parameter 'monitor_id' when calling get_monitor_result." if monitor_id.nil? raise "Missing the required parameter 'vantage_point' when calling get_monitor_result." if vantage_point.nil? raise "Missing the required parameter 'result_type' when calling get_monitor_result." if result_type.nil? raise "Missing the required parameter 'result_content_type' when calling get_monitor_result." if result_content_type.nil? raise "Missing the required parameter 'execution_time' when calling get_monitor_result." if execution_time.nil? raise "Parameter value for 'monitor_id' must not be blank" if OCI::Internal::Util.blank_string?(monitor_id) raise "Parameter value for 'execution_time' must not be blank" if OCI::Internal::Util.blank_string?(execution_time) path = '/monitors/{monitorId}/results/{executionTime}'.sub('{monitorId}', monitor_id.to_s).sub('{executionTime}', execution_time.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:apmDomainId] = apm_domain_id query_params[:vantagePoint] = vantage_point query_params[:resultType] = result_type query_params[:resultContentType] = result_content_type # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ApmSyntheticClient#get_monitor_result') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::ApmSynthetics::Models::MonitorResult' ) end # rubocop:enable Metrics/BlockLength end |
#get_script(apm_domain_id, script_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/apmsynthetics/get_script.rb.html) to see an example of how to use get_script API.
Gets the configuration of the script identified by the OCID.
712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 |
# File 'lib/oci/apm_synthetics/apm_synthetic_client.rb', line 712 def get_script(apm_domain_id, script_id, opts = {}) logger.debug 'Calling operation ApmSyntheticClient#get_script.' if logger raise "Missing the required parameter 'apm_domain_id' when calling get_script." if apm_domain_id.nil? raise "Missing the required parameter 'script_id' when calling get_script." if script_id.nil? raise "Parameter value for 'script_id' must not be blank" if OCI::Internal::Util.blank_string?(script_id) path = '/scripts/{scriptId}'.sub('{scriptId}', script_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:apmDomainId] = apm_domain_id # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ApmSyntheticClient#get_script') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::ApmSynthetics::Models::Script' ) end # rubocop:enable Metrics/BlockLength end |
#list_dedicated_vantage_points(apm_domain_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/apmsynthetics/list_dedicated_vantage_points.rb.html) to see an example of how to use list_dedicated_vantage_points API.
Returns a list of dedicated vantage points.
790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 |
# File 'lib/oci/apm_synthetics/apm_synthetic_client.rb', line 790 def list_dedicated_vantage_points(apm_domain_id, opts = {}) logger.debug 'Calling operation ApmSyntheticClient#list_dedicated_vantage_points.' if logger raise "Missing the required parameter 'apm_domain_id' when calling list_dedicated_vantage_points." if apm_domain_id.nil? if opts[:sort_order] && !OCI::ApmSynthetics::Models::SORT_ORDERS_ENUM.include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of the values in OCI::ApmSynthetics::Models::SORT_ORDERS_ENUM.' end if opts[:sort_by] && !%w[displayName name timeCreated timeUpdated status].include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of displayName, name, timeCreated, timeUpdated, status.' end if opts[:status] && !OCI::ApmSynthetics::Models::DEDICATED_VANTAGE_POINT_STATUS_ENUM.include?(opts[:status]) raise 'Invalid value for "status", must be one of the values in OCI::ApmSynthetics::Models::DEDICATED_VANTAGE_POINT_STATUS_ENUM.' end path = '/dedicatedVantagePoints' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:apmDomainId] = apm_domain_id query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] query_params[:displayName] = opts[:display_name] if opts[:display_name] query_params[:name] = opts[:name] if opts[:name] query_params[:status] = opts[:status] if opts[:status] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ApmSyntheticClient#list_dedicated_vantage_points') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::ApmSynthetics::Models::DedicatedVantagePointCollection' ) end # rubocop:enable Metrics/BlockLength end |
#list_monitors(apm_domain_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/apmsynthetics/list_monitors.rb.html) to see an example of how to use list_monitors API.
Returns a list of monitors.
890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 |
# File 'lib/oci/apm_synthetics/apm_synthetic_client.rb', line 890 def list_monitors(apm_domain_id, opts = {}) logger.debug 'Calling operation ApmSyntheticClient#list_monitors.' if logger raise "Missing the required parameter 'apm_domain_id' when calling list_monitors." if apm_domain_id.nil? if opts[:status] && !OCI::ApmSynthetics::Models::MONITOR_STATUS_ENUM.include?(opts[:status]) raise 'Invalid value for "status", must be one of the values in OCI::ApmSynthetics::Models::MONITOR_STATUS_ENUM.' end if opts[:sort_order] && !OCI::ApmSynthetics::Models::SORT_ORDERS_ENUM.include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of the values in OCI::ApmSynthetics::Models::SORT_ORDERS_ENUM.' end if opts[:sort_by] && !%w[displayName timeCreated timeUpdated status monitorType].include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of displayName, timeCreated, timeUpdated, status, monitorType.' end path = '/monitors' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:apmDomainId] = apm_domain_id query_params[:displayName] = opts[:display_name] if opts[:display_name] query_params[:scriptId] = opts[:script_id] if opts[:script_id] query_params[:vantagePoint] = opts[:vantage_point] if opts[:vantage_point] query_params[:monitorType] = opts[:monitor_type] if opts[:monitor_type] query_params[:status] = opts[:status] if opts[:status] query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ApmSyntheticClient#list_monitors') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::ApmSynthetics::Models::MonitorCollection' ) end # rubocop:enable Metrics/BlockLength end |
#list_public_vantage_points(apm_domain_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/apmsynthetics/list_public_vantage_points.rb.html) to see an example of how to use list_public_vantage_points API.
Returns a list of public vantage points.
984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 |
# File 'lib/oci/apm_synthetics/apm_synthetic_client.rb', line 984 def list_public_vantage_points(apm_domain_id, opts = {}) logger.debug 'Calling operation ApmSyntheticClient#list_public_vantage_points.' if logger raise "Missing the required parameter 'apm_domain_id' when calling list_public_vantage_points." if apm_domain_id.nil? if opts[:sort_order] && !OCI::ApmSynthetics::Models::SORT_ORDERS_ENUM.include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of the values in OCI::ApmSynthetics::Models::SORT_ORDERS_ENUM.' end if opts[:sort_by] && !%w[name displayName].include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of name, displayName.' end path = '/publicVantagePoints' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:apmDomainId] = apm_domain_id query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] query_params[:displayName] = opts[:display_name] if opts[:display_name] query_params[:name] = opts[:name] if opts[:name] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ApmSyntheticClient#list_public_vantage_points') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::ApmSynthetics::Models::PublicVantagePointCollection' ) end # rubocop:enable Metrics/BlockLength end |
#list_scripts(apm_domain_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/apmsynthetics/list_scripts.rb.html) to see an example of how to use list_scripts API.
Returns a list of scripts.
1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 |
# File 'lib/oci/apm_synthetics/apm_synthetic_client.rb', line 1073 def list_scripts(apm_domain_id, opts = {}) logger.debug 'Calling operation ApmSyntheticClient#list_scripts.' if logger raise "Missing the required parameter 'apm_domain_id' when calling list_scripts." if apm_domain_id.nil? if opts[:sort_order] && !OCI::ApmSynthetics::Models::SORT_ORDERS_ENUM.include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of the values in OCI::ApmSynthetics::Models::SORT_ORDERS_ENUM.' end if opts[:sort_by] && !%w[displayName timeCreated timeUpdated contentType].include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of displayName, timeCreated, timeUpdated, contentType.' end path = '/scripts' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:apmDomainId] = apm_domain_id query_params[:displayName] = opts[:display_name] if opts[:display_name] query_params[:contentType] = opts[:content_type] if opts[:content_type] query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ApmSyntheticClient#list_scripts') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::ApmSynthetics::Models::ScriptCollection' ) end # rubocop:enable Metrics/BlockLength end |
#logger ⇒ Logger
Returns The logger for this client. May be nil.
92 93 94 |
# File 'lib/oci/apm_synthetics/apm_synthetic_client.rb', line 92 def logger @api_client.config.logger end |
#update_dedicated_vantage_point(apm_domain_id, dedicated_vantage_point_id, update_dedicated_vantage_point_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/apmsynthetics/update_dedicated_vantage_point.rb.html) to see an example of how to use update_dedicated_vantage_point API.
Updates the dedicated vantage point.
1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 |
# File 'lib/oci/apm_synthetics/apm_synthetic_client.rb', line 1152 def update_dedicated_vantage_point(apm_domain_id, dedicated_vantage_point_id, update_dedicated_vantage_point_details, opts = {}) logger.debug 'Calling operation ApmSyntheticClient#update_dedicated_vantage_point.' if logger raise "Missing the required parameter 'apm_domain_id' when calling update_dedicated_vantage_point." if apm_domain_id.nil? raise "Missing the required parameter 'dedicated_vantage_point_id' when calling update_dedicated_vantage_point." if dedicated_vantage_point_id.nil? raise "Missing the required parameter 'update_dedicated_vantage_point_details' when calling update_dedicated_vantage_point." if update_dedicated_vantage_point_details.nil? raise "Parameter value for 'dedicated_vantage_point_id' must not be blank" if OCI::Internal::Util.blank_string?(dedicated_vantage_point_id) path = '/dedicatedVantagePoints/{dedicatedVantagePointId}'.sub('{dedicatedVantagePointId}', dedicated_vantage_point_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:apmDomainId] = apm_domain_id # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(update_dedicated_vantage_point_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ApmSyntheticClient#update_dedicated_vantage_point') do @api_client.call_api( :PUT, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::ApmSynthetics::Models::DedicatedVantagePoint' ) end # rubocop:enable Metrics/BlockLength end |
#update_monitor(apm_domain_id, monitor_id, update_monitor_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/apmsynthetics/update_monitor.rb.html) to see an example of how to use update_monitor API.
Updates the monitor.
1221 1222 1223 1224 1225 1226 1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 |
# File 'lib/oci/apm_synthetics/apm_synthetic_client.rb', line 1221 def update_monitor(apm_domain_id, monitor_id, update_monitor_details, opts = {}) logger.debug 'Calling operation ApmSyntheticClient#update_monitor.' if logger raise "Missing the required parameter 'apm_domain_id' when calling update_monitor." if apm_domain_id.nil? raise "Missing the required parameter 'monitor_id' when calling update_monitor." if monitor_id.nil? raise "Missing the required parameter 'update_monitor_details' when calling update_monitor." if update_monitor_details.nil? raise "Parameter value for 'monitor_id' must not be blank" if OCI::Internal::Util.blank_string?(monitor_id) path = '/monitors/{monitorId}'.sub('{monitorId}', monitor_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:apmDomainId] = apm_domain_id # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(update_monitor_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ApmSyntheticClient#update_monitor') do @api_client.call_api( :PUT, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::ApmSynthetics::Models::Monitor' ) end # rubocop:enable Metrics/BlockLength end |
#update_script(apm_domain_id, script_id, update_script_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/apmsynthetics/update_script.rb.html) to see an example of how to use update_script API.
Updates the script.
1290 1291 1292 1293 1294 1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 1329 1330 |
# File 'lib/oci/apm_synthetics/apm_synthetic_client.rb', line 1290 def update_script(apm_domain_id, script_id, update_script_details, opts = {}) logger.debug 'Calling operation ApmSyntheticClient#update_script.' if logger raise "Missing the required parameter 'apm_domain_id' when calling update_script." if apm_domain_id.nil? raise "Missing the required parameter 'script_id' when calling update_script." if script_id.nil? raise "Missing the required parameter 'update_script_details' when calling update_script." if update_script_details.nil? raise "Parameter value for 'script_id' must not be blank" if OCI::Internal::Util.blank_string?(script_id) path = '/scripts/{scriptId}'.sub('{scriptId}', script_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:apmDomainId] = apm_domain_id # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(update_script_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ApmSyntheticClient#update_script') do @api_client.call_api( :PUT, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::ApmSynthetics::Models::Script' ) end # rubocop:enable Metrics/BlockLength end |