Class: OCI::ApmSynthetics::Models::CreateDedicatedVantagePointDetails
- Inherits:
-
Object
- Object
- OCI::ApmSynthetics::Models::CreateDedicatedVantagePointDetails
- Defined in:
- lib/oci/apm_synthetics/models/create_dedicated_vantage_point_details.rb
Overview
Details of the request body used to create a new dedicated vantage point.
Constant Summary collapse
- STATUS_ENUM =
[ STATUS_ENABLED = 'ENABLED'.freeze, STATUS_DISABLED = 'DISABLED'.freeze ].freeze
Instance Attribute Summary collapse
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
**[Required]** Unique dedicated vantage point name that cannot be edited.
-
#dvp_stack_details ⇒ OCI::ApmSynthetics::Models::DvpStackDetails
This attribute is required.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#region ⇒ String
**[Required]** Name of the region.
-
#status ⇒ String
Status of the dedicated vantage point.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateDedicatedVantagePointDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateDedicatedVantagePointDetails
Initializes the object
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/oci/apm_synthetics/models/create_dedicated_vantage_point_details.rb', line 83 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.dvp_stack_details = attributes[:'dvpStackDetails'] if attributes[:'dvpStackDetails'] raise 'You cannot provide both :dvpStackDetails and :dvp_stack_details' if attributes.key?(:'dvpStackDetails') && attributes.key?(:'dvp_stack_details') self.dvp_stack_details = attributes[:'dvp_stack_details'] if attributes[:'dvp_stack_details'] self.region = attributes[:'region'] if attributes[:'region'] self.status = attributes[:'status'] if attributes[:'status'] self.status = "ENABLED" if status.nil? && !attributes.key?(:'status') # rubocop:disable Style/StringLiterals self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
41 42 43 |
# File 'lib/oci/apm_synthetics/models/create_dedicated_vantage_point_details.rb', line 41 def @defined_tags end |
#display_name ⇒ String
**[Required]** Unique dedicated vantage point name that cannot be edited. The name should not contain any confidential information.
17 18 19 |
# File 'lib/oci/apm_synthetics/models/create_dedicated_vantage_point_details.rb', line 17 def display_name @display_name end |
#dvp_stack_details ⇒ OCI::ApmSynthetics::Models::DvpStackDetails
This attribute is required.
21 22 23 |
# File 'lib/oci/apm_synthetics/models/create_dedicated_vantage_point_details.rb', line 21 def dvp_stack_details @dvp_stack_details end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
35 36 37 |
# File 'lib/oci/apm_synthetics/models/create_dedicated_vantage_point_details.rb', line 35 def @freeform_tags end |
#region ⇒ String
**[Required]** Name of the region.
25 26 27 |
# File 'lib/oci/apm_synthetics/models/create_dedicated_vantage_point_details.rb', line 25 def region @region end |
#status ⇒ String
Status of the dedicated vantage point.
29 30 31 |
# File 'lib/oci/apm_synthetics/models/create_dedicated_vantage_point_details.rb', line 29 def status @status end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/oci/apm_synthetics/models/create_dedicated_vantage_point_details.rb', line 44 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'dvp_stack_details': :'dvpStackDetails', 'region': :'region', 'status': :'status', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/oci/apm_synthetics/models/create_dedicated_vantage_point_details.rb', line 58 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'dvp_stack_details': :'OCI::ApmSynthetics::Models::DvpStackDetails', 'region': :'String', 'status': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/oci/apm_synthetics/models/create_dedicated_vantage_point_details.rb', line 134 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && dvp_stack_details == other.dvp_stack_details && region == other.region && status == other.status && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/oci/apm_synthetics/models/create_dedicated_vantage_point_details.rb', line 169 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
149 150 151 |
# File 'lib/oci/apm_synthetics/models/create_dedicated_vantage_point_details.rb', line 149 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
158 159 160 |
# File 'lib/oci/apm_synthetics/models/create_dedicated_vantage_point_details.rb', line 158 def hash [display_name, dvp_stack_details, region, status, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
202 203 204 205 206 207 208 209 210 211 |
# File 'lib/oci/apm_synthetics/models/create_dedicated_vantage_point_details.rb', line 202 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
196 197 198 |
# File 'lib/oci/apm_synthetics/models/create_dedicated_vantage_point_details.rb', line 196 def to_s to_hash.to_s end |