Class: OCI::ApmSynthetics::Models::DedicatedVantagePointSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/apm_synthetics/models/dedicated_vantage_point_summary.rb

Overview

Information about dedicated vantage points.

Constant Summary collapse

STATUS_ENUM =
[
  STATUS_ENABLED = 'ENABLED'.freeze,
  STATUS_DISABLED = 'DISABLED'.freeze,
  STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DedicatedVantagePointSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/oci/apm_synthetics/models/dedicated_vantage_point_summary.rb', line 126

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.name = attributes[:'name'] if attributes[:'name']

  self.status = attributes[:'status'] if attributes[:'status']

  self.dvp_stack_details = attributes[:'dvpStackDetails'] if attributes[:'dvpStackDetails']

  raise 'You cannot provide both :dvpStackDetails and :dvp_stack_details' if attributes.key?(:'dvpStackDetails') && attributes.key?(:'dvp_stack_details')

  self.dvp_stack_details = attributes[:'dvp_stack_details'] if attributes[:'dvp_stack_details']

  self.region = attributes[:'region'] if attributes[:'region']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.monitor_status_count_map = attributes[:'monitorStatusCountMap'] if attributes[:'monitorStatusCountMap']

  raise 'You cannot provide both :monitorStatusCountMap and :monitor_status_count_map' if attributes.key?(:'monitorStatusCountMap') && attributes.key?(:'monitor_status_count_map')

  self.monitor_status_count_map = attributes[:'monitor_status_count_map'] if attributes[:'monitor_status_count_map']
end

Instance Attribute Details

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


65
66
67
# File 'lib/oci/apm_synthetics/models/dedicated_vantage_point_summary.rb', line 65

def defined_tags
  @defined_tags
end

#display_nameString

**[Required]** Unique dedicated vantage point name that cannot be edited. The name should not contain any confidential information.

Returns:

  • (String)


23
24
25
# File 'lib/oci/apm_synthetics/models/dedicated_vantage_point_summary.rb', line 23

def display_name
  @display_name
end

#dvp_stack_detailsOCI::ApmSynthetics::Models::DvpStackDetails

This attribute is required.



35
36
37
# File 'lib/oci/apm_synthetics/models/dedicated_vantage_point_summary.rb', line 35

def dvp_stack_details
  @dvp_stack_details
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`

Returns:

  • (Hash<String, String>)


59
60
61
# File 'lib/oci/apm_synthetics/models/dedicated_vantage_point_summary.rb', line 59

def freeform_tags
  @freeform_tags
end

#idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the dedicated vantage point.

Returns:

  • (String)


19
20
21
# File 'lib/oci/apm_synthetics/models/dedicated_vantage_point_summary.rb', line 19

def id
  @id
end

#monitor_status_count_mapOCI::ApmSynthetics::Models::MonitorStatusCountMap

This attribute is required.



69
70
71
# File 'lib/oci/apm_synthetics/models/dedicated_vantage_point_summary.rb', line 69

def monitor_status_count_map
  @monitor_status_count_map
end

#nameString

**[Required]** Unique permanent name of the vantage point.

Returns:

  • (String)


27
28
29
# File 'lib/oci/apm_synthetics/models/dedicated_vantage_point_summary.rb', line 27

def name
  @name
end

#regionString

**[Required]** Name of the region.

Returns:

  • (String)


39
40
41
# File 'lib/oci/apm_synthetics/models/dedicated_vantage_point_summary.rb', line 39

def region
  @region
end

#statusString

**[Required]** Status of the dedicated vantage point.

Returns:

  • (String)


31
32
33
# File 'lib/oci/apm_synthetics/models/dedicated_vantage_point_summary.rb', line 31

def status
  @status
end

#time_createdDateTime

The time the resource was created, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format. Example: `2020-02-12T22:47:12.613Z`

Returns:

  • (DateTime)


46
47
48
# File 'lib/oci/apm_synthetics/models/dedicated_vantage_point_summary.rb', line 46

def time_created
  @time_created
end

#time_updatedDateTime

The time the resource was updated, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format. Example: `2020-02-13T22:47:12.613Z`

Returns:

  • (DateTime)


53
54
55
# File 'lib/oci/apm_synthetics/models/dedicated_vantage_point_summary.rb', line 53

def time_updated
  @time_updated
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/oci/apm_synthetics/models/dedicated_vantage_point_summary.rb', line 72

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'display_name': :'displayName',
    'name': :'name',
    'status': :'status',
    'dvp_stack_details': :'dvpStackDetails',
    'region': :'region',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'monitor_status_count_map': :'monitorStatusCountMap'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/oci/apm_synthetics/models/dedicated_vantage_point_summary.rb', line 91

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'display_name': :'String',
    'name': :'String',
    'status': :'String',
    'dvp_stack_details': :'OCI::ApmSynthetics::Models::DvpStackDetails',
    'region': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'monitor_status_count_map': :'OCI::ApmSynthetics::Models::MonitorStatusCountMap'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/oci/apm_synthetics/models/dedicated_vantage_point_summary.rb', line 203

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    display_name == other.display_name &&
    name == other.name &&
    status == other.status &&
    dvp_stack_details == other.dvp_stack_details &&
    region == other.region &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    monitor_status_count_map == other.monitor_status_count_map
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/oci/apm_synthetics/models/dedicated_vantage_point_summary.rb', line 243

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


223
224
225
# File 'lib/oci/apm_synthetics/models/dedicated_vantage_point_summary.rb', line 223

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



232
233
234
# File 'lib/oci/apm_synthetics/models/dedicated_vantage_point_summary.rb', line 232

def hash
  [id, display_name, name, status, dvp_stack_details, region, time_created, time_updated, freeform_tags, defined_tags, monitor_status_count_map].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



276
277
278
279
280
281
282
283
284
285
# File 'lib/oci/apm_synthetics/models/dedicated_vantage_point_summary.rb', line 276

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



270
271
272
# File 'lib/oci/apm_synthetics/models/dedicated_vantage_point_summary.rb', line 270

def to_s
  to_hash.to_s
end