Class: OCI::ApmSynthetics::Models::MonitorResult
- Inherits:
-
Object
- Object
- OCI::ApmSynthetics::Models::MonitorResult
- Defined in:
- lib/oci/apm_synthetics/models/monitor_result.rb
Overview
The monitor result for a specific execution.
Instance Attribute Summary collapse
-
#execution_time ⇒ String
The specific point of time when the result of an execution is collected.
-
#monitor_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the monitor.
-
#result_content_type ⇒ String
**[Required]** Type of result content.
-
#result_data_set ⇒ Array<OCI::ApmSynthetics::Models::MonitorResultData>
Monitor result data set.
-
#result_type ⇒ String
Type of result.
-
#vantage_point ⇒ String
The name of the public or dedicated vantage point.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MonitorResult
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ MonitorResult
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/oci/apm_synthetics/models/monitor_result.rb', line 78 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.result_type = attributes[:'resultType'] if attributes[:'resultType'] raise 'You cannot provide both :resultType and :result_type' if attributes.key?(:'resultType') && attributes.key?(:'result_type') self.result_type = attributes[:'result_type'] if attributes[:'result_type'] self.result_content_type = attributes[:'resultContentType'] if attributes[:'resultContentType'] raise 'You cannot provide both :resultContentType and :result_content_type' if attributes.key?(:'resultContentType') && attributes.key?(:'result_content_type') self.result_content_type = attributes[:'result_content_type'] if attributes[:'result_content_type'] self.result_data_set = attributes[:'resultDataSet'] if attributes[:'resultDataSet'] raise 'You cannot provide both :resultDataSet and :result_data_set' if attributes.key?(:'resultDataSet') && attributes.key?(:'result_data_set') self.result_data_set = attributes[:'result_data_set'] if attributes[:'result_data_set'] self.monitor_id = attributes[:'monitorId'] if attributes[:'monitorId'] raise 'You cannot provide both :monitorId and :monitor_id' if attributes.key?(:'monitorId') && attributes.key?(:'monitor_id') self.monitor_id = attributes[:'monitor_id'] if attributes[:'monitor_id'] self.vantage_point = attributes[:'vantagePoint'] if attributes[:'vantagePoint'] raise 'You cannot provide both :vantagePoint and :vantage_point' if attributes.key?(:'vantagePoint') && attributes.key?(:'vantage_point') self.vantage_point = attributes[:'vantage_point'] if attributes[:'vantage_point'] self.execution_time = attributes[:'executionTime'] if attributes[:'executionTime'] raise 'You cannot provide both :executionTime and :execution_time' if attributes.key?(:'executionTime') && attributes.key?(:'execution_time') self.execution_time = attributes[:'execution_time'] if attributes[:'execution_time'] end |
Instance Attribute Details
#execution_time ⇒ String
The specific point of time when the result of an execution is collected.
36 37 38 |
# File 'lib/oci/apm_synthetics/models/monitor_result.rb', line 36 def execution_time @execution_time end |
#monitor_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the monitor.
28 29 30 |
# File 'lib/oci/apm_synthetics/models/monitor_result.rb', line 28 def monitor_id @monitor_id end |
#result_content_type ⇒ String
**[Required]** Type of result content. Example: Zip or Raw file.
20 21 22 |
# File 'lib/oci/apm_synthetics/models/monitor_result.rb', line 20 def result_content_type @result_content_type end |
#result_data_set ⇒ Array<OCI::ApmSynthetics::Models::MonitorResultData>
Monitor result data set.
24 25 26 |
# File 'lib/oci/apm_synthetics/models/monitor_result.rb', line 24 def result_data_set @result_data_set end |
#result_type ⇒ String
Type of result. Example: HAR, Screenshot, Log or Network.
14 15 16 |
# File 'lib/oci/apm_synthetics/models/monitor_result.rb', line 14 def result_type @result_type end |
#vantage_point ⇒ String
The name of the public or dedicated vantage point.
32 33 34 |
# File 'lib/oci/apm_synthetics/models/monitor_result.rb', line 32 def vantage_point @vantage_point end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/oci/apm_synthetics/models/monitor_result.rb', line 39 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'result_type': :'resultType', 'result_content_type': :'resultContentType', 'result_data_set': :'resultDataSet', 'monitor_id': :'monitorId', 'vantage_point': :'vantagePoint', 'execution_time': :'executionTime' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/oci/apm_synthetics/models/monitor_result.rb', line 53 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'result_type': :'String', 'result_content_type': :'String', 'result_data_set': :'Array<OCI::ApmSynthetics::Models::MonitorResultData>', 'monitor_id': :'String', 'vantage_point': :'String', 'execution_time': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/oci/apm_synthetics/models/monitor_result.rb', line 128 def ==(other) return true if equal?(other) self.class == other.class && result_type == other.result_type && result_content_type == other.result_content_type && result_data_set == other.result_data_set && monitor_id == other.monitor_id && vantage_point == other.vantage_point && execution_time == other.execution_time end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/oci/apm_synthetics/models/monitor_result.rb', line 163 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
143 144 145 |
# File 'lib/oci/apm_synthetics/models/monitor_result.rb', line 143 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
152 153 154 |
# File 'lib/oci/apm_synthetics/models/monitor_result.rb', line 152 def hash [result_type, result_content_type, result_data_set, monitor_id, vantage_point, execution_time].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
196 197 198 199 200 201 202 203 204 205 |
# File 'lib/oci/apm_synthetics/models/monitor_result.rb', line 196 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
190 191 192 |
# File 'lib/oci/apm_synthetics/models/monitor_result.rb', line 190 def to_s to_hash.to_s end |