Class: OCI::ApmSynthetics::Models::MonitorResultData
- Inherits:
-
Object
- Object
- OCI::ApmSynthetics::Models::MonitorResultData
- Defined in:
- lib/oci/apm_synthetics/models/monitor_result_data.rb
Overview
Details of the monitor result data.
Instance Attribute Summary collapse
-
#byte_content ⇒ String
Data content in byte format.
-
#name ⇒ String
Name of the data.
-
#string_content ⇒ String
Data content in string format.
-
#timestamp ⇒ DateTime
The time when the data was generated, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MonitorResultData
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ MonitorResultData
Initializes the object
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/oci/apm_synthetics/models/monitor_result_data.rb', line 67 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.byte_content = attributes[:'byteContent'] if attributes[:'byteContent'] raise 'You cannot provide both :byteContent and :byte_content' if attributes.key?(:'byteContent') && attributes.key?(:'byte_content') self.byte_content = attributes[:'byte_content'] if attributes[:'byte_content'] self.string_content = attributes[:'stringContent'] if attributes[:'stringContent'] raise 'You cannot provide both :stringContent and :string_content' if attributes.key?(:'stringContent') && attributes.key?(:'string_content') self.string_content = attributes[:'string_content'] if attributes[:'string_content'] self. = attributes[:'timestamp'] if attributes[:'timestamp'] end |
Instance Attribute Details
#byte_content ⇒ String
Data content in byte format. Example: Zip or Screenshot.
18 19 20 |
# File 'lib/oci/apm_synthetics/models/monitor_result_data.rb', line 18 def byte_content @byte_content end |
#name ⇒ String
Name of the data.
12 13 14 |
# File 'lib/oci/apm_synthetics/models/monitor_result_data.rb', line 12 def name @name end |
#string_content ⇒ String
Data content in string format. Example: HAR.
24 25 26 |
# File 'lib/oci/apm_synthetics/models/monitor_result_data.rb', line 24 def string_content @string_content end |
#timestamp ⇒ DateTime
The time when the data was generated, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format. Example: `2020-02-13T22:47:12.613Z`
31 32 33 |
# File 'lib/oci/apm_synthetics/models/monitor_result_data.rb', line 31 def @timestamp end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 43 |
# File 'lib/oci/apm_synthetics/models/monitor_result_data.rb', line 34 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'byte_content': :'byteContent', 'string_content': :'stringContent', 'timestamp': :'timestamp' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
46 47 48 49 50 51 52 53 54 55 |
# File 'lib/oci/apm_synthetics/models/monitor_result_data.rb', line 46 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'byte_content': :'String', 'string_content': :'String', 'timestamp': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
97 98 99 100 101 102 103 104 105 |
# File 'lib/oci/apm_synthetics/models/monitor_result_data.rb', line 97 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && byte_content == other.byte_content && string_content == other.string_content && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/oci/apm_synthetics/models/monitor_result_data.rb', line 130 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
110 111 112 |
# File 'lib/oci/apm_synthetics/models/monitor_result_data.rb', line 110 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
119 120 121 |
# File 'lib/oci/apm_synthetics/models/monitor_result_data.rb', line 119 def hash [name, byte_content, string_content, ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
163 164 165 166 167 168 169 170 171 172 |
# File 'lib/oci/apm_synthetics/models/monitor_result_data.rb', line 163 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
157 158 159 |
# File 'lib/oci/apm_synthetics/models/monitor_result_data.rb', line 157 def to_s to_hash.to_s end |