Class: OCI::ApmSynthetics::Models::RequestQueryParam

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/apm_synthetics/models/request_query_param.rb

Overview

Information about request query parameters.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ RequestQueryParam

Initializes the object

Options Hash (attributes):

  • :param_name (String)

    The value to assign to the #param_name property

  • :param_value (String)

    The value to assign to the #param_value property



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/oci/apm_synthetics/models/request_query_param.rb', line 47

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.param_name = attributes[:'paramName'] if attributes[:'paramName']

  raise 'You cannot provide both :paramName and :param_name' if attributes.key?(:'paramName') && attributes.key?(:'param_name')

  self.param_name = attributes[:'param_name'] if attributes[:'param_name']

  self.param_value = attributes[:'paramValue'] if attributes[:'paramValue']

  raise 'You cannot provide both :paramValue and :param_value' if attributes.key?(:'paramValue') && attributes.key?(:'param_value')

  self.param_value = attributes[:'param_value'] if attributes[:'param_value']
end

Instance Attribute Details

#param_nameString

[Required] Name of request query parameter.



13
14
15
# File 'lib/oci/apm_synthetics/models/request_query_param.rb', line 13

def param_name
  @param_name
end

#param_valueString

Value of request query parameter.



17
18
19
# File 'lib/oci/apm_synthetics/models/request_query_param.rb', line 17

def param_value
  @param_value
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



20
21
22
23
24
25
26
27
# File 'lib/oci/apm_synthetics/models/request_query_param.rb', line 20

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'param_name': :'paramName',
    'param_value': :'paramValue'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



30
31
32
33
34
35
36
37
# File 'lib/oci/apm_synthetics/models/request_query_param.rb', line 30

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'param_name': :'String',
    'param_value': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.



73
74
75
76
77
78
79
# File 'lib/oci/apm_synthetics/models/request_query_param.rb', line 73

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    param_name == other.param_name &&
    param_value == other.param_value
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/oci/apm_synthetics/models/request_query_param.rb', line 104

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method


84
85
86
# File 'lib/oci/apm_synthetics/models/request_query_param.rb', line 84

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.



93
94
95
# File 'lib/oci/apm_synthetics/models/request_query_param.rb', line 93

def hash
  [param_name, param_value].hash
end

#to_hashHash

Returns the object in the form of hash



137
138
139
140
141
142
143
144
145
146
# File 'lib/oci/apm_synthetics/models/request_query_param.rb', line 137

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



131
132
133
# File 'lib/oci/apm_synthetics/models/request_query_param.rb', line 131

def to_s
  to_hash.to_s
end