Class: ApmSynthetics::Models::Script

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/apm_synthetics/models/script.rb

Overview

The information about the script.

Constant Summary collapse

CONTENT_TYPE_ENUM =
[
  CONTENT_TYPE_SIDE = 'SIDE'.freeze,
  CONTENT_TYPE_JS = 'JS'.freeze,
  CONTENT_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Script

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/oci/apm_synthetics/models/script.rb', line 150

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.content_type = attributes[:'contentType'] if attributes[:'contentType']

  raise 'You cannot provide both :contentType and :content_type' if attributes.key?(:'contentType') && attributes.key?(:'content_type')

  self.content_type = attributes[:'content_type'] if attributes[:'content_type']

  self.content = attributes[:'content'] if attributes[:'content']

  self.time_uploaded = attributes[:'timeUploaded'] if attributes[:'timeUploaded']

  raise 'You cannot provide both :timeUploaded and :time_uploaded' if attributes.key?(:'timeUploaded') && attributes.key?(:'time_uploaded')

  self.time_uploaded = attributes[:'time_uploaded'] if attributes[:'time_uploaded']

  self.content_size_in_bytes = attributes[:'contentSizeInBytes'] if attributes[:'contentSizeInBytes']

  raise 'You cannot provide both :contentSizeInBytes and :content_size_in_bytes' if attributes.key?(:'contentSizeInBytes') && attributes.key?(:'content_size_in_bytes')

  self.content_size_in_bytes = attributes[:'content_size_in_bytes'] if attributes[:'content_size_in_bytes']

  self.content_file_name = attributes[:'contentFileName'] if attributes[:'contentFileName']

  raise 'You cannot provide both :contentFileName and :content_file_name' if attributes.key?(:'contentFileName') && attributes.key?(:'content_file_name')

  self.content_file_name = attributes[:'content_file_name'] if attributes[:'content_file_name']

  self.parameters = attributes[:'parameters'] if attributes[:'parameters']

  self.monitor_status_count_map = attributes[:'monitorStatusCountMap'] if attributes[:'monitorStatusCountMap']

  raise 'You cannot provide both :monitorStatusCountMap and :monitor_status_count_map' if attributes.key?(:'monitorStatusCountMap') && attributes.key?(:'monitor_status_count_map')

  self.monitor_status_count_map = attributes[:'monitor_status_count_map'] if attributes[:'monitor_status_count_map']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#contentString

The content of the script. It may contain custom-defined tags that can be used for setting dynamic parameters. The format to set dynamic parameters is: `<ORAP><ON>param name</ON><OV>param value</OV><OS>isParamValueSecret(true/false)</OS></ORAP>`. Param value and isParamValueSecret are optional, the default value for isParamValueSecret is false. Examples: With mandatory param name : `<ORAP><ON>param name</ON></ORAP>` With parameter name and value : `<ORAP><ON>param name</ON><OV>param value</OV></ORAP>` Note that the content is valid if it matches the given content type. For example, if the content type is SIDE, then the content should be in Side script format. If the content type is JS, then the content should be in JavaScript format.

Returns:

  • (String)


40
41
42
# File 'lib/oci/apm_synthetics/models/script.rb', line 40

def content
  @content
end

#content_file_nameString

File name of the uploaded script content.

Returns:

  • (String)


52
53
54
# File 'lib/oci/apm_synthetics/models/script.rb', line 52

def content_file_name
  @content_file_name
end

#content_size_in_bytesInteger

Size of the script content.

Returns:

  • (Integer)


48
49
50
# File 'lib/oci/apm_synthetics/models/script.rb', line 48

def content_size_in_bytes
  @content_size_in_bytes
end

#content_typeString

**[Required]** Content type of the script.

Returns:

  • (String)


29
30
31
# File 'lib/oci/apm_synthetics/models/script.rb', line 29

def content_type
  @content_type
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


87
88
89
# File 'lib/oci/apm_synthetics/models/script.rb', line 87

def defined_tags
  @defined_tags
end

#display_nameString

**[Required]** Unique name that can be edited. The name should not contain any confidential information.

Returns:

  • (String)


25
26
27
# File 'lib/oci/apm_synthetics/models/script.rb', line 25

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`

Returns:

  • (Hash<String, String>)


81
82
83
# File 'lib/oci/apm_synthetics/models/script.rb', line 81

def freeform_tags
  @freeform_tags
end

#idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the script. scriptId is mandatory for creation of SCRIPTED_BROWSER and SCRIPTED_REST monitor types. For other monitor types, it should be set to null.

Returns:

  • (String)


21
22
23
# File 'lib/oci/apm_synthetics/models/script.rb', line 21

def id
  @id
end

#monitor_status_count_mapOCI::ApmSynthetics::Models::MonitorStatusCountMap

This attribute is required.



61
62
63
# File 'lib/oci/apm_synthetics/models/script.rb', line 61

def monitor_status_count_map
  @monitor_status_count_map
end

#parametersArray<OCI::ApmSynthetics::Models::ScriptParameterInfo>

List of script parameters. Example: `[{"paramName": "userid", "paramValue":"testuser", "isSecret": false, "isOverwritten": false}]`



57
58
59
# File 'lib/oci/apm_synthetics/models/script.rb', line 57

def parameters
  @parameters
end

#time_createdDateTime

The time the resource was created, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format. Example: `2020-02-12T22:47:12.613Z`

Returns:

  • (DateTime)


68
69
70
# File 'lib/oci/apm_synthetics/models/script.rb', line 68

def time_created
  @time_created
end

#time_updatedDateTime

The time the resource was updated, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format. Example: `2020-02-13T22:47:12.613Z`

Returns:

  • (DateTime)


75
76
77
# File 'lib/oci/apm_synthetics/models/script.rb', line 75

def time_updated
  @time_updated
end

#time_uploadedDateTime

The time the script was uploaded.

Returns:

  • (DateTime)


44
45
46
# File 'lib/oci/apm_synthetics/models/script.rb', line 44

def time_uploaded
  @time_uploaded
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/oci/apm_synthetics/models/script.rb', line 90

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'display_name': :'displayName',
    'content_type': :'contentType',
    'content': :'content',
    'time_uploaded': :'timeUploaded',
    'content_size_in_bytes': :'contentSizeInBytes',
    'content_file_name': :'contentFileName',
    'parameters': :'parameters',
    'monitor_status_count_map': :'monitorStatusCountMap',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/oci/apm_synthetics/models/script.rb', line 111

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'display_name': :'String',
    'content_type': :'String',
    'content': :'String',
    'time_uploaded': :'DateTime',
    'content_size_in_bytes': :'Integer',
    'content_file_name': :'String',
    'parameters': :'Array<OCI::ApmSynthetics::Models::ScriptParameterInfo>',
    'monitor_status_count_map': :'OCI::ApmSynthetics::Models::MonitorStatusCountMap',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/oci/apm_synthetics/models/script.rb', line 243

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    display_name == other.display_name &&
    content_type == other.content_type &&
    content == other.content &&
    time_uploaded == other.time_uploaded &&
    content_size_in_bytes == other.content_size_in_bytes &&
    content_file_name == other.content_file_name &&
    parameters == other.parameters &&
    monitor_status_count_map == other.monitor_status_count_map &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
# File 'lib/oci/apm_synthetics/models/script.rb', line 285

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


265
266
267
# File 'lib/oci/apm_synthetics/models/script.rb', line 265

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



274
275
276
# File 'lib/oci/apm_synthetics/models/script.rb', line 274

def hash
  [id, display_name, content_type, content, time_uploaded, content_size_in_bytes, content_file_name, parameters, monitor_status_count_map, time_created, time_updated, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



318
319
320
321
322
323
324
325
326
327
# File 'lib/oci/apm_synthetics/models/script.rb', line 318

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



312
313
314
# File 'lib/oci/apm_synthetics/models/script.rb', line 312

def to_s
  to_hash.to_s
end