Class: OCI::ApmSynthetics::Models::ScriptedRestMonitorConfiguration

Inherits:
MonitorConfiguration show all
Defined in:
lib/oci/apm_synthetics/models/scripted_rest_monitor_configuration.rb

Overview

Configuration details for the SCRIPTED_REST monitor type.

Constant Summary

Constants inherited from MonitorConfiguration

MonitorConfiguration::CONFIG_TYPE_ENUM

Instance Attribute Summary collapse

Attributes inherited from MonitorConfiguration

#config_type, #is_failure_retried

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from MonitorConfiguration

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ ScriptedRestMonitorConfiguration

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/oci/apm_synthetics/models/scripted_rest_monitor_configuration.rb', line 44

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['configType'] = 'SCRIPTED_REST_CONFIG'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.network_configuration = attributes[:'networkConfiguration'] if attributes[:'networkConfiguration']

  raise 'You cannot provide both :networkConfiguration and :network_configuration' if attributes.key?(:'networkConfiguration') && attributes.key?(:'network_configuration')

  self.network_configuration = attributes[:'network_configuration'] if attributes[:'network_configuration']
end

Instance Attribute Details

#network_configurationOCI::ApmSynthetics::Models::NetworkConfiguration



12
13
14
# File 'lib/oci/apm_synthetics/models/scripted_rest_monitor_configuration.rb', line 12

def network_configuration
  @network_configuration
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



15
16
17
18
19
20
21
22
23
# File 'lib/oci/apm_synthetics/models/scripted_rest_monitor_configuration.rb', line 15

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'config_type': :'configType',
    'is_failure_retried': :'isFailureRetried',
    'network_configuration': :'networkConfiguration'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



26
27
28
29
30
31
32
33
34
# File 'lib/oci/apm_synthetics/models/scripted_rest_monitor_configuration.rb', line 26

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'config_type': :'String',
    'is_failure_retried': :'BOOLEAN',
    'network_configuration': :'OCI::ApmSynthetics::Models::NetworkConfiguration'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



68
69
70
71
72
73
74
75
# File 'lib/oci/apm_synthetics/models/scripted_rest_monitor_configuration.rb', line 68

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    config_type == other.config_type &&
    is_failure_retried == other.is_failure_retried &&
    network_configuration == other.network_configuration
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/oci/apm_synthetics/models/scripted_rest_monitor_configuration.rb', line 100

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


80
81
82
# File 'lib/oci/apm_synthetics/models/scripted_rest_monitor_configuration.rb', line 80

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



89
90
91
# File 'lib/oci/apm_synthetics/models/scripted_rest_monitor_configuration.rb', line 89

def hash
  [config_type, is_failure_retried, network_configuration].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



133
134
135
136
137
138
139
140
141
142
# File 'lib/oci/apm_synthetics/models/scripted_rest_monitor_configuration.rb', line 133

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



127
128
129
# File 'lib/oci/apm_synthetics/models/scripted_rest_monitor_configuration.rb', line 127

def to_s
  to_hash.to_s
end