Class: OCI::ApmSynthetics::Models::UpdateScriptDetails
- Inherits:
-
Object
- Object
- OCI::ApmSynthetics::Models::UpdateScriptDetails
- Defined in:
- lib/oci/apm_synthetics/models/update_script_details.rb
Overview
Details of the request body used to update a script. Only Side or JavaScript content types are supported and content should be in Side or JavaScript formats only.
Constant Summary collapse
- CONTENT_TYPE_ENUM =
[ CONTENT_TYPE_SIDE = 'SIDE'.freeze, CONTENT_TYPE_JS = 'JS'.freeze ].freeze
Instance Attribute Summary collapse
-
#content ⇒ String
The content of the script.
-
#content_file_name ⇒ String
File name of uploaded script content.
-
#content_type ⇒ String
Content type of script.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
Unique name that can be edited.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#parameters ⇒ Array<OCI::ApmSynthetics::Models::ScriptParameter>
List of script parameters.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateScriptDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateScriptDetails
Initializes the object
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/oci/apm_synthetics/models/update_script_details.rb', line 100 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.content_type = attributes[:'contentType'] if attributes[:'contentType'] raise 'You cannot provide both :contentType and :content_type' if attributes.key?(:'contentType') && attributes.key?(:'content_type') self.content_type = attributes[:'content_type'] if attributes[:'content_type'] self.content = attributes[:'content'] if attributes[:'content'] self.content_file_name = attributes[:'contentFileName'] if attributes[:'contentFileName'] raise 'You cannot provide both :contentFileName and :content_file_name' if attributes.key?(:'contentFileName') && attributes.key?(:'content_file_name') self.content_file_name = attributes[:'content_file_name'] if attributes[:'content_file_name'] self.parameters = attributes[:'parameters'] if attributes[:'parameters'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#content ⇒ String
The content of the script. It may contain custom-defined tags that can be used for setting dynamic parameters. The format to set dynamic parameters is: ‘<ORAP><ON>param name</ON><OV>param value</OV><OS>isParamValueSecret(true/false)</OS></ORAP>`. Param value and isParamValueSecret are optional, the default value for isParamValueSecret is false. Examples: With mandatory param name : `<ORAP><ON>param name</ON></ORAP>` With parameter name and value : `<ORAP><ON>param name</ON><OV>param value</OV></ORAP>` Note that the content is valid if it matches the given content type. For example, if the content type is SIDE, then the content should be in Side script format. If the content type is JS, then the content should be in JavaScript format.
34 35 36 |
# File 'lib/oci/apm_synthetics/models/update_script_details.rb', line 34 def content @content end |
#content_file_name ⇒ String
File name of uploaded script content.
38 39 40 |
# File 'lib/oci/apm_synthetics/models/update_script_details.rb', line 38 def content_file_name @content_file_name end |
#content_type ⇒ String
Content type of script.
23 24 25 |
# File 'lib/oci/apm_synthetics/models/update_script_details.rb', line 23 def content_type @content_type end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
55 56 57 |
# File 'lib/oci/apm_synthetics/models/update_script_details.rb', line 55 def end |
#display_name ⇒ String
Unique name that can be edited. The name should not contain any confidential information.
19 20 21 |
# File 'lib/oci/apm_synthetics/models/update_script_details.rb', line 19 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`
49 50 51 |
# File 'lib/oci/apm_synthetics/models/update_script_details.rb', line 49 def end |
#parameters ⇒ Array<OCI::ApmSynthetics::Models::ScriptParameter>
List of script parameters. Example: ‘["userid", "paramValue":"testuser", "isSecret": false]`
43 44 45 |
# File 'lib/oci/apm_synthetics/models/update_script_details.rb', line 43 def parameters @parameters end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/oci/apm_synthetics/models/update_script_details.rb', line 58 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'content_type': :'contentType', 'content': :'content', 'content_file_name': :'contentFileName', 'parameters': :'parameters', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/oci/apm_synthetics/models/update_script_details.rb', line 73 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'content_type': :'String', 'content': :'String', 'content_file_name': :'String', 'parameters': :'Array<OCI::ApmSynthetics::Models::ScriptParameter>', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/oci/apm_synthetics/models/update_script_details.rb', line 156 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && content_type == other.content_type && content == other.content && content_file_name == other.content_file_name && parameters == other.parameters && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/oci/apm_synthetics/models/update_script_details.rb', line 192 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
172 173 174 |
# File 'lib/oci/apm_synthetics/models/update_script_details.rb', line 172 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
181 182 183 |
# File 'lib/oci/apm_synthetics/models/update_script_details.rb', line 181 def hash [display_name, content_type, content, content_file_name, parameters, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
225 226 227 228 229 230 231 232 233 234 |
# File 'lib/oci/apm_synthetics/models/update_script_details.rb', line 225 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
219 220 221 |
# File 'lib/oci/apm_synthetics/models/update_script_details.rb', line 219 def to_s to_hash.to_s end |