Class: OCI::ApmTraces::Models::QueryResultMetadataSummary
- Inherits:
-
Object
- Object
- OCI::ApmTraces::Models::QueryResultMetadataSummary
- Defined in:
- lib/oci/apm_traces/models/query_result_metadata_summary.rb
Overview
Summary containing the metadata about the query result set.
Instance Attribute Summary collapse
-
#query_result_row_type_summaries ⇒ Array<OCI::ApmTraces::Models::QueryResultRowTypeSummary>
A collection of QueryResultRowTypeSummary objects that describe the type and properties of the individual row elements of the query rows being returned.
-
#query_results_grouped_by ⇒ Array<OCI::ApmTraces::Models::QueryResultsGroupedBySummary>
Columns or attributes of the query rows which are group by values.
-
#query_results_ordered_by ⇒ Array<OCI::ApmTraces::Models::QueryResultsOrderedBySummary>
Order by which the query results are organized.
-
#source_name ⇒ String
Source of the query result set (traces, spans, etc).
-
#time_series_interval_in_mins ⇒ Integer
Interval for the time series function in minutes.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ QueryResultMetadataSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ QueryResultMetadataSummary
Initializes the object
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/oci/apm_traces/models/query_result_metadata_summary.rb', line 76 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.query_result_row_type_summaries = attributes[:'queryResultRowTypeSummaries'] if attributes[:'queryResultRowTypeSummaries'] raise 'You cannot provide both :queryResultRowTypeSummaries and :query_result_row_type_summaries' if attributes.key?(:'queryResultRowTypeSummaries') && attributes.key?(:'query_result_row_type_summaries') self.query_result_row_type_summaries = attributes[:'query_result_row_type_summaries'] if attributes[:'query_result_row_type_summaries'] self.source_name = attributes[:'sourceName'] if attributes[:'sourceName'] raise 'You cannot provide both :sourceName and :source_name' if attributes.key?(:'sourceName') && attributes.key?(:'source_name') self.source_name = attributes[:'source_name'] if attributes[:'source_name'] self.query_results_grouped_by = attributes[:'queryResultsGroupedBy'] if attributes[:'queryResultsGroupedBy'] raise 'You cannot provide both :queryResultsGroupedBy and :query_results_grouped_by' if attributes.key?(:'queryResultsGroupedBy') && attributes.key?(:'query_results_grouped_by') self.query_results_grouped_by = attributes[:'query_results_grouped_by'] if attributes[:'query_results_grouped_by'] self.query_results_ordered_by = attributes[:'queryResultsOrderedBy'] if attributes[:'queryResultsOrderedBy'] raise 'You cannot provide both :queryResultsOrderedBy and :query_results_ordered_by' if attributes.key?(:'queryResultsOrderedBy') && attributes.key?(:'query_results_ordered_by') self.query_results_ordered_by = attributes[:'query_results_ordered_by'] if attributes[:'query_results_ordered_by'] self.time_series_interval_in_mins = attributes[:'timeSeriesIntervalInMins'] if attributes[:'timeSeriesIntervalInMins'] raise 'You cannot provide both :timeSeriesIntervalInMins and :time_series_interval_in_mins' if attributes.key?(:'timeSeriesIntervalInMins') && attributes.key?(:'time_series_interval_in_mins') self.time_series_interval_in_mins = attributes[:'time_series_interval_in_mins'] if attributes[:'time_series_interval_in_mins'] end |
Instance Attribute Details
#query_result_row_type_summaries ⇒ Array<OCI::ApmTraces::Models::QueryResultRowTypeSummary>
A collection of QueryResultRowTypeSummary objects that describe the type and properties of the individual row elements of the query rows being returned. The ith element in this list contains the QueryResultRowTypeSummary of the ith key value pair in the QueryResultRowData map.
15 16 17 |
# File 'lib/oci/apm_traces/models/query_result_metadata_summary.rb', line 15 def query_result_row_type_summaries @query_result_row_type_summaries end |
#query_results_grouped_by ⇒ Array<OCI::ApmTraces::Models::QueryResultsGroupedBySummary>
Columns or attributes of the query rows which are group by values. This is a list of ResultsGroupedBy summary objects, and the list will contain as many elements as the attributes and aggregate functions in the group by clause in the select query.
26 27 28 |
# File 'lib/oci/apm_traces/models/query_result_metadata_summary.rb', line 26 def query_results_grouped_by @query_results_grouped_by end |
#query_results_ordered_by ⇒ Array<OCI::ApmTraces::Models::QueryResultsOrderedBySummary>
Order by which the query results are organized. This is a list of queryResultsOrderedBy summary objects, and the list will contain more than one OrderedBy summary object, if the sort was multidimensional.
32 33 34 |
# File 'lib/oci/apm_traces/models/query_result_metadata_summary.rb', line 32 def query_results_ordered_by @query_results_ordered_by end |
#source_name ⇒ String
Source of the query result set (traces, spans, etc).
20 21 22 |
# File 'lib/oci/apm_traces/models/query_result_metadata_summary.rb', line 20 def source_name @source_name end |
#time_series_interval_in_mins ⇒ Integer
Interval for the time series function in minutes.
37 38 39 |
# File 'lib/oci/apm_traces/models/query_result_metadata_summary.rb', line 37 def time_series_interval_in_mins @time_series_interval_in_mins end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/oci/apm_traces/models/query_result_metadata_summary.rb', line 40 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'query_result_row_type_summaries': :'queryResultRowTypeSummaries', 'source_name': :'sourceName', 'query_results_grouped_by': :'queryResultsGroupedBy', 'query_results_ordered_by': :'queryResultsOrderedBy', 'time_series_interval_in_mins': :'timeSeriesIntervalInMins' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/oci/apm_traces/models/query_result_metadata_summary.rb', line 53 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'query_result_row_type_summaries': :'Array<OCI::ApmTraces::Models::QueryResultRowTypeSummary>', 'source_name': :'String', 'query_results_grouped_by': :'Array<OCI::ApmTraces::Models::QueryResultsGroupedBySummary>', 'query_results_ordered_by': :'Array<OCI::ApmTraces::Models::QueryResultsOrderedBySummary>', 'time_series_interval_in_mins': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
120 121 122 123 124 125 126 127 128 129 |
# File 'lib/oci/apm_traces/models/query_result_metadata_summary.rb', line 120 def ==(other) return true if equal?(other) self.class == other.class && query_result_row_type_summaries == other.query_result_row_type_summaries && source_name == other.source_name && query_results_grouped_by == other.query_results_grouped_by && query_results_ordered_by == other.query_results_ordered_by && time_series_interval_in_mins == other.time_series_interval_in_mins end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/oci/apm_traces/models/query_result_metadata_summary.rb', line 154 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
134 135 136 |
# File 'lib/oci/apm_traces/models/query_result_metadata_summary.rb', line 134 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
143 144 145 |
# File 'lib/oci/apm_traces/models/query_result_metadata_summary.rb', line 143 def hash [query_result_row_type_summaries, source_name, query_results_grouped_by, query_results_ordered_by, time_series_interval_in_mins].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
187 188 189 190 191 192 193 194 195 196 |
# File 'lib/oci/apm_traces/models/query_result_metadata_summary.rb', line 187 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
181 182 183 |
# File 'lib/oci/apm_traces/models/query_result_metadata_summary.rb', line 181 def to_s to_hash.to_s end |