Class: OCI::ApmTraces::Models::QueryResultRow
- Inherits:
-
Object
- Object
- OCI::ApmTraces::Models::QueryResultRow
- Defined in:
- lib/oci/apm_traces/models/query_result_row.rb
Overview
Object that represents a single row of the query result. It contains the queryResultRowData object that contains the actual data represented by the elements of the query result row, and a queryResultRowMetadata object that contains the metadata about the data contained in the query result row.
Instance Attribute Summary collapse
-
#query_result_row_data ⇒ Hash<String, Object>
[Required] A map containing the actual data represented by a single row of the query result.
-
#query_result_row_metadata ⇒ Hash<String, Object>
[Required] A map containing metadata or add-on data for the data presented in the queryResultRowData map.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ QueryResultRow
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ QueryResultRow
Initializes the object
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/oci/apm_traces/models/query_result_row.rb', line 59 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.query_result_row_data = attributes[:'queryResultRowData'] if attributes[:'queryResultRowData'] raise 'You cannot provide both :queryResultRowData and :query_result_row_data' if attributes.key?(:'queryResultRowData') && attributes.key?(:'query_result_row_data') self.query_result_row_data = attributes[:'query_result_row_data'] if attributes[:'query_result_row_data'] self. = attributes[:'queryResultRowMetadata'] if attributes[:'queryResultRowMetadata'] raise 'You cannot provide both :queryResultRowMetadata and :query_result_row_metadata' if attributes.key?(:'queryResultRowMetadata') && attributes.key?(:'query_result_row_metadata') self. = attributes[:'query_result_row_metadata'] if attributes[:'query_result_row_metadata'] end |
Instance Attribute Details
#query_result_row_data ⇒ Hash<String, Object>
[Required] A map containing the actual data represented by a single row of the query result. The key is the column name or attribute specified in the show clause, or an aggregate function in the show clause. The value is the actual value of that attribute or aggregate function of the corresponding single row of the query result set. If an alias name is specified for an attribute or an aggregate function, then the key will be the alias name specified in the show clause. If an alias name is not specified for the group by aggregate function in the show clause, then the corresponding key will be the appropriate aggregate_function_name_column_name (For example: count(traces) will be keyed as count_traces). The datatype of the value is presented in the queryResultRowTypeSummaries list in the queryResultMetadata structure, where the i-th queryResultRowTypeSummary object represents the datatype of the i-th value when this map is iterated in order.
23 24 25 |
# File 'lib/oci/apm_traces/models/query_result_row.rb', line 23 def query_result_row_data @query_result_row_data end |
#query_result_row_metadata ⇒ Hash<String, Object>
[Required] A map containing metadata or add-on data for the data presented in the queryResultRowData map. Data required to present drill down information from the queryResultRowData is presented as key-value pairs.
29 30 31 |
# File 'lib/oci/apm_traces/models/query_result_row.rb', line 29 def end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 |
# File 'lib/oci/apm_traces/models/query_result_row.rb', line 32 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'query_result_row_data': :'queryResultRowData', 'query_result_row_metadata': :'queryResultRowMetadata' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
42 43 44 45 46 47 48 49 |
# File 'lib/oci/apm_traces/models/query_result_row.rb', line 42 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'query_result_row_data': :'Hash<String, Object>', 'query_result_row_metadata': :'Hash<String, Object>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
85 86 87 88 89 90 91 |
# File 'lib/oci/apm_traces/models/query_result_row.rb', line 85 def ==(other) return true if equal?(other) self.class == other.class && query_result_row_data == other.query_result_row_data && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/oci/apm_traces/models/query_result_row.rb', line 116 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
96 97 98 |
# File 'lib/oci/apm_traces/models/query_result_row.rb', line 96 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
105 106 107 |
# File 'lib/oci/apm_traces/models/query_result_row.rb', line 105 def hash [query_result_row_data, ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
149 150 151 152 153 154 155 156 157 158 |
# File 'lib/oci/apm_traces/models/query_result_row.rb', line 149 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
143 144 145 |
# File 'lib/oci/apm_traces/models/query_result_row.rb', line 143 def to_s to_hash.to_s end |