Class: OCI::ApmTraces::Models::SpanSnapshot

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/apm_traces/models/span_snapshot.rb

Overview

Definition of a span snapshot object.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ SpanSnapshot

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/oci/apm_traces/models/span_snapshot.rb', line 89

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.key = attributes[:'key'] if attributes[:'key']

  self.span_name = attributes[:'spanName'] if attributes[:'spanName']

  raise 'You cannot provide both :spanName and :span_name' if attributes.key?(:'spanName') && attributes.key?(:'span_name')

  self.span_name = attributes[:'span_name'] if attributes[:'span_name']

  self.time_started = attributes[:'timeStarted'] if attributes[:'timeStarted']

  raise 'You cannot provide both :timeStarted and :time_started' if attributes.key?(:'timeStarted') && attributes.key?(:'time_started')

  self.time_started = attributes[:'time_started'] if attributes[:'time_started']

  self.time_ended = attributes[:'timeEnded'] if attributes[:'timeEnded']

  raise 'You cannot provide both :timeEnded and :time_ended' if attributes.key?(:'timeEnded') && attributes.key?(:'time_ended')

  self.time_ended = attributes[:'time_ended'] if attributes[:'time_ended']

  self.span_snapshot_details = attributes[:'spanSnapshotDetails'] if attributes[:'spanSnapshotDetails']

  raise 'You cannot provide both :spanSnapshotDetails and :span_snapshot_details' if attributes.key?(:'spanSnapshotDetails') && attributes.key?(:'span_snapshot_details')

  self.span_snapshot_details = attributes[:'span_snapshot_details'] if attributes[:'span_snapshot_details']

  self.thread_snapshots = attributes[:'threadSnapshots'] if attributes[:'threadSnapshots']

  raise 'You cannot provide both :threadSnapshots and :thread_snapshots' if attributes.key?(:'threadSnapshots') && attributes.key?(:'thread_snapshots')

  self.thread_snapshots = attributes[:'thread_snapshots'] if attributes[:'thread_snapshots']

  self.children = attributes[:'children'] if attributes[:'children']
end

Instance Attribute Details

#childrenArray<OCI::ApmTraces::Models::SpanSnapshot>

An array of child span snapshots.



44
45
46
# File 'lib/oci/apm_traces/models/span_snapshot.rb', line 44

def children
  @children
end

#keyString

**[Required]** Unique identifier (spanId) for the trace span.

Returns:

  • (String)


14
15
16
# File 'lib/oci/apm_traces/models/span_snapshot.rb', line 14

def key
  @key
end

#span_nameString

Span name associated with the trace.

Returns:

  • (String)


19
20
21
# File 'lib/oci/apm_traces/models/span_snapshot.rb', line 19

def span_name
  @span_name
end

#span_snapshot_detailsArray<OCI::ApmTraces::Models::SnapshotDetail>

Span snapshots properties.



34
35
36
# File 'lib/oci/apm_traces/models/span_snapshot.rb', line 34

def span_snapshot_details
  @span_snapshot_details
end

#thread_snapshotsArray<OCI::ApmTraces::Models::ThreadSnapshot>

Thread snapshots.



39
40
41
# File 'lib/oci/apm_traces/models/span_snapshot.rb', line 39

def thread_snapshots
  @thread_snapshots
end

#time_endedDateTime

**[Required]** End time of the span.

Returns:

  • (DateTime)


29
30
31
# File 'lib/oci/apm_traces/models/span_snapshot.rb', line 29

def time_ended
  @time_ended
end

#time_startedDateTime

**[Required]** Start time of the span.

Returns:

  • (DateTime)


24
25
26
# File 'lib/oci/apm_traces/models/span_snapshot.rb', line 24

def time_started
  @time_started
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



47
48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/oci/apm_traces/models/span_snapshot.rb', line 47

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'key',
    'span_name': :'spanName',
    'time_started': :'timeStarted',
    'time_ended': :'timeEnded',
    'span_snapshot_details': :'spanSnapshotDetails',
    'thread_snapshots': :'threadSnapshots',
    'children': :'children'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/oci/apm_traces/models/span_snapshot.rb', line 62

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'String',
    'span_name': :'String',
    'time_started': :'DateTime',
    'time_ended': :'DateTime',
    'span_snapshot_details': :'Array<OCI::ApmTraces::Models::SnapshotDetail>',
    'thread_snapshots': :'Array<OCI::ApmTraces::Models::ThreadSnapshot>',
    'children': :'Array<OCI::ApmTraces::Models::SpanSnapshot>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



137
138
139
140
141
142
143
144
145
146
147
148
# File 'lib/oci/apm_traces/models/span_snapshot.rb', line 137

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    key == other.key &&
    span_name == other.span_name &&
    time_started == other.time_started &&
    time_ended == other.time_ended &&
    span_snapshot_details == other.span_snapshot_details &&
    thread_snapshots == other.thread_snapshots &&
    children == other.children
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/oci/apm_traces/models/span_snapshot.rb', line 173

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


153
154
155
# File 'lib/oci/apm_traces/models/span_snapshot.rb', line 153

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



162
163
164
# File 'lib/oci/apm_traces/models/span_snapshot.rb', line 162

def hash
  [key, span_name, time_started, time_ended, span_snapshot_details, thread_snapshots, children].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



206
207
208
209
210
211
212
213
214
215
# File 'lib/oci/apm_traces/models/span_snapshot.rb', line 206

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



200
201
202
# File 'lib/oci/apm_traces/models/span_snapshot.rb', line 200

def to_s
  to_hash.to_s
end