Class: OCI::ApmTraces::Models::StackTraceElement

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/apm_traces/models/stack_trace_element.rb

Overview

Stack trace element.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ StackTraceElement

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :method_name (String)

    The value to assign to the #method_name property

  • :file_name (String)

    The value to assign to the #file_name property

  • :line_number (Integer)

    The value to assign to the #line_number property

  • :class_name (String)

    The value to assign to the #class_name property

  • :weightage (Float)

    The value to assign to the #weightage property



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/oci/apm_traces/models/stack_trace_element.rb', line 73

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.method_name = attributes[:'methodName'] if attributes[:'methodName']

  raise 'You cannot provide both :methodName and :method_name' if attributes.key?(:'methodName') && attributes.key?(:'method_name')

  self.method_name = attributes[:'method_name'] if attributes[:'method_name']

  self.file_name = attributes[:'fileName'] if attributes[:'fileName']

  raise 'You cannot provide both :fileName and :file_name' if attributes.key?(:'fileName') && attributes.key?(:'file_name')

  self.file_name = attributes[:'file_name'] if attributes[:'file_name']

  self.line_number = attributes[:'lineNumber'] if attributes[:'lineNumber']

  raise 'You cannot provide both :lineNumber and :line_number' if attributes.key?(:'lineNumber') && attributes.key?(:'line_number')

  self.line_number = attributes[:'line_number'] if attributes[:'line_number']

  self.class_name = attributes[:'className'] if attributes[:'className']

  raise 'You cannot provide both :className and :class_name' if attributes.key?(:'className') && attributes.key?(:'class_name')

  self.class_name = attributes[:'class_name'] if attributes[:'class_name']

  self.weightage = attributes[:'weightage'] if attributes[:'weightage']
end

Instance Attribute Details

#class_nameString

Name of the class containing the execution point.

Returns:

  • (String)


29
30
31
# File 'lib/oci/apm_traces/models/stack_trace_element.rb', line 29

def class_name
  @class_name
end

#file_nameString

Name of the source file containing the execution point.

Returns:

  • (String)


19
20
21
# File 'lib/oci/apm_traces/models/stack_trace_element.rb', line 19

def file_name
  @file_name
end

#line_numberInteger

Line number of the source line containing the execution point.

Returns:

  • (Integer)


24
25
26
# File 'lib/oci/apm_traces/models/stack_trace_element.rb', line 24

def line_number
  @line_number
end

#method_nameString

Name of the method containing the execution point.

Returns:

  • (String)


14
15
16
# File 'lib/oci/apm_traces/models/stack_trace_element.rb', line 14

def method_name
  @method_name
end

#weightageFloat

The weight distribution that denotes the percentage occurrence of a method in the captured snapshots.

Returns:

  • (Float)


34
35
36
# File 'lib/oci/apm_traces/models/stack_trace_element.rb', line 34

def weightage
  @weightage
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
47
# File 'lib/oci/apm_traces/models/stack_trace_element.rb', line 37

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'method_name': :'methodName',
    'file_name': :'fileName',
    'line_number': :'lineNumber',
    'class_name': :'className',
    'weightage': :'weightage'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



50
51
52
53
54
55
56
57
58
59
60
# File 'lib/oci/apm_traces/models/stack_trace_element.rb', line 50

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'method_name': :'String',
    'file_name': :'String',
    'line_number': :'Integer',
    'class_name': :'String',
    'weightage': :'Float'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



113
114
115
116
117
118
119
120
121
122
# File 'lib/oci/apm_traces/models/stack_trace_element.rb', line 113

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    method_name == other.method_name &&
    file_name == other.file_name &&
    line_number == other.line_number &&
    class_name == other.class_name &&
    weightage == other.weightage
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/oci/apm_traces/models/stack_trace_element.rb', line 147

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


127
128
129
# File 'lib/oci/apm_traces/models/stack_trace_element.rb', line 127

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



136
137
138
# File 'lib/oci/apm_traces/models/stack_trace_element.rb', line 136

def hash
  [method_name, file_name, line_number, class_name, weightage].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



180
181
182
183
184
185
186
187
188
189
# File 'lib/oci/apm_traces/models/stack_trace_element.rb', line 180

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



174
175
176
# File 'lib/oci/apm_traces/models/stack_trace_element.rb', line 174

def to_s
  to_hash.to_s
end