Class: OCI::ApmTraces::Models::TraceSnapshot

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/apm_traces/models/trace_snapshot.rb

Overview

Definition of a trace snapshot object.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ TraceSnapshot

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/oci/apm_traces/models/trace_snapshot.rb', line 75

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.key = attributes[:'key'] if attributes[:'key']

  self.time_started = attributes[:'timeStarted'] if attributes[:'timeStarted']

  raise 'You cannot provide both :timeStarted and :time_started' if attributes.key?(:'timeStarted') && attributes.key?(:'time_started')

  self.time_started = attributes[:'time_started'] if attributes[:'time_started']

  self.time_ended = attributes[:'timeEnded'] if attributes[:'timeEnded']

  raise 'You cannot provide both :timeEnded and :time_ended' if attributes.key?(:'timeEnded') && attributes.key?(:'time_ended')

  self.time_ended = attributes[:'time_ended'] if attributes[:'time_ended']

  self.trace_snapshot_details = attributes[:'traceSnapshotDetails'] if attributes[:'traceSnapshotDetails']

  raise 'You cannot provide both :traceSnapshotDetails and :trace_snapshot_details' if attributes.key?(:'traceSnapshotDetails') && attributes.key?(:'trace_snapshot_details')

  self.trace_snapshot_details = attributes[:'trace_snapshot_details'] if attributes[:'trace_snapshot_details']

  self.span_snapshots = attributes[:'spanSnapshots'] if attributes[:'spanSnapshots']

  raise 'You cannot provide both :spanSnapshots and :span_snapshots' if attributes.key?(:'spanSnapshots') && attributes.key?(:'span_snapshots')

  self.span_snapshots = attributes[:'span_snapshots'] if attributes[:'span_snapshots']
end

Instance Attribute Details

#keyString

**[Required]** Unique identifier (traceId) for the trace that represents the span set. Note that this field is defined as traceKey in the API and it maps to the traceId in the trace data in Application Performance Monitoring.

Returns:

  • (String)


16
17
18
# File 'lib/oci/apm_traces/models/trace_snapshot.rb', line 16

def key
  @key
end

#span_snapshotsArray<OCI::ApmTraces::Models::SpanSnapshot>

**[Required]** List of spans.



36
37
38
# File 'lib/oci/apm_traces/models/trace_snapshot.rb', line 36

def span_snapshots
  @span_snapshots
end

#time_endedDateTime

End time of the trace.

Returns:

  • (DateTime)


26
27
28
# File 'lib/oci/apm_traces/models/trace_snapshot.rb', line 26

def time_ended
  @time_ended
end

#time_startedDateTime

Start time of the trace.

Returns:

  • (DateTime)


21
22
23
# File 'lib/oci/apm_traces/models/trace_snapshot.rb', line 21

def time_started
  @time_started
end

#trace_snapshot_detailsArray<OCI::ApmTraces::Models::SnapshotDetail>

Trace snapshots properties.



31
32
33
# File 'lib/oci/apm_traces/models/trace_snapshot.rb', line 31

def trace_snapshot_details
  @trace_snapshot_details
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



39
40
41
42
43
44
45
46
47
48
49
# File 'lib/oci/apm_traces/models/trace_snapshot.rb', line 39

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'key',
    'time_started': :'timeStarted',
    'time_ended': :'timeEnded',
    'trace_snapshot_details': :'traceSnapshotDetails',
    'span_snapshots': :'spanSnapshots'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



52
53
54
55
56
57
58
59
60
61
62
# File 'lib/oci/apm_traces/models/trace_snapshot.rb', line 52

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'String',
    'time_started': :'DateTime',
    'time_ended': :'DateTime',
    'trace_snapshot_details': :'Array<OCI::ApmTraces::Models::SnapshotDetail>',
    'span_snapshots': :'Array<OCI::ApmTraces::Models::SpanSnapshot>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



115
116
117
118
119
120
121
122
123
124
# File 'lib/oci/apm_traces/models/trace_snapshot.rb', line 115

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    key == other.key &&
    time_started == other.time_started &&
    time_ended == other.time_ended &&
    trace_snapshot_details == other.trace_snapshot_details &&
    span_snapshots == other.span_snapshots
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/oci/apm_traces/models/trace_snapshot.rb', line 149

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


129
130
131
# File 'lib/oci/apm_traces/models/trace_snapshot.rb', line 129

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



138
139
140
# File 'lib/oci/apm_traces/models/trace_snapshot.rb', line 138

def hash
  [key, time_started, time_ended, trace_snapshot_details, span_snapshots].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



182
183
184
185
186
187
188
189
190
191
# File 'lib/oci/apm_traces/models/trace_snapshot.rb', line 182

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



176
177
178
# File 'lib/oci/apm_traces/models/trace_snapshot.rb', line 176

def to_s
  to_hash.to_s
end