Class: OCI::ApplicationMigration::Models::AuthorizationDetails
- Inherits:
-
Object
- Object
- OCI::ApplicationMigration::Models::AuthorizationDetails
- Defined in:
- lib/oci/application_migration/models/authorization_details.rb
Overview
Details of the source environment from which you want to migrate applications to Oracle Cloud Infrastructure. It also contains access credentials.
This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
InternalAuthorizationDetails, OccAuthorizationDetails, OcicAuthorizationDetails, OcicAuthorizationTokenDetails
Constant Summary collapse
- TYPE_ENUM =
[ TYPE_OCIC = 'OCIC'.freeze, TYPE_INTERNAL_COMPUTE = 'INTERNAL_COMPUTE'.freeze, TYPE_OCC = 'OCC'.freeze, TYPE_OCIC_IDCS = 'OCIC_IDCS'.freeze, TYPE_IMPORT = 'IMPORT'.freeze ].freeze
Instance Attribute Summary collapse
-
#type ⇒ String
[Required] Type of the source environment from which you are migrating applications to Oracle Cloud Infrastructure.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AuthorizationDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ AuthorizationDetails
Initializes the object
68 69 70 71 72 73 74 75 |
# File 'lib/oci/application_migration/models/authorization_details.rb', line 68 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.type = attributes[:'type'] if attributes[:'type'] end |
Instance Attribute Details
#type ⇒ String
[Required] Type of the source environment from which you are migrating applications to Oracle Cloud Infrastructure.
23 24 25 |
# File 'lib/oci/application_migration/models/authorization_details.rb', line 23 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
26 27 28 29 30 31 32 |
# File 'lib/oci/application_migration/models/authorization_details.rb', line 26 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'type': :'type' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/oci/application_migration/models/authorization_details.rb', line 48 def self.get_subtype(object_hash) type = object_hash[:'type'] # rubocop:disable Style/SymbolLiteral return 'OCI::ApplicationMigration::Models::OccAuthorizationDetails' if type == 'OCC' return 'OCI::ApplicationMigration::Models::InternalAuthorizationDetails' if type == 'INTERNAL_COMPUTE' return 'OCI::ApplicationMigration::Models::OcicAuthorizationTokenDetails' if type == 'OCIC_IDCS' return 'OCI::ApplicationMigration::Models::OcicAuthorizationDetails' if type == 'OCIC' # TODO: Log a warning when the subtype is not found. 'OCI::ApplicationMigration::Models::AuthorizationDetails' end |
.swagger_types ⇒ Object
Attribute type mapping.
35 36 37 38 39 40 41 |
# File 'lib/oci/application_migration/models/authorization_details.rb', line 35 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'type': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
92 93 94 95 96 97 |
# File 'lib/oci/application_migration/models/authorization_details.rb', line 92 def ==(other) return true if equal?(other) self.class == other.class && type == other.type end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/oci/application_migration/models/authorization_details.rb', line 122 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
102 103 104 |
# File 'lib/oci/application_migration/models/authorization_details.rb', line 102 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
111 112 113 |
# File 'lib/oci/application_migration/models/authorization_details.rb', line 111 def hash [type].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
155 156 157 158 159 160 161 162 163 164 |
# File 'lib/oci/application_migration/models/authorization_details.rb', line 155 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
149 150 151 |
# File 'lib/oci/application_migration/models/authorization_details.rb', line 149 def to_s to_hash.to_s end |