Class: OCI::ApplicationMigration::Models::CreateSourceDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/application_migration/models/create_source_details.rb

Overview

The configuration details for creating a source.

When you create a source, provide the required information to let Application Migration access the source environment. You must also assign a name and provide a description for the source. This helps you to identify the appropriate source environment when you have multiple sources defined.

Warning: Oracle recommends that you avoid using any confidential information when you supply string values using the API.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateSourceDetails

Initializes the object

Options Hash (attributes):



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/oci/application_migration/models/create_source_details.rb', line 92

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.source_details = attributes[:'sourceDetails'] if attributes[:'sourceDetails']

  raise 'You cannot provide both :sourceDetails and :source_details' if attributes.key?(:'sourceDetails') && attributes.key?(:'source_details')

  self.source_details = attributes[:'source_details'] if attributes[:'source_details']

  self.authorization_details = attributes[:'authorizationDetails'] if attributes[:'authorizationDetails']

  raise 'You cannot provide both :authorizationDetails and :authorization_details' if attributes.key?(:'authorizationDetails') && attributes.key?(:'authorization_details')

  self.authorization_details = attributes[:'authorization_details'] if attributes[:'authorization_details']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#authorization_detailsOCI::ApplicationMigration::Models::AuthorizationDetails



35
36
37
# File 'lib/oci/application_migration/models/create_source_details.rb', line 35

def authorization_details
  @authorization_details
end

#compartment_idString

[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment that contains the source.



20
21
22
# File 'lib/oci/application_migration/models/create_source_details.rb', line 20

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"CostCenter": "42"}`



47
48
49
# File 'lib/oci/application_migration/models/create_source_details.rb', line 47

def defined_tags
  @defined_tags
end

#descriptionString

Description of the source. This helps you to identify the appropriate source environment when you have multiple sources defined.



28
29
30
# File 'lib/oci/application_migration/models/create_source_details.rb', line 28

def description
  @description
end

#display_nameString

Name of the source. This helps you to identify the appropriate source environment when you have multiple sources defined.



24
25
26
# File 'lib/oci/application_migration/models/create_source_details.rb', line 24

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"Finance"`



41
42
43
# File 'lib/oci/application_migration/models/create_source_details.rb', line 41

def freeform_tags
  @freeform_tags
end

#source_detailsOCI::ApplicationMigration::Models::SourceDetails

This attribute is required.



32
33
34
# File 'lib/oci/application_migration/models/create_source_details.rb', line 32

def source_details
  @source_details
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/oci/application_migration/models/create_source_details.rb', line 50

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'compartmentId',
    'display_name': :'displayName',
    'description': :'description',
    'source_details': :'sourceDetails',
    'authorization_details': :'authorizationDetails',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/oci/application_migration/models/create_source_details.rb', line 65

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'String',
    'display_name': :'String',
    'description': :'String',
    'source_details': :'OCI::ApplicationMigration::Models::SourceDetails',
    'authorization_details': :'OCI::ApplicationMigration::Models::AuthorizationDetails',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.



144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/oci/application_migration/models/create_source_details.rb', line 144

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    compartment_id == other.compartment_id &&
    display_name == other.display_name &&
    description == other.description &&
    source_details == other.source_details &&
    authorization_details == other.authorization_details &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/oci/application_migration/models/create_source_details.rb', line 180

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method


160
161
162
# File 'lib/oci/application_migration/models/create_source_details.rb', line 160

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.



169
170
171
# File 'lib/oci/application_migration/models/create_source_details.rb', line 169

def hash
  [compartment_id, display_name, description, source_details, authorization_details, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash



213
214
215
216
217
218
219
220
221
222
# File 'lib/oci/application_migration/models/create_source_details.rb', line 213

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



207
208
209
# File 'lib/oci/application_migration/models/create_source_details.rb', line 207

def to_s
  to_hash.to_s
end