Class: OCI::ApplicationMigration::Models::IcsDiscoveryDetails
- Inherits:
-
DiscoveryDetails
- Object
- DiscoveryDetails
- OCI::ApplicationMigration::Models::IcsDiscoveryDetails
- Defined in:
- lib/oci/application_migration/models/ics_discovery_details.rb
Overview
Credentials to access the Oracle Integration Cloud Service application in the source environment. Application Migration connects to the application in the source environment with the supplied credentials.
Constant Summary
Constants inherited from DiscoveryDetails
Instance Attribute Summary collapse
-
#service_instance_password ⇒ String
**[Required]** Password for this user.
-
#service_instance_user ⇒ String
**[Required]** Application administrator username to access the Oracle Integration Cloud Service application in the source environment.
Attributes inherited from DiscoveryDetails
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IcsDiscoveryDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from DiscoveryDetails
Constructor Details
#initialize(attributes = {}) ⇒ IcsDiscoveryDetails
Initializes the object
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/oci/application_migration/models/ics_discovery_details.rb', line 51 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['type'] = 'ICS' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.service_instance_user = attributes[:'serviceInstanceUser'] if attributes[:'serviceInstanceUser'] raise 'You cannot provide both :serviceInstanceUser and :service_instance_user' if attributes.key?(:'serviceInstanceUser') && attributes.key?(:'service_instance_user') self.service_instance_user = attributes[:'service_instance_user'] if attributes[:'service_instance_user'] self.service_instance_password = attributes[:'serviceInstancePassword'] if attributes[:'serviceInstancePassword'] raise 'You cannot provide both :serviceInstancePassword and :service_instance_password' if attributes.key?(:'serviceInstancePassword') && attributes.key?(:'service_instance_password') self.service_instance_password = attributes[:'service_instance_password'] if attributes[:'service_instance_password'] end |
Instance Attribute Details
#service_instance_password ⇒ String
**[Required]** Password for this user.
19 20 21 |
# File 'lib/oci/application_migration/models/ics_discovery_details.rb', line 19 def service_instance_password @service_instance_password end |
#service_instance_user ⇒ String
**[Required]** Application administrator username to access the Oracle Integration Cloud Service application in the source environment.
15 16 17 |
# File 'lib/oci/application_migration/models/ics_discovery_details.rb', line 15 def service_instance_user @service_instance_user end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
22 23 24 25 26 27 28 29 30 |
# File 'lib/oci/application_migration/models/ics_discovery_details.rb', line 22 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'type': :'type', 'service_instance_user': :'serviceInstanceUser', 'service_instance_password': :'serviceInstancePassword' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
33 34 35 36 37 38 39 40 41 |
# File 'lib/oci/application_migration/models/ics_discovery_details.rb', line 33 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'type': :'String', 'service_instance_user': :'String', 'service_instance_password': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
81 82 83 84 85 86 87 88 |
# File 'lib/oci/application_migration/models/ics_discovery_details.rb', line 81 def ==(other) return true if equal?(other) self.class == other.class && type == other.type && service_instance_user == other.service_instance_user && service_instance_password == other.service_instance_password end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/oci/application_migration/models/ics_discovery_details.rb', line 113 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
93 94 95 |
# File 'lib/oci/application_migration/models/ics_discovery_details.rb', line 93 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
102 103 104 |
# File 'lib/oci/application_migration/models/ics_discovery_details.rb', line 102 def hash [type, service_instance_user, service_instance_password].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
146 147 148 149 150 151 152 153 154 155 |
# File 'lib/oci/application_migration/models/ics_discovery_details.rb', line 146 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
140 141 142 |
# File 'lib/oci/application_migration/models/ics_discovery_details.rb', line 140 def to_s to_hash.to_s end |