Class: OCI::ApplicationMigration::Models::ImportSourceDetails

Inherits:
SourceDetails
  • Object
show all
Defined in:
lib/oci/application_migration/models/import_source_details.rb

Overview

/ Basic details about the source, import manifest and object storage bucket as well as object name of the archive that should be used during import

Constant Summary

Constants inherited from SourceDetails

SourceDetails::TYPE_ENUM

Instance Attribute Summary collapse

Attributes inherited from SourceDetails

#type

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from SourceDetails

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ ImportSourceDetails

Initializes the object

Options Hash (attributes):



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/oci/application_migration/models/import_source_details.rb', line 63

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['type'] = 'IMPORT'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.manifest = attributes[:'manifest'] if attributes[:'manifest']

  self.namespace = attributes[:'namespace'] if attributes[:'namespace']

  self.bucket = attributes[:'bucket'] if attributes[:'bucket']

  self.object_name = attributes[:'objectName'] if attributes[:'objectName']

  raise 'You cannot provide both :objectName and :object_name' if attributes.key?(:'objectName') && attributes.key?(:'object_name')

  self.object_name = attributes[:'object_name'] if attributes[:'object_name']
end

Instance Attribute Details

#bucketString

[Required] the bucket wherein the export archive exists in object storage



21
22
23
# File 'lib/oci/application_migration/models/import_source_details.rb', line 21

def bucket
  @bucket
end

#manifestOCI::ApplicationMigration::Models::ImportManifest

This attribute is required.



13
14
15
# File 'lib/oci/application_migration/models/import_source_details.rb', line 13

def manifest
  @manifest
end

#namespaceString

[Required] the object storage namespace where the bucket and uploaded object resides



17
18
19
# File 'lib/oci/application_migration/models/import_source_details.rb', line 17

def namespace
  @namespace
end

#object_nameString

[Required] the name of the archive as it exists in object storage



25
26
27
# File 'lib/oci/application_migration/models/import_source_details.rb', line 25

def object_name
  @object_name
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



28
29
30
31
32
33
34
35
36
37
38
# File 'lib/oci/application_migration/models/import_source_details.rb', line 28

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'type': :'type',
    'manifest': :'manifest',
    'namespace': :'namespace',
    'bucket': :'bucket',
    'object_name': :'objectName'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



41
42
43
44
45
46
47
48
49
50
51
# File 'lib/oci/application_migration/models/import_source_details.rb', line 41

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'type': :'String',
    'manifest': :'OCI::ApplicationMigration::Models::ImportManifest',
    'namespace': :'String',
    'bucket': :'String',
    'object_name': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.



93
94
95
96
97
98
99
100
101
102
# File 'lib/oci/application_migration/models/import_source_details.rb', line 93

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    type == other.type &&
    manifest == other.manifest &&
    namespace == other.namespace &&
    bucket == other.bucket &&
    object_name == other.object_name
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/oci/application_migration/models/import_source_details.rb', line 127

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method


107
108
109
# File 'lib/oci/application_migration/models/import_source_details.rb', line 107

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.



116
117
118
# File 'lib/oci/application_migration/models/import_source_details.rb', line 116

def hash
  [type, manifest, namespace, bucket, object_name].hash
end

#to_hashHash

Returns the object in the form of hash



160
161
162
163
164
165
166
167
168
169
# File 'lib/oci/application_migration/models/import_source_details.rb', line 160

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



154
155
156
# File 'lib/oci/application_migration/models/import_source_details.rb', line 154

def to_s
  to_hash.to_s
end