Class: OCI::ApplicationMigration::Models::MigrationSummary
- Inherits:
-
Object
- Object
- OCI::ApplicationMigration::Models::MigrationSummary
- Defined in:
- lib/oci/application_migration/models/migration_summary.rb
Overview
Details about the migration. Each migration moves a single application from a specified source to Oracle Cloud Infrastructure.
Constant Summary collapse
- APPLICATION_TYPE_ENUM =
[ APPLICATION_TYPE_JCS = 'JCS'.freeze, APPLICATION_TYPE_SOACS = 'SOACS'.freeze, APPLICATION_TYPE_OIC = 'OIC'.freeze, APPLICATION_TYPE_OAC = 'OAC'.freeze, APPLICATION_TYPE_ICS = 'ICS'.freeze, APPLICATION_TYPE_PCS = 'PCS'.freeze, APPLICATION_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_SUCCEEDED = 'SUCCEEDED'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- MIGRATION_STATE_ENUM =
[ MIGRATION_STATE_DISCOVERING_APPLICATION = 'DISCOVERING_APPLICATION'.freeze, MIGRATION_STATE_DISCOVERY_FAILED = 'DISCOVERY_FAILED'.freeze, MIGRATION_STATE_MISSING_CONFIG_VALUES = 'MISSING_CONFIG_VALUES'.freeze, MIGRATION_STATE_READY = 'READY'.freeze, MIGRATION_STATE_MIGRATING = 'MIGRATING'.freeze, MIGRATION_STATE_MIGRATION_FAILED = 'MIGRATION_FAILED'.freeze, MIGRATION_STATE_MIGRATION_SUCCEEDED = 'MIGRATION_SUCCEEDED'.freeze, MIGRATION_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#application_name ⇒ String
Name of the application which is being migrated from the source environment.
-
#application_type ⇒ String
The type of application being migrated.
-
#compartment_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment that contains the migration.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
Description of the migration.
-
#display_name ⇒ String
User-friendly name of the migration.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the migration.
-
#lifecycle_details ⇒ String
Details about the current lifecycle state.
-
#lifecycle_state ⇒ String
The current state of the migration.
-
#migration_state ⇒ String
The current state of the overall migration process.
-
#source_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the source.
-
#time_created ⇒ DateTime
The date and time at which the migration was created, in the format defined by RFC3339.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MigrationSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ MigrationSummary
Initializes the object
162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/oci/application_migration/models/migration_summary.rb', line 162 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.source_id = attributes[:'sourceId'] if attributes[:'sourceId'] raise 'You cannot provide both :sourceId and :source_id' if attributes.key?(:'sourceId') && attributes.key?(:'source_id') self.source_id = attributes[:'source_id'] if attributes[:'source_id'] self.application_name = attributes[:'applicationName'] if attributes[:'applicationName'] raise 'You cannot provide both :applicationName and :application_name' if attributes.key?(:'applicationName') && attributes.key?(:'application_name') self.application_name = attributes[:'application_name'] if attributes[:'application_name'] self.application_type = attributes[:'applicationType'] if attributes[:'applicationType'] raise 'You cannot provide both :applicationType and :application_type' if attributes.key?(:'applicationType') && attributes.key?(:'application_type') self.application_type = attributes[:'application_type'] if attributes[:'application_type'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.migration_state = attributes[:'migrationState'] if attributes[:'migrationState'] raise 'You cannot provide both :migrationState and :migration_state' if attributes.key?(:'migrationState') && attributes.key?(:'migration_state') self.migration_state = attributes[:'migration_state'] if attributes[:'migration_state'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#application_name ⇒ String
Name of the application which is being migrated from the source environment.
71 72 73 |
# File 'lib/oci/application_migration/models/migration_summary.rb', line 71 def application_name @application_name end |
#application_type ⇒ String
The type of application being migrated.
75 76 77 |
# File 'lib/oci/application_migration/models/migration_summary.rb', line 75 def application_type @application_type end |
#compartment_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment that contains the migration.
51 52 53 |
# File 'lib/oci/application_migration/models/migration_summary.rb', line 51 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"CostCenter": "42"}`
99 100 101 |
# File 'lib/oci/application_migration/models/migration_summary.rb', line 99 def @defined_tags end |
#description ⇒ String
Description of the migration.
59 60 61 |
# File 'lib/oci/application_migration/models/migration_summary.rb', line 59 def description @description end |
#display_name ⇒ String
User-friendly name of the migration.
55 56 57 |
# File 'lib/oci/application_migration/models/migration_summary.rb', line 55 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"Finance"`
93 94 95 |
# File 'lib/oci/application_migration/models/migration_summary.rb', line 93 def @freeform_tags end |
#id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the migration.
46 47 48 |
# File 'lib/oci/application_migration/models/migration_summary.rb', line 46 def id @id end |
#lifecycle_details ⇒ String
Details about the current lifecycle state.
83 84 85 |
# File 'lib/oci/application_migration/models/migration_summary.rb', line 83 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
The current state of the migration.
79 80 81 |
# File 'lib/oci/application_migration/models/migration_summary.rb', line 79 def lifecycle_state @lifecycle_state end |
#migration_state ⇒ String
The current state of the overall migration process.
87 88 89 |
# File 'lib/oci/application_migration/models/migration_summary.rb', line 87 def migration_state @migration_state end |
#source_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the source.
67 68 69 |
# File 'lib/oci/application_migration/models/migration_summary.rb', line 67 def source_id @source_id end |
#time_created ⇒ DateTime
The date and time at which the migration was created, in the format defined by RFC3339.
63 64 65 |
# File 'lib/oci/application_migration/models/migration_summary.rb', line 63 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/oci/application_migration/models/migration_summary.rb', line 102 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'description': :'description', 'time_created': :'timeCreated', 'source_id': :'sourceId', 'application_name': :'applicationName', 'application_type': :'applicationType', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'migration_state': :'migrationState', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/oci/application_migration/models/migration_summary.rb', line 123 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'display_name': :'String', 'description': :'String', 'time_created': :'DateTime', 'source_id': :'String', 'application_name': :'String', 'application_type': :'String', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'migration_state': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/oci/application_migration/models/migration_summary.rb', line 285 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && display_name == other.display_name && description == other.description && time_created == other.time_created && source_id == other.source_id && application_name == other.application_name && application_type == other.application_type && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && migration_state == other.migration_state && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/oci/application_migration/models/migration_summary.rb', line 327 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
307 308 309 |
# File 'lib/oci/application_migration/models/migration_summary.rb', line 307 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
316 317 318 |
# File 'lib/oci/application_migration/models/migration_summary.rb', line 316 def hash [id, compartment_id, display_name, description, time_created, source_id, application_name, application_type, lifecycle_state, lifecycle_details, migration_state, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
360 361 362 363 364 365 366 367 368 369 |
# File 'lib/oci/application_migration/models/migration_summary.rb', line 360 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
354 355 356 |
# File 'lib/oci/application_migration/models/migration_summary.rb', line 354 def to_s to_hash.to_s end |