Class: OCI::ApplicationMigration::Models::SourceDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/application_migration/models/source_details.rb

Overview

Specify one of the following values depending for the ‘type’ attribute based on the application that you want to migrate.

Specify OCIC if you want to migrate Oracle Java Cloud Service, Oracle Analytics Cloud - Classic, Oracle Integration, and Oracle SOA Cloud Service applications from Oracle Cloud Infrastructure - Classic.

Specify INTERNAL_COMPUTE if you have a traditional Oracle Cloud Infrastructure - Classic account and you want to migrate Oracle Process Cloud Service or Oracle Integration Cloud Service applications.

Specify OCC if you want to migrate applications from Oracle Cloud@Customer.

This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class

Constant Summary collapse

TYPE_ENUM =
[
  TYPE_OCIC = 'OCIC'.freeze,
  TYPE_INTERNAL_COMPUTE = 'INTERNAL_COMPUTE'.freeze,
  TYPE_OCC = 'OCC'.freeze,
  TYPE_OCIC_IDCS = 'OCIC_IDCS'.freeze,
  TYPE_IMPORT = 'IMPORT'.freeze,
  TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ SourceDetails

Initializes the object

Options Hash (attributes):

  • :type (String)

    The value to assign to the #type property



78
79
80
81
82
83
84
85
# File 'lib/oci/application_migration/models/source_details.rb', line 78

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.type = attributes[:'type'] if attributes[:'type']
end

Instance Attribute Details

#typeString

[Required] The type of source environment.



33
34
35
# File 'lib/oci/application_migration/models/source_details.rb', line 33

def type
  @type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



36
37
38
39
40
41
42
# File 'lib/oci/application_migration/models/source_details.rb', line 36

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'type': :'type'
    # rubocop:enable Style/SymbolLiteral
  }
end

.get_subtype(object_hash) ⇒ Object

Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.



58
59
60
61
62
63
64
65
66
67
68
# File 'lib/oci/application_migration/models/source_details.rb', line 58

def self.get_subtype(object_hash)
  type = object_hash[:'type'] # rubocop:disable Style/SymbolLiteral

  return 'OCI::ApplicationMigration::Models::ImportSourceDetails' if type == 'IMPORT'
  return 'OCI::ApplicationMigration::Models::OccSourceDetails' if type == 'OCC'
  return 'OCI::ApplicationMigration::Models::InternalSourceDetails' if type == 'INTERNAL_COMPUTE'
  return 'OCI::ApplicationMigration::Models::OcicSourceDetails' if type == 'OCIC'

  # TODO: Log a warning when the subtype is not found.
  'OCI::ApplicationMigration::Models::SourceDetails'
end

.swagger_typesObject

Attribute type mapping.



45
46
47
48
49
50
51
# File 'lib/oci/application_migration/models/source_details.rb', line 45

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'type': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.



107
108
109
110
111
112
# File 'lib/oci/application_migration/models/source_details.rb', line 107

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    type == other.type
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/oci/application_migration/models/source_details.rb', line 137

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method


117
118
119
# File 'lib/oci/application_migration/models/source_details.rb', line 117

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.



126
127
128
# File 'lib/oci/application_migration/models/source_details.rb', line 126

def hash
  [type].hash
end

#to_hashHash

Returns the object in the form of hash



170
171
172
173
174
175
176
177
178
179
# File 'lib/oci/application_migration/models/source_details.rb', line 170

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



164
165
166
# File 'lib/oci/application_migration/models/source_details.rb', line 164

def to_s
  to_hash.to_s
end