Class: OCI::Artifacts::Models::ContainerImage

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/artifacts/models/container_image.rb

Overview

Container image metadata.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ContainerImage

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/oci/artifacts/models/container_image.rb', line 160

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.created_by = attributes[:'createdBy'] if attributes[:'createdBy']

  raise 'You cannot provide both :createdBy and :created_by' if attributes.key?(:'createdBy') && attributes.key?(:'created_by')

  self.created_by = attributes[:'created_by'] if attributes[:'created_by']

  self.digest = attributes[:'digest'] if attributes[:'digest']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.id = attributes[:'id'] if attributes[:'id']

  self.layers = attributes[:'layers'] if attributes[:'layers']

  self.layers_size_in_bytes = attributes[:'layersSizeInBytes'] if attributes[:'layersSizeInBytes']

  raise 'You cannot provide both :layersSizeInBytes and :layers_size_in_bytes' if attributes.key?(:'layersSizeInBytes') && attributes.key?(:'layers_size_in_bytes')

  self.layers_size_in_bytes = attributes[:'layers_size_in_bytes'] if attributes[:'layers_size_in_bytes']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.manifest_size_in_bytes = attributes[:'manifestSizeInBytes'] if attributes[:'manifestSizeInBytes']

  raise 'You cannot provide both :manifestSizeInBytes and :manifest_size_in_bytes' if attributes.key?(:'manifestSizeInBytes') && attributes.key?(:'manifest_size_in_bytes')

  self.manifest_size_in_bytes = attributes[:'manifest_size_in_bytes'] if attributes[:'manifest_size_in_bytes']

  self.pull_count = attributes[:'pullCount'] if attributes[:'pullCount']

  raise 'You cannot provide both :pullCount and :pull_count' if attributes.key?(:'pullCount') && attributes.key?(:'pull_count')

  self.pull_count = attributes[:'pull_count'] if attributes[:'pull_count']

  self.repository_id = attributes[:'repositoryId'] if attributes[:'repositoryId']

  raise 'You cannot provide both :repositoryId and :repository_id' if attributes.key?(:'repositoryId') && attributes.key?(:'repository_id')

  self.repository_id = attributes[:'repository_id'] if attributes[:'repository_id']

  self.repository_name = attributes[:'repositoryName'] if attributes[:'repositoryName']

  raise 'You cannot provide both :repositoryName and :repository_name' if attributes.key?(:'repositoryName') && attributes.key?(:'repository_name')

  self.repository_name = attributes[:'repository_name'] if attributes[:'repository_name']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_last_pulled = attributes[:'timeLastPulled'] if attributes[:'timeLastPulled']

  raise 'You cannot provide both :timeLastPulled and :time_last_pulled' if attributes.key?(:'timeLastPulled') && attributes.key?(:'time_last_pulled')

  self.time_last_pulled = attributes[:'time_last_pulled'] if attributes[:'time_last_pulled']

  self.version = attributes[:'version'] if attributes[:'version']

  self.versions = attributes[:'versions'] if attributes[:'versions']
end

Instance Attribute Details

#compartment_idString

**[Required]** The compartment OCID to which the container image belongs. Inferred from the container repository.

Returns:

  • (String)


20
21
22
# File 'lib/oci/artifacts/models/container_image.rb', line 20

def compartment_id
  @compartment_id
end

#created_byString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the user or principal that created the resource.

Returns:

  • (String)


24
25
26
# File 'lib/oci/artifacts/models/container_image.rb', line 24

def created_by
  @created_by
end

#digestString

**[Required]** The container image digest.

Returns:

  • (String)


28
29
30
# File 'lib/oci/artifacts/models/container_image.rb', line 28

def digest
  @digest
end

#display_nameString

**[Required]** The repository name and the most recent version associated with the image. If there are no versions associated with the image, then last known version and digest are used instead. If the last known version is unavailable, then 'unknown' is used instead of the version.

Example: `ubuntu:latest` or `ubuntu:latest@sha256:45b23dee08af5e43a7fea6c4cf9c25ccf269ee113168c19722f87876677c5cb2`

Returns:

  • (String)


37
38
39
# File 'lib/oci/artifacts/models/container_image.rb', line 37

def display_name
  @display_name
end

#idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the container image.

Example: `ocid1.containerimage.oc1..exampleuniqueID`

Returns:

  • (String)


44
45
46
# File 'lib/oci/artifacts/models/container_image.rb', line 44

def id
  @id
end

#layersArray<OCI::Artifacts::Models::ContainerImageLayer>

**[Required]** Layers of which the image is composed, ordered by the layer digest.



48
49
50
# File 'lib/oci/artifacts/models/container_image.rb', line 48

def layers
  @layers
end

#layers_size_in_bytesInteger

**[Required]** The total size of the container image layers in bytes.

Returns:

  • (Integer)


52
53
54
# File 'lib/oci/artifacts/models/container_image.rb', line 52

def layers_size_in_bytes
  @layers_size_in_bytes
end

#lifecycle_stateString

**[Required]** The current state of the container image.

Returns:

  • (String)


56
57
58
# File 'lib/oci/artifacts/models/container_image.rb', line 56

def lifecycle_state
  @lifecycle_state
end

#manifest_size_in_bytesInteger

**[Required]** The size of the container image manifest in bytes.

Returns:

  • (Integer)


60
61
62
# File 'lib/oci/artifacts/models/container_image.rb', line 60

def manifest_size_in_bytes
  @manifest_size_in_bytes
end

#pull_countInteger

**[Required]** Total number of pulls.

Returns:

  • (Integer)


64
65
66
# File 'lib/oci/artifacts/models/container_image.rb', line 64

def pull_count
  @pull_count
end

#repository_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the container repository.

Returns:

  • (String)


68
69
70
# File 'lib/oci/artifacts/models/container_image.rb', line 68

def repository_id
  @repository_id
end

#repository_nameString

**[Required]** The container repository name.

Returns:

  • (String)


72
73
74
# File 'lib/oci/artifacts/models/container_image.rb', line 72

def repository_name
  @repository_name
end

#time_createdDateTime

**[Required]** An RFC 3339 timestamp indicating when the image was created.

Returns:

  • (DateTime)


76
77
78
# File 'lib/oci/artifacts/models/container_image.rb', line 76

def time_created
  @time_created
end

#time_last_pulledDateTime

An RFC 3339 timestamp indicating when the image was last pulled.

Returns:

  • (DateTime)


80
81
82
# File 'lib/oci/artifacts/models/container_image.rb', line 80

def time_last_pulled
  @time_last_pulled
end

#versionString

The most recent version associated with this image.

Returns:

  • (String)


84
85
86
# File 'lib/oci/artifacts/models/container_image.rb', line 84

def version
  @version
end

#versionsArray<OCI::Artifacts::Models::ContainerVersion>

**[Required]** The versions associated with this image.



88
89
90
# File 'lib/oci/artifacts/models/container_image.rb', line 88

def versions
  @versions
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/oci/artifacts/models/container_image.rb', line 91

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'compartmentId',
    'created_by': :'createdBy',
    'digest': :'digest',
    'display_name': :'displayName',
    'id': :'id',
    'layers': :'layers',
    'layers_size_in_bytes': :'layersSizeInBytes',
    'lifecycle_state': :'lifecycleState',
    'manifest_size_in_bytes': :'manifestSizeInBytes',
    'pull_count': :'pullCount',
    'repository_id': :'repositoryId',
    'repository_name': :'repositoryName',
    'time_created': :'timeCreated',
    'time_last_pulled': :'timeLastPulled',
    'version': :'version',
    'versions': :'versions'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/oci/artifacts/models/container_image.rb', line 115

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'String',
    'created_by': :'String',
    'digest': :'String',
    'display_name': :'String',
    'id': :'String',
    'layers': :'Array<OCI::Artifacts::Models::ContainerImageLayer>',
    'layers_size_in_bytes': :'Integer',
    'lifecycle_state': :'String',
    'manifest_size_in_bytes': :'Integer',
    'pull_count': :'Integer',
    'repository_id': :'String',
    'repository_name': :'String',
    'time_created': :'DateTime',
    'time_last_pulled': :'DateTime',
    'version': :'String',
    'versions': :'Array<OCI::Artifacts::Models::ContainerVersion>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/oci/artifacts/models/container_image.rb', line 263

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    compartment_id == other.compartment_id &&
    created_by == other.created_by &&
    digest == other.digest &&
    display_name == other.display_name &&
    id == other.id &&
    layers == other.layers &&
    layers_size_in_bytes == other.layers_size_in_bytes &&
    lifecycle_state == other.lifecycle_state &&
    manifest_size_in_bytes == other.manifest_size_in_bytes &&
    pull_count == other.pull_count &&
    repository_id == other.repository_id &&
    repository_name == other.repository_name &&
    time_created == other.time_created &&
    time_last_pulled == other.time_last_pulled &&
    version == other.version &&
    versions == other.versions
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
# File 'lib/oci/artifacts/models/container_image.rb', line 308

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


288
289
290
# File 'lib/oci/artifacts/models/container_image.rb', line 288

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



297
298
299
# File 'lib/oci/artifacts/models/container_image.rb', line 297

def hash
  [compartment_id, created_by, digest, display_name, id, layers, layers_size_in_bytes, lifecycle_state, manifest_size_in_bytes, pull_count, repository_id, repository_name, time_created, time_last_pulled, version, versions].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



341
342
343
344
345
346
347
348
349
350
# File 'lib/oci/artifacts/models/container_image.rb', line 341

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



335
336
337
# File 'lib/oci/artifacts/models/container_image.rb', line 335

def to_s
  to_hash.to_s
end