Class: OCI::Artifacts::Models::ContainerImageSignature

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/artifacts/models/container_image_signature.rb

Overview

Container image signature metadata.

Constant Summary collapse

SIGNING_ALGORITHM_ENUM =
[
  SIGNING_ALGORITHM_SHA_224_RSA_PKCS_PSS = 'SHA_224_RSA_PKCS_PSS'.freeze,
  SIGNING_ALGORITHM_SHA_256_RSA_PKCS_PSS = 'SHA_256_RSA_PKCS_PSS'.freeze,
  SIGNING_ALGORITHM_SHA_384_RSA_PKCS_PSS = 'SHA_384_RSA_PKCS_PSS'.freeze,
  SIGNING_ALGORITHM_SHA_512_RSA_PKCS_PSS = 'SHA_512_RSA_PKCS_PSS'.freeze,
  SIGNING_ALGORITHM_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ContainerImageSignature

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :created_by (String)

    The value to assign to the #created_by property

  • :display_name (String)

    The value to assign to the #display_name property

  • :id (String)

    The value to assign to the #id property

  • :image_id (String)

    The value to assign to the #image_id property

  • :kms_key_id (String)

    The value to assign to the #kms_key_id property

  • :kms_key_version_id (String)

    The value to assign to the #kms_key_version_id property

  • :message (String)

    The value to assign to the #message property

  • :signature (String)

    The value to assign to the #signature property

  • :signing_algorithm (String)

    The value to assign to the #signing_algorithm property

  • :time_created (DateTime)

    The value to assign to the #time_created property



133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/oci/artifacts/models/container_image_signature.rb', line 133

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.created_by = attributes[:'createdBy'] if attributes[:'createdBy']

  raise 'You cannot provide both :createdBy and :created_by' if attributes.key?(:'createdBy') && attributes.key?(:'created_by')

  self.created_by = attributes[:'created_by'] if attributes[:'created_by']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.id = attributes[:'id'] if attributes[:'id']

  self.image_id = attributes[:'imageId'] if attributes[:'imageId']

  raise 'You cannot provide both :imageId and :image_id' if attributes.key?(:'imageId') && attributes.key?(:'image_id')

  self.image_id = attributes[:'image_id'] if attributes[:'image_id']

  self.kms_key_id = attributes[:'kmsKeyId'] if attributes[:'kmsKeyId']

  raise 'You cannot provide both :kmsKeyId and :kms_key_id' if attributes.key?(:'kmsKeyId') && attributes.key?(:'kms_key_id')

  self.kms_key_id = attributes[:'kms_key_id'] if attributes[:'kms_key_id']

  self.kms_key_version_id = attributes[:'kmsKeyVersionId'] if attributes[:'kmsKeyVersionId']

  raise 'You cannot provide both :kmsKeyVersionId and :kms_key_version_id' if attributes.key?(:'kmsKeyVersionId') && attributes.key?(:'kms_key_version_id')

  self.kms_key_version_id = attributes[:'kms_key_version_id'] if attributes[:'kms_key_version_id']

  self.message = attributes[:'message'] if attributes[:'message']

  self.signature = attributes[:'signature'] if attributes[:'signature']

  self.signing_algorithm = attributes[:'signingAlgorithm'] if attributes[:'signingAlgorithm']

  raise 'You cannot provide both :signingAlgorithm and :signing_algorithm' if attributes.key?(:'signingAlgorithm') && attributes.key?(:'signing_algorithm')

  self.signing_algorithm = attributes[:'signing_algorithm'] if attributes[:'signing_algorithm']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']
end

Instance Attribute Details

#compartment_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment in which the container repository exists.

Returns:

  • (String)


21
22
23
# File 'lib/oci/artifacts/models/container_image_signature.rb', line 21

def compartment_id
  @compartment_id
end

#created_byString

**[Required]** The id of the user or principal that created the resource.

Returns:

  • (String)


25
26
27
# File 'lib/oci/artifacts/models/container_image_signature.rb', line 25

def created_by
  @created_by
end

#display_nameString

**[Required]** The last 10 characters of the kmsKeyId, the last 10 characters of the kmsKeyVersionId, the signingAlgorithm, and the last 10 characters of the signatureId.

Example: `wrmz22sixa::qdwyc2ptun::SHA_256_RSA_PKCS_PSS::2vwmobasva`

Returns:

  • (String)


32
33
34
# File 'lib/oci/artifacts/models/container_image_signature.rb', line 32

def display_name
  @display_name
end

#idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the container image signature.

Example: `ocid1.containerimagesignature.oc1..exampleuniqueID`

Returns:

  • (String)


39
40
41
# File 'lib/oci/artifacts/models/container_image_signature.rb', line 39

def id
  @id
end

#image_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the container image.

Example: `ocid1.containerimage.oc1..exampleuniqueID`

Returns:

  • (String)


46
47
48
# File 'lib/oci/artifacts/models/container_image_signature.rb', line 46

def image_id
  @image_id
end

#kms_key_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the kmsKeyId used to sign the container image.

Example: `ocid1.key.oc1..exampleuniqueID`

Returns:

  • (String)


53
54
55
# File 'lib/oci/artifacts/models/container_image_signature.rb', line 53

def kms_key_id
  @kms_key_id
end

#kms_key_version_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the kmsKeyVersionId used to sign the container image.

Example: `ocid1.keyversion.oc1..exampleuniqueID`

Returns:

  • (String)


60
61
62
# File 'lib/oci/artifacts/models/container_image_signature.rb', line 60

def kms_key_version_id
  @kms_key_version_id
end

#messageString

**[Required]** The base64 encoded signature payload that was signed.

Returns:

  • (String)


64
65
66
# File 'lib/oci/artifacts/models/container_image_signature.rb', line 64

def message
  @message
end

#signatureString

**[Required]** The signature of the message field using the kmsKeyId, the kmsKeyVersionId, and the signingAlgorithm.

Returns:

  • (String)


68
69
70
# File 'lib/oci/artifacts/models/container_image_signature.rb', line 68

def signature
  @signature
end

#signing_algorithmString

**[Required]** The algorithm to be used for signing. These are the only supported signing algorithms for container images.

Returns:

  • (String)


72
73
74
# File 'lib/oci/artifacts/models/container_image_signature.rb', line 72

def signing_algorithm
  @signing_algorithm
end

#time_createdDateTime

**[Required]** An RFC 3339 timestamp indicating when the image was created.

Returns:

  • (DateTime)


76
77
78
# File 'lib/oci/artifacts/models/container_image_signature.rb', line 76

def time_created
  @time_created
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/oci/artifacts/models/container_image_signature.rb', line 79

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'compartmentId',
    'created_by': :'createdBy',
    'display_name': :'displayName',
    'id': :'id',
    'image_id': :'imageId',
    'kms_key_id': :'kmsKeyId',
    'kms_key_version_id': :'kmsKeyVersionId',
    'message': :'message',
    'signature': :'signature',
    'signing_algorithm': :'signingAlgorithm',
    'time_created': :'timeCreated'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/oci/artifacts/models/container_image_signature.rb', line 98

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'String',
    'created_by': :'String',
    'display_name': :'String',
    'id': :'String',
    'image_id': :'String',
    'kms_key_id': :'String',
    'kms_key_version_id': :'String',
    'message': :'String',
    'signature': :'String',
    'signing_algorithm': :'String',
    'time_created': :'DateTime'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/oci/artifacts/models/container_image_signature.rb', line 214

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    compartment_id == other.compartment_id &&
    created_by == other.created_by &&
    display_name == other.display_name &&
    id == other.id &&
    image_id == other.image_id &&
    kms_key_id == other.kms_key_id &&
    kms_key_version_id == other.kms_key_version_id &&
    message == other.message &&
    signature == other.signature &&
    signing_algorithm == other.signing_algorithm &&
    time_created == other.time_created
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/oci/artifacts/models/container_image_signature.rb', line 254

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


234
235
236
# File 'lib/oci/artifacts/models/container_image_signature.rb', line 234

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



243
244
245
# File 'lib/oci/artifacts/models/container_image_signature.rb', line 243

def hash
  [compartment_id, created_by, display_name, id, image_id, kms_key_id, kms_key_version_id, message, signature, signing_algorithm, time_created].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



287
288
289
290
291
292
293
294
295
296
# File 'lib/oci/artifacts/models/container_image_signature.rb', line 287

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



281
282
283
# File 'lib/oci/artifacts/models/container_image_signature.rb', line 281

def to_s
  to_hash.to_s
end