Class: OCI::Artifacts::Models::ContainerImageSignatureSummary
- Inherits:
-
Object
- Object
- OCI::Artifacts::Models::ContainerImageSignatureSummary
- Defined in:
- lib/oci/artifacts/models/container_image_signature_summary.rb
Overview
Container image signature summary.
Constant Summary collapse
- SIGNING_ALGORITHM_ENUM =
[ SIGNING_ALGORITHM_SHA_224_RSA_PKCS_PSS = 'SHA_224_RSA_PKCS_PSS'.freeze, SIGNING_ALGORITHM_SHA_256_RSA_PKCS_PSS = 'SHA_256_RSA_PKCS_PSS'.freeze, SIGNING_ALGORITHM_SHA_384_RSA_PKCS_PSS = 'SHA_384_RSA_PKCS_PSS'.freeze, SIGNING_ALGORITHM_SHA_512_RSA_PKCS_PSS = 'SHA_512_RSA_PKCS_PSS'.freeze, SIGNING_ALGORITHM_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The OCID of the compartment in which the container repository exists.
-
#display_name ⇒ String
**[Required]** The last 10 characters of the kmsKeyId, the last 10 characters of the kmsKeyVersionId, the signingAlgorithm, and the last 10 characters of the signatureId.
-
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the container image signature.
-
#image_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the container image.
-
#kms_key_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the kmsKeyId used to sign the container image.
-
#kms_key_version_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the kmsKeyVersionId used to sign the container image.
-
#message ⇒ String
**[Required]** The base64 encoded signature payload that was signed.
-
#signature ⇒ String
**[Required]** The signature of the message field using the kmsKeyId, the kmsKeyVersionId, and the signingAlgorithm.
-
#signing_algorithm ⇒ String
**[Required]** The algorithm to be used for signing.
-
#time_created ⇒ DateTime
**[Required]** An RFC 3339 timestamp indicating when the image was created.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ContainerImageSignatureSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ContainerImageSignatureSummary
Initializes the object
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/oci/artifacts/models/container_image_signature_summary.rb', line 126 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.id = attributes[:'id'] if attributes[:'id'] self.image_id = attributes[:'imageId'] if attributes[:'imageId'] raise 'You cannot provide both :imageId and :image_id' if attributes.key?(:'imageId') && attributes.key?(:'image_id') self.image_id = attributes[:'image_id'] if attributes[:'image_id'] self.kms_key_id = attributes[:'kmsKeyId'] if attributes[:'kmsKeyId'] raise 'You cannot provide both :kmsKeyId and :kms_key_id' if attributes.key?(:'kmsKeyId') && attributes.key?(:'kms_key_id') self.kms_key_id = attributes[:'kms_key_id'] if attributes[:'kms_key_id'] self.kms_key_version_id = attributes[:'kmsKeyVersionId'] if attributes[:'kmsKeyVersionId'] raise 'You cannot provide both :kmsKeyVersionId and :kms_key_version_id' if attributes.key?(:'kmsKeyVersionId') && attributes.key?(:'kms_key_version_id') self.kms_key_version_id = attributes[:'kms_key_version_id'] if attributes[:'kms_key_version_id'] self. = attributes[:'message'] if attributes[:'message'] self.signature = attributes[:'signature'] if attributes[:'signature'] self.signing_algorithm = attributes[:'signingAlgorithm'] if attributes[:'signingAlgorithm'] raise 'You cannot provide both :signingAlgorithm and :signing_algorithm' if attributes.key?(:'signingAlgorithm') && attributes.key?(:'signing_algorithm') self.signing_algorithm = attributes[:'signing_algorithm'] if attributes[:'signing_algorithm'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The OCID of the compartment in which the container repository exists.
21 22 23 |
# File 'lib/oci/artifacts/models/container_image_signature_summary.rb', line 21 def compartment_id @compartment_id end |
#display_name ⇒ String
**[Required]** The last 10 characters of the kmsKeyId, the last 10 characters of the kmsKeyVersionId, the signingAlgorithm, and the last 10 characters of the signatureId.
Example: `wrmz22sixa::qdwyc2ptun::SHA_256_RSA_PKCS_PSS::2vwmobasva`
28 29 30 |
# File 'lib/oci/artifacts/models/container_image_signature_summary.rb', line 28 def display_name @display_name end |
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the container image signature.
Example: `ocid1.containerimagesignature.oc1..exampleuniqueID`
35 36 37 |
# File 'lib/oci/artifacts/models/container_image_signature_summary.rb', line 35 def id @id end |
#image_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the container image.
Example: `ocid1.containerimage.oc1..exampleuniqueID`
42 43 44 |
# File 'lib/oci/artifacts/models/container_image_signature_summary.rb', line 42 def image_id @image_id end |
#kms_key_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the kmsKeyId used to sign the container image.
Example: `ocid1.key.oc1..exampleuniqueID`
49 50 51 |
# File 'lib/oci/artifacts/models/container_image_signature_summary.rb', line 49 def kms_key_id @kms_key_id end |
#kms_key_version_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the kmsKeyVersionId used to sign the container image.
Example: `ocid1.keyversion.oc1..exampleuniqueID`
56 57 58 |
# File 'lib/oci/artifacts/models/container_image_signature_summary.rb', line 56 def kms_key_version_id @kms_key_version_id end |
#message ⇒ String
**[Required]** The base64 encoded signature payload that was signed.
60 61 62 |
# File 'lib/oci/artifacts/models/container_image_signature_summary.rb', line 60 def @message end |
#signature ⇒ String
**[Required]** The signature of the message field using the kmsKeyId, the kmsKeyVersionId, and the signingAlgorithm.
64 65 66 |
# File 'lib/oci/artifacts/models/container_image_signature_summary.rb', line 64 def signature @signature end |
#signing_algorithm ⇒ String
**[Required]** The algorithm to be used for signing. These are the only supported signing algorithms for container images.
68 69 70 |
# File 'lib/oci/artifacts/models/container_image_signature_summary.rb', line 68 def signing_algorithm @signing_algorithm end |
#time_created ⇒ DateTime
**[Required]** An RFC 3339 timestamp indicating when the image was created.
72 73 74 |
# File 'lib/oci/artifacts/models/container_image_signature_summary.rb', line 72 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/oci/artifacts/models/container_image_signature_summary.rb', line 75 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'id': :'id', 'image_id': :'imageId', 'kms_key_id': :'kmsKeyId', 'kms_key_version_id': :'kmsKeyVersionId', 'message': :'message', 'signature': :'signature', 'signing_algorithm': :'signingAlgorithm', 'time_created': :'timeCreated' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/oci/artifacts/models/container_image_signature_summary.rb', line 93 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'display_name': :'String', 'id': :'String', 'image_id': :'String', 'kms_key_id': :'String', 'kms_key_version_id': :'String', 'message': :'String', 'signature': :'String', 'signing_algorithm': :'String', 'time_created': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/oci/artifacts/models/container_image_signature_summary.rb', line 201 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && display_name == other.display_name && id == other.id && image_id == other.image_id && kms_key_id == other.kms_key_id && kms_key_version_id == other.kms_key_version_id && == other. && signature == other.signature && signing_algorithm == other.signing_algorithm && time_created == other.time_created end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 |
# File 'lib/oci/artifacts/models/container_image_signature_summary.rb', line 240 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
220 221 222 |
# File 'lib/oci/artifacts/models/container_image_signature_summary.rb', line 220 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
229 230 231 |
# File 'lib/oci/artifacts/models/container_image_signature_summary.rb', line 229 def hash [compartment_id, display_name, id, image_id, kms_key_id, kms_key_version_id, , signature, signing_algorithm, time_created].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
273 274 275 276 277 278 279 280 281 282 |
# File 'lib/oci/artifacts/models/container_image_signature_summary.rb', line 273 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
267 268 269 |
# File 'lib/oci/artifacts/models/container_image_signature_summary.rb', line 267 def to_s to_hash.to_s end |