Class: OCI::Artifacts::Models::ContainerRepositorySummary
- Inherits:
-
Object
- Object
- OCI::Artifacts::Models::ContainerRepositorySummary
- Defined in:
- lib/oci/artifacts/models/container_repository_summary.rb
Overview
Container repository summary.
Instance Attribute Summary collapse
-
#billable_size_in_gbs ⇒ Integer
[Required] Total storage size in GBs that will be charged.
-
#compartment_id ⇒ String
[Required] The OCID of the compartment in which the container repository exists.
-
#display_name ⇒ String
[Required] The container repository name.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the container repository.
-
#image_count ⇒ Integer
[Required] Total number of images.
-
#is_public ⇒ BOOLEAN
[Required] Whether the repository is public.
-
#layer_count ⇒ Integer
[Required] Total number of layers.
-
#layers_size_in_bytes ⇒ Integer
[Required] Total storage in bytes consumed by layers.
-
#lifecycle_state ⇒ String
[Required] The current state of the container repository.
-
#time_created ⇒ DateTime
[Required] An RFC 3339 timestamp indicating when the repository was created.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ContainerRepositorySummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ContainerRepositorySummary
Initializes the object
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/oci/artifacts/models/container_repository_summary.rb', line 105 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.id = attributes[:'id'] if attributes[:'id'] self.image_count = attributes[:'imageCount'] if attributes[:'imageCount'] raise 'You cannot provide both :imageCount and :image_count' if attributes.key?(:'imageCount') && attributes.key?(:'image_count') self.image_count = attributes[:'image_count'] if attributes[:'image_count'] self.is_public = attributes[:'isPublic'] unless attributes[:'isPublic'].nil? raise 'You cannot provide both :isPublic and :is_public' if attributes.key?(:'isPublic') && attributes.key?(:'is_public') self.is_public = attributes[:'is_public'] unless attributes[:'is_public'].nil? self.layer_count = attributes[:'layerCount'] if attributes[:'layerCount'] raise 'You cannot provide both :layerCount and :layer_count' if attributes.key?(:'layerCount') && attributes.key?(:'layer_count') self.layer_count = attributes[:'layer_count'] if attributes[:'layer_count'] self.layers_size_in_bytes = attributes[:'layersSizeInBytes'] if attributes[:'layersSizeInBytes'] raise 'You cannot provide both :layersSizeInBytes and :layers_size_in_bytes' if attributes.key?(:'layersSizeInBytes') && attributes.key?(:'layers_size_in_bytes') self.layers_size_in_bytes = attributes[:'layers_size_in_bytes'] if attributes[:'layers_size_in_bytes'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.billable_size_in_gbs = attributes[:'billableSizeInGBs'] if attributes[:'billableSizeInGBs'] raise 'You cannot provide both :billableSizeInGBs and :billable_size_in_gbs' if attributes.key?(:'billableSizeInGBs') && attributes.key?(:'billable_size_in_gbs') self.billable_size_in_gbs = attributes[:'billable_size_in_gbs'] if attributes[:'billable_size_in_gbs'] end |
Instance Attribute Details
#billable_size_in_gbs ⇒ Integer
[Required] Total storage size in GBs that will be charged.
51 52 53 |
# File 'lib/oci/artifacts/models/container_repository_summary.rb', line 51 def billable_size_in_gbs @billable_size_in_gbs end |
#compartment_id ⇒ String
[Required] The OCID of the compartment in which the container repository exists.
12 13 14 |
# File 'lib/oci/artifacts/models/container_repository_summary.rb', line 12 def compartment_id @compartment_id end |
#display_name ⇒ String
[Required] The container repository name.
16 17 18 |
# File 'lib/oci/artifacts/models/container_repository_summary.rb', line 16 def display_name @display_name end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the container repository.
Example: ocid1.containerrepo.oc1..exampleuniqueID
23 24 25 |
# File 'lib/oci/artifacts/models/container_repository_summary.rb', line 23 def id @id end |
#image_count ⇒ Integer
[Required] Total number of images.
27 28 29 |
# File 'lib/oci/artifacts/models/container_repository_summary.rb', line 27 def image_count @image_count end |
#is_public ⇒ BOOLEAN
[Required] Whether the repository is public. A public repository allows unauthenticated access.
31 32 33 |
# File 'lib/oci/artifacts/models/container_repository_summary.rb', line 31 def is_public @is_public end |
#layer_count ⇒ Integer
[Required] Total number of layers.
35 36 37 |
# File 'lib/oci/artifacts/models/container_repository_summary.rb', line 35 def layer_count @layer_count end |
#layers_size_in_bytes ⇒ Integer
[Required] Total storage in bytes consumed by layers.
39 40 41 |
# File 'lib/oci/artifacts/models/container_repository_summary.rb', line 39 def layers_size_in_bytes @layers_size_in_bytes end |
#lifecycle_state ⇒ String
[Required] The current state of the container repository.
43 44 45 |
# File 'lib/oci/artifacts/models/container_repository_summary.rb', line 43 def lifecycle_state @lifecycle_state end |
#time_created ⇒ DateTime
[Required] An RFC 3339 timestamp indicating when the repository was created.
47 48 49 |
# File 'lib/oci/artifacts/models/container_repository_summary.rb', line 47 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/oci/artifacts/models/container_repository_summary.rb', line 54 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'id': :'id', 'image_count': :'imageCount', 'is_public': :'isPublic', 'layer_count': :'layerCount', 'layers_size_in_bytes': :'layersSizeInBytes', 'lifecycle_state': :'lifecycleState', 'time_created': :'timeCreated', 'billable_size_in_gbs': :'billableSizeInGBs' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/oci/artifacts/models/container_repository_summary.rb', line 72 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'display_name': :'String', 'id': :'String', 'image_count': :'Integer', 'is_public': :'BOOLEAN', 'layer_count': :'Integer', 'layers_size_in_bytes': :'Integer', 'lifecycle_state': :'String', 'time_created': :'DateTime', 'billable_size_in_gbs': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/oci/artifacts/models/container_repository_summary.rb', line 175 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && display_name == other.display_name && id == other.id && image_count == other.image_count && is_public == other.is_public && layer_count == other.layer_count && layers_size_in_bytes == other.layers_size_in_bytes && lifecycle_state == other.lifecycle_state && time_created == other.time_created && billable_size_in_gbs == other.billable_size_in_gbs end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/oci/artifacts/models/container_repository_summary.rb', line 214 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
194 195 196 |
# File 'lib/oci/artifacts/models/container_repository_summary.rb', line 194 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
203 204 205 |
# File 'lib/oci/artifacts/models/container_repository_summary.rb', line 203 def hash [compartment_id, display_name, id, image_count, is_public, layer_count, layers_size_in_bytes, lifecycle_state, time_created, billable_size_in_gbs].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
247 248 249 250 251 252 253 254 255 256 |
# File 'lib/oci/artifacts/models/container_repository_summary.rb', line 247 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
241 242 243 |
# File 'lib/oci/artifacts/models/container_repository_summary.rb', line 241 def to_s to_hash.to_s end |