Class: OCI::Artifacts::Models::CreateContainerImageSignatureDetails
- Inherits:
-
Object
- Object
- OCI::Artifacts::Models::CreateContainerImageSignatureDetails
- Defined in:
- lib/oci/artifacts/models/create_container_image_signature_details.rb
Overview
Upload container image signature request details.
Constant Summary collapse
- SIGNING_ALGORITHM_ENUM =
[ SIGNING_ALGORITHM_SHA_224_RSA_PKCS_PSS = 'SHA_224_RSA_PKCS_PSS'.freeze, SIGNING_ALGORITHM_SHA_256_RSA_PKCS_PSS = 'SHA_256_RSA_PKCS_PSS'.freeze, SIGNING_ALGORITHM_SHA_384_RSA_PKCS_PSS = 'SHA_384_RSA_PKCS_PSS'.freeze, SIGNING_ALGORITHM_SHA_512_RSA_PKCS_PSS = 'SHA_512_RSA_PKCS_PSS'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment in which the container repository exists.
-
#image_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the container image.
-
#kms_key_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the kmsKeyId used to sign the container image.
-
#kms_key_version_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the kmsKeyVersionId used to sign the container image.
-
#message ⇒ String
**[Required]** The base64 encoded signature payload that was signed.
-
#signature ⇒ String
**[Required]** The signature of the message field using the kmsKeyId, the kmsKeyVersionId, and the signingAlgorithm.
-
#signing_algorithm ⇒ String
**[Required]** The algorithm to be used for signing.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateContainerImageSignatureDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateContainerImageSignatureDetails
Initializes the object
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/oci/artifacts/models/create_container_image_signature_details.rb', line 97 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.image_id = attributes[:'imageId'] if attributes[:'imageId'] raise 'You cannot provide both :imageId and :image_id' if attributes.key?(:'imageId') && attributes.key?(:'image_id') self.image_id = attributes[:'image_id'] if attributes[:'image_id'] self.kms_key_id = attributes[:'kmsKeyId'] if attributes[:'kmsKeyId'] raise 'You cannot provide both :kmsKeyId and :kms_key_id' if attributes.key?(:'kmsKeyId') && attributes.key?(:'kms_key_id') self.kms_key_id = attributes[:'kms_key_id'] if attributes[:'kms_key_id'] self.kms_key_version_id = attributes[:'kmsKeyVersionId'] if attributes[:'kmsKeyVersionId'] raise 'You cannot provide both :kmsKeyVersionId and :kms_key_version_id' if attributes.key?(:'kmsKeyVersionId') && attributes.key?(:'kms_key_version_id') self.kms_key_version_id = attributes[:'kms_key_version_id'] if attributes[:'kms_key_version_id'] self. = attributes[:'message'] if attributes[:'message'] self.signature = attributes[:'signature'] if attributes[:'signature'] self.signing_algorithm = attributes[:'signingAlgorithm'] if attributes[:'signingAlgorithm'] raise 'You cannot provide both :signingAlgorithm and :signing_algorithm' if attributes.key?(:'signingAlgorithm') && attributes.key?(:'signing_algorithm') self.signing_algorithm = attributes[:'signing_algorithm'] if attributes[:'signing_algorithm'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment in which the container repository exists.
19 20 21 |
# File 'lib/oci/artifacts/models/create_container_image_signature_details.rb', line 19 def compartment_id @compartment_id end |
#image_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the container image.
Example: `ocid1.containerimage.oc1..exampleuniqueID`
26 27 28 |
# File 'lib/oci/artifacts/models/create_container_image_signature_details.rb', line 26 def image_id @image_id end |
#kms_key_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the kmsKeyId used to sign the container image.
Example: `ocid1.key.oc1..exampleuniqueID`
33 34 35 |
# File 'lib/oci/artifacts/models/create_container_image_signature_details.rb', line 33 def kms_key_id @kms_key_id end |
#kms_key_version_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the kmsKeyVersionId used to sign the container image.
Example: `ocid1.keyversion.oc1..exampleuniqueID`
40 41 42 |
# File 'lib/oci/artifacts/models/create_container_image_signature_details.rb', line 40 def kms_key_version_id @kms_key_version_id end |
#message ⇒ String
**[Required]** The base64 encoded signature payload that was signed.
44 45 46 |
# File 'lib/oci/artifacts/models/create_container_image_signature_details.rb', line 44 def @message end |
#signature ⇒ String
**[Required]** The signature of the message field using the kmsKeyId, the kmsKeyVersionId, and the signingAlgorithm.
48 49 50 |
# File 'lib/oci/artifacts/models/create_container_image_signature_details.rb', line 48 def signature @signature end |
#signing_algorithm ⇒ String
**[Required]** The algorithm to be used for signing. These are the only supported signing algorithms for container images.
52 53 54 |
# File 'lib/oci/artifacts/models/create_container_image_signature_details.rb', line 52 def signing_algorithm @signing_algorithm end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/oci/artifacts/models/create_container_image_signature_details.rb', line 55 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'image_id': :'imageId', 'kms_key_id': :'kmsKeyId', 'kms_key_version_id': :'kmsKeyVersionId', 'message': :'message', 'signature': :'signature', 'signing_algorithm': :'signingAlgorithm' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/oci/artifacts/models/create_container_image_signature_details.rb', line 70 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'image_id': :'String', 'kms_key_id': :'String', 'kms_key_version_id': :'String', 'message': :'String', 'signature': :'String', 'signing_algorithm': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/oci/artifacts/models/create_container_image_signature_details.rb', line 153 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && image_id == other.image_id && kms_key_id == other.kms_key_id && kms_key_version_id == other.kms_key_version_id && == other. && signature == other.signature && signing_algorithm == other.signing_algorithm end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/oci/artifacts/models/create_container_image_signature_details.rb', line 189 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
169 170 171 |
# File 'lib/oci/artifacts/models/create_container_image_signature_details.rb', line 169 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
178 179 180 |
# File 'lib/oci/artifacts/models/create_container_image_signature_details.rb', line 178 def hash [compartment_id, image_id, kms_key_id, kms_key_version_id, , signature, signing_algorithm].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
222 223 224 225 226 227 228 229 230 231 |
# File 'lib/oci/artifacts/models/create_container_image_signature_details.rb', line 222 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
216 217 218 |
# File 'lib/oci/artifacts/models/create_container_image_signature_details.rb', line 216 def to_s to_hash.to_s end |