Class: OCI::Artifacts::Models::CreateContainerRepositoryDetails
- Inherits:
-
Object
- Object
- OCI::Artifacts::Models::CreateContainerRepositoryDetails
- Defined in:
- lib/oci/artifacts/models/create_container_repository_details.rb
Overview
Create container repository details.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment in which to create the resource.
-
#display_name ⇒ String
[Required] The container repository name.
-
#is_immutable ⇒ BOOLEAN
Whether the repository is immutable.
-
#is_public ⇒ BOOLEAN
Whether the repository is public.
- #readme ⇒ OCI::Artifacts::Models::ContainerRepositoryReadme
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateContainerRepositoryDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateContainerRepositoryDetails
Initializes the object
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/oci/artifacts/models/create_container_repository_details.rb', line 67 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.is_immutable = attributes[:'isImmutable'] unless attributes[:'isImmutable'].nil? raise 'You cannot provide both :isImmutable and :is_immutable' if attributes.key?(:'isImmutable') && attributes.key?(:'is_immutable') self.is_immutable = attributes[:'is_immutable'] unless attributes[:'is_immutable'].nil? self.is_public = attributes[:'isPublic'] unless attributes[:'isPublic'].nil? raise 'You cannot provide both :isPublic and :is_public' if attributes.key?(:'isPublic') && attributes.key?(:'is_public') self.is_public = attributes[:'is_public'] unless attributes[:'is_public'].nil? self.readme = attributes[:'readme'] if attributes[:'readme'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment in which to create the resource.
13 14 15 |
# File 'lib/oci/artifacts/models/create_container_repository_details.rb', line 13 def compartment_id @compartment_id end |
#display_name ⇒ String
[Required] The container repository name.
17 18 19 |
# File 'lib/oci/artifacts/models/create_container_repository_details.rb', line 17 def display_name @display_name end |
#is_immutable ⇒ BOOLEAN
Whether the repository is immutable. Images cannot be overwritten in an immutable repository.
21 22 23 |
# File 'lib/oci/artifacts/models/create_container_repository_details.rb', line 21 def is_immutable @is_immutable end |
#is_public ⇒ BOOLEAN
Whether the repository is public. A public repository allows unauthenticated access.
25 26 27 |
# File 'lib/oci/artifacts/models/create_container_repository_details.rb', line 25 def is_public @is_public end |
#readme ⇒ OCI::Artifacts::Models::ContainerRepositoryReadme
28 29 30 |
# File 'lib/oci/artifacts/models/create_container_repository_details.rb', line 28 def readme @readme end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 40 41 |
# File 'lib/oci/artifacts/models/create_container_repository_details.rb', line 31 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'is_immutable': :'isImmutable', 'is_public': :'isPublic', 'readme': :'readme' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/oci/artifacts/models/create_container_repository_details.rb', line 44 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'display_name': :'String', 'is_immutable': :'BOOLEAN', 'is_public': :'BOOLEAN', 'readme': :'OCI::Artifacts::Models::ContainerRepositoryReadme' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
107 108 109 110 111 112 113 114 115 116 |
# File 'lib/oci/artifacts/models/create_container_repository_details.rb', line 107 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && display_name == other.display_name && is_immutable == other.is_immutable && is_public == other.is_public && readme == other.readme end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/oci/artifacts/models/create_container_repository_details.rb', line 141 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
121 122 123 |
# File 'lib/oci/artifacts/models/create_container_repository_details.rb', line 121 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
130 131 132 |
# File 'lib/oci/artifacts/models/create_container_repository_details.rb', line 130 def hash [compartment_id, display_name, is_immutable, is_public, readme].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
174 175 176 177 178 179 180 181 182 183 |
# File 'lib/oci/artifacts/models/create_container_repository_details.rb', line 174 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
168 169 170 |
# File 'lib/oci/artifacts/models/create_container_repository_details.rb', line 168 def to_s to_hash.to_s end |