Class: OCI::Autoscaling::Models::AutoScalingConfiguration
- Inherits:
-
Object
- Object
- OCI::Autoscaling::Models::AutoScalingConfiguration
- Defined in:
- lib/oci/autoscaling/models/auto_scaling_configuration.rb
Overview
An autoscaling configuration lets you dynamically scale the resources in a Compute instance pool. For more information, see [Autoscaling](docs.cloud.oracle.com/iaas/Content/Compute/Tasks/autoscalinginstancepools.htm).
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment containing the autoscaling configuration.
-
#cool_down_in_seconds ⇒ Integer
For threshold-based autoscaling policies, this value is the minimum period of time to wait between scaling actions.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
A user-friendly name.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the autoscaling configuration.
-
#is_enabled ⇒ BOOLEAN
Whether the autoscaling configuration is enabled.
-
#max_resource_count ⇒ Integer
The maximum number of resources to scale out to.
-
#min_resource_count ⇒ Integer
The minimum number of resources to scale in to.
-
#policies ⇒ Array<OCI::Autoscaling::Models::AutoScalingPolicy>
[Required] Autoscaling policy definitions for the autoscaling configuration.
-
#resource ⇒ OCI::Autoscaling::Models::Resource
This attribute is required.
-
#time_created ⇒ DateTime
[Required] The date and time the autoscaling configuration was created, in the format defined by RFC3339.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AutoScalingConfiguration
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ AutoScalingConfiguration
Initializes the object
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/oci/autoscaling/models/auto_scaling_configuration.rb', line 138 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.id = attributes[:'id'] if attributes[:'id'] self.cool_down_in_seconds = attributes[:'coolDownInSeconds'] if attributes[:'coolDownInSeconds'] raise 'You cannot provide both :coolDownInSeconds and :cool_down_in_seconds' if attributes.key?(:'coolDownInSeconds') && attributes.key?(:'cool_down_in_seconds') self.cool_down_in_seconds = attributes[:'cool_down_in_seconds'] if attributes[:'cool_down_in_seconds'] self.is_enabled = attributes[:'isEnabled'] unless attributes[:'isEnabled'].nil? raise 'You cannot provide both :isEnabled and :is_enabled' if attributes.key?(:'isEnabled') && attributes.key?(:'is_enabled') self.is_enabled = attributes[:'is_enabled'] unless attributes[:'is_enabled'].nil? self.resource = attributes[:'resource'] if attributes[:'resource'] self.policies = attributes[:'policies'] if attributes[:'policies'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.max_resource_count = attributes[:'maxResourceCount'] if attributes[:'maxResourceCount'] raise 'You cannot provide both :maxResourceCount and :max_resource_count' if attributes.key?(:'maxResourceCount') && attributes.key?(:'max_resource_count') self.max_resource_count = attributes[:'max_resource_count'] if attributes[:'max_resource_count'] self.min_resource_count = attributes[:'minResourceCount'] if attributes[:'minResourceCount'] raise 'You cannot provide both :minResourceCount and :min_resource_count' if attributes.key?(:'minResourceCount') && attributes.key?(:'min_resource_count') self.min_resource_count = attributes[:'min_resource_count'] if attributes[:'min_resource_count'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment containing the autoscaling configuration.
15 16 17 |
# File 'lib/oci/autoscaling/models/auto_scaling_configuration.rb', line 15 def compartment_id @compartment_id end |
#cool_down_in_seconds ⇒ Integer
For threshold-based autoscaling policies, this value is the minimum period of time to wait between scaling actions. The cooldown period gives the system time to stabilize before rescaling. The minimum value is 300 seconds, which is also the default. The cooldown period starts when the instance pool reaches the running state.
For schedule-based autoscaling policies, this value is not used.
49 50 51 |
# File 'lib/oci/autoscaling/models/auto_scaling_configuration.rb', line 49 def cool_down_in_seconds @cool_down_in_seconds end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
23 24 25 |
# File 'lib/oci/autoscaling/models/auto_scaling_configuration.rb', line 23 def end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
28 29 30 |
# File 'lib/oci/autoscaling/models/auto_scaling_configuration.rb', line 28 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
36 37 38 |
# File 'lib/oci/autoscaling/models/auto_scaling_configuration.rb', line 36 def end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the autoscaling configuration.
40 41 42 |
# File 'lib/oci/autoscaling/models/auto_scaling_configuration.rb', line 40 def id @id end |
#is_enabled ⇒ BOOLEAN
Whether the autoscaling configuration is enabled.
53 54 55 |
# File 'lib/oci/autoscaling/models/auto_scaling_configuration.rb', line 53 def is_enabled @is_enabled end |
#max_resource_count ⇒ Integer
The maximum number of resources to scale out to.
74 75 76 |
# File 'lib/oci/autoscaling/models/auto_scaling_configuration.rb', line 74 def max_resource_count @max_resource_count end |
#min_resource_count ⇒ Integer
The minimum number of resources to scale in to.
78 79 80 |
# File 'lib/oci/autoscaling/models/auto_scaling_configuration.rb', line 78 def min_resource_count @min_resource_count end |
#policies ⇒ Array<OCI::Autoscaling::Models::AutoScalingPolicy>
[Required] Autoscaling policy definitions for the autoscaling configuration. An autoscaling policy defines the criteria that trigger autoscaling actions and the actions to take.
63 64 65 |
# File 'lib/oci/autoscaling/models/auto_scaling_configuration.rb', line 63 def policies @policies end |
#resource ⇒ OCI::Autoscaling::Models::Resource
This attribute is required.
57 58 59 |
# File 'lib/oci/autoscaling/models/auto_scaling_configuration.rb', line 57 def resource @resource end |
#time_created ⇒ DateTime
[Required] The date and time the autoscaling configuration was created, in the format defined by RFC3339.
Example: 2016-08-25T21:10:29.600Z
70 71 72 |
# File 'lib/oci/autoscaling/models/auto_scaling_configuration.rb', line 70 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/oci/autoscaling/models/auto_scaling_configuration.rb', line 81 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'defined_tags': :'definedTags', 'display_name': :'displayName', 'freeform_tags': :'freeformTags', 'id': :'id', 'cool_down_in_seconds': :'coolDownInSeconds', 'is_enabled': :'isEnabled', 'resource': :'resource', 'policies': :'policies', 'time_created': :'timeCreated', 'max_resource_count': :'maxResourceCount', 'min_resource_count': :'minResourceCount' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/oci/autoscaling/models/auto_scaling_configuration.rb', line 101 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'freeform_tags': :'Hash<String, String>', 'id': :'String', 'cool_down_in_seconds': :'Integer', 'is_enabled': :'BOOLEAN', 'resource': :'OCI::Autoscaling::Models::Resource', 'policies': :'Array<OCI::Autoscaling::Models::AutoScalingPolicy>', 'time_created': :'DateTime', 'max_resource_count': :'Integer', 'min_resource_count': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/oci/autoscaling/models/auto_scaling_configuration.rb', line 212 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && == other. && display_name == other.display_name && == other. && id == other.id && cool_down_in_seconds == other.cool_down_in_seconds && is_enabled == other.is_enabled && resource == other.resource && policies == other.policies && time_created == other.time_created && max_resource_count == other.max_resource_count && min_resource_count == other.min_resource_count end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/oci/autoscaling/models/auto_scaling_configuration.rb', line 253 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
233 234 235 |
# File 'lib/oci/autoscaling/models/auto_scaling_configuration.rb', line 233 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
242 243 244 |
# File 'lib/oci/autoscaling/models/auto_scaling_configuration.rb', line 242 def hash [compartment_id, , display_name, , id, cool_down_in_seconds, is_enabled, resource, policies, time_created, max_resource_count, min_resource_count].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
286 287 288 289 290 291 292 293 294 295 |
# File 'lib/oci/autoscaling/models/auto_scaling_configuration.rb', line 286 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
280 281 282 |
# File 'lib/oci/autoscaling/models/auto_scaling_configuration.rb', line 280 def to_s to_hash.to_s end |