Class: OCI::Autoscaling::Models::AutoScalingConfigurationSummary
- Inherits:
-
Object
- Object
- OCI::Autoscaling::Models::AutoScalingConfigurationSummary
- Defined in:
- lib/oci/autoscaling/models/auto_scaling_configuration_summary.rb
Overview
Summary information for an autoscaling configuration.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment containing the autoscaling configuration.
-
#cool_down_in_seconds ⇒ Integer
For threshold-based autoscaling policies, this value is the minimum period of time to wait between scaling actions.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
A user-friendly name.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the autoscaling configuration.
-
#is_enabled ⇒ BOOLEAN
Whether the autoscaling configuration is enabled.
-
#resource ⇒ OCI::Autoscaling::Models::Resource
This attribute is required.
-
#time_created ⇒ DateTime
[Required] The date and time the autoscaling configuration was created, in the format defined by RFC3339.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AutoScalingConfigurationSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ AutoScalingConfigurationSummary
Initializes the object
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/oci/autoscaling/models/auto_scaling_configuration_summary.rb', line 114 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.id = attributes[:'id'] if attributes[:'id'] self.cool_down_in_seconds = attributes[:'coolDownInSeconds'] if attributes[:'coolDownInSeconds'] raise 'You cannot provide both :coolDownInSeconds and :cool_down_in_seconds' if attributes.key?(:'coolDownInSeconds') && attributes.key?(:'cool_down_in_seconds') self.cool_down_in_seconds = attributes[:'cool_down_in_seconds'] if attributes[:'cool_down_in_seconds'] self.is_enabled = attributes[:'isEnabled'] unless attributes[:'isEnabled'].nil? raise 'You cannot provide both :isEnabled and :is_enabled' if attributes.key?(:'isEnabled') && attributes.key?(:'is_enabled') self.is_enabled = attributes[:'is_enabled'] unless attributes[:'is_enabled'].nil? self.resource = attributes[:'resource'] if attributes[:'resource'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment containing the autoscaling configuration.
14 15 16 |
# File 'lib/oci/autoscaling/models/auto_scaling_configuration_summary.rb', line 14 def compartment_id @compartment_id end |
#cool_down_in_seconds ⇒ Integer
For threshold-based autoscaling policies, this value is the minimum period of time to wait between scaling actions. The cooldown period gives the system time to stabilize before rescaling. The minimum value is 300 seconds, which is also the default. The cooldown period starts when the instance pool reaches the running state.
For schedule-based autoscaling policies, this value is not used.
32 33 34 |
# File 'lib/oci/autoscaling/models/auto_scaling_configuration_summary.rb', line 32 def cool_down_in_seconds @cool_down_in_seconds end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
48 49 50 |
# File 'lib/oci/autoscaling/models/auto_scaling_configuration_summary.rb', line 48 def end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
19 20 21 |
# File 'lib/oci/autoscaling/models/auto_scaling_configuration_summary.rb', line 19 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
56 57 58 |
# File 'lib/oci/autoscaling/models/auto_scaling_configuration_summary.rb', line 56 def end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the autoscaling configuration.
23 24 25 |
# File 'lib/oci/autoscaling/models/auto_scaling_configuration_summary.rb', line 23 def id @id end |
#is_enabled ⇒ BOOLEAN
Whether the autoscaling configuration is enabled.
36 37 38 |
# File 'lib/oci/autoscaling/models/auto_scaling_configuration_summary.rb', line 36 def is_enabled @is_enabled end |
#resource ⇒ OCI::Autoscaling::Models::Resource
This attribute is required.
40 41 42 |
# File 'lib/oci/autoscaling/models/auto_scaling_configuration_summary.rb', line 40 def resource @resource end |
#time_created ⇒ DateTime
[Required] The date and time the autoscaling configuration was created, in the format defined by RFC3339.
Example: 2016-08-25T21:10:29.600Z
63 64 65 |
# File 'lib/oci/autoscaling/models/auto_scaling_configuration_summary.rb', line 63 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/oci/autoscaling/models/auto_scaling_configuration_summary.rb', line 66 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'id': :'id', 'cool_down_in_seconds': :'coolDownInSeconds', 'is_enabled': :'isEnabled', 'resource': :'resource', 'defined_tags': :'definedTags', 'freeform_tags': :'freeformTags', 'time_created': :'timeCreated' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/oci/autoscaling/models/auto_scaling_configuration_summary.rb', line 83 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'display_name': :'String', 'id': :'String', 'cool_down_in_seconds': :'Integer', 'is_enabled': :'BOOLEAN', 'resource': :'OCI::Autoscaling::Models::Resource', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'freeform_tags': :'Hash<String, String>', 'time_created': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/oci/autoscaling/models/auto_scaling_configuration_summary.rb', line 174 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && display_name == other.display_name && id == other.id && cool_down_in_seconds == other.cool_down_in_seconds && is_enabled == other.is_enabled && resource == other.resource && == other. && == other. && time_created == other.time_created end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/oci/autoscaling/models/auto_scaling_configuration_summary.rb', line 212 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
192 193 194 |
# File 'lib/oci/autoscaling/models/auto_scaling_configuration_summary.rb', line 192 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
201 202 203 |
# File 'lib/oci/autoscaling/models/auto_scaling_configuration_summary.rb', line 201 def hash [compartment_id, display_name, id, cool_down_in_seconds, is_enabled, resource, , , time_created].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
245 246 247 248 249 250 251 252 253 254 |
# File 'lib/oci/autoscaling/models/auto_scaling_configuration_summary.rb', line 245 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
239 240 241 |
# File 'lib/oci/autoscaling/models/auto_scaling_configuration_summary.rb', line 239 def to_s to_hash.to_s end |