Class: OCI::Autoscaling::Models::AutoScalingPolicy

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/autoscaling/models/auto_scaling_policy.rb

Overview

Autoscaling policies define the criteria that trigger autoscaling actions and the actions to take.

An autoscaling policy is part of an autoscaling configuration. For more information, see [Autoscaling](docs.cloud.oracle.com/iaas/Content/Compute/Tasks/autoscalinginstancepools.htm).

You can create the following types of autoscaling policies:

- **Schedule-based:** Autoscaling events take place at the specific times that you schedule.
- **Threshold-based:** An autoscaling action is triggered when a performance metric meets or exceeds a threshold.

This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class

Direct Known Subclasses

ScheduledPolicy, ThresholdPolicy

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ AutoScalingPolicy

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/oci/autoscaling/models/auto_scaling_policy.rb', line 104

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.capacity = attributes[:'capacity'] if attributes[:'capacity']

  self.id = attributes[:'id'] if attributes[:'id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.policy_type = attributes[:'policyType'] if attributes[:'policyType']

  raise 'You cannot provide both :policyType and :policy_type' if attributes.key?(:'policyType') && attributes.key?(:'policy_type')

  self.policy_type = attributes[:'policy_type'] if attributes[:'policy_type']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.is_enabled = attributes[:'isEnabled'] unless attributes[:'isEnabled'].nil?

  raise 'You cannot provide both :isEnabled and :is_enabled' if attributes.key?(:'isEnabled') && attributes.key?(:'is_enabled')

  self.is_enabled = attributes[:'is_enabled'] unless attributes[:'is_enabled'].nil?
end

Instance Attribute Details

#capacityOCI::Autoscaling::Models::Capacity

The capacity requirements of the autoscaling policy.



22
23
24
# File 'lib/oci/autoscaling/models/auto_scaling_policy.rb', line 22

def capacity
  @capacity
end

#display_nameString

A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.

Returns:

  • (String)


31
32
33
# File 'lib/oci/autoscaling/models/auto_scaling_policy.rb', line 31

def display_name
  @display_name
end

#idString

The ID of the autoscaling policy that is assigned after creation.

Returns:

  • (String)


26
27
28
# File 'lib/oci/autoscaling/models/auto_scaling_policy.rb', line 26

def id
  @id
end

#is_enabledBOOLEAN

Whether the autoscaling policy is enabled.

Returns:

  • (BOOLEAN)


46
47
48
# File 'lib/oci/autoscaling/models/auto_scaling_policy.rb', line 46

def is_enabled
  @is_enabled
end

#policy_typeString

**[Required]** The type of autoscaling policy.

Returns:

  • (String)


35
36
37
# File 'lib/oci/autoscaling/models/auto_scaling_policy.rb', line 35

def policy_type
  @policy_type
end

#time_createdDateTime

**[Required]** The date and time the autoscaling configuration was created, in the format defined by RFC3339.

Example: `2016-08-25T21:10:29.600Z`

Returns:

  • (DateTime)


42
43
44
# File 'lib/oci/autoscaling/models/auto_scaling_policy.rb', line 42

def time_created
  @time_created
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



49
50
51
52
53
54
55
56
57
58
59
60
# File 'lib/oci/autoscaling/models/auto_scaling_policy.rb', line 49

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'capacity': :'capacity',
    'id': :'id',
    'display_name': :'displayName',
    'policy_type': :'policyType',
    'time_created': :'timeCreated',
    'is_enabled': :'isEnabled'
    # rubocop:enable Style/SymbolLiteral
  }
end

.get_subtype(object_hash) ⇒ Object

Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.



81
82
83
84
85
86
87
88
89
# File 'lib/oci/autoscaling/models/auto_scaling_policy.rb', line 81

def self.get_subtype(object_hash)
  type = object_hash[:'policyType'] # rubocop:disable Style/SymbolLiteral

  return 'OCI::Autoscaling::Models::ScheduledPolicy' if type == 'scheduled'
  return 'OCI::Autoscaling::Models::ThresholdPolicy' if type == 'threshold'

  # TODO: Log a warning when the subtype is not found.
  'OCI::Autoscaling::Models::AutoScalingPolicy'
end

.swagger_typesObject

Attribute type mapping.



63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/oci/autoscaling/models/auto_scaling_policy.rb', line 63

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'capacity': :'OCI::Autoscaling::Models::Capacity',
    'id': :'String',
    'display_name': :'String',
    'policy_type': :'String',
    'time_created': :'DateTime',
    'is_enabled': :'BOOLEAN'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



146
147
148
149
150
151
152
153
154
155
156
# File 'lib/oci/autoscaling/models/auto_scaling_policy.rb', line 146

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    capacity == other.capacity &&
    id == other.id &&
    display_name == other.display_name &&
    policy_type == other.policy_type &&
    time_created == other.time_created &&
    is_enabled == other.is_enabled
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/oci/autoscaling/models/auto_scaling_policy.rb', line 181

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


161
162
163
# File 'lib/oci/autoscaling/models/auto_scaling_policy.rb', line 161

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



170
171
172
# File 'lib/oci/autoscaling/models/auto_scaling_policy.rb', line 170

def hash
  [capacity, id, display_name, policy_type, time_created, is_enabled].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



214
215
216
217
218
219
220
221
222
223
# File 'lib/oci/autoscaling/models/auto_scaling_policy.rb', line 214

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



208
209
210
# File 'lib/oci/autoscaling/models/auto_scaling_policy.rb', line 208

def to_s
  to_hash.to_s
end