Class: OCI::Autoscaling::Models::Capacity
- Inherits:
-
Object
- Object
- OCI::Autoscaling::Models::Capacity
- Defined in:
- lib/oci/autoscaling/models/capacity.rb
Overview
Capacity limits for the instance pool.
Instance Attribute Summary collapse
-
#initial ⇒ Integer
For a threshold-based autoscaling policy, this value is the initial number of instances to launch in the instance pool immediately after autoscaling is enabled.
-
#max ⇒ Integer
For a threshold-based autoscaling policy, this value is the maximum number of instances the instance pool is allowed to increase to (scale out).
-
#min ⇒ Integer
For a threshold-based autoscaling policy, this value is the minimum number of instances the instance pool is allowed to decrease to (scale in).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Capacity
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Capacity
Initializes the object
69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/oci/autoscaling/models/capacity.rb', line 69 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.max = attributes[:'max'] if attributes[:'max'] self.min = attributes[:'min'] if attributes[:'min'] self.initial = attributes[:'initial'] if attributes[:'initial'] end |
Instance Attribute Details
#initial ⇒ Integer
For a threshold-based autoscaling policy, this value is the initial number of instances to launch in the instance pool immediately after autoscaling is enabled. After autoscaling retrieves performance metrics, the number of instances is automatically adjusted from this initial number to a number that is based on the limits that you set.
For a schedule-based autoscaling policy, this value is the target pool size to scale to when executing the schedule that’s defined in the autoscaling policy.
36 37 38 |
# File 'lib/oci/autoscaling/models/capacity.rb', line 36 def initial @initial end |
#max ⇒ Integer
For a threshold-based autoscaling policy, this value is the maximum number of instances the instance pool is allowed to increase to (scale out).
For a schedule-based autoscaling policy, this value is not used.
17 18 19 |
# File 'lib/oci/autoscaling/models/capacity.rb', line 17 def max @max end |
#min ⇒ Integer
For a threshold-based autoscaling policy, this value is the minimum number of instances the instance pool is allowed to decrease to (scale in).
For a schedule-based autoscaling policy, this value is not used.
25 26 27 |
# File 'lib/oci/autoscaling/models/capacity.rb', line 25 def min @min end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 |
# File 'lib/oci/autoscaling/models/capacity.rb', line 39 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'max': :'max', 'min': :'min', 'initial': :'initial' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
50 51 52 53 54 55 56 57 58 |
# File 'lib/oci/autoscaling/models/capacity.rb', line 50 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'max': :'Integer', 'min': :'Integer', 'initial': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
89 90 91 92 93 94 95 96 |
# File 'lib/oci/autoscaling/models/capacity.rb', line 89 def ==(other) return true if equal?(other) self.class == other.class && max == other.max && min == other.min && initial == other.initial end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/oci/autoscaling/models/capacity.rb', line 121 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
101 102 103 |
# File 'lib/oci/autoscaling/models/capacity.rb', line 101 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
110 111 112 |
# File 'lib/oci/autoscaling/models/capacity.rb', line 110 def hash [max, min, initial].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
154 155 156 157 158 159 160 161 162 163 |
# File 'lib/oci/autoscaling/models/capacity.rb', line 154 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
148 149 150 |
# File 'lib/oci/autoscaling/models/capacity.rb', line 148 def to_s to_hash.to_s end |