Class: OCI::Autoscaling::Models::CreateAutoScalingPolicyDetails
- Inherits:
-
Object
- Object
- OCI::Autoscaling::Models::CreateAutoScalingPolicyDetails
- Defined in:
- lib/oci/autoscaling/models/create_auto_scaling_policy_details.rb
Overview
Creation details for an autoscaling policy. You can create the following types of autoscaling policies:
-
Schedule-based: Autoscaling events take place at the specific times that you schedule.
-
Threshold-based: An autoscaling action is triggered when a performance metric meets
or exceeds a threshold.
An autoscaling configuration can either have multiple schedule-based autoscaling policies, or one threshold-based autoscaling policy.
This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
Instance Attribute Summary collapse
-
#capacity ⇒ OCI::Autoscaling::Models::Capacity
The capacity requirements of the autoscaling policy.
-
#display_name ⇒ String
A user-friendly name.
-
#is_enabled ⇒ BOOLEAN
Whether the autoscaling policy is enabled.
-
#policy_type ⇒ String
[Required] The type of autoscaling policy.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateAutoScalingPolicyDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateAutoScalingPolicyDetails
Initializes the object
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/oci/autoscaling/models/create_auto_scaling_policy_details.rb', line 86 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.capacity = attributes[:'capacity'] if attributes[:'capacity'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.policy_type = attributes[:'policyType'] if attributes[:'policyType'] raise 'You cannot provide both :policyType and :policy_type' if attributes.key?(:'policyType') && attributes.key?(:'policy_type') self.policy_type = attributes[:'policy_type'] if attributes[:'policy_type'] self.is_enabled = attributes[:'isEnabled'] unless attributes[:'isEnabled'].nil? self.is_enabled = true if is_enabled.nil? && !attributes.key?(:'isEnabled') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isEnabled and :is_enabled' if attributes.key?(:'isEnabled') && attributes.key?(:'is_enabled') self.is_enabled = attributes[:'is_enabled'] unless attributes[:'is_enabled'].nil? self.is_enabled = true if is_enabled.nil? && !attributes.key?(:'isEnabled') && !attributes.key?(:'is_enabled') # rubocop:disable Style/StringLiterals end |
Instance Attribute Details
#capacity ⇒ OCI::Autoscaling::Models::Capacity
The capacity requirements of the autoscaling policy.
21 22 23 |
# File 'lib/oci/autoscaling/models/create_auto_scaling_policy_details.rb', line 21 def capacity @capacity end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
26 27 28 |
# File 'lib/oci/autoscaling/models/create_auto_scaling_policy_details.rb', line 26 def display_name @display_name end |
#is_enabled ⇒ BOOLEAN
Whether the autoscaling policy is enabled.
34 35 36 |
# File 'lib/oci/autoscaling/models/create_auto_scaling_policy_details.rb', line 34 def is_enabled @is_enabled end |
#policy_type ⇒ String
[Required] The type of autoscaling policy.
30 31 32 |
# File 'lib/oci/autoscaling/models/create_auto_scaling_policy_details.rb', line 30 def policy_type @policy_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/oci/autoscaling/models/create_auto_scaling_policy_details.rb', line 37 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'capacity': :'capacity', 'display_name': :'displayName', 'policy_type': :'policyType', 'is_enabled': :'isEnabled' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
65 66 67 68 69 70 71 72 73 |
# File 'lib/oci/autoscaling/models/create_auto_scaling_policy_details.rb', line 65 def self.get_subtype(object_hash) type = object_hash[:'policyType'] # rubocop:disable Style/SymbolLiteral return 'OCI::Autoscaling::Models::CreateScheduledPolicyDetails' if type == 'scheduled' return 'OCI::Autoscaling::Models::CreateThresholdPolicyDetails' if type == 'threshold' # TODO: Log a warning when the subtype is not found. 'OCI::Autoscaling::Models::CreateAutoScalingPolicyDetails' end |
.swagger_types ⇒ Object
Attribute type mapping.
49 50 51 52 53 54 55 56 57 58 |
# File 'lib/oci/autoscaling/models/create_auto_scaling_policy_details.rb', line 49 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'capacity': :'OCI::Autoscaling::Models::Capacity', 'display_name': :'String', 'policy_type': :'String', 'is_enabled': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
122 123 124 125 126 127 128 129 130 |
# File 'lib/oci/autoscaling/models/create_auto_scaling_policy_details.rb', line 122 def ==(other) return true if equal?(other) self.class == other.class && capacity == other.capacity && display_name == other.display_name && policy_type == other.policy_type && is_enabled == other.is_enabled end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/oci/autoscaling/models/create_auto_scaling_policy_details.rb', line 155 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
135 136 137 |
# File 'lib/oci/autoscaling/models/create_auto_scaling_policy_details.rb', line 135 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
144 145 146 |
# File 'lib/oci/autoscaling/models/create_auto_scaling_policy_details.rb', line 144 def hash [capacity, display_name, policy_type, is_enabled].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
188 189 190 191 192 193 194 195 196 197 |
# File 'lib/oci/autoscaling/models/create_auto_scaling_policy_details.rb', line 188 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
182 183 184 |
# File 'lib/oci/autoscaling/models/create_auto_scaling_policy_details.rb', line 182 def to_s to_hash.to_s end |