Class: OCI::Bastion::Models::Bastion

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/bastion/models/bastion.rb

Overview

A bastion resource. A bastion provides secured, public access to target resources in the cloud that you cannot otherwise reach from the internet. A bastion resides in a public subnet and establishes the network infrastructure needed to connect a user to a target resource in a private subnet.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Bastion

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :bastion_type (String)

    The value to assign to the #bastion_type property

  • :id (String)

    The value to assign to the #id property

  • :name (String)

    The value to assign to the #name property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :target_vcn_id (String)

    The value to assign to the #target_vcn_id property

  • :target_subnet_id (String)

    The value to assign to the #target_subnet_id property

  • :phone_book_entry (String)

    The value to assign to the #phone_book_entry property

  • :client_cidr_block_allow_list (Array<String>)

    The value to assign to the #client_cidr_block_allow_list property

  • :static_jump_host_ip_addresses (Array<String>)

    The value to assign to the #static_jump_host_ip_addresses property

  • :private_endpoint_ip_address (String)

    The value to assign to the #private_endpoint_ip_address property

  • :max_session_ttl_in_seconds (Integer)

    The value to assign to the #max_session_ttl_in_seconds property

  • :max_sessions_allowed (Integer)

    The value to assign to the #max_sessions_allowed property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :time_updated (DateTime)

    The value to assign to the #time_updated property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :lifecycle_details (String)

    The value to assign to the #lifecycle_details property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property

  • :system_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #system_tags property



188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/oci/bastion/models/bastion.rb', line 188

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.bastion_type = attributes[:'bastionType'] if attributes[:'bastionType']

  raise 'You cannot provide both :bastionType and :bastion_type' if attributes.key?(:'bastionType') && attributes.key?(:'bastion_type')

  self.bastion_type = attributes[:'bastion_type'] if attributes[:'bastion_type']

  self.id = attributes[:'id'] if attributes[:'id']

  self.name = attributes[:'name'] if attributes[:'name']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.target_vcn_id = attributes[:'targetVcnId'] if attributes[:'targetVcnId']

  raise 'You cannot provide both :targetVcnId and :target_vcn_id' if attributes.key?(:'targetVcnId') && attributes.key?(:'target_vcn_id')

  self.target_vcn_id = attributes[:'target_vcn_id'] if attributes[:'target_vcn_id']

  self.target_subnet_id = attributes[:'targetSubnetId'] if attributes[:'targetSubnetId']

  raise 'You cannot provide both :targetSubnetId and :target_subnet_id' if attributes.key?(:'targetSubnetId') && attributes.key?(:'target_subnet_id')

  self.target_subnet_id = attributes[:'target_subnet_id'] if attributes[:'target_subnet_id']

  self.phone_book_entry = attributes[:'phoneBookEntry'] if attributes[:'phoneBookEntry']

  raise 'You cannot provide both :phoneBookEntry and :phone_book_entry' if attributes.key?(:'phoneBookEntry') && attributes.key?(:'phone_book_entry')

  self.phone_book_entry = attributes[:'phone_book_entry'] if attributes[:'phone_book_entry']

  self.client_cidr_block_allow_list = attributes[:'clientCidrBlockAllowList'] if attributes[:'clientCidrBlockAllowList']

  raise 'You cannot provide both :clientCidrBlockAllowList and :client_cidr_block_allow_list' if attributes.key?(:'clientCidrBlockAllowList') && attributes.key?(:'client_cidr_block_allow_list')

  self.client_cidr_block_allow_list = attributes[:'client_cidr_block_allow_list'] if attributes[:'client_cidr_block_allow_list']

  self.static_jump_host_ip_addresses = attributes[:'staticJumpHostIpAddresses'] if attributes[:'staticJumpHostIpAddresses']

  raise 'You cannot provide both :staticJumpHostIpAddresses and :static_jump_host_ip_addresses' if attributes.key?(:'staticJumpHostIpAddresses') && attributes.key?(:'static_jump_host_ip_addresses')

  self.static_jump_host_ip_addresses = attributes[:'static_jump_host_ip_addresses'] if attributes[:'static_jump_host_ip_addresses']

  self.private_endpoint_ip_address = attributes[:'privateEndpointIpAddress'] if attributes[:'privateEndpointIpAddress']

  raise 'You cannot provide both :privateEndpointIpAddress and :private_endpoint_ip_address' if attributes.key?(:'privateEndpointIpAddress') && attributes.key?(:'private_endpoint_ip_address')

  self.private_endpoint_ip_address = attributes[:'private_endpoint_ip_address'] if attributes[:'private_endpoint_ip_address']

  self.max_session_ttl_in_seconds = attributes[:'maxSessionTtlInSeconds'] if attributes[:'maxSessionTtlInSeconds']

  raise 'You cannot provide both :maxSessionTtlInSeconds and :max_session_ttl_in_seconds' if attributes.key?(:'maxSessionTtlInSeconds') && attributes.key?(:'max_session_ttl_in_seconds')

  self.max_session_ttl_in_seconds = attributes[:'max_session_ttl_in_seconds'] if attributes[:'max_session_ttl_in_seconds']

  self.max_sessions_allowed = attributes[:'maxSessionsAllowed'] if attributes[:'maxSessionsAllowed']

  raise 'You cannot provide both :maxSessionsAllowed and :max_sessions_allowed' if attributes.key?(:'maxSessionsAllowed') && attributes.key?(:'max_sessions_allowed')

  self.max_sessions_allowed = attributes[:'max_sessions_allowed'] if attributes[:'max_sessions_allowed']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

  raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

  self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']
end

Instance Attribute Details

#bastion_typeString

**[Required]** The type of bastion.

Returns:

  • (String)


23
24
25
# File 'lib/oci/bastion/models/bastion.rb', line 23

def bastion_type
  @bastion_type
end

#client_cidr_block_allow_listArray<String>

A list of address ranges in CIDR notation that you want to allow to connect to sessions hosted by this bastion.

Returns:

  • (Array<String>)


52
53
54
# File 'lib/oci/bastion/models/bastion.rb', line 52

def client_cidr_block_allow_list
  @client_cidr_block_allow_list
end

#compartment_idString

**[Required]** The unique identifier (OCID) of the compartment where the bastion is located.

Returns:

  • (String)


35
36
37
# File 'lib/oci/bastion/models/bastion.rb', line 35

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


101
102
103
# File 'lib/oci/bastion/models/bastion.rb', line 101

def defined_tags
  @defined_tags
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`

Returns:

  • (Hash<String, String>)


95
96
97
# File 'lib/oci/bastion/models/bastion.rb', line 95

def freeform_tags
  @freeform_tags
end

#idString

**[Required]** The unique identifier (OCID) of the bastion, which can't be changed after creation.

Returns:

  • (String)


27
28
29
# File 'lib/oci/bastion/models/bastion.rb', line 27

def id
  @id
end

#lifecycle_detailsString

A message describing the current state in more detail.

Returns:

  • (String)


89
90
91
# File 'lib/oci/bastion/models/bastion.rb', line 89

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

**[Required]** The current state of the bastion.

Returns:

  • (String)


85
86
87
# File 'lib/oci/bastion/models/bastion.rb', line 85

def lifecycle_state
  @lifecycle_state
end

#max_session_ttl_in_secondsInteger

**[Required]** The maximum amount of time that any session on the bastion can remain active.

Returns:

  • (Integer)


65
66
67
# File 'lib/oci/bastion/models/bastion.rb', line 65

def max_session_ttl_in_seconds
  @max_session_ttl_in_seconds
end

#max_sessions_allowedInteger

The maximum number of active sessions allowed on the bastion.

Returns:

  • (Integer)


69
70
71
# File 'lib/oci/bastion/models/bastion.rb', line 69

def max_sessions_allowed
  @max_sessions_allowed
end

#nameString

**[Required]** The name of the bastion, which can't be changed after creation.

Returns:

  • (String)


31
32
33
# File 'lib/oci/bastion/models/bastion.rb', line 31

def name
  @name
end

#phone_book_entryString

The phonebook entry of the customer's team, which can't be changed after creation. Not applicable to `standard` bastions.

Returns:

  • (String)


48
49
50
# File 'lib/oci/bastion/models/bastion.rb', line 48

def phone_book_entry
  @phone_book_entry
end

#private_endpoint_ip_addressString

The private IP address of the created private endpoint.

Returns:

  • (String)


61
62
63
# File 'lib/oci/bastion/models/bastion.rb', line 61

def private_endpoint_ip_address
  @private_endpoint_ip_address
end

#static_jump_host_ip_addressesArray<String>

A list of IP addresses of the hosts that the bastion has access to. Not applicable to `standard` bastions.

Returns:

  • (Array<String>)


57
58
59
# File 'lib/oci/bastion/models/bastion.rb', line 57

def static_jump_host_ip_addresses
  @static_jump_host_ip_addresses
end

#system_tagsHash<String, Hash<String, Object>>

Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"free-tier-retained": "true"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


107
108
109
# File 'lib/oci/bastion/models/bastion.rb', line 107

def system_tags
  @system_tags
end

#target_subnet_idString

**[Required]** The unique identifier (OCID) of the subnet that the bastion connects to.

Returns:

  • (String)


43
44
45
# File 'lib/oci/bastion/models/bastion.rb', line 43

def target_subnet_id
  @target_subnet_id
end

#target_vcn_idString

**[Required]** The unique identifier (OCID) of the virtual cloud network (VCN) that the bastion connects to.

Returns:

  • (String)


39
40
41
# File 'lib/oci/bastion/models/bastion.rb', line 39

def target_vcn_id
  @target_vcn_id
end

#time_createdDateTime

**[Required]** The time the bastion was created. Format is defined by [RFC3339](tools.ietf.org/html/rfc3339). Example: `2020-01-25T21:10:29.600Z`

Returns:

  • (DateTime)


75
76
77
# File 'lib/oci/bastion/models/bastion.rb', line 75

def time_created
  @time_created
end

#time_updatedDateTime

The time the bastion was updated. Format is defined by [RFC3339](tools.ietf.org/html/rfc3339). Example: `2020-01-25T21:10:29.600Z`

Returns:

  • (DateTime)


81
82
83
# File 'lib/oci/bastion/models/bastion.rb', line 81

def time_updated
  @time_updated
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/oci/bastion/models/bastion.rb', line 110

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'bastion_type': :'bastionType',
    'id': :'id',
    'name': :'name',
    'compartment_id': :'compartmentId',
    'target_vcn_id': :'targetVcnId',
    'target_subnet_id': :'targetSubnetId',
    'phone_book_entry': :'phoneBookEntry',
    'client_cidr_block_allow_list': :'clientCidrBlockAllowList',
    'static_jump_host_ip_addresses': :'staticJumpHostIpAddresses',
    'private_endpoint_ip_address': :'privateEndpointIpAddress',
    'max_session_ttl_in_seconds': :'maxSessionTtlInSeconds',
    'max_sessions_allowed': :'maxSessionsAllowed',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/oci/bastion/models/bastion.rb', line 137

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'bastion_type': :'String',
    'id': :'String',
    'name': :'String',
    'compartment_id': :'String',
    'target_vcn_id': :'String',
    'target_subnet_id': :'String',
    'phone_book_entry': :'String',
    'client_cidr_block_allow_list': :'Array<String>',
    'static_jump_host_ip_addresses': :'Array<String>',
    'private_endpoint_ip_address': :'String',
    'max_session_ttl_in_seconds': :'Integer',
    'max_sessions_allowed': :'Integer',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/oci/bastion/models/bastion.rb', line 321

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    bastion_type == other.bastion_type &&
    id == other.id &&
    name == other.name &&
    compartment_id == other.compartment_id &&
    target_vcn_id == other.target_vcn_id &&
    target_subnet_id == other.target_subnet_id &&
    phone_book_entry == other.phone_book_entry &&
    client_cidr_block_allow_list == other.client_cidr_block_allow_list &&
    static_jump_host_ip_addresses == other.static_jump_host_ip_addresses &&
    private_endpoint_ip_address == other.private_endpoint_ip_address &&
    max_session_ttl_in_seconds == other.max_session_ttl_in_seconds &&
    max_sessions_allowed == other.max_sessions_allowed &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/oci/bastion/models/bastion.rb', line 369

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


349
350
351
# File 'lib/oci/bastion/models/bastion.rb', line 349

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



358
359
360
# File 'lib/oci/bastion/models/bastion.rb', line 358

def hash
  [bastion_type, id, name, compartment_id, target_vcn_id, target_subnet_id, phone_book_entry, client_cidr_block_allow_list, static_jump_host_ip_addresses, private_endpoint_ip_address, max_session_ttl_in_seconds, max_sessions_allowed, time_created, time_updated, lifecycle_state, lifecycle_details, freeform_tags, defined_tags, system_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



402
403
404
405
406
407
408
409
410
411
# File 'lib/oci/bastion/models/bastion.rb', line 402

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



396
397
398
# File 'lib/oci/bastion/models/bastion.rb', line 396

def to_s
  to_hash.to_s
end