Class: OCI::Bastion::Models::BastionSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/bastion/models/bastion_summary.rb

Overview

Summary information for a bastion resource. A bastion provides secured, public access to target resources in the cloud that you cannot otherwise reach from the internet. A bastion resides in a public subnet and establishes the network infrastructure needed to connect a user to a target resource in a private subnet.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ BastionSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :bastion_type (String)

    The value to assign to the #bastion_type property

  • :id (String)

    The value to assign to the #id property

  • :name (String)

    The value to assign to the #name property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :target_vcn_id (String)

    The value to assign to the #target_vcn_id property

  • :target_subnet_id (String)

    The value to assign to the #target_subnet_id property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :time_updated (DateTime)

    The value to assign to the #time_updated property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :lifecycle_details (String)

    The value to assign to the #lifecycle_details property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property

  • :system_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #system_tags property



144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/oci/bastion/models/bastion_summary.rb', line 144

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.bastion_type = attributes[:'bastionType'] if attributes[:'bastionType']

  raise 'You cannot provide both :bastionType and :bastion_type' if attributes.key?(:'bastionType') && attributes.key?(:'bastion_type')

  self.bastion_type = attributes[:'bastion_type'] if attributes[:'bastion_type']

  self.id = attributes[:'id'] if attributes[:'id']

  self.name = attributes[:'name'] if attributes[:'name']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.target_vcn_id = attributes[:'targetVcnId'] if attributes[:'targetVcnId']

  raise 'You cannot provide both :targetVcnId and :target_vcn_id' if attributes.key?(:'targetVcnId') && attributes.key?(:'target_vcn_id')

  self.target_vcn_id = attributes[:'target_vcn_id'] if attributes[:'target_vcn_id']

  self.target_subnet_id = attributes[:'targetSubnetId'] if attributes[:'targetSubnetId']

  raise 'You cannot provide both :targetSubnetId and :target_subnet_id' if attributes.key?(:'targetSubnetId') && attributes.key?(:'target_subnet_id')

  self.target_subnet_id = attributes[:'target_subnet_id'] if attributes[:'target_subnet_id']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

  raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

  self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']
end

Instance Attribute Details

#bastion_typeString

**[Required]** The type of bastion.

Returns:

  • (String)


23
24
25
# File 'lib/oci/bastion/models/bastion_summary.rb', line 23

def bastion_type
  @bastion_type
end

#compartment_idString

**[Required]** The unique identifier (OCID) of the compartment where the bastion is located.

Returns:

  • (String)


35
36
37
# File 'lib/oci/bastion/models/bastion_summary.rb', line 35

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


75
76
77
# File 'lib/oci/bastion/models/bastion_summary.rb', line 75

def defined_tags
  @defined_tags
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`

Returns:

  • (Hash<String, String>)


69
70
71
# File 'lib/oci/bastion/models/bastion_summary.rb', line 69

def freeform_tags
  @freeform_tags
end

#idString

**[Required]** The unique identifier (OCID) of the bastion, which can't be changed after creation.

Returns:

  • (String)


27
28
29
# File 'lib/oci/bastion/models/bastion_summary.rb', line 27

def id
  @id
end

#lifecycle_detailsString

A message describing the current state in more detail.

Returns:

  • (String)


63
64
65
# File 'lib/oci/bastion/models/bastion_summary.rb', line 63

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

**[Required]** The current state of the bastion.

Returns:

  • (String)


59
60
61
# File 'lib/oci/bastion/models/bastion_summary.rb', line 59

def lifecycle_state
  @lifecycle_state
end

#nameString

**[Required]** The name of the bastion, which can't be changed after creation.

Returns:

  • (String)


31
32
33
# File 'lib/oci/bastion/models/bastion_summary.rb', line 31

def name
  @name
end

#system_tagsHash<String, Hash<String, Object>>

Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"free-tier-retained": "true"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


81
82
83
# File 'lib/oci/bastion/models/bastion_summary.rb', line 81

def system_tags
  @system_tags
end

#target_subnet_idString

**[Required]** The unique identifier (OCID) of the subnet that the bastion connects to.

Returns:

  • (String)


43
44
45
# File 'lib/oci/bastion/models/bastion_summary.rb', line 43

def target_subnet_id
  @target_subnet_id
end

#target_vcn_idString

**[Required]** The unique identifier (OCID) of the virtual cloud network (VCN) that the bastion connects to.

Returns:

  • (String)


39
40
41
# File 'lib/oci/bastion/models/bastion_summary.rb', line 39

def target_vcn_id
  @target_vcn_id
end

#time_createdDateTime

**[Required]** The time the bastion was created. Format is defined by [RFC3339](tools.ietf.org/html/rfc3339). Example: `2020-01-25T21:10:29.600Z`

Returns:

  • (DateTime)


49
50
51
# File 'lib/oci/bastion/models/bastion_summary.rb', line 49

def time_created
  @time_created
end

#time_updatedDateTime

The time the bastion was updated. Format is defined by [RFC3339](tools.ietf.org/html/rfc3339). Example: `2020-01-25T21:10:29.600Z`

Returns:

  • (DateTime)


55
56
57
# File 'lib/oci/bastion/models/bastion_summary.rb', line 55

def time_updated
  @time_updated
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/oci/bastion/models/bastion_summary.rb', line 84

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'bastion_type': :'bastionType',
    'id': :'id',
    'name': :'name',
    'compartment_id': :'compartmentId',
    'target_vcn_id': :'targetVcnId',
    'target_subnet_id': :'targetSubnetId',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/oci/bastion/models/bastion_summary.rb', line 105

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'bastion_type': :'String',
    'id': :'String',
    'name': :'String',
    'compartment_id': :'String',
    'target_vcn_id': :'String',
    'target_subnet_id': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/oci/bastion/models/bastion_summary.rb', line 241

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    bastion_type == other.bastion_type &&
    id == other.id &&
    name == other.name &&
    compartment_id == other.compartment_id &&
    target_vcn_id == other.target_vcn_id &&
    target_subnet_id == other.target_subnet_id &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
# File 'lib/oci/bastion/models/bastion_summary.rb', line 283

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


263
264
265
# File 'lib/oci/bastion/models/bastion_summary.rb', line 263

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



272
273
274
# File 'lib/oci/bastion/models/bastion_summary.rb', line 272

def hash
  [bastion_type, id, name, compartment_id, target_vcn_id, target_subnet_id, time_created, time_updated, lifecycle_state, lifecycle_details, freeform_tags, defined_tags, system_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



316
317
318
319
320
321
322
323
324
325
# File 'lib/oci/bastion/models/bastion_summary.rb', line 316

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



310
311
312
# File 'lib/oci/bastion/models/bastion_summary.rb', line 310

def to_s
  to_hash.to_s
end