Class: OCI::Bastion::Models::CreateBastionDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/bastion/models/create_bastion_details.rb

Overview

The configuration details for a new bastion. A bastion provides secured, public access to target resources in the cloud that you cannot otherwise reach from the internet. A bastion resides in a public subnet and establishes the network infrastructure needed to connect a user to a target resource in a private subnet.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateBastionDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :bastion_type (String)

    The value to assign to the #bastion_type property

  • :name (String)

    The value to assign to the #name property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :target_subnet_id (String)

    The value to assign to the #target_subnet_id property

  • :phone_book_entry (String)

    The value to assign to the #phone_book_entry property

  • :static_jump_host_ip_addresses (Array<String>)

    The value to assign to the #static_jump_host_ip_addresses property

  • :client_cidr_block_allow_list (Array<String>)

    The value to assign to the #client_cidr_block_allow_list property

  • :max_session_ttl_in_seconds (Integer)

    The value to assign to the #max_session_ttl_in_seconds property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/oci/bastion/models/create_bastion_details.rb', line 109

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.bastion_type = attributes[:'bastionType'] if attributes[:'bastionType']

  raise 'You cannot provide both :bastionType and :bastion_type' if attributes.key?(:'bastionType') && attributes.key?(:'bastion_type')

  self.bastion_type = attributes[:'bastion_type'] if attributes[:'bastion_type']

  self.name = attributes[:'name'] if attributes[:'name']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.target_subnet_id = attributes[:'targetSubnetId'] if attributes[:'targetSubnetId']

  raise 'You cannot provide both :targetSubnetId and :target_subnet_id' if attributes.key?(:'targetSubnetId') && attributes.key?(:'target_subnet_id')

  self.target_subnet_id = attributes[:'target_subnet_id'] if attributes[:'target_subnet_id']

  self.phone_book_entry = attributes[:'phoneBookEntry'] if attributes[:'phoneBookEntry']

  raise 'You cannot provide both :phoneBookEntry and :phone_book_entry' if attributes.key?(:'phoneBookEntry') && attributes.key?(:'phone_book_entry')

  self.phone_book_entry = attributes[:'phone_book_entry'] if attributes[:'phone_book_entry']

  self.static_jump_host_ip_addresses = attributes[:'staticJumpHostIpAddresses'] if attributes[:'staticJumpHostIpAddresses']

  raise 'You cannot provide both :staticJumpHostIpAddresses and :static_jump_host_ip_addresses' if attributes.key?(:'staticJumpHostIpAddresses') && attributes.key?(:'static_jump_host_ip_addresses')

  self.static_jump_host_ip_addresses = attributes[:'static_jump_host_ip_addresses'] if attributes[:'static_jump_host_ip_addresses']

  self.client_cidr_block_allow_list = attributes[:'clientCidrBlockAllowList'] if attributes[:'clientCidrBlockAllowList']

  raise 'You cannot provide both :clientCidrBlockAllowList and :client_cidr_block_allow_list' if attributes.key?(:'clientCidrBlockAllowList') && attributes.key?(:'client_cidr_block_allow_list')

  self.client_cidr_block_allow_list = attributes[:'client_cidr_block_allow_list'] if attributes[:'client_cidr_block_allow_list']

  self.max_session_ttl_in_seconds = attributes[:'maxSessionTtlInSeconds'] if attributes[:'maxSessionTtlInSeconds']

  raise 'You cannot provide both :maxSessionTtlInSeconds and :max_session_ttl_in_seconds' if attributes.key?(:'maxSessionTtlInSeconds') && attributes.key?(:'max_session_ttl_in_seconds')

  self.max_session_ttl_in_seconds = attributes[:'max_session_ttl_in_seconds'] if attributes[:'max_session_ttl_in_seconds']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#bastion_typeString

**[Required]** The type of bastion. Use `standard`.

Returns:

  • (String)


13
14
15
# File 'lib/oci/bastion/models/create_bastion_details.rb', line 13

def bastion_type
  @bastion_type
end

#client_cidr_block_allow_listArray<String>

A list of address ranges in CIDR notation that you want to allow to connect to sessions hosted by this bastion.

Returns:

  • (Array<String>)


39
40
41
# File 'lib/oci/bastion/models/create_bastion_details.rb', line 39

def client_cidr_block_allow_list
  @client_cidr_block_allow_list
end

#compartment_idString

**[Required]** The unique identifier (OCID) of the compartment where the bastion is located.

Returns:

  • (String)


21
22
23
# File 'lib/oci/bastion/models/create_bastion_details.rb', line 21

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


55
56
57
# File 'lib/oci/bastion/models/create_bastion_details.rb', line 55

def defined_tags
  @defined_tags
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`

Returns:

  • (Hash<String, String>)


49
50
51
# File 'lib/oci/bastion/models/create_bastion_details.rb', line 49

def freeform_tags
  @freeform_tags
end

#max_session_ttl_in_secondsInteger

The maximum amount of time that any session on the bastion can remain active.

Returns:

  • (Integer)


43
44
45
# File 'lib/oci/bastion/models/create_bastion_details.rb', line 43

def max_session_ttl_in_seconds
  @max_session_ttl_in_seconds
end

#nameString

The name of the bastion, which can't be changed after creation.

Returns:

  • (String)


17
18
19
# File 'lib/oci/bastion/models/create_bastion_details.rb', line 17

def name
  @name
end

#phone_book_entryString

The phonebook entry of the customer's team, which can't be changed after creation. Not applicable to `standard` bastions.

Returns:

  • (String)


30
31
32
# File 'lib/oci/bastion/models/create_bastion_details.rb', line 30

def phone_book_entry
  @phone_book_entry
end

#static_jump_host_ip_addressesArray<String>

A list of IP addresses of the hosts that the bastion has access to. Not applicable to `standard` bastions.

Returns:

  • (Array<String>)


35
36
37
# File 'lib/oci/bastion/models/create_bastion_details.rb', line 35

def static_jump_host_ip_addresses
  @static_jump_host_ip_addresses
end

#target_subnet_idString

**[Required]** The unique identifier (OCID) of the subnet that the bastion connects to.

Returns:

  • (String)


25
26
27
# File 'lib/oci/bastion/models/create_bastion_details.rb', line 25

def target_subnet_id
  @target_subnet_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/oci/bastion/models/create_bastion_details.rb', line 58

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'bastion_type': :'bastionType',
    'name': :'name',
    'compartment_id': :'compartmentId',
    'target_subnet_id': :'targetSubnetId',
    'phone_book_entry': :'phoneBookEntry',
    'static_jump_host_ip_addresses': :'staticJumpHostIpAddresses',
    'client_cidr_block_allow_list': :'clientCidrBlockAllowList',
    'max_session_ttl_in_seconds': :'maxSessionTtlInSeconds',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/oci/bastion/models/create_bastion_details.rb', line 76

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'bastion_type': :'String',
    'name': :'String',
    'compartment_id': :'String',
    'target_subnet_id': :'String',
    'phone_book_entry': :'String',
    'static_jump_host_ip_addresses': :'Array<String>',
    'client_cidr_block_allow_list': :'Array<String>',
    'max_session_ttl_in_seconds': :'Integer',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/oci/bastion/models/create_bastion_details.rb', line 179

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    bastion_type == other.bastion_type &&
    name == other.name &&
    compartment_id == other.compartment_id &&
    target_subnet_id == other.target_subnet_id &&
    phone_book_entry == other.phone_book_entry &&
    static_jump_host_ip_addresses == other.static_jump_host_ip_addresses &&
    client_cidr_block_allow_list == other.client_cidr_block_allow_list &&
    max_session_ttl_in_seconds == other.max_session_ttl_in_seconds &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/oci/bastion/models/create_bastion_details.rb', line 218

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


198
199
200
# File 'lib/oci/bastion/models/create_bastion_details.rb', line 198

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



207
208
209
# File 'lib/oci/bastion/models/create_bastion_details.rb', line 207

def hash
  [bastion_type, name, compartment_id, target_subnet_id, phone_book_entry, static_jump_host_ip_addresses, client_cidr_block_allow_list, max_session_ttl_in_seconds, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



251
252
253
254
255
256
257
258
259
260
# File 'lib/oci/bastion/models/create_bastion_details.rb', line 251

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



245
246
247
# File 'lib/oci/bastion/models/create_bastion_details.rb', line 245

def to_s
  to_hash.to_s
end