Class: OCI::Bastion::Models::CreateSessionDetails
- Inherits:
-
Object
- Object
- OCI::Bastion::Models::CreateSessionDetails
- Defined in:
- lib/oci/bastion/models/create_session_details.rb
Overview
The configuration details for a new bastion session. A session lets authorized users connect to a target resource for a predetermined amount of time. The Bastion service recognizes two types of sessions, managed SSH sessions and SSH port forwarding sessions. Managed SSH sessions require that the target resource has an OpenSSH server and the Oracle Cloud Agent both running.
Constant Summary collapse
- KEY_TYPE_ENUM =
[ KEY_TYPE_PUB = 'PUB'.freeze ].freeze
Instance Attribute Summary collapse
-
#bastion_id ⇒ String
[Required] The unique identifier (OCID) of the bastion on which to create this session.
-
#display_name ⇒ String
The name of the session.
-
#key_details ⇒ OCI::Bastion::Models::PublicKeyDetails
This attribute is required.
-
#key_type ⇒ String
The type of the key used to connect to the session.
-
#session_ttl_in_seconds ⇒ Integer
The amount of time the session can remain active.
-
#target_resource_details ⇒ OCI::Bastion::Models::CreateSessionTargetResourceDetails
This attribute is required.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateSessionDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateSessionDetails
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/oci/bastion/models/create_session_details.rb', line 78 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.bastion_id = attributes[:'bastionId'] if attributes[:'bastionId'] raise 'You cannot provide both :bastionId and :bastion_id' if attributes.key?(:'bastionId') && attributes.key?(:'bastion_id') self.bastion_id = attributes[:'bastion_id'] if attributes[:'bastion_id'] self.target_resource_details = attributes[:'targetResourceDetails'] if attributes[:'targetResourceDetails'] raise 'You cannot provide both :targetResourceDetails and :target_resource_details' if attributes.key?(:'targetResourceDetails') && attributes.key?(:'target_resource_details') self.target_resource_details = attributes[:'target_resource_details'] if attributes[:'target_resource_details'] self.key_type = attributes[:'keyType'] if attributes[:'keyType'] self.key_type = "PUB" if key_type.nil? && !attributes.key?(:'keyType') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :keyType and :key_type' if attributes.key?(:'keyType') && attributes.key?(:'key_type') self.key_type = attributes[:'key_type'] if attributes[:'key_type'] self.key_type = "PUB" if key_type.nil? && !attributes.key?(:'keyType') && !attributes.key?(:'key_type') # rubocop:disable Style/StringLiterals self.key_details = attributes[:'keyDetails'] if attributes[:'keyDetails'] raise 'You cannot provide both :keyDetails and :key_details' if attributes.key?(:'keyDetails') && attributes.key?(:'key_details') self.key_details = attributes[:'key_details'] if attributes[:'key_details'] self.session_ttl_in_seconds = attributes[:'sessionTtlInSeconds'] if attributes[:'sessionTtlInSeconds'] raise 'You cannot provide both :sessionTtlInSeconds and :session_ttl_in_seconds' if attributes.key?(:'sessionTtlInSeconds') && attributes.key?(:'session_ttl_in_seconds') self.session_ttl_in_seconds = attributes[:'session_ttl_in_seconds'] if attributes[:'session_ttl_in_seconds'] end |
Instance Attribute Details
#bastion_id ⇒ String
[Required] The unique identifier (OCID) of the bastion on which to create this session.
20 21 22 |
# File 'lib/oci/bastion/models/create_session_details.rb', line 20 def bastion_id @bastion_id end |
#display_name ⇒ String
The name of the session.
16 17 18 |
# File 'lib/oci/bastion/models/create_session_details.rb', line 16 def display_name @display_name end |
#key_details ⇒ OCI::Bastion::Models::PublicKeyDetails
This attribute is required.
32 33 34 |
# File 'lib/oci/bastion/models/create_session_details.rb', line 32 def key_details @key_details end |
#key_type ⇒ String
The type of the key used to connect to the session. PUB is a standard public key in OpenSSH format.
28 29 30 |
# File 'lib/oci/bastion/models/create_session_details.rb', line 28 def key_type @key_type end |
#session_ttl_in_seconds ⇒ Integer
The amount of time the session can remain active.
36 37 38 |
# File 'lib/oci/bastion/models/create_session_details.rb', line 36 def session_ttl_in_seconds @session_ttl_in_seconds end |
#target_resource_details ⇒ OCI::Bastion::Models::CreateSessionTargetResourceDetails
This attribute is required.
24 25 26 |
# File 'lib/oci/bastion/models/create_session_details.rb', line 24 def target_resource_details @target_resource_details end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/oci/bastion/models/create_session_details.rb', line 39 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'bastion_id': :'bastionId', 'target_resource_details': :'targetResourceDetails', 'key_type': :'keyType', 'key_details': :'keyDetails', 'session_ttl_in_seconds': :'sessionTtlInSeconds' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/oci/bastion/models/create_session_details.rb', line 53 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'bastion_id': :'String', 'target_resource_details': :'OCI::Bastion::Models::CreateSessionTargetResourceDetails', 'key_type': :'String', 'key_details': :'OCI::Bastion::Models::PublicKeyDetails', 'session_ttl_in_seconds': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/oci/bastion/models/create_session_details.rb', line 138 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && bastion_id == other.bastion_id && target_resource_details == other.target_resource_details && key_type == other.key_type && key_details == other.key_details && session_ttl_in_seconds == other.session_ttl_in_seconds end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/oci/bastion/models/create_session_details.rb', line 173 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
153 154 155 |
# File 'lib/oci/bastion/models/create_session_details.rb', line 153 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
162 163 164 |
# File 'lib/oci/bastion/models/create_session_details.rb', line 162 def hash [display_name, bastion_id, target_resource_details, key_type, key_details, session_ttl_in_seconds].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
206 207 208 209 210 211 212 213 214 215 |
# File 'lib/oci/bastion/models/create_session_details.rb', line 206 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
200 201 202 |
# File 'lib/oci/bastion/models/create_session_details.rb', line 200 def to_s to_hash.to_s end |