Class: OCI::Bastion::Models::CreateSessionTargetResourceDetails
- Inherits:
-
Object
- Object
- OCI::Bastion::Models::CreateSessionTargetResourceDetails
- Defined in:
- lib/oci/bastion/models/create_session_target_resource_details.rb
Overview
Details about a bastion session’s target resource. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
CreateManagedSshSessionTargetResourceDetails, CreatePortForwardingSessionTargetResourceDetails
Constant Summary collapse
- SESSION_TYPE_ENUM =
[ SESSION_TYPE_MANAGED_SSH = 'MANAGED_SSH'.freeze, SESSION_TYPE_PORT_FORWARDING = 'PORT_FORWARDING'.freeze ].freeze
Instance Attribute Summary collapse
-
#session_type ⇒ String
[Required] The session type.
-
#target_resource_port ⇒ Integer
The port number to connect to on the target resource.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateSessionTargetResourceDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateSessionTargetResourceDetails
Initializes the object
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/oci/bastion/models/create_session_target_resource_details.rb', line 68 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.session_type = attributes[:'sessionType'] if attributes[:'sessionType'] raise 'You cannot provide both :sessionType and :session_type' if attributes.key?(:'sessionType') && attributes.key?(:'session_type') self.session_type = attributes[:'session_type'] if attributes[:'session_type'] self.target_resource_port = attributes[:'targetResourcePort'] if attributes[:'targetResourcePort'] raise 'You cannot provide both :targetResourcePort and :target_resource_port' if attributes.key?(:'targetResourcePort') && attributes.key?(:'target_resource_port') self.target_resource_port = attributes[:'target_resource_port'] if attributes[:'target_resource_port'] end |
Instance Attribute Details
#session_type ⇒ String
[Required] The session type.
18 19 20 |
# File 'lib/oci/bastion/models/create_session_target_resource_details.rb', line 18 def session_type @session_type end |
#target_resource_port ⇒ Integer
The port number to connect to on the target resource.
22 23 24 |
# File 'lib/oci/bastion/models/create_session_target_resource_details.rb', line 22 def target_resource_port @target_resource_port end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
25 26 27 28 29 30 31 32 |
# File 'lib/oci/bastion/models/create_session_target_resource_details.rb', line 25 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'session_type': :'sessionType', 'target_resource_port': :'targetResourcePort' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
49 50 51 52 53 54 55 56 57 |
# File 'lib/oci/bastion/models/create_session_target_resource_details.rb', line 49 def self.get_subtype(object_hash) type = object_hash[:'sessionType'] # rubocop:disable Style/SymbolLiteral return 'OCI::Bastion::Models::CreateManagedSshSessionTargetResourceDetails' if type == 'MANAGED_SSH' return 'OCI::Bastion::Models::CreatePortForwardingSessionTargetResourceDetails' if type == 'PORT_FORWARDING' # TODO: Log a warning when the subtype is not found. 'OCI::Bastion::Models::CreateSessionTargetResourceDetails' end |
.swagger_types ⇒ Object
Attribute type mapping.
35 36 37 38 39 40 41 42 |
# File 'lib/oci/bastion/models/create_session_target_resource_details.rb', line 35 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'session_type': :'String', 'target_resource_port': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
102 103 104 105 106 107 108 |
# File 'lib/oci/bastion/models/create_session_target_resource_details.rb', line 102 def ==(other) return true if equal?(other) self.class == other.class && session_type == other.session_type && target_resource_port == other.target_resource_port end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/oci/bastion/models/create_session_target_resource_details.rb', line 133 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
113 114 115 |
# File 'lib/oci/bastion/models/create_session_target_resource_details.rb', line 113 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
122 123 124 |
# File 'lib/oci/bastion/models/create_session_target_resource_details.rb', line 122 def hash [session_type, target_resource_port].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
166 167 168 169 170 171 172 173 174 175 |
# File 'lib/oci/bastion/models/create_session_target_resource_details.rb', line 166 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
160 161 162 |
# File 'lib/oci/bastion/models/create_session_target_resource_details.rb', line 160 def to_s to_hash.to_s end |