Class: OCI::Bastion::Models::Session
- Inherits:
-
Object
- Object
- OCI::Bastion::Models::Session
- Defined in:
- lib/oci/bastion/models/session.rb
Overview
A bastion session resource. A bastion session lets authorized users connect to a target resource using a Secure Shell (SSH) for a predetermined amount of time.
Constant Summary collapse
- KEY_TYPE_ENUM =
[ KEY_TYPE_PUB = 'PUB'.freeze, KEY_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#bastion_id ⇒ String
**[Required]** The unique identifier (OCID) of the bastion that is hosting this session.
-
#bastion_name ⇒ String
**[Required]** The name of the bastion that is hosting this session.
-
#bastion_public_host_key_info ⇒ String
The public key of the bastion host.
-
#bastion_user_name ⇒ String
The username that the session uses to connect to the target resource.
-
#display_name ⇒ String
The name of the session.
-
#id ⇒ String
**[Required]** The unique identifier (OCID) of the session, which can't be changed after creation.
-
#key_details ⇒ OCI::Bastion::Models::PublicKeyDetails
This attribute is required.
-
#key_type ⇒ String
The type of the key used to connect to the session.
-
#lifecycle_details ⇒ String
A message describing the current session state in more detail.
-
#lifecycle_state ⇒ String
**[Required]** The current state of the session.
-
#session_ttl_in_seconds ⇒ Integer
**[Required]** The amount of time the session can remain active.
-
#ssh_metadata ⇒ Hash<String, String>
The connection message for the session.
-
#target_resource_details ⇒ OCI::Bastion::Models::TargetResourceDetails
This attribute is required.
-
#time_created ⇒ DateTime
**[Required]** The time the session was created.
-
#time_updated ⇒ DateTime
The time the session was updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Session
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Session
Initializes the object
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/oci/bastion/models/session.rb', line 156 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.bastion_id = attributes[:'bastionId'] if attributes[:'bastionId'] raise 'You cannot provide both :bastionId and :bastion_id' if attributes.key?(:'bastionId') && attributes.key?(:'bastion_id') self.bastion_id = attributes[:'bastion_id'] if attributes[:'bastion_id'] self.bastion_name = attributes[:'bastionName'] if attributes[:'bastionName'] raise 'You cannot provide both :bastionName and :bastion_name' if attributes.key?(:'bastionName') && attributes.key?(:'bastion_name') self.bastion_name = attributes[:'bastion_name'] if attributes[:'bastion_name'] self.bastion_user_name = attributes[:'bastionUserName'] if attributes[:'bastionUserName'] raise 'You cannot provide both :bastionUserName and :bastion_user_name' if attributes.key?(:'bastionUserName') && attributes.key?(:'bastion_user_name') self.bastion_user_name = attributes[:'bastion_user_name'] if attributes[:'bastion_user_name'] self.target_resource_details = attributes[:'targetResourceDetails'] if attributes[:'targetResourceDetails'] raise 'You cannot provide both :targetResourceDetails and :target_resource_details' if attributes.key?(:'targetResourceDetails') && attributes.key?(:'target_resource_details') self.target_resource_details = attributes[:'target_resource_details'] if attributes[:'target_resource_details'] self. = attributes[:'sshMetadata'] if attributes[:'sshMetadata'] raise 'You cannot provide both :sshMetadata and :ssh_metadata' if attributes.key?(:'sshMetadata') && attributes.key?(:'ssh_metadata') self. = attributes[:'ssh_metadata'] if attributes[:'ssh_metadata'] self.key_type = attributes[:'keyType'] if attributes[:'keyType'] self.key_type = "PUB" if key_type.nil? && !attributes.key?(:'keyType') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :keyType and :key_type' if attributes.key?(:'keyType') && attributes.key?(:'key_type') self.key_type = attributes[:'key_type'] if attributes[:'key_type'] self.key_type = "PUB" if key_type.nil? && !attributes.key?(:'keyType') && !attributes.key?(:'key_type') # rubocop:disable Style/StringLiterals self.key_details = attributes[:'keyDetails'] if attributes[:'keyDetails'] raise 'You cannot provide both :keyDetails and :key_details' if attributes.key?(:'keyDetails') && attributes.key?(:'key_details') self.key_details = attributes[:'key_details'] if attributes[:'key_details'] self.bastion_public_host_key_info = attributes[:'bastionPublicHostKeyInfo'] if attributes[:'bastionPublicHostKeyInfo'] raise 'You cannot provide both :bastionPublicHostKeyInfo and :bastion_public_host_key_info' if attributes.key?(:'bastionPublicHostKeyInfo') && attributes.key?(:'bastion_public_host_key_info') self.bastion_public_host_key_info = attributes[:'bastion_public_host_key_info'] if attributes[:'bastion_public_host_key_info'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.session_ttl_in_seconds = attributes[:'sessionTtlInSeconds'] if attributes[:'sessionTtlInSeconds'] raise 'You cannot provide both :sessionTtlInSeconds and :session_ttl_in_seconds' if attributes.key?(:'sessionTtlInSeconds') && attributes.key?(:'session_ttl_in_seconds') self.session_ttl_in_seconds = attributes[:'session_ttl_in_seconds'] if attributes[:'session_ttl_in_seconds'] end |
Instance Attribute Details
#bastion_id ⇒ String
**[Required]** The unique identifier (OCID) of the bastion that is hosting this session.
35 36 37 |
# File 'lib/oci/bastion/models/session.rb', line 35 def bastion_id @bastion_id end |
#bastion_name ⇒ String
**[Required]** The name of the bastion that is hosting this session.
39 40 41 |
# File 'lib/oci/bastion/models/session.rb', line 39 def bastion_name @bastion_name end |
#bastion_public_host_key_info ⇒ String
The public key of the bastion host. You can use this to verify that you're connecting to the correct bastion.
63 64 65 |
# File 'lib/oci/bastion/models/session.rb', line 63 def bastion_public_host_key_info @bastion_public_host_key_info end |
#bastion_user_name ⇒ String
The username that the session uses to connect to the target resource.
43 44 45 |
# File 'lib/oci/bastion/models/session.rb', line 43 def bastion_user_name @bastion_user_name end |
#display_name ⇒ String
The name of the session.
31 32 33 |
# File 'lib/oci/bastion/models/session.rb', line 31 def display_name @display_name end |
#id ⇒ String
**[Required]** The unique identifier (OCID) of the session, which can't be changed after creation.
27 28 29 |
# File 'lib/oci/bastion/models/session.rb', line 27 def id @id end |
#key_details ⇒ OCI::Bastion::Models::PublicKeyDetails
This attribute is required.
59 60 61 |
# File 'lib/oci/bastion/models/session.rb', line 59 def key_details @key_details end |
#key_type ⇒ String
The type of the key used to connect to the session. PUB is a standard public key in OpenSSH format.
55 56 57 |
# File 'lib/oci/bastion/models/session.rb', line 55 def key_type @key_type end |
#lifecycle_details ⇒ String
A message describing the current session state in more detail.
83 84 85 |
# File 'lib/oci/bastion/models/session.rb', line 83 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
**[Required]** The current state of the session.
79 80 81 |
# File 'lib/oci/bastion/models/session.rb', line 79 def lifecycle_state @lifecycle_state end |
#session_ttl_in_seconds ⇒ Integer
**[Required]** The amount of time the session can remain active.
87 88 89 |
# File 'lib/oci/bastion/models/session.rb', line 87 def session_ttl_in_seconds @session_ttl_in_seconds end |
#ssh_metadata ⇒ Hash<String, String>
The connection message for the session.
51 52 53 |
# File 'lib/oci/bastion/models/session.rb', line 51 def @ssh_metadata end |
#target_resource_details ⇒ OCI::Bastion::Models::TargetResourceDetails
This attribute is required.
47 48 49 |
# File 'lib/oci/bastion/models/session.rb', line 47 def target_resource_details @target_resource_details end |
#time_created ⇒ DateTime
**[Required]** The time the session was created. Format is defined by [RFC3339](tools.ietf.org/html/rfc3339). Example: `2020-01-25T21:10:29.600Z`
69 70 71 |
# File 'lib/oci/bastion/models/session.rb', line 69 def time_created @time_created end |
#time_updated ⇒ DateTime
The time the session was updated. Format is defined by [RFC3339](tools.ietf.org/html/rfc3339). Example: `2020-01-25T21:10:29.600Z`
75 76 77 |
# File 'lib/oci/bastion/models/session.rb', line 75 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/oci/bastion/models/session.rb', line 90 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'bastion_id': :'bastionId', 'bastion_name': :'bastionName', 'bastion_user_name': :'bastionUserName', 'target_resource_details': :'targetResourceDetails', 'ssh_metadata': :'sshMetadata', 'key_type': :'keyType', 'key_details': :'keyDetails', 'bastion_public_host_key_info': :'bastionPublicHostKeyInfo', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'session_ttl_in_seconds': :'sessionTtlInSeconds' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/oci/bastion/models/session.rb', line 113 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'bastion_id': :'String', 'bastion_name': :'String', 'bastion_user_name': :'String', 'target_resource_details': :'OCI::Bastion::Models::TargetResourceDetails', 'ssh_metadata': :'Hash<String, String>', 'key_type': :'String', 'key_details': :'OCI::Bastion::Models::PublicKeyDetails', 'bastion_public_host_key_info': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'session_ttl_in_seconds': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 |
# File 'lib/oci/bastion/models/session.rb', line 284 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && bastion_id == other.bastion_id && bastion_name == other.bastion_name && bastion_user_name == other.bastion_user_name && target_resource_details == other.target_resource_details && == other. && key_type == other.key_type && key_details == other.key_details && bastion_public_host_key_info == other.bastion_public_host_key_info && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && session_ttl_in_seconds == other.session_ttl_in_seconds end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 |
# File 'lib/oci/bastion/models/session.rb', line 328 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
308 309 310 |
# File 'lib/oci/bastion/models/session.rb', line 308 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
317 318 319 |
# File 'lib/oci/bastion/models/session.rb', line 317 def hash [id, display_name, bastion_id, bastion_name, bastion_user_name, target_resource_details, , key_type, key_details, bastion_public_host_key_info, time_created, time_updated, lifecycle_state, lifecycle_details, session_ttl_in_seconds].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
361 362 363 364 365 366 367 368 369 370 |
# File 'lib/oci/bastion/models/session.rb', line 361 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
355 356 357 |
# File 'lib/oci/bastion/models/session.rb', line 355 def to_s to_hash.to_s end |