Class: OCI::Bastion::Models::UpdateBastionDetails
- Inherits:
-
Object
- Object
- OCI::Bastion::Models::UpdateBastionDetails
- Defined in:
- lib/oci/bastion/models/update_bastion_details.rb
Overview
The configuration to update on an existing bastion.
Instance Attribute Summary collapse
-
#client_cidr_block_allow_list ⇒ Array<String>
A list of address ranges in CIDR notation that you want to allow to connect to sessions hosted by this bastion.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#max_session_ttl_in_seconds ⇒ Integer
The maximum amount of time that any session on the bastion can remain active.
-
#static_jump_host_ip_addresses ⇒ Array<String>
A list of IP addresses of the hosts that the bastion has access to.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateBastionDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateBastionDetails
Initializes the object
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/oci/bastion/models/update_bastion_details.rb', line 72 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.max_session_ttl_in_seconds = attributes[:'maxSessionTtlInSeconds'] if attributes[:'maxSessionTtlInSeconds'] raise 'You cannot provide both :maxSessionTtlInSeconds and :max_session_ttl_in_seconds' if attributes.key?(:'maxSessionTtlInSeconds') && attributes.key?(:'max_session_ttl_in_seconds') self.max_session_ttl_in_seconds = attributes[:'max_session_ttl_in_seconds'] if attributes[:'max_session_ttl_in_seconds'] self.static_jump_host_ip_addresses = attributes[:'staticJumpHostIpAddresses'] if attributes[:'staticJumpHostIpAddresses'] raise 'You cannot provide both :staticJumpHostIpAddresses and :static_jump_host_ip_addresses' if attributes.key?(:'staticJumpHostIpAddresses') && attributes.key?(:'static_jump_host_ip_addresses') self.static_jump_host_ip_addresses = attributes[:'static_jump_host_ip_addresses'] if attributes[:'static_jump_host_ip_addresses'] self.client_cidr_block_allow_list = attributes[:'clientCidrBlockAllowList'] if attributes[:'clientCidrBlockAllowList'] raise 'You cannot provide both :clientCidrBlockAllowList and :client_cidr_block_allow_list' if attributes.key?(:'clientCidrBlockAllowList') && attributes.key?(:'client_cidr_block_allow_list') self.client_cidr_block_allow_list = attributes[:'client_cidr_block_allow_list'] if attributes[:'client_cidr_block_allow_list'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#client_cidr_block_allow_list ⇒ Array<String>
A list of address ranges in CIDR notation that you want to allow to connect to sessions hosted by this bastion.
21 22 23 |
# File 'lib/oci/bastion/models/update_bastion_details.rb', line 21 def client_cidr_block_allow_list @client_cidr_block_allow_list end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
33 34 35 |
# File 'lib/oci/bastion/models/update_bastion_details.rb', line 33 def @defined_tags end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
27 28 29 |
# File 'lib/oci/bastion/models/update_bastion_details.rb', line 27 def @freeform_tags end |
#max_session_ttl_in_seconds ⇒ Integer
The maximum amount of time that any session on the bastion can remain active.
12 13 14 |
# File 'lib/oci/bastion/models/update_bastion_details.rb', line 12 def max_session_ttl_in_seconds @max_session_ttl_in_seconds end |
#static_jump_host_ip_addresses ⇒ Array<String>
A list of IP addresses of the hosts that the bastion has access to. Not applicable to `standard` bastions.
17 18 19 |
# File 'lib/oci/bastion/models/update_bastion_details.rb', line 17 def static_jump_host_ip_addresses @static_jump_host_ip_addresses end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/oci/bastion/models/update_bastion_details.rb', line 36 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'max_session_ttl_in_seconds': :'maxSessionTtlInSeconds', 'static_jump_host_ip_addresses': :'staticJumpHostIpAddresses', 'client_cidr_block_allow_list': :'clientCidrBlockAllowList', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/oci/bastion/models/update_bastion_details.rb', line 49 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'max_session_ttl_in_seconds': :'Integer', 'static_jump_host_ip_addresses': :'Array<String>', 'client_cidr_block_allow_list': :'Array<String>', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
116 117 118 119 120 121 122 123 124 125 |
# File 'lib/oci/bastion/models/update_bastion_details.rb', line 116 def ==(other) return true if equal?(other) self.class == other.class && max_session_ttl_in_seconds == other.max_session_ttl_in_seconds && static_jump_host_ip_addresses == other.static_jump_host_ip_addresses && client_cidr_block_allow_list == other.client_cidr_block_allow_list && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/oci/bastion/models/update_bastion_details.rb', line 150 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
130 131 132 |
# File 'lib/oci/bastion/models/update_bastion_details.rb', line 130 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
139 140 141 |
# File 'lib/oci/bastion/models/update_bastion_details.rb', line 139 def hash [max_session_ttl_in_seconds, static_jump_host_ip_addresses, client_cidr_block_allow_list, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
183 184 185 186 187 188 189 190 191 192 |
# File 'lib/oci/bastion/models/update_bastion_details.rb', line 183 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
177 178 179 |
# File 'lib/oci/bastion/models/update_bastion_details.rb', line 177 def to_s to_hash.to_s end |