Class: OCI::Bds::Models::AddAutoScalePolicyDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/bds/models/add_auto_scale_policy_details.rb

Overview

Policy definition for the autoscale configuration.

An autoscaling policy is part of an autoscaling configuration. For more information, see [Autoscaling](docs.cloud.oracle.com/iaas/Content/bigdata/create-cluster.htm#cluster-autoscale)

You can create following type of autoscaling policies:

  • *MetricBasedVerticalScalingPolicy:* Vertical autoscaling action is triggered when a performance metric exceeds a threshold

  • *MetricBasedHorizontalScalingPolicy:* Horizontal autoscaling action is triggered when a performance metric exceeds a threshold

  • *ScheduleBasedVerticalScalingPolicy:* Vertical autoscaling action is triggered at the specific times that you schedule.

  • *ScheduleBasedHorizontalScalingPolicy:* Horizontal autoscaling action is triggered at the specific times that you schedule.

An autoscaling configuration can have one of above supported policies.

This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ AddAutoScalePolicyDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :policy_type (String)

    The value to assign to the #policy_type property



71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/oci/bds/models/add_auto_scale_policy_details.rb', line 71

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.policy_type = attributes[:'policyType'] if attributes[:'policyType']

  raise 'You cannot provide both :policyType and :policy_type' if attributes.key?(:'policyType') && attributes.key?(:'policy_type')

  self.policy_type = attributes[:'policy_type'] if attributes[:'policy_type']
end

Instance Attribute Details

#policy_typeString

**[Required]** Type of autoscaling policy.

Returns:

  • (String)


26
27
28
# File 'lib/oci/bds/models/add_auto_scale_policy_details.rb', line 26

def policy_type
  @policy_type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



29
30
31
32
33
34
35
# File 'lib/oci/bds/models/add_auto_scale_policy_details.rb', line 29

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'policy_type': :'policyType'
    # rubocop:enable Style/SymbolLiteral
  }
end

.get_subtype(object_hash) ⇒ Object

Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.



51
52
53
54
55
56
57
58
59
60
61
# File 'lib/oci/bds/models/add_auto_scale_policy_details.rb', line 51

def self.get_subtype(object_hash)
  type = object_hash[:'policyType'] # rubocop:disable Style/SymbolLiteral

  return 'OCI::Bds::Models::AddMetricBasedHorizontalScalingPolicyDetails' if type == 'METRIC_BASED_HORIZONTAL_SCALING_POLICY'
  return 'OCI::Bds::Models::AddScheduleBasedVerticalScalingPolicyDetails' if type == 'SCHEDULE_BASED_VERTICAL_SCALING_POLICY'
  return 'OCI::Bds::Models::AddScheduleBasedHorizontalScalingPolicyDetails' if type == 'SCHEDULE_BASED_HORIZONTAL_SCALING_POLICY'
  return 'OCI::Bds::Models::AddMetricBasedVerticalScalingPolicyDetails' if type == 'METRIC_BASED_VERTICAL_SCALING_POLICY'

  # TODO: Log a warning when the subtype is not found.
  'OCI::Bds::Models::AddAutoScalePolicyDetails'
end

.swagger_typesObject

Attribute type mapping.



38
39
40
41
42
43
44
# File 'lib/oci/bds/models/add_auto_scale_policy_details.rb', line 38

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'policy_type': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



91
92
93
94
95
96
# File 'lib/oci/bds/models/add_auto_scale_policy_details.rb', line 91

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    policy_type == other.policy_type
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/oci/bds/models/add_auto_scale_policy_details.rb', line 121

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


101
102
103
# File 'lib/oci/bds/models/add_auto_scale_policy_details.rb', line 101

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



110
111
112
# File 'lib/oci/bds/models/add_auto_scale_policy_details.rb', line 110

def hash
  [policy_type].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



154
155
156
157
158
159
160
161
162
163
# File 'lib/oci/bds/models/add_auto_scale_policy_details.rb', line 154

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



148
149
150
# File 'lib/oci/bds/models/add_auto_scale_policy_details.rb', line 148

def to_s
  to_hash.to_s
end