Class: OCI::Bds::Models::AddAutoScalingConfigurationDetails
- Inherits:
-
Object
- Object
- OCI::Bds::Models::AddAutoScalingConfigurationDetails
- Defined in:
- lib/oci/bds/models/add_auto_scaling_configuration_details.rb
Overview
The information about the autoscale configuration.
Instance Attribute Summary collapse
-
#cluster_admin_password ⇒ String
**[Required]** Base-64 encoded password for the cluster (and Cloudera Manager) admin user.
-
#display_name ⇒ String
A user-friendly name.
-
#is_enabled ⇒ BOOLEAN
**[Required]** Whether the autoscale configuration is enabled.
-
#node_type ⇒ String
**[Required]** A node type that is managed by an autoscale configuration.
- #policy ⇒ OCI::Bds::Models::AutoScalePolicy
- #policy_details ⇒ OCI::Bds::Models::AddAutoScalePolicyDetails
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AddAutoScalingConfigurationDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ AddAutoScalingConfigurationDetails
Initializes the object
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/oci/bds/models/add_auto_scaling_configuration_details.rb', line 72 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.node_type = attributes[:'nodeType'] if attributes[:'nodeType'] raise 'You cannot provide both :nodeType and :node_type' if attributes.key?(:'nodeType') && attributes.key?(:'node_type') self.node_type = attributes[:'node_type'] if attributes[:'node_type'] self.is_enabled = attributes[:'isEnabled'] unless attributes[:'isEnabled'].nil? raise 'You cannot provide both :isEnabled and :is_enabled' if attributes.key?(:'isEnabled') && attributes.key?(:'is_enabled') self.is_enabled = attributes[:'is_enabled'] unless attributes[:'is_enabled'].nil? self.cluster_admin_password = attributes[:'clusterAdminPassword'] if attributes[:'clusterAdminPassword'] raise 'You cannot provide both :clusterAdminPassword and :cluster_admin_password' if attributes.key?(:'clusterAdminPassword') && attributes.key?(:'cluster_admin_password') self.cluster_admin_password = attributes[:'cluster_admin_password'] if attributes[:'cluster_admin_password'] self.policy = attributes[:'policy'] if attributes[:'policy'] self.policy_details = attributes[:'policyDetails'] if attributes[:'policyDetails'] raise 'You cannot provide both :policyDetails and :policy_details' if attributes.key?(:'policyDetails') && attributes.key?(:'policy_details') self.policy_details = attributes[:'policy_details'] if attributes[:'policy_details'] end |
Instance Attribute Details
#cluster_admin_password ⇒ String
**[Required]** Base-64 encoded password for the cluster (and Cloudera Manager) admin user.
24 25 26 |
# File 'lib/oci/bds/models/add_auto_scaling_configuration_details.rb', line 24 def cluster_admin_password @cluster_admin_password end |
#display_name ⇒ String
A user-friendly name. The name does not have to be unique, and it may be changed. Avoid entering confidential information.
12 13 14 |
# File 'lib/oci/bds/models/add_auto_scaling_configuration_details.rb', line 12 def display_name @display_name end |
#is_enabled ⇒ BOOLEAN
**[Required]** Whether the autoscale configuration is enabled.
20 21 22 |
# File 'lib/oci/bds/models/add_auto_scaling_configuration_details.rb', line 20 def is_enabled @is_enabled end |
#node_type ⇒ String
**[Required]** A node type that is managed by an autoscale configuration. The only supported types are WORKER and COMPUTE_ONLY_WORKER.
16 17 18 |
# File 'lib/oci/bds/models/add_auto_scaling_configuration_details.rb', line 16 def node_type @node_type end |
#policy ⇒ OCI::Bds::Models::AutoScalePolicy
27 28 29 |
# File 'lib/oci/bds/models/add_auto_scaling_configuration_details.rb', line 27 def policy @policy end |
#policy_details ⇒ OCI::Bds::Models::AddAutoScalePolicyDetails
30 31 32 |
# File 'lib/oci/bds/models/add_auto_scaling_configuration_details.rb', line 30 def policy_details @policy_details end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 41 42 43 44 |
# File 'lib/oci/bds/models/add_auto_scaling_configuration_details.rb', line 33 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'node_type': :'nodeType', 'is_enabled': :'isEnabled', 'cluster_admin_password': :'clusterAdminPassword', 'policy': :'policy', 'policy_details': :'policyDetails' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/oci/bds/models/add_auto_scaling_configuration_details.rb', line 47 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'node_type': :'String', 'is_enabled': :'BOOLEAN', 'cluster_admin_password': :'String', 'policy': :'OCI::Bds::Models::AutoScalePolicy', 'policy_details': :'OCI::Bds::Models::AddAutoScalePolicyDetails' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/oci/bds/models/add_auto_scaling_configuration_details.rb', line 118 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && node_type == other.node_type && is_enabled == other.is_enabled && cluster_admin_password == other.cluster_admin_password && policy == other.policy && policy_details == other.policy_details end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/oci/bds/models/add_auto_scaling_configuration_details.rb', line 153 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
133 134 135 |
# File 'lib/oci/bds/models/add_auto_scaling_configuration_details.rb', line 133 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
142 143 144 |
# File 'lib/oci/bds/models/add_auto_scaling_configuration_details.rb', line 142 def hash [display_name, node_type, is_enabled, cluster_admin_password, policy, policy_details].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
186 187 188 189 190 191 192 193 194 195 |
# File 'lib/oci/bds/models/add_auto_scaling_configuration_details.rb', line 186 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
180 181 182 |
# File 'lib/oci/bds/models/add_auto_scaling_configuration_details.rb', line 180 def to_s to_hash.to_s end |