Class: OCI::Bds::Models::AddBlockStorageDetails
- Inherits:
-
Object
- Object
- OCI::Bds::Models::AddBlockStorageDetails
- Defined in:
- lib/oci/bds/models/add_block_storage_details.rb
Overview
The information about added block volumes.
Constant Summary collapse
- NODE_TYPE_ENUM =
[ NODE_TYPE_WORKER = 'WORKER'.freeze, NODE_TYPE_COMPUTE_ONLY_WORKER = 'COMPUTE_ONLY_WORKER'.freeze ].freeze
Instance Attribute Summary collapse
-
#block_volume_size_in_gbs ⇒ Integer
**[Required]** The size of block volume in GB to be added to each worker node.
-
#cluster_admin_password ⇒ String
**[Required]** Base-64 encoded password for the cluster (and Cloudera Manager) admin user.
-
#node_type ⇒ String
**[Required]** Worker node types, can either be Worker Data node or Compute only worker node.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AddBlockStorageDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ AddBlockStorageDetails
Initializes the object
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/oci/bds/models/add_block_storage_details.rb', line 60 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.cluster_admin_password = attributes[:'clusterAdminPassword'] if attributes[:'clusterAdminPassword'] raise 'You cannot provide both :clusterAdminPassword and :cluster_admin_password' if attributes.key?(:'clusterAdminPassword') && attributes.key?(:'cluster_admin_password') self.cluster_admin_password = attributes[:'cluster_admin_password'] if attributes[:'cluster_admin_password'] self.block_volume_size_in_gbs = attributes[:'blockVolumeSizeInGBs'] if attributes[:'blockVolumeSizeInGBs'] raise 'You cannot provide both :blockVolumeSizeInGBs and :block_volume_size_in_gbs' if attributes.key?(:'blockVolumeSizeInGBs') && attributes.key?(:'block_volume_size_in_gbs') self.block_volume_size_in_gbs = attributes[:'block_volume_size_in_gbs'] if attributes[:'block_volume_size_in_gbs'] self.node_type = attributes[:'nodeType'] if attributes[:'nodeType'] raise 'You cannot provide both :nodeType and :node_type' if attributes.key?(:'nodeType') && attributes.key?(:'node_type') self.node_type = attributes[:'node_type'] if attributes[:'node_type'] end |
Instance Attribute Details
#block_volume_size_in_gbs ⇒ Integer
**[Required]** The size of block volume in GB to be added to each worker node. All the details needed for attaching the block volume are managed by service itself.
23 24 25 |
# File 'lib/oci/bds/models/add_block_storage_details.rb', line 23 def block_volume_size_in_gbs @block_volume_size_in_gbs end |
#cluster_admin_password ⇒ String
**[Required]** Base-64 encoded password for the cluster (and Cloudera Manager) admin user.
17 18 19 |
# File 'lib/oci/bds/models/add_block_storage_details.rb', line 17 def cluster_admin_password @cluster_admin_password end |
#node_type ⇒ String
**[Required]** Worker node types, can either be Worker Data node or Compute only worker node.
27 28 29 |
# File 'lib/oci/bds/models/add_block_storage_details.rb', line 27 def node_type @node_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
30 31 32 33 34 35 36 37 38 |
# File 'lib/oci/bds/models/add_block_storage_details.rb', line 30 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'cluster_admin_password': :'clusterAdminPassword', 'block_volume_size_in_gbs': :'blockVolumeSizeInGBs', 'node_type': :'nodeType' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
41 42 43 44 45 46 47 48 49 |
# File 'lib/oci/bds/models/add_block_storage_details.rb', line 41 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'cluster_admin_password': :'String', 'block_volume_size_in_gbs': :'Integer', 'node_type': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
100 101 102 103 104 105 106 107 |
# File 'lib/oci/bds/models/add_block_storage_details.rb', line 100 def ==(other) return true if equal?(other) self.class == other.class && cluster_admin_password == other.cluster_admin_password && block_volume_size_in_gbs == other.block_volume_size_in_gbs && node_type == other.node_type end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/oci/bds/models/add_block_storage_details.rb', line 132 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
112 113 114 |
# File 'lib/oci/bds/models/add_block_storage_details.rb', line 112 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
121 122 123 |
# File 'lib/oci/bds/models/add_block_storage_details.rb', line 121 def hash [cluster_admin_password, block_volume_size_in_gbs, node_type].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
165 166 167 168 169 170 171 172 173 174 |
# File 'lib/oci/bds/models/add_block_storage_details.rb', line 165 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
159 160 161 |
# File 'lib/oci/bds/models/add_block_storage_details.rb', line 159 def to_s to_hash.to_s end |