Class: OCI::Bds::Models::AutoScalePolicy
- Inherits:
-
Object
- Object
- OCI::Bds::Models::AutoScalePolicy
- Defined in:
- lib/oci/bds/models/auto_scale_policy.rb
Overview
Policy definitions for the autoscale configuration.
Constant Summary collapse
- POLICY_TYPE_ENUM =
[ POLICY_TYPE_THRESHOLD_BASED = 'THRESHOLD_BASED'.freeze, POLICY_TYPE_SCHEDULE_BASED = 'SCHEDULE_BASED'.freeze, POLICY_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#policy_type ⇒ String
[Required] Types of autoscale policies.
-
#rules ⇒ Array<OCI::Bds::Models::AutoScalePolicyRule>
[Required] The list of rules for autoscaling.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AutoScalePolicy
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ AutoScalePolicy
Initializes the object
53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/oci/bds/models/auto_scale_policy.rb', line 53 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.policy_type = attributes[:'policyType'] if attributes[:'policyType'] raise 'You cannot provide both :policyType and :policy_type' if attributes.key?(:'policyType') && attributes.key?(:'policy_type') self.policy_type = attributes[:'policy_type'] if attributes[:'policy_type'] self.rules = attributes[:'rules'] if attributes[:'rules'] end |
Instance Attribute Details
#policy_type ⇒ String
[Required] Types of autoscale policies. Options are SCHEDULE-BASED or THRESHOLD-BASED. (Only THRESHOLD-BASED is supported in this release.)
19 20 21 |
# File 'lib/oci/bds/models/auto_scale_policy.rb', line 19 def policy_type @policy_type end |
#rules ⇒ Array<OCI::Bds::Models::AutoScalePolicyRule>
[Required] The list of rules for autoscaling. If an action has multiple rules, the last rule in the array will be applied.
23 24 25 |
# File 'lib/oci/bds/models/auto_scale_policy.rb', line 23 def rules @rules end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
26 27 28 29 30 31 32 33 |
# File 'lib/oci/bds/models/auto_scale_policy.rb', line 26 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'policy_type': :'policyType', 'rules': :'rules' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
36 37 38 39 40 41 42 43 |
# File 'lib/oci/bds/models/auto_scale_policy.rb', line 36 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'policy_type': :'String', 'rules': :'Array<OCI::Bds::Models::AutoScalePolicyRule>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
88 89 90 91 92 93 94 |
# File 'lib/oci/bds/models/auto_scale_policy.rb', line 88 def ==(other) return true if equal?(other) self.class == other.class && policy_type == other.policy_type && rules == other.rules end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/oci/bds/models/auto_scale_policy.rb', line 119 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
99 100 101 |
# File 'lib/oci/bds/models/auto_scale_policy.rb', line 99 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
108 109 110 |
# File 'lib/oci/bds/models/auto_scale_policy.rb', line 108 def hash [policy_type, rules].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
152 153 154 155 156 157 158 159 160 161 |
# File 'lib/oci/bds/models/auto_scale_policy.rb', line 152 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
146 147 148 |
# File 'lib/oci/bds/models/auto_scale_policy.rb', line 146 def to_s to_hash.to_s end |