Class: OCI::Bds::Models::BdsApiKeySummary
- Inherits:
-
Object
- Object
- OCI::Bds::Models::BdsApiKeySummary
- Defined in:
- lib/oci/bds/models/bds_api_key_summary.rb
Overview
The API key summary.
Instance Attribute Summary collapse
-
#default_region ⇒ String
**[Required]** The name of the region to establish the Object Storage endpoint which was set as part of key creation operation.
-
#id ⇒ String
**[Required]** Identifier of the user's API key.
-
#key_alias ⇒ String
**[Required]** User friendly identifier used to uniquely differentiate between different API keys.
-
#lifecycle_state ⇒ String
**[Required]** The current status of the API key.
-
#time_created ⇒ DateTime
**[Required]** The time the API key was created, shown as an RFC 3339 formatted datetime string.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BdsApiKeySummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ BdsApiKeySummary
Initializes the object
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/oci/bds/models/bds_api_key_summary.rb', line 71 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.key_alias = attributes[:'keyAlias'] if attributes[:'keyAlias'] raise 'You cannot provide both :keyAlias and :key_alias' if attributes.key?(:'keyAlias') && attributes.key?(:'key_alias') self.key_alias = attributes[:'key_alias'] if attributes[:'key_alias'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.default_region = attributes[:'defaultRegion'] if attributes[:'defaultRegion'] raise 'You cannot provide both :defaultRegion and :default_region' if attributes.key?(:'defaultRegion') && attributes.key?(:'default_region') self.default_region = attributes[:'default_region'] if attributes[:'default_region'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] end |
Instance Attribute Details
#default_region ⇒ String
**[Required]** The name of the region to establish the Object Storage endpoint which was set as part of key creation operation. If no region was provided this will be set to be the same region where the cluster lives. Example us-phoenix-1 .
28 29 30 |
# File 'lib/oci/bds/models/bds_api_key_summary.rb', line 28 def default_region @default_region end |
#id ⇒ String
**[Required]** Identifier of the user's API key.
12 13 14 |
# File 'lib/oci/bds/models/bds_api_key_summary.rb', line 12 def id @id end |
#key_alias ⇒ String
**[Required]** User friendly identifier used to uniquely differentiate between different API keys. Only ASCII alphanumeric characters with no spaces allowed.
18 19 20 |
# File 'lib/oci/bds/models/bds_api_key_summary.rb', line 18 def key_alias @key_alias end |
#lifecycle_state ⇒ String
**[Required]** The current status of the API key.
22 23 24 |
# File 'lib/oci/bds/models/bds_api_key_summary.rb', line 22 def lifecycle_state @lifecycle_state end |
#time_created ⇒ DateTime
**[Required]** The time the API key was created, shown as an RFC 3339 formatted datetime string.
32 33 34 |
# File 'lib/oci/bds/models/bds_api_key_summary.rb', line 32 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 45 |
# File 'lib/oci/bds/models/bds_api_key_summary.rb', line 35 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'key_alias': :'keyAlias', 'lifecycle_state': :'lifecycleState', 'default_region': :'defaultRegion', 'time_created': :'timeCreated' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/oci/bds/models/bds_api_key_summary.rb', line 48 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'key_alias': :'String', 'lifecycle_state': :'String', 'default_region': :'String', 'time_created': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
111 112 113 114 115 116 117 118 119 120 |
# File 'lib/oci/bds/models/bds_api_key_summary.rb', line 111 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && key_alias == other.key_alias && lifecycle_state == other.lifecycle_state && default_region == other.default_region && time_created == other.time_created end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/oci/bds/models/bds_api_key_summary.rb', line 145 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
125 126 127 |
# File 'lib/oci/bds/models/bds_api_key_summary.rb', line 125 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
134 135 136 |
# File 'lib/oci/bds/models/bds_api_key_summary.rb', line 134 def hash [id, key_alias, lifecycle_state, default_region, time_created].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
178 179 180 181 182 183 184 185 186 187 |
# File 'lib/oci/bds/models/bds_api_key_summary.rb', line 178 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
172 173 174 |
# File 'lib/oci/bds/models/bds_api_key_summary.rb', line 172 def to_s to_hash.to_s end |