Class: OCI::Bds::Models::BdsMetastoreConfiguration
- Inherits:
-
Object
- Object
- OCI::Bds::Models::BdsMetastoreConfiguration
- Defined in:
- lib/oci/bds/models/bds_metastore_configuration.rb
Overview
The metastore configuration information.
Constant Summary collapse
- METASTORE_TYPE_ENUM =
[ METASTORE_TYPE_LOCAL = 'LOCAL'.freeze, METASTORE_TYPE_EXTERNAL = 'EXTERNAL'.freeze, METASTORE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVATING = 'ACTIVATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#bds_api_key_id ⇒ String
The ID of BDS API Key used for metastore configuration.
-
#display_name ⇒ String
**[Required]** The display name of metastore configuration.
-
#id ⇒ String
**[Required]** The ID of the metastore configuration.
-
#lifecycle_state ⇒ String
**[Required]** the lifecycle state of the metastore configuration.
-
#metastore_id ⇒ String
The OCID of the Data Catalog metastore.
-
#metastore_type ⇒ String
**[Required]** The type of the metastore in the metastore configuration.
-
#time_created ⇒ DateTime
**[Required]** The time when the configuration was created, shown as an RFC 3339 formatted datetime string.
-
#time_updated ⇒ DateTime
The time when the configuration was updated, shown as an RFC 3339 formatted datetime string.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BdsMetastoreConfiguration
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ BdsMetastoreConfiguration
Initializes the object
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/oci/bds/models/bds_metastore_configuration.rb', line 107 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self. = attributes[:'metastoreType'] if attributes[:'metastoreType'] raise 'You cannot provide both :metastoreType and :metastore_type' if attributes.key?(:'metastoreType') && attributes.key?(:'metastore_type') self. = attributes[:'metastore_type'] if attributes[:'metastore_type'] self. = attributes[:'metastoreId'] if attributes[:'metastoreId'] raise 'You cannot provide both :metastoreId and :metastore_id' if attributes.key?(:'metastoreId') && attributes.key?(:'metastore_id') self. = attributes[:'metastore_id'] if attributes[:'metastore_id'] self.bds_api_key_id = attributes[:'bdsApiKeyId'] if attributes[:'bdsApiKeyId'] raise 'You cannot provide both :bdsApiKeyId and :bds_api_key_id' if attributes.key?(:'bdsApiKeyId') && attributes.key?(:'bds_api_key_id') self.bds_api_key_id = attributes[:'bds_api_key_id'] if attributes[:'bds_api_key_id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] end |
Instance Attribute Details
#bds_api_key_id ⇒ String
The ID of BDS API Key used for metastore configuration. Set only if metastore's type is EXTERNAL.
47 48 49 |
# File 'lib/oci/bds/models/bds_metastore_configuration.rb', line 47 def bds_api_key_id @bds_api_key_id end |
#display_name ⇒ String
**[Required]** The display name of metastore configuration
35 36 37 |
# File 'lib/oci/bds/models/bds_metastore_configuration.rb', line 35 def display_name @display_name end |
#id ⇒ String
**[Required]** The ID of the metastore configuration
31 32 33 |
# File 'lib/oci/bds/models/bds_metastore_configuration.rb', line 31 def id @id end |
#lifecycle_state ⇒ String
**[Required]** the lifecycle state of the metastore configuration.
51 52 53 |
# File 'lib/oci/bds/models/bds_metastore_configuration.rb', line 51 def lifecycle_state @lifecycle_state end |
#metastore_id ⇒ String
The OCID of the Data Catalog metastore. Set only if metastore's type is EXTERNAL.
43 44 45 |
# File 'lib/oci/bds/models/bds_metastore_configuration.rb', line 43 def @metastore_id end |
#metastore_type ⇒ String
**[Required]** The type of the metastore in the metastore configuration.
39 40 41 |
# File 'lib/oci/bds/models/bds_metastore_configuration.rb', line 39 def @metastore_type end |
#time_created ⇒ DateTime
**[Required]** The time when the configuration was created, shown as an RFC 3339 formatted datetime string.
55 56 57 |
# File 'lib/oci/bds/models/bds_metastore_configuration.rb', line 55 def time_created @time_created end |
#time_updated ⇒ DateTime
The time when the configuration was updated, shown as an RFC 3339 formatted datetime string.
59 60 61 |
# File 'lib/oci/bds/models/bds_metastore_configuration.rb', line 59 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/oci/bds/models/bds_metastore_configuration.rb', line 62 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'metastore_type': :'metastoreType', 'metastore_id': :'metastoreId', 'bds_api_key_id': :'bdsApiKeyId', 'lifecycle_state': :'lifecycleState', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/oci/bds/models/bds_metastore_configuration.rb', line 78 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'metastore_type': :'String', 'metastore_id': :'String', 'bds_api_key_id': :'String', 'lifecycle_state': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/oci/bds/models/bds_metastore_configuration.rb', line 191 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && == other. && == other. && bds_api_key_id == other.bds_api_key_id && lifecycle_state == other.lifecycle_state && time_created == other.time_created && time_updated == other.time_updated end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/oci/bds/models/bds_metastore_configuration.rb', line 228 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
208 209 210 |
# File 'lib/oci/bds/models/bds_metastore_configuration.rb', line 208 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
217 218 219 |
# File 'lib/oci/bds/models/bds_metastore_configuration.rb', line 217 def hash [id, display_name, , , bds_api_key_id, lifecycle_state, time_created, time_updated].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
261 262 263 264 265 266 267 268 269 270 |
# File 'lib/oci/bds/models/bds_metastore_configuration.rb', line 261 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
255 256 257 |
# File 'lib/oci/bds/models/bds_metastore_configuration.rb', line 255 def to_s to_hash.to_s end |