Class: OCI::Bds::Models::BdsMetastoreConfigurationSummary
- Inherits:
-
Object
- Object
- OCI::Bds::Models::BdsMetastoreConfigurationSummary
- Defined in:
- lib/oci/bds/models/bds_metastore_configuration_summary.rb
Overview
The summary of metastore configuration information.
Instance Attribute Summary collapse
-
#bds_api_key_id ⇒ String
The ID of BDS API Key used for metastore configuration.
-
#display_name ⇒ String
**[Required]** The display name of metastore configuration.
-
#id ⇒ String
**[Required]** The ID of the metastore configuration.
-
#lifecycle_state ⇒ String
**[Required]** the lifecycle state of the metastore configuration.
-
#metastore_id ⇒ String
The OCID of the Data Catalog metastore.
-
#metastore_type ⇒ String
**[Required]** The type of the metastore in the metastore configuration.
-
#time_created ⇒ DateTime
**[Required]** The time when the configuration was created, shown as an RFC 3339 formatted datetime string.
-
#time_updated ⇒ DateTime
The time when the configuration was updated, shown as an RFC 3339 formatted datetime string.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BdsMetastoreConfigurationSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ BdsMetastoreConfigurationSummary
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/oci/bds/models/bds_metastore_configuration_summary.rb', line 88 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self. = attributes[:'metastoreType'] if attributes[:'metastoreType'] raise 'You cannot provide both :metastoreType and :metastore_type' if attributes.key?(:'metastoreType') && attributes.key?(:'metastore_type') self. = attributes[:'metastore_type'] if attributes[:'metastore_type'] self. = attributes[:'metastoreId'] if attributes[:'metastoreId'] raise 'You cannot provide both :metastoreId and :metastore_id' if attributes.key?(:'metastoreId') && attributes.key?(:'metastore_id') self. = attributes[:'metastore_id'] if attributes[:'metastore_id'] self.bds_api_key_id = attributes[:'bdsApiKeyId'] if attributes[:'bdsApiKeyId'] raise 'You cannot provide both :bdsApiKeyId and :bds_api_key_id' if attributes.key?(:'bdsApiKeyId') && attributes.key?(:'bds_api_key_id') self.bds_api_key_id = attributes[:'bds_api_key_id'] if attributes[:'bds_api_key_id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] end |
Instance Attribute Details
#bds_api_key_id ⇒ String
The ID of BDS API Key used for metastore configuration. Set only if metastore's type is EXTERNAL.
28 29 30 |
# File 'lib/oci/bds/models/bds_metastore_configuration_summary.rb', line 28 def bds_api_key_id @bds_api_key_id end |
#display_name ⇒ String
**[Required]** The display name of metastore configuration
16 17 18 |
# File 'lib/oci/bds/models/bds_metastore_configuration_summary.rb', line 16 def display_name @display_name end |
#id ⇒ String
**[Required]** The ID of the metastore configuration
12 13 14 |
# File 'lib/oci/bds/models/bds_metastore_configuration_summary.rb', line 12 def id @id end |
#lifecycle_state ⇒ String
**[Required]** the lifecycle state of the metastore configuration.
32 33 34 |
# File 'lib/oci/bds/models/bds_metastore_configuration_summary.rb', line 32 def lifecycle_state @lifecycle_state end |
#metastore_id ⇒ String
The OCID of the Data Catalog metastore. Set only if metastore's type is EXTERNAL.
24 25 26 |
# File 'lib/oci/bds/models/bds_metastore_configuration_summary.rb', line 24 def @metastore_id end |
#metastore_type ⇒ String
**[Required]** The type of the metastore in the metastore configuration.
20 21 22 |
# File 'lib/oci/bds/models/bds_metastore_configuration_summary.rb', line 20 def @metastore_type end |
#time_created ⇒ DateTime
**[Required]** The time when the configuration was created, shown as an RFC 3339 formatted datetime string.
36 37 38 |
# File 'lib/oci/bds/models/bds_metastore_configuration_summary.rb', line 36 def time_created @time_created end |
#time_updated ⇒ DateTime
The time when the configuration was updated, shown as an RFC 3339 formatted datetime string.
40 41 42 |
# File 'lib/oci/bds/models/bds_metastore_configuration_summary.rb', line 40 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/oci/bds/models/bds_metastore_configuration_summary.rb', line 43 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'metastore_type': :'metastoreType', 'metastore_id': :'metastoreId', 'bds_api_key_id': :'bdsApiKeyId', 'lifecycle_state': :'lifecycleState', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/oci/bds/models/bds_metastore_configuration_summary.rb', line 59 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'metastore_type': :'String', 'metastore_id': :'String', 'bds_api_key_id': :'String', 'lifecycle_state': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/oci/bds/models/bds_metastore_configuration_summary.rb', line 146 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && == other. && == other. && bds_api_key_id == other.bds_api_key_id && lifecycle_state == other.lifecycle_state && time_created == other.time_created && time_updated == other.time_updated end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/oci/bds/models/bds_metastore_configuration_summary.rb', line 183 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
163 164 165 |
# File 'lib/oci/bds/models/bds_metastore_configuration_summary.rb', line 163 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
172 173 174 |
# File 'lib/oci/bds/models/bds_metastore_configuration_summary.rb', line 172 def hash [id, display_name, , , bds_api_key_id, lifecycle_state, time_created, time_updated].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
216 217 218 219 220 221 222 223 224 225 |
# File 'lib/oci/bds/models/bds_metastore_configuration_summary.rb', line 216 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
210 211 212 |
# File 'lib/oci/bds/models/bds_metastore_configuration_summary.rb', line 210 def to_s to_hash.to_s end |