Class: OCI::Bds::Models::ClusterDetails
- Inherits:
-
Object
- Object
- OCI::Bds::Models::ClusterDetails
- Defined in:
- lib/oci/bds/models/cluster_details.rb
Overview
Specific info about a Hadoop cluster
Instance Attribute Summary collapse
-
#ambari_url ⇒ String
The URL of Ambari.
-
#bd_cell_version ⇒ String
Cloud SQL cell version.
-
#bda_version ⇒ String
BDA version installed in the cluster.
-
#bdm_version ⇒ String
Big Data Manager version installed in the cluster.
-
#bds_version ⇒ String
Big Data Service version installed in the cluster.
-
#big_data_manager_url ⇒ String
The URL of Big Data Manager.
-
#cloudera_manager_url ⇒ String
The URL of Cloudera Manager.
-
#csql_cell_version ⇒ String
Big Data SQL version.
-
#db_version ⇒ String
Cloud SQL query server database version.
-
#hue_server_url ⇒ String
The URL of the Hue server.
-
#jupyter_hub_url ⇒ String
The URL of the Jupyterhub.
-
#odh_version ⇒ String
Version of the ODH (Oracle Distribution including Apache Hadoop) installed on the cluster.
-
#os_version ⇒ String
Oracle Linux version installed in the cluster.
-
#time_created ⇒ DateTime
**[Required]** The time the cluster was created, shown as an RFC 3339 formatted datetime string.
-
#time_refreshed ⇒ DateTime
The time the cluster was automatically or manually refreshed, shown as an RFC 3339 formatted datetime string.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ClusterDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ClusterDetails
Initializes the object
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/oci/bds/models/cluster_details.rb', line 138 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.bda_version = attributes[:'bdaVersion'] if attributes[:'bdaVersion'] raise 'You cannot provide both :bdaVersion and :bda_version' if attributes.key?(:'bdaVersion') && attributes.key?(:'bda_version') self.bda_version = attributes[:'bda_version'] if attributes[:'bda_version'] self.bdm_version = attributes[:'bdmVersion'] if attributes[:'bdmVersion'] raise 'You cannot provide both :bdmVersion and :bdm_version' if attributes.key?(:'bdmVersion') && attributes.key?(:'bdm_version') self.bdm_version = attributes[:'bdm_version'] if attributes[:'bdm_version'] self.bds_version = attributes[:'bdsVersion'] if attributes[:'bdsVersion'] raise 'You cannot provide both :bdsVersion and :bds_version' if attributes.key?(:'bdsVersion') && attributes.key?(:'bds_version') self.bds_version = attributes[:'bds_version'] if attributes[:'bds_version'] self.os_version = attributes[:'osVersion'] if attributes[:'osVersion'] raise 'You cannot provide both :osVersion and :os_version' if attributes.key?(:'osVersion') && attributes.key?(:'os_version') self.os_version = attributes[:'os_version'] if attributes[:'os_version'] self.db_version = attributes[:'dbVersion'] if attributes[:'dbVersion'] raise 'You cannot provide both :dbVersion and :db_version' if attributes.key?(:'dbVersion') && attributes.key?(:'db_version') self.db_version = attributes[:'db_version'] if attributes[:'db_version'] self.bd_cell_version = attributes[:'bdCellVersion'] if attributes[:'bdCellVersion'] raise 'You cannot provide both :bdCellVersion and :bd_cell_version' if attributes.key?(:'bdCellVersion') && attributes.key?(:'bd_cell_version') self.bd_cell_version = attributes[:'bd_cell_version'] if attributes[:'bd_cell_version'] self.csql_cell_version = attributes[:'csqlCellVersion'] if attributes[:'csqlCellVersion'] raise 'You cannot provide both :csqlCellVersion and :csql_cell_version' if attributes.key?(:'csqlCellVersion') && attributes.key?(:'csql_cell_version') self.csql_cell_version = attributes[:'csql_cell_version'] if attributes[:'csql_cell_version'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_refreshed = attributes[:'timeRefreshed'] if attributes[:'timeRefreshed'] raise 'You cannot provide both :timeRefreshed and :time_refreshed' if attributes.key?(:'timeRefreshed') && attributes.key?(:'time_refreshed') self.time_refreshed = attributes[:'time_refreshed'] if attributes[:'time_refreshed'] self.cloudera_manager_url = attributes[:'clouderaManagerUrl'] if attributes[:'clouderaManagerUrl'] raise 'You cannot provide both :clouderaManagerUrl and :cloudera_manager_url' if attributes.key?(:'clouderaManagerUrl') && attributes.key?(:'cloudera_manager_url') self.cloudera_manager_url = attributes[:'cloudera_manager_url'] if attributes[:'cloudera_manager_url'] self. = attributes[:'ambariUrl'] if attributes[:'ambariUrl'] raise 'You cannot provide both :ambariUrl and :ambari_url' if attributes.key?(:'ambariUrl') && attributes.key?(:'ambari_url') self. = attributes[:'ambari_url'] if attributes[:'ambari_url'] self.big_data_manager_url = attributes[:'bigDataManagerUrl'] if attributes[:'bigDataManagerUrl'] raise 'You cannot provide both :bigDataManagerUrl and :big_data_manager_url' if attributes.key?(:'bigDataManagerUrl') && attributes.key?(:'big_data_manager_url') self.big_data_manager_url = attributes[:'big_data_manager_url'] if attributes[:'big_data_manager_url'] self.hue_server_url = attributes[:'hueServerUrl'] if attributes[:'hueServerUrl'] raise 'You cannot provide both :hueServerUrl and :hue_server_url' if attributes.key?(:'hueServerUrl') && attributes.key?(:'hue_server_url') self.hue_server_url = attributes[:'hue_server_url'] if attributes[:'hue_server_url'] self.odh_version = attributes[:'odhVersion'] if attributes[:'odhVersion'] raise 'You cannot provide both :odhVersion and :odh_version' if attributes.key?(:'odhVersion') && attributes.key?(:'odh_version') self.odh_version = attributes[:'odh_version'] if attributes[:'odh_version'] self.jupyter_hub_url = attributes[:'jupyterHubUrl'] if attributes[:'jupyterHubUrl'] raise 'You cannot provide both :jupyterHubUrl and :jupyter_hub_url' if attributes.key?(:'jupyterHubUrl') && attributes.key?(:'jupyter_hub_url') self.jupyter_hub_url = attributes[:'jupyter_hub_url'] if attributes[:'jupyter_hub_url'] end |
Instance Attribute Details
#ambari_url ⇒ String
The URL of Ambari
53 54 55 |
# File 'lib/oci/bds/models/cluster_details.rb', line 53 def @ambari_url end |
#bd_cell_version ⇒ String
Cloud SQL cell version.
32 33 34 |
# File 'lib/oci/bds/models/cluster_details.rb', line 32 def bd_cell_version @bd_cell_version end |
#bda_version ⇒ String
BDA version installed in the cluster
12 13 14 |
# File 'lib/oci/bds/models/cluster_details.rb', line 12 def bda_version @bda_version end |
#bdm_version ⇒ String
Big Data Manager version installed in the cluster.
16 17 18 |
# File 'lib/oci/bds/models/cluster_details.rb', line 16 def bdm_version @bdm_version end |
#bds_version ⇒ String
Big Data Service version installed in the cluster.
20 21 22 |
# File 'lib/oci/bds/models/cluster_details.rb', line 20 def bds_version @bds_version end |
#big_data_manager_url ⇒ String
The URL of Big Data Manager.
57 58 59 |
# File 'lib/oci/bds/models/cluster_details.rb', line 57 def big_data_manager_url @big_data_manager_url end |
#cloudera_manager_url ⇒ String
The URL of Cloudera Manager
49 50 51 |
# File 'lib/oci/bds/models/cluster_details.rb', line 49 def cloudera_manager_url @cloudera_manager_url end |
#csql_cell_version ⇒ String
Big Data SQL version.
36 37 38 |
# File 'lib/oci/bds/models/cluster_details.rb', line 36 def csql_cell_version @csql_cell_version end |
#db_version ⇒ String
Cloud SQL query server database version.
28 29 30 |
# File 'lib/oci/bds/models/cluster_details.rb', line 28 def db_version @db_version end |
#hue_server_url ⇒ String
The URL of the Hue server.
61 62 63 |
# File 'lib/oci/bds/models/cluster_details.rb', line 61 def hue_server_url @hue_server_url end |
#jupyter_hub_url ⇒ String
The URL of the Jupyterhub.
69 70 71 |
# File 'lib/oci/bds/models/cluster_details.rb', line 69 def jupyter_hub_url @jupyter_hub_url end |
#odh_version ⇒ String
Version of the ODH (Oracle Distribution including Apache Hadoop) installed on the cluster.
65 66 67 |
# File 'lib/oci/bds/models/cluster_details.rb', line 65 def odh_version @odh_version end |
#os_version ⇒ String
Oracle Linux version installed in the cluster.
24 25 26 |
# File 'lib/oci/bds/models/cluster_details.rb', line 24 def os_version @os_version end |
#time_created ⇒ DateTime
**[Required]** The time the cluster was created, shown as an RFC 3339 formatted datetime string.
40 41 42 |
# File 'lib/oci/bds/models/cluster_details.rb', line 40 def time_created @time_created end |
#time_refreshed ⇒ DateTime
The time the cluster was automatically or manually refreshed, shown as an RFC 3339 formatted datetime string.
45 46 47 |
# File 'lib/oci/bds/models/cluster_details.rb', line 45 def time_refreshed @time_refreshed end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/oci/bds/models/cluster_details.rb', line 72 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'bda_version': :'bdaVersion', 'bdm_version': :'bdmVersion', 'bds_version': :'bdsVersion', 'os_version': :'osVersion', 'db_version': :'dbVersion', 'bd_cell_version': :'bdCellVersion', 'csql_cell_version': :'csqlCellVersion', 'time_created': :'timeCreated', 'time_refreshed': :'timeRefreshed', 'cloudera_manager_url': :'clouderaManagerUrl', 'ambari_url': :'ambariUrl', 'big_data_manager_url': :'bigDataManagerUrl', 'hue_server_url': :'hueServerUrl', 'odh_version': :'odhVersion', 'jupyter_hub_url': :'jupyterHubUrl' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/oci/bds/models/cluster_details.rb', line 95 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'bda_version': :'String', 'bdm_version': :'String', 'bds_version': :'String', 'os_version': :'String', 'db_version': :'String', 'bd_cell_version': :'String', 'csql_cell_version': :'String', 'time_created': :'DateTime', 'time_refreshed': :'DateTime', 'cloudera_manager_url': :'String', 'ambari_url': :'String', 'big_data_manager_url': :'String', 'hue_server_url': :'String', 'odh_version': :'String', 'jupyter_hub_url': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/oci/bds/models/cluster_details.rb', line 242 def ==(other) return true if equal?(other) self.class == other.class && bda_version == other.bda_version && bdm_version == other.bdm_version && bds_version == other.bds_version && os_version == other.os_version && db_version == other.db_version && bd_cell_version == other.bd_cell_version && csql_cell_version == other.csql_cell_version && time_created == other.time_created && time_refreshed == other.time_refreshed && cloudera_manager_url == other.cloudera_manager_url && == other. && big_data_manager_url == other.big_data_manager_url && hue_server_url == other.hue_server_url && odh_version == other.odh_version && jupyter_hub_url == other.jupyter_hub_url end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 |
# File 'lib/oci/bds/models/cluster_details.rb', line 286 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
266 267 268 |
# File 'lib/oci/bds/models/cluster_details.rb', line 266 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
275 276 277 |
# File 'lib/oci/bds/models/cluster_details.rb', line 275 def hash [bda_version, bdm_version, bds_version, os_version, db_version, bd_cell_version, csql_cell_version, time_created, time_refreshed, cloudera_manager_url, , big_data_manager_url, hue_server_url, odh_version, jupyter_hub_url].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
319 320 321 322 323 324 325 326 327 328 |
# File 'lib/oci/bds/models/cluster_details.rb', line 319 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
313 314 315 |
# File 'lib/oci/bds/models/cluster_details.rb', line 313 def to_s to_hash.to_s end |