Class: OCI::Bds::Models::CreateBdsInstanceDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/bds/models/create_bds_instance_details.rb

Overview

The information about the new cluster.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateBdsInstanceDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/oci/bds/models/create_bds_instance_details.rb', line 126

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.cluster_version = attributes[:'clusterVersion'] if attributes[:'clusterVersion']

  raise 'You cannot provide both :clusterVersion and :cluster_version' if attributes.key?(:'clusterVersion') && attributes.key?(:'cluster_version')

  self.cluster_version = attributes[:'cluster_version'] if attributes[:'cluster_version']

  self.cluster_public_key = attributes[:'clusterPublicKey'] if attributes[:'clusterPublicKey']

  raise 'You cannot provide both :clusterPublicKey and :cluster_public_key' if attributes.key?(:'clusterPublicKey') && attributes.key?(:'cluster_public_key')

  self.cluster_public_key = attributes[:'cluster_public_key'] if attributes[:'cluster_public_key']

  self.cluster_admin_password = attributes[:'clusterAdminPassword'] if attributes[:'clusterAdminPassword']

  raise 'You cannot provide both :clusterAdminPassword and :cluster_admin_password' if attributes.key?(:'clusterAdminPassword') && attributes.key?(:'cluster_admin_password')

  self.cluster_admin_password = attributes[:'cluster_admin_password'] if attributes[:'cluster_admin_password']

  self.is_high_availability = attributes[:'isHighAvailability'] unless attributes[:'isHighAvailability'].nil?
  self.is_high_availability = false if is_high_availability.nil? && !attributes.key?(:'isHighAvailability') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isHighAvailability and :is_high_availability' if attributes.key?(:'isHighAvailability') && attributes.key?(:'is_high_availability')

  self.is_high_availability = attributes[:'is_high_availability'] unless attributes[:'is_high_availability'].nil?
  self.is_high_availability = false if is_high_availability.nil? && !attributes.key?(:'isHighAvailability') && !attributes.key?(:'is_high_availability') # rubocop:disable Style/StringLiterals

  self.is_secure = attributes[:'isSecure'] unless attributes[:'isSecure'].nil?
  self.is_secure = true if is_secure.nil? && !attributes.key?(:'isSecure') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isSecure and :is_secure' if attributes.key?(:'isSecure') && attributes.key?(:'is_secure')

  self.is_secure = attributes[:'is_secure'] unless attributes[:'is_secure'].nil?
  self.is_secure = true if is_secure.nil? && !attributes.key?(:'isSecure') && !attributes.key?(:'is_secure') # rubocop:disable Style/StringLiterals

  self.network_config = attributes[:'networkConfig'] if attributes[:'networkConfig']

  raise 'You cannot provide both :networkConfig and :network_config' if attributes.key?(:'networkConfig') && attributes.key?(:'network_config')

  self.network_config = attributes[:'network_config'] if attributes[:'network_config']

  self.bootstrap_script_url = attributes[:'bootstrapScriptUrl'] if attributes[:'bootstrapScriptUrl']

  raise 'You cannot provide both :bootstrapScriptUrl and :bootstrap_script_url' if attributes.key?(:'bootstrapScriptUrl') && attributes.key?(:'bootstrap_script_url')

  self.bootstrap_script_url = attributes[:'bootstrap_script_url'] if attributes[:'bootstrap_script_url']

  self.nodes = attributes[:'nodes'] if attributes[:'nodes']

  self.kerberos_realm_name = attributes[:'kerberosRealmName'] if attributes[:'kerberosRealmName']

  raise 'You cannot provide both :kerberosRealmName and :kerberos_realm_name' if attributes.key?(:'kerberosRealmName') && attributes.key?(:'kerberos_realm_name')

  self.kerberos_realm_name = attributes[:'kerberos_realm_name'] if attributes[:'kerberos_realm_name']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#bootstrap_script_urlString

Pre-authenticated URL of the script in Object Store that is downloaded and executed.

Returns:

  • (String)


43
44
45
# File 'lib/oci/bds/models/create_bds_instance_details.rb', line 43

def bootstrap_script_url
  @bootstrap_script_url
end

#cluster_admin_passwordString

**[Required]** Base-64 encoded password for the cluster (and Cloudera Manager) admin user.

Returns:

  • (String)


28
29
30
# File 'lib/oci/bds/models/create_bds_instance_details.rb', line 28

def cluster_admin_password
  @cluster_admin_password
end

#cluster_public_keyString

**[Required]** The SSH public key used to authenticate the cluster connection.

Returns:

  • (String)


24
25
26
# File 'lib/oci/bds/models/create_bds_instance_details.rb', line 24

def cluster_public_key
  @cluster_public_key
end

#cluster_versionString

**[Required]** Version of the Hadoop distribution.

Returns:

  • (String)


20
21
22
# File 'lib/oci/bds/models/create_bds_instance_details.rb', line 20

def cluster_version
  @cluster_version
end

#compartment_idString

**[Required]** The OCID of the compartment.

Returns:

  • (String)


12
13
14
# File 'lib/oci/bds/models/create_bds_instance_details.rb', line 12

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For example, `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


63
64
65
# File 'lib/oci/bds/models/create_bds_instance_details.rb', line 63

def defined_tags
  @defined_tags
end

#display_nameString

**[Required]** Name of the Big Data Service cluster.

Returns:

  • (String)


16
17
18
# File 'lib/oci/bds/models/create_bds_instance_details.rb', line 16

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type, or scope. Exists for cross-compatibility only. For example, `"value"`

Returns:

  • (Hash<String, String>)


57
58
59
# File 'lib/oci/bds/models/create_bds_instance_details.rb', line 57

def freeform_tags
  @freeform_tags
end

#is_high_availabilityBOOLEAN

**[Required]** Boolean flag specifying whether or not the cluster is highly available (HA).

Returns:

  • (BOOLEAN)


32
33
34
# File 'lib/oci/bds/models/create_bds_instance_details.rb', line 32

def is_high_availability
  @is_high_availability
end

#is_secureBOOLEAN

**[Required]** Boolean flag specifying whether or not the cluster should be set up as secure.

Returns:

  • (BOOLEAN)


36
37
38
# File 'lib/oci/bds/models/create_bds_instance_details.rb', line 36

def is_secure
  @is_secure
end

#kerberos_realm_nameString

The user-defined kerberos realm name.

Returns:

  • (String)


51
52
53
# File 'lib/oci/bds/models/create_bds_instance_details.rb', line 51

def kerberos_realm_name
  @kerberos_realm_name
end

#network_configOCI::Bds::Models::NetworkConfig



39
40
41
# File 'lib/oci/bds/models/create_bds_instance_details.rb', line 39

def network_config
  @network_config
end

#nodesArray<OCI::Bds::Models::CreateNodeDetails>

**[Required]** The list of nodes in the Big Data Service cluster.



47
48
49
# File 'lib/oci/bds/models/create_bds_instance_details.rb', line 47

def nodes
  @nodes
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/oci/bds/models/create_bds_instance_details.rb', line 66

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'compartmentId',
    'display_name': :'displayName',
    'cluster_version': :'clusterVersion',
    'cluster_public_key': :'clusterPublicKey',
    'cluster_admin_password': :'clusterAdminPassword',
    'is_high_availability': :'isHighAvailability',
    'is_secure': :'isSecure',
    'network_config': :'networkConfig',
    'bootstrap_script_url': :'bootstrapScriptUrl',
    'nodes': :'nodes',
    'kerberos_realm_name': :'kerberosRealmName',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/oci/bds/models/create_bds_instance_details.rb', line 87

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'String',
    'display_name': :'String',
    'cluster_version': :'String',
    'cluster_public_key': :'String',
    'cluster_admin_password': :'String',
    'is_high_availability': :'BOOLEAN',
    'is_secure': :'BOOLEAN',
    'network_config': :'OCI::Bds::Models::NetworkConfig',
    'bootstrap_script_url': :'String',
    'nodes': :'Array<OCI::Bds::Models::CreateNodeDetails>',
    'kerberos_realm_name': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/oci/bds/models/create_bds_instance_details.rb', line 218

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    compartment_id == other.compartment_id &&
    display_name == other.display_name &&
    cluster_version == other.cluster_version &&
    cluster_public_key == other.cluster_public_key &&
    cluster_admin_password == other.cluster_admin_password &&
    is_high_availability == other.is_high_availability &&
    is_secure == other.is_secure &&
    network_config == other.network_config &&
    bootstrap_script_url == other.bootstrap_script_url &&
    nodes == other.nodes &&
    kerberos_realm_name == other.kerberos_realm_name &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'lib/oci/bds/models/create_bds_instance_details.rb', line 260

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


240
241
242
# File 'lib/oci/bds/models/create_bds_instance_details.rb', line 240

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



249
250
251
# File 'lib/oci/bds/models/create_bds_instance_details.rb', line 249

def hash
  [compartment_id, display_name, cluster_version, cluster_public_key, cluster_admin_password, is_high_availability, is_secure, network_config, bootstrap_script_url, nodes, kerberos_realm_name, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



293
294
295
296
297
298
299
300
301
302
# File 'lib/oci/bds/models/create_bds_instance_details.rb', line 293

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



287
288
289
# File 'lib/oci/bds/models/create_bds_instance_details.rb', line 287

def to_s
  to_hash.to_s
end