Class: OCI::Bds::Models::CreateBdsMetastoreConfigurationDetails
- Inherits:
-
Object
- Object
- OCI::Bds::Models::CreateBdsMetastoreConfigurationDetails
- Defined in:
- lib/oci/bds/models/create_bds_metastore_configuration_details.rb
Overview
The request body when creating BDS metastore configuration.
Instance Attribute Summary collapse
-
#bds_api_key_id ⇒ String
[Required] The ID of BDS Api Key used for Data Catalog metastore integration.
-
#bds_api_key_passphrase ⇒ String
[Required] Base-64 encoded passphrase of the BDS Api Key.
-
#cluster_admin_password ⇒ String
[Required] Base-64 encoded password for the cluster admin user.
-
#display_name ⇒ String
The display name of the metastore configuration.
-
#metastore_id ⇒ String
[Required] The OCID of the Data Catalog metastore.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateBdsMetastoreConfigurationDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateBdsMetastoreConfigurationDetails
Initializes the object
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/oci/bds/models/create_bds_metastore_configuration_details.rb', line 67 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self. = attributes[:'metastoreId'] if attributes[:'metastoreId'] raise 'You cannot provide both :metastoreId and :metastore_id' if attributes.key?(:'metastoreId') && attributes.key?(:'metastore_id') self. = attributes[:'metastore_id'] if attributes[:'metastore_id'] self.bds_api_key_id = attributes[:'bdsApiKeyId'] if attributes[:'bdsApiKeyId'] raise 'You cannot provide both :bdsApiKeyId and :bds_api_key_id' if attributes.key?(:'bdsApiKeyId') && attributes.key?(:'bds_api_key_id') self.bds_api_key_id = attributes[:'bds_api_key_id'] if attributes[:'bds_api_key_id'] self.bds_api_key_passphrase = attributes[:'bdsApiKeyPassphrase'] if attributes[:'bdsApiKeyPassphrase'] raise 'You cannot provide both :bdsApiKeyPassphrase and :bds_api_key_passphrase' if attributes.key?(:'bdsApiKeyPassphrase') && attributes.key?(:'bds_api_key_passphrase') self.bds_api_key_passphrase = attributes[:'bds_api_key_passphrase'] if attributes[:'bds_api_key_passphrase'] self.cluster_admin_password = attributes[:'clusterAdminPassword'] if attributes[:'clusterAdminPassword'] raise 'You cannot provide both :clusterAdminPassword and :cluster_admin_password' if attributes.key?(:'clusterAdminPassword') && attributes.key?(:'cluster_admin_password') self.cluster_admin_password = attributes[:'cluster_admin_password'] if attributes[:'cluster_admin_password'] end |
Instance Attribute Details
#bds_api_key_id ⇒ String
[Required] The ID of BDS Api Key used for Data Catalog metastore integration.
20 21 22 |
# File 'lib/oci/bds/models/create_bds_metastore_configuration_details.rb', line 20 def bds_api_key_id @bds_api_key_id end |
#bds_api_key_passphrase ⇒ String
[Required] Base-64 encoded passphrase of the BDS Api Key.
24 25 26 |
# File 'lib/oci/bds/models/create_bds_metastore_configuration_details.rb', line 24 def bds_api_key_passphrase @bds_api_key_passphrase end |
#cluster_admin_password ⇒ String
[Required] Base-64 encoded password for the cluster admin user.
28 29 30 |
# File 'lib/oci/bds/models/create_bds_metastore_configuration_details.rb', line 28 def cluster_admin_password @cluster_admin_password end |
#display_name ⇒ String
The display name of the metastore configuration
12 13 14 |
# File 'lib/oci/bds/models/create_bds_metastore_configuration_details.rb', line 12 def display_name @display_name end |
#metastore_id ⇒ String
[Required] The OCID of the Data Catalog metastore.
16 17 18 |
# File 'lib/oci/bds/models/create_bds_metastore_configuration_details.rb', line 16 def end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 40 41 |
# File 'lib/oci/bds/models/create_bds_metastore_configuration_details.rb', line 31 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'metastore_id': :'metastoreId', 'bds_api_key_id': :'bdsApiKeyId', 'bds_api_key_passphrase': :'bdsApiKeyPassphrase', 'cluster_admin_password': :'clusterAdminPassword' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/oci/bds/models/create_bds_metastore_configuration_details.rb', line 44 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'metastore_id': :'String', 'bds_api_key_id': :'String', 'bds_api_key_passphrase': :'String', 'cluster_admin_password': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
111 112 113 114 115 116 117 118 119 120 |
# File 'lib/oci/bds/models/create_bds_metastore_configuration_details.rb', line 111 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && == other. && bds_api_key_id == other.bds_api_key_id && bds_api_key_passphrase == other.bds_api_key_passphrase && cluster_admin_password == other.cluster_admin_password end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/oci/bds/models/create_bds_metastore_configuration_details.rb', line 145 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
125 126 127 |
# File 'lib/oci/bds/models/create_bds_metastore_configuration_details.rb', line 125 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
134 135 136 |
# File 'lib/oci/bds/models/create_bds_metastore_configuration_details.rb', line 134 def hash [display_name, , bds_api_key_id, bds_api_key_passphrase, cluster_admin_password].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
178 179 180 181 182 183 184 185 186 187 |
# File 'lib/oci/bds/models/create_bds_metastore_configuration_details.rb', line 178 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
172 173 174 |
# File 'lib/oci/bds/models/create_bds_metastore_configuration_details.rb', line 172 def to_s to_hash.to_s end |