Class: OCI::Bds::Models::TimeAndHorizontalScalingConfig
- Inherits:
-
Object
- Object
- OCI::Bds::Models::TimeAndHorizontalScalingConfig
- Defined in:
- lib/oci/bds/models/time_and_horizontal_scaling_config.rb
Overview
Time of day and horizontal scaling configuration.
Instance Attribute Summary collapse
-
#target_node_count ⇒ Integer
This value is the desired number of nodes in the cluster.
-
#time_recurrence ⇒ String
Day/time recurrence (specified following RFC 5545) at which to trigger autoscaling action.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TimeAndHorizontalScalingConfig
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ TimeAndHorizontalScalingConfig
Initializes the object
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/oci/bds/models/time_and_horizontal_scaling_config.rb', line 47 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.time_recurrence = attributes[:'timeRecurrence'] if attributes[:'timeRecurrence'] raise 'You cannot provide both :timeRecurrence and :time_recurrence' if attributes.key?(:'timeRecurrence') && attributes.key?(:'time_recurrence') self.time_recurrence = attributes[:'time_recurrence'] if attributes[:'time_recurrence'] self.target_node_count = attributes[:'targetNodeCount'] if attributes[:'targetNodeCount'] raise 'You cannot provide both :targetNodeCount and :target_node_count' if attributes.key?(:'targetNodeCount') && attributes.key?(:'target_node_count') self.target_node_count = attributes[:'target_node_count'] if attributes[:'target_node_count'] end |
Instance Attribute Details
#target_node_count ⇒ Integer
This value is the desired number of nodes in the cluster.
17 18 19 |
# File 'lib/oci/bds/models/time_and_horizontal_scaling_config.rb', line 17 def target_node_count @target_node_count end |
#time_recurrence ⇒ String
Day/time recurrence (specified following RFC 5545) at which to trigger autoscaling action. Currently only WEEKLY frequency is supported. Days of the week are specified using BYDAY field. Time of the day is specified using BYHOUR and BYMINUTE fields. Other fields are not supported.
13 14 15 |
# File 'lib/oci/bds/models/time_and_horizontal_scaling_config.rb', line 13 def time_recurrence @time_recurrence end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
20 21 22 23 24 25 26 27 |
# File 'lib/oci/bds/models/time_and_horizontal_scaling_config.rb', line 20 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'time_recurrence': :'timeRecurrence', 'target_node_count': :'targetNodeCount' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
30 31 32 33 34 35 36 37 |
# File 'lib/oci/bds/models/time_and_horizontal_scaling_config.rb', line 30 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'time_recurrence': :'String', 'target_node_count': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
73 74 75 76 77 78 79 |
# File 'lib/oci/bds/models/time_and_horizontal_scaling_config.rb', line 73 def ==(other) return true if equal?(other) self.class == other.class && time_recurrence == other.time_recurrence && target_node_count == other.target_node_count end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/oci/bds/models/time_and_horizontal_scaling_config.rb', line 104 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
84 85 86 |
# File 'lib/oci/bds/models/time_and_horizontal_scaling_config.rb', line 84 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
93 94 95 |
# File 'lib/oci/bds/models/time_and_horizontal_scaling_config.rb', line 93 def hash [time_recurrence, target_node_count].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
137 138 139 140 141 142 143 144 145 146 |
# File 'lib/oci/bds/models/time_and_horizontal_scaling_config.rb', line 137 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
131 132 133 |
# File 'lib/oci/bds/models/time_and_horizontal_scaling_config.rb', line 131 def to_s to_hash.to_s end |