Class: OCI::Bds::Models::UpdateBdsMetastoreConfigurationDetails
- Inherits:
-
Object
- Object
- OCI::Bds::Models::UpdateBdsMetastoreConfigurationDetails
- Defined in:
- lib/oci/bds/models/update_bds_metastore_configuration_details.rb
Overview
The request body when updating BDS metastore configuration.
Instance Attribute Summary collapse
-
#bds_api_key_id ⇒ String
The ID of BDS Api Key used for Data Catalog metastore integration.
-
#bds_api_key_passphrase ⇒ String
Base-64 encoded passphrase of the BDS Api Key.
-
#cluster_admin_password ⇒ String
Base-64 encoded password for the cluster admin user.
-
#display_name ⇒ String
The display name of the metastore configuration.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateBdsMetastoreConfigurationDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateBdsMetastoreConfigurationDetails
Initializes the object
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/oci/bds/models/update_bds_metastore_configuration_details.rb', line 60 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.bds_api_key_id = attributes[:'bdsApiKeyId'] if attributes[:'bdsApiKeyId'] raise 'You cannot provide both :bdsApiKeyId and :bds_api_key_id' if attributes.key?(:'bdsApiKeyId') && attributes.key?(:'bds_api_key_id') self.bds_api_key_id = attributes[:'bds_api_key_id'] if attributes[:'bds_api_key_id'] self.bds_api_key_passphrase = attributes[:'bdsApiKeyPassphrase'] if attributes[:'bdsApiKeyPassphrase'] raise 'You cannot provide both :bdsApiKeyPassphrase and :bds_api_key_passphrase' if attributes.key?(:'bdsApiKeyPassphrase') && attributes.key?(:'bds_api_key_passphrase') self.bds_api_key_passphrase = attributes[:'bds_api_key_passphrase'] if attributes[:'bds_api_key_passphrase'] self.cluster_admin_password = attributes[:'clusterAdminPassword'] if attributes[:'clusterAdminPassword'] raise 'You cannot provide both :clusterAdminPassword and :cluster_admin_password' if attributes.key?(:'clusterAdminPassword') && attributes.key?(:'cluster_admin_password') self.cluster_admin_password = attributes[:'cluster_admin_password'] if attributes[:'cluster_admin_password'] end |
Instance Attribute Details
#bds_api_key_id ⇒ String
The ID of BDS Api Key used for Data Catalog metastore integration. Set only if metastore's type is EXTERNAL.
16 17 18 |
# File 'lib/oci/bds/models/update_bds_metastore_configuration_details.rb', line 16 def bds_api_key_id @bds_api_key_id end |
#bds_api_key_passphrase ⇒ String
Base-64 encoded passphrase of the BDS Api Key.
20 21 22 |
# File 'lib/oci/bds/models/update_bds_metastore_configuration_details.rb', line 20 def bds_api_key_passphrase @bds_api_key_passphrase end |
#cluster_admin_password ⇒ String
Base-64 encoded password for the cluster admin user.
24 25 26 |
# File 'lib/oci/bds/models/update_bds_metastore_configuration_details.rb', line 24 def cluster_admin_password @cluster_admin_password end |
#display_name ⇒ String
The display name of the metastore configuration.
12 13 14 |
# File 'lib/oci/bds/models/update_bds_metastore_configuration_details.rb', line 12 def display_name @display_name end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
27 28 29 30 31 32 33 34 35 36 |
# File 'lib/oci/bds/models/update_bds_metastore_configuration_details.rb', line 27 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'bds_api_key_id': :'bdsApiKeyId', 'bds_api_key_passphrase': :'bdsApiKeyPassphrase', 'cluster_admin_password': :'clusterAdminPassword' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
39 40 41 42 43 44 45 46 47 48 |
# File 'lib/oci/bds/models/update_bds_metastore_configuration_details.rb', line 39 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'bds_api_key_id': :'String', 'bds_api_key_passphrase': :'String', 'cluster_admin_password': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
98 99 100 101 102 103 104 105 106 |
# File 'lib/oci/bds/models/update_bds_metastore_configuration_details.rb', line 98 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && bds_api_key_id == other.bds_api_key_id && bds_api_key_passphrase == other.bds_api_key_passphrase && cluster_admin_password == other.cluster_admin_password end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/oci/bds/models/update_bds_metastore_configuration_details.rb', line 131 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
111 112 113 |
# File 'lib/oci/bds/models/update_bds_metastore_configuration_details.rb', line 111 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
120 121 122 |
# File 'lib/oci/bds/models/update_bds_metastore_configuration_details.rb', line 120 def hash [display_name, bds_api_key_id, bds_api_key_passphrase, cluster_admin_password].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
164 165 166 167 168 169 170 171 172 173 |
# File 'lib/oci/bds/models/update_bds_metastore_configuration_details.rb', line 164 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
158 159 160 |
# File 'lib/oci/bds/models/update_bds_metastore_configuration_details.rb', line 158 def to_s to_hash.to_s end |