Class: OCI::Blockchain::Models::BlockchainPlatformSummary
- Inherits:
-
Object
- Object
- OCI::Blockchain::Models::BlockchainPlatformSummary
- Defined in:
- lib/oci/blockchain/models/blockchain_platform_summary.rb
Overview
Blockchain Platform Instance Summary.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] Compartment Identifier.
-
#compute_shape ⇒ String
[Required] Compute shape - STANDARD or ENTERPRISE_SMALL or ENTERPRISE_MEDIUM or ENTERPRISE_LARGE or ENTERPRISE_EXTRA_LARGE or ENTERPRISE_CUSTOM.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
Platform Instance Description.
-
#display_name ⇒ String
[Required] Platform Instance Display name, can be renamed.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
[Required] unique identifier that is immutable on creation.
-
#lifecycle_details ⇒ String
An message describing the current state in more detail.
-
#lifecycle_state ⇒ String
The current state of the Platform Instance.
-
#platform_role ⇒ String
Role of platform - founder or participant.
-
#service_endpoint ⇒ String
Service endpoint URL, valid post-provisioning.
-
#time_created ⇒ DateTime
The time the the Platform Instance was created.
-
#time_updated ⇒ DateTime
The time the Platform Instance was updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BlockchainPlatformSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ BlockchainPlatformSummary
Initializes the object
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/oci/blockchain/models/blockchain_platform_summary.rb', line 127 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.description = attributes[:'description'] if attributes[:'description'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.platform_role = attributes[:'platformRole'] if attributes[:'platformRole'] raise 'You cannot provide both :platformRole and :platform_role' if attributes.key?(:'platformRole') && attributes.key?(:'platform_role') self.platform_role = attributes[:'platform_role'] if attributes[:'platform_role'] self.compute_shape = attributes[:'computeShape'] if attributes[:'computeShape'] raise 'You cannot provide both :computeShape and :compute_shape' if attributes.key?(:'computeShape') && attributes.key?(:'compute_shape') self.compute_shape = attributes[:'compute_shape'] if attributes[:'compute_shape'] self.service_endpoint = attributes[:'serviceEndpoint'] if attributes[:'serviceEndpoint'] raise 'You cannot provide both :serviceEndpoint and :service_endpoint' if attributes.key?(:'serviceEndpoint') && attributes.key?(:'service_endpoint') self.service_endpoint = attributes[:'service_endpoint'] if attributes[:'service_endpoint'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] Compartment Identifier
20 21 22 |
# File 'lib/oci/blockchain/models/blockchain_platform_summary.rb', line 20 def compartment_id @compartment_id end |
#compute_shape ⇒ String
[Required] Compute shape - STANDARD or ENTERPRISE_SMALL or ENTERPRISE_MEDIUM or ENTERPRISE_LARGE or ENTERPRISE_EXTRA_LARGE or ENTERPRISE_CUSTOM
40 41 42 |
# File 'lib/oci/blockchain/models/blockchain_platform_summary.rb', line 40 def compute_shape @compute_shape end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
64 65 66 |
# File 'lib/oci/blockchain/models/blockchain_platform_summary.rb', line 64 def end |
#description ⇒ String
Platform Instance Description
24 25 26 |
# File 'lib/oci/blockchain/models/blockchain_platform_summary.rb', line 24 def description @description end |
#display_name ⇒ String
[Required] Platform Instance Display name, can be renamed
16 17 18 |
# File 'lib/oci/blockchain/models/blockchain_platform_summary.rb', line 16 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`
58 59 60 |
# File 'lib/oci/blockchain/models/blockchain_platform_summary.rb', line 58 def end |
#id ⇒ String
[Required] unique identifier that is immutable on creation
12 13 14 |
# File 'lib/oci/blockchain/models/blockchain_platform_summary.rb', line 12 def id @id end |
#lifecycle_details ⇒ String
An message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
52 53 54 |
# File 'lib/oci/blockchain/models/blockchain_platform_summary.rb', line 52 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
The current state of the Platform Instance.
48 49 50 |
# File 'lib/oci/blockchain/models/blockchain_platform_summary.rb', line 48 def lifecycle_state @lifecycle_state end |
#platform_role ⇒ String
Role of platform - founder or participant
36 37 38 |
# File 'lib/oci/blockchain/models/blockchain_platform_summary.rb', line 36 def platform_role @platform_role end |
#service_endpoint ⇒ String
Service endpoint URL, valid post-provisioning
44 45 46 |
# File 'lib/oci/blockchain/models/blockchain_platform_summary.rb', line 44 def service_endpoint @service_endpoint end |
#time_created ⇒ DateTime
The time the the Platform Instance was created. An RFC3339 formatted datetime string
28 29 30 |
# File 'lib/oci/blockchain/models/blockchain_platform_summary.rb', line 28 def time_created @time_created end |
#time_updated ⇒ DateTime
The time the Platform Instance was updated. An RFC3339 formatted datetime string
32 33 34 |
# File 'lib/oci/blockchain/models/blockchain_platform_summary.rb', line 32 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/oci/blockchain/models/blockchain_platform_summary.rb', line 67 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'description': :'description', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'platform_role': :'platformRole', 'compute_shape': :'computeShape', 'service_endpoint': :'serviceEndpoint', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/oci/blockchain/models/blockchain_platform_summary.rb', line 88 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'compartment_id': :'String', 'description': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'platform_role': :'String', 'compute_shape': :'String', 'service_endpoint': :'String', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/oci/blockchain/models/blockchain_platform_summary.rb', line 211 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && compartment_id == other.compartment_id && description == other.description && time_created == other.time_created && time_updated == other.time_updated && platform_role == other.platform_role && compute_shape == other.compute_shape && service_endpoint == other.service_endpoint && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/oci/blockchain/models/blockchain_platform_summary.rb', line 253 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
233 234 235 |
# File 'lib/oci/blockchain/models/blockchain_platform_summary.rb', line 233 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
242 243 244 |
# File 'lib/oci/blockchain/models/blockchain_platform_summary.rb', line 242 def hash [id, display_name, compartment_id, description, time_created, time_updated, platform_role, compute_shape, service_endpoint, lifecycle_state, lifecycle_details, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
286 287 288 289 290 291 292 293 294 295 |
# File 'lib/oci/blockchain/models/blockchain_platform_summary.rb', line 286 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
280 281 282 |
# File 'lib/oci/blockchain/models/blockchain_platform_summary.rb', line 280 def to_s to_hash.to_s end |