Class: OCI::Blockchain::Models::CreateBlockchainPlatformDetails
- Inherits:
-
Object
- Object
- OCI::Blockchain::Models::CreateBlockchainPlatformDetails
- Defined in:
- lib/oci/blockchain/models/create_blockchain_platform_details.rb
Overview
Blockchain Platform details for creating a new service.
Instance Attribute Summary collapse
-
#ca_cert_archive_text ⇒ String
Base64 encoded text in ASCII character set of a Thirdparty CA Certificates archive file.
-
#compartment_id ⇒ String
[Required] Compartment Identifier.
-
#compute_shape ⇒ String
[Required] Compute shape - STANDARD or ENTERPRISE_SMALL or ENTERPRISE_MEDIUM or ENTERPRISE_LARGE or ENTERPRISE_EXTRA_LARGE.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
Platform Instance Description.
-
#display_name ⇒ String
[Required] Platform Instance Display name, can be renamed.
-
#federated_user_id ⇒ String
Identifier for a federated user.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#idcs_access_token ⇒ String
[Required] IDCS access token with Identity Domain Administrator role.
-
#is_byol ⇒ BOOLEAN
Bring your own license.
-
#platform_role ⇒ String
[Required] Role of platform - founder or participant.
-
#platform_version ⇒ String
Platform version.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateBlockchainPlatformDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateBlockchainPlatformDetails
Initializes the object
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/oci/blockchain/models/create_blockchain_platform_details.rb', line 127 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.description = attributes[:'description'] if attributes[:'description'] self.platform_role = attributes[:'platformRole'] if attributes[:'platformRole'] raise 'You cannot provide both :platformRole and :platform_role' if attributes.key?(:'platformRole') && attributes.key?(:'platform_role') self.platform_role = attributes[:'platform_role'] if attributes[:'platform_role'] self.compute_shape = attributes[:'computeShape'] if attributes[:'computeShape'] raise 'You cannot provide both :computeShape and :compute_shape' if attributes.key?(:'computeShape') && attributes.key?(:'compute_shape') self.compute_shape = attributes[:'compute_shape'] if attributes[:'compute_shape'] self.is_byol = attributes[:'isByol'] unless attributes[:'isByol'].nil? self.is_byol = false if is_byol.nil? && !attributes.key?(:'isByol') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isByol and :is_byol' if attributes.key?(:'isByol') && attributes.key?(:'is_byol') self.is_byol = attributes[:'is_byol'] unless attributes[:'is_byol'].nil? self.is_byol = false if is_byol.nil? && !attributes.key?(:'isByol') && !attributes.key?(:'is_byol') # rubocop:disable Style/StringLiterals self.platform_version = attributes[:'platformVersion'] if attributes[:'platformVersion'] raise 'You cannot provide both :platformVersion and :platform_version' if attributes.key?(:'platformVersion') && attributes.key?(:'platform_version') self.platform_version = attributes[:'platform_version'] if attributes[:'platform_version'] self.idcs_access_token = attributes[:'idcsAccessToken'] if attributes[:'idcsAccessToken'] raise 'You cannot provide both :idcsAccessToken and :idcs_access_token' if attributes.key?(:'idcsAccessToken') && attributes.key?(:'idcs_access_token') self.idcs_access_token = attributes[:'idcs_access_token'] if attributes[:'idcs_access_token'] self.federated_user_id = attributes[:'federatedUserId'] if attributes[:'federatedUserId'] raise 'You cannot provide both :federatedUserId and :federated_user_id' if attributes.key?(:'federatedUserId') && attributes.key?(:'federated_user_id') self.federated_user_id = attributes[:'federated_user_id'] if attributes[:'federated_user_id'] self.ca_cert_archive_text = attributes[:'caCertArchiveText'] if attributes[:'caCertArchiveText'] raise 'You cannot provide both :caCertArchiveText and :ca_cert_archive_text' if attributes.key?(:'caCertArchiveText') && attributes.key?(:'ca_cert_archive_text') self.ca_cert_archive_text = attributes[:'ca_cert_archive_text'] if attributes[:'ca_cert_archive_text'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#ca_cert_archive_text ⇒ String
Base64 encoded text in ASCII character set of a Thirdparty CA Certificates archive file. The Archive file is a zip file containing third part CA Certificates, the ca key and certificate files used when issuing enrollment certificates (ECerts) and transaction certificates (TCerts). The chainfile (if it exists) contains the certificate chain which should be trusted for this CA, where the 1st in the chain is always the root CA certificate. File list in zip file [ca-cert.pem,ca-key.pem,ca-chain.pem(optional)].
55 56 57 |
# File 'lib/oci/blockchain/models/create_blockchain_platform_details.rb', line 55 def ca_cert_archive_text @ca_cert_archive_text end |
#compartment_id ⇒ String
[Required] Compartment Identifier
16 17 18 |
# File 'lib/oci/blockchain/models/create_blockchain_platform_details.rb', line 16 def compartment_id @compartment_id end |
#compute_shape ⇒ String
[Required] Compute shape - STANDARD or ENTERPRISE_SMALL or ENTERPRISE_MEDIUM or ENTERPRISE_LARGE or ENTERPRISE_EXTRA_LARGE
28 29 30 |
# File 'lib/oci/blockchain/models/create_blockchain_platform_details.rb', line 28 def compute_shape @compute_shape end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
67 68 69 |
# File 'lib/oci/blockchain/models/create_blockchain_platform_details.rb', line 67 def end |
#description ⇒ String
Platform Instance Description
20 21 22 |
# File 'lib/oci/blockchain/models/create_blockchain_platform_details.rb', line 20 def description @description end |
#display_name ⇒ String
[Required] Platform Instance Display name, can be renamed
12 13 14 |
# File 'lib/oci/blockchain/models/create_blockchain_platform_details.rb', line 12 def display_name @display_name end |
#federated_user_id ⇒ String
Identifier for a federated user
44 45 46 |
# File 'lib/oci/blockchain/models/create_blockchain_platform_details.rb', line 44 def federated_user_id @federated_user_id end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`
61 62 63 |
# File 'lib/oci/blockchain/models/create_blockchain_platform_details.rb', line 61 def end |
#idcs_access_token ⇒ String
[Required] IDCS access token with Identity Domain Administrator role
40 41 42 |
# File 'lib/oci/blockchain/models/create_blockchain_platform_details.rb', line 40 def idcs_access_token @idcs_access_token end |
#is_byol ⇒ BOOLEAN
Bring your own license
32 33 34 |
# File 'lib/oci/blockchain/models/create_blockchain_platform_details.rb', line 32 def is_byol @is_byol end |
#platform_role ⇒ String
[Required] Role of platform - founder or participant
24 25 26 |
# File 'lib/oci/blockchain/models/create_blockchain_platform_details.rb', line 24 def platform_role @platform_role end |
#platform_version ⇒ String
Platform version
36 37 38 |
# File 'lib/oci/blockchain/models/create_blockchain_platform_details.rb', line 36 def platform_version @platform_version end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/oci/blockchain/models/create_blockchain_platform_details.rb', line 70 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'description': :'description', 'platform_role': :'platformRole', 'compute_shape': :'computeShape', 'is_byol': :'isByol', 'platform_version': :'platformVersion', 'idcs_access_token': :'idcsAccessToken', 'federated_user_id': :'federatedUserId', 'ca_cert_archive_text': :'caCertArchiveText', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/oci/blockchain/models/create_blockchain_platform_details.rb', line 90 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'compartment_id': :'String', 'description': :'String', 'platform_role': :'String', 'compute_shape': :'String', 'is_byol': :'BOOLEAN', 'platform_version': :'String', 'idcs_access_token': :'String', 'federated_user_id': :'String', 'ca_cert_archive_text': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/oci/blockchain/models/create_blockchain_platform_details.rb', line 211 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && compartment_id == other.compartment_id && description == other.description && platform_role == other.platform_role && compute_shape == other.compute_shape && is_byol == other.is_byol && platform_version == other.platform_version && idcs_access_token == other.idcs_access_token && federated_user_id == other.federated_user_id && ca_cert_archive_text == other.ca_cert_archive_text && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/oci/blockchain/models/create_blockchain_platform_details.rb', line 252 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
232 233 234 |
# File 'lib/oci/blockchain/models/create_blockchain_platform_details.rb', line 232 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
241 242 243 |
# File 'lib/oci/blockchain/models/create_blockchain_platform_details.rb', line 241 def hash [display_name, compartment_id, description, platform_role, compute_shape, is_byol, platform_version, idcs_access_token, federated_user_id, ca_cert_archive_text, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
285 286 287 288 289 290 291 292 293 294 |
# File 'lib/oci/blockchain/models/create_blockchain_platform_details.rb', line 285 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
279 280 281 |
# File 'lib/oci/blockchain/models/create_blockchain_platform_details.rb', line 279 def to_s to_hash.to_s end |