Class: OCI::Blockchain::Models::MetadataDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/blockchain/models/metadata_details.rb

Overview

Metadata parameter details

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ MetadataDetails

Initializes the object

Options Hash (attributes):

  • :param_name (String)

    The value to assign to the #param_name property

  • :param_value (String)

    The value to assign to the #param_value property

  • :is_json_value (BOOLEAN)

    The value to assign to the #is_json_value property

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/oci/blockchain/models/metadata_details.rb', line 53

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.param_name = attributes[:'paramName'] if attributes[:'paramName']

  raise 'You cannot provide both :paramName and :param_name' if attributes.key?(:'paramName') && attributes.key?(:'param_name')

  self.param_name = attributes[:'param_name'] if attributes[:'param_name']

  self.param_value = attributes[:'paramValue'] if attributes[:'paramValue']

  raise 'You cannot provide both :paramValue and :param_value' if attributes.key?(:'paramValue') && attributes.key?(:'param_value')

  self.param_value = attributes[:'param_value'] if attributes[:'param_value']

  self.is_json_value = attributes[:'isJsonValue'] unless attributes[:'isJsonValue'].nil?

  raise 'You cannot provide both :isJsonValue and :is_json_value' if attributes.key?(:'isJsonValue') && attributes.key?(:'is_json_value')

  self.is_json_value = attributes[:'is_json_value'] unless attributes[:'is_json_value'].nil?
end

Instance Attribute Details

#is_json_valueBOOLEAN

[Required] Indicates if the value is a JSON string

Returns:



20
21
22
# File 'lib/oci/blockchain/models/metadata_details.rb', line 20

def is_json_value
  @is_json_value
end

#param_nameString

[Required] Metadata param name

Returns:



12
13
14
# File 'lib/oci/blockchain/models/metadata_details.rb', line 12

def param_name
  @param_name
end

#param_valueString

[Required] Metadata param value. Complex value will be a JSON string.

Returns:



16
17
18
# File 'lib/oci/blockchain/models/metadata_details.rb', line 16

def param_value
  @param_value
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



23
24
25
26
27
28
29
30
31
# File 'lib/oci/blockchain/models/metadata_details.rb', line 23

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'param_name': :'paramName',
    'param_value': :'paramValue',
    'is_json_value': :'isJsonValue'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



34
35
36
37
38
39
40
41
42
# File 'lib/oci/blockchain/models/metadata_details.rb', line 34

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'param_name': :'String',
    'param_value': :'String',
    'is_json_value': :'BOOLEAN'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • the other object to be compared



85
86
87
88
89
90
91
92
# File 'lib/oci/blockchain/models/metadata_details.rb', line 85

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    param_name == other.param_name &&
    param_value == other.param_value &&
    is_json_value == other.is_json_value
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/oci/blockchain/models/metadata_details.rb', line 117

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method

Parameters:

  • the other object to be compared

Returns:



97
98
99
# File 'lib/oci/blockchain/models/metadata_details.rb', line 97

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • Hash code



106
107
108
# File 'lib/oci/blockchain/models/metadata_details.rb', line 106

def hash
  [param_name, param_value, is_json_value].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



150
151
152
153
154
155
156
157
158
159
# File 'lib/oci/blockchain/models/metadata_details.rb', line 150

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



144
145
146
# File 'lib/oci/blockchain/models/metadata_details.rb', line 144

def to_s
  to_hash.to_s
end