Class: OCI::Blockchain::Models::Peer
- Inherits:
-
Object
- Object
- OCI::Blockchain::Models::Peer
- Defined in:
- lib/oci/blockchain/models/peer.rb
Overview
A Peer details
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#_alias ⇒ String
peer alias.
-
#ad ⇒ String
[Required] Availability Domain of peer.
-
#host ⇒ String
[Required] Host on which the Peer exists.
-
#lifecycle_state ⇒ String
The current state of the peer.
- #ocpu_allocation_param ⇒ OCI::Blockchain::Models::OcpuAllocationNumberParam
-
#peer_key ⇒ String
[Required] peer identifier.
-
#role ⇒ String
[Required] Peer role.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Peer
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Peer
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/oci/blockchain/models/peer.rb', line 88 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.peer_key = attributes[:'peerKey'] if attributes[:'peerKey'] raise 'You cannot provide both :peerKey and :peer_key' if attributes.key?(:'peerKey') && attributes.key?(:'peer_key') self.peer_key = attributes[:'peer_key'] if attributes[:'peer_key'] self.role = attributes[:'role'] if attributes[:'role'] self._alias = attributes[:'alias'] if attributes[:'alias'] raise 'You cannot provide both :alias and :_alias' if attributes.key?(:'alias') && attributes.key?(:'_alias') self._alias = attributes[:'_alias'] if attributes[:'_alias'] self.ocpu_allocation_param = attributes[:'ocpuAllocationParam'] if attributes[:'ocpuAllocationParam'] raise 'You cannot provide both :ocpuAllocationParam and :ocpu_allocation_param' if attributes.key?(:'ocpuAllocationParam') && attributes.key?(:'ocpu_allocation_param') self.ocpu_allocation_param = attributes[:'ocpu_allocation_param'] if attributes[:'ocpu_allocation_param'] self.host = attributes[:'host'] if attributes[:'host'] self.ad = attributes[:'ad'] if attributes[:'ad'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] end |
Instance Attribute Details
#_alias ⇒ String
peer alias
28 29 30 |
# File 'lib/oci/blockchain/models/peer.rb', line 28 def _alias @_alias end |
#ad ⇒ String
[Required] Availability Domain of peer
39 40 41 |
# File 'lib/oci/blockchain/models/peer.rb', line 39 def ad @ad end |
#host ⇒ String
[Required] Host on which the Peer exists
35 36 37 |
# File 'lib/oci/blockchain/models/peer.rb', line 35 def host @host end |
#lifecycle_state ⇒ String
The current state of the peer.
43 44 45 |
# File 'lib/oci/blockchain/models/peer.rb', line 43 def lifecycle_state @lifecycle_state end |
#ocpu_allocation_param ⇒ OCI::Blockchain::Models::OcpuAllocationNumberParam
31 32 33 |
# File 'lib/oci/blockchain/models/peer.rb', line 31 def ocpu_allocation_param @ocpu_allocation_param end |
#peer_key ⇒ String
[Required] peer identifier
20 21 22 |
# File 'lib/oci/blockchain/models/peer.rb', line 20 def peer_key @peer_key end |
#role ⇒ String
[Required] Peer role
24 25 26 |
# File 'lib/oci/blockchain/models/peer.rb', line 24 def role @role end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/oci/blockchain/models/peer.rb', line 46 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'peer_key': :'peerKey', 'role': :'role', '_alias': :'alias', 'ocpu_allocation_param': :'ocpuAllocationParam', 'host': :'host', 'ad': :'ad', 'lifecycle_state': :'lifecycleState' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/oci/blockchain/models/peer.rb', line 61 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'peer_key': :'String', 'role': :'String', '_alias': :'String', 'ocpu_allocation_param': :'OCI::Blockchain::Models::OcpuAllocationNumberParam', 'host': :'String', 'ad': :'String', 'lifecycle_state': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/oci/blockchain/models/peer.rb', line 145 def ==(other) return true if equal?(other) self.class == other.class && peer_key == other.peer_key && role == other.role && _alias == other._alias && ocpu_allocation_param == other.ocpu_allocation_param && host == other.host && ad == other.ad && lifecycle_state == other.lifecycle_state end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/oci/blockchain/models/peer.rb', line 181 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
161 162 163 |
# File 'lib/oci/blockchain/models/peer.rb', line 161 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
170 171 172 |
# File 'lib/oci/blockchain/models/peer.rb', line 170 def hash [peer_key, role, _alias, ocpu_allocation_param, host, ad, lifecycle_state].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
214 215 216 217 218 219 220 221 222 223 |
# File 'lib/oci/blockchain/models/peer.rb', line 214 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
208 209 210 |
# File 'lib/oci/blockchain/models/peer.rb', line 208 def to_s to_hash.to_s end |