Class: OCI::Blockchain::Models::ScaleBlockchainPlatformDetails
- Inherits:
-
Object
- Object
- OCI::Blockchain::Models::ScaleBlockchainPlatformDetails
- Defined in:
- lib/oci/blockchain/models/scale_blockchain_platform_details.rb
Overview
Scale operation details for a blockchain platform. The scale operation payload has multiple options
-
Add one or more Ordering Service Node (addOsns)
-
Add one or more Peers (addPeers)
-
Add more replicas of CA, Console and Rest Proxy (addReplicas)
-
Add more storage to the platform (addStorage)
-
Modify the CPU allocation for Peer Nodes (modifyPeers)
-
Remove one or more replicas of CA, Console and Rest Proxy (removeReplicas)
-
Remove one or more Ordering Service Node (removeOsns)
-
Remove one or more Peers (removePeers).
The scale operation payload must have at least one of the above options.
Instance Attribute Summary collapse
-
#add_osns ⇒ Array<OCI::Blockchain::Models::CreateOsnDetails>
new OSNs to add.
-
#add_peers ⇒ Array<OCI::Blockchain::Models::CreatePeerDetails>
new Peers to add.
- #add_replicas ⇒ OCI::Blockchain::Models::ReplicaDetails
- #add_storage ⇒ OCI::Blockchain::Models::ScaleStorageDetails
-
#modify_peers ⇒ Array<OCI::Blockchain::Models::ModifyPeerDetails>
modify ocpu allocation to existing Peers.
-
#remove_osns ⇒ Array<String>
OSN id list to remove.
-
#remove_peers ⇒ Array<String>
Peer id list to remove.
- #remove_replicas ⇒ OCI::Blockchain::Models::ReplicaDetails
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ScaleBlockchainPlatformDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ScaleBlockchainPlatformDetails
Initializes the object
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/oci/blockchain/models/scale_blockchain_platform_details.rb', line 95 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.add_osns = attributes[:'addOsns'] if attributes[:'addOsns'] raise 'You cannot provide both :addOsns and :add_osns' if attributes.key?(:'addOsns') && attributes.key?(:'add_osns') self.add_osns = attributes[:'add_osns'] if attributes[:'add_osns'] self.add_replicas = attributes[:'addReplicas'] if attributes[:'addReplicas'] raise 'You cannot provide both :addReplicas and :add_replicas' if attributes.key?(:'addReplicas') && attributes.key?(:'add_replicas') self.add_replicas = attributes[:'add_replicas'] if attributes[:'add_replicas'] self.add_peers = attributes[:'addPeers'] if attributes[:'addPeers'] raise 'You cannot provide both :addPeers and :add_peers' if attributes.key?(:'addPeers') && attributes.key?(:'add_peers') self.add_peers = attributes[:'add_peers'] if attributes[:'add_peers'] self.add_storage = attributes[:'addStorage'] if attributes[:'addStorage'] raise 'You cannot provide both :addStorage and :add_storage' if attributes.key?(:'addStorage') && attributes.key?(:'add_storage') self.add_storage = attributes[:'add_storage'] if attributes[:'add_storage'] self.modify_peers = attributes[:'modifyPeers'] if attributes[:'modifyPeers'] raise 'You cannot provide both :modifyPeers and :modify_peers' if attributes.key?(:'modifyPeers') && attributes.key?(:'modify_peers') self.modify_peers = attributes[:'modify_peers'] if attributes[:'modify_peers'] self.remove_replicas = attributes[:'removeReplicas'] if attributes[:'removeReplicas'] raise 'You cannot provide both :removeReplicas and :remove_replicas' if attributes.key?(:'removeReplicas') && attributes.key?(:'remove_replicas') self.remove_replicas = attributes[:'remove_replicas'] if attributes[:'remove_replicas'] self.remove_osns = attributes[:'removeOsns'] if attributes[:'removeOsns'] raise 'You cannot provide both :removeOsns and :remove_osns' if attributes.key?(:'removeOsns') && attributes.key?(:'remove_osns') self.remove_osns = attributes[:'remove_osns'] if attributes[:'remove_osns'] self.remove_peers = attributes[:'removePeers'] if attributes[:'removePeers'] raise 'You cannot provide both :removePeers and :remove_peers' if attributes.key?(:'removePeers') && attributes.key?(:'remove_peers') self.remove_peers = attributes[:'remove_peers'] if attributes[:'remove_peers'] end |
Instance Attribute Details
#add_osns ⇒ Array<OCI::Blockchain::Models::CreateOsnDetails>
new OSNs to add
22 23 24 |
# File 'lib/oci/blockchain/models/scale_blockchain_platform_details.rb', line 22 def add_osns @add_osns end |
#add_peers ⇒ Array<OCI::Blockchain::Models::CreatePeerDetails>
new Peers to add
29 30 31 |
# File 'lib/oci/blockchain/models/scale_blockchain_platform_details.rb', line 29 def add_peers @add_peers end |
#add_replicas ⇒ OCI::Blockchain::Models::ReplicaDetails
25 26 27 |
# File 'lib/oci/blockchain/models/scale_blockchain_platform_details.rb', line 25 def add_replicas @add_replicas end |
#add_storage ⇒ OCI::Blockchain::Models::ScaleStorageDetails
32 33 34 |
# File 'lib/oci/blockchain/models/scale_blockchain_platform_details.rb', line 32 def add_storage @add_storage end |
#modify_peers ⇒ Array<OCI::Blockchain::Models::ModifyPeerDetails>
modify ocpu allocation to existing Peers
36 37 38 |
# File 'lib/oci/blockchain/models/scale_blockchain_platform_details.rb', line 36 def modify_peers @modify_peers end |
#remove_osns ⇒ Array<String>
OSN id list to remove
43 44 45 |
# File 'lib/oci/blockchain/models/scale_blockchain_platform_details.rb', line 43 def remove_osns @remove_osns end |
#remove_peers ⇒ Array<String>
Peer id list to remove
47 48 49 |
# File 'lib/oci/blockchain/models/scale_blockchain_platform_details.rb', line 47 def remove_peers @remove_peers end |
#remove_replicas ⇒ OCI::Blockchain::Models::ReplicaDetails
39 40 41 |
# File 'lib/oci/blockchain/models/scale_blockchain_platform_details.rb', line 39 def remove_replicas @remove_replicas end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/oci/blockchain/models/scale_blockchain_platform_details.rb', line 50 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'add_osns': :'addOsns', 'add_replicas': :'addReplicas', 'add_peers': :'addPeers', 'add_storage': :'addStorage', 'modify_peers': :'modifyPeers', 'remove_replicas': :'removeReplicas', 'remove_osns': :'removeOsns', 'remove_peers': :'removePeers' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/oci/blockchain/models/scale_blockchain_platform_details.rb', line 66 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'add_osns': :'Array<OCI::Blockchain::Models::CreateOsnDetails>', 'add_replicas': :'OCI::Blockchain::Models::ReplicaDetails', 'add_peers': :'Array<OCI::Blockchain::Models::CreatePeerDetails>', 'add_storage': :'OCI::Blockchain::Models::ScaleStorageDetails', 'modify_peers': :'Array<OCI::Blockchain::Models::ModifyPeerDetails>', 'remove_replicas': :'OCI::Blockchain::Models::ReplicaDetails', 'remove_osns': :'Array<String>', 'remove_peers': :'Array<String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/oci/blockchain/models/scale_blockchain_platform_details.rb', line 157 def ==(other) return true if equal?(other) self.class == other.class && add_osns == other.add_osns && add_replicas == other.add_replicas && add_peers == other.add_peers && add_storage == other.add_storage && modify_peers == other.modify_peers && remove_replicas == other.remove_replicas && remove_osns == other.remove_osns && remove_peers == other.remove_peers end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/oci/blockchain/models/scale_blockchain_platform_details.rb', line 194 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
174 175 176 |
# File 'lib/oci/blockchain/models/scale_blockchain_platform_details.rb', line 174 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
183 184 185 |
# File 'lib/oci/blockchain/models/scale_blockchain_platform_details.rb', line 183 def hash [add_osns, add_replicas, add_peers, add_storage, modify_peers, remove_replicas, remove_osns, remove_peers].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
227 228 229 230 231 232 233 234 235 236 |
# File 'lib/oci/blockchain/models/scale_blockchain_platform_details.rb', line 227 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
221 222 223 |
# File 'lib/oci/blockchain/models/scale_blockchain_platform_details.rb', line 221 def to_s to_hash.to_s end |