Class: OCI::Blockchain::Models::UpdateBlockchainPlatformDetails
- Inherits:
-
Object
- Object
- OCI::Blockchain::Models::UpdateBlockchainPlatformDetails
- Defined in:
- lib/oci/blockchain/models/update_blockchain_platform_details.rb
Overview
Blockchain Platform details for updating a service.
Instance Attribute Summary collapse
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
Platform Description.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#load_balancer_shape ⇒ String
Type of Load Balancer shape - LB_100_MBPS or LB_400_MBPS.
- #replicas ⇒ OCI::Blockchain::Models::ReplicaDetails
-
#storage_size_in_tbs ⇒ Float
Storage size in TBs.
-
#total_ocpu_capacity ⇒ Integer
Number of total OCPUs to allocate.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateBlockchainPlatformDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateBlockchainPlatformDetails
Initializes the object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/oci/blockchain/models/update_blockchain_platform_details.rb', line 84 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.description = attributes[:'description'] if attributes[:'description'] self.storage_size_in_tbs = attributes[:'storageSizeInTBs'] if attributes[:'storageSizeInTBs'] raise 'You cannot provide both :storageSizeInTBs and :storage_size_in_tbs' if attributes.key?(:'storageSizeInTBs') && attributes.key?(:'storage_size_in_tbs') self.storage_size_in_tbs = attributes[:'storage_size_in_tbs'] if attributes[:'storage_size_in_tbs'] self.replicas = attributes[:'replicas'] if attributes[:'replicas'] self.total_ocpu_capacity = attributes[:'totalOcpuCapacity'] if attributes[:'totalOcpuCapacity'] raise 'You cannot provide both :totalOcpuCapacity and :total_ocpu_capacity' if attributes.key?(:'totalOcpuCapacity') && attributes.key?(:'total_ocpu_capacity') self.total_ocpu_capacity = attributes[:'total_ocpu_capacity'] if attributes[:'total_ocpu_capacity'] self.load_balancer_shape = attributes[:'loadBalancerShape'] if attributes[:'loadBalancerShape'] raise 'You cannot provide both :loadBalancerShape and :load_balancer_shape' if attributes.key?(:'loadBalancerShape') && attributes.key?(:'load_balancer_shape') self.load_balancer_shape = attributes[:'load_balancer_shape'] if attributes[:'load_balancer_shape'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
39 40 41 |
# File 'lib/oci/blockchain/models/update_blockchain_platform_details.rb', line 39 def end |
#description ⇒ String
Platform Description
12 13 14 |
# File 'lib/oci/blockchain/models/update_blockchain_platform_details.rb', line 12 def description @description end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`
33 34 35 |
# File 'lib/oci/blockchain/models/update_blockchain_platform_details.rb', line 33 def end |
#load_balancer_shape ⇒ String
Type of Load Balancer shape - LB_100_MBPS or LB_400_MBPS. Default is LB_100_MBPS.
27 28 29 |
# File 'lib/oci/blockchain/models/update_blockchain_platform_details.rb', line 27 def load_balancer_shape @load_balancer_shape end |
#replicas ⇒ OCI::Blockchain::Models::ReplicaDetails
19 20 21 |
# File 'lib/oci/blockchain/models/update_blockchain_platform_details.rb', line 19 def replicas @replicas end |
#storage_size_in_tbs ⇒ Float
Storage size in TBs
16 17 18 |
# File 'lib/oci/blockchain/models/update_blockchain_platform_details.rb', line 16 def storage_size_in_tbs @storage_size_in_tbs end |
#total_ocpu_capacity ⇒ Integer
Number of total OCPUs to allocate
23 24 25 |
# File 'lib/oci/blockchain/models/update_blockchain_platform_details.rb', line 23 def total_ocpu_capacity @total_ocpu_capacity end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
42 43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/oci/blockchain/models/update_blockchain_platform_details.rb', line 42 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'description': :'description', 'storage_size_in_tbs': :'storageSizeInTBs', 'replicas': :'replicas', 'total_ocpu_capacity': :'totalOcpuCapacity', 'load_balancer_shape': :'loadBalancerShape', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/oci/blockchain/models/update_blockchain_platform_details.rb', line 57 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'description': :'String', 'storage_size_in_tbs': :'Float', 'replicas': :'OCI::Blockchain::Models::ReplicaDetails', 'total_ocpu_capacity': :'Integer', 'load_balancer_shape': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/oci/blockchain/models/update_blockchain_platform_details.rb', line 132 def ==(other) return true if equal?(other) self.class == other.class && description == other.description && storage_size_in_tbs == other.storage_size_in_tbs && replicas == other.replicas && total_ocpu_capacity == other.total_ocpu_capacity && load_balancer_shape == other.load_balancer_shape && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/oci/blockchain/models/update_blockchain_platform_details.rb', line 168 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
148 149 150 |
# File 'lib/oci/blockchain/models/update_blockchain_platform_details.rb', line 148 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
157 158 159 |
# File 'lib/oci/blockchain/models/update_blockchain_platform_details.rb', line 157 def hash [description, storage_size_in_tbs, replicas, total_ocpu_capacity, load_balancer_shape, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
201 202 203 204 205 206 207 208 209 210 |
# File 'lib/oci/blockchain/models/update_blockchain_platform_details.rb', line 201 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
195 196 197 |
# File 'lib/oci/blockchain/models/update_blockchain_platform_details.rb', line 195 def to_s to_hash.to_s end |