Class: OCI::Budget::Models::Budget

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/budget/models/budget.rb

Overview

A budget.

Constant Summary collapse

RESET_PERIOD_ENUM =
[
  RESET_PERIOD_MONTHLY = 'MONTHLY'.freeze,
  RESET_PERIOD_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
PROCESSING_PERIOD_TYPE_ENUM =
[
  PROCESSING_PERIOD_TYPE_INVOICE = 'INVOICE'.freeze,
  PROCESSING_PERIOD_TYPE_MONTH = 'MONTH'.freeze,
  PROCESSING_PERIOD_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
TARGET_TYPE_ENUM =
[
  TARGET_TYPE_COMPARTMENT = 'COMPARTMENT'.freeze,
  TARGET_TYPE_TAG = 'TAG'.freeze,
  TARGET_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Budget

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :target_compartment_id (String)

    The value to assign to the #target_compartment_id property

  • :display_name (String)

    The value to assign to the #display_name property

  • :description (String)

    The value to assign to the #description property

  • :amount (Float)

    The value to assign to the #amount property

  • :reset_period (String)

    The value to assign to the #reset_period property

  • :budget_processing_period_start_offset (Integer)

    The value to assign to the #budget_processing_period_start_offset property

  • :processing_period_type (String)

    The value to assign to the #processing_period_type property

  • :target_type (String)

    The value to assign to the #target_type property

  • :targets (Array<String>)

    The value to assign to the #targets property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :alert_rule_count (Integer)

    The value to assign to the #alert_rule_count property

  • :version (Integer)

    The value to assign to the #version property

  • :actual_spend (Float)

    The value to assign to the #actual_spend property

  • :forecasted_spend (Float)

    The value to assign to the #forecasted_spend property

  • :time_spend_computed (DateTime)

    The value to assign to the #time_spend_computed property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :time_updated (DateTime)

    The value to assign to the #time_updated property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property



221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'lib/oci/budget/models/budget.rb', line 221

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.target_compartment_id = attributes[:'targetCompartmentId'] if attributes[:'targetCompartmentId']

  raise 'You cannot provide both :targetCompartmentId and :target_compartment_id' if attributes.key?(:'targetCompartmentId') && attributes.key?(:'target_compartment_id')

  self.target_compartment_id = attributes[:'target_compartment_id'] if attributes[:'target_compartment_id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.amount = attributes[:'amount'] if attributes[:'amount']

  self.reset_period = attributes[:'resetPeriod'] if attributes[:'resetPeriod']

  raise 'You cannot provide both :resetPeriod and :reset_period' if attributes.key?(:'resetPeriod') && attributes.key?(:'reset_period')

  self.reset_period = attributes[:'reset_period'] if attributes[:'reset_period']

  self.budget_processing_period_start_offset = attributes[:'budgetProcessingPeriodStartOffset'] if attributes[:'budgetProcessingPeriodStartOffset']

  raise 'You cannot provide both :budgetProcessingPeriodStartOffset and :budget_processing_period_start_offset' if attributes.key?(:'budgetProcessingPeriodStartOffset') && attributes.key?(:'budget_processing_period_start_offset')

  self.budget_processing_period_start_offset = attributes[:'budget_processing_period_start_offset'] if attributes[:'budget_processing_period_start_offset']

  self.processing_period_type = attributes[:'processingPeriodType'] if attributes[:'processingPeriodType']

  raise 'You cannot provide both :processingPeriodType and :processing_period_type' if attributes.key?(:'processingPeriodType') && attributes.key?(:'processing_period_type')

  self.processing_period_type = attributes[:'processing_period_type'] if attributes[:'processing_period_type']

  self.target_type = attributes[:'targetType'] if attributes[:'targetType']

  raise 'You cannot provide both :targetType and :target_type' if attributes.key?(:'targetType') && attributes.key?(:'target_type')

  self.target_type = attributes[:'target_type'] if attributes[:'target_type']

  self.targets = attributes[:'targets'] if attributes[:'targets']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.alert_rule_count = attributes[:'alertRuleCount'] if attributes[:'alertRuleCount']

  raise 'You cannot provide both :alertRuleCount and :alert_rule_count' if attributes.key?(:'alertRuleCount') && attributes.key?(:'alert_rule_count')

  self.alert_rule_count = attributes[:'alert_rule_count'] if attributes[:'alert_rule_count']

  self.version = attributes[:'version'] if attributes[:'version']

  self.actual_spend = attributes[:'actualSpend'] if attributes[:'actualSpend']

  raise 'You cannot provide both :actualSpend and :actual_spend' if attributes.key?(:'actualSpend') && attributes.key?(:'actual_spend')

  self.actual_spend = attributes[:'actual_spend'] if attributes[:'actual_spend']

  self.forecasted_spend = attributes[:'forecastedSpend'] if attributes[:'forecastedSpend']

  raise 'You cannot provide both :forecastedSpend and :forecasted_spend' if attributes.key?(:'forecastedSpend') && attributes.key?(:'forecasted_spend')

  self.forecasted_spend = attributes[:'forecasted_spend'] if attributes[:'forecasted_spend']

  self.time_spend_computed = attributes[:'timeSpendComputed'] if attributes[:'timeSpendComputed']

  raise 'You cannot provide both :timeSpendComputed and :time_spend_computed' if attributes.key?(:'timeSpendComputed') && attributes.key?(:'time_spend_computed')

  self.time_spend_computed = attributes[:'time_spend_computed'] if attributes[:'time_spend_computed']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#actual_spendFloat

The actual spend in currency for the current budget cycle.

Returns:

  • (Float)


102
103
104
# File 'lib/oci/budget/models/budget.rb', line 102

def actual_spend
  @actual_spend
end

#alert_rule_countInteger

**[Required]** The total number of alert rules in the budget.

Returns:

  • (Integer)


94
95
96
# File 'lib/oci/budget/models/budget.rb', line 94

def alert_rule_count
  @alert_rule_count
end

#amountFloat

**[Required]** The amount of the budget expressed in the currency of the customer's rate card.

Returns:

  • (Float)


60
61
62
# File 'lib/oci/budget/models/budget.rb', line 60

def amount
  @amount
end

#budget_processing_period_start_offsetInteger

The number of days offset from the first day of the month, at which the budget processing period starts. In months that have fewer days than this value, processing will begin on the last day of that month. For example, for a value of 12, processing starts every month on the 12th at midnight.

Returns:

  • (Integer)


69
70
71
# File 'lib/oci/budget/models/budget.rb', line 69

def budget_processing_period_start_offset
  @budget_processing_period_start_offset
end

#compartment_idString

**[Required]** The OCID of the compartment.

Returns:

  • (String)


40
41
42
# File 'lib/oci/budget/models/budget.rb', line 40

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: `{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


134
135
136
# File 'lib/oci/budget/models/budget.rb', line 134

def defined_tags
  @defined_tags
end

#descriptionString

The description of the budget.

Returns:

  • (String)


55
56
57
# File 'lib/oci/budget/models/budget.rb', line 55

def description
  @description
end

#display_nameString

**[Required]** The display name of the budget. Avoid entering confidential information.

Returns:

  • (String)


51
52
53
# File 'lib/oci/budget/models/budget.rb', line 51

def display_name
  @display_name
end

#forecasted_spendFloat

The forecasted spend in currency by the end of the current budget cycle.

Returns:

  • (Float)


106
107
108
# File 'lib/oci/budget/models/budget.rb', line 106

def forecasted_spend
  @forecasted_spend
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: `"Finance"`

Returns:

  • (Hash<String, String>)


126
127
128
# File 'lib/oci/budget/models/budget.rb', line 126

def freeform_tags
  @freeform_tags
end

#idString

**[Required]** The OCID of the budget.

Returns:

  • (String)


36
37
38
# File 'lib/oci/budget/models/budget.rb', line 36

def id
  @id
end

#lifecycle_stateString

**[Required]** The current state of the budget.

Returns:

  • (String)


90
91
92
# File 'lib/oci/budget/models/budget.rb', line 90

def lifecycle_state
  @lifecycle_state
end

#processing_period_typeString

The type of the budget processing period. Valid values are INVOICE and MONTH.

Returns:

  • (String)


74
75
76
# File 'lib/oci/budget/models/budget.rb', line 74

def processing_period_type
  @processing_period_type
end

#reset_periodString

**[Required]** The reset period for the budget.

Returns:

  • (String)


65
66
67
# File 'lib/oci/budget/models/budget.rb', line 65

def reset_period
  @reset_period
end

#target_compartment_idString

This is DEPRECATED. For backwards compatability, the property is populated when the targetType is "COMPARTMENT", and targets contain the specific target compartment OCID. For all other scenarios, this property will be left empty.

Returns:

  • (String)


47
48
49
# File 'lib/oci/budget/models/budget.rb', line 47

def target_compartment_id
  @target_compartment_id
end

#target_typeString

The type of target on which the budget is applied.

Returns:

  • (String)


79
80
81
# File 'lib/oci/budget/models/budget.rb', line 79

def target_type
  @target_type
end

#targetsArray<String>

The list of targets on which the budget is applied.

If the targetType is \"COMPARTMENT\", the targets contain the list of compartment OCIDs.
If the targetType is \"TAG\", the targets contain the list of cost tracking tag identifiers in the form of \"{tagNamespace}.{tagKey}.{tagValue}\".

Returns:

  • (Array<String>)


86
87
88
# File 'lib/oci/budget/models/budget.rb', line 86

def targets
  @targets
end

#time_createdDateTime

**[Required]** The time that the budget was created.

Returns:

  • (DateTime)


114
115
116
# File 'lib/oci/budget/models/budget.rb', line 114

def time_created
  @time_created
end

#time_spend_computedDateTime

The time that the budget spend was last computed.

Returns:

  • (DateTime)


110
111
112
# File 'lib/oci/budget/models/budget.rb', line 110

def time_spend_computed
  @time_spend_computed
end

#time_updatedDateTime

**[Required]** The time that the budget was updated.

Returns:

  • (DateTime)


118
119
120
# File 'lib/oci/budget/models/budget.rb', line 118

def time_updated
  @time_updated
end

#versionInteger

The version of the budget. Starts from 1 and increments by 1.

Returns:

  • (Integer)


98
99
100
# File 'lib/oci/budget/models/budget.rb', line 98

def version
  @version
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/oci/budget/models/budget.rb', line 137

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'compartment_id': :'compartmentId',
    'target_compartment_id': :'targetCompartmentId',
    'display_name': :'displayName',
    'description': :'description',
    'amount': :'amount',
    'reset_period': :'resetPeriod',
    'budget_processing_period_start_offset': :'budgetProcessingPeriodStartOffset',
    'processing_period_type': :'processingPeriodType',
    'target_type': :'targetType',
    'targets': :'targets',
    'lifecycle_state': :'lifecycleState',
    'alert_rule_count': :'alertRuleCount',
    'version': :'version',
    'actual_spend': :'actualSpend',
    'forecasted_spend': :'forecastedSpend',
    'time_spend_computed': :'timeSpendComputed',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/oci/budget/models/budget.rb', line 166

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'compartment_id': :'String',
    'target_compartment_id': :'String',
    'display_name': :'String',
    'description': :'String',
    'amount': :'Float',
    'reset_period': :'String',
    'budget_processing_period_start_offset': :'Integer',
    'processing_period_type': :'String',
    'target_type': :'String',
    'targets': :'Array<String>',
    'lifecycle_state': :'String',
    'alert_rule_count': :'Integer',
    'version': :'Integer',
    'actual_spend': :'Float',
    'forecasted_spend': :'Float',
    'time_spend_computed': :'DateTime',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
# File 'lib/oci/budget/models/budget.rb', line 393

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    target_compartment_id == other.target_compartment_id &&
    display_name == other.display_name &&
    description == other.description &&
    amount == other.amount &&
    reset_period == other.reset_period &&
    budget_processing_period_start_offset == other.budget_processing_period_start_offset &&
    processing_period_type == other.processing_period_type &&
    target_type == other.target_type &&
    targets == other.targets &&
    lifecycle_state == other.lifecycle_state &&
    alert_rule_count == other.alert_rule_count &&
    version == other.version &&
    actual_spend == other.actual_spend &&
    forecasted_spend == other.forecasted_spend &&
    time_spend_computed == other.time_spend_computed &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
# File 'lib/oci/budget/models/budget.rb', line 443

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


423
424
425
# File 'lib/oci/budget/models/budget.rb', line 423

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



432
433
434
# File 'lib/oci/budget/models/budget.rb', line 432

def hash
  [id, compartment_id, target_compartment_id, display_name, description, amount, reset_period, budget_processing_period_start_offset, processing_period_type, target_type, targets, lifecycle_state, alert_rule_count, version, actual_spend, forecasted_spend, time_spend_computed, time_created, time_updated, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



476
477
478
479
480
481
482
483
484
485
# File 'lib/oci/budget/models/budget.rb', line 476

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



470
471
472
# File 'lib/oci/budget/models/budget.rb', line 470

def to_s
  to_hash.to_s
end