Class: OCI::Budget::Models::CreateBudgetDetails
- Inherits:
-
Object
- Object
- OCI::Budget::Models::CreateBudgetDetails
- Defined in:
- lib/oci/budget/models/create_budget_details.rb
Overview
The create budget details.
Clients should use 'targetType' and 'targets' to specify the target type and list of targets on which the budget is applied.
For backwards compatibility, 'targetCompartmentId' is still supported for all existing clients. This is considered deprecated, however, and all clients are upgraded to use 'targetType' and 'targets'.
Specifying both 'targetCompartmentId' and 'targets' causes a Bad Request.
Constant Summary collapse
- RESET_PERIOD_ENUM =
[ RESET_PERIOD_MONTHLY = 'MONTHLY'.freeze ].freeze
- PROCESSING_PERIOD_TYPE_ENUM =
[ PROCESSING_PERIOD_TYPE_INVOICE = 'INVOICE'.freeze, PROCESSING_PERIOD_TYPE_MONTH = 'MONTH'.freeze ].freeze
- TARGET_TYPE_ENUM =
[ TARGET_TYPE_COMPARTMENT = 'COMPARTMENT'.freeze, TARGET_TYPE_TAG = 'TAG'.freeze ].freeze
Instance Attribute Summary collapse
-
#amount ⇒ Float
**[Required]** The amount of the budget expressed as a whole number in the currency of the customer's rate card.
-
#budget_processing_period_start_offset ⇒ Integer
The number of days offset from the first day of the month, at which the budget processing period starts.
-
#compartment_id ⇒ String
**[Required]** The OCID of the compartment.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
The description of the budget.
-
#display_name ⇒ String
The displayName of the budget.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#processing_period_type ⇒ String
The type of the budget processing period.
-
#reset_period ⇒ String
**[Required]** The reset period for the budget.
-
#target_compartment_id ⇒ String
This is DEPRECATED.
-
#target_type ⇒ String
The type of target on which the budget is applied.
-
#targets ⇒ Array<String>
The list of targets on which the budget is applied.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateBudgetDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateBudgetDetails
Initializes the object
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/oci/budget/models/create_budget_details.rb', line 155 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.target_compartment_id = attributes[:'targetCompartmentId'] if attributes[:'targetCompartmentId'] raise 'You cannot provide both :targetCompartmentId and :target_compartment_id' if attributes.key?(:'targetCompartmentId') && attributes.key?(:'target_compartment_id') self.target_compartment_id = attributes[:'target_compartment_id'] if attributes[:'target_compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.amount = attributes[:'amount'] if attributes[:'amount'] self.reset_period = attributes[:'resetPeriod'] if attributes[:'resetPeriod'] raise 'You cannot provide both :resetPeriod and :reset_period' if attributes.key?(:'resetPeriod') && attributes.key?(:'reset_period') self.reset_period = attributes[:'reset_period'] if attributes[:'reset_period'] self.budget_processing_period_start_offset = attributes[:'budgetProcessingPeriodStartOffset'] if attributes[:'budgetProcessingPeriodStartOffset'] raise 'You cannot provide both :budgetProcessingPeriodStartOffset and :budget_processing_period_start_offset' if attributes.key?(:'budgetProcessingPeriodStartOffset') && attributes.key?(:'budget_processing_period_start_offset') self.budget_processing_period_start_offset = attributes[:'budget_processing_period_start_offset'] if attributes[:'budget_processing_period_start_offset'] self.processing_period_type = attributes[:'processingPeriodType'] if attributes[:'processingPeriodType'] raise 'You cannot provide both :processingPeriodType and :processing_period_type' if attributes.key?(:'processingPeriodType') && attributes.key?(:'processing_period_type') self.processing_period_type = attributes[:'processing_period_type'] if attributes[:'processing_period_type'] self.target_type = attributes[:'targetType'] if attributes[:'targetType'] self.target_type = "COMPARTMENT" if target_type.nil? && !attributes.key?(:'targetType') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :targetType and :target_type' if attributes.key?(:'targetType') && attributes.key?(:'target_type') self.target_type = attributes[:'target_type'] if attributes[:'target_type'] self.target_type = "COMPARTMENT" if target_type.nil? && !attributes.key?(:'targetType') && !attributes.key?(:'target_type') # rubocop:disable Style/StringLiterals self.targets = attributes[:'targets'] if attributes[:'targets'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#amount ⇒ Float
**[Required]** The amount of the budget expressed as a whole number in the currency of the customer's rate card.
52 53 54 |
# File 'lib/oci/budget/models/create_budget_details.rb', line 52 def amount @amount end |
#budget_processing_period_start_offset ⇒ Integer
The number of days offset from the first day of the month, at which the budget processing period starts. In months that have fewer days than this value, processing will begin on the last day of that month. For example, for a value of 12, processing starts every month on the 12th at midnight.
61 62 63 |
# File 'lib/oci/budget/models/create_budget_details.rb', line 61 def budget_processing_period_start_offset @budget_processing_period_start_offset end |
#compartment_id ⇒ String
**[Required]** The OCID of the compartment.
34 35 36 |
# File 'lib/oci/budget/models/create_budget_details.rb', line 34 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: `{"CostCenter": "42"}`
95 96 97 |
# File 'lib/oci/budget/models/create_budget_details.rb', line 95 def @defined_tags end |
#description ⇒ String
The description of the budget.
47 48 49 |
# File 'lib/oci/budget/models/create_budget_details.rb', line 47 def description @description end |
#display_name ⇒ String
The displayName of the budget. Avoid entering confidential information.
43 44 45 |
# File 'lib/oci/budget/models/create_budget_details.rb', line 43 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: `"Finance"`
87 88 89 |
# File 'lib/oci/budget/models/create_budget_details.rb', line 87 def @freeform_tags end |
#processing_period_type ⇒ String
The type of the budget processing period. Valid values are INVOICE and MONTH.
66 67 68 |
# File 'lib/oci/budget/models/create_budget_details.rb', line 66 def processing_period_type @processing_period_type end |
#reset_period ⇒ String
**[Required]** The reset period for the budget.
57 58 59 |
# File 'lib/oci/budget/models/create_budget_details.rb', line 57 def reset_period @reset_period end |
#target_compartment_id ⇒ String
This is DEPRECATED. Set the target compartment ID in targets instead.
39 40 41 |
# File 'lib/oci/budget/models/create_budget_details.rb', line 39 def target_compartment_id @target_compartment_id end |
#target_type ⇒ String
The type of target on which the budget is applied.
71 72 73 |
# File 'lib/oci/budget/models/create_budget_details.rb', line 71 def target_type @target_type end |
#targets ⇒ Array<String>
The list of targets on which the budget is applied.
If targetType is \"COMPARTMENT\", the targets contain the list of compartment OCIDs.
If targetType is \"TAG\", the targets contain the list of cost tracking tag identifiers in the form of \"{tagNamespace}.{tagKey}.{tagValue}\".
Curerntly, the array should contain exactly one item.
79 80 81 |
# File 'lib/oci/budget/models/create_budget_details.rb', line 79 def targets @targets end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/oci/budget/models/create_budget_details.rb', line 98 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'target_compartment_id': :'targetCompartmentId', 'display_name': :'displayName', 'description': :'description', 'amount': :'amount', 'reset_period': :'resetPeriod', 'budget_processing_period_start_offset': :'budgetProcessingPeriodStartOffset', 'processing_period_type': :'processingPeriodType', 'target_type': :'targetType', 'targets': :'targets', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/oci/budget/models/create_budget_details.rb', line 118 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'target_compartment_id': :'String', 'display_name': :'String', 'description': :'String', 'amount': :'Float', 'reset_period': :'String', 'budget_processing_period_start_offset': :'Integer', 'processing_period_type': :'String', 'target_type': :'String', 'targets': :'Array<String>', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/oci/budget/models/create_budget_details.rb', line 255 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && target_compartment_id == other.target_compartment_id && display_name == other.display_name && description == other.description && amount == other.amount && reset_period == other.reset_period && budget_processing_period_start_offset == other.budget_processing_period_start_offset && processing_period_type == other.processing_period_type && target_type == other.target_type && targets == other.targets && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 |
# File 'lib/oci/budget/models/create_budget_details.rb', line 296 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
276 277 278 |
# File 'lib/oci/budget/models/create_budget_details.rb', line 276 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
285 286 287 |
# File 'lib/oci/budget/models/create_budget_details.rb', line 285 def hash [compartment_id, target_compartment_id, display_name, description, amount, reset_period, budget_processing_period_start_offset, processing_period_type, target_type, targets, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
329 330 331 332 333 334 335 336 337 338 |
# File 'lib/oci/budget/models/create_budget_details.rb', line 329 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
323 324 325 |
# File 'lib/oci/budget/models/create_budget_details.rb', line 323 def to_s to_hash.to_s end |