Class: OCI::Budget::Models::UpdateBudgetDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/budget/models/update_budget_details.rb

Overview

The update budget details.

Constant Summary collapse

PROCESSING_PERIOD_TYPE_ENUM =
[
  PROCESSING_PERIOD_TYPE_INVOICE = 'INVOICE'.freeze,
  PROCESSING_PERIOD_TYPE_MONTH = 'MONTH'.freeze
].freeze
RESET_PERIOD_ENUM =
[
  RESET_PERIOD_MONTHLY = 'MONTHLY'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateBudgetDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :display_name (String)

    The value to assign to the #display_name property

  • :description (String)

    The value to assign to the #description property

  • :amount (Float)

    The value to assign to the #amount property

  • :budget_processing_period_start_offset (Integer)

    The value to assign to the #budget_processing_period_start_offset property

  • :processing_period_type (String)

    The value to assign to the #processing_period_type property

  • :reset_period (String)

    The value to assign to the #reset_period property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/oci/budget/models/update_budget_details.rb', line 108

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.amount = attributes[:'amount'] if attributes[:'amount']

  self.budget_processing_period_start_offset = attributes[:'budgetProcessingPeriodStartOffset'] if attributes[:'budgetProcessingPeriodStartOffset']

  raise 'You cannot provide both :budgetProcessingPeriodStartOffset and :budget_processing_period_start_offset' if attributes.key?(:'budgetProcessingPeriodStartOffset') && attributes.key?(:'budget_processing_period_start_offset')

  self.budget_processing_period_start_offset = attributes[:'budget_processing_period_start_offset'] if attributes[:'budget_processing_period_start_offset']

  self.processing_period_type = attributes[:'processingPeriodType'] if attributes[:'processingPeriodType']

  raise 'You cannot provide both :processingPeriodType and :processing_period_type' if attributes.key?(:'processingPeriodType') && attributes.key?(:'processing_period_type')

  self.processing_period_type = attributes[:'processing_period_type'] if attributes[:'processing_period_type']

  self.reset_period = attributes[:'resetPeriod'] if attributes[:'resetPeriod']

  raise 'You cannot provide both :resetPeriod and :reset_period' if attributes.key?(:'resetPeriod') && attributes.key?(:'reset_period')

  self.reset_period = attributes[:'reset_period'] if attributes[:'reset_period']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#amountFloat

The amount of the budget expressed as a whole number in the currency of the customer's rate card.

Returns:

  • (Float)


30
31
32
# File 'lib/oci/budget/models/update_budget_details.rb', line 30

def amount
  @amount
end

#budget_processing_period_start_offsetInteger

The number of days offset from the first day of the month, at which the budget processing period starts. In months that have fewer days than this value, processing will begin on the last day of that month. For example, for a value of 12, processing starts every month on the 12th at midnight.

Returns:

  • (Integer)


34
35
36
# File 'lib/oci/budget/models/update_budget_details.rb', line 34

def budget_processing_period_start_offset
  @budget_processing_period_start_offset
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: `{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


60
61
62
# File 'lib/oci/budget/models/update_budget_details.rb', line 60

def defined_tags
  @defined_tags
end

#descriptionString

The description of the budget.

Returns:

  • (String)


25
26
27
# File 'lib/oci/budget/models/update_budget_details.rb', line 25

def description
  @description
end

#display_nameString

The displayName of the budget. Avoid entering confidential information.

Returns:

  • (String)


21
22
23
# File 'lib/oci/budget/models/update_budget_details.rb', line 21

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: `"Finance"`

Returns:

  • (Hash<String, String>)


52
53
54
# File 'lib/oci/budget/models/update_budget_details.rb', line 52

def freeform_tags
  @freeform_tags
end

#processing_period_typeString

The type of the budget processing period. Valid values are INVOICE and MONTH.

Returns:

  • (String)


39
40
41
# File 'lib/oci/budget/models/update_budget_details.rb', line 39

def processing_period_type
  @processing_period_type
end

#reset_periodString

The reset period for the budget.

Returns:

  • (String)


44
45
46
# File 'lib/oci/budget/models/update_budget_details.rb', line 44

def reset_period
  @reset_period
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/oci/budget/models/update_budget_details.rb', line 63

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'displayName',
    'description': :'description',
    'amount': :'amount',
    'budget_processing_period_start_offset': :'budgetProcessingPeriodStartOffset',
    'processing_period_type': :'processingPeriodType',
    'reset_period': :'resetPeriod',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/oci/budget/models/update_budget_details.rb', line 79

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'String',
    'description': :'String',
    'amount': :'Float',
    'budget_processing_period_start_offset': :'Integer',
    'processing_period_type': :'String',
    'reset_period': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/oci/budget/models/update_budget_details.rb', line 178

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    display_name == other.display_name &&
    description == other.description &&
    amount == other.amount &&
    budget_processing_period_start_offset == other.budget_processing_period_start_offset &&
    processing_period_type == other.processing_period_type &&
    reset_period == other.reset_period &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/oci/budget/models/update_budget_details.rb', line 215

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


195
196
197
# File 'lib/oci/budget/models/update_budget_details.rb', line 195

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



204
205
206
# File 'lib/oci/budget/models/update_budget_details.rb', line 204

def hash
  [display_name, description, amount, budget_processing_period_start_offset, processing_period_type, reset_period, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



248
249
250
251
252
253
254
255
256
257
# File 'lib/oci/budget/models/update_budget_details.rb', line 248

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



242
243
244
# File 'lib/oci/budget/models/update_budget_details.rb', line 242

def to_s
  to_hash.to_s
end