Class: OCI::Certificates::Models::CertificateBundlePublicOnly
- Inherits:
-
CertificateBundle
- Object
- CertificateBundle
- OCI::Certificates::Models::CertificateBundlePublicOnly
- Defined in:
- lib/oci/certificates/models/certificate_bundle_public_only.rb
Overview
A certificate bundle, not including the private key.
Constant Summary
Constants inherited from CertificateBundle
OCI::Certificates::Models::CertificateBundle::CERTIFICATE_BUNDLE_TYPE_ENUM, OCI::Certificates::Models::CertificateBundle::STAGES_ENUM
Instance Attribute Summary
Attributes inherited from CertificateBundle
#cert_chain_pem, #certificate_bundle_type, #certificate_id, #certificate_name, #certificate_pem, #revocation_status, #serial_number, #stages, #time_created, #validity, #version_name, #version_number
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CertificateBundlePublicOnly
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from CertificateBundle
Constructor Details
#initialize(attributes = {}) ⇒ CertificateBundlePublicOnly
Initializes the object
68 69 70 71 72 73 74 |
# File 'lib/oci/certificates/models/certificate_bundle_public_only.rb', line 68 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['certificateBundleType'] = 'CERTIFICATE_CONTENT_PUBLIC_ONLY' super(attributes) end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 |
# File 'lib/oci/certificates/models/certificate_bundle_public_only.rb', line 12 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'certificate_bundle_type': :'certificateBundleType', 'certificate_id': :'certificateId', 'certificate_name': :'certificateName', 'version_number': :'versionNumber', 'serial_number': :'serialNumber', 'certificate_pem': :'certificatePem', 'cert_chain_pem': :'certChainPem', 'time_created': :'timeCreated', 'validity': :'validity', 'version_name': :'versionName', 'stages': :'stages', 'revocation_status': :'revocationStatus' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 |
# File 'lib/oci/certificates/models/certificate_bundle_public_only.rb', line 32 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'certificate_bundle_type': :'String', 'certificate_id': :'String', 'certificate_name': :'String', 'version_number': :'Integer', 'serial_number': :'String', 'certificate_pem': :'String', 'cert_chain_pem': :'String', 'time_created': :'DateTime', 'validity': :'OCI::Certificates::Models::Validity', 'version_name': :'String', 'stages': :'Array<String>', 'revocation_status': :'OCI::Certificates::Models::RevocationStatus' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/oci/certificates/models/certificate_bundle_public_only.rb', line 83 def ==(other) return true if equal?(other) self.class == other.class && certificate_bundle_type == other.certificate_bundle_type && certificate_id == other.certificate_id && certificate_name == other.certificate_name && version_number == other.version_number && serial_number == other.serial_number && certificate_pem == other.certificate_pem && cert_chain_pem == other.cert_chain_pem && time_created == other.time_created && validity == other.validity && version_name == other.version_name && stages == other.stages && revocation_status == other.revocation_status end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/oci/certificates/models/certificate_bundle_public_only.rb', line 124 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
104 105 106 |
# File 'lib/oci/certificates/models/certificate_bundle_public_only.rb', line 104 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
113 114 115 |
# File 'lib/oci/certificates/models/certificate_bundle_public_only.rb', line 113 def hash [certificate_bundle_type, certificate_id, certificate_name, version_number, serial_number, certificate_pem, cert_chain_pem, time_created, validity, version_name, stages, revocation_status].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
157 158 159 160 161 162 163 164 165 166 |
# File 'lib/oci/certificates/models/certificate_bundle_public_only.rb', line 157 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
151 152 153 |
# File 'lib/oci/certificates/models/certificate_bundle_public_only.rb', line 151 def to_s to_hash.to_s end |