Class: OCI::CertificatesManagement::Models::AssociationSummary
- Inherits:
-
Object
- Object
- OCI::CertificatesManagement::Models::AssociationSummary
- Defined in:
- lib/oci/certificates_management/models/association_summary.rb
Overview
The details of the association.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- ASSOCIATION_TYPE_ENUM =
[ ASSOCIATION_TYPE_CERTIFICATE = 'CERTIFICATE'.freeze, ASSOCIATION_TYPE_CERTIFICATE_AUTHORITY = 'CERTIFICATE_AUTHORITY'.freeze, ASSOCIATION_TYPE_CA_BUNDLE = 'CA_BUNDLE'.freeze, ASSOCIATION_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#associated_resource_id ⇒ String
**[Required]** The OCID of the associated resource.
-
#association_type ⇒ String
**[Required]** Type of the association.
-
#certificates_resource_id ⇒ String
**[Required]** The OCID of the certificate-related resource associated with another Oracle Cloud Infrastructure resource.
-
#compartment_id ⇒ String
**[Required]** The compartment OCID of the association.
-
#id ⇒ String
**[Required]** The OCID of the association.
-
#lifecycle_state ⇒ String
**[Required]** The current lifecycle state of the association.
-
#name ⇒ String
**[Required]** A user-friendly name generated by the service for the association.
-
#time_created ⇒ DateTime
**[Required]** A property indicating when the association was created, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AssociationSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ AssociationSummary
Initializes the object
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/oci/certificates_management/models/association_summary.rb', line 107 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.name = attributes[:'name'] if attributes[:'name'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.certificates_resource_id = attributes[:'certificatesResourceId'] if attributes[:'certificatesResourceId'] raise 'You cannot provide both :certificatesResourceId and :certificates_resource_id' if attributes.key?(:'certificatesResourceId') && attributes.key?(:'certificates_resource_id') self.certificates_resource_id = attributes[:'certificates_resource_id'] if attributes[:'certificates_resource_id'] self.associated_resource_id = attributes[:'associatedResourceId'] if attributes[:'associatedResourceId'] raise 'You cannot provide both :associatedResourceId and :associated_resource_id' if attributes.key?(:'associatedResourceId') && attributes.key?(:'associated_resource_id') self.associated_resource_id = attributes[:'associated_resource_id'] if attributes[:'associated_resource_id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.association_type = attributes[:'associationType'] if attributes[:'associationType'] raise 'You cannot provide both :associationType and :association_type' if attributes.key?(:'associationType') && attributes.key?(:'association_type') self.association_type = attributes[:'association_type'] if attributes[:'association_type'] end |
Instance Attribute Details
#associated_resource_id ⇒ String
**[Required]** The OCID of the associated resource.
51 52 53 |
# File 'lib/oci/certificates_management/models/association_summary.rb', line 51 def associated_resource_id @associated_resource_id end |
#association_type ⇒ String
**[Required]** Type of the association.
59 60 61 |
# File 'lib/oci/certificates_management/models/association_summary.rb', line 59 def association_type @association_type end |
#certificates_resource_id ⇒ String
**[Required]** The OCID of the certificate-related resource associated with another Oracle Cloud Infrastructure resource.
47 48 49 |
# File 'lib/oci/certificates_management/models/association_summary.rb', line 47 def certificates_resource_id @certificates_resource_id end |
#compartment_id ⇒ String
**[Required]** The compartment OCID of the association. This is strongly tied to the compartment OCID of the certificate-related resource.
55 56 57 |
# File 'lib/oci/certificates_management/models/association_summary.rb', line 55 def compartment_id @compartment_id end |
#id ⇒ String
**[Required]** The OCID of the association.
29 30 31 |
# File 'lib/oci/certificates_management/models/association_summary.rb', line 29 def id @id end |
#lifecycle_state ⇒ String
**[Required]** The current lifecycle state of the association.
43 44 45 |
# File 'lib/oci/certificates_management/models/association_summary.rb', line 43 def lifecycle_state @lifecycle_state end |
#name ⇒ String
**[Required]** A user-friendly name generated by the service for the association. Name format follows the pattern [certificatesResourceEntityType]--UUID.
33 34 35 |
# File 'lib/oci/certificates_management/models/association_summary.rb', line 33 def name @name end |
#time_created ⇒ DateTime
**[Required]** A property indicating when the association was created, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format. Example: `2019-04-03T21:10:29.600Z`
39 40 41 |
# File 'lib/oci/certificates_management/models/association_summary.rb', line 39 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/oci/certificates_management/models/association_summary.rb', line 62 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'name': :'name', 'time_created': :'timeCreated', 'lifecycle_state': :'lifecycleState', 'certificates_resource_id': :'certificatesResourceId', 'associated_resource_id': :'associatedResourceId', 'compartment_id': :'compartmentId', 'association_type': :'associationType' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/oci/certificates_management/models/association_summary.rb', line 78 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'name': :'String', 'time_created': :'DateTime', 'lifecycle_state': :'String', 'certificates_resource_id': :'String', 'associated_resource_id': :'String', 'compartment_id': :'String', 'association_type': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/oci/certificates_management/models/association_summary.rb', line 187 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && name == other.name && time_created == other.time_created && lifecycle_state == other.lifecycle_state && certificates_resource_id == other.certificates_resource_id && associated_resource_id == other.associated_resource_id && compartment_id == other.compartment_id && association_type == other.association_type end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 |
# File 'lib/oci/certificates_management/models/association_summary.rb', line 224 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
204 205 206 |
# File 'lib/oci/certificates_management/models/association_summary.rb', line 204 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
213 214 215 |
# File 'lib/oci/certificates_management/models/association_summary.rb', line 213 def hash [id, name, time_created, lifecycle_state, certificates_resource_id, associated_resource_id, compartment_id, association_type].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
257 258 259 260 261 262 263 264 265 266 |
# File 'lib/oci/certificates_management/models/association_summary.rb', line 257 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
251 252 253 |
# File 'lib/oci/certificates_management/models/association_summary.rb', line 251 def to_s to_hash.to_s end |