Class: OCI::CertificatesManagement::Models::CertificateAuthorityRule
- Inherits:
-
Object
- Object
- OCI::CertificatesManagement::Models::CertificateAuthorityRule
- Defined in:
- lib/oci/certificates_management/models/certificate_authority_rule.rb
Overview
A rule that you can apply to a certificate authority (CA) to enforce certain conditions on its usage and management. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
Constant Summary collapse
- RULE_TYPE_ENUM =
[ RULE_TYPE_CERTIFICATE_AUTHORITY_ISSUANCE_EXPIRY_RULE = 'CERTIFICATE_AUTHORITY_ISSUANCE_EXPIRY_RULE'.freeze, RULE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#rule_type ⇒ String
**[Required]** The type of rule, whether a renewal rule regarding when to renew the CA or an issuance expiry rule that governs how long the certificates and CAs issued by the CA are valid.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CertificateAuthorityRule
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CertificateAuthorityRule
Initializes the object
62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/oci/certificates_management/models/certificate_authority_rule.rb', line 62 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.rule_type = attributes[:'ruleType'] if attributes[:'ruleType'] raise 'You cannot provide both :ruleType and :rule_type' if attributes.key?(:'ruleType') && attributes.key?(:'rule_type') self.rule_type = attributes[:'rule_type'] if attributes[:'rule_type'] end |
Instance Attribute Details
#rule_type ⇒ String
**[Required]** The type of rule, whether a renewal rule regarding when to renew the CA or an issuance expiry rule that governs how long the certificates and CAs issued by the CA are valid. (For internal use only) An internal issuance rule defines the number and type of certificates that the CA can issue.
20 21 22 |
# File 'lib/oci/certificates_management/models/certificate_authority_rule.rb', line 20 def rule_type @rule_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
23 24 25 26 27 28 29 |
# File 'lib/oci/certificates_management/models/certificate_authority_rule.rb', line 23 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'rule_type': :'ruleType' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
45 46 47 48 49 50 51 52 |
# File 'lib/oci/certificates_management/models/certificate_authority_rule.rb', line 45 def self.get_subtype(object_hash) type = object_hash[:'ruleType'] # rubocop:disable Style/SymbolLiteral return 'OCI::CertificatesManagement::Models::CertificateAuthorityIssuanceExpiryRule' if type == 'CERTIFICATE_AUTHORITY_ISSUANCE_EXPIRY_RULE' # TODO: Log a warning when the subtype is not found. 'OCI::CertificatesManagement::Models::CertificateAuthorityRule' end |
.swagger_types ⇒ Object
Attribute type mapping.
32 33 34 35 36 37 38 |
# File 'lib/oci/certificates_management/models/certificate_authority_rule.rb', line 32 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'rule_type': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
95 96 97 98 99 100 |
# File 'lib/oci/certificates_management/models/certificate_authority_rule.rb', line 95 def ==(other) return true if equal?(other) self.class == other.class && rule_type == other.rule_type end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/oci/certificates_management/models/certificate_authority_rule.rb', line 125 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
105 106 107 |
# File 'lib/oci/certificates_management/models/certificate_authority_rule.rb', line 105 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
114 115 116 |
# File 'lib/oci/certificates_management/models/certificate_authority_rule.rb', line 114 def hash [rule_type].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
158 159 160 161 162 163 164 165 166 167 |
# File 'lib/oci/certificates_management/models/certificate_authority_rule.rb', line 158 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
152 153 154 |
# File 'lib/oci/certificates_management/models/certificate_authority_rule.rb', line 152 def to_s to_hash.to_s end |