Class: OCI::CertificatesManagement::Models::CertificateAuthoritySummary
- Inherits:
-
Object
- Object
- OCI::CertificatesManagement::Models::CertificateAuthoritySummary
- Defined in:
- lib/oci/certificates_management/models/certificate_authority_summary.rb
Overview
The metadata details of the certificate authority (CA). This summary object does not contain the CA contents.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_SCHEDULING_DELETION = 'SCHEDULING_DELETION'.freeze, LIFECYCLE_STATE_PENDING_DELETION = 'PENDING_DELETION'.freeze, LIFECYCLE_STATE_CANCELLING_DELETION = 'CANCELLING_DELETION'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- CONFIG_TYPE_ENUM =
[ CONFIG_TYPE_ROOT_CA_GENERATED_INTERNALLY = 'ROOT_CA_GENERATED_INTERNALLY'.freeze, CONFIG_TYPE_SUBORDINATE_CA_ISSUED_BY_INTERNAL_CA = 'SUBORDINATE_CA_ISSUED_BY_INTERNAL_CA'.freeze, CONFIG_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- SIGNING_ALGORITHM_ENUM =
[ SIGNING_ALGORITHM_SHA256_WITH_RSA = 'SHA256_WITH_RSA'.freeze, SIGNING_ALGORITHM_SHA384_WITH_RSA = 'SHA384_WITH_RSA'.freeze, SIGNING_ALGORITHM_SHA512_WITH_RSA = 'SHA512_WITH_RSA'.freeze, SIGNING_ALGORITHM_SHA256_WITH_ECDSA = 'SHA256_WITH_ECDSA'.freeze, SIGNING_ALGORITHM_SHA384_WITH_ECDSA = 'SHA384_WITH_ECDSA'.freeze, SIGNING_ALGORITHM_SHA512_WITH_ECDSA = 'SHA512_WITH_ECDSA'.freeze, SIGNING_ALGORITHM_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#certificate_authority_rules ⇒ Array<OCI::CertificatesManagement::Models::CertificateAuthorityRule>
An optional list of rules that control how the CA is used and managed.
-
#compartment_id ⇒ String
**[Required]** The OCID of the compartment under which the CA is created.
-
#config_type ⇒ String
**[Required]** The origin of the CA.
- #current_version_summary ⇒ OCI::CertificatesManagement::Models::CertificateAuthorityVersionSummary
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Usage of predefined tag keys.
-
#description ⇒ String
A brief description of the CA.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
**[Required]** The OCID of the certificate authority (CA).
-
#issuer_certificate_authority_id ⇒ String
The OCID of the parent CA which issued this CA.
-
#kms_key_id ⇒ String
The OCID of the Oracle Cloud Infrastructure Vault key used to encrypt the CA.
-
#lifecycle_state ⇒ String
**[Required]** The current lifecycle state of the CA.
-
#name ⇒ String
**[Required]** A user-friendly name for the CA.
-
#signing_algorithm ⇒ String
The algorithm used to sign public key certificates that the CA issues.
- #subject ⇒ OCI::CertificatesManagement::Models::CertificateSubject
-
#time_created ⇒ DateTime
**[Required]** A property indicating when the CA was created, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.
-
#time_of_deletion ⇒ DateTime
An optional property indicating when to delete the CA version, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CertificateAuthoritySummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CertificateAuthoritySummary
Initializes the object
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'lib/oci/certificates_management/models/certificate_authority_summary.rb', line 181 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self. = attributes[:'issuerCertificateAuthorityId'] if attributes[:'issuerCertificateAuthorityId'] raise 'You cannot provide both :issuerCertificateAuthorityId and :issuer_certificate_authority_id' if attributes.key?(:'issuerCertificateAuthorityId') && attributes.key?(:'issuer_certificate_authority_id') self. = attributes[:'issuer_certificate_authority_id'] if attributes[:'issuer_certificate_authority_id'] self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.description = "null" if description.nil? && !attributes.key?(:'description') # rubocop:disable Style/StringLiterals self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_of_deletion = attributes[:'timeOfDeletion'] if attributes[:'timeOfDeletion'] raise 'You cannot provide both :timeOfDeletion and :time_of_deletion' if attributes.key?(:'timeOfDeletion') && attributes.key?(:'time_of_deletion') self.time_of_deletion = attributes[:'time_of_deletion'] if attributes[:'time_of_deletion'] self.kms_key_id = attributes[:'kmsKeyId'] if attributes[:'kmsKeyId'] raise 'You cannot provide both :kmsKeyId and :kms_key_id' if attributes.key?(:'kmsKeyId') && attributes.key?(:'kms_key_id') self.kms_key_id = attributes[:'kms_key_id'] if attributes[:'kms_key_id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self. = attributes[:'certificateAuthorityRules'] if attributes[:'certificateAuthorityRules'] raise 'You cannot provide both :certificateAuthorityRules and :certificate_authority_rules' if attributes.key?(:'certificateAuthorityRules') && attributes.key?(:'certificate_authority_rules') self. = attributes[:'certificate_authority_rules'] if attributes[:'certificate_authority_rules'] self.current_version_summary = attributes[:'currentVersionSummary'] if attributes[:'currentVersionSummary'] raise 'You cannot provide both :currentVersionSummary and :current_version_summary' if attributes.key?(:'currentVersionSummary') && attributes.key?(:'current_version_summary') self.current_version_summary = attributes[:'current_version_summary'] if attributes[:'current_version_summary'] self.subject = attributes[:'subject'] if attributes[:'subject'] self.config_type = attributes[:'configType'] if attributes[:'configType'] raise 'You cannot provide both :configType and :config_type' if attributes.key?(:'configType') && attributes.key?(:'config_type') self.config_type = attributes[:'config_type'] if attributes[:'config_type'] self.signing_algorithm = attributes[:'signingAlgorithm'] if attributes[:'signingAlgorithm'] raise 'You cannot provide both :signingAlgorithm and :signing_algorithm' if attributes.key?(:'signingAlgorithm') && attributes.key?(:'signing_algorithm') self.signing_algorithm = attributes[:'signing_algorithm'] if attributes[:'signing_algorithm'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#certificate_authority_rules ⇒ Array<OCI::CertificatesManagement::Models::CertificateAuthorityRule>
An optional list of rules that control how the CA is used and managed.
83 84 85 |
# File 'lib/oci/certificates_management/models/certificate_authority_summary.rb', line 83 def @certificate_authority_rules end |
#compartment_id ⇒ String
**[Required]** The OCID of the compartment under which the CA is created.
79 80 81 |
# File 'lib/oci/certificates_management/models/certificate_authority_summary.rb', line 79 def compartment_id @compartment_id end |
#config_type ⇒ String
**[Required]** The origin of the CA.
93 94 95 |
# File 'lib/oci/certificates_management/models/certificate_authority_summary.rb', line 93 def config_type @config_type end |
#current_version_summary ⇒ OCI::CertificatesManagement::Models::CertificateAuthorityVersionSummary
86 87 88 |
# File 'lib/oci/certificates_management/models/certificate_authority_summary.rb', line 86 def current_version_summary @current_version_summary end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Usage of predefined tag keys. These predefined keys are scoped to namespaces. Example: `{"bar-key": "value"}`
109 110 111 |
# File 'lib/oci/certificates_management/models/certificate_authority_summary.rb', line 109 def @defined_tags end |
#description ⇒ String
A brief description of the CA.
55 56 57 |
# File 'lib/oci/certificates_management/models/certificate_authority_summary.rb', line 55 def description @description end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
103 104 105 |
# File 'lib/oci/certificates_management/models/certificate_authority_summary.rb', line 103 def @freeform_tags end |
#id ⇒ String
**[Required]** The OCID of the certificate authority (CA).
42 43 44 |
# File 'lib/oci/certificates_management/models/certificate_authority_summary.rb', line 42 def id @id end |
#issuer_certificate_authority_id ⇒ String
The OCID of the parent CA which issued this CA. If this is the root CA, then this value is the same as the `id`.
47 48 49 |
# File 'lib/oci/certificates_management/models/certificate_authority_summary.rb', line 47 def @issuer_certificate_authority_id end |
#kms_key_id ⇒ String
The OCID of the Oracle Cloud Infrastructure Vault key used to encrypt the CA.
71 72 73 |
# File 'lib/oci/certificates_management/models/certificate_authority_summary.rb', line 71 def kms_key_id @kms_key_id end |
#lifecycle_state ⇒ String
**[Required]** The current lifecycle state of the CA.
75 76 77 |
# File 'lib/oci/certificates_management/models/certificate_authority_summary.rb', line 75 def lifecycle_state @lifecycle_state end |
#name ⇒ String
**[Required]** A user-friendly name for the CA. Names are unique within a compartment. Avoid entering confidential information. Valid characters include uppercase or lowercase letters, numbers, hyphens, underscores, and periods.
51 52 53 |
# File 'lib/oci/certificates_management/models/certificate_authority_summary.rb', line 51 def name @name end |
#signing_algorithm ⇒ String
The algorithm used to sign public key certificates that the CA issues.
97 98 99 |
# File 'lib/oci/certificates_management/models/certificate_authority_summary.rb', line 97 def signing_algorithm @signing_algorithm end |
#subject ⇒ OCI::CertificatesManagement::Models::CertificateSubject
89 90 91 |
# File 'lib/oci/certificates_management/models/certificate_authority_summary.rb', line 89 def subject @subject end |
#time_created ⇒ DateTime
**[Required]** A property indicating when the CA was created, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format. Example: `2019-04-03T21:10:29.600Z`
61 62 63 |
# File 'lib/oci/certificates_management/models/certificate_authority_summary.rb', line 61 def time_created @time_created end |
#time_of_deletion ⇒ DateTime
An optional property indicating when to delete the CA version, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format. Example: `2019-04-03T21:10:29.600Z`
67 68 69 |
# File 'lib/oci/certificates_management/models/certificate_authority_summary.rb', line 67 def time_of_deletion @time_of_deletion end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/oci/certificates_management/models/certificate_authority_summary.rb', line 112 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'issuer_certificate_authority_id': :'issuerCertificateAuthorityId', 'name': :'name', 'description': :'description', 'time_created': :'timeCreated', 'time_of_deletion': :'timeOfDeletion', 'kms_key_id': :'kmsKeyId', 'lifecycle_state': :'lifecycleState', 'compartment_id': :'compartmentId', 'certificate_authority_rules': :'certificateAuthorityRules', 'current_version_summary': :'currentVersionSummary', 'subject': :'subject', 'config_type': :'configType', 'signing_algorithm': :'signingAlgorithm', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/oci/certificates_management/models/certificate_authority_summary.rb', line 136 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'issuer_certificate_authority_id': :'String', 'name': :'String', 'description': :'String', 'time_created': :'DateTime', 'time_of_deletion': :'DateTime', 'kms_key_id': :'String', 'lifecycle_state': :'String', 'compartment_id': :'String', 'certificate_authority_rules': :'Array<OCI::CertificatesManagement::Models::CertificateAuthorityRule>', 'current_version_summary': :'OCI::CertificatesManagement::Models::CertificateAuthorityVersionSummary', 'subject': :'OCI::CertificatesManagement::Models::CertificateSubject', 'config_type': :'String', 'signing_algorithm': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'lib/oci/certificates_management/models/certificate_authority_summary.rb', line 315 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && == other. && name == other.name && description == other.description && time_created == other.time_created && time_of_deletion == other.time_of_deletion && kms_key_id == other.kms_key_id && lifecycle_state == other.lifecycle_state && compartment_id == other.compartment_id && == other. && current_version_summary == other.current_version_summary && subject == other.subject && config_type == other.config_type && signing_algorithm == other.signing_algorithm && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 |
# File 'lib/oci/certificates_management/models/certificate_authority_summary.rb', line 360 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
340 341 342 |
# File 'lib/oci/certificates_management/models/certificate_authority_summary.rb', line 340 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
349 350 351 |
# File 'lib/oci/certificates_management/models/certificate_authority_summary.rb', line 349 def hash [id, , name, description, time_created, time_of_deletion, kms_key_id, lifecycle_state, compartment_id, , current_version_summary, subject, config_type, signing_algorithm, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
393 394 395 396 397 398 399 400 401 402 |
# File 'lib/oci/certificates_management/models/certificate_authority_summary.rb', line 393 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
387 388 389 |
# File 'lib/oci/certificates_management/models/certificate_authority_summary.rb', line 387 def to_s to_hash.to_s end |