Class: OCI::CertificatesManagement::Models::CertificateAuthorityVersionSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/certificates_management/models/certificate_authority_version_summary.rb

Overview

The metadata details of the certificate authority (CA) version. This summary object does not contain the CA contents.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CertificateAuthorityVersionSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/oci/certificates_management/models/certificate_authority_version_summary.rb', line 107

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.certificate_authority_id = attributes[:'certificateAuthorityId'] if attributes[:'certificateAuthorityId']

  raise 'You cannot provide both :certificateAuthorityId and :certificate_authority_id' if attributes.key?(:'certificateAuthorityId') && attributes.key?(:'certificate_authority_id')

  self.certificate_authority_id = attributes[:'certificate_authority_id'] if attributes[:'certificate_authority_id']

  self.issuer_ca_version_number = attributes[:'issuerCaVersionNumber'] if attributes[:'issuerCaVersionNumber']

  raise 'You cannot provide both :issuerCaVersionNumber and :issuer_ca_version_number' if attributes.key?(:'issuerCaVersionNumber') && attributes.key?(:'issuer_ca_version_number')

  self.issuer_ca_version_number = attributes[:'issuer_ca_version_number'] if attributes[:'issuer_ca_version_number']

  self.serial_number = attributes[:'serialNumber'] if attributes[:'serialNumber']

  raise 'You cannot provide both :serialNumber and :serial_number' if attributes.key?(:'serialNumber') && attributes.key?(:'serial_number')

  self.serial_number = attributes[:'serial_number'] if attributes[:'serial_number']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.version_number = attributes[:'versionNumber'] if attributes[:'versionNumber']

  raise 'You cannot provide both :versionNumber and :version_number' if attributes.key?(:'versionNumber') && attributes.key?(:'version_number')

  self.version_number = attributes[:'version_number'] if attributes[:'version_number']

  self.version_name = attributes[:'versionName'] if attributes[:'versionName']
  self.version_name = "null" if version_name.nil? && !attributes.key?(:'versionName') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :versionName and :version_name' if attributes.key?(:'versionName') && attributes.key?(:'version_name')

  self.version_name = attributes[:'version_name'] if attributes[:'version_name']
  self.version_name = "null" if version_name.nil? && !attributes.key?(:'versionName') && !attributes.key?(:'version_name') # rubocop:disable Style/StringLiterals

  self.time_of_deletion = attributes[:'timeOfDeletion'] if attributes[:'timeOfDeletion']

  raise 'You cannot provide both :timeOfDeletion and :time_of_deletion' if attributes.key?(:'timeOfDeletion') && attributes.key?(:'time_of_deletion')

  self.time_of_deletion = attributes[:'time_of_deletion'] if attributes[:'time_of_deletion']

  self.validity = attributes[:'validity'] if attributes[:'validity']

  self.stages = attributes[:'stages'] if attributes[:'stages']

  self.revocation_status = attributes[:'revocationStatus'] if attributes[:'revocationStatus']

  raise 'You cannot provide both :revocationStatus and :revocation_status' if attributes.key?(:'revocationStatus') && attributes.key?(:'revocation_status')

  self.revocation_status = attributes[:'revocation_status'] if attributes[:'revocation_status']
end

Instance Attribute Details

#certificate_authority_idString

**[Required]** The OCID of the CA.

Returns:

  • (String)


12
13
14
# File 'lib/oci/certificates_management/models/certificate_authority_version_summary.rb', line 12

def certificate_authority_id
  @certificate_authority_id
end

#issuer_ca_version_numberInteger

The version number of the issuing CA.

Returns:

  • (Integer)


16
17
18
# File 'lib/oci/certificates_management/models/certificate_authority_version_summary.rb', line 16

def issuer_ca_version_number
  @issuer_ca_version_number
end

#revocation_statusOCI::CertificatesManagement::Models::RevocationStatus



53
54
55
# File 'lib/oci/certificates_management/models/certificate_authority_version_summary.rb', line 53

def revocation_status
  @revocation_status
end

#serial_numberString

A unique certificate identifier used in certificate revocation tracking, formatted as octets. Example: `03 AC FC FA CC B3 CB 02 B8 F8 DE F5 85 E7 7B FF`

Returns:

  • (String)


22
23
24
# File 'lib/oci/certificates_management/models/certificate_authority_version_summary.rb', line 22

def serial_number
  @serial_number
end

#stagesArray<OCI::CertificatesManagement::Models::VersionStage>

**[Required]** A list of rotation states for this CA version.

Returns:

  • (Array<OCI::CertificatesManagement::Models::VersionStage>)


50
51
52
# File 'lib/oci/certificates_management/models/certificate_authority_version_summary.rb', line 50

def stages
  @stages
end

#time_createdDateTime

**[Required]** A optional property indicating when the CA version was created, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format. Example: `2019-04-03T21:10:29.600Z`

Returns:

  • (DateTime)


28
29
30
# File 'lib/oci/certificates_management/models/certificate_authority_version_summary.rb', line 28

def time_created
  @time_created
end

#time_of_deletionDateTime

An optional property indicating when to delete the CA version, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format. Example: `2019-04-03T21:10:29.600Z`

Returns:

  • (DateTime)


43
44
45
# File 'lib/oci/certificates_management/models/certificate_authority_version_summary.rb', line 43

def time_of_deletion
  @time_of_deletion
end

#validityOCI::CertificatesManagement::Models::Validity

Returns:

  • (OCI::CertificatesManagement::Models::Validity)


46
47
48
# File 'lib/oci/certificates_management/models/certificate_authority_version_summary.rb', line 46

def validity
  @validity
end

#version_nameString

The name of the CA version. When this value is not null, the name is unique across CA versions for a given CA.

Returns:

  • (String)


37
38
39
# File 'lib/oci/certificates_management/models/certificate_authority_version_summary.rb', line 37

def version_name
  @version_name
end

#version_numberInteger

**[Required]** The version number of the CA.

Returns:

  • (Integer)


32
33
34
# File 'lib/oci/certificates_management/models/certificate_authority_version_summary.rb', line 32

def version_number
  @version_number
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/oci/certificates_management/models/certificate_authority_version_summary.rb', line 56

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'certificate_authority_id': :'certificateAuthorityId',
    'issuer_ca_version_number': :'issuerCaVersionNumber',
    'serial_number': :'serialNumber',
    'time_created': :'timeCreated',
    'version_number': :'versionNumber',
    'version_name': :'versionName',
    'time_of_deletion': :'timeOfDeletion',
    'validity': :'validity',
    'stages': :'stages',
    'revocation_status': :'revocationStatus'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/oci/certificates_management/models/certificate_authority_version_summary.rb', line 74

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'certificate_authority_id': :'String',
    'issuer_ca_version_number': :'Integer',
    'serial_number': :'String',
    'time_created': :'DateTime',
    'version_number': :'Integer',
    'version_name': :'String',
    'time_of_deletion': :'DateTime',
    'validity': :'OCI::CertificatesManagement::Models::Validity',
    'stages': :'Array<OCI::CertificatesManagement::Models::VersionStage>',
    'revocation_status': :'OCI::CertificatesManagement::Models::RevocationStatus'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/oci/certificates_management/models/certificate_authority_version_summary.rb', line 175

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    certificate_authority_id == other.certificate_authority_id &&
    issuer_ca_version_number == other.issuer_ca_version_number &&
    serial_number == other.serial_number &&
    time_created == other.time_created &&
    version_number == other.version_number &&
    version_name == other.version_name &&
    time_of_deletion == other.time_of_deletion &&
    validity == other.validity &&
    stages == other.stages &&
    revocation_status == other.revocation_status
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/oci/certificates_management/models/certificate_authority_version_summary.rb', line 214

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


194
195
196
# File 'lib/oci/certificates_management/models/certificate_authority_version_summary.rb', line 194

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



203
204
205
# File 'lib/oci/certificates_management/models/certificate_authority_version_summary.rb', line 203

def hash
  [certificate_authority_id, issuer_ca_version_number, serial_number, time_created, version_number, version_name, time_of_deletion, validity, stages, revocation_status].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



247
248
249
250
251
252
253
254
255
256
# File 'lib/oci/certificates_management/models/certificate_authority_version_summary.rb', line 247

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



241
242
243
# File 'lib/oci/certificates_management/models/certificate_authority_version_summary.rb', line 241

def to_s
  to_hash.to_s
end