Class: OCI::CertificatesManagement::Models::CertificateSummary
- Inherits:
-
Object
- Object
- OCI::CertificatesManagement::Models::CertificateSummary
- Defined in:
- lib/oci/certificates_management/models/certificate_summary.rb
Overview
The details of the certificate. This object does not contain the certificate contents.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_SCHEDULING_DELETION = 'SCHEDULING_DELETION'.freeze, LIFECYCLE_STATE_PENDING_DELETION = 'PENDING_DELETION'.freeze, LIFECYCLE_STATE_CANCELLING_DELETION = 'CANCELLING_DELETION'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- CONFIG_TYPE_ENUM =
[ CONFIG_TYPE_ISSUED_BY_INTERNAL_CA = 'ISSUED_BY_INTERNAL_CA'.freeze, CONFIG_TYPE_MANAGED_EXTERNALLY_ISSUED_BY_INTERNAL_CA = 'MANAGED_EXTERNALLY_ISSUED_BY_INTERNAL_CA'.freeze, CONFIG_TYPE_IMPORTED = 'IMPORTED'.freeze, CONFIG_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- KEY_ALGORITHM_ENUM =
[ KEY_ALGORITHM_RSA2048 = 'RSA2048'.freeze, KEY_ALGORITHM_RSA4096 = 'RSA4096'.freeze, KEY_ALGORITHM_ECDSA_P256 = 'ECDSA_P256'.freeze, KEY_ALGORITHM_ECDSA_P384 = 'ECDSA_P384'.freeze, KEY_ALGORITHM_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- SIGNATURE_ALGORITHM_ENUM =
[ SIGNATURE_ALGORITHM_SHA256_WITH_RSA = 'SHA256_WITH_RSA'.freeze, SIGNATURE_ALGORITHM_SHA384_WITH_RSA = 'SHA384_WITH_RSA'.freeze, SIGNATURE_ALGORITHM_SHA512_WITH_RSA = 'SHA512_WITH_RSA'.freeze, SIGNATURE_ALGORITHM_SHA256_WITH_ECDSA = 'SHA256_WITH_ECDSA'.freeze, SIGNATURE_ALGORITHM_SHA384_WITH_ECDSA = 'SHA384_WITH_ECDSA'.freeze, SIGNATURE_ALGORITHM_SHA512_WITH_ECDSA = 'SHA512_WITH_ECDSA'.freeze, SIGNATURE_ALGORITHM_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- CERTIFICATE_PROFILE_TYPE_ENUM =
[ CERTIFICATE_PROFILE_TYPE_TLS_SERVER_OR_CLIENT = 'TLS_SERVER_OR_CLIENT'.freeze, CERTIFICATE_PROFILE_TYPE_TLS_SERVER = 'TLS_SERVER'.freeze, CERTIFICATE_PROFILE_TYPE_TLS_CLIENT = 'TLS_CLIENT'.freeze, CERTIFICATE_PROFILE_TYPE_TLS_CODE_SIGN = 'TLS_CODE_SIGN'.freeze, CERTIFICATE_PROFILE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#certificate_profile_type ⇒ String
The name of the profile used to create the certificate, which depends on the type of certificate you need.
-
#certificate_rules ⇒ Array<OCI::CertificatesManagement::Models::CertificateRule>
An optional list of rules that control how the certificate is used and managed.
-
#compartment_id ⇒ String
**[Required]** The OCID of the compartment that contains the certificate.
-
#config_type ⇒ String
**[Required]** The origin of the certificate.
- #current_version_summary ⇒ OCI::CertificatesManagement::Models::CertificateVersionSummary
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
A brief description of the certificate.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
**[Required]** The OCID of the certificate.
-
#issuer_certificate_authority_id ⇒ String
The OCID of the certificate authority (CA) that issued the certificate.
-
#key_algorithm ⇒ String
The algorithm used to create key pairs.
-
#lifecycle_state ⇒ String
**[Required]** The current lifecycle state of the certificate.
-
#name ⇒ String
**[Required]** A user-friendly name for the certificate.
-
#signature_algorithm ⇒ String
The algorithm used to sign the public key certificate.
- #subject ⇒ OCI::CertificatesManagement::Models::CertificateSubject
-
#time_created ⇒ DateTime
**[Required]** A property indicating when the certificate was created, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.
-
#time_of_deletion ⇒ DateTime
An optional property indicating when to delete the certificate version, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CertificateSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CertificateSummary
Initializes the object
206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/oci/certificates_management/models/certificate_summary.rb', line 206 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self. = attributes[:'issuerCertificateAuthorityId'] if attributes[:'issuerCertificateAuthorityId'] raise 'You cannot provide both :issuerCertificateAuthorityId and :issuer_certificate_authority_id' if attributes.key?(:'issuerCertificateAuthorityId') && attributes.key?(:'issuer_certificate_authority_id') self. = attributes[:'issuer_certificate_authority_id'] if attributes[:'issuer_certificate_authority_id'] self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.description = "null" if description.nil? && !attributes.key?(:'description') # rubocop:disable Style/StringLiterals self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_of_deletion = attributes[:'timeOfDeletion'] if attributes[:'timeOfDeletion'] raise 'You cannot provide both :timeOfDeletion and :time_of_deletion' if attributes.key?(:'timeOfDeletion') && attributes.key?(:'time_of_deletion') self.time_of_deletion = attributes[:'time_of_deletion'] if attributes[:'time_of_deletion'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.certificate_rules = attributes[:'certificateRules'] if attributes[:'certificateRules'] raise 'You cannot provide both :certificateRules and :certificate_rules' if attributes.key?(:'certificateRules') && attributes.key?(:'certificate_rules') self.certificate_rules = attributes[:'certificate_rules'] if attributes[:'certificate_rules'] self.current_version_summary = attributes[:'currentVersionSummary'] if attributes[:'currentVersionSummary'] raise 'You cannot provide both :currentVersionSummary and :current_version_summary' if attributes.key?(:'currentVersionSummary') && attributes.key?(:'current_version_summary') self.current_version_summary = attributes[:'current_version_summary'] if attributes[:'current_version_summary'] self.subject = attributes[:'subject'] if attributes[:'subject'] self.config_type = attributes[:'configType'] if attributes[:'configType'] raise 'You cannot provide both :configType and :config_type' if attributes.key?(:'configType') && attributes.key?(:'config_type') self.config_type = attributes[:'config_type'] if attributes[:'config_type'] self.key_algorithm = attributes[:'keyAlgorithm'] if attributes[:'keyAlgorithm'] raise 'You cannot provide both :keyAlgorithm and :key_algorithm' if attributes.key?(:'keyAlgorithm') && attributes.key?(:'key_algorithm') self.key_algorithm = attributes[:'key_algorithm'] if attributes[:'key_algorithm'] self.signature_algorithm = attributes[:'signatureAlgorithm'] if attributes[:'signatureAlgorithm'] raise 'You cannot provide both :signatureAlgorithm and :signature_algorithm' if attributes.key?(:'signatureAlgorithm') && attributes.key?(:'signature_algorithm') self.signature_algorithm = attributes[:'signature_algorithm'] if attributes[:'signature_algorithm'] self.certificate_profile_type = attributes[:'certificateProfileType'] if attributes[:'certificateProfileType'] raise 'You cannot provide both :certificateProfileType and :certificate_profile_type' if attributes.key?(:'certificateProfileType') && attributes.key?(:'certificate_profile_type') self.certificate_profile_type = attributes[:'certificate_profile_type'] if attributes[:'certificate_profile_type'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#certificate_profile_type ⇒ String
The name of the profile used to create the certificate, which depends on the type of certificate you need.
117 118 119 |
# File 'lib/oci/certificates_management/models/certificate_summary.rb', line 117 def certificate_profile_type @certificate_profile_type end |
#certificate_rules ⇒ Array<OCI::CertificatesManagement::Models::CertificateRule>
An optional list of rules that control how the certificate is used and managed.
95 96 97 |
# File 'lib/oci/certificates_management/models/certificate_summary.rb', line 95 def certificate_rules @certificate_rules end |
#compartment_id ⇒ String
**[Required]** The OCID of the compartment that contains the certificate.
91 92 93 |
# File 'lib/oci/certificates_management/models/certificate_summary.rb', line 91 def compartment_id @compartment_id end |
#config_type ⇒ String
**[Required]** The origin of the certificate.
105 106 107 |
# File 'lib/oci/certificates_management/models/certificate_summary.rb', line 105 def config_type @config_type end |
#current_version_summary ⇒ OCI::CertificatesManagement::Models::CertificateVersionSummary
98 99 100 |
# File 'lib/oci/certificates_management/models/certificate_summary.rb', line 98 def current_version_summary @current_version_summary end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `{"CostCenter": "42"}`
131 132 133 |
# File 'lib/oci/certificates_management/models/certificate_summary.rb', line 131 def @defined_tags end |
#description ⇒ String
A brief description of the certificate.
71 72 73 |
# File 'lib/oci/certificates_management/models/certificate_summary.rb', line 71 def description @description end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `"Finance"`
124 125 126 |
# File 'lib/oci/certificates_management/models/certificate_summary.rb', line 124 def @freeform_tags end |
#id ⇒ String
**[Required]** The OCID of the certificate.
59 60 61 |
# File 'lib/oci/certificates_management/models/certificate_summary.rb', line 59 def id @id end |
#issuer_certificate_authority_id ⇒ String
The OCID of the certificate authority (CA) that issued the certificate.
63 64 65 |
# File 'lib/oci/certificates_management/models/certificate_summary.rb', line 63 def @issuer_certificate_authority_id end |
#key_algorithm ⇒ String
The algorithm used to create key pairs.
109 110 111 |
# File 'lib/oci/certificates_management/models/certificate_summary.rb', line 109 def key_algorithm @key_algorithm end |
#lifecycle_state ⇒ String
**[Required]** The current lifecycle state of the certificate.
87 88 89 |
# File 'lib/oci/certificates_management/models/certificate_summary.rb', line 87 def lifecycle_state @lifecycle_state end |
#name ⇒ String
**[Required]** A user-friendly name for the certificate. Names are unique within a compartment. Avoid entering confidential information. Valid characters are uppercase or lowercase letters, numbers, hyphens, underscores, and periods.
67 68 69 |
# File 'lib/oci/certificates_management/models/certificate_summary.rb', line 67 def name @name end |
#signature_algorithm ⇒ String
The algorithm used to sign the public key certificate.
113 114 115 |
# File 'lib/oci/certificates_management/models/certificate_summary.rb', line 113 def signature_algorithm @signature_algorithm end |
#subject ⇒ OCI::CertificatesManagement::Models::CertificateSubject
101 102 103 |
# File 'lib/oci/certificates_management/models/certificate_summary.rb', line 101 def subject @subject end |
#time_created ⇒ DateTime
**[Required]** A property indicating when the certificate was created, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format. Example: `2019-04-03T21:10:29.600Z`
77 78 79 |
# File 'lib/oci/certificates_management/models/certificate_summary.rb', line 77 def time_created @time_created end |
#time_of_deletion ⇒ DateTime
An optional property indicating when to delete the certificate version, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format. Example: `2019-04-03T21:10:29.600Z`
83 84 85 |
# File 'lib/oci/certificates_management/models/certificate_summary.rb', line 83 def time_of_deletion @time_of_deletion end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/oci/certificates_management/models/certificate_summary.rb', line 134 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'issuer_certificate_authority_id': :'issuerCertificateAuthorityId', 'name': :'name', 'description': :'description', 'time_created': :'timeCreated', 'time_of_deletion': :'timeOfDeletion', 'lifecycle_state': :'lifecycleState', 'compartment_id': :'compartmentId', 'certificate_rules': :'certificateRules', 'current_version_summary': :'currentVersionSummary', 'subject': :'subject', 'config_type': :'configType', 'key_algorithm': :'keyAlgorithm', 'signature_algorithm': :'signatureAlgorithm', 'certificate_profile_type': :'certificateProfileType', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/oci/certificates_management/models/certificate_summary.rb', line 159 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'issuer_certificate_authority_id': :'String', 'name': :'String', 'description': :'String', 'time_created': :'DateTime', 'time_of_deletion': :'DateTime', 'lifecycle_state': :'String', 'compartment_id': :'String', 'certificate_rules': :'Array<OCI::CertificatesManagement::Models::CertificateRule>', 'current_version_summary': :'OCI::CertificatesManagement::Models::CertificateVersionSummary', 'subject': :'OCI::CertificatesManagement::Models::CertificateSubject', 'config_type': :'String', 'key_algorithm': :'String', 'signature_algorithm': :'String', 'certificate_profile_type': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 |
# File 'lib/oci/certificates_management/models/certificate_summary.rb', line 372 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && == other. && name == other.name && description == other.description && time_created == other.time_created && time_of_deletion == other.time_of_deletion && lifecycle_state == other.lifecycle_state && compartment_id == other.compartment_id && certificate_rules == other.certificate_rules && current_version_summary == other.current_version_summary && subject == other.subject && config_type == other.config_type && key_algorithm == other.key_algorithm && signature_algorithm == other.signature_algorithm && certificate_profile_type == other.certificate_profile_type && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 |
# File 'lib/oci/certificates_management/models/certificate_summary.rb', line 418 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
398 399 400 |
# File 'lib/oci/certificates_management/models/certificate_summary.rb', line 398 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
407 408 409 |
# File 'lib/oci/certificates_management/models/certificate_summary.rb', line 407 def hash [id, , name, description, time_created, time_of_deletion, lifecycle_state, compartment_id, certificate_rules, current_version_summary, subject, config_type, key_algorithm, signature_algorithm, certificate_profile_type, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
451 452 453 454 455 456 457 458 459 460 |
# File 'lib/oci/certificates_management/models/certificate_summary.rb', line 451 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
445 446 447 |
# File 'lib/oci/certificates_management/models/certificate_summary.rb', line 445 def to_s to_hash.to_s end |