Class: OCI::CertificatesManagement::Models::CreateCaBundleDetails
- Inherits:
-
Object
- Object
- OCI::CertificatesManagement::Models::CreateCaBundleDetails
- Defined in:
- lib/oci/certificates_management/models/create_ca_bundle_details.rb
Overview
The details of the CA bundle that you want to create.
Instance Attribute Summary collapse
-
#ca_bundle_pem ⇒ String
**[Required]** Certificates (in PEM format) to include in the CA bundle.
-
#compartment_id ⇒ String
**[Required]** The OCID of the compartment for the CA bundle.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
A brief description of the CA bundle.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#name ⇒ String
**[Required]** A user-friendly name for the CA bundle.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateCaBundleDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateCaBundleDetails
Initializes the object
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/oci/certificates_management/models/create_ca_bundle_details.rb', line 80 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.description = "null" if description.nil? && !attributes.key?(:'description') # rubocop:disable Style/StringLiterals self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.ca_bundle_pem = attributes[:'caBundlePem'] if attributes[:'caBundlePem'] raise 'You cannot provide both :caBundlePem and :ca_bundle_pem' if attributes.key?(:'caBundlePem') && attributes.key?(:'ca_bundle_pem') self.ca_bundle_pem = attributes[:'ca_bundle_pem'] if attributes[:'ca_bundle_pem'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#ca_bundle_pem ⇒ String
**[Required]** Certificates (in PEM format) to include in the CA bundle.
24 25 26 |
# File 'lib/oci/certificates_management/models/create_ca_bundle_details.rb', line 24 def ca_bundle_pem @ca_bundle_pem end |
#compartment_id ⇒ String
**[Required]** The OCID of the compartment for the CA bundle.
20 21 22 |
# File 'lib/oci/certificates_management/models/create_ca_bundle_details.rb', line 20 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `{"CostCenter": "42"}`
38 39 40 |
# File 'lib/oci/certificates_management/models/create_ca_bundle_details.rb', line 38 def @defined_tags end |
#description ⇒ String
A brief description of the CA bundle.
16 17 18 |
# File 'lib/oci/certificates_management/models/create_ca_bundle_details.rb', line 16 def description @description end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `"Finance"`
31 32 33 |
# File 'lib/oci/certificates_management/models/create_ca_bundle_details.rb', line 31 def @freeform_tags end |
#name ⇒ String
**[Required]** A user-friendly name for the CA bundle. Names are unique within a compartment. Avoid entering confidential information. Valid characters include uppercase or lowercase letters, numbers, hyphens, underscores, and periods.
12 13 14 |
# File 'lib/oci/certificates_management/models/create_ca_bundle_details.rb', line 12 def name @name end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/oci/certificates_management/models/create_ca_bundle_details.rb', line 41 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'description': :'description', 'compartment_id': :'compartmentId', 'ca_bundle_pem': :'caBundlePem', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/oci/certificates_management/models/create_ca_bundle_details.rb', line 55 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'description': :'String', 'compartment_id': :'String', 'ca_bundle_pem': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/oci/certificates_management/models/create_ca_bundle_details.rb', line 123 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && description == other.description && compartment_id == other.compartment_id && ca_bundle_pem == other.ca_bundle_pem && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/oci/certificates_management/models/create_ca_bundle_details.rb', line 158 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
138 139 140 |
# File 'lib/oci/certificates_management/models/create_ca_bundle_details.rb', line 138 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
147 148 149 |
# File 'lib/oci/certificates_management/models/create_ca_bundle_details.rb', line 147 def hash [name, description, compartment_id, ca_bundle_pem, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
191 192 193 194 195 196 197 198 199 200 |
# File 'lib/oci/certificates_management/models/create_ca_bundle_details.rb', line 191 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
185 186 187 |
# File 'lib/oci/certificates_management/models/create_ca_bundle_details.rb', line 185 def to_s to_hash.to_s end |