Class: OCI::CertificatesManagement::Models::CreateCertificateAuthorityDetails
- Inherits:
-
Object
- Object
- OCI::CertificatesManagement::Models::CreateCertificateAuthorityDetails
- Defined in:
- lib/oci/certificates_management/models/create_certificate_authority_details.rb
Overview
The details for creating a certificate authority (CA).
Instance Attribute Summary collapse
-
#certificate_authority_config ⇒ OCI::CertificatesManagement::Models::CreateCertificateAuthorityConfigDetails
This attribute is required.
-
#certificate_authority_rules ⇒ Array<OCI::CertificatesManagement::Models::CertificateAuthorityRule>
A list of rules that control how the CA is used and managed.
- #certificate_revocation_list_details ⇒ OCI::CertificatesManagement::Models::CertificateRevocationListDetails
-
#compartment_id ⇒ String
**[Required]** The compartment in which you want to create the CA.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Usage of predefined tag keys.
-
#description ⇒ String
A brief description of the CA.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#kms_key_id ⇒ String
**[Required]** The OCID of the Oracle Cloud Infrastructure Vault key used to encrypt the CA.
-
#name ⇒ String
**[Required]** A user-friendly name for the CA.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateCertificateAuthorityDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateCertificateAuthorityDetails
Initializes the object
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/oci/certificates_management/models/create_certificate_authority_details.rb', line 98 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.description = "null" if description.nil? && !attributes.key?(:'description') # rubocop:disable Style/StringLiterals self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self. = attributes[:'certificateAuthorityRules'] if attributes[:'certificateAuthorityRules'] raise 'You cannot provide both :certificateAuthorityRules and :certificate_authority_rules' if attributes.key?(:'certificateAuthorityRules') && attributes.key?(:'certificate_authority_rules') self. = attributes[:'certificate_authority_rules'] if attributes[:'certificate_authority_rules'] self. = attributes[:'certificateAuthorityConfig'] if attributes[:'certificateAuthorityConfig'] raise 'You cannot provide both :certificateAuthorityConfig and :certificate_authority_config' if attributes.key?(:'certificateAuthorityConfig') && attributes.key?(:'certificate_authority_config') self. = attributes[:'certificate_authority_config'] if attributes[:'certificate_authority_config'] self.certificate_revocation_list_details = attributes[:'certificateRevocationListDetails'] if attributes[:'certificateRevocationListDetails'] raise 'You cannot provide both :certificateRevocationListDetails and :certificate_revocation_list_details' if attributes.key?(:'certificateRevocationListDetails') && attributes.key?(:'certificate_revocation_list_details') self.certificate_revocation_list_details = attributes[:'certificate_revocation_list_details'] if attributes[:'certificate_revocation_list_details'] self.kms_key_id = attributes[:'kmsKeyId'] if attributes[:'kmsKeyId'] raise 'You cannot provide both :kmsKeyId and :kms_key_id' if attributes.key?(:'kmsKeyId') && attributes.key?(:'kms_key_id') self.kms_key_id = attributes[:'kms_key_id'] if attributes[:'kms_key_id'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#certificate_authority_config ⇒ OCI::CertificatesManagement::Models::CreateCertificateAuthorityConfigDetails
This attribute is required.
28 29 30 |
# File 'lib/oci/certificates_management/models/create_certificate_authority_details.rb', line 28 def @certificate_authority_config end |
#certificate_authority_rules ⇒ Array<OCI::CertificatesManagement::Models::CertificateAuthorityRule>
A list of rules that control how the CA is used and managed.
24 25 26 |
# File 'lib/oci/certificates_management/models/create_certificate_authority_details.rb', line 24 def @certificate_authority_rules end |
#certificate_revocation_list_details ⇒ OCI::CertificatesManagement::Models::CertificateRevocationListDetails
31 32 33 |
# File 'lib/oci/certificates_management/models/create_certificate_authority_details.rb', line 31 def certificate_revocation_list_details @certificate_revocation_list_details end |
#compartment_id ⇒ String
**[Required]** The compartment in which you want to create the CA.
20 21 22 |
# File 'lib/oci/certificates_management/models/create_certificate_authority_details.rb', line 20 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Usage of predefined tag keys. These predefined keys are scoped to namespaces. Example: `{"bar-key": "value"}`
47 48 49 |
# File 'lib/oci/certificates_management/models/create_certificate_authority_details.rb', line 47 def @defined_tags end |
#description ⇒ String
A brief description of the CA.
16 17 18 |
# File 'lib/oci/certificates_management/models/create_certificate_authority_details.rb', line 16 def description @description end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
41 42 43 |
# File 'lib/oci/certificates_management/models/create_certificate_authority_details.rb', line 41 def @freeform_tags end |
#kms_key_id ⇒ String
**[Required]** The OCID of the Oracle Cloud Infrastructure Vault key used to encrypt the CA.
35 36 37 |
# File 'lib/oci/certificates_management/models/create_certificate_authority_details.rb', line 35 def kms_key_id @kms_key_id end |
#name ⇒ String
**[Required]** A user-friendly name for the CA. Names are unique within a compartment. Avoid entering confidential information. Valid characters include uppercase or lowercase letters, numbers, hyphens, underscores, and periods.
12 13 14 |
# File 'lib/oci/certificates_management/models/create_certificate_authority_details.rb', line 12 def name @name end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/oci/certificates_management/models/create_certificate_authority_details.rb', line 50 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'description': :'description', 'compartment_id': :'compartmentId', 'certificate_authority_rules': :'certificateAuthorityRules', 'certificate_authority_config': :'certificateAuthorityConfig', 'certificate_revocation_list_details': :'certificateRevocationListDetails', 'kms_key_id': :'kmsKeyId', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/oci/certificates_management/models/create_certificate_authority_details.rb', line 67 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'description': :'String', 'compartment_id': :'String', 'certificate_authority_rules': :'Array<OCI::CertificatesManagement::Models::CertificateAuthorityRule>', 'certificate_authority_config': :'OCI::CertificatesManagement::Models::CreateCertificateAuthorityConfigDetails', 'certificate_revocation_list_details': :'OCI::CertificatesManagement::Models::CertificateRevocationListDetails', 'kms_key_id': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/oci/certificates_management/models/create_certificate_authority_details.rb', line 159 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && description == other.description && compartment_id == other.compartment_id && == other. && == other. && certificate_revocation_list_details == other.certificate_revocation_list_details && kms_key_id == other.kms_key_id && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/oci/certificates_management/models/create_certificate_authority_details.rb', line 197 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
177 178 179 |
# File 'lib/oci/certificates_management/models/create_certificate_authority_details.rb', line 177 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
186 187 188 |
# File 'lib/oci/certificates_management/models/create_certificate_authority_details.rb', line 186 def hash [name, description, compartment_id, , , certificate_revocation_list_details, kms_key_id, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
230 231 232 233 234 235 236 237 238 239 |
# File 'lib/oci/certificates_management/models/create_certificate_authority_details.rb', line 230 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
224 225 226 |
# File 'lib/oci/certificates_management/models/create_certificate_authority_details.rb', line 224 def to_s to_hash.to_s end |