Class: OCI::CertificatesManagement::Models::CreateCertificateManagedExternallyIssuedByInternalCaConfigDetails

Inherits:
CreateCertificateConfigDetails show all
Defined in:
lib/oci/certificates_management/models/create_certificate_managed_externally_issued_by_internal_ca_config_details.rb

Overview

The details of the configuration for creating an externally managed certificate which is issued by a private certificate authority (CA).

Constant Summary

Constants inherited from CreateCertificateConfigDetails

OCI::CertificatesManagement::Models::CreateCertificateConfigDetails::CONFIG_TYPE_ENUM

Instance Attribute Summary collapse

Attributes inherited from CreateCertificateConfigDetails

#config_type, #version_name

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from CreateCertificateConfigDetails

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ CreateCertificateManagedExternallyIssuedByInternalCaConfigDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :version_name (String)

    The value to assign to the #version_name proprety

  • :issuer_certificate_authority_id (String)

    The value to assign to the #issuer_certificate_authority_id property

  • :validity (OCI::CertificatesManagement::Models::Validity)

    The value to assign to the #validity property

  • :csr_pem (String)

    The value to assign to the #csr_pem property



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/oci/certificates_management/models/create_certificate_managed_externally_issued_by_internal_ca_config_details.rb', line 58

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['configType'] = 'MANAGED_EXTERNALLY_ISSUED_BY_INTERNAL_CA'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.issuer_certificate_authority_id = attributes[:'issuerCertificateAuthorityId'] if attributes[:'issuerCertificateAuthorityId']

  raise 'You cannot provide both :issuerCertificateAuthorityId and :issuer_certificate_authority_id' if attributes.key?(:'issuerCertificateAuthorityId') && attributes.key?(:'issuer_certificate_authority_id')

  self.issuer_certificate_authority_id = attributes[:'issuer_certificate_authority_id'] if attributes[:'issuer_certificate_authority_id']

  self.validity = attributes[:'validity'] if attributes[:'validity']

  self.csr_pem = attributes[:'csrPem'] if attributes[:'csrPem']

  raise 'You cannot provide both :csrPem and :csr_pem' if attributes.key?(:'csrPem') && attributes.key?(:'csr_pem')

  self.csr_pem = attributes[:'csr_pem'] if attributes[:'csr_pem']
end

Instance Attribute Details

#csr_pemString

**[Required]** The certificate signing request (in PEM format).

Returns:

  • (String)


20
21
22
# File 'lib/oci/certificates_management/models/create_certificate_managed_externally_issued_by_internal_ca_config_details.rb', line 20

def csr_pem
  @csr_pem
end

#issuer_certificate_authority_idString

**[Required]** The OCID of the private CA.

Returns:

  • (String)


13
14
15
# File 'lib/oci/certificates_management/models/create_certificate_managed_externally_issued_by_internal_ca_config_details.rb', line 13

def issuer_certificate_authority_id
  @issuer_certificate_authority_id
end

#validityOCI::CertificatesManagement::Models::Validity

Returns:

  • (OCI::CertificatesManagement::Models::Validity)


16
17
18
# File 'lib/oci/certificates_management/models/create_certificate_managed_externally_issued_by_internal_ca_config_details.rb', line 16

def validity
  @validity
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



23
24
25
26
27
28
29
30
31
32
33
# File 'lib/oci/certificates_management/models/create_certificate_managed_externally_issued_by_internal_ca_config_details.rb', line 23

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'config_type': :'configType',
    'version_name': :'versionName',
    'issuer_certificate_authority_id': :'issuerCertificateAuthorityId',
    'validity': :'validity',
    'csr_pem': :'csrPem'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



36
37
38
39
40
41
42
43
44
45
46
# File 'lib/oci/certificates_management/models/create_certificate_managed_externally_issued_by_internal_ca_config_details.rb', line 36

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'config_type': :'String',
    'version_name': :'String',
    'issuer_certificate_authority_id': :'String',
    'validity': :'OCI::CertificatesManagement::Models::Validity',
    'csr_pem': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



90
91
92
93
94
95
96
97
98
99
# File 'lib/oci/certificates_management/models/create_certificate_managed_externally_issued_by_internal_ca_config_details.rb', line 90

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    config_type == other.config_type &&
    version_name == other.version_name &&
    issuer_certificate_authority_id == other.issuer_certificate_authority_id &&
    validity == other.validity &&
    csr_pem == other.csr_pem
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/oci/certificates_management/models/create_certificate_managed_externally_issued_by_internal_ca_config_details.rb', line 124

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


104
105
106
# File 'lib/oci/certificates_management/models/create_certificate_managed_externally_issued_by_internal_ca_config_details.rb', line 104

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



113
114
115
# File 'lib/oci/certificates_management/models/create_certificate_managed_externally_issued_by_internal_ca_config_details.rb', line 113

def hash
  [config_type, version_name, issuer_certificate_authority_id, validity, csr_pem].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



157
158
159
160
161
162
163
164
165
166
# File 'lib/oci/certificates_management/models/create_certificate_managed_externally_issued_by_internal_ca_config_details.rb', line 157

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



151
152
153
# File 'lib/oci/certificates_management/models/create_certificate_managed_externally_issued_by_internal_ca_config_details.rb', line 151

def to_s
  to_hash.to_s
end