Class: OCI::CertificatesManagement::Models::UpdateCertificateAuthorityDetails
- Inherits:
-
Object
- Object
- OCI::CertificatesManagement::Models::UpdateCertificateAuthorityDetails
- Defined in:
- lib/oci/certificates_management/models/update_certificate_authority_details.rb
Overview
The details for updating a certificate authority (CA).
Instance Attribute Summary collapse
- #certificate_authority_config ⇒ OCI::CertificatesManagement::Models::UpdateCertificateAuthorityConfigDetails
-
#certificate_authority_rules ⇒ Array<OCI::CertificatesManagement::Models::CertificateAuthorityRule>
A list of rules that control how the CA is used and managed.
- #certificate_revocation_list_details ⇒ OCI::CertificatesManagement::Models::CertificateRevocationListDetails
-
#current_version_number ⇒ Integer
Makes this version the current version.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Usage of predefined tag keys.
-
#description ⇒ String
A brief description of the CA.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateCertificateAuthorityDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateCertificateAuthorityDetails
Initializes the object
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/oci/certificates_management/models/update_certificate_authority_details.rb', line 83 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.description = attributes[:'description'] if attributes[:'description'] self.current_version_number = attributes[:'currentVersionNumber'] if attributes[:'currentVersionNumber'] raise 'You cannot provide both :currentVersionNumber and :current_version_number' if attributes.key?(:'currentVersionNumber') && attributes.key?(:'current_version_number') self.current_version_number = attributes[:'current_version_number'] if attributes[:'current_version_number'] self. = attributes[:'certificateAuthorityConfig'] if attributes[:'certificateAuthorityConfig'] raise 'You cannot provide both :certificateAuthorityConfig and :certificate_authority_config' if attributes.key?(:'certificateAuthorityConfig') && attributes.key?(:'certificate_authority_config') self. = attributes[:'certificate_authority_config'] if attributes[:'certificate_authority_config'] self.certificate_revocation_list_details = attributes[:'certificateRevocationListDetails'] if attributes[:'certificateRevocationListDetails'] raise 'You cannot provide both :certificateRevocationListDetails and :certificate_revocation_list_details' if attributes.key?(:'certificateRevocationListDetails') && attributes.key?(:'certificate_revocation_list_details') self.certificate_revocation_list_details = attributes[:'certificate_revocation_list_details'] if attributes[:'certificate_revocation_list_details'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'certificateAuthorityRules'] if attributes[:'certificateAuthorityRules'] raise 'You cannot provide both :certificateAuthorityRules and :certificate_authority_rules' if attributes.key?(:'certificateAuthorityRules') && attributes.key?(:'certificate_authority_rules') self. = attributes[:'certificate_authority_rules'] if attributes[:'certificate_authority_rules'] end |
Instance Attribute Details
#certificate_authority_config ⇒ OCI::CertificatesManagement::Models::UpdateCertificateAuthorityConfigDetails
19 20 21 |
# File 'lib/oci/certificates_management/models/update_certificate_authority_details.rb', line 19 def @certificate_authority_config end |
#certificate_authority_rules ⇒ Array<OCI::CertificatesManagement::Models::CertificateAuthorityRule>
A list of rules that control how the CA is used and managed.
38 39 40 |
# File 'lib/oci/certificates_management/models/update_certificate_authority_details.rb', line 38 def @certificate_authority_rules end |
#certificate_revocation_list_details ⇒ OCI::CertificatesManagement::Models::CertificateRevocationListDetails
22 23 24 |
# File 'lib/oci/certificates_management/models/update_certificate_authority_details.rb', line 22 def certificate_revocation_list_details @certificate_revocation_list_details end |
#current_version_number ⇒ Integer
Makes this version the current version. This property cannot be updated in combination with any other properties.
16 17 18 |
# File 'lib/oci/certificates_management/models/update_certificate_authority_details.rb', line 16 def current_version_number @current_version_number end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Usage of predefined tag keys. These predefined keys are scoped to namespaces. Example: `{"bar-key": "value"}`
34 35 36 |
# File 'lib/oci/certificates_management/models/update_certificate_authority_details.rb', line 34 def @defined_tags end |
#description ⇒ String
A brief description of the CA.
12 13 14 |
# File 'lib/oci/certificates_management/models/update_certificate_authority_details.rb', line 12 def description @description end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
28 29 30 |
# File 'lib/oci/certificates_management/models/update_certificate_authority_details.rb', line 28 def @freeform_tags end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/oci/certificates_management/models/update_certificate_authority_details.rb', line 41 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'description': :'description', 'current_version_number': :'currentVersionNumber', 'certificate_authority_config': :'certificateAuthorityConfig', 'certificate_revocation_list_details': :'certificateRevocationListDetails', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'certificate_authority_rules': :'certificateAuthorityRules' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/oci/certificates_management/models/update_certificate_authority_details.rb', line 56 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'description': :'String', 'current_version_number': :'Integer', 'certificate_authority_config': :'OCI::CertificatesManagement::Models::UpdateCertificateAuthorityConfigDetails', 'certificate_revocation_list_details': :'OCI::CertificatesManagement::Models::CertificateRevocationListDetails', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'certificate_authority_rules': :'Array<OCI::CertificatesManagement::Models::CertificateAuthorityRule>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/oci/certificates_management/models/update_certificate_authority_details.rb', line 135 def ==(other) return true if equal?(other) self.class == other.class && description == other.description && current_version_number == other.current_version_number && == other. && certificate_revocation_list_details == other.certificate_revocation_list_details && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/oci/certificates_management/models/update_certificate_authority_details.rb', line 171 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
151 152 153 |
# File 'lib/oci/certificates_management/models/update_certificate_authority_details.rb', line 151 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
160 161 162 |
# File 'lib/oci/certificates_management/models/update_certificate_authority_details.rb', line 160 def hash [description, current_version_number, , certificate_revocation_list_details, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
204 205 206 207 208 209 210 211 212 213 |
# File 'lib/oci/certificates_management/models/update_certificate_authority_details.rb', line 204 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
198 199 200 |
# File 'lib/oci/certificates_management/models/update_certificate_authority_details.rb', line 198 def to_s to_hash.to_s end |