Class: OCI::CertificatesManagement::Models::UpdateCertificateByImportingConfigDetails
- Inherits:
-
UpdateCertificateConfigDetails
- Object
- UpdateCertificateConfigDetails
- OCI::CertificatesManagement::Models::UpdateCertificateByImportingConfigDetails
- Defined in:
- lib/oci/certificates_management/models/update_certificate_by_importing_config_details.rb
Overview
The details of the configuration for updating a certificate based on the keys from an imported certificate.
Constant Summary
Constants inherited from UpdateCertificateConfigDetails
OCI::CertificatesManagement::Models::UpdateCertificateConfigDetails::CONFIG_TYPE_ENUM, OCI::CertificatesManagement::Models::UpdateCertificateConfigDetails::STAGE_ENUM
Instance Attribute Summary collapse
-
#cert_chain_pem ⇒ String
**[Required]** The certificate chain (in PEM format) for the imported certificate.
-
#certificate_pem ⇒ String
**[Required]** The certificate (in PEM format) for the imported certificate.
-
#private_key_pem ⇒ String
**[Required]** The private key (in PEM format) for the imported certificate.
-
#private_key_pem_passphrase ⇒ String
An optional passphrase for the private key.
Attributes inherited from UpdateCertificateConfigDetails
#config_type, #stage, #version_name
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateCertificateByImportingConfigDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from UpdateCertificateConfigDetails
Constructor Details
#initialize(attributes = {}) ⇒ UpdateCertificateByImportingConfigDetails
Initializes the object
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/oci/certificates_management/models/update_certificate_by_importing_config_details.rb', line 69 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['configType'] = 'IMPORTED' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.cert_chain_pem = attributes[:'certChainPem'] if attributes[:'certChainPem'] raise 'You cannot provide both :certChainPem and :cert_chain_pem' if attributes.key?(:'certChainPem') && attributes.key?(:'cert_chain_pem') self.cert_chain_pem = attributes[:'cert_chain_pem'] if attributes[:'cert_chain_pem'] self.private_key_pem = attributes[:'privateKeyPem'] if attributes[:'privateKeyPem'] raise 'You cannot provide both :privateKeyPem and :private_key_pem' if attributes.key?(:'privateKeyPem') && attributes.key?(:'private_key_pem') self.private_key_pem = attributes[:'private_key_pem'] if attributes[:'private_key_pem'] self.certificate_pem = attributes[:'certificatePem'] if attributes[:'certificatePem'] raise 'You cannot provide both :certificatePem and :certificate_pem' if attributes.key?(:'certificatePem') && attributes.key?(:'certificate_pem') self.certificate_pem = attributes[:'certificate_pem'] if attributes[:'certificate_pem'] self.private_key_pem_passphrase = attributes[:'privateKeyPemPassphrase'] if attributes[:'privateKeyPemPassphrase'] raise 'You cannot provide both :privateKeyPemPassphrase and :private_key_pem_passphrase' if attributes.key?(:'privateKeyPemPassphrase') && attributes.key?(:'private_key_pem_passphrase') self.private_key_pem_passphrase = attributes[:'private_key_pem_passphrase'] if attributes[:'private_key_pem_passphrase'] end |
Instance Attribute Details
#cert_chain_pem ⇒ String
**[Required]** The certificate chain (in PEM format) for the imported certificate.
13 14 15 |
# File 'lib/oci/certificates_management/models/update_certificate_by_importing_config_details.rb', line 13 def cert_chain_pem @cert_chain_pem end |
#certificate_pem ⇒ String
**[Required]** The certificate (in PEM format) for the imported certificate.
21 22 23 |
# File 'lib/oci/certificates_management/models/update_certificate_by_importing_config_details.rb', line 21 def certificate_pem @certificate_pem end |
#private_key_pem ⇒ String
**[Required]** The private key (in PEM format) for the imported certificate.
17 18 19 |
# File 'lib/oci/certificates_management/models/update_certificate_by_importing_config_details.rb', line 17 def private_key_pem @private_key_pem end |
#private_key_pem_passphrase ⇒ String
An optional passphrase for the private key.
25 26 27 |
# File 'lib/oci/certificates_management/models/update_certificate_by_importing_config_details.rb', line 25 def private_key_pem_passphrase @private_key_pem_passphrase end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 35 36 37 38 39 40 |
# File 'lib/oci/certificates_management/models/update_certificate_by_importing_config_details.rb', line 28 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'config_type': :'configType', 'version_name': :'versionName', 'stage': :'stage', 'cert_chain_pem': :'certChainPem', 'private_key_pem': :'privateKeyPem', 'certificate_pem': :'certificatePem', 'private_key_pem_passphrase': :'privateKeyPemPassphrase' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
43 44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/oci/certificates_management/models/update_certificate_by_importing_config_details.rb', line 43 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'config_type': :'String', 'version_name': :'String', 'stage': :'String', 'cert_chain_pem': :'String', 'private_key_pem': :'String', 'certificate_pem': :'String', 'private_key_pem_passphrase': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/oci/certificates_management/models/update_certificate_by_importing_config_details.rb', line 111 def ==(other) return true if equal?(other) self.class == other.class && config_type == other.config_type && version_name == other.version_name && stage == other.stage && cert_chain_pem == other.cert_chain_pem && private_key_pem == other.private_key_pem && certificate_pem == other.certificate_pem && private_key_pem_passphrase == other.private_key_pem_passphrase end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/oci/certificates_management/models/update_certificate_by_importing_config_details.rb', line 147 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
127 128 129 |
# File 'lib/oci/certificates_management/models/update_certificate_by_importing_config_details.rb', line 127 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
136 137 138 |
# File 'lib/oci/certificates_management/models/update_certificate_by_importing_config_details.rb', line 136 def hash [config_type, version_name, stage, cert_chain_pem, private_key_pem, certificate_pem, private_key_pem_passphrase].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
180 181 182 183 184 185 186 187 188 189 |
# File 'lib/oci/certificates_management/models/update_certificate_by_importing_config_details.rb', line 180 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
174 175 176 |
# File 'lib/oci/certificates_management/models/update_certificate_by_importing_config_details.rb', line 174 def to_s to_hash.to_s end |