Class: OCI::Cims::IncidentClient
- Inherits:
-
Object
- Object
- OCI::Cims::IncidentClient
- Defined in:
- lib/oci/cims/incident_client.rb
Overview
Use the Support Management API to manage support requests. For more information, see [Getting Help and Contacting Support](/iaas/Content/GSG/Tasks/contactingsupport.htm). *Note*: Before you can create service requests with this API, you need to have an Oracle Single Sign On (SSO) account, and you need to register your Customer Support Identifier (CSI) with My Oracle Support.
Instance Attribute Summary collapse
-
#api_client ⇒ OCI::ApiClient
readonly
Client used to make HTTP requests.
-
#endpoint ⇒ String
readonly
Fully qualified endpoint URL.
-
#region ⇒ String
The region, which will usually correspond to a value in Regions::REGION_ENUM.
-
#retry_config ⇒ OCI::Retry::RetryConfig
readonly
The default retry configuration to apply to all operations in this service client.
Instance Method Summary collapse
-
#create_incident(create_incident_details, ocid, opts = {}) ⇒ Response
Enables the customer to create an support ticket.
-
#get_incident(incident_key, csi, ocid, opts = {}) ⇒ Response
Gets the details of the support ticket.
-
#get_status(source, ocid, opts = {}) ⇒ Response
Gets the status of the service.
-
#initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) ⇒ IncidentClient
constructor
Creates a new IncidentClient.
-
#list_incident_resource_types(problem_type, compartment_id, csi, ocid, opts = {}) ⇒ Response
During support ticket creation, returns the list of all possible products that Oracle Cloud Infrastructure supports.
-
#list_incidents(csi, compartment_id, ocid, opts = {}) ⇒ Response
Returns the list of support tickets raised by the tenancy.
-
#logger ⇒ Logger
The logger for this client.
-
#update_incident(incident_key, csi, update_incident_details, ocid, opts = {}) ⇒ Response
Updates the specified support ticket's information.
-
#validate_user(csi, ocid, opts = {}) ⇒ Response
Checks whether the requested user is valid.
Constructor Details
#initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) ⇒ IncidentClient
Creates a new IncidentClient. Notes:
If a config is not specified, then the global OCI.config will be used.
This client is not thread-safe
Either a region or an endpoint must be specified. If an endpoint is specified, it will be used instead of the
region. A region may be specified in the config or via or the region parameter. If specified in both, then the
region parameter will be used.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/oci/cims/incident_client.rb', line 53 def initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) # If the signer is an InstancePrincipalsSecurityTokenSigner or SecurityTokenSigner and no config was supplied (they are self-sufficient signers) # then create a dummy config to pass to the ApiClient constructor. If customers wish to create a client which uses instance principals # and has config (either populated programmatically or loaded from a file), they must construct that config themselves and then # pass it to this constructor. # # If there is no signer (or the signer is not an instance principals signer) and no config was supplied, this is not valid # so try and load the config from the default file. config = OCI::Config.validate_and_build_config_with_signer(config, signer) signer = OCI::Signer.config_file_auth_builder(config) if signer.nil? @api_client = OCI::ApiClient.new(config, signer, proxy_settings: proxy_settings) @retry_config = retry_config if endpoint @endpoint = endpoint + '/20181231' else region ||= config.region region ||= signer.region if signer.respond_to?(:region) self.region = region end logger.info "IncidentClient endpoint set to '#{@endpoint}'." if logger end |
Instance Attribute Details
#api_client ⇒ OCI::ApiClient (readonly)
Client used to make HTTP requests.
13 14 15 |
# File 'lib/oci/cims/incident_client.rb', line 13 def api_client @api_client end |
#endpoint ⇒ String (readonly)
Fully qualified endpoint URL
17 18 19 |
# File 'lib/oci/cims/incident_client.rb', line 17 def endpoint @endpoint end |
#region ⇒ String
The region, which will usually correspond to a value in Regions::REGION_ENUM.
27 28 29 |
# File 'lib/oci/cims/incident_client.rb', line 27 def region @region end |
#retry_config ⇒ OCI::Retry::RetryConfig (readonly)
The default retry configuration to apply to all operations in this service client. This can be overridden on a per-operation basis. The default retry configuration value is `nil`, which means that an operation will not perform any retries
23 24 25 |
# File 'lib/oci/cims/incident_client.rb', line 23 def retry_config @retry_config end |
Instance Method Details
#create_incident(create_incident_details, ocid, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/cims/create_incident.rb.html) to see an example of how to use create_incident API.
Enables the customer to create an support ticket.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/oci/cims/incident_client.rb', line 111 def create_incident(create_incident_details, ocid, opts = {}) logger.debug 'Calling operation IncidentClient#create_incident.' if logger raise "Missing the required parameter 'create_incident_details' when calling create_incident." if create_incident_details.nil? raise "Missing the required parameter 'ocid' when calling create_incident." if ocid.nil? path = '/v2/incidents' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:ocid] = ocid header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:homeregion] = opts[:homeregion] if opts[:homeregion] # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(create_incident_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'IncidentClient#create_incident') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Cims::Models::Incident' ) end # rubocop:enable Metrics/BlockLength end |
#get_incident(incident_key, csi, ocid, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/cims/get_incident.rb.html) to see an example of how to use get_incident API.
Gets the details of the support ticket.
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/oci/cims/incident_client.rb', line 171 def get_incident(incident_key, csi, ocid, opts = {}) logger.debug 'Calling operation IncidentClient#get_incident.' if logger raise "Missing the required parameter 'incident_key' when calling get_incident." if incident_key.nil? raise "Missing the required parameter 'csi' when calling get_incident." if csi.nil? raise "Missing the required parameter 'ocid' when calling get_incident." if ocid.nil? raise "Parameter value for 'incident_key' must not be blank" if OCI::Internal::Util.blank_string?(incident_key) path = '/v2/incidents/{incidentKey}'.sub('{incidentKey}', incident_key.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:csi] = csi header_params[:ocid] = ocid header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:homeregion] = opts[:homeregion] if opts[:homeregion] header_params[:'problem-type'] = opts[:problem_type] if opts[:problem_type] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'IncidentClient#get_incident') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Cims::Models::Incident' ) end # rubocop:enable Metrics/BlockLength end |
#get_status(source, ocid, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/cims/get_status.rb.html) to see an example of how to use get_status API.
Gets the status of the service.
233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 |
# File 'lib/oci/cims/incident_client.rb', line 233 def get_status(source, ocid, opts = {}) logger.debug 'Calling operation IncidentClient#get_status.' if logger raise "Missing the required parameter 'source' when calling get_status." if source.nil? raise "Missing the required parameter 'ocid' when calling get_status." if ocid.nil? raise "Parameter value for 'source' must not be blank" if OCI::Internal::Util.blank_string?(source) path = '/v2/incidents/status/{source}'.sub('{source}', source.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:ocid] = ocid header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:homeregion] = opts[:homeregion] if opts[:homeregion] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'IncidentClient#get_status') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Cims::Models::Status' ) end # rubocop:enable Metrics/BlockLength end |
#list_incident_resource_types(problem_type, compartment_id, csi, ocid, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/cims/list_incident_resource_types.rb.html) to see an example of how to use list_incident_resource_types API.
During support ticket creation, returns the list of all possible products that Oracle Cloud Infrastructure supports.
301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 |
# File 'lib/oci/cims/incident_client.rb', line 301 def list_incident_resource_types(problem_type, compartment_id, csi, ocid, opts = {}) logger.debug 'Calling operation IncidentClient#list_incident_resource_types.' if logger raise "Missing the required parameter 'problem_type' when calling list_incident_resource_types." if problem_type.nil? raise "Missing the required parameter 'compartment_id' when calling list_incident_resource_types." if compartment_id.nil? raise "Missing the required parameter 'csi' when calling list_incident_resource_types." if csi.nil? raise "Missing the required parameter 'ocid' when calling list_incident_resource_types." if ocid.nil? if opts[:sort_by] && !OCI::Cims::Models::SORT_BY_ENUM.include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of the values in OCI::Cims::Models::SORT_BY_ENUM.' end if opts[:sort_order] && !OCI::Cims::Models::SORT_ORDER_ENUM.include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of the values in OCI::Cims::Models::SORT_ORDER_ENUM.' end path = '/v2/incidents/incidentResourceTypes' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:problemType] = problem_type query_params[:compartmentId] = compartment_id query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] query_params[:name] = opts[:name] if opts[:name] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:csi] = csi header_params[:ocid] = ocid header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:homeregion] = opts[:homeregion] if opts[:homeregion] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'IncidentClient#list_incident_resource_types') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'Array<OCI::Cims::Models::IncidentResourceType>' ) end # rubocop:enable Metrics/BlockLength end |
#list_incidents(csi, compartment_id, ocid, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/cims/list_incidents.rb.html) to see an example of how to use list_incidents API.
Returns the list of support tickets raised by the tenancy.
386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 |
# File 'lib/oci/cims/incident_client.rb', line 386 def list_incidents(csi, compartment_id, ocid, opts = {}) logger.debug 'Calling operation IncidentClient#list_incidents.' if logger raise "Missing the required parameter 'csi' when calling list_incidents." if csi.nil? raise "Missing the required parameter 'compartment_id' when calling list_incidents." if compartment_id.nil? raise "Missing the required parameter 'ocid' when calling list_incidents." if ocid.nil? if opts[:sort_by] && !OCI::Cims::Models::SORT_BY_ENUM.include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of the values in OCI::Cims::Models::SORT_BY_ENUM.' end if opts[:sort_order] && !OCI::Cims::Models::SORT_ORDER_ENUM.include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of the values in OCI::Cims::Models::SORT_ORDER_ENUM.' end if opts[:lifecycle_state] && !OCI::Cims::Models::LIFECYCLE_STATE_ENUM.include?(opts[:lifecycle_state]) raise 'Invalid value for "lifecycle_state", must be one of the values in OCI::Cims::Models::LIFECYCLE_STATE_ENUM.' end path = '/v2/incidents' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:compartmentId] = compartment_id query_params[:limit] = opts[:limit] if opts[:limit] query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] query_params[:lifecycleState] = opts[:lifecycle_state] if opts[:lifecycle_state] query_params[:page] = opts[:page] if opts[:page] query_params[:problemType] = opts[:problem_type] if opts[:problem_type] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:csi] = csi header_params[:ocid] = ocid header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:homeregion] = opts[:homeregion] if opts[:homeregion] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'IncidentClient#list_incidents') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'Array<OCI::Cims::Models::IncidentSummary>' ) end # rubocop:enable Metrics/BlockLength end |
#logger ⇒ Logger
Returns The logger for this client. May be nil.
92 93 94 |
# File 'lib/oci/cims/incident_client.rb', line 92 def logger @api_client.config.logger end |
#update_incident(incident_key, csi, update_incident_details, ocid, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/cims/update_incident.rb.html) to see an example of how to use update_incident API.
Updates the specified support ticket's information.
468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 |
# File 'lib/oci/cims/incident_client.rb', line 468 def update_incident(incident_key, csi, update_incident_details, ocid, opts = {}) logger.debug 'Calling operation IncidentClient#update_incident.' if logger raise "Missing the required parameter 'incident_key' when calling update_incident." if incident_key.nil? raise "Missing the required parameter 'csi' when calling update_incident." if csi.nil? raise "Missing the required parameter 'update_incident_details' when calling update_incident." if update_incident_details.nil? raise "Missing the required parameter 'ocid' when calling update_incident." if ocid.nil? raise "Parameter value for 'incident_key' must not be blank" if OCI::Internal::Util.blank_string?(incident_key) path = '/v2/incidents/{incidentKey}'.sub('{incidentKey}', incident_key.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:csi] = csi header_params[:ocid] = ocid header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:homeregion] = opts[:homeregion] if opts[:homeregion] # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(update_incident_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'IncidentClient#update_incident') do @api_client.call_api( :PUT, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Cims::Models::Incident' ) end # rubocop:enable Metrics/BlockLength end |
#validate_user(csi, ocid, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/cims/validate_user.rb.html) to see an example of how to use validate_user API.
Checks whether the requested user is valid.
532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 |
# File 'lib/oci/cims/incident_client.rb', line 532 def validate_user(csi, ocid, opts = {}) logger.debug 'Calling operation IncidentClient#validate_user.' if logger raise "Missing the required parameter 'csi' when calling validate_user." if csi.nil? raise "Missing the required parameter 'ocid' when calling validate_user." if ocid.nil? path = '/v2/incidents/user/validate' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:problemType] = opts[:problem_type] if opts[:problem_type] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:csi] = csi header_params[:ocid] = ocid header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:homeregion] = opts[:homeregion] if opts[:homeregion] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'IncidentClient#validate_user') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Cims::Models::ValidationResponse' ) end # rubocop:enable Metrics/BlockLength end |