Class: OCI::Cims::Models::ContextualData
- Inherits:
-
Object
- Object
- OCI::Cims::Models::ContextualData
- Defined in:
- lib/oci/cims/models/contextual_data.rb
Overview
ContextualData model.
Instance Attribute Summary collapse
-
#client_id ⇒ String
**[Required]** The unique client identifier.
-
#payload ⇒ String
**[Required]** The context data payload.
-
#schema_name ⇒ String
**[Required]** The schema name.
-
#schema_version ⇒ String
**[Required]** The schema version.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ContextualData
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ContextualData
Initializes the object
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/oci/cims/models/contextual_data.rb', line 60 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.client_id = attributes[:'clientId'] if attributes[:'clientId'] raise 'You cannot provide both :clientId and :client_id' if attributes.key?(:'clientId') && attributes.key?(:'client_id') self.client_id = attributes[:'client_id'] if attributes[:'client_id'] self.schema_name = attributes[:'schemaName'] if attributes[:'schemaName'] raise 'You cannot provide both :schemaName and :schema_name' if attributes.key?(:'schemaName') && attributes.key?(:'schema_name') self.schema_name = attributes[:'schema_name'] if attributes[:'schema_name'] self.schema_version = attributes[:'schemaVersion'] if attributes[:'schemaVersion'] raise 'You cannot provide both :schemaVersion and :schema_version' if attributes.key?(:'schemaVersion') && attributes.key?(:'schema_version') self.schema_version = attributes[:'schema_version'] if attributes[:'schema_version'] self.payload = attributes[:'payload'] if attributes[:'payload'] end |
Instance Attribute Details
#client_id ⇒ String
**[Required]** The unique client identifier
12 13 14 |
# File 'lib/oci/cims/models/contextual_data.rb', line 12 def client_id @client_id end |
#payload ⇒ String
**[Required]** The context data payload
24 25 26 |
# File 'lib/oci/cims/models/contextual_data.rb', line 24 def payload @payload end |
#schema_name ⇒ String
**[Required]** The schema name
16 17 18 |
# File 'lib/oci/cims/models/contextual_data.rb', line 16 def schema_name @schema_name end |
#schema_version ⇒ String
**[Required]** The schema version
20 21 22 |
# File 'lib/oci/cims/models/contextual_data.rb', line 20 def schema_version @schema_version end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
27 28 29 30 31 32 33 34 35 36 |
# File 'lib/oci/cims/models/contextual_data.rb', line 27 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'client_id': :'clientId', 'schema_name': :'schemaName', 'schema_version': :'schemaVersion', 'payload': :'payload' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
39 40 41 42 43 44 45 46 47 48 |
# File 'lib/oci/cims/models/contextual_data.rb', line 39 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'client_id': :'String', 'schema_name': :'String', 'schema_version': :'String', 'payload': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
94 95 96 97 98 99 100 101 102 |
# File 'lib/oci/cims/models/contextual_data.rb', line 94 def ==(other) return true if equal?(other) self.class == other.class && client_id == other.client_id && schema_name == other.schema_name && schema_version == other.schema_version && payload == other.payload end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/oci/cims/models/contextual_data.rb', line 127 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
107 108 109 |
# File 'lib/oci/cims/models/contextual_data.rb', line 107 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
116 117 118 |
# File 'lib/oci/cims/models/contextual_data.rb', line 116 def hash [client_id, schema_name, schema_version, payload].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
160 161 162 163 164 165 166 167 168 169 |
# File 'lib/oci/cims/models/contextual_data.rb', line 160 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
154 155 156 |
# File 'lib/oci/cims/models/contextual_data.rb', line 154 def to_s to_hash.to_s end |