Class: OCI::Cims::Models::CreateIncident
- Inherits:
-
Object
- Object
- OCI::Cims::Models::CreateIncident
- Defined in:
- lib/oci/cims/models/create_incident.rb
Overview
Details gathered during the creation of the support ticket.
Caution: Avoid using any confidential information when you supply string values using the API.
Constant Summary collapse
- PROBLEM_TYPE_ENUM =
[ PROBLEM_TYPE_LIMIT = 'LIMIT'.freeze, PROBLEM_TYPE_LEGACY_LIMIT = 'LEGACY_LIMIT'.freeze, PROBLEM_TYPE_TECH = 'TECH'.freeze, PROBLEM_TYPE_ACCOUNT = 'ACCOUNT'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The OCID of the tenancy.
-
#contacts ⇒ Array<OCI::Cims::Models::Contact>
The list of contacts.
-
#csi ⇒ String
The Customer Support Identifier number for the support account.
-
#problem_type ⇒ String
[Required] The kind of support ticket, such as a technical issue request.
-
#referrer ⇒ String
The incident referrer.
-
#ticket ⇒ OCI::Cims::Models::CreateTicketDetails
This attribute is required.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateIncident
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateIncident
Initializes the object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/oci/cims/models/create_incident.rb', line 84 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.ticket = attributes[:'ticket'] if attributes[:'ticket'] self.csi = attributes[:'csi'] if attributes[:'csi'] self.problem_type = attributes[:'problemType'] if attributes[:'problemType'] raise 'You cannot provide both :problemType and :problem_type' if attributes.key?(:'problemType') && attributes.key?(:'problem_type') self.problem_type = attributes[:'problem_type'] if attributes[:'problem_type'] self.contacts = attributes[:'contacts'] if attributes[:'contacts'] self.referrer = attributes[:'referrer'] if attributes[:'referrer'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The OCID of the tenancy.
22 23 24 |
# File 'lib/oci/cims/models/create_incident.rb', line 22 def compartment_id @compartment_id end |
#contacts ⇒ Array<OCI::Cims::Models::Contact>
The list of contacts.
38 39 40 |
# File 'lib/oci/cims/models/create_incident.rb', line 38 def contacts @contacts end |
#csi ⇒ String
The Customer Support Identifier number for the support account.
30 31 32 |
# File 'lib/oci/cims/models/create_incident.rb', line 30 def csi @csi end |
#problem_type ⇒ String
[Required] The kind of support ticket, such as a technical issue request.
34 35 36 |
# File 'lib/oci/cims/models/create_incident.rb', line 34 def problem_type @problem_type end |
#referrer ⇒ String
The incident referrer. This value is often the URL that the customer used when creating the support ticket.
42 43 44 |
# File 'lib/oci/cims/models/create_incident.rb', line 42 def referrer @referrer end |
#ticket ⇒ OCI::Cims::Models::CreateTicketDetails
This attribute is required.
26 27 28 |
# File 'lib/oci/cims/models/create_incident.rb', line 26 def ticket @ticket end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/oci/cims/models/create_incident.rb', line 45 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'ticket': :'ticket', 'csi': :'csi', 'problem_type': :'problemType', 'contacts': :'contacts', 'referrer': :'referrer' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/oci/cims/models/create_incident.rb', line 59 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'ticket': :'OCI::Cims::Models::CreateTicketDetails', 'csi': :'String', 'problem_type': :'String', 'contacts': :'Array<OCI::Cims::Models::Contact>', 'referrer': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/oci/cims/models/create_incident.rb', line 126 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && ticket == other.ticket && csi == other.csi && problem_type == other.problem_type && contacts == other.contacts && referrer == other.referrer end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/oci/cims/models/create_incident.rb', line 161 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
141 142 143 |
# File 'lib/oci/cims/models/create_incident.rb', line 141 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
150 151 152 |
# File 'lib/oci/cims/models/create_incident.rb', line 150 def hash [compartment_id, ticket, csi, problem_type, contacts, referrer].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
194 195 196 197 198 199 200 201 202 203 |
# File 'lib/oci/cims/models/create_incident.rb', line 194 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
188 189 190 |
# File 'lib/oci/cims/models/create_incident.rb', line 188 def to_s to_hash.to_s end |