Class: OCI::Cims::Models::ServiceCategory
- Inherits:
-
Object
- Object
- OCI::Cims::Models::ServiceCategory
- Defined in:
- lib/oci/cims/models/service_category.rb
Overview
Information about the incident classifier.
Constant Summary collapse
- SCOPE_ENUM =
[ SCOPE_AD = 'AD'.freeze, SCOPE_REGION = 'REGION'.freeze, SCOPE_TENANCY = 'TENANCY'.freeze, SCOPE_NONE = 'NONE'.freeze, SCOPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- UNIT_ENUM =
[ UNIT_COUNT = 'COUNT'.freeze, UNIT_GB = 'GB'.freeze, UNIT_NONE = 'NONE'.freeze, UNIT_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#description ⇒ String
The text describing the classifier.
-
#issue_type_list ⇒ Array<OCI::Cims::Models::IssueType>
The list of issues.
-
#key ⇒ String
The unique ID that identifies a classifier.
-
#label ⇒ String
The label for the classifier.
-
#limit_id ⇒ String
The unique ID for the limit.
-
#name ⇒ String
The name of the classifier.
-
#scope ⇒ String
The scope of the incident.
-
#unit ⇒ String
The unit to use to measure the service category or resource.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ServiceCategory
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ServiceCategory
Initializes the object
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/oci/cims/models/service_category.rb', line 104 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.key = attributes[:'key'] if attributes[:'key'] self.name = attributes[:'name'] if attributes[:'name'] self.label = attributes[:'label'] if attributes[:'label'] self.description = attributes[:'description'] if attributes[:'description'] self.issue_type_list = attributes[:'issueTypeList'] if attributes[:'issueTypeList'] raise 'You cannot provide both :issueTypeList and :issue_type_list' if attributes.key?(:'issueTypeList') && attributes.key?(:'issue_type_list') self.issue_type_list = attributes[:'issue_type_list'] if attributes[:'issue_type_list'] self.scope = attributes[:'scope'] if attributes[:'scope'] self.unit = attributes[:'unit'] if attributes[:'unit'] self.limit_id = attributes[:'limitId'] if attributes[:'limitId'] raise 'You cannot provide both :limitId and :limit_id' if attributes.key?(:'limitId') && attributes.key?(:'limit_id') self.limit_id = attributes[:'limit_id'] if attributes[:'limit_id'] end |
Instance Attribute Details
#description ⇒ String
The text describing the classifier.
40 41 42 |
# File 'lib/oci/cims/models/service_category.rb', line 40 def description @description end |
#issue_type_list ⇒ Array<OCI::Cims::Models::IssueType>
The list of issues.
44 45 46 |
# File 'lib/oci/cims/models/service_category.rb', line 44 def issue_type_list @issue_type_list end |
#key ⇒ String
The unique ID that identifies a classifier.
28 29 30 |
# File 'lib/oci/cims/models/service_category.rb', line 28 def key @key end |
#label ⇒ String
The label for the classifier.
36 37 38 |
# File 'lib/oci/cims/models/service_category.rb', line 36 def label @label end |
#limit_id ⇒ String
The unique ID for the limit.
56 57 58 |
# File 'lib/oci/cims/models/service_category.rb', line 56 def limit_id @limit_id end |
#name ⇒ String
The name of the classifier.
32 33 34 |
# File 'lib/oci/cims/models/service_category.rb', line 32 def name @name end |
#scope ⇒ String
The scope of the incident.
48 49 50 |
# File 'lib/oci/cims/models/service_category.rb', line 48 def scope @scope end |
#unit ⇒ String
The unit to use to measure the service category or resource.
52 53 54 |
# File 'lib/oci/cims/models/service_category.rb', line 52 def unit @unit end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/oci/cims/models/service_category.rb', line 59 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'key': :'key', 'name': :'name', 'label': :'label', 'description': :'description', 'issue_type_list': :'issueTypeList', 'scope': :'scope', 'unit': :'unit', 'limit_id': :'limitId' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/oci/cims/models/service_category.rb', line 75 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'key': :'String', 'name': :'String', 'label': :'String', 'description': :'String', 'issue_type_list': :'Array<OCI::Cims::Models::IssueType>', 'scope': :'String', 'unit': :'String', 'limit_id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/oci/cims/models/service_category.rb', line 168 def ==(other) return true if equal?(other) self.class == other.class && key == other.key && name == other.name && label == other.label && description == other.description && issue_type_list == other.issue_type_list && scope == other.scope && unit == other.unit && limit_id == other.limit_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/oci/cims/models/service_category.rb', line 205 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
185 186 187 |
# File 'lib/oci/cims/models/service_category.rb', line 185 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
194 195 196 |
# File 'lib/oci/cims/models/service_category.rb', line 194 def hash [key, name, label, description, issue_type_list, scope, unit, limit_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
238 239 240 241 242 243 244 245 246 247 |
# File 'lib/oci/cims/models/service_category.rb', line 238 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
232 233 234 |
# File 'lib/oci/cims/models/service_category.rb', line 232 def to_s to_hash.to_s end |