Class: OCI::Cims::Models::User
- Inherits:
-
Object
- Object
- OCI::Cims::Models::User
- Defined in:
- lib/oci/cims/models/user.rb
Overview
Details about the user object.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
The OCID of the tenancy.
-
#contact_email ⇒ String
The email of the contact person.
-
#country ⇒ String
Country of the user.
-
#csi ⇒ String
CSI to be associated to the user.
-
#first_name ⇒ String
First name of the user.
-
#key ⇒ String
[Required] Unique identifier for the user.
-
#last_name ⇒ String
Last name of the user.
-
#organization_name ⇒ String
Organization of the user.
-
#phone ⇒ String
Contact number of the user.
-
#timezone ⇒ String
Timezone of the user.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ User
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ User
Initializes the object
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/oci/cims/models/user.rb', line 103 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.key = attributes[:'key'] if attributes[:'key'] self.first_name = attributes[:'firstName'] if attributes[:'firstName'] raise 'You cannot provide both :firstName and :first_name' if attributes.key?(:'firstName') && attributes.key?(:'first_name') self.first_name = attributes[:'first_name'] if attributes[:'first_name'] self.last_name = attributes[:'lastName'] if attributes[:'lastName'] raise 'You cannot provide both :lastName and :last_name' if attributes.key?(:'lastName') && attributes.key?(:'last_name') self.last_name = attributes[:'last_name'] if attributes[:'last_name'] self.country = attributes[:'country'] if attributes[:'country'] self.csi = attributes[:'csi'] if attributes[:'csi'] self.phone = attributes[:'phone'] if attributes[:'phone'] self.timezone = attributes[:'timezone'] if attributes[:'timezone'] self.organization_name = attributes[:'organizationName'] if attributes[:'organizationName'] raise 'You cannot provide both :organizationName and :organization_name' if attributes.key?(:'organizationName') && attributes.key?(:'organization_name') self.organization_name = attributes[:'organization_name'] if attributes[:'organization_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.contact_email = attributes[:'contactEmail'] if attributes[:'contactEmail'] raise 'You cannot provide both :contactEmail and :contact_email' if attributes.key?(:'contactEmail') && attributes.key?(:'contact_email') self.contact_email = attributes[:'contact_email'] if attributes[:'contact_email'] end |
Instance Attribute Details
#compartment_id ⇒ String
The OCID of the tenancy.
45 46 47 |
# File 'lib/oci/cims/models/user.rb', line 45 def compartment_id @compartment_id end |
#contact_email ⇒ String
The email of the contact person.
49 50 51 |
# File 'lib/oci/cims/models/user.rb', line 49 def contact_email @contact_email end |
#country ⇒ String
Country of the user.
25 26 27 |
# File 'lib/oci/cims/models/user.rb', line 25 def country @country end |
#csi ⇒ String
CSI to be associated to the user.
29 30 31 |
# File 'lib/oci/cims/models/user.rb', line 29 def csi @csi end |
#first_name ⇒ String
First name of the user.
17 18 19 |
# File 'lib/oci/cims/models/user.rb', line 17 def first_name @first_name end |
#key ⇒ String
[Required] Unique identifier for the user.
13 14 15 |
# File 'lib/oci/cims/models/user.rb', line 13 def key @key end |
#last_name ⇒ String
Last name of the user.
21 22 23 |
# File 'lib/oci/cims/models/user.rb', line 21 def last_name @last_name end |
#organization_name ⇒ String
Organization of the user.
41 42 43 |
# File 'lib/oci/cims/models/user.rb', line 41 def organization_name @organization_name end |
#phone ⇒ String
Contact number of the user.
33 34 35 |
# File 'lib/oci/cims/models/user.rb', line 33 def phone @phone end |
#timezone ⇒ String
Timezone of the user.
37 38 39 |
# File 'lib/oci/cims/models/user.rb', line 37 def timezone @timezone end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/oci/cims/models/user.rb', line 52 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'key': :'key', 'first_name': :'firstName', 'last_name': :'lastName', 'country': :'country', 'csi': :'csi', 'phone': :'phone', 'timezone': :'timezone', 'organization_name': :'organizationName', 'compartment_id': :'compartmentId', 'contact_email': :'contactEmail' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/oci/cims/models/user.rb', line 70 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'key': :'String', 'first_name': :'String', 'last_name': :'String', 'country': :'String', 'csi': :'String', 'phone': :'String', 'timezone': :'String', 'organization_name': :'String', 'compartment_id': :'String', 'contact_email': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/oci/cims/models/user.rb', line 157 def ==(other) return true if equal?(other) self.class == other.class && key == other.key && first_name == other.first_name && last_name == other.last_name && country == other.country && csi == other.csi && phone == other.phone && timezone == other.timezone && organization_name == other.organization_name && compartment_id == other.compartment_id && contact_email == other.contact_email end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/oci/cims/models/user.rb', line 196 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
176 177 178 |
# File 'lib/oci/cims/models/user.rb', line 176 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
185 186 187 |
# File 'lib/oci/cims/models/user.rb', line 185 def hash [key, first_name, last_name, country, csi, phone, timezone, organization_name, compartment_id, contact_email].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
229 230 231 232 233 234 235 236 237 238 |
# File 'lib/oci/cims/models/user.rb', line 229 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
223 224 225 |
# File 'lib/oci/cims/models/user.rb', line 223 def to_s to_hash.to_s end |