Class: OCI::CloudGuard::Models::CompositeCondition
- Defined in:
- lib/oci/cloud_guard/models/composite_condition.rb
Overview
Composite Condition object with nested Condition
Constant Summary collapse
- COMPOSITE_OPERATOR_ENUM =
[ COMPOSITE_OPERATOR_AND = 'AND'.freeze, COMPOSITE_OPERATOR_OR = 'OR'.freeze, COMPOSITE_OPERATOR_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Constants inherited from Condition
OCI::CloudGuard::Models::Condition::KIND_ENUM
Instance Attribute Summary collapse
- #composite_operator ⇒ String
- #left_operand ⇒ OCI::CloudGuard::Models::Condition
- #right_operand ⇒ OCI::CloudGuard::Models::Condition
Attributes inherited from Condition
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CompositeCondition
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from Condition
Constructor Details
#initialize(attributes = {}) ⇒ CompositeCondition
Initializes the object
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/oci/cloud_guard/models/composite_condition.rb', line 60 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['kind'] = 'COMPOSITE' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.left_operand = attributes[:'leftOperand'] if attributes[:'leftOperand'] raise 'You cannot provide both :leftOperand and :left_operand' if attributes.key?(:'leftOperand') && attributes.key?(:'left_operand') self.left_operand = attributes[:'left_operand'] if attributes[:'left_operand'] self.composite_operator = attributes[:'compositeOperator'] if attributes[:'compositeOperator'] raise 'You cannot provide both :compositeOperator and :composite_operator' if attributes.key?(:'compositeOperator') && attributes.key?(:'composite_operator') self.composite_operator = attributes[:'composite_operator'] if attributes[:'composite_operator'] self.right_operand = attributes[:'rightOperand'] if attributes[:'rightOperand'] raise 'You cannot provide both :rightOperand and :right_operand' if attributes.key?(:'rightOperand') && attributes.key?(:'right_operand') self.right_operand = attributes[:'right_operand'] if attributes[:'right_operand'] end |
Instance Attribute Details
#composite_operator ⇒ String
22 23 24 |
# File 'lib/oci/cloud_guard/models/composite_condition.rb', line 22 def composite_operator @composite_operator end |
#left_operand ⇒ OCI::CloudGuard::Models::Condition
19 20 21 |
# File 'lib/oci/cloud_guard/models/composite_condition.rb', line 19 def left_operand @left_operand end |
#right_operand ⇒ OCI::CloudGuard::Models::Condition
25 26 27 |
# File 'lib/oci/cloud_guard/models/composite_condition.rb', line 25 def right_operand @right_operand end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 35 36 37 |
# File 'lib/oci/cloud_guard/models/composite_condition.rb', line 28 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'kind': :'kind', 'left_operand': :'leftOperand', 'composite_operator': :'compositeOperator', 'right_operand': :'rightOperand' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
40 41 42 43 44 45 46 47 48 49 |
# File 'lib/oci/cloud_guard/models/composite_condition.rb', line 40 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'kind': :'String', 'left_operand': :'OCI::CloudGuard::Models::Condition', 'composite_operator': :'String', 'right_operand': :'OCI::CloudGuard::Models::Condition' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
109 110 111 112 113 114 115 116 117 |
# File 'lib/oci/cloud_guard/models/composite_condition.rb', line 109 def ==(other) return true if equal?(other) self.class == other.class && kind == other.kind && left_operand == other.left_operand && composite_operator == other.composite_operator && right_operand == other.right_operand end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/oci/cloud_guard/models/composite_condition.rb', line 142 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
122 123 124 |
# File 'lib/oci/cloud_guard/models/composite_condition.rb', line 122 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
131 132 133 |
# File 'lib/oci/cloud_guard/models/composite_condition.rb', line 131 def hash [kind, left_operand, composite_operator, right_operand].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
175 176 177 178 179 180 181 182 183 184 |
# File 'lib/oci/cloud_guard/models/composite_condition.rb', line 175 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
169 170 171 |
# File 'lib/oci/cloud_guard/models/composite_condition.rb', line 169 def to_s to_hash.to_s end |