Class: OCI::CloudGuard::Models::CreateDataMaskRuleDetails
- Inherits:
-
Object
- Object
- OCI::CloudGuard::Models::CreateDataMaskRuleDetails
- Defined in:
- lib/oci/cloud_guard/models/create_data_mask_rule_details.rb
Overview
The information about new Data Mask Rule.
Constant Summary collapse
- DATA_MASK_CATEGORIES_ENUM =
[ DATA_MASK_CATEGORIES_ACTOR = 'ACTOR'.freeze, DATA_MASK_CATEGORIES_PII = 'PII'.freeze, DATA_MASK_CATEGORIES_PHI = 'PHI'.freeze, DATA_MASK_CATEGORIES_FINANCIAL = 'FINANCIAL'.freeze, DATA_MASK_CATEGORIES_LOCATION = 'LOCATION'.freeze, DATA_MASK_CATEGORIES_CUSTOM = 'CUSTOM'.freeze ].freeze
- DATA_MASK_RULE_STATUS_ENUM =
[ DATA_MASK_RULE_STATUS_ENABLED = 'ENABLED'.freeze, DATA_MASK_RULE_STATUS_DISABLED = 'DISABLED'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] Compartment Identifier where the resource is created.
-
#data_mask_categories ⇒ Array<String>
[Required] Data Mask Categories.
-
#data_mask_rule_status ⇒ String
The status of the dataMaskRule.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
The Data Mask Rule description.
-
#display_name ⇒ String
[Required] Data Mask Rule name.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#iam_group_id ⇒ String
[Required] IAM Group id associated with the data mask rule.
-
#lifecycle_state ⇒ String
The current state of the DataMaskRule.
-
#target_selected ⇒ OCI::CloudGuard::Models::TargetSelected
This attribute is required.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateDataMaskRuleDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateDataMaskRuleDetails
Initializes the object
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/oci/cloud_guard/models/create_data_mask_rule_details.rb', line 130 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.description = attributes[:'description'] if attributes[:'description'] self.iam_group_id = attributes[:'iamGroupId'] if attributes[:'iamGroupId'] raise 'You cannot provide both :iamGroupId and :iam_group_id' if attributes.key?(:'iamGroupId') && attributes.key?(:'iam_group_id') self.iam_group_id = attributes[:'iam_group_id'] if attributes[:'iam_group_id'] self.target_selected = attributes[:'targetSelected'] if attributes[:'targetSelected'] raise 'You cannot provide both :targetSelected and :target_selected' if attributes.key?(:'targetSelected') && attributes.key?(:'target_selected') self.target_selected = attributes[:'target_selected'] if attributes[:'target_selected'] self.data_mask_categories = attributes[:'dataMaskCategories'] if attributes[:'dataMaskCategories'] raise 'You cannot provide both :dataMaskCategories and :data_mask_categories' if attributes.key?(:'dataMaskCategories') && attributes.key?(:'data_mask_categories') self.data_mask_categories = attributes[:'data_mask_categories'] if attributes[:'data_mask_categories'] self.data_mask_rule_status = attributes[:'dataMaskRuleStatus'] if attributes[:'dataMaskRuleStatus'] raise 'You cannot provide both :dataMaskRuleStatus and :data_mask_rule_status' if attributes.key?(:'dataMaskRuleStatus') && attributes.key?(:'data_mask_rule_status') self.data_mask_rule_status = attributes[:'data_mask_rule_status'] if attributes[:'data_mask_rule_status'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] Compartment Identifier where the resource is created
40 41 42 |
# File 'lib/oci/cloud_guard/models/create_data_mask_rule_details.rb', line 40 def compartment_id @compartment_id end |
#data_mask_categories ⇒ Array<String>
[Required] Data Mask Categories
56 57 58 |
# File 'lib/oci/cloud_guard/models/create_data_mask_rule_details.rb', line 56 def data_mask_categories @data_mask_categories end |
#data_mask_rule_status ⇒ String
The status of the dataMaskRule.
60 61 62 |
# File 'lib/oci/cloud_guard/models/create_data_mask_rule_details.rb', line 60 def data_mask_rule_status @data_mask_rule_status end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
76 77 78 |
# File 'lib/oci/cloud_guard/models/create_data_mask_rule_details.rb', line 76 def end |
#description ⇒ String
The Data Mask Rule description.
44 45 46 |
# File 'lib/oci/cloud_guard/models/create_data_mask_rule_details.rb', line 44 def description @description end |
#display_name ⇒ String
[Required] Data Mask Rule name
36 37 38 |
# File 'lib/oci/cloud_guard/models/create_data_mask_rule_details.rb', line 36 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`
70 71 72 |
# File 'lib/oci/cloud_guard/models/create_data_mask_rule_details.rb', line 70 def end |
#iam_group_id ⇒ String
[Required] IAM Group id associated with the data mask rule
48 49 50 |
# File 'lib/oci/cloud_guard/models/create_data_mask_rule_details.rb', line 48 def iam_group_id @iam_group_id end |
#lifecycle_state ⇒ String
The current state of the DataMaskRule.
64 65 66 |
# File 'lib/oci/cloud_guard/models/create_data_mask_rule_details.rb', line 64 def lifecycle_state @lifecycle_state end |
#target_selected ⇒ OCI::CloudGuard::Models::TargetSelected
This attribute is required.
52 53 54 |
# File 'lib/oci/cloud_guard/models/create_data_mask_rule_details.rb', line 52 def target_selected @target_selected end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/oci/cloud_guard/models/create_data_mask_rule_details.rb', line 79 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'description': :'description', 'iam_group_id': :'iamGroupId', 'target_selected': :'targetSelected', 'data_mask_categories': :'dataMaskCategories', 'data_mask_rule_status': :'dataMaskRuleStatus', 'lifecycle_state': :'lifecycleState', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/oci/cloud_guard/models/create_data_mask_rule_details.rb', line 97 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'compartment_id': :'String', 'description': :'String', 'iam_group_id': :'String', 'target_selected': :'OCI::CloudGuard::Models::TargetSelected', 'data_mask_categories': :'Array<String>', 'data_mask_rule_status': :'String', 'lifecycle_state': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/oci/cloud_guard/models/create_data_mask_rule_details.rb', line 231 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && compartment_id == other.compartment_id && description == other.description && iam_group_id == other.iam_group_id && target_selected == other.target_selected && data_mask_categories == other.data_mask_categories && data_mask_rule_status == other.data_mask_rule_status && lifecycle_state == other.lifecycle_state && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 |
# File 'lib/oci/cloud_guard/models/create_data_mask_rule_details.rb', line 270 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
250 251 252 |
# File 'lib/oci/cloud_guard/models/create_data_mask_rule_details.rb', line 250 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
259 260 261 |
# File 'lib/oci/cloud_guard/models/create_data_mask_rule_details.rb', line 259 def hash [display_name, compartment_id, description, iam_group_id, target_selected, data_mask_categories, data_mask_rule_status, lifecycle_state, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
303 304 305 306 307 308 309 310 311 312 |
# File 'lib/oci/cloud_guard/models/create_data_mask_rule_details.rb', line 303 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
297 298 299 |
# File 'lib/oci/cloud_guard/models/create_data_mask_rule_details.rb', line 297 def to_s to_hash.to_s end |