Class: OCI::CloudGuard::Models::CreateDetectorRecipeDetails
- Inherits:
-
Object
- Object
- OCI::CloudGuard::Models::CreateDetectorRecipeDetails
- Defined in:
- lib/oci/cloud_guard/models/create_detector_recipe_details.rb
Overview
Create of Detector recipe.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** Compartment Identifier.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
Detector recipe description.
-
#detector_rules ⇒ Array<OCI::CloudGuard::Models::UpdateDetectorRecipeDetectorRule>
Detector Rules to override from source detector recipe.
-
#display_name ⇒ String
**[Required]** Detector recipe display name.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#source_detector_recipe_id ⇒ String
**[Required]** The id of the source detector recipe.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateDetectorRecipeDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateDetectorRecipeDetails
Initializes the object
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/oci/cloud_guard/models/create_detector_recipe_details.rb', line 93 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.source_detector_recipe_id = attributes[:'sourceDetectorRecipeId'] if attributes[:'sourceDetectorRecipeId'] raise 'You cannot provide both :sourceDetectorRecipeId and :source_detector_recipe_id' if attributes.key?(:'sourceDetectorRecipeId') && attributes.key?(:'source_detector_recipe_id') self.source_detector_recipe_id = attributes[:'source_detector_recipe_id'] if attributes[:'source_detector_recipe_id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.detector_rules = attributes[:'detectorRules'] if attributes[:'detectorRules'] raise 'You cannot provide both :detectorRules and :detector_rules' if attributes.key?(:'detectorRules') && attributes.key?(:'detector_rules') self.detector_rules = attributes[:'detector_rules'] if attributes[:'detector_rules'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** Compartment Identifier
30 31 32 |
# File 'lib/oci/cloud_guard/models/create_detector_recipe_details.rb', line 30 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
48 49 50 |
# File 'lib/oci/cloud_guard/models/create_detector_recipe_details.rb', line 48 def @defined_tags end |
#description ⇒ String
Detector recipe description.
Avoid entering confidential information.
22 23 24 |
# File 'lib/oci/cloud_guard/models/create_detector_recipe_details.rb', line 22 def description @description end |
#detector_rules ⇒ Array<OCI::CloudGuard::Models::UpdateDetectorRecipeDetectorRule>
Detector Rules to override from source detector recipe
34 35 36 |
# File 'lib/oci/cloud_guard/models/create_detector_recipe_details.rb', line 34 def detector_rules @detector_rules end |
#display_name ⇒ String
**[Required]** Detector recipe display name.
Avoid entering confidential information.
15 16 17 |
# File 'lib/oci/cloud_guard/models/create_detector_recipe_details.rb', line 15 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
Avoid entering confidential information.
42 43 44 |
# File 'lib/oci/cloud_guard/models/create_detector_recipe_details.rb', line 42 def @freeform_tags end |
#source_detector_recipe_id ⇒ String
**[Required]** The id of the source detector recipe.
26 27 28 |
# File 'lib/oci/cloud_guard/models/create_detector_recipe_details.rb', line 26 def source_detector_recipe_id @source_detector_recipe_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/oci/cloud_guard/models/create_detector_recipe_details.rb', line 51 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'description': :'description', 'source_detector_recipe_id': :'sourceDetectorRecipeId', 'compartment_id': :'compartmentId', 'detector_rules': :'detectorRules', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/oci/cloud_guard/models/create_detector_recipe_details.rb', line 66 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'description': :'String', 'source_detector_recipe_id': :'String', 'compartment_id': :'String', 'detector_rules': :'Array<OCI::CloudGuard::Models::UpdateDetectorRecipeDetectorRule>', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/oci/cloud_guard/models/create_detector_recipe_details.rb', line 145 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && description == other.description && source_detector_recipe_id == other.source_detector_recipe_id && compartment_id == other.compartment_id && detector_rules == other.detector_rules && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/oci/cloud_guard/models/create_detector_recipe_details.rb', line 181 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
161 162 163 |
# File 'lib/oci/cloud_guard/models/create_detector_recipe_details.rb', line 161 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
170 171 172 |
# File 'lib/oci/cloud_guard/models/create_detector_recipe_details.rb', line 170 def hash [display_name, description, source_detector_recipe_id, compartment_id, detector_rules, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
214 215 216 217 218 219 220 221 222 223 |
# File 'lib/oci/cloud_guard/models/create_detector_recipe_details.rb', line 214 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
208 209 210 |
# File 'lib/oci/cloud_guard/models/create_detector_recipe_details.rb', line 208 def to_s to_hash.to_s end |