Class: OCI::CloudGuard::Models::CreateManagedListDetails
- Inherits:
-
Object
- Object
- OCI::CloudGuard::Models::CreateManagedListDetails
- Defined in:
- lib/oci/cloud_guard/models/create_managed_list_details.rb
Overview
Create ManagedList
Constant Summary collapse
- LIST_TYPE_ENUM =
[ LIST_TYPE_CIDR_BLOCK = 'CIDR_BLOCK'.freeze, LIST_TYPE_USERS = 'USERS'.freeze, LIST_TYPE_GROUPS = 'GROUPS'.freeze, LIST_TYPE_IPV4_ADDRESS = 'IPV4ADDRESS'.freeze, LIST_TYPE_IPV6_ADDRESS = 'IPV6ADDRESS'.freeze, LIST_TYPE_RESOURCE_OCID = 'RESOURCE_OCID'.freeze, LIST_TYPE_REGION = 'REGION'.freeze, LIST_TYPE_COUNTRY = 'COUNTRY'.freeze, LIST_TYPE_STATE = 'STATE'.freeze, LIST_TYPE_CITY = 'CITY'.freeze, LIST_TYPE_TAGS = 'TAGS'.freeze, LIST_TYPE_GENERIC = 'GENERIC'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** Compartment Identifier.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
Managed list description.
-
#display_name ⇒ String
**[Required]** Managed list display name.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#list_items ⇒ Array<String>
List of ManagedListItem.
-
#list_type ⇒ String
type of the list.
-
#source_managed_list_id ⇒ String
OCID of the Source ManagedList.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateManagedListDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateManagedListDetails
Initializes the object
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/oci/cloud_guard/models/create_managed_list_details.rb', line 115 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.source_managed_list_id = attributes[:'sourceManagedListId'] if attributes[:'sourceManagedListId'] raise 'You cannot provide both :sourceManagedListId and :source_managed_list_id' if attributes.key?(:'sourceManagedListId') && attributes.key?(:'source_managed_list_id') self.source_managed_list_id = attributes[:'source_managed_list_id'] if attributes[:'source_managed_list_id'] self.description = attributes[:'description'] if attributes[:'description'] self.list_type = attributes[:'listType'] if attributes[:'listType'] raise 'You cannot provide both :listType and :list_type' if attributes.key?(:'listType') && attributes.key?(:'list_type') self.list_type = attributes[:'list_type'] if attributes[:'list_type'] self.list_items = attributes[:'listItems'] if attributes[:'listItems'] raise 'You cannot provide both :listItems and :list_items' if attributes.key?(:'listItems') && attributes.key?(:'list_items') self.list_items = attributes[:'list_items'] if attributes[:'list_items'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** Compartment Identifier
34 35 36 |
# File 'lib/oci/cloud_guard/models/create_managed_list_details.rb', line 34 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
67 68 69 |
# File 'lib/oci/cloud_guard/models/create_managed_list_details.rb', line 67 def @defined_tags end |
#description ⇒ String
Managed list description.
Avoid entering confidential information.
45 46 47 |
# File 'lib/oci/cloud_guard/models/create_managed_list_details.rb', line 45 def description @description end |
#display_name ⇒ String
**[Required]** Managed list display name.
Avoid entering confidential information.
30 31 32 |
# File 'lib/oci/cloud_guard/models/create_managed_list_details.rb', line 30 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
Avoid entering confidential information.
61 62 63 |
# File 'lib/oci/cloud_guard/models/create_managed_list_details.rb', line 61 def @freeform_tags end |
#list_items ⇒ Array<String>
List of ManagedListItem
53 54 55 |
# File 'lib/oci/cloud_guard/models/create_managed_list_details.rb', line 53 def list_items @list_items end |
#list_type ⇒ String
type of the list
49 50 51 |
# File 'lib/oci/cloud_guard/models/create_managed_list_details.rb', line 49 def list_type @list_type end |
#source_managed_list_id ⇒ String
OCID of the Source ManagedList
38 39 40 |
# File 'lib/oci/cloud_guard/models/create_managed_list_details.rb', line 38 def source_managed_list_id @source_managed_list_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/oci/cloud_guard/models/create_managed_list_details.rb', line 70 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'source_managed_list_id': :'sourceManagedListId', 'description': :'description', 'list_type': :'listType', 'list_items': :'listItems', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/oci/cloud_guard/models/create_managed_list_details.rb', line 86 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'compartment_id': :'String', 'source_managed_list_id': :'String', 'description': :'String', 'list_type': :'String', 'list_items': :'Array<String>', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/oci/cloud_guard/models/create_managed_list_details.rb', line 181 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && compartment_id == other.compartment_id && source_managed_list_id == other.source_managed_list_id && description == other.description && list_type == other.list_type && list_items == other.list_items && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/oci/cloud_guard/models/create_managed_list_details.rb', line 218 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
198 199 200 |
# File 'lib/oci/cloud_guard/models/create_managed_list_details.rb', line 198 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
207 208 209 |
# File 'lib/oci/cloud_guard/models/create_managed_list_details.rb', line 207 def hash [display_name, compartment_id, source_managed_list_id, description, list_type, list_items, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
251 252 253 254 255 256 257 258 259 260 |
# File 'lib/oci/cloud_guard/models/create_managed_list_details.rb', line 251 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
245 246 247 |
# File 'lib/oci/cloud_guard/models/create_managed_list_details.rb', line 245 def to_s to_hash.to_s end |