Class: OCI::CloudGuard::Models::CreateSecurityPolicyDetails
- Inherits:
-
Object
- Object
- OCI::CloudGuard::Models::CreateSecurityPolicyDetails
- Defined in:
- lib/oci/cloud_guard/models/create_security_policy_details.rb
Overview
The information about new SecurityPolicy.
Instance Attribute Summary collapse
-
#category ⇒ String
The category of security policy.
-
#compartment_id ⇒ String
**[Required]** Compartment Identifier.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
Security policy description.
-
#display_name ⇒ String
**[Required]** SecurityPolicy Identifier.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#friendly_name ⇒ String
SecurityPolicy friendly name.
-
#services ⇒ Array<String>
The list of services for policy.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateSecurityPolicyDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateSecurityPolicyDetails
Initializes the object
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/oci/cloud_guard/models/create_security_policy_details.rb', line 94 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.friendly_name = attributes[:'friendlyName'] if attributes[:'friendlyName'] raise 'You cannot provide both :friendlyName and :friendly_name' if attributes.key?(:'friendlyName') && attributes.key?(:'friendly_name') self.friendly_name = attributes[:'friendly_name'] if attributes[:'friendly_name'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.category = attributes[:'category'] if attributes[:'category'] self.services = attributes[:'services'] if attributes[:'services'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#category ⇒ String
The category of security policy.
24 25 26 |
# File 'lib/oci/cloud_guard/models/create_security_policy_details.rb', line 24 def category @category end |
#compartment_id ⇒ String
**[Required]** Compartment Identifier
32 33 34 |
# File 'lib/oci/cloud_guard/models/create_security_policy_details.rb', line 32 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
46 47 48 |
# File 'lib/oci/cloud_guard/models/create_security_policy_details.rb', line 46 def @defined_tags end |
#description ⇒ String
Security policy description
20 21 22 |
# File 'lib/oci/cloud_guard/models/create_security_policy_details.rb', line 20 def description @description end |
#display_name ⇒ String
**[Required]** SecurityPolicy Identifier
16 17 18 |
# File 'lib/oci/cloud_guard/models/create_security_policy_details.rb', line 16 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
Avoid entering confidential information.
40 41 42 |
# File 'lib/oci/cloud_guard/models/create_security_policy_details.rb', line 40 def @freeform_tags end |
#friendly_name ⇒ String
SecurityPolicy friendly name
12 13 14 |
# File 'lib/oci/cloud_guard/models/create_security_policy_details.rb', line 12 def friendly_name @friendly_name end |
#services ⇒ Array<String>
The list of services for policy.
28 29 30 |
# File 'lib/oci/cloud_guard/models/create_security_policy_details.rb', line 28 def services @services end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/oci/cloud_guard/models/create_security_policy_details.rb', line 49 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'friendly_name': :'friendlyName', 'display_name': :'displayName', 'description': :'description', 'category': :'category', 'services': :'services', 'compartment_id': :'compartmentId', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/oci/cloud_guard/models/create_security_policy_details.rb', line 65 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'friendly_name': :'String', 'display_name': :'String', 'description': :'String', 'category': :'String', 'services': :'Array<String>', 'compartment_id': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/oci/cloud_guard/models/create_security_policy_details.rb', line 144 def ==(other) return true if equal?(other) self.class == other.class && friendly_name == other.friendly_name && display_name == other.display_name && description == other.description && category == other.category && services == other.services && compartment_id == other.compartment_id && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/oci/cloud_guard/models/create_security_policy_details.rb', line 181 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
161 162 163 |
# File 'lib/oci/cloud_guard/models/create_security_policy_details.rb', line 161 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
170 171 172 |
# File 'lib/oci/cloud_guard/models/create_security_policy_details.rb', line 170 def hash [friendly_name, display_name, description, category, services, compartment_id, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
214 215 216 217 218 219 220 221 222 223 |
# File 'lib/oci/cloud_guard/models/create_security_policy_details.rb', line 214 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
208 209 210 |
# File 'lib/oci/cloud_guard/models/create_security_policy_details.rb', line 208 def to_s to_hash.to_s end |