Class: OCI::CloudGuard::Models::CreateTargetDetails
- Inherits:
-
Object
- Object
- OCI::CloudGuard::Models::CreateTargetDetails
- Defined in:
- lib/oci/cloud_guard/models/create_target_details.rb
Overview
The information about new Target.
Constant Summary collapse
- TARGET_RESOURCE_TYPE_ENUM =
[ TARGET_RESOURCE_TYPE_COMPARTMENT = 'COMPARTMENT'.freeze, TARGET_RESOURCE_TYPE_ERPCLOUD = 'ERPCLOUD'.freeze, TARGET_RESOURCE_TYPE_HCMCLOUD = 'HCMCLOUD'.freeze, TARGET_RESOURCE_TYPE_SECURITY_ZONE = 'SECURITY_ZONE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** Compartment Identifier where the resource is created.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
The target description.
-
#display_name ⇒ String
**[Required]** DetectorTemplate identifier.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#lifecycle_state ⇒ String
The current state of the DetectorRule.
-
#target_detector_recipes ⇒ Array<OCI::CloudGuard::Models::CreateTargetDetectorRecipeDetails>
List of detector recipes to associate with target.
-
#target_resource_id ⇒ String
**[Required]** Resource ID which the target uses to monitor.
-
#target_resource_type ⇒ String
**[Required]** possible type of targets(compartment/HCMCloud/ERPCloud).
-
#target_responder_recipes ⇒ Array<OCI::CloudGuard::Models::CreateTargetResponderRecipeDetails>
List of responder recipes to associate with target.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateTargetDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateTargetDetails
Initializes the object
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/oci/cloud_guard/models/create_target_details.rb', line 131 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.description = attributes[:'description'] if attributes[:'description'] self.target_resource_type = attributes[:'targetResourceType'] if attributes[:'targetResourceType'] raise 'You cannot provide both :targetResourceType and :target_resource_type' if attributes.key?(:'targetResourceType') && attributes.key?(:'target_resource_type') self.target_resource_type = attributes[:'target_resource_type'] if attributes[:'target_resource_type'] self.target_resource_id = attributes[:'targetResourceId'] if attributes[:'targetResourceId'] raise 'You cannot provide both :targetResourceId and :target_resource_id' if attributes.key?(:'targetResourceId') && attributes.key?(:'target_resource_id') self.target_resource_id = attributes[:'target_resource_id'] if attributes[:'target_resource_id'] self.target_detector_recipes = attributes[:'targetDetectorRecipes'] if attributes[:'targetDetectorRecipes'] raise 'You cannot provide both :targetDetectorRecipes and :target_detector_recipes' if attributes.key?(:'targetDetectorRecipes') && attributes.key?(:'target_detector_recipes') self.target_detector_recipes = attributes[:'target_detector_recipes'] if attributes[:'target_detector_recipes'] self.target_responder_recipes = attributes[:'targetResponderRecipes'] if attributes[:'targetResponderRecipes'] raise 'You cannot provide both :targetResponderRecipes and :target_responder_recipes' if attributes.key?(:'targetResponderRecipes') && attributes.key?(:'target_responder_recipes') self.target_responder_recipes = attributes[:'target_responder_recipes'] if attributes[:'target_responder_recipes'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** Compartment Identifier where the resource is created
36 37 38 |
# File 'lib/oci/cloud_guard/models/create_target_details.rb', line 36 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
77 78 79 |
# File 'lib/oci/cloud_guard/models/create_target_details.rb', line 77 def @defined_tags end |
#description ⇒ String
The target description.
Avoid entering confidential information.
43 44 45 |
# File 'lib/oci/cloud_guard/models/create_target_details.rb', line 43 def description @description end |
#display_name ⇒ String
**[Required]** DetectorTemplate identifier.
Avoid entering confidential information.
32 33 34 |
# File 'lib/oci/cloud_guard/models/create_target_details.rb', line 32 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
Avoid entering confidential information.
71 72 73 |
# File 'lib/oci/cloud_guard/models/create_target_details.rb', line 71 def @freeform_tags end |
#lifecycle_state ⇒ String
The current state of the DetectorRule.
63 64 65 |
# File 'lib/oci/cloud_guard/models/create_target_details.rb', line 63 def lifecycle_state @lifecycle_state end |
#target_detector_recipes ⇒ Array<OCI::CloudGuard::Models::CreateTargetDetectorRecipeDetails>
List of detector recipes to associate with target
55 56 57 |
# File 'lib/oci/cloud_guard/models/create_target_details.rb', line 55 def target_detector_recipes @target_detector_recipes end |
#target_resource_id ⇒ String
**[Required]** Resource ID which the target uses to monitor
51 52 53 |
# File 'lib/oci/cloud_guard/models/create_target_details.rb', line 51 def target_resource_id @target_resource_id end |
#target_resource_type ⇒ String
**[Required]** possible type of targets(compartment/HCMCloud/ERPCloud)
47 48 49 |
# File 'lib/oci/cloud_guard/models/create_target_details.rb', line 47 def target_resource_type @target_resource_type end |
#target_responder_recipes ⇒ Array<OCI::CloudGuard::Models::CreateTargetResponderRecipeDetails>
List of responder recipes to associate with target
59 60 61 |
# File 'lib/oci/cloud_guard/models/create_target_details.rb', line 59 def target_responder_recipes @target_responder_recipes end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/oci/cloud_guard/models/create_target_details.rb', line 80 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'description': :'description', 'target_resource_type': :'targetResourceType', 'target_resource_id': :'targetResourceId', 'target_detector_recipes': :'targetDetectorRecipes', 'target_responder_recipes': :'targetResponderRecipes', 'lifecycle_state': :'lifecycleState', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/oci/cloud_guard/models/create_target_details.rb', line 98 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'compartment_id': :'String', 'description': :'String', 'target_resource_type': :'String', 'target_resource_id': :'String', 'target_detector_recipes': :'Array<OCI::CloudGuard::Models::CreateTargetDetectorRecipeDetails>', 'target_responder_recipes': :'Array<OCI::CloudGuard::Models::CreateTargetResponderRecipeDetails>', 'lifecycle_state': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/oci/cloud_guard/models/create_target_details.rb', line 217 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && compartment_id == other.compartment_id && description == other.description && target_resource_type == other.target_resource_type && target_resource_id == other.target_resource_id && target_detector_recipes == other.target_detector_recipes && target_responder_recipes == other.target_responder_recipes && lifecycle_state == other.lifecycle_state && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 |
# File 'lib/oci/cloud_guard/models/create_target_details.rb', line 256 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
236 237 238 |
# File 'lib/oci/cloud_guard/models/create_target_details.rb', line 236 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
245 246 247 |
# File 'lib/oci/cloud_guard/models/create_target_details.rb', line 245 def hash [display_name, compartment_id, description, target_resource_type, target_resource_id, target_detector_recipes, target_responder_recipes, lifecycle_state, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
289 290 291 292 293 294 295 296 297 298 |
# File 'lib/oci/cloud_guard/models/create_target_details.rb', line 289 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
283 284 285 |
# File 'lib/oci/cloud_guard/models/create_target_details.rb', line 283 def to_s to_hash.to_s end |