Class: OCI::CloudGuard::Models::DataMaskRule
- Inherits:
-
Object
- Object
- OCI::CloudGuard::Models::DataMaskRule
- Defined in:
- lib/oci/cloud_guard/models/data_mask_rule.rb
Overview
Description of DataMaskRule.
Constant Summary collapse
- DATA_MASK_CATEGORIES_ENUM =
[ DATA_MASK_CATEGORIES_ACTOR = 'ACTOR'.freeze, DATA_MASK_CATEGORIES_PII = 'PII'.freeze, DATA_MASK_CATEGORIES_PHI = 'PHI'.freeze, DATA_MASK_CATEGORIES_FINANCIAL = 'FINANCIAL'.freeze, DATA_MASK_CATEGORIES_LOCATION = 'LOCATION'.freeze, DATA_MASK_CATEGORIES_CUSTOM = 'CUSTOM'.freeze, DATA_MASK_CATEGORIES_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- DATA_MASK_RULE_STATUS_ENUM =
[ DATA_MASK_RULE_STATUS_ENABLED = 'ENABLED'.freeze, DATA_MASK_RULE_STATUS_DISABLED = 'DISABLED'.freeze, DATA_MASK_RULE_STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] Compartment Identifier where the resource is created.
-
#data_mask_categories ⇒ Array<String>
Data Mask Categories.
-
#data_mask_rule_status ⇒ String
The status of the dataMaskRule.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
The data mask rule description.
-
#display_name ⇒ String
Data Mask Rule Identifier, can be renamed.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#iam_group_id ⇒ String
[Required] IAM Group id associated with the data mask rule.
-
#id ⇒ String
[Required] Unique identifier that is immutable on creation.
-
#lifecycle_state ⇒ String
The current state of the DataMaskRule.
-
#lifecyle_details ⇒ String
A message describing the current state in more detail.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
System tags for this resource.
-
#target_selected ⇒ OCI::CloudGuard::Models::TargetSelected
This attribute is required.
-
#time_created ⇒ DateTime
The date and time the target was created.
-
#time_updated ⇒ DateTime
The date and time the target was updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DataMaskRule
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DataMaskRule
Initializes the object
174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/oci/cloud_guard/models/data_mask_rule.rb', line 174 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.description = attributes[:'description'] if attributes[:'description'] self.iam_group_id = attributes[:'iamGroupId'] if attributes[:'iamGroupId'] raise 'You cannot provide both :iamGroupId and :iam_group_id' if attributes.key?(:'iamGroupId') && attributes.key?(:'iam_group_id') self.iam_group_id = attributes[:'iam_group_id'] if attributes[:'iam_group_id'] self.target_selected = attributes[:'targetSelected'] if attributes[:'targetSelected'] raise 'You cannot provide both :targetSelected and :target_selected' if attributes.key?(:'targetSelected') && attributes.key?(:'target_selected') self.target_selected = attributes[:'target_selected'] if attributes[:'target_selected'] self.data_mask_categories = attributes[:'dataMaskCategories'] if attributes[:'dataMaskCategories'] raise 'You cannot provide both :dataMaskCategories and :data_mask_categories' if attributes.key?(:'dataMaskCategories') && attributes.key?(:'data_mask_categories') self.data_mask_categories = attributes[:'data_mask_categories'] if attributes[:'data_mask_categories'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.data_mask_rule_status = attributes[:'dataMaskRuleStatus'] if attributes[:'dataMaskRuleStatus'] raise 'You cannot provide both :dataMaskRuleStatus and :data_mask_rule_status' if attributes.key?(:'dataMaskRuleStatus') && attributes.key?(:'data_mask_rule_status') self.data_mask_rule_status = attributes[:'data_mask_rule_status'] if attributes[:'data_mask_rule_status'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecyle_details = attributes[:'lifecyleDetails'] if attributes[:'lifecyleDetails'] raise 'You cannot provide both :lifecyleDetails and :lifecyle_details' if attributes.key?(:'lifecyleDetails') && attributes.key?(:'lifecyle_details') self.lifecyle_details = attributes[:'lifecyle_details'] if attributes[:'lifecyle_details'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] Compartment Identifier where the resource is created
48 49 50 |
# File 'lib/oci/cloud_guard/models/data_mask_rule.rb', line 48 def compartment_id @compartment_id end |
#data_mask_categories ⇒ Array<String>
Data Mask Categories
64 65 66 |
# File 'lib/oci/cloud_guard/models/data_mask_rule.rb', line 64 def data_mask_categories @data_mask_categories end |
#data_mask_rule_status ⇒ String
The status of the dataMaskRule.
76 77 78 |
# File 'lib/oci/cloud_guard/models/data_mask_rule.rb', line 76 def data_mask_rule_status @data_mask_rule_status end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
96 97 98 |
# File 'lib/oci/cloud_guard/models/data_mask_rule.rb', line 96 def end |
#description ⇒ String
The data mask rule description.
52 53 54 |
# File 'lib/oci/cloud_guard/models/data_mask_rule.rb', line 52 def description @description end |
#display_name ⇒ String
Data Mask Rule Identifier, can be renamed
44 45 46 |
# File 'lib/oci/cloud_guard/models/data_mask_rule.rb', line 44 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`
90 91 92 |
# File 'lib/oci/cloud_guard/models/data_mask_rule.rb', line 90 def end |
#iam_group_id ⇒ String
[Required] IAM Group id associated with the data mask rule
56 57 58 |
# File 'lib/oci/cloud_guard/models/data_mask_rule.rb', line 56 def iam_group_id @iam_group_id end |
#id ⇒ String
[Required] Unique identifier that is immutable on creation
40 41 42 |
# File 'lib/oci/cloud_guard/models/data_mask_rule.rb', line 40 def id @id end |
#lifecycle_state ⇒ String
The current state of the DataMaskRule.
80 81 82 |
# File 'lib/oci/cloud_guard/models/data_mask_rule.rb', line 80 def lifecycle_state @lifecycle_state end |
#lifecyle_details ⇒ String
A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
84 85 86 |
# File 'lib/oci/cloud_guard/models/data_mask_rule.rb', line 84 def lifecyle_details @lifecyle_details end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
System tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). System tags can be viewed by users, but can only be created by the system.
Example: ‘{"free-tier-retained": "true"}`
105 106 107 |
# File 'lib/oci/cloud_guard/models/data_mask_rule.rb', line 105 def end |
#target_selected ⇒ OCI::CloudGuard::Models::TargetSelected
This attribute is required.
60 61 62 |
# File 'lib/oci/cloud_guard/models/data_mask_rule.rb', line 60 def target_selected @target_selected end |
#time_created ⇒ DateTime
The date and time the target was created. Format defined by RFC3339.
68 69 70 |
# File 'lib/oci/cloud_guard/models/data_mask_rule.rb', line 68 def time_created @time_created end |
#time_updated ⇒ DateTime
The date and time the target was updated. Format defined by RFC3339.
72 73 74 |
# File 'lib/oci/cloud_guard/models/data_mask_rule.rb', line 72 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/oci/cloud_guard/models/data_mask_rule.rb', line 108 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'description': :'description', 'iam_group_id': :'iamGroupId', 'target_selected': :'targetSelected', 'data_mask_categories': :'dataMaskCategories', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'data_mask_rule_status': :'dataMaskRuleStatus', 'lifecycle_state': :'lifecycleState', 'lifecyle_details': :'lifecyleDetails', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/oci/cloud_guard/models/data_mask_rule.rb', line 131 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'compartment_id': :'String', 'description': :'String', 'iam_group_id': :'String', 'target_selected': :'OCI::CloudGuard::Models::TargetSelected', 'data_mask_categories': :'Array<String>', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'data_mask_rule_status': :'String', 'lifecycle_state': :'String', 'lifecyle_details': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'lib/oci/cloud_guard/models/data_mask_rule.rb', line 316 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && compartment_id == other.compartment_id && description == other.description && iam_group_id == other.iam_group_id && target_selected == other.target_selected && data_mask_categories == other.data_mask_categories && time_created == other.time_created && time_updated == other.time_updated && data_mask_rule_status == other.data_mask_rule_status && lifecycle_state == other.lifecycle_state && lifecyle_details == other.lifecyle_details && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 |
# File 'lib/oci/cloud_guard/models/data_mask_rule.rb', line 360 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
340 341 342 |
# File 'lib/oci/cloud_guard/models/data_mask_rule.rb', line 340 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
349 350 351 |
# File 'lib/oci/cloud_guard/models/data_mask_rule.rb', line 349 def hash [id, display_name, compartment_id, description, iam_group_id, target_selected, data_mask_categories, time_created, time_updated, data_mask_rule_status, lifecycle_state, lifecyle_details, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
393 394 395 396 397 398 399 400 401 402 |
# File 'lib/oci/cloud_guard/models/data_mask_rule.rb', line 393 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
387 388 389 |
# File 'lib/oci/cloud_guard/models/data_mask_rule.rb', line 387 def to_s to_hash.to_s end |