Class: OCI::CloudGuard::Models::DetectorDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/cloud_guard/models/detector_details.rb

Overview

Details of a Detector Rule

Constant Summary collapse

RISK_LEVEL_ENUM =
[
  RISK_LEVEL_CRITICAL = 'CRITICAL'.freeze,
  RISK_LEVEL_HIGH = 'HIGH'.freeze,
  RISK_LEVEL_MEDIUM = 'MEDIUM'.freeze,
  RISK_LEVEL_LOW = 'LOW'.freeze,
  RISK_LEVEL_MINOR = 'MINOR'.freeze,
  RISK_LEVEL_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DetectorDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/oci/cloud_guard/models/detector_details.rb', line 104

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.is_enabled = attributes[:'isEnabled'] unless attributes[:'isEnabled'].nil?

  raise 'You cannot provide both :isEnabled and :is_enabled' if attributes.key?(:'isEnabled') && attributes.key?(:'is_enabled')

  self.is_enabled = attributes[:'is_enabled'] unless attributes[:'is_enabled'].nil?

  self.risk_level = attributes[:'riskLevel'] if attributes[:'riskLevel']

  raise 'You cannot provide both :riskLevel and :risk_level' if attributes.key?(:'riskLevel') && attributes.key?(:'risk_level')

  self.risk_level = attributes[:'risk_level'] if attributes[:'risk_level']

  self.configurations = attributes[:'configurations'] if attributes[:'configurations']

  self.condition = attributes[:'condition'] if attributes[:'condition']

  self.labels = attributes[:'labels'] if attributes[:'labels']

  self.is_configuration_allowed = attributes[:'isConfigurationAllowed'] unless attributes[:'isConfigurationAllowed'].nil?

  raise 'You cannot provide both :isConfigurationAllowed and :is_configuration_allowed' if attributes.key?(:'isConfigurationAllowed') && attributes.key?(:'is_configuration_allowed')

  self.is_configuration_allowed = attributes[:'is_configuration_allowed'] unless attributes[:'is_configuration_allowed'].nil?

  self.problem_threshold = attributes[:'problemThreshold'] if attributes[:'problemThreshold']

  raise 'You cannot provide both :problemThreshold and :problem_threshold' if attributes.key?(:'problemThreshold') && attributes.key?(:'problem_threshold')

  self.problem_threshold = attributes[:'problem_threshold'] if attributes[:'problem_threshold']

  self.target_types = attributes[:'targetTypes'] if attributes[:'targetTypes']

  raise 'You cannot provide both :targetTypes and :target_types' if attributes.key?(:'targetTypes') && attributes.key?(:'target_types')

  self.target_types = attributes[:'target_types'] if attributes[:'target_types']

  self.sighting_types = attributes[:'sightingTypes'] if attributes[:'sightingTypes']

  raise 'You cannot provide both :sightingTypes and :sighting_types' if attributes.key?(:'sightingTypes') && attributes.key?(:'sighting_types')

  self.sighting_types = attributes[:'sighting_types'] if attributes[:'sighting_types']
end

Instance Attribute Details

#conditionOCI::CloudGuard::Models::Condition



33
34
35
# File 'lib/oci/cloud_guard/models/detector_details.rb', line 33

def condition
  @condition
end

#configurationsArray<OCI::CloudGuard::Models::DetectorConfiguration>

Configuration details



30
31
32
# File 'lib/oci/cloud_guard/models/detector_details.rb', line 30

def configurations
  @configurations
end

#is_configuration_allowedBOOLEAN

configuration allowed or not

Returns:

  • (BOOLEAN)


41
42
43
# File 'lib/oci/cloud_guard/models/detector_details.rb', line 41

def is_configuration_allowed
  @is_configuration_allowed
end

#is_enabledBOOLEAN

**[Required]** Enables the control

Returns:

  • (BOOLEAN)


22
23
24
# File 'lib/oci/cloud_guard/models/detector_details.rb', line 22

def is_enabled
  @is_enabled
end

#labelsArray<String>

user defined labels for a detector rule

Returns:

  • (Array<String>)


37
38
39
# File 'lib/oci/cloud_guard/models/detector_details.rb', line 37

def labels
  @labels
end

#problem_thresholdInteger

Cutover point for an elevated resource Risk Score to create a Problem

Returns:

  • (Integer)


45
46
47
# File 'lib/oci/cloud_guard/models/detector_details.rb', line 45

def problem_threshold
  @problem_threshold
end

#risk_levelString

The Risk Level

Returns:

  • (String)


26
27
28
# File 'lib/oci/cloud_guard/models/detector_details.rb', line 26

def risk_level
  @risk_level
end

#sighting_typesArray<OCI::CloudGuard::Models::SightingType>

List of sighting types



53
54
55
# File 'lib/oci/cloud_guard/models/detector_details.rb', line 53

def sighting_types
  @sighting_types
end

#target_typesArray<String>

List of target types for which the detector rule is applicable

Returns:

  • (Array<String>)


49
50
51
# File 'lib/oci/cloud_guard/models/detector_details.rb', line 49

def target_types
  @target_types
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/oci/cloud_guard/models/detector_details.rb', line 56

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'is_enabled': :'isEnabled',
    'risk_level': :'riskLevel',
    'configurations': :'configurations',
    'condition': :'condition',
    'labels': :'labels',
    'is_configuration_allowed': :'isConfigurationAllowed',
    'problem_threshold': :'problemThreshold',
    'target_types': :'targetTypes',
    'sighting_types': :'sightingTypes'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/oci/cloud_guard/models/detector_details.rb', line 73

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'is_enabled': :'BOOLEAN',
    'risk_level': :'String',
    'configurations': :'Array<OCI::CloudGuard::Models::DetectorConfiguration>',
    'condition': :'OCI::CloudGuard::Models::Condition',
    'labels': :'Array<String>',
    'is_configuration_allowed': :'BOOLEAN',
    'problem_threshold': :'Integer',
    'target_types': :'Array<String>',
    'sighting_types': :'Array<OCI::CloudGuard::Models::SightingType>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/oci/cloud_guard/models/detector_details.rb', line 173

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    is_enabled == other.is_enabled &&
    risk_level == other.risk_level &&
    configurations == other.configurations &&
    condition == other.condition &&
    labels == other.labels &&
    is_configuration_allowed == other.is_configuration_allowed &&
    problem_threshold == other.problem_threshold &&
    target_types == other.target_types &&
    sighting_types == other.sighting_types
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/oci/cloud_guard/models/detector_details.rb', line 211

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


191
192
193
# File 'lib/oci/cloud_guard/models/detector_details.rb', line 191

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



200
201
202
# File 'lib/oci/cloud_guard/models/detector_details.rb', line 200

def hash
  [is_enabled, risk_level, configurations, condition, labels, is_configuration_allowed, problem_threshold, target_types, sighting_types].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



244
245
246
247
248
249
250
251
252
253
# File 'lib/oci/cloud_guard/models/detector_details.rb', line 244

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



238
239
240
# File 'lib/oci/cloud_guard/models/detector_details.rb', line 238

def to_s
  to_hash.to_s
end