Class: OCI::CloudGuard::Models::DetectorRecipe

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/cloud_guard/models/detector_recipe.rb

Overview

Details of Detector recipe

Constant Summary collapse

OWNER_ENUM =
[
  OWNER_CUSTOMER = 'CUSTOMER'.freeze,
  OWNER_ORACLE = 'ORACLE'.freeze,
  OWNER_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
DETECTOR_ENUM =
[
  DETECTOR_IAAS_ACTIVITY_DETECTOR = 'IAAS_ACTIVITY_DETECTOR'.freeze,
  DETECTOR_IAAS_CONFIGURATION_DETECTOR = 'IAAS_CONFIGURATION_DETECTOR'.freeze,
  DETECTOR_IAAS_THREAT_DETECTOR = 'IAAS_THREAT_DETECTOR'.freeze,
  DETECTOR_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DetectorRecipe

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/oci/cloud_guard/models/detector_recipe.rb', line 180

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.source_detector_recipe_id = attributes[:'sourceDetectorRecipeId'] if attributes[:'sourceDetectorRecipeId']

  raise 'You cannot provide both :sourceDetectorRecipeId and :source_detector_recipe_id' if attributes.key?(:'sourceDetectorRecipeId') && attributes.key?(:'source_detector_recipe_id')

  self.source_detector_recipe_id = attributes[:'source_detector_recipe_id'] if attributes[:'source_detector_recipe_id']

  self.owner = attributes[:'owner'] if attributes[:'owner']

  self.detector = attributes[:'detector'] if attributes[:'detector']

  self.detector_rules = attributes[:'detectorRules'] if attributes[:'detectorRules']

  raise 'You cannot provide both :detectorRules and :detector_rules' if attributes.key?(:'detectorRules') && attributes.key?(:'detector_rules')

  self.detector_rules = attributes[:'detector_rules'] if attributes[:'detector_rules']

  self.effective_detector_rules = attributes[:'effectiveDetectorRules'] if attributes[:'effectiveDetectorRules']

  raise 'You cannot provide both :effectiveDetectorRules and :effective_detector_rules' if attributes.key?(:'effectiveDetectorRules') && attributes.key?(:'effective_detector_rules')

  self.effective_detector_rules = attributes[:'effective_detector_rules'] if attributes[:'effective_detector_rules']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.source_data_retention = attributes[:'sourceDataRetention'] if attributes[:'sourceDataRetention']

  raise 'You cannot provide both :sourceDataRetention and :source_data_retention' if attributes.key?(:'sourceDataRetention') && attributes.key?(:'source_data_retention')

  self.source_data_retention = attributes[:'source_data_retention'] if attributes[:'source_data_retention']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

  raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

  self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']
end

Instance Attribute Details

#compartment_idString

**[Required]** compartmentId of detector recipe

Returns:

  • (String)


49
50
51
# File 'lib/oci/cloud_guard/models/detector_recipe.rb', line 49

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


99
100
101
# File 'lib/oci/cloud_guard/models/detector_recipe.rb', line 99

def defined_tags
  @defined_tags
end

#descriptionString

Detector recipe description.

Returns:

  • (String)


45
46
47
# File 'lib/oci/cloud_guard/models/detector_recipe.rb', line 45

def description
  @description
end

#detectorString

**[Required]** Type of detector

Returns:

  • (String)


61
62
63
# File 'lib/oci/cloud_guard/models/detector_recipe.rb', line 61

def detector
  @detector
end

#detector_rulesArray<OCI::CloudGuard::Models::DetectorRecipeDetectorRule>

List of detector rules for the detector type for recipe - user input



65
66
67
# File 'lib/oci/cloud_guard/models/detector_recipe.rb', line 65

def detector_rules
  @detector_rules
end

#display_nameString

**[Required]** DisplayName of detector recipe.

Returns:

  • (String)


41
42
43
# File 'lib/oci/cloud_guard/models/detector_recipe.rb', line 41

def display_name
  @display_name
end

#effective_detector_rulesArray<OCI::CloudGuard::Models::DetectorRecipeDetectorRule>

List of effective detector rules for the detector type for recipe after applying defaults



69
70
71
# File 'lib/oci/cloud_guard/models/detector_recipe.rb', line 69

def effective_detector_rules
  @effective_detector_rules
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`

Avoid entering confidential information.

Returns:

  • (Hash<String, String>)


93
94
95
# File 'lib/oci/cloud_guard/models/detector_recipe.rb', line 93

def freeform_tags
  @freeform_tags
end

#idString

**[Required]** Ocid for detector recipe

Returns:

  • (String)


37
38
39
# File 'lib/oci/cloud_guard/models/detector_recipe.rb', line 37

def id
  @id
end

#lifecycle_stateString

The current state of the resource.

Returns:

  • (String)


81
82
83
# File 'lib/oci/cloud_guard/models/detector_recipe.rb', line 81

def lifecycle_state
  @lifecycle_state
end

#ownerString

**[Required]** Owner of detector recipe

Returns:

  • (String)


57
58
59
# File 'lib/oci/cloud_guard/models/detector_recipe.rb', line 57

def owner
  @owner
end

#source_data_retentionInteger

The number of days for which source data is retained

Returns:

  • (Integer)


85
86
87
# File 'lib/oci/cloud_guard/models/detector_recipe.rb', line 85

def source_data_retention
  @source_data_retention
end

#source_detector_recipe_idString

**[Required]** Recipe Ocid of the Source Recipe to be cloned

Returns:

  • (String)


53
54
55
# File 'lib/oci/cloud_guard/models/detector_recipe.rb', line 53

def source_detector_recipe_id
  @source_detector_recipe_id
end

#system_tagsHash<String, Hash<String, Object>>

System tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). System tags can be viewed by users, but can only be created by the system.

Example: `{"free-tier-retained": "true"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


108
109
110
# File 'lib/oci/cloud_guard/models/detector_recipe.rb', line 108

def system_tags
  @system_tags
end

#time_createdDateTime

The date and time the detector recipe was created. Format defined by RFC3339.

Returns:

  • (DateTime)


73
74
75
# File 'lib/oci/cloud_guard/models/detector_recipe.rb', line 73

def time_created
  @time_created
end

#time_updatedDateTime

The date and time the detector recipe was updated. Format defined by RFC3339.

Returns:

  • (DateTime)


77
78
79
# File 'lib/oci/cloud_guard/models/detector_recipe.rb', line 77

def time_updated
  @time_updated
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'lib/oci/cloud_guard/models/detector_recipe.rb', line 111

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'display_name': :'displayName',
    'description': :'description',
    'compartment_id': :'compartmentId',
    'source_detector_recipe_id': :'sourceDetectorRecipeId',
    'owner': :'owner',
    'detector': :'detector',
    'detector_rules': :'detectorRules',
    'effective_detector_rules': :'effectiveDetectorRules',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'lifecycle_state': :'lifecycleState',
    'source_data_retention': :'sourceDataRetention',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/oci/cloud_guard/models/detector_recipe.rb', line 135

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'display_name': :'String',
    'description': :'String',
    'compartment_id': :'String',
    'source_detector_recipe_id': :'String',
    'owner': :'String',
    'detector': :'String',
    'detector_rules': :'Array<OCI::CloudGuard::Models::DetectorRecipeDetectorRule>',
    'effective_detector_rules': :'Array<OCI::CloudGuard::Models::DetectorRecipeDetectorRule>',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'lifecycle_state': :'String',
    'source_data_retention': :'Integer',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
# File 'lib/oci/cloud_guard/models/detector_recipe.rb', line 313

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    display_name == other.display_name &&
    description == other.description &&
    compartment_id == other.compartment_id &&
    source_detector_recipe_id == other.source_detector_recipe_id &&
    owner == other.owner &&
    detector == other.detector &&
    detector_rules == other.detector_rules &&
    effective_detector_rules == other.effective_detector_rules &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    lifecycle_state == other.lifecycle_state &&
    source_data_retention == other.source_data_retention &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
# File 'lib/oci/cloud_guard/models/detector_recipe.rb', line 358

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


338
339
340
# File 'lib/oci/cloud_guard/models/detector_recipe.rb', line 338

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



347
348
349
# File 'lib/oci/cloud_guard/models/detector_recipe.rb', line 347

def hash
  [id, display_name, description, compartment_id, source_detector_recipe_id, owner, detector, detector_rules, effective_detector_rules, time_created, time_updated, lifecycle_state, source_data_retention, freeform_tags, defined_tags, system_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



391
392
393
394
395
396
397
398
399
400
# File 'lib/oci/cloud_guard/models/detector_recipe.rb', line 391

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



385
386
387
# File 'lib/oci/cloud_guard/models/detector_recipe.rb', line 385

def to_s
  to_hash.to_s
end