Class: OCI::CloudGuard::Models::DetectorRecipeSummary
- Inherits:
-
Object
- Object
- OCI::CloudGuard::Models::DetectorRecipeSummary
- Defined in:
- lib/oci/cloud_guard/models/detector_recipe_summary.rb
Overview
Summary of Detector recipe
Constant Summary collapse
- OWNER_ENUM =
[ OWNER_CUSTOMER = 'CUSTOMER'.freeze, OWNER_ORACLE = 'ORACLE'.freeze, OWNER_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- DETECTOR_ENUM =
[ DETECTOR_IAAS_ACTIVITY_DETECTOR = 'IAAS_ACTIVITY_DETECTOR'.freeze, DETECTOR_IAAS_CONFIGURATION_DETECTOR = 'IAAS_CONFIGURATION_DETECTOR'.freeze, DETECTOR_IAAS_THREAT_DETECTOR = 'IAAS_THREAT_DETECTOR'.freeze, DETECTOR_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** compartmentId of detector recipe.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
Detector recipe description.
-
#detector ⇒ String
**[Required]** Type of detector.
-
#detector_rules ⇒ Array<OCI::CloudGuard::Models::DetectorRecipeDetectorRule>
List of detetor rules for the detector type.
-
#display_name ⇒ String
**[Required]** DisplayName of detector recipe.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
**[Required]** Ocid for detector recipe.
-
#lifecycle_state ⇒ String
The current state of the resource.
-
#owner ⇒ String
**[Required]** Owner of detector recipe.
-
#source_data_retention ⇒ Integer
The number of days for which source data is retained.
-
#source_detector_recipe_id ⇒ String
Recipe Ocid of the Source Recipe to be cloned.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
System tags for this resource.
-
#time_created ⇒ DateTime
The date and time the detector recipe was created.
-
#time_updated ⇒ DateTime
The date and time the detector recipe was updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DetectorRecipeSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DetectorRecipeSummary
Initializes the object
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/oci/cloud_guard/models/detector_recipe_summary.rb', line 173 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.source_detector_recipe_id = attributes[:'sourceDetectorRecipeId'] if attributes[:'sourceDetectorRecipeId'] raise 'You cannot provide both :sourceDetectorRecipeId and :source_detector_recipe_id' if attributes.key?(:'sourceDetectorRecipeId') && attributes.key?(:'source_detector_recipe_id') self.source_detector_recipe_id = attributes[:'source_detector_recipe_id'] if attributes[:'source_detector_recipe_id'] self.owner = attributes[:'owner'] if attributes[:'owner'] self.detector = attributes[:'detector'] if attributes[:'detector'] self.detector_rules = attributes[:'detectorRules'] if attributes[:'detectorRules'] raise 'You cannot provide both :detectorRules and :detector_rules' if attributes.key?(:'detectorRules') && attributes.key?(:'detector_rules') self.detector_rules = attributes[:'detector_rules'] if attributes[:'detector_rules'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.source_data_retention = attributes[:'sourceDataRetention'] if attributes[:'sourceDataRetention'] raise 'You cannot provide both :sourceDataRetention and :source_data_retention' if attributes.key?(:'sourceDataRetention') && attributes.key?(:'source_data_retention') self.source_data_retention = attributes[:'source_data_retention'] if attributes[:'source_data_retention'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** compartmentId of detector recipe
49 50 51 |
# File 'lib/oci/cloud_guard/models/detector_recipe_summary.rb', line 49 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
95 96 97 |
# File 'lib/oci/cloud_guard/models/detector_recipe_summary.rb', line 95 def @defined_tags end |
#description ⇒ String
Detector recipe description
45 46 47 |
# File 'lib/oci/cloud_guard/models/detector_recipe_summary.rb', line 45 def description @description end |
#detector ⇒ String
**[Required]** Type of detector
61 62 63 |
# File 'lib/oci/cloud_guard/models/detector_recipe_summary.rb', line 61 def detector @detector end |
#detector_rules ⇒ Array<OCI::CloudGuard::Models::DetectorRecipeDetectorRule>
List of detetor rules for the detector type
65 66 67 |
# File 'lib/oci/cloud_guard/models/detector_recipe_summary.rb', line 65 def detector_rules @detector_rules end |
#display_name ⇒ String
**[Required]** DisplayName of detector recipe
41 42 43 |
# File 'lib/oci/cloud_guard/models/detector_recipe_summary.rb', line 41 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
Avoid entering confidential information.
89 90 91 |
# File 'lib/oci/cloud_guard/models/detector_recipe_summary.rb', line 89 def @freeform_tags end |
#id ⇒ String
**[Required]** Ocid for detector recipe
37 38 39 |
# File 'lib/oci/cloud_guard/models/detector_recipe_summary.rb', line 37 def id @id end |
#lifecycle_state ⇒ String
The current state of the resource.
77 78 79 |
# File 'lib/oci/cloud_guard/models/detector_recipe_summary.rb', line 77 def lifecycle_state @lifecycle_state end |
#owner ⇒ String
**[Required]** Owner of detector recipe
57 58 59 |
# File 'lib/oci/cloud_guard/models/detector_recipe_summary.rb', line 57 def owner @owner end |
#source_data_retention ⇒ Integer
The number of days for which source data is retained
81 82 83 |
# File 'lib/oci/cloud_guard/models/detector_recipe_summary.rb', line 81 def source_data_retention @source_data_retention end |
#source_detector_recipe_id ⇒ String
Recipe Ocid of the Source Recipe to be cloned
53 54 55 |
# File 'lib/oci/cloud_guard/models/detector_recipe_summary.rb', line 53 def source_detector_recipe_id @source_detector_recipe_id end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
System tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). System tags can be viewed by users, but can only be created by the system.
Example: `{"free-tier-retained": "true"}`
104 105 106 |
# File 'lib/oci/cloud_guard/models/detector_recipe_summary.rb', line 104 def @system_tags end |
#time_created ⇒ DateTime
The date and time the detector recipe was created. Format defined by RFC3339.
69 70 71 |
# File 'lib/oci/cloud_guard/models/detector_recipe_summary.rb', line 69 def time_created @time_created end |
#time_updated ⇒ DateTime
The date and time the detector recipe was updated. Format defined by RFC3339.
73 74 75 |
# File 'lib/oci/cloud_guard/models/detector_recipe_summary.rb', line 73 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/oci/cloud_guard/models/detector_recipe_summary.rb', line 107 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'description': :'description', 'compartment_id': :'compartmentId', 'source_detector_recipe_id': :'sourceDetectorRecipeId', 'owner': :'owner', 'detector': :'detector', 'detector_rules': :'detectorRules', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'source_data_retention': :'sourceDataRetention', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/oci/cloud_guard/models/detector_recipe_summary.rb', line 130 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'description': :'String', 'compartment_id': :'String', 'source_detector_recipe_id': :'String', 'owner': :'String', 'detector': :'String', 'detector_rules': :'Array<OCI::CloudGuard::Models::DetectorRecipeDetectorRule>', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'source_data_retention': :'Integer', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 |
# File 'lib/oci/cloud_guard/models/detector_recipe_summary.rb', line 300 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && description == other.description && compartment_id == other.compartment_id && source_detector_recipe_id == other.source_detector_recipe_id && owner == other.owner && detector == other.detector && detector_rules == other.detector_rules && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && source_data_retention == other.source_data_retention && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 |
# File 'lib/oci/cloud_guard/models/detector_recipe_summary.rb', line 344 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
324 325 326 |
# File 'lib/oci/cloud_guard/models/detector_recipe_summary.rb', line 324 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
333 334 335 |
# File 'lib/oci/cloud_guard/models/detector_recipe_summary.rb', line 333 def hash [id, display_name, description, compartment_id, source_detector_recipe_id, owner, detector, detector_rules, time_created, time_updated, lifecycle_state, source_data_retention, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
377 378 379 380 381 382 383 384 385 386 |
# File 'lib/oci/cloud_guard/models/detector_recipe_summary.rb', line 377 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
371 372 373 |
# File 'lib/oci/cloud_guard/models/detector_recipe_summary.rb', line 371 def to_s to_hash.to_s end |