Class: OCI::CloudGuard::Models::ImpactedResourceSummary
- Inherits:
-
Object
- Object
- OCI::CloudGuard::Models::ImpactedResourceSummary
- Defined in:
- lib/oci/cloud_guard/models/impacted_resource_summary.rb
Overview
Impacted Resource summary Definition.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** Compartment Id where the resource is created.
-
#id ⇒ String
**[Required]** Unique identifier for finding event.
-
#problem_id ⇒ String
**[Required]** Problem Id to which the Impacted Resource is associated.
-
#region ⇒ String
**[Required]** Region where the resource is created.
-
#resource_id ⇒ String
**[Required]** Unique id of the Impacted Resource.
-
#resource_name ⇒ String
**[Required]** Name of the Impacted Resource.
-
#resource_type ⇒ String
**[Required]** Type of the Impacted Resource.
-
#sighting_type ⇒ String
Identifier for the sighting type.
-
#sighting_type_display_name ⇒ String
Name of the sighting type.
-
#time_identified ⇒ DateTime
**[Required]** Time when the problem was identified.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ImpactedResourceSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ImpactedResourceSummary
Initializes the object
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/oci/cloud_guard/models/impacted_resource_summary.rb', line 102 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.resource_id = attributes[:'resourceId'] if attributes[:'resourceId'] raise 'You cannot provide both :resourceId and :resource_id' if attributes.key?(:'resourceId') && attributes.key?(:'resource_id') self.resource_id = attributes[:'resource_id'] if attributes[:'resource_id'] self.problem_id = attributes[:'problemId'] if attributes[:'problemId'] raise 'You cannot provide both :problemId and :problem_id' if attributes.key?(:'problemId') && attributes.key?(:'problem_id') self.problem_id = attributes[:'problem_id'] if attributes[:'problem_id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.sighting_type = attributes[:'sightingType'] if attributes[:'sightingType'] raise 'You cannot provide both :sightingType and :sighting_type' if attributes.key?(:'sightingType') && attributes.key?(:'sighting_type') self.sighting_type = attributes[:'sighting_type'] if attributes[:'sighting_type'] self.sighting_type_display_name = attributes[:'sightingTypeDisplayName'] if attributes[:'sightingTypeDisplayName'] raise 'You cannot provide both :sightingTypeDisplayName and :sighting_type_display_name' if attributes.key?(:'sightingTypeDisplayName') && attributes.key?(:'sighting_type_display_name') self.sighting_type_display_name = attributes[:'sighting_type_display_name'] if attributes[:'sighting_type_display_name'] self.resource_name = attributes[:'resourceName'] if attributes[:'resourceName'] raise 'You cannot provide both :resourceName and :resource_name' if attributes.key?(:'resourceName') && attributes.key?(:'resource_name') self.resource_name = attributes[:'resource_name'] if attributes[:'resource_name'] self.resource_type = attributes[:'resourceType'] if attributes[:'resourceType'] raise 'You cannot provide both :resourceType and :resource_type' if attributes.key?(:'resourceType') && attributes.key?(:'resource_type') self.resource_type = attributes[:'resource_type'] if attributes[:'resource_type'] self.region = attributes[:'region'] if attributes[:'region'] self.time_identified = attributes[:'timeIdentified'] if attributes[:'timeIdentified'] raise 'You cannot provide both :timeIdentified and :time_identified' if attributes.key?(:'timeIdentified') && attributes.key?(:'time_identified') self.time_identified = attributes[:'time_identified'] if attributes[:'time_identified'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** Compartment Id where the resource is created
24 25 26 |
# File 'lib/oci/cloud_guard/models/impacted_resource_summary.rb', line 24 def compartment_id @compartment_id end |
#id ⇒ String
**[Required]** Unique identifier for finding event
12 13 14 |
# File 'lib/oci/cloud_guard/models/impacted_resource_summary.rb', line 12 def id @id end |
#problem_id ⇒ String
**[Required]** Problem Id to which the Impacted Resource is associated
20 21 22 |
# File 'lib/oci/cloud_guard/models/impacted_resource_summary.rb', line 20 def problem_id @problem_id end |
#region ⇒ String
**[Required]** Region where the resource is created
44 45 46 |
# File 'lib/oci/cloud_guard/models/impacted_resource_summary.rb', line 44 def region @region end |
#resource_id ⇒ String
**[Required]** Unique id of the Impacted Resource
16 17 18 |
# File 'lib/oci/cloud_guard/models/impacted_resource_summary.rb', line 16 def resource_id @resource_id end |
#resource_name ⇒ String
**[Required]** Name of the Impacted Resource
36 37 38 |
# File 'lib/oci/cloud_guard/models/impacted_resource_summary.rb', line 36 def resource_name @resource_name end |
#resource_type ⇒ String
**[Required]** Type of the Impacted Resource
40 41 42 |
# File 'lib/oci/cloud_guard/models/impacted_resource_summary.rb', line 40 def resource_type @resource_type end |
#sighting_type ⇒ String
Identifier for the sighting type
28 29 30 |
# File 'lib/oci/cloud_guard/models/impacted_resource_summary.rb', line 28 def sighting_type @sighting_type end |
#sighting_type_display_name ⇒ String
Name of the sighting type
32 33 34 |
# File 'lib/oci/cloud_guard/models/impacted_resource_summary.rb', line 32 def sighting_type_display_name @sighting_type_display_name end |
#time_identified ⇒ DateTime
**[Required]** Time when the problem was identified
48 49 50 |
# File 'lib/oci/cloud_guard/models/impacted_resource_summary.rb', line 48 def time_identified @time_identified end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/oci/cloud_guard/models/impacted_resource_summary.rb', line 51 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'resource_id': :'resourceId', 'problem_id': :'problemId', 'compartment_id': :'compartmentId', 'sighting_type': :'sightingType', 'sighting_type_display_name': :'sightingTypeDisplayName', 'resource_name': :'resourceName', 'resource_type': :'resourceType', 'region': :'region', 'time_identified': :'timeIdentified' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/oci/cloud_guard/models/impacted_resource_summary.rb', line 69 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'resource_id': :'String', 'problem_id': :'String', 'compartment_id': :'String', 'sighting_type': :'String', 'sighting_type_display_name': :'String', 'resource_name': :'String', 'resource_type': :'String', 'region': :'String', 'time_identified': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/oci/cloud_guard/models/impacted_resource_summary.rb', line 168 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && resource_id == other.resource_id && problem_id == other.problem_id && compartment_id == other.compartment_id && sighting_type == other.sighting_type && sighting_type_display_name == other.sighting_type_display_name && resource_name == other.resource_name && resource_type == other.resource_type && region == other.region && time_identified == other.time_identified end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/oci/cloud_guard/models/impacted_resource_summary.rb', line 207 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
187 188 189 |
# File 'lib/oci/cloud_guard/models/impacted_resource_summary.rb', line 187 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
196 197 198 |
# File 'lib/oci/cloud_guard/models/impacted_resource_summary.rb', line 196 def hash [id, resource_id, problem_id, compartment_id, sighting_type, sighting_type_display_name, resource_name, resource_type, region, time_identified].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
240 241 242 243 244 245 246 247 248 249 |
# File 'lib/oci/cloud_guard/models/impacted_resource_summary.rb', line 240 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
234 235 236 |
# File 'lib/oci/cloud_guard/models/impacted_resource_summary.rb', line 234 def to_s to_hash.to_s end |