Class: OCI::CloudGuard::Models::ManagedList
- Inherits:
-
Object
- Object
- OCI::CloudGuard::Models::ManagedList
- Defined in:
- lib/oci/cloud_guard/models/managed_list.rb
Overview
A cloud guard list containing one or more items of a list type
Constant Summary collapse
- LIST_TYPE_ENUM =
[ LIST_TYPE_CIDR_BLOCK = 'CIDR_BLOCK'.freeze, LIST_TYPE_USERS = 'USERS'.freeze, LIST_TYPE_GROUPS = 'GROUPS'.freeze, LIST_TYPE_IPV4_ADDRESS = 'IPV4ADDRESS'.freeze, LIST_TYPE_IPV6_ADDRESS = 'IPV6ADDRESS'.freeze, LIST_TYPE_RESOURCE_OCID = 'RESOURCE_OCID'.freeze, LIST_TYPE_REGION = 'REGION'.freeze, LIST_TYPE_COUNTRY = 'COUNTRY'.freeze, LIST_TYPE_STATE = 'STATE'.freeze, LIST_TYPE_CITY = 'CITY'.freeze, LIST_TYPE_TAGS = 'TAGS'.freeze, LIST_TYPE_GENERIC = 'GENERIC'.freeze, LIST_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- FEED_PROVIDER_ENUM =
[ FEED_PROVIDER_CUSTOMER = 'CUSTOMER'.freeze, FEED_PROVIDER_ORACLE = 'ORACLE'.freeze, FEED_PROVIDER_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** Compartment Identifier where the resource is created.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
ManagedList description.
-
#display_name ⇒ String
**[Required]** ManagedList display name.
-
#feed_provider ⇒ String
provider of the feed.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
**[Required]** Unique identifier that is immutable on creation.
-
#is_editable ⇒ BOOLEAN
If this list is editable or not.
-
#lifecycle_state ⇒ String
The current state of the resource.
-
#lifecyle_details ⇒ String
A message describing the current state in more detail.
-
#list_items ⇒ Array<String>
List of ManagedListItem.
-
#list_type ⇒ String
**[Required]** type of the list.
-
#source_managed_list_id ⇒ String
OCID of the Source ManagedList.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
System tags for this resource.
-
#time_created ⇒ DateTime
The date and time the managed list was created.
-
#time_updated ⇒ DateTime
The date and time the managed list was updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ManagedList
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ManagedList
Initializes the object
189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/oci/cloud_guard/models/managed_list.rb', line 189 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.source_managed_list_id = attributes[:'sourceManagedListId'] if attributes[:'sourceManagedListId'] raise 'You cannot provide both :sourceManagedListId and :source_managed_list_id' if attributes.key?(:'sourceManagedListId') && attributes.key?(:'source_managed_list_id') self.source_managed_list_id = attributes[:'source_managed_list_id'] if attributes[:'source_managed_list_id'] self.list_type = attributes[:'listType'] if attributes[:'listType'] raise 'You cannot provide both :listType and :list_type' if attributes.key?(:'listType') && attributes.key?(:'list_type') self.list_type = attributes[:'list_type'] if attributes[:'list_type'] self.list_items = attributes[:'listItems'] if attributes[:'listItems'] raise 'You cannot provide both :listItems and :list_items' if attributes.key?(:'listItems') && attributes.key?(:'list_items') self.list_items = attributes[:'list_items'] if attributes[:'list_items'] self.feed_provider = attributes[:'feedProvider'] if attributes[:'feedProvider'] raise 'You cannot provide both :feedProvider and :feed_provider' if attributes.key?(:'feedProvider') && attributes.key?(:'feed_provider') self.feed_provider = attributes[:'feed_provider'] if attributes[:'feed_provider'] self.is_editable = attributes[:'isEditable'] unless attributes[:'isEditable'].nil? raise 'You cannot provide both :isEditable and :is_editable' if attributes.key?(:'isEditable') && attributes.key?(:'is_editable') self.is_editable = attributes[:'is_editable'] unless attributes[:'is_editable'].nil? self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecyle_details = attributes[:'lifecyleDetails'] if attributes[:'lifecyleDetails'] raise 'You cannot provide both :lifecyleDetails and :lifecyle_details' if attributes.key?(:'lifecyleDetails') && attributes.key?(:'lifecyle_details') self.lifecyle_details = attributes[:'lifecyle_details'] if attributes[:'lifecyle_details'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** Compartment Identifier where the resource is created
58 59 60 |
# File 'lib/oci/cloud_guard/models/managed_list.rb', line 58 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
108 109 110 |
# File 'lib/oci/cloud_guard/models/managed_list.rb', line 108 def @defined_tags end |
#description ⇒ String
ManagedList description.
54 55 56 |
# File 'lib/oci/cloud_guard/models/managed_list.rb', line 54 def description @description end |
#display_name ⇒ String
**[Required]** ManagedList display name.
50 51 52 |
# File 'lib/oci/cloud_guard/models/managed_list.rb', line 50 def display_name @display_name end |
#feed_provider ⇒ String
provider of the feed
74 75 76 |
# File 'lib/oci/cloud_guard/models/managed_list.rb', line 74 def feed_provider @feed_provider end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
Avoid entering confidential information.
102 103 104 |
# File 'lib/oci/cloud_guard/models/managed_list.rb', line 102 def @freeform_tags end |
#id ⇒ String
**[Required]** Unique identifier that is immutable on creation
46 47 48 |
# File 'lib/oci/cloud_guard/models/managed_list.rb', line 46 def id @id end |
#is_editable ⇒ BOOLEAN
If this list is editable or not
78 79 80 |
# File 'lib/oci/cloud_guard/models/managed_list.rb', line 78 def is_editable @is_editable end |
#lifecycle_state ⇒ String
The current state of the resource.
90 91 92 |
# File 'lib/oci/cloud_guard/models/managed_list.rb', line 90 def lifecycle_state @lifecycle_state end |
#lifecyle_details ⇒ String
A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
94 95 96 |
# File 'lib/oci/cloud_guard/models/managed_list.rb', line 94 def lifecyle_details @lifecyle_details end |
#list_items ⇒ Array<String>
List of ManagedListItem
70 71 72 |
# File 'lib/oci/cloud_guard/models/managed_list.rb', line 70 def list_items @list_items end |
#list_type ⇒ String
**[Required]** type of the list
66 67 68 |
# File 'lib/oci/cloud_guard/models/managed_list.rb', line 66 def list_type @list_type end |
#source_managed_list_id ⇒ String
OCID of the Source ManagedList
62 63 64 |
# File 'lib/oci/cloud_guard/models/managed_list.rb', line 62 def source_managed_list_id @source_managed_list_id end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
System tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). System tags can be viewed by users, but can only be created by the system.
Example: `{"free-tier-retained": "true"}`
117 118 119 |
# File 'lib/oci/cloud_guard/models/managed_list.rb', line 117 def @system_tags end |
#time_created ⇒ DateTime
The date and time the managed list was created. Format defined by RFC3339.
82 83 84 |
# File 'lib/oci/cloud_guard/models/managed_list.rb', line 82 def time_created @time_created end |
#time_updated ⇒ DateTime
The date and time the managed list was updated. Format defined by RFC3339.
86 87 88 |
# File 'lib/oci/cloud_guard/models/managed_list.rb', line 86 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/oci/cloud_guard/models/managed_list.rb', line 120 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'description': :'description', 'compartment_id': :'compartmentId', 'source_managed_list_id': :'sourceManagedListId', 'list_type': :'listType', 'list_items': :'listItems', 'feed_provider': :'feedProvider', 'is_editable': :'isEditable', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'lifecyle_details': :'lifecyleDetails', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/oci/cloud_guard/models/managed_list.rb', line 144 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'description': :'String', 'compartment_id': :'String', 'source_managed_list_id': :'String', 'list_type': :'String', 'list_items': :'Array<String>', 'feed_provider': :'String', 'is_editable': :'BOOLEAN', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'lifecyle_details': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 |
# File 'lib/oci/cloud_guard/models/managed_list.rb', line 330 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && description == other.description && compartment_id == other.compartment_id && source_managed_list_id == other.source_managed_list_id && list_type == other.list_type && list_items == other.list_items && feed_provider == other.feed_provider && is_editable == other.is_editable && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && lifecyle_details == other.lifecyle_details && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 |
# File 'lib/oci/cloud_guard/models/managed_list.rb', line 375 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
355 356 357 |
# File 'lib/oci/cloud_guard/models/managed_list.rb', line 355 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
364 365 366 |
# File 'lib/oci/cloud_guard/models/managed_list.rb', line 364 def hash [id, display_name, description, compartment_id, source_managed_list_id, list_type, list_items, feed_provider, is_editable, time_created, time_updated, lifecycle_state, lifecyle_details, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
408 409 410 411 412 413 414 415 416 417 |
# File 'lib/oci/cloud_guard/models/managed_list.rb', line 408 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
402 403 404 |
# File 'lib/oci/cloud_guard/models/managed_list.rb', line 402 def to_s to_hash.to_s end |