Class: OCI::CloudGuard::Models::OperatorSummary
- Inherits:
-
Object
- Object
- OCI::CloudGuard::Models::OperatorSummary
- Defined in:
- lib/oci/cloud_guard/models/operator_summary.rb
Overview
Summary of Operator
Constant Summary collapse
- FILTER_TYPE_ENUM =
[ FILTER_TYPE_CONDITION = 'CONDITION'.freeze, FILTER_TYPE_CONFIG = 'CONFIG'.freeze, FILTER_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#datatype ⇒ String
[Required] data type of operand.
-
#display_name ⇒ String
[Required] display name of the operand.
-
#filter_type ⇒ String
[Required] Filter type can be config filter or condition filter.
-
#managed_listtype ⇒ String
[Required] operand list type.
-
#multi_list_types ⇒ Array<String>
configuration value type list for multilist data type.
-
#name ⇒ String
[Required] name of the operand.
-
#operators ⇒ Array<OCI::CloudGuard::Models::ConditionOperator>
[Required] List of parameters.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OperatorSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ OperatorSummary
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/oci/cloud_guard/models/operator_summary.rb', line 88 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.datatype = attributes[:'datatype'] if attributes[:'datatype'] self.managed_listtype = attributes[:'managedListtype'] if attributes[:'managedListtype'] raise 'You cannot provide both :managedListtype and :managed_listtype' if attributes.key?(:'managedListtype') && attributes.key?(:'managed_listtype') self.managed_listtype = attributes[:'managed_listtype'] if attributes[:'managed_listtype'] self.filter_type = attributes[:'filterType'] if attributes[:'filterType'] raise 'You cannot provide both :filterType and :filter_type' if attributes.key?(:'filterType') && attributes.key?(:'filter_type') self.filter_type = attributes[:'filter_type'] if attributes[:'filter_type'] self.operators = attributes[:'operators'] if attributes[:'operators'] self.multi_list_types = attributes[:'multiListTypes'] if attributes[:'multiListTypes'] raise 'You cannot provide both :multiListTypes and :multi_list_types' if attributes.key?(:'multiListTypes') && attributes.key?(:'multi_list_types') self.multi_list_types = attributes[:'multi_list_types'] if attributes[:'multi_list_types'] end |
Instance Attribute Details
#datatype ⇒ String
[Required] data type of operand
27 28 29 |
# File 'lib/oci/cloud_guard/models/operator_summary.rb', line 27 def datatype @datatype end |
#display_name ⇒ String
[Required] display name of the operand
23 24 25 |
# File 'lib/oci/cloud_guard/models/operator_summary.rb', line 23 def display_name @display_name end |
#filter_type ⇒ String
[Required] Filter type can be config filter or condition filter
35 36 37 |
# File 'lib/oci/cloud_guard/models/operator_summary.rb', line 35 def filter_type @filter_type end |
#managed_listtype ⇒ String
[Required] operand list type
31 32 33 |
# File 'lib/oci/cloud_guard/models/operator_summary.rb', line 31 def managed_listtype @managed_listtype end |
#multi_list_types ⇒ Array<String>
configuration value type list for multilist data type
43 44 45 |
# File 'lib/oci/cloud_guard/models/operator_summary.rb', line 43 def multi_list_types @multi_list_types end |
#name ⇒ String
[Required] name of the operand
19 20 21 |
# File 'lib/oci/cloud_guard/models/operator_summary.rb', line 19 def name @name end |
#operators ⇒ Array<OCI::CloudGuard::Models::ConditionOperator>
[Required] List of parameters
39 40 41 |
# File 'lib/oci/cloud_guard/models/operator_summary.rb', line 39 def operators @operators end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/oci/cloud_guard/models/operator_summary.rb', line 46 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'display_name': :'displayName', 'datatype': :'datatype', 'managed_listtype': :'managedListtype', 'filter_type': :'filterType', 'operators': :'operators', 'multi_list_types': :'multiListTypes' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/oci/cloud_guard/models/operator_summary.rb', line 61 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'display_name': :'String', 'datatype': :'String', 'managed_listtype': :'String', 'filter_type': :'String', 'operators': :'Array<OCI::CloudGuard::Models::ConditionOperator>', 'multi_list_types': :'Array<String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/oci/cloud_guard/models/operator_summary.rb', line 145 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && display_name == other.display_name && datatype == other.datatype && managed_listtype == other.managed_listtype && filter_type == other.filter_type && operators == other.operators && multi_list_types == other.multi_list_types end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/oci/cloud_guard/models/operator_summary.rb', line 181 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
161 162 163 |
# File 'lib/oci/cloud_guard/models/operator_summary.rb', line 161 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
170 171 172 |
# File 'lib/oci/cloud_guard/models/operator_summary.rb', line 170 def hash [name, display_name, datatype, managed_listtype, filter_type, operators, multi_list_types].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
214 215 216 217 218 219 220 221 222 223 |
# File 'lib/oci/cloud_guard/models/operator_summary.rb', line 214 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
208 209 210 |
# File 'lib/oci/cloud_guard/models/operator_summary.rb', line 208 def to_s to_hash.to_s end |