Class: OCI::CloudGuard::Models::RecommendationSummary
- Inherits:
-
Object
- Object
- OCI::CloudGuard::Models::RecommendationSummary
- Defined in:
- lib/oci/cloud_guard/models/recommendation_summary.rb
Overview
Recommendation Definition.
Constant Summary collapse
- TYPE_ENUM =
[ TYPE_DETECTOR_PROBLEMS = 'DETECTOR_PROBLEMS'.freeze, TYPE_RESOLVED_PROBLEMS = 'RESOLVED_PROBLEMS'.freeze, TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- RISK_LEVEL_ENUM =
[ RISK_LEVEL_CRITICAL = 'CRITICAL'.freeze, RISK_LEVEL_HIGH = 'HIGH'.freeze, RISK_LEVEL_MEDIUM = 'MEDIUM'.freeze, RISK_LEVEL_LOW = 'LOW'.freeze, RISK_LEVEL_MINOR = 'MINOR'.freeze, RISK_LEVEL_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_DETAIL_ENUM =
[ LIFECYCLE_DETAIL_OPEN = 'OPEN'.freeze, LIFECYCLE_DETAIL_RESOLVED = 'RESOLVED'.freeze, LIFECYCLE_DETAIL_DISMISSED = 'DISMISSED'.freeze, LIFECYCLE_DETAIL_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** Compartment Identifier.
-
#description ⇒ String
**[Required]** description of the recommendation.
-
#details ⇒ Hash<String, String>
**[Required]** Recommendation details.
-
#id ⇒ String
**[Required]** Unique identifier for Recommendation.
-
#lifecycle_detail ⇒ String
**[Required]** The lifecycleDetail will give more detail on the substate of the lifecycleState.
-
#lifecycle_state ⇒ String
**[Required]** The current state of the Recommendation.
-
#name ⇒ String
**[Required]** recommendation string showing on UX.
-
#problem_count ⇒ Integer
**[Required]** Count number of the problem.
-
#risk_level ⇒ String
The Risk Level.
-
#target_id ⇒ String
**[Required]** targetId associated with the problem.
-
#tenant_id ⇒ String
Tenant Identifier.
-
#time_created ⇒ DateTime
problem creating time.
-
#time_updated ⇒ DateTime
problem updating time.
-
#type ⇒ String
Recommendation type.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RecommendationSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ RecommendationSummary
Initializes the object
164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/oci/cloud_guard/models/recommendation_summary.rb', line 164 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.type = attributes[:'type'] if attributes[:'type'] self.tenant_id = attributes[:'tenantId'] if attributes[:'tenantId'] raise 'You cannot provide both :tenantId and :tenant_id' if attributes.key?(:'tenantId') && attributes.key?(:'tenant_id') self.tenant_id = attributes[:'tenant_id'] if attributes[:'tenant_id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.target_id = attributes[:'targetId'] if attributes[:'targetId'] raise 'You cannot provide both :targetId and :target_id' if attributes.key?(:'targetId') && attributes.key?(:'target_id') self.target_id = attributes[:'target_id'] if attributes[:'target_id'] self.details = attributes[:'details'] if attributes[:'details'] self.risk_level = attributes[:'riskLevel'] if attributes[:'riskLevel'] raise 'You cannot provide both :riskLevel and :risk_level' if attributes.key?(:'riskLevel') && attributes.key?(:'risk_level') self.risk_level = attributes[:'risk_level'] if attributes[:'risk_level'] self.problem_count = attributes[:'problemCount'] if attributes[:'problemCount'] raise 'You cannot provide both :problemCount and :problem_count' if attributes.key?(:'problemCount') && attributes.key?(:'problem_count') self.problem_count = attributes[:'problem_count'] if attributes[:'problem_count'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_detail = attributes[:'lifecycleDetail'] if attributes[:'lifecycleDetail'] raise 'You cannot provide both :lifecycleDetail and :lifecycle_detail' if attributes.key?(:'lifecycleDetail') && attributes.key?(:'lifecycle_detail') self.lifecycle_detail = attributes[:'lifecycle_detail'] if attributes[:'lifecycle_detail'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** Compartment Identifier
58 59 60 |
# File 'lib/oci/cloud_guard/models/recommendation_summary.rb', line 58 def compartment_id @compartment_id end |
#description ⇒ String
**[Required]** description of the recommendation
98 99 100 |
# File 'lib/oci/cloud_guard/models/recommendation_summary.rb', line 98 def description @description end |
#details ⇒ Hash<String, String>
**[Required]** Recommendation details
66 67 68 |
# File 'lib/oci/cloud_guard/models/recommendation_summary.rb', line 66 def details @details end |
#id ⇒ String
**[Required]** Unique identifier for Recommendation
46 47 48 |
# File 'lib/oci/cloud_guard/models/recommendation_summary.rb', line 46 def id @id end |
#lifecycle_detail ⇒ String
**[Required]** The lifecycleDetail will give more detail on the substate of the lifecycleState.
82 83 84 |
# File 'lib/oci/cloud_guard/models/recommendation_summary.rb', line 82 def lifecycle_detail @lifecycle_detail end |
#lifecycle_state ⇒ String
**[Required]** The current state of the Recommendation.
78 79 80 |
# File 'lib/oci/cloud_guard/models/recommendation_summary.rb', line 78 def lifecycle_state @lifecycle_state end |
#name ⇒ String
**[Required]** recommendation string showing on UX
94 95 96 |
# File 'lib/oci/cloud_guard/models/recommendation_summary.rb', line 94 def name @name end |
#problem_count ⇒ Integer
**[Required]** Count number of the problem
74 75 76 |
# File 'lib/oci/cloud_guard/models/recommendation_summary.rb', line 74 def problem_count @problem_count end |
#risk_level ⇒ String
The Risk Level
70 71 72 |
# File 'lib/oci/cloud_guard/models/recommendation_summary.rb', line 70 def risk_level @risk_level end |
#target_id ⇒ String
**[Required]** targetId associated with the problem
62 63 64 |
# File 'lib/oci/cloud_guard/models/recommendation_summary.rb', line 62 def target_id @target_id end |
#tenant_id ⇒ String
Tenant Identifier
54 55 56 |
# File 'lib/oci/cloud_guard/models/recommendation_summary.rb', line 54 def tenant_id @tenant_id end |
#time_created ⇒ DateTime
problem creating time
86 87 88 |
# File 'lib/oci/cloud_guard/models/recommendation_summary.rb', line 86 def time_created @time_created end |
#time_updated ⇒ DateTime
problem updating time
90 91 92 |
# File 'lib/oci/cloud_guard/models/recommendation_summary.rb', line 90 def time_updated @time_updated end |
#type ⇒ String
Recommendation type
50 51 52 |
# File 'lib/oci/cloud_guard/models/recommendation_summary.rb', line 50 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/oci/cloud_guard/models/recommendation_summary.rb', line 101 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'type': :'type', 'tenant_id': :'tenantId', 'compartment_id': :'compartmentId', 'target_id': :'targetId', 'details': :'details', 'risk_level': :'riskLevel', 'problem_count': :'problemCount', 'lifecycle_state': :'lifecycleState', 'lifecycle_detail': :'lifecycleDetail', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'name': :'name', 'description': :'description' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/oci/cloud_guard/models/recommendation_summary.rb', line 123 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'type': :'String', 'tenant_id': :'String', 'compartment_id': :'String', 'target_id': :'String', 'details': :'Hash<String, String>', 'risk_level': :'String', 'problem_count': :'Integer', 'lifecycle_state': :'String', 'lifecycle_detail': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'name': :'String', 'description': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 |
# File 'lib/oci/cloud_guard/models/recommendation_summary.rb', line 294 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && type == other.type && tenant_id == other.tenant_id && compartment_id == other.compartment_id && target_id == other.target_id && details == other.details && risk_level == other.risk_level && problem_count == other.problem_count && lifecycle_state == other.lifecycle_state && lifecycle_detail == other.lifecycle_detail && time_created == other.time_created && time_updated == other.time_updated && name == other.name && description == other.description end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 |
# File 'lib/oci/cloud_guard/models/recommendation_summary.rb', line 337 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
317 318 319 |
# File 'lib/oci/cloud_guard/models/recommendation_summary.rb', line 317 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
326 327 328 |
# File 'lib/oci/cloud_guard/models/recommendation_summary.rb', line 326 def hash [id, type, tenant_id, compartment_id, target_id, details, risk_level, problem_count, lifecycle_state, lifecycle_detail, time_created, time_updated, name, description].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
370 371 372 373 374 375 376 377 378 379 |
# File 'lib/oci/cloud_guard/models/recommendation_summary.rb', line 370 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
364 365 366 |
# File 'lib/oci/cloud_guard/models/recommendation_summary.rb', line 364 def to_s to_hash.to_s end |