Class: OCI::CloudGuard::Models::ResourceProfileImpactedResourceSummary
- Inherits:
-
Object
- Object
- OCI::CloudGuard::Models::ResourceProfileImpactedResourceSummary
- Defined in:
- lib/oci/cloud_guard/models/resource_profile_impacted_resource_summary.rb
Overview
Resource Profile impacted resource summary.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** Compartment Id for impacted resource.
-
#id ⇒ String
**[Required]** Unique identifier for impacted resource.
-
#problem_id ⇒ String
Problem Id for impacted resource.
-
#region ⇒ String
**[Required]** Region for impacted resource.
-
#resource_id ⇒ String
**[Required]** Impacted resource Id.
-
#resource_name ⇒ String
**[Required]** Resource name.
-
#resource_profile_id ⇒ String
**[Required]** Resource profile Id associated with the imacted resource.
-
#resource_type ⇒ String
**[Required]** Resource type.
-
#sighting_type ⇒ String
**[Required]** Identifier for the sighting type.
-
#sighting_type_display_name ⇒ String
**[Required]** Name of the sighting type.
-
#time_identified ⇒ DateTime
**[Required]** Time when the impacted resource is identified for given resource profile.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ResourceProfileImpactedResourceSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ResourceProfileImpactedResourceSummary
Initializes the object
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/oci/cloud_guard/models/resource_profile_impacted_resource_summary.rb', line 109 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.resource_profile_id = attributes[:'resourceProfileId'] if attributes[:'resourceProfileId'] raise 'You cannot provide both :resourceProfileId and :resource_profile_id' if attributes.key?(:'resourceProfileId') && attributes.key?(:'resource_profile_id') self.resource_profile_id = attributes[:'resource_profile_id'] if attributes[:'resource_profile_id'] self.problem_id = attributes[:'problemId'] if attributes[:'problemId'] raise 'You cannot provide both :problemId and :problem_id' if attributes.key?(:'problemId') && attributes.key?(:'problem_id') self.problem_id = attributes[:'problem_id'] if attributes[:'problem_id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.resource_id = attributes[:'resourceId'] if attributes[:'resourceId'] raise 'You cannot provide both :resourceId and :resource_id' if attributes.key?(:'resourceId') && attributes.key?(:'resource_id') self.resource_id = attributes[:'resource_id'] if attributes[:'resource_id'] self.resource_name = attributes[:'resourceName'] if attributes[:'resourceName'] raise 'You cannot provide both :resourceName and :resource_name' if attributes.key?(:'resourceName') && attributes.key?(:'resource_name') self.resource_name = attributes[:'resource_name'] if attributes[:'resource_name'] self.resource_type = attributes[:'resourceType'] if attributes[:'resourceType'] raise 'You cannot provide both :resourceType and :resource_type' if attributes.key?(:'resourceType') && attributes.key?(:'resource_type') self.resource_type = attributes[:'resource_type'] if attributes[:'resource_type'] self.sighting_type = attributes[:'sightingType'] if attributes[:'sightingType'] raise 'You cannot provide both :sightingType and :sighting_type' if attributes.key?(:'sightingType') && attributes.key?(:'sighting_type') self.sighting_type = attributes[:'sighting_type'] if attributes[:'sighting_type'] self.sighting_type_display_name = attributes[:'sightingTypeDisplayName'] if attributes[:'sightingTypeDisplayName'] raise 'You cannot provide both :sightingTypeDisplayName and :sighting_type_display_name' if attributes.key?(:'sightingTypeDisplayName') && attributes.key?(:'sighting_type_display_name') self.sighting_type_display_name = attributes[:'sighting_type_display_name'] if attributes[:'sighting_type_display_name'] self.region = attributes[:'region'] if attributes[:'region'] self.time_identified = attributes[:'timeIdentified'] if attributes[:'timeIdentified'] raise 'You cannot provide both :timeIdentified and :time_identified' if attributes.key?(:'timeIdentified') && attributes.key?(:'time_identified') self.time_identified = attributes[:'time_identified'] if attributes[:'time_identified'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** Compartment Id for impacted resource
24 25 26 |
# File 'lib/oci/cloud_guard/models/resource_profile_impacted_resource_summary.rb', line 24 def compartment_id @compartment_id end |
#id ⇒ String
**[Required]** Unique identifier for impacted resource
12 13 14 |
# File 'lib/oci/cloud_guard/models/resource_profile_impacted_resource_summary.rb', line 12 def id @id end |
#problem_id ⇒ String
Problem Id for impacted resource
20 21 22 |
# File 'lib/oci/cloud_guard/models/resource_profile_impacted_resource_summary.rb', line 20 def problem_id @problem_id end |
#region ⇒ String
**[Required]** Region for impacted resource
48 49 50 |
# File 'lib/oci/cloud_guard/models/resource_profile_impacted_resource_summary.rb', line 48 def region @region end |
#resource_id ⇒ String
**[Required]** Impacted resource Id
28 29 30 |
# File 'lib/oci/cloud_guard/models/resource_profile_impacted_resource_summary.rb', line 28 def resource_id @resource_id end |
#resource_name ⇒ String
**[Required]** Resource name
32 33 34 |
# File 'lib/oci/cloud_guard/models/resource_profile_impacted_resource_summary.rb', line 32 def resource_name @resource_name end |
#resource_profile_id ⇒ String
**[Required]** Resource profile Id associated with the imacted resource
16 17 18 |
# File 'lib/oci/cloud_guard/models/resource_profile_impacted_resource_summary.rb', line 16 def resource_profile_id @resource_profile_id end |
#resource_type ⇒ String
**[Required]** Resource type
36 37 38 |
# File 'lib/oci/cloud_guard/models/resource_profile_impacted_resource_summary.rb', line 36 def resource_type @resource_type end |
#sighting_type ⇒ String
**[Required]** Identifier for the sighting type
40 41 42 |
# File 'lib/oci/cloud_guard/models/resource_profile_impacted_resource_summary.rb', line 40 def sighting_type @sighting_type end |
#sighting_type_display_name ⇒ String
**[Required]** Name of the sighting type
44 45 46 |
# File 'lib/oci/cloud_guard/models/resource_profile_impacted_resource_summary.rb', line 44 def sighting_type_display_name @sighting_type_display_name end |
#time_identified ⇒ DateTime
**[Required]** Time when the impacted resource is identified for given resource profile.
52 53 54 |
# File 'lib/oci/cloud_guard/models/resource_profile_impacted_resource_summary.rb', line 52 def time_identified @time_identified end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/oci/cloud_guard/models/resource_profile_impacted_resource_summary.rb', line 55 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'resource_profile_id': :'resourceProfileId', 'problem_id': :'problemId', 'compartment_id': :'compartmentId', 'resource_id': :'resourceId', 'resource_name': :'resourceName', 'resource_type': :'resourceType', 'sighting_type': :'sightingType', 'sighting_type_display_name': :'sightingTypeDisplayName', 'region': :'region', 'time_identified': :'timeIdentified' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/oci/cloud_guard/models/resource_profile_impacted_resource_summary.rb', line 74 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'resource_profile_id': :'String', 'problem_id': :'String', 'compartment_id': :'String', 'resource_id': :'String', 'resource_name': :'String', 'resource_type': :'String', 'sighting_type': :'String', 'sighting_type_display_name': :'String', 'region': :'String', 'time_identified': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/oci/cloud_guard/models/resource_profile_impacted_resource_summary.rb', line 181 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && resource_profile_id == other.resource_profile_id && problem_id == other.problem_id && compartment_id == other.compartment_id && resource_id == other.resource_id && resource_name == other.resource_name && resource_type == other.resource_type && sighting_type == other.sighting_type && sighting_type_display_name == other.sighting_type_display_name && region == other.region && time_identified == other.time_identified end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/oci/cloud_guard/models/resource_profile_impacted_resource_summary.rb', line 221 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
201 202 203 |
# File 'lib/oci/cloud_guard/models/resource_profile_impacted_resource_summary.rb', line 201 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
210 211 212 |
# File 'lib/oci/cloud_guard/models/resource_profile_impacted_resource_summary.rb', line 210 def hash [id, resource_profile_id, problem_id, compartment_id, resource_id, resource_name, resource_type, sighting_type, sighting_type_display_name, region, time_identified].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
254 255 256 257 258 259 260 261 262 263 |
# File 'lib/oci/cloud_guard/models/resource_profile_impacted_resource_summary.rb', line 254 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
248 249 250 |
# File 'lib/oci/cloud_guard/models/resource_profile_impacted_resource_summary.rb', line 248 def to_s to_hash.to_s end |