Class: OCI::CloudGuard::Models::ResponderRecipe

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/cloud_guard/models/responder_recipe.rb

Overview

Details of ResponderRecipe.

Constant Summary collapse

OWNER_ENUM =
[
  OWNER_CUSTOMER = 'CUSTOMER'.freeze,
  OWNER_ORACLE = 'ORACLE'.freeze,
  OWNER_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ResponderRecipe

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/oci/cloud_guard/models/responder_recipe.rb', line 166

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.owner = attributes[:'owner'] if attributes[:'owner']

  self.responder_rules = attributes[:'responderRules'] if attributes[:'responderRules']

  raise 'You cannot provide both :responderRules and :responder_rules' if attributes.key?(:'responderRules') && attributes.key?(:'responder_rules')

  self.responder_rules = attributes[:'responder_rules'] if attributes[:'responder_rules']

  self.effective_responder_rules = attributes[:'effectiveResponderRules'] if attributes[:'effectiveResponderRules']

  raise 'You cannot provide both :effectiveResponderRules and :effective_responder_rules' if attributes.key?(:'effectiveResponderRules') && attributes.key?(:'effective_responder_rules')

  self.effective_responder_rules = attributes[:'effective_responder_rules'] if attributes[:'effective_responder_rules']

  self.source_responder_recipe_id = attributes[:'sourceResponderRecipeId'] if attributes[:'sourceResponderRecipeId']

  raise 'You cannot provide both :sourceResponderRecipeId and :source_responder_recipe_id' if attributes.key?(:'sourceResponderRecipeId') && attributes.key?(:'source_responder_recipe_id')

  self.source_responder_recipe_id = attributes[:'source_responder_recipe_id'] if attributes[:'source_responder_recipe_id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

  raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

  self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']
end

Instance Attribute Details

#compartment_idString

**[Required]** Compartment Identifier

Returns:

  • (String)


58
59
60
# File 'lib/oci/cloud_guard/models/responder_recipe.rb', line 58

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


88
89
90
# File 'lib/oci/cloud_guard/models/responder_recipe.rb', line 88

def defined_tags
  @defined_tags
end

#descriptionString

ResponderRecipe description.

Returns:

  • (String)


38
39
40
# File 'lib/oci/cloud_guard/models/responder_recipe.rb', line 38

def description
  @description
end

#display_nameString

ResponderRecipe display name.

Returns:

  • (String)


34
35
36
# File 'lib/oci/cloud_guard/models/responder_recipe.rb', line 34

def display_name
  @display_name
end

#effective_responder_rulesArray<OCI::CloudGuard::Models::ResponderRecipeResponderRule>

List of responder rules associated with the recipe



50
51
52
# File 'lib/oci/cloud_guard/models/responder_recipe.rb', line 50

def effective_responder_rules
  @effective_responder_rules
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`

Avoid entering confidential information.

Returns:

  • (Hash<String, String>)


82
83
84
# File 'lib/oci/cloud_guard/models/responder_recipe.rb', line 82

def freeform_tags
  @freeform_tags
end

#idString

**[Required]** Identifier for ResponderRecipe.

Returns:

  • (String)


30
31
32
# File 'lib/oci/cloud_guard/models/responder_recipe.rb', line 30

def id
  @id
end

#lifecycle_detailsString

A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.

Returns:

  • (String)


74
75
76
# File 'lib/oci/cloud_guard/models/responder_recipe.rb', line 74

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

The current state of the Example.

Returns:

  • (String)


70
71
72
# File 'lib/oci/cloud_guard/models/responder_recipe.rb', line 70

def lifecycle_state
  @lifecycle_state
end

#ownerString

Owner of ResponderRecipe

Returns:

  • (String)


42
43
44
# File 'lib/oci/cloud_guard/models/responder_recipe.rb', line 42

def owner
  @owner
end

#responder_rulesArray<OCI::CloudGuard::Models::ResponderRecipeResponderRule>

List of responder rules associated with the recipe



46
47
48
# File 'lib/oci/cloud_guard/models/responder_recipe.rb', line 46

def responder_rules
  @responder_rules
end

#source_responder_recipe_idString

The id of the source responder recipe.

Returns:

  • (String)


54
55
56
# File 'lib/oci/cloud_guard/models/responder_recipe.rb', line 54

def source_responder_recipe_id
  @source_responder_recipe_id
end

#system_tagsHash<String, Hash<String, Object>>

System tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). System tags can be viewed by users, but can only be created by the system.

Example: `{"free-tier-retained": "true"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


97
98
99
# File 'lib/oci/cloud_guard/models/responder_recipe.rb', line 97

def system_tags
  @system_tags
end

#time_createdDateTime

The date and time the responder recipe was created. Format defined by RFC3339.

Returns:

  • (DateTime)


62
63
64
# File 'lib/oci/cloud_guard/models/responder_recipe.rb', line 62

def time_created
  @time_created
end

#time_updatedDateTime

The date and time the responder recipe was updated. Format defined by RFC3339.

Returns:

  • (DateTime)


66
67
68
# File 'lib/oci/cloud_guard/models/responder_recipe.rb', line 66

def time_updated
  @time_updated
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/oci/cloud_guard/models/responder_recipe.rb', line 100

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'display_name': :'displayName',
    'description': :'description',
    'owner': :'owner',
    'responder_rules': :'responderRules',
    'effective_responder_rules': :'effectiveResponderRules',
    'source_responder_recipe_id': :'sourceResponderRecipeId',
    'compartment_id': :'compartmentId',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/oci/cloud_guard/models/responder_recipe.rb', line 123

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'display_name': :'String',
    'description': :'String',
    'owner': :'String',
    'responder_rules': :'Array<OCI::CloudGuard::Models::ResponderRecipeResponderRule>',
    'effective_responder_rules': :'Array<OCI::CloudGuard::Models::ResponderRecipeResponderRule>',
    'source_responder_recipe_id': :'String',
    'compartment_id': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
# File 'lib/oci/cloud_guard/models/responder_recipe.rb', line 284

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    display_name == other.display_name &&
    description == other.description &&
    owner == other.owner &&
    responder_rules == other.responder_rules &&
    effective_responder_rules == other.effective_responder_rules &&
    source_responder_recipe_id == other.source_responder_recipe_id &&
    compartment_id == other.compartment_id &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
# File 'lib/oci/cloud_guard/models/responder_recipe.rb', line 328

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


308
309
310
# File 'lib/oci/cloud_guard/models/responder_recipe.rb', line 308

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



317
318
319
# File 'lib/oci/cloud_guard/models/responder_recipe.rb', line 317

def hash
  [id, display_name, description, owner, responder_rules, effective_responder_rules, source_responder_recipe_id, compartment_id, time_created, time_updated, lifecycle_state, lifecycle_details, freeform_tags, defined_tags, system_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



361
362
363
364
365
366
367
368
369
370
# File 'lib/oci/cloud_guard/models/responder_recipe.rb', line 361

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



355
356
357
# File 'lib/oci/cloud_guard/models/responder_recipe.rb', line 355

def to_s
  to_hash.to_s
end