Class: OCI::CloudGuard::Models::ResponderRecipeResponderRule
- Inherits:
-
Object
- Object
- OCI::CloudGuard::Models::ResponderRecipeResponderRule
- Defined in:
- lib/oci/cloud_guard/models/responder_recipe_responder_rule.rb
Overview
Details of ResponderRule.
Constant Summary collapse
- TYPE_ENUM =
[ TYPE_REMEDIATION = 'REMEDIATION'.freeze, TYPE_NOTIFICATION = 'NOTIFICATION'.freeze, TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- SUPPORTED_MODES_ENUM =
[ SUPPORTED_MODES_AUTOACTION = 'AUTOACTION'.freeze, SUPPORTED_MODES_USERACTION = 'USERACTION'.freeze, SUPPORTED_MODES_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** Compartment Identifier.
-
#description ⇒ String
ResponderRule description.
- #details ⇒ OCI::CloudGuard::Models::ResponderRuleDetails
-
#display_name ⇒ String
ResponderRule display name.
-
#lifecycle_details ⇒ String
A message describing the current state in more detail.
-
#lifecycle_state ⇒ String
The current state of the ResponderRule.
-
#policies ⇒ Array<String>
List of Policy.
-
#responder_rule_id ⇒ String
**[Required]** Identifier for ResponderRule.
-
#supported_modes ⇒ Array<String>
Supported Execution Modes.
-
#time_created ⇒ DateTime
The date and time the responder recipe rule was created.
-
#time_updated ⇒ DateTime
The date and time the responder recipe rule was updated.
-
#type ⇒ String
Type of Responder.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ResponderRecipeResponderRule
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ResponderRecipeResponderRule
Initializes the object
139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/oci/cloud_guard/models/responder_recipe_responder_rule.rb', line 139 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.responder_rule_id = attributes[:'responderRuleId'] if attributes[:'responderRuleId'] raise 'You cannot provide both :responderRuleId and :responder_rule_id' if attributes.key?(:'responderRuleId') && attributes.key?(:'responder_rule_id') self.responder_rule_id = attributes[:'responder_rule_id'] if attributes[:'responder_rule_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.type = attributes[:'type'] if attributes[:'type'] self.policies = attributes[:'policies'] if attributes[:'policies'] self.supported_modes = attributes[:'supportedModes'] if attributes[:'supportedModes'] raise 'You cannot provide both :supportedModes and :supported_modes' if attributes.key?(:'supportedModes') && attributes.key?(:'supported_modes') self.supported_modes = attributes[:'supported_modes'] if attributes[:'supported_modes'] self.details = attributes[:'details'] if attributes[:'details'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** Compartment Identifier
63 64 65 |
# File 'lib/oci/cloud_guard/models/responder_recipe_responder_rule.rb', line 63 def compartment_id @compartment_id end |
#description ⇒ String
ResponderRule description.
44 45 46 |
# File 'lib/oci/cloud_guard/models/responder_recipe_responder_rule.rb', line 44 def description @description end |
#details ⇒ OCI::CloudGuard::Models::ResponderRuleDetails
59 60 61 |
# File 'lib/oci/cloud_guard/models/responder_recipe_responder_rule.rb', line 59 def details @details end |
#display_name ⇒ String
ResponderRule display name.
40 41 42 |
# File 'lib/oci/cloud_guard/models/responder_recipe_responder_rule.rb', line 40 def display_name @display_name end |
#lifecycle_details ⇒ String
A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
79 80 81 |
# File 'lib/oci/cloud_guard/models/responder_recipe_responder_rule.rb', line 79 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
The current state of the ResponderRule.
75 76 77 |
# File 'lib/oci/cloud_guard/models/responder_recipe_responder_rule.rb', line 75 def lifecycle_state @lifecycle_state end |
#policies ⇒ Array<String>
List of Policy
52 53 54 |
# File 'lib/oci/cloud_guard/models/responder_recipe_responder_rule.rb', line 52 def policies @policies end |
#responder_rule_id ⇒ String
**[Required]** Identifier for ResponderRule.
36 37 38 |
# File 'lib/oci/cloud_guard/models/responder_recipe_responder_rule.rb', line 36 def responder_rule_id @responder_rule_id end |
#supported_modes ⇒ Array<String>
Supported Execution Modes
56 57 58 |
# File 'lib/oci/cloud_guard/models/responder_recipe_responder_rule.rb', line 56 def supported_modes @supported_modes end |
#time_created ⇒ DateTime
The date and time the responder recipe rule was created. Format defined by RFC3339.
67 68 69 |
# File 'lib/oci/cloud_guard/models/responder_recipe_responder_rule.rb', line 67 def time_created @time_created end |
#time_updated ⇒ DateTime
The date and time the responder recipe rule was updated. Format defined by RFC3339.
71 72 73 |
# File 'lib/oci/cloud_guard/models/responder_recipe_responder_rule.rb', line 71 def time_updated @time_updated end |
#type ⇒ String
Type of Responder
48 49 50 |
# File 'lib/oci/cloud_guard/models/responder_recipe_responder_rule.rb', line 48 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/oci/cloud_guard/models/responder_recipe_responder_rule.rb', line 82 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'responder_rule_id': :'responderRuleId', 'display_name': :'displayName', 'description': :'description', 'type': :'type', 'policies': :'policies', 'supported_modes': :'supportedModes', 'details': :'details', 'compartment_id': :'compartmentId', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/oci/cloud_guard/models/responder_recipe_responder_rule.rb', line 102 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'responder_rule_id': :'String', 'display_name': :'String', 'description': :'String', 'type': :'String', 'policies': :'Array<String>', 'supported_modes': :'Array<String>', 'details': :'OCI::CloudGuard::Models::ResponderRuleDetails', 'compartment_id': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_details': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/oci/cloud_guard/models/responder_recipe_responder_rule.rb', line 255 def ==(other) return true if equal?(other) self.class == other.class && responder_rule_id == other.responder_rule_id && display_name == other.display_name && description == other.description && type == other.type && policies == other.policies && supported_modes == other.supported_modes && details == other.details && compartment_id == other.compartment_id && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 |
# File 'lib/oci/cloud_guard/models/responder_recipe_responder_rule.rb', line 296 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
276 277 278 |
# File 'lib/oci/cloud_guard/models/responder_recipe_responder_rule.rb', line 276 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
285 286 287 |
# File 'lib/oci/cloud_guard/models/responder_recipe_responder_rule.rb', line 285 def hash [responder_rule_id, display_name, description, type, policies, supported_modes, details, compartment_id, time_created, time_updated, lifecycle_state, lifecycle_details].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
329 330 331 332 333 334 335 336 337 338 |
# File 'lib/oci/cloud_guard/models/responder_recipe_responder_rule.rb', line 329 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
323 324 325 |
# File 'lib/oci/cloud_guard/models/responder_recipe_responder_rule.rb', line 323 def to_s to_hash.to_s end |