Class: OCI::CloudGuard::Models::SecurityScoreAggregation

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/cloud_guard/models/security_score_aggregation.rb

Overview

Provides the dimensions and their corresponding count value.

Constant Summary collapse

SECURITY_RATING_ENUM =
[
  SECURITY_RATING_EXCELLENT = 'EXCELLENT'.freeze,
  SECURITY_RATING_GOOD = 'GOOD'.freeze,
  SECURITY_RATING_FAIR = 'FAIR'.freeze,
  SECURITY_RATING_POOR = 'POOR'.freeze,
  SECURITY_RATING_NA = 'NA'.freeze,
  SECURITY_RATING_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ SecurityScoreAggregation

Initializes the object

Options Hash (attributes):

  • :dimensions_map (Hash<String, String>)

    The value to assign to the #dimensions_map property

  • :security_rating (String)

    The value to assign to the #security_rating property

  • :security_score (Integer)

    The value to assign to the #security_score property

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/oci/cloud_guard/models/security_score_aggregation.rb', line 63

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.dimensions_map = attributes[:'dimensionsMap'] if attributes[:'dimensionsMap']

  raise 'You cannot provide both :dimensionsMap and :dimensions_map' if attributes.key?(:'dimensionsMap') && attributes.key?(:'dimensions_map')

  self.dimensions_map = attributes[:'dimensions_map'] if attributes[:'dimensions_map']

  self.security_rating = attributes[:'securityRating'] if attributes[:'securityRating']

  raise 'You cannot provide both :securityRating and :security_rating' if attributes.key?(:'securityRating') && attributes.key?(:'security_rating')

  self.security_rating = attributes[:'security_rating'] if attributes[:'security_rating']

  self.security_score = attributes[:'securityScore'] if attributes[:'securityScore']

  raise 'You cannot provide both :securityScore and :security_score' if attributes.key?(:'securityScore') && attributes.key?(:'security_score')

  self.security_score = attributes[:'security_score'] if attributes[:'security_score']
end

Instance Attribute Details

#dimensions_mapHash<String, String>

[Required] The key-value pairs of dimensions and their names.

Returns:



22
23
24
# File 'lib/oci/cloud_guard/models/security_score_aggregation.rb', line 22

def dimensions_map
  @dimensions_map
end

#security_ratingString

[Required] The security rating with given dimension/s

Returns:



26
27
28
# File 'lib/oci/cloud_guard/models/security_score_aggregation.rb', line 26

def security_rating
  @security_rating
end

#security_scoreInteger

[Required] The security score with given dimension/s

Returns:



30
31
32
# File 'lib/oci/cloud_guard/models/security_score_aggregation.rb', line 30

def security_score
  @security_score
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



33
34
35
36
37
38
39
40
41
# File 'lib/oci/cloud_guard/models/security_score_aggregation.rb', line 33

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'dimensions_map': :'dimensionsMap',
    'security_rating': :'securityRating',
    'security_score': :'securityScore'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



44
45
46
47
48
49
50
51
52
# File 'lib/oci/cloud_guard/models/security_score_aggregation.rb', line 44

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'dimensions_map': :'Hash<String, String>',
    'security_rating': :'String',
    'security_score': :'Integer'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • the other object to be compared



108
109
110
111
112
113
114
115
# File 'lib/oci/cloud_guard/models/security_score_aggregation.rb', line 108

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    dimensions_map == other.dimensions_map &&
    security_rating == other.security_rating &&
    security_score == other.security_score
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/oci/cloud_guard/models/security_score_aggregation.rb', line 140

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method

Parameters:

  • the other object to be compared

Returns:



120
121
122
# File 'lib/oci/cloud_guard/models/security_score_aggregation.rb', line 120

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • Hash code



129
130
131
# File 'lib/oci/cloud_guard/models/security_score_aggregation.rb', line 129

def hash
  [dimensions_map, security_rating, security_score].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



173
174
175
176
177
178
179
180
181
182
# File 'lib/oci/cloud_guard/models/security_score_aggregation.rb', line 173

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



167
168
169
# File 'lib/oci/cloud_guard/models/security_score_aggregation.rb', line 167

def to_s
  to_hash.to_s
end