Class: OCI::CloudGuard::Models::SecurityScoreTrendAggregation
- Inherits:
-
Object
- Object
- OCI::CloudGuard::Models::SecurityScoreTrendAggregation
- Defined in:
- lib/oci/cloud_guard/models/security_score_trend_aggregation.rb
Overview
Provides the dimensions and their corresponding time and security score.
Constant Summary collapse
- SECURITY_RATING_ENUM =
[ SECURITY_RATING_EXCELLENT = 'EXCELLENT'.freeze, SECURITY_RATING_GOOD = 'GOOD'.freeze, SECURITY_RATING_FAIR = 'FAIR'.freeze, SECURITY_RATING_POOR = 'POOR'.freeze, SECURITY_RATING_NA = 'NA'.freeze, SECURITY_RATING_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#dimensions_map ⇒ Hash<String, String>
[Required] The key-value pairs of dimensions and their names.
-
#duration_in_seconds ⇒ Integer
[Required] Duration.
-
#security_rating ⇒ String
[Required] The security rating with given dimensions and time range.
-
#security_score ⇒ Integer
[Required] The security score with given dimensions and time range.
-
#start_timestamp ⇒ Float
[Required] Start Time in epoch seconds.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SecurityScoreTrendAggregation
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ SecurityScoreTrendAggregation
Initializes the object
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/oci/cloud_guard/models/security_score_trend_aggregation.rb', line 77 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.dimensions_map = attributes[:'dimensionsMap'] if attributes[:'dimensionsMap'] raise 'You cannot provide both :dimensionsMap and :dimensions_map' if attributes.key?(:'dimensionsMap') && attributes.key?(:'dimensions_map') self.dimensions_map = attributes[:'dimensions_map'] if attributes[:'dimensions_map'] self. = attributes[:'startTimestamp'] if attributes[:'startTimestamp'] raise 'You cannot provide both :startTimestamp and :start_timestamp' if attributes.key?(:'startTimestamp') && attributes.key?(:'start_timestamp') self. = attributes[:'start_timestamp'] if attributes[:'start_timestamp'] self.duration_in_seconds = attributes[:'durationInSeconds'] if attributes[:'durationInSeconds'] raise 'You cannot provide both :durationInSeconds and :duration_in_seconds' if attributes.key?(:'durationInSeconds') && attributes.key?(:'duration_in_seconds') self.duration_in_seconds = attributes[:'duration_in_seconds'] if attributes[:'duration_in_seconds'] self. = attributes[:'securityRating'] if attributes[:'securityRating'] raise 'You cannot provide both :securityRating and :security_rating' if attributes.key?(:'securityRating') && attributes.key?(:'security_rating') self. = attributes[:'security_rating'] if attributes[:'security_rating'] self.security_score = attributes[:'securityScore'] if attributes[:'securityScore'] raise 'You cannot provide both :securityScore and :security_score' if attributes.key?(:'securityScore') && attributes.key?(:'security_score') self.security_score = attributes[:'security_score'] if attributes[:'security_score'] end |
Instance Attribute Details
#dimensions_map ⇒ Hash<String, String>
[Required] The key-value pairs of dimensions and their names.
22 23 24 |
# File 'lib/oci/cloud_guard/models/security_score_trend_aggregation.rb', line 22 def dimensions_map @dimensions_map end |
#duration_in_seconds ⇒ Integer
[Required] Duration
30 31 32 |
# File 'lib/oci/cloud_guard/models/security_score_trend_aggregation.rb', line 30 def duration_in_seconds @duration_in_seconds end |
#security_rating ⇒ String
[Required] The security rating with given dimensions and time range
34 35 36 |
# File 'lib/oci/cloud_guard/models/security_score_trend_aggregation.rb', line 34 def end |
#security_score ⇒ Integer
[Required] The security score with given dimensions and time range
38 39 40 |
# File 'lib/oci/cloud_guard/models/security_score_trend_aggregation.rb', line 38 def security_score @security_score end |
#start_timestamp ⇒ Float
[Required] Start Time in epoch seconds
26 27 28 |
# File 'lib/oci/cloud_guard/models/security_score_trend_aggregation.rb', line 26 def end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/oci/cloud_guard/models/security_score_trend_aggregation.rb', line 41 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'dimensions_map': :'dimensionsMap', 'start_timestamp': :'startTimestamp', 'duration_in_seconds': :'durationInSeconds', 'security_rating': :'securityRating', 'security_score': :'securityScore' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/oci/cloud_guard/models/security_score_trend_aggregation.rb', line 54 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'dimensions_map': :'Hash<String, String>', 'start_timestamp': :'Float', 'duration_in_seconds': :'Integer', 'security_rating': :'String', 'security_score': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
134 135 136 137 138 139 140 141 142 143 |
# File 'lib/oci/cloud_guard/models/security_score_trend_aggregation.rb', line 134 def ==(other) return true if equal?(other) self.class == other.class && dimensions_map == other.dimensions_map && == other. && duration_in_seconds == other.duration_in_seconds && == other. && security_score == other.security_score end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/oci/cloud_guard/models/security_score_trend_aggregation.rb', line 168 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
148 149 150 |
# File 'lib/oci/cloud_guard/models/security_score_trend_aggregation.rb', line 148 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
157 158 159 |
# File 'lib/oci/cloud_guard/models/security_score_trend_aggregation.rb', line 157 def hash [dimensions_map, , duration_in_seconds, , security_score].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
201 202 203 204 205 206 207 208 209 210 |
# File 'lib/oci/cloud_guard/models/security_score_trend_aggregation.rb', line 201 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
195 196 197 |
# File 'lib/oci/cloud_guard/models/security_score_trend_aggregation.rb', line 195 def to_s to_hash.to_s end |