Class: OCI::CloudGuard::Models::SecurityZoneTargetDetails
- Inherits:
-
TargetDetails
- Object
- TargetDetails
- OCI::CloudGuard::Models::SecurityZoneTargetDetails
- Defined in:
- lib/oci/cloud_guard/models/security_zone_target_details.rb
Overview
Details about Security Zone Target.
Constant Summary
Constants inherited from TargetDetails
TargetDetails::TARGET_RESOURCE_TYPE_ENUM
Instance Attribute Summary collapse
-
#security_zone_display_name ⇒ String
The name of the security zone to associate this compartment with.
-
#security_zone_id ⇒ String
The OCID of the security zone to associate this compartment with.
-
#target_security_zone_recipes ⇒ Array<OCI::CloudGuard::Models::SecurityRecipe>
The list of security zone recipes to associate this compartment with.
Attributes inherited from TargetDetails
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SecurityZoneTargetDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from TargetDetails
Constructor Details
#initialize(attributes = {}) ⇒ SecurityZoneTargetDetails
Initializes the object
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/oci/cloud_guard/models/security_zone_target_details.rb', line 56 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['targetResourceType'] = 'SECURITY_ZONE' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.security_zone_id = attributes[:'securityZoneId'] if attributes[:'securityZoneId'] raise 'You cannot provide both :securityZoneId and :security_zone_id' if attributes.key?(:'securityZoneId') && attributes.key?(:'security_zone_id') self.security_zone_id = attributes[:'security_zone_id'] if attributes[:'security_zone_id'] self.security_zone_display_name = attributes[:'securityZoneDisplayName'] if attributes[:'securityZoneDisplayName'] raise 'You cannot provide both :securityZoneDisplayName and :security_zone_display_name' if attributes.key?(:'securityZoneDisplayName') && attributes.key?(:'security_zone_display_name') self.security_zone_display_name = attributes[:'security_zone_display_name'] if attributes[:'security_zone_display_name'] self.target_security_zone_recipes = attributes[:'targetSecurityZoneRecipes'] if attributes[:'targetSecurityZoneRecipes'] raise 'You cannot provide both :targetSecurityZoneRecipes and :target_security_zone_recipes' if attributes.key?(:'targetSecurityZoneRecipes') && attributes.key?(:'target_security_zone_recipes') self.target_security_zone_recipes = attributes[:'target_security_zone_recipes'] if attributes[:'target_security_zone_recipes'] end |
Instance Attribute Details
#security_zone_display_name ⇒ String
The name of the security zone to associate this compartment with.
17 18 19 |
# File 'lib/oci/cloud_guard/models/security_zone_target_details.rb', line 17 def security_zone_display_name @security_zone_display_name end |
#security_zone_id ⇒ String
The OCID of the security zone to associate this compartment with.
13 14 15 |
# File 'lib/oci/cloud_guard/models/security_zone_target_details.rb', line 13 def security_zone_id @security_zone_id end |
#target_security_zone_recipes ⇒ Array<OCI::CloudGuard::Models::SecurityRecipe>
The list of security zone recipes to associate this compartment with.
21 22 23 |
# File 'lib/oci/cloud_guard/models/security_zone_target_details.rb', line 21 def target_security_zone_recipes @target_security_zone_recipes end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
24 25 26 27 28 29 30 31 32 33 |
# File 'lib/oci/cloud_guard/models/security_zone_target_details.rb', line 24 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'target_resource_type': :'targetResourceType', 'security_zone_id': :'securityZoneId', 'security_zone_display_name': :'securityZoneDisplayName', 'target_security_zone_recipes': :'targetSecurityZoneRecipes' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
36 37 38 39 40 41 42 43 44 45 |
# File 'lib/oci/cloud_guard/models/security_zone_target_details.rb', line 36 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'target_resource_type': :'String', 'security_zone_id': :'String', 'security_zone_display_name': :'String', 'target_security_zone_recipes': :'Array<OCI::CloudGuard::Models::SecurityRecipe>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
92 93 94 95 96 97 98 99 100 |
# File 'lib/oci/cloud_guard/models/security_zone_target_details.rb', line 92 def ==(other) return true if equal?(other) self.class == other.class && target_resource_type == other.target_resource_type && security_zone_id == other.security_zone_id && security_zone_display_name == other.security_zone_display_name && target_security_zone_recipes == other.target_security_zone_recipes end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/oci/cloud_guard/models/security_zone_target_details.rb', line 125 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
105 106 107 |
# File 'lib/oci/cloud_guard/models/security_zone_target_details.rb', line 105 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
114 115 116 |
# File 'lib/oci/cloud_guard/models/security_zone_target_details.rb', line 114 def hash [target_resource_type, security_zone_id, security_zone_display_name, target_security_zone_recipes].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
158 159 160 161 162 163 164 165 166 167 |
# File 'lib/oci/cloud_guard/models/security_zone_target_details.rb', line 158 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
152 153 154 |
# File 'lib/oci/cloud_guard/models/security_zone_target_details.rb', line 152 def to_s to_hash.to_s end |