Class: OCI::CloudGuard::Models::Sighting
- Inherits:
-
Object
- Object
- OCI::CloudGuard::Models::Sighting
- Defined in:
- lib/oci/cloud_guard/models/sighting.rb
Overview
Sighting details.
Constant Summary collapse
- CLASSIFICATION_STATUS_ENUM =
[ CLASSIFICATION_STATUS_FALSE_POSITIVE = 'FALSE_POSITIVE'.freeze, CLASSIFICATION_STATUS_FALSE_NEGATIVE = 'FALSE_NEGATIVE'.freeze, CLASSIFICATION_STATUS_TRUE_POSITIVE = 'TRUE_POSITIVE'.freeze, CLASSIFICATION_STATUS_TRUE_NEGATIVE = 'TRUE_NEGATIVE'.freeze, CLASSIFICATION_STATUS_NOT_CLASSIFIED = 'NOT_CLASSIFIED'.freeze, CLASSIFICATION_STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- SEVERITY_ENUM =
[ SEVERITY_CRITICAL = 'CRITICAL'.freeze, SEVERITY_HIGH = 'HIGH'.freeze, SEVERITY_MEDIUM = 'MEDIUM'.freeze, SEVERITY_LOW = 'LOW'.freeze, SEVERITY_MINOR = 'MINOR'.freeze, SEVERITY_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- CONFIDENCE_ENUM =
[ CONFIDENCE_CRITICAL = 'CRITICAL'.freeze, CONFIDENCE_HIGH = 'HIGH'.freeze, CONFIDENCE_MEDIUM = 'MEDIUM'.freeze, CONFIDENCE_LOW = 'LOW'.freeze, CONFIDENCE_MINOR = 'MINOR'.freeze, CONFIDENCE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#actor_principal_id ⇒ String
Unique identifier for principal actor.
-
#actor_principal_name ⇒ String
Name of the principal actor.
-
#actor_principal_type ⇒ String
Type of the principal actor.
-
#additional_details ⇒ Hash<String, String>
The additional details of the Sighting.
-
#classification_status ⇒ String
**[Required]** ClassificationStatus of the sighting event.
-
#compartment_id ⇒ String
**[Required]** Compartment Id where the resource is created.
-
#confidence ⇒ String
**[Required]** Confidence of the sighting.
-
#description ⇒ String
**[Required]** Description of the sighting event.
-
#id ⇒ String
**[Required]** Unique identifier for sighting event.
-
#problem_id ⇒ String
Problem Id to which the Sighting is associated.
-
#regions ⇒ Array<String>
**[Required]** regions involved in the sighting.
-
#severity ⇒ String
**[Required]** Severity of the sighting.
-
#sighting_score ⇒ Integer
**[Required]** Score for the sighting.
-
#sighting_type ⇒ String
**[Required]** Identifier for the sighting type.
-
#sighting_type_display_name ⇒ String
**[Required]** Display name of the sighting type.
-
#tactic_name ⇒ String
**[Required]** Name of the Mitre att&ck tactic.
-
#technique_name ⇒ String
**[Required]** Name of the Mitre att&ck technique.
-
#time_first_detected ⇒ DateTime
**[Required]** The date and time the sighting was first detected.
-
#time_last_detected ⇒ DateTime
**[Required]** The date and time the sighting was last detected.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Sighting
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Sighting
Initializes the object
193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 |
# File 'lib/oci/cloud_guard/models/sighting.rb', line 193 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.description = attributes[:'description'] if attributes[:'description'] self.problem_id = attributes[:'problemId'] if attributes[:'problemId'] raise 'You cannot provide both :problemId and :problem_id' if attributes.key?(:'problemId') && attributes.key?(:'problem_id') self.problem_id = attributes[:'problem_id'] if attributes[:'problem_id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.actor_principal_id = attributes[:'actorPrincipalId'] if attributes[:'actorPrincipalId'] raise 'You cannot provide both :actorPrincipalId and :actor_principal_id' if attributes.key?(:'actorPrincipalId') && attributes.key?(:'actor_principal_id') self.actor_principal_id = attributes[:'actor_principal_id'] if attributes[:'actor_principal_id'] self.actor_principal_name = attributes[:'actorPrincipalName'] if attributes[:'actorPrincipalName'] raise 'You cannot provide both :actorPrincipalName and :actor_principal_name' if attributes.key?(:'actorPrincipalName') && attributes.key?(:'actor_principal_name') self.actor_principal_name = attributes[:'actor_principal_name'] if attributes[:'actor_principal_name'] self.actor_principal_type = attributes[:'actorPrincipalType'] if attributes[:'actorPrincipalType'] raise 'You cannot provide both :actorPrincipalType and :actor_principal_type' if attributes.key?(:'actorPrincipalType') && attributes.key?(:'actor_principal_type') self.actor_principal_type = attributes[:'actor_principal_type'] if attributes[:'actor_principal_type'] self.classification_status = attributes[:'classificationStatus'] if attributes[:'classificationStatus'] raise 'You cannot provide both :classificationStatus and :classification_status' if attributes.key?(:'classificationStatus') && attributes.key?(:'classification_status') self.classification_status = attributes[:'classification_status'] if attributes[:'classification_status'] self.sighting_type = attributes[:'sightingType'] if attributes[:'sightingType'] raise 'You cannot provide both :sightingType and :sighting_type' if attributes.key?(:'sightingType') && attributes.key?(:'sighting_type') self.sighting_type = attributes[:'sighting_type'] if attributes[:'sighting_type'] self.sighting_type_display_name = attributes[:'sightingTypeDisplayName'] if attributes[:'sightingTypeDisplayName'] raise 'You cannot provide both :sightingTypeDisplayName and :sighting_type_display_name' if attributes.key?(:'sightingTypeDisplayName') && attributes.key?(:'sighting_type_display_name') self.sighting_type_display_name = attributes[:'sighting_type_display_name'] if attributes[:'sighting_type_display_name'] self.tactic_name = attributes[:'tacticName'] if attributes[:'tacticName'] raise 'You cannot provide both :tacticName and :tactic_name' if attributes.key?(:'tacticName') && attributes.key?(:'tactic_name') self.tactic_name = attributes[:'tactic_name'] if attributes[:'tactic_name'] self.technique_name = attributes[:'techniqueName'] if attributes[:'techniqueName'] raise 'You cannot provide both :techniqueName and :technique_name' if attributes.key?(:'techniqueName') && attributes.key?(:'technique_name') self.technique_name = attributes[:'technique_name'] if attributes[:'technique_name'] self.sighting_score = attributes[:'sightingScore'] if attributes[:'sightingScore'] raise 'You cannot provide both :sightingScore and :sighting_score' if attributes.key?(:'sightingScore') && attributes.key?(:'sighting_score') self.sighting_score = attributes[:'sighting_score'] if attributes[:'sighting_score'] self.severity = attributes[:'severity'] if attributes[:'severity'] self.confidence = attributes[:'confidence'] if attributes[:'confidence'] self.time_first_detected = attributes[:'timeFirstDetected'] if attributes[:'timeFirstDetected'] raise 'You cannot provide both :timeFirstDetected and :time_first_detected' if attributes.key?(:'timeFirstDetected') && attributes.key?(:'time_first_detected') self.time_first_detected = attributes[:'time_first_detected'] if attributes[:'time_first_detected'] self.time_last_detected = attributes[:'timeLastDetected'] if attributes[:'timeLastDetected'] raise 'You cannot provide both :timeLastDetected and :time_last_detected' if attributes.key?(:'timeLastDetected') && attributes.key?(:'time_last_detected') self.time_last_detected = attributes[:'time_last_detected'] if attributes[:'time_last_detected'] self.regions = attributes[:'regions'] if attributes[:'regions'] self.additional_details = attributes[:'additionalDetails'] if attributes[:'additionalDetails'] raise 'You cannot provide both :additionalDetails and :additional_details' if attributes.key?(:'additionalDetails') && attributes.key?(:'additional_details') self.additional_details = attributes[:'additional_details'] if attributes[:'additional_details'] end |
Instance Attribute Details
#actor_principal_id ⇒ String
Unique identifier for principal actor
56 57 58 |
# File 'lib/oci/cloud_guard/models/sighting.rb', line 56 def actor_principal_id @actor_principal_id end |
#actor_principal_name ⇒ String
Name of the principal actor
60 61 62 |
# File 'lib/oci/cloud_guard/models/sighting.rb', line 60 def actor_principal_name @actor_principal_name end |
#actor_principal_type ⇒ String
Type of the principal actor
64 65 66 |
# File 'lib/oci/cloud_guard/models/sighting.rb', line 64 def actor_principal_type @actor_principal_type end |
#additional_details ⇒ Hash<String, String>
The additional details of the Sighting
112 113 114 |
# File 'lib/oci/cloud_guard/models/sighting.rb', line 112 def additional_details @additional_details end |
#classification_status ⇒ String
**[Required]** ClassificationStatus of the sighting event
68 69 70 |
# File 'lib/oci/cloud_guard/models/sighting.rb', line 68 def classification_status @classification_status end |
#compartment_id ⇒ String
**[Required]** Compartment Id where the resource is created
52 53 54 |
# File 'lib/oci/cloud_guard/models/sighting.rb', line 52 def compartment_id @compartment_id end |
#confidence ⇒ String
**[Required]** Confidence of the sighting
96 97 98 |
# File 'lib/oci/cloud_guard/models/sighting.rb', line 96 def confidence @confidence end |
#description ⇒ String
**[Required]** Description of the sighting event
44 45 46 |
# File 'lib/oci/cloud_guard/models/sighting.rb', line 44 def description @description end |
#id ⇒ String
**[Required]** Unique identifier for sighting event
40 41 42 |
# File 'lib/oci/cloud_guard/models/sighting.rb', line 40 def id @id end |
#problem_id ⇒ String
Problem Id to which the Sighting is associated
48 49 50 |
# File 'lib/oci/cloud_guard/models/sighting.rb', line 48 def problem_id @problem_id end |
#regions ⇒ Array<String>
**[Required]** regions involved in the sighting
108 109 110 |
# File 'lib/oci/cloud_guard/models/sighting.rb', line 108 def regions @regions end |
#severity ⇒ String
**[Required]** Severity of the sighting
92 93 94 |
# File 'lib/oci/cloud_guard/models/sighting.rb', line 92 def severity @severity end |
#sighting_score ⇒ Integer
**[Required]** Score for the sighting
88 89 90 |
# File 'lib/oci/cloud_guard/models/sighting.rb', line 88 def sighting_score @sighting_score end |
#sighting_type ⇒ String
**[Required]** Identifier for the sighting type
72 73 74 |
# File 'lib/oci/cloud_guard/models/sighting.rb', line 72 def sighting_type @sighting_type end |
#sighting_type_display_name ⇒ String
**[Required]** Display name of the sighting type
76 77 78 |
# File 'lib/oci/cloud_guard/models/sighting.rb', line 76 def sighting_type_display_name @sighting_type_display_name end |
#tactic_name ⇒ String
**[Required]** Name of the Mitre att&ck tactic
80 81 82 |
# File 'lib/oci/cloud_guard/models/sighting.rb', line 80 def tactic_name @tactic_name end |
#technique_name ⇒ String
**[Required]** Name of the Mitre att&ck technique
84 85 86 |
# File 'lib/oci/cloud_guard/models/sighting.rb', line 84 def technique_name @technique_name end |
#time_first_detected ⇒ DateTime
**[Required]** The date and time the sighting was first detected. Format defined by RFC3339.
100 101 102 |
# File 'lib/oci/cloud_guard/models/sighting.rb', line 100 def time_first_detected @time_first_detected end |
#time_last_detected ⇒ DateTime
**[Required]** The date and time the sighting was last detected. Format defined by RFC3339.
104 105 106 |
# File 'lib/oci/cloud_guard/models/sighting.rb', line 104 def time_last_detected @time_last_detected end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/oci/cloud_guard/models/sighting.rb', line 115 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'description': :'description', 'problem_id': :'problemId', 'compartment_id': :'compartmentId', 'actor_principal_id': :'actorPrincipalId', 'actor_principal_name': :'actorPrincipalName', 'actor_principal_type': :'actorPrincipalType', 'classification_status': :'classificationStatus', 'sighting_type': :'sightingType', 'sighting_type_display_name': :'sightingTypeDisplayName', 'tactic_name': :'tacticName', 'technique_name': :'techniqueName', 'sighting_score': :'sightingScore', 'severity': :'severity', 'confidence': :'confidence', 'time_first_detected': :'timeFirstDetected', 'time_last_detected': :'timeLastDetected', 'regions': :'regions', 'additional_details': :'additionalDetails' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/oci/cloud_guard/models/sighting.rb', line 142 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'description': :'String', 'problem_id': :'String', 'compartment_id': :'String', 'actor_principal_id': :'String', 'actor_principal_name': :'String', 'actor_principal_type': :'String', 'classification_status': :'String', 'sighting_type': :'String', 'sighting_type_display_name': :'String', 'tactic_name': :'String', 'technique_name': :'String', 'sighting_score': :'Integer', 'severity': :'String', 'confidence': :'String', 'time_first_detected': :'DateTime', 'time_last_detected': :'DateTime', 'regions': :'Array<String>', 'additional_details': :'Hash<String, String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 |
# File 'lib/oci/cloud_guard/models/sighting.rb', line 340 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && description == other.description && problem_id == other.problem_id && compartment_id == other.compartment_id && actor_principal_id == other.actor_principal_id && actor_principal_name == other.actor_principal_name && actor_principal_type == other.actor_principal_type && classification_status == other.classification_status && sighting_type == other.sighting_type && sighting_type_display_name == other.sighting_type_display_name && tactic_name == other.tactic_name && technique_name == other.technique_name && sighting_score == other.sighting_score && severity == other.severity && confidence == other.confidence && time_first_detected == other.time_first_detected && time_last_detected == other.time_last_detected && regions == other.regions && additional_details == other.additional_details end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 |
# File 'lib/oci/cloud_guard/models/sighting.rb', line 388 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
368 369 370 |
# File 'lib/oci/cloud_guard/models/sighting.rb', line 368 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
377 378 379 |
# File 'lib/oci/cloud_guard/models/sighting.rb', line 377 def hash [id, description, problem_id, compartment_id, actor_principal_id, actor_principal_name, actor_principal_type, classification_status, sighting_type, sighting_type_display_name, tactic_name, technique_name, sighting_score, severity, confidence, time_first_detected, time_last_detected, regions, additional_details].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
421 422 423 424 425 426 427 428 429 430 |
# File 'lib/oci/cloud_guard/models/sighting.rb', line 421 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
415 416 417 |
# File 'lib/oci/cloud_guard/models/sighting.rb', line 415 def to_s to_hash.to_s end |