Class: OCI::CloudGuard::Models::SightingImpactedResourceSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/cloud_guard/models/sighting_impacted_resource_summary.rb

Overview

Sighting Impacted Resource summary.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ SightingImpactedResourceSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :resource_id (String)

    The value to assign to the #resource_id property

  • :sighting_id (String)

    The value to assign to the #sighting_id property

  • :problem_id (String)

    The value to assign to the #problem_id property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :resource_name (String)

    The value to assign to the #resource_name property

  • :resource_type (String)

    The value to assign to the #resource_type property

  • :region (String)

    The value to assign to the #region property

  • :time_identified (DateTime)

    The value to assign to the #time_identified property



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/oci/cloud_guard/models/sighting_impacted_resource_summary.rb', line 95

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.resource_id = attributes[:'resourceId'] if attributes[:'resourceId']

  raise 'You cannot provide both :resourceId and :resource_id' if attributes.key?(:'resourceId') && attributes.key?(:'resource_id')

  self.resource_id = attributes[:'resource_id'] if attributes[:'resource_id']

  self.sighting_id = attributes[:'sightingId'] if attributes[:'sightingId']

  raise 'You cannot provide both :sightingId and :sighting_id' if attributes.key?(:'sightingId') && attributes.key?(:'sighting_id')

  self.sighting_id = attributes[:'sighting_id'] if attributes[:'sighting_id']

  self.problem_id = attributes[:'problemId'] if attributes[:'problemId']

  raise 'You cannot provide both :problemId and :problem_id' if attributes.key?(:'problemId') && attributes.key?(:'problem_id')

  self.problem_id = attributes[:'problem_id'] if attributes[:'problem_id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.resource_name = attributes[:'resourceName'] if attributes[:'resourceName']

  raise 'You cannot provide both :resourceName and :resource_name' if attributes.key?(:'resourceName') && attributes.key?(:'resource_name')

  self.resource_name = attributes[:'resource_name'] if attributes[:'resource_name']

  self.resource_type = attributes[:'resourceType'] if attributes[:'resourceType']

  raise 'You cannot provide both :resourceType and :resource_type' if attributes.key?(:'resourceType') && attributes.key?(:'resource_type')

  self.resource_type = attributes[:'resource_type'] if attributes[:'resource_type']

  self.region = attributes[:'region'] if attributes[:'region']

  self.time_identified = attributes[:'timeIdentified'] if attributes[:'timeIdentified']

  raise 'You cannot provide both :timeIdentified and :time_identified' if attributes.key?(:'timeIdentified') && attributes.key?(:'time_identified')

  self.time_identified = attributes[:'time_identified'] if attributes[:'time_identified']
end

Instance Attribute Details

#compartment_idString

**[Required]** Compartment Id for impacted resource

Returns:

  • (String)


28
29
30
# File 'lib/oci/cloud_guard/models/sighting_impacted_resource_summary.rb', line 28

def compartment_id
  @compartment_id
end

#idString

**[Required]** Unique identifier for impacted resource

Returns:

  • (String)


12
13
14
# File 'lib/oci/cloud_guard/models/sighting_impacted_resource_summary.rb', line 12

def id
  @id
end

#problem_idString

Problem Id for impacted resource

Returns:

  • (String)


24
25
26
# File 'lib/oci/cloud_guard/models/sighting_impacted_resource_summary.rb', line 24

def problem_id
  @problem_id
end

#regionString

**[Required]** Region for impacted resource

Returns:

  • (String)


40
41
42
# File 'lib/oci/cloud_guard/models/sighting_impacted_resource_summary.rb', line 40

def region
  @region
end

#resource_idString

**[Required]** Impacted resource Id

Returns:

  • (String)


16
17
18
# File 'lib/oci/cloud_guard/models/sighting_impacted_resource_summary.rb', line 16

def resource_id
  @resource_id
end

#resource_nameString

**[Required]** Resource name

Returns:

  • (String)


32
33
34
# File 'lib/oci/cloud_guard/models/sighting_impacted_resource_summary.rb', line 32

def resource_name
  @resource_name
end

#resource_typeString

**[Required]** Resource type

Returns:

  • (String)


36
37
38
# File 'lib/oci/cloud_guard/models/sighting_impacted_resource_summary.rb', line 36

def resource_type
  @resource_type
end

#sighting_idString

**[Required]** Sighting Id

Returns:

  • (String)


20
21
22
# File 'lib/oci/cloud_guard/models/sighting_impacted_resource_summary.rb', line 20

def sighting_id
  @sighting_id
end

#time_identifiedDateTime

**[Required]** Time when the impacted resource is identified for given sighting.

Returns:

  • (DateTime)


44
45
46
# File 'lib/oci/cloud_guard/models/sighting_impacted_resource_summary.rb', line 44

def time_identified
  @time_identified
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/oci/cloud_guard/models/sighting_impacted_resource_summary.rb', line 47

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'resource_id': :'resourceId',
    'sighting_id': :'sightingId',
    'problem_id': :'problemId',
    'compartment_id': :'compartmentId',
    'resource_name': :'resourceName',
    'resource_type': :'resourceType',
    'region': :'region',
    'time_identified': :'timeIdentified'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/oci/cloud_guard/models/sighting_impacted_resource_summary.rb', line 64

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'resource_id': :'String',
    'sighting_id': :'String',
    'problem_id': :'String',
    'compartment_id': :'String',
    'resource_name': :'String',
    'resource_type': :'String',
    'region': :'String',
    'time_identified': :'DateTime'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



155
156
157
158
159
160
161
162
163
164
165
166
167
168
# File 'lib/oci/cloud_guard/models/sighting_impacted_resource_summary.rb', line 155

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    resource_id == other.resource_id &&
    sighting_id == other.sighting_id &&
    problem_id == other.problem_id &&
    compartment_id == other.compartment_id &&
    resource_name == other.resource_name &&
    resource_type == other.resource_type &&
    region == other.region &&
    time_identified == other.time_identified
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/oci/cloud_guard/models/sighting_impacted_resource_summary.rb', line 193

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


173
174
175
# File 'lib/oci/cloud_guard/models/sighting_impacted_resource_summary.rb', line 173

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



182
183
184
# File 'lib/oci/cloud_guard/models/sighting_impacted_resource_summary.rb', line 182

def hash
  [id, resource_id, sighting_id, problem_id, compartment_id, resource_name, resource_type, region, time_identified].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



226
227
228
229
230
231
232
233
234
235
# File 'lib/oci/cloud_guard/models/sighting_impacted_resource_summary.rb', line 226

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



220
221
222
# File 'lib/oci/cloud_guard/models/sighting_impacted_resource_summary.rb', line 220

def to_s
  to_hash.to_s
end