Class: OCI::CloudGuard::Models::TargetDetectorDetails
- Inherits:
-
Object
- Object
- OCI::CloudGuard::Models::TargetDetectorDetails
- Defined in:
- lib/oci/cloud_guard/models/target_detector_details.rb
Overview
Overriden settings of a Detector Rule applied on target
Constant Summary collapse
- RISK_LEVEL_ENUM =
[ RISK_LEVEL_CRITICAL = 'CRITICAL'.freeze, RISK_LEVEL_HIGH = 'HIGH'.freeze, RISK_LEVEL_MEDIUM = 'MEDIUM'.freeze, RISK_LEVEL_LOW = 'LOW'.freeze, RISK_LEVEL_MINOR = 'MINOR'.freeze, RISK_LEVEL_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#condition_groups ⇒ Array<OCI::CloudGuard::Models::ConditionGroup>
Condition group corresponding to each compartment.
-
#configurations ⇒ Array<OCI::CloudGuard::Models::DetectorConfiguration>
Configuration details.
-
#is_configuration_allowed ⇒ BOOLEAN
configuration allowed or not.
-
#is_enabled ⇒ BOOLEAN
**[Required]** Enables the control.
-
#labels ⇒ Array<String>
user defined labels for a detector rule.
-
#problem_threshold ⇒ Integer
Cutover point for an elevated resource Risk Score to create a Problem.
-
#risk_level ⇒ String
The Risk Level.
-
#sighting_types ⇒ Array<OCI::CloudGuard::Models::SightingType>
List of sighting types.
-
#target_types ⇒ Array<String>
List of target types for which the detector rule is applicable.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TargetDetectorDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ TargetDetectorDetails
Initializes the object
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/oci/cloud_guard/models/target_detector_details.rb', line 105 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.is_enabled = attributes[:'isEnabled'] unless attributes[:'isEnabled'].nil? raise 'You cannot provide both :isEnabled and :is_enabled' if attributes.key?(:'isEnabled') && attributes.key?(:'is_enabled') self.is_enabled = attributes[:'is_enabled'] unless attributes[:'is_enabled'].nil? self.risk_level = attributes[:'riskLevel'] if attributes[:'riskLevel'] raise 'You cannot provide both :riskLevel and :risk_level' if attributes.key?(:'riskLevel') && attributes.key?(:'risk_level') self.risk_level = attributes[:'risk_level'] if attributes[:'risk_level'] self.configurations = attributes[:'configurations'] if attributes[:'configurations'] self.condition_groups = attributes[:'conditionGroups'] if attributes[:'conditionGroups'] raise 'You cannot provide both :conditionGroups and :condition_groups' if attributes.key?(:'conditionGroups') && attributes.key?(:'condition_groups') self.condition_groups = attributes[:'condition_groups'] if attributes[:'condition_groups'] self.labels = attributes[:'labels'] if attributes[:'labels'] self.is_configuration_allowed = attributes[:'isConfigurationAllowed'] unless attributes[:'isConfigurationAllowed'].nil? raise 'You cannot provide both :isConfigurationAllowed and :is_configuration_allowed' if attributes.key?(:'isConfigurationAllowed') && attributes.key?(:'is_configuration_allowed') self.is_configuration_allowed = attributes[:'is_configuration_allowed'] unless attributes[:'is_configuration_allowed'].nil? self.problem_threshold = attributes[:'problemThreshold'] if attributes[:'problemThreshold'] raise 'You cannot provide both :problemThreshold and :problem_threshold' if attributes.key?(:'problemThreshold') && attributes.key?(:'problem_threshold') self.problem_threshold = attributes[:'problem_threshold'] if attributes[:'problem_threshold'] self.target_types = attributes[:'targetTypes'] if attributes[:'targetTypes'] raise 'You cannot provide both :targetTypes and :target_types' if attributes.key?(:'targetTypes') && attributes.key?(:'target_types') self.target_types = attributes[:'target_types'] if attributes[:'target_types'] self.sighting_types = attributes[:'sightingTypes'] if attributes[:'sightingTypes'] raise 'You cannot provide both :sightingTypes and :sighting_types' if attributes.key?(:'sightingTypes') && attributes.key?(:'sighting_types') self.sighting_types = attributes[:'sighting_types'] if attributes[:'sighting_types'] end |
Instance Attribute Details
#condition_groups ⇒ Array<OCI::CloudGuard::Models::ConditionGroup>
Condition group corresponding to each compartment
34 35 36 |
# File 'lib/oci/cloud_guard/models/target_detector_details.rb', line 34 def condition_groups @condition_groups end |
#configurations ⇒ Array<OCI::CloudGuard::Models::DetectorConfiguration>
Configuration details
30 31 32 |
# File 'lib/oci/cloud_guard/models/target_detector_details.rb', line 30 def configurations @configurations end |
#is_configuration_allowed ⇒ BOOLEAN
configuration allowed or not
42 43 44 |
# File 'lib/oci/cloud_guard/models/target_detector_details.rb', line 42 def is_configuration_allowed @is_configuration_allowed end |
#is_enabled ⇒ BOOLEAN
**[Required]** Enables the control
22 23 24 |
# File 'lib/oci/cloud_guard/models/target_detector_details.rb', line 22 def is_enabled @is_enabled end |
#labels ⇒ Array<String>
user defined labels for a detector rule
38 39 40 |
# File 'lib/oci/cloud_guard/models/target_detector_details.rb', line 38 def labels @labels end |
#problem_threshold ⇒ Integer
Cutover point for an elevated resource Risk Score to create a Problem
46 47 48 |
# File 'lib/oci/cloud_guard/models/target_detector_details.rb', line 46 def problem_threshold @problem_threshold end |
#risk_level ⇒ String
The Risk Level
26 27 28 |
# File 'lib/oci/cloud_guard/models/target_detector_details.rb', line 26 def risk_level @risk_level end |
#sighting_types ⇒ Array<OCI::CloudGuard::Models::SightingType>
List of sighting types
54 55 56 |
# File 'lib/oci/cloud_guard/models/target_detector_details.rb', line 54 def sighting_types @sighting_types end |
#target_types ⇒ Array<String>
List of target types for which the detector rule is applicable
50 51 52 |
# File 'lib/oci/cloud_guard/models/target_detector_details.rb', line 50 def target_types @target_types end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/oci/cloud_guard/models/target_detector_details.rb', line 57 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'is_enabled': :'isEnabled', 'risk_level': :'riskLevel', 'configurations': :'configurations', 'condition_groups': :'conditionGroups', 'labels': :'labels', 'is_configuration_allowed': :'isConfigurationAllowed', 'problem_threshold': :'problemThreshold', 'target_types': :'targetTypes', 'sighting_types': :'sightingTypes' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/oci/cloud_guard/models/target_detector_details.rb', line 74 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'is_enabled': :'BOOLEAN', 'risk_level': :'String', 'configurations': :'Array<OCI::CloudGuard::Models::DetectorConfiguration>', 'condition_groups': :'Array<OCI::CloudGuard::Models::ConditionGroup>', 'labels': :'Array<String>', 'is_configuration_allowed': :'BOOLEAN', 'problem_threshold': :'Integer', 'target_types': :'Array<String>', 'sighting_types': :'Array<OCI::CloudGuard::Models::SightingType>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/oci/cloud_guard/models/target_detector_details.rb', line 178 def ==(other) return true if equal?(other) self.class == other.class && is_enabled == other.is_enabled && risk_level == other.risk_level && configurations == other.configurations && condition_groups == other.condition_groups && labels == other.labels && is_configuration_allowed == other.is_configuration_allowed && problem_threshold == other.problem_threshold && target_types == other.target_types && sighting_types == other.sighting_types end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/oci/cloud_guard/models/target_detector_details.rb', line 216 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
196 197 198 |
# File 'lib/oci/cloud_guard/models/target_detector_details.rb', line 196 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
205 206 207 |
# File 'lib/oci/cloud_guard/models/target_detector_details.rb', line 205 def hash [is_enabled, risk_level, configurations, condition_groups, labels, is_configuration_allowed, problem_threshold, target_types, sighting_types].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
249 250 251 252 253 254 255 256 257 258 |
# File 'lib/oci/cloud_guard/models/target_detector_details.rb', line 249 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
243 244 245 |
# File 'lib/oci/cloud_guard/models/target_detector_details.rb', line 243 def to_s to_hash.to_s end |