Class: OCI::CloudGuard::Models::TargetDetectorRecipe
- Inherits:
-
Object
- Object
- OCI::CloudGuard::Models::TargetDetectorRecipe
- Defined in:
- lib/oci/cloud_guard/models/target_detector_recipe.rb
Overview
Target Detector recipe
Constant Summary collapse
- OWNER_ENUM =
[ OWNER_CUSTOMER = 'CUSTOMER'.freeze, OWNER_ORACLE = 'ORACLE'.freeze, OWNER_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- DETECTOR_ENUM =
[ DETECTOR_IAAS_ACTIVITY_DETECTOR = 'IAAS_ACTIVITY_DETECTOR'.freeze, DETECTOR_IAAS_CONFIGURATION_DETECTOR = 'IAAS_CONFIGURATION_DETECTOR'.freeze, DETECTOR_IAAS_THREAT_DETECTOR = 'IAAS_THREAT_DETECTOR'.freeze, DETECTOR_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** compartmentId of detector recipe.
-
#description ⇒ String
Detector recipe description.
-
#detector ⇒ String
**[Required]** Type of detector.
-
#detector_recipe_id ⇒ String
**[Required]** Unique identifier for Detector Recipe of which this is an extension.
-
#detector_rules ⇒ Array<OCI::CloudGuard::Models::TargetDetectorRecipeDetectorRule>
List of detector rules for the detector type for recipe - user input.
-
#display_name ⇒ String
**[Required]** Display name of detector recipe.
-
#effective_detector_rules ⇒ Array<OCI::CloudGuard::Models::TargetDetectorRecipeDetectorRule>
List of effective detector rules for the detector type for recipe after applying defaults.
-
#id ⇒ String
**[Required]** Ocid for detector recipe.
-
#lifecycle_state ⇒ String
The current state of the resource.
-
#owner ⇒ String
**[Required]** Owner of detector recipe.
-
#source_data_retention ⇒ Integer
The number of days for which source data is retained.
-
#time_created ⇒ DateTime
The date and time the target detector recipe was created.
-
#time_updated ⇒ DateTime
The date and time the target detector recipe was updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TargetDetectorRecipe
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ TargetDetectorRecipe
Initializes the object
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe.rb', line 148 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.detector_recipe_id = attributes[:'detectorRecipeId'] if attributes[:'detectorRecipeId'] raise 'You cannot provide both :detectorRecipeId and :detector_recipe_id' if attributes.key?(:'detectorRecipeId') && attributes.key?(:'detector_recipe_id') self.detector_recipe_id = attributes[:'detector_recipe_id'] if attributes[:'detector_recipe_id'] self.owner = attributes[:'owner'] if attributes[:'owner'] self.detector = attributes[:'detector'] if attributes[:'detector'] self.detector_rules = attributes[:'detectorRules'] if attributes[:'detectorRules'] raise 'You cannot provide both :detectorRules and :detector_rules' if attributes.key?(:'detectorRules') && attributes.key?(:'detector_rules') self.detector_rules = attributes[:'detector_rules'] if attributes[:'detector_rules'] self.effective_detector_rules = attributes[:'effectiveDetectorRules'] if attributes[:'effectiveDetectorRules'] raise 'You cannot provide both :effectiveDetectorRules and :effective_detector_rules' if attributes.key?(:'effectiveDetectorRules') && attributes.key?(:'effective_detector_rules') self.effective_detector_rules = attributes[:'effective_detector_rules'] if attributes[:'effective_detector_rules'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.source_data_retention = attributes[:'sourceDataRetention'] if attributes[:'sourceDataRetention'] raise 'You cannot provide both :sourceDataRetention and :source_data_retention' if attributes.key?(:'sourceDataRetention') && attributes.key?(:'source_data_retention') self.source_data_retention = attributes[:'source_data_retention'] if attributes[:'source_data_retention'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** compartmentId of detector recipe
49 50 51 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe.rb', line 49 def compartment_id @compartment_id end |
#description ⇒ String
Detector recipe description.
45 46 47 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe.rb', line 45 def description @description end |
#detector ⇒ String
**[Required]** Type of detector
61 62 63 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe.rb', line 61 def detector @detector end |
#detector_recipe_id ⇒ String
**[Required]** Unique identifier for Detector Recipe of which this is an extension
53 54 55 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe.rb', line 53 def detector_recipe_id @detector_recipe_id end |
#detector_rules ⇒ Array<OCI::CloudGuard::Models::TargetDetectorRecipeDetectorRule>
List of detector rules for the detector type for recipe - user input
65 66 67 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe.rb', line 65 def detector_rules @detector_rules end |
#display_name ⇒ String
**[Required]** Display name of detector recipe.
41 42 43 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe.rb', line 41 def display_name @display_name end |
#effective_detector_rules ⇒ Array<OCI::CloudGuard::Models::TargetDetectorRecipeDetectorRule>
List of effective detector rules for the detector type for recipe after applying defaults
69 70 71 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe.rb', line 69 def effective_detector_rules @effective_detector_rules end |
#id ⇒ String
**[Required]** Ocid for detector recipe
37 38 39 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe.rb', line 37 def id @id end |
#lifecycle_state ⇒ String
The current state of the resource.
81 82 83 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe.rb', line 81 def lifecycle_state @lifecycle_state end |
#owner ⇒ String
**[Required]** Owner of detector recipe
57 58 59 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe.rb', line 57 def owner @owner end |
#source_data_retention ⇒ Integer
The number of days for which source data is retained
85 86 87 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe.rb', line 85 def source_data_retention @source_data_retention end |
#time_created ⇒ DateTime
The date and time the target detector recipe was created. Format defined by RFC3339.
73 74 75 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe.rb', line 73 def time_created @time_created end |
#time_updated ⇒ DateTime
The date and time the target detector recipe was updated. Format defined by RFC3339.
77 78 79 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe.rb', line 77 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe.rb', line 88 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'description': :'description', 'compartment_id': :'compartmentId', 'detector_recipe_id': :'detectorRecipeId', 'owner': :'owner', 'detector': :'detector', 'detector_rules': :'detectorRules', 'effective_detector_rules': :'effectiveDetectorRules', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'source_data_retention': :'sourceDataRetention' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe.rb', line 109 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'description': :'String', 'compartment_id': :'String', 'detector_recipe_id': :'String', 'owner': :'String', 'detector': :'String', 'detector_rules': :'Array<OCI::CloudGuard::Models::TargetDetectorRecipeDetectorRule>', 'effective_detector_rules': :'Array<OCI::CloudGuard::Models::TargetDetectorRecipeDetectorRule>', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'source_data_retention': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe.rb', line 263 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && description == other.description && compartment_id == other.compartment_id && detector_recipe_id == other.detector_recipe_id && owner == other.owner && detector == other.detector && detector_rules == other.detector_rules && effective_detector_rules == other.effective_detector_rules && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && source_data_retention == other.source_data_retention end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe.rb', line 305 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
285 286 287 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe.rb', line 285 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
294 295 296 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe.rb', line 294 def hash [id, display_name, description, compartment_id, detector_recipe_id, owner, detector, detector_rules, effective_detector_rules, time_created, time_updated, lifecycle_state, source_data_retention].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
338 339 340 341 342 343 344 345 346 347 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe.rb', line 338 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
332 333 334 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe.rb', line 332 def to_s to_hash.to_s end |