Class: OCI::CloudGuard::Models::TargetDetectorRecipeDetectorRule
- Inherits:
-
Object
- Object
- OCI::CloudGuard::Models::TargetDetectorRecipeDetectorRule
- Defined in:
- lib/oci/cloud_guard/models/target_detector_recipe_detector_rule.rb
Overview
Detector Recipe Rule
Constant Summary collapse
- DETECTOR_ENUM =
[ DETECTOR_IAAS_ACTIVITY_DETECTOR = 'IAAS_ACTIVITY_DETECTOR'.freeze, DETECTOR_IAAS_CONFIGURATION_DETECTOR = 'IAAS_CONFIGURATION_DETECTOR'.freeze, DETECTOR_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- MANAGED_LIST_TYPES_ENUM =
[ MANAGED_LIST_TYPES_CIDR_BLOCK = 'CIDR_BLOCK'.freeze, MANAGED_LIST_TYPES_USERS = 'USERS'.freeze, MANAGED_LIST_TYPES_GROUPS = 'GROUPS'.freeze, MANAGED_LIST_TYPES_IPV4_ADDRESS = 'IPV4ADDRESS'.freeze, MANAGED_LIST_TYPES_IPV6_ADDRESS = 'IPV6ADDRESS'.freeze, MANAGED_LIST_TYPES_RESOURCE_OCID = 'RESOURCE_OCID'.freeze, MANAGED_LIST_TYPES_REGION = 'REGION'.freeze, MANAGED_LIST_TYPES_COUNTRY = 'COUNTRY'.freeze, MANAGED_LIST_TYPES_STATE = 'STATE'.freeze, MANAGED_LIST_TYPES_CITY = 'CITY'.freeze, MANAGED_LIST_TYPES_TAGS = 'TAGS'.freeze, MANAGED_LIST_TYPES_GENERIC = 'GENERIC'.freeze, MANAGED_LIST_TYPES_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#description ⇒ String
Description for TargetDetectorRecipeDetectorRule.
- #details ⇒ OCI::CloudGuard::Models::TargetDetectorDetails
-
#detector ⇒ String
[Required] detector for the rule.
-
#detector_rule_id ⇒ String
[Required] The unique identifier of the detector rule.
-
#display_name ⇒ String
displayName.
-
#lifecycle_details ⇒ String
A message describing the current state in more detail.
-
#lifecycle_state ⇒ String
The current state of the DetectorRule.
-
#managed_list_types ⇒ Array<String>
List of cloudguard managed list types related to this rule.
-
#recommendation ⇒ String
Recommendation for TargetDetectorRecipeDetectorRule.
-
#resource_type ⇒ String
[Required] resource type of the configuration to which the rule is applied.
-
#service_type ⇒ String
[Required] service type of the configuration to which the rule is applied.
-
#time_created ⇒ DateTime
The date and time the target detector recipe rule was created.
-
#time_updated ⇒ DateTime
The date and time the target detector recipe rule was updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TargetDetectorRecipeDetectorRule
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ TargetDetectorRecipeDetectorRule
Initializes the object
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe_detector_rule.rb', line 156 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.detector_rule_id = attributes[:'detectorRuleId'] if attributes[:'detectorRuleId'] raise 'You cannot provide both :detectorRuleId and :detector_rule_id' if attributes.key?(:'detectorRuleId') && attributes.key?(:'detector_rule_id') self.detector_rule_id = attributes[:'detector_rule_id'] if attributes[:'detector_rule_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.recommendation = attributes[:'recommendation'] if attributes[:'recommendation'] self.detector = attributes[:'detector'] if attributes[:'detector'] self.service_type = attributes[:'serviceType'] if attributes[:'serviceType'] raise 'You cannot provide both :serviceType and :service_type' if attributes.key?(:'serviceType') && attributes.key?(:'service_type') self.service_type = attributes[:'service_type'] if attributes[:'service_type'] self.resource_type = attributes[:'resourceType'] if attributes[:'resourceType'] raise 'You cannot provide both :resourceType and :resource_type' if attributes.key?(:'resourceType') && attributes.key?(:'resource_type') self.resource_type = attributes[:'resource_type'] if attributes[:'resource_type'] self.details = attributes[:'details'] if attributes[:'details'] self.managed_list_types = attributes[:'managedListTypes'] if attributes[:'managedListTypes'] raise 'You cannot provide both :managedListTypes and :managed_list_types' if attributes.key?(:'managedListTypes') && attributes.key?(:'managed_list_types') self.managed_list_types = attributes[:'managed_list_types'] if attributes[:'managed_list_types'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] end |
Instance Attribute Details
#description ⇒ String
Description for TargetDetectorRecipeDetectorRule
54 55 56 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe_detector_rule.rb', line 54 def description @description end |
#details ⇒ OCI::CloudGuard::Models::TargetDetectorDetails
73 74 75 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe_detector_rule.rb', line 73 def details @details end |
#detector ⇒ String
[Required] detector for the rule
62 63 64 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe_detector_rule.rb', line 62 def detector @detector end |
#detector_rule_id ⇒ String
[Required] The unique identifier of the detector rule
46 47 48 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe_detector_rule.rb', line 46 def detector_rule_id @detector_rule_id end |
#display_name ⇒ String
displayName
50 51 52 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe_detector_rule.rb', line 50 def display_name @display_name end |
#lifecycle_details ⇒ String
A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
93 94 95 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe_detector_rule.rb', line 93 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
The current state of the DetectorRule.
89 90 91 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe_detector_rule.rb', line 89 def lifecycle_state @lifecycle_state end |
#managed_list_types ⇒ Array<String>
List of cloudguard managed list types related to this rule
77 78 79 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe_detector_rule.rb', line 77 def managed_list_types @managed_list_types end |
#recommendation ⇒ String
Recommendation for TargetDetectorRecipeDetectorRule
58 59 60 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe_detector_rule.rb', line 58 def recommendation @recommendation end |
#resource_type ⇒ String
[Required] resource type of the configuration to which the rule is applied
70 71 72 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe_detector_rule.rb', line 70 def resource_type @resource_type end |
#service_type ⇒ String
[Required] service type of the configuration to which the rule is applied
66 67 68 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe_detector_rule.rb', line 66 def service_type @service_type end |
#time_created ⇒ DateTime
The date and time the target detector recipe rule was created. Format defined by RFC3339.
81 82 83 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe_detector_rule.rb', line 81 def time_created @time_created end |
#time_updated ⇒ DateTime
The date and time the target detector recipe rule was updated. Format defined by RFC3339.
85 86 87 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe_detector_rule.rb', line 85 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe_detector_rule.rb', line 96 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'detector_rule_id': :'detectorRuleId', 'display_name': :'displayName', 'description': :'description', 'recommendation': :'recommendation', 'detector': :'detector', 'service_type': :'serviceType', 'resource_type': :'resourceType', 'details': :'details', 'managed_list_types': :'managedListTypes', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe_detector_rule.rb', line 117 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'detector_rule_id': :'String', 'display_name': :'String', 'description': :'String', 'recommendation': :'String', 'detector': :'String', 'service_type': :'String', 'resource_type': :'String', 'details': :'OCI::CloudGuard::Models::TargetDetectorDetails', 'managed_list_types': :'Array<String>', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_details': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe_detector_rule.rb', line 278 def ==(other) return true if equal?(other) self.class == other.class && detector_rule_id == other.detector_rule_id && display_name == other.display_name && description == other.description && recommendation == other.recommendation && detector == other.detector && service_type == other.service_type && resource_type == other.resource_type && details == other.details && managed_list_types == other.managed_list_types && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe_detector_rule.rb', line 320 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
300 301 302 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe_detector_rule.rb', line 300 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
309 310 311 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe_detector_rule.rb', line 309 def hash [detector_rule_id, display_name, description, recommendation, detector, service_type, resource_type, details, managed_list_types, time_created, time_updated, lifecycle_state, lifecycle_details].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
353 354 355 356 357 358 359 360 361 362 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe_detector_rule.rb', line 353 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
347 348 349 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe_detector_rule.rb', line 347 def to_s to_hash.to_s end |