Class: OCI::CloudGuard::Models::TargetResourceTypesSelected
- Inherits:
-
TargetSelected
- Object
- TargetSelected
- OCI::CloudGuard::Models::TargetResourceTypesSelected
- Defined in:
- lib/oci/cloud_guard/models/target_resource_types_selected.rb
Overview
Target selection on basis of TargetResourceTypes.
Constant Summary collapse
- VALUES_ENUM =
[ VALUES_COMPARTMENT = 'COMPARTMENT'.freeze, VALUES_ERPCLOUD = 'ERPCLOUD'.freeze, VALUES_HCMCLOUD = 'HCMCLOUD'.freeze, VALUES_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Constants inherited from TargetSelected
OCI::CloudGuard::Models::TargetSelected::KIND_ENUM
Instance Attribute Summary collapse
-
#values ⇒ Array<String>
Types of Targets.
Attributes inherited from TargetSelected
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TargetResourceTypesSelected
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from TargetSelected
Constructor Details
#initialize(attributes = {}) ⇒ TargetResourceTypesSelected
Initializes the object
50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/oci/cloud_guard/models/target_resource_types_selected.rb', line 50 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['kind'] = 'TARGETTYPES' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.values = attributes[:'values'] if attributes[:'values'] end |
Instance Attribute Details
#values ⇒ Array<String>
Types of Targets
21 22 23 |
# File 'lib/oci/cloud_guard/models/target_resource_types_selected.rb', line 21 def values @values end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
24 25 26 27 28 29 30 31 |
# File 'lib/oci/cloud_guard/models/target_resource_types_selected.rb', line 24 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'kind': :'kind', 'values': :'values' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
34 35 36 37 38 39 40 41 |
# File 'lib/oci/cloud_guard/models/target_resource_types_selected.rb', line 34 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'kind': :'String', 'values': :'Array<String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
90 91 92 93 94 95 96 |
# File 'lib/oci/cloud_guard/models/target_resource_types_selected.rb', line 90 def ==(other) return true if equal?(other) self.class == other.class && kind == other.kind && values == other.values end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/oci/cloud_guard/models/target_resource_types_selected.rb', line 121 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
101 102 103 |
# File 'lib/oci/cloud_guard/models/target_resource_types_selected.rb', line 101 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
110 111 112 |
# File 'lib/oci/cloud_guard/models/target_resource_types_selected.rb', line 110 def hash [kind, values].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
154 155 156 157 158 159 160 161 162 163 |
# File 'lib/oci/cloud_guard/models/target_resource_types_selected.rb', line 154 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
148 149 150 |
# File 'lib/oci/cloud_guard/models/target_resource_types_selected.rb', line 148 def to_s to_hash.to_s end |