Class: OCI::CloudGuard::Models::TargetResponderRecipe

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/cloud_guard/models/target_responder_recipe.rb

Overview

Details of Target ResponderRecipe

Constant Summary collapse

OWNER_ENUM =
[
  OWNER_CUSTOMER = 'CUSTOMER'.freeze,
  OWNER_ORACLE = 'ORACLE'.freeze,
  OWNER_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ TargetResponderRecipe

Initializes the object

Options Hash (attributes):



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/oci/cloud_guard/models/target_responder_recipe.rb', line 109

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.responder_recipe_id = attributes[:'responderRecipeId'] if attributes[:'responderRecipeId']

  raise 'You cannot provide both :responderRecipeId and :responder_recipe_id' if attributes.key?(:'responderRecipeId') && attributes.key?(:'responder_recipe_id')

  self.responder_recipe_id = attributes[:'responder_recipe_id'] if attributes[:'responder_recipe_id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.owner = attributes[:'owner'] if attributes[:'owner']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.responder_rules = attributes[:'responderRules'] if attributes[:'responderRules']

  raise 'You cannot provide both :responderRules and :responder_rules' if attributes.key?(:'responderRules') && attributes.key?(:'responder_rules')

  self.responder_rules = attributes[:'responder_rules'] if attributes[:'responder_rules']

  self.effective_responder_rules = attributes[:'effectiveResponderRules'] if attributes[:'effectiveResponderRules']

  raise 'You cannot provide both :effectiveResponderRules and :effective_responder_rules' if attributes.key?(:'effectiveResponderRules') && attributes.key?(:'effective_responder_rules')

  self.effective_responder_rules = attributes[:'effective_responder_rules'] if attributes[:'effective_responder_rules']
end

Instance Attribute Details

#compartment_idString

[Required] Compartment Identifier



27
28
29
# File 'lib/oci/cloud_guard/models/target_responder_recipe.rb', line 27

def compartment_id
  @compartment_id
end

#descriptionString

[Required] ResponderRecipe Description



35
36
37
# File 'lib/oci/cloud_guard/models/target_responder_recipe.rb', line 35

def description
  @description
end

#display_nameString

[Required] ResponderRecipe Identifier Name



31
32
33
# File 'lib/oci/cloud_guard/models/target_responder_recipe.rb', line 31

def display_name
  @display_name
end

#effective_responder_rulesArray<OCI::CloudGuard::Models::TargetResponderRecipeResponderRule>

List of responder rules associated with the recipe after applying all defaults



55
56
57
# File 'lib/oci/cloud_guard/models/target_responder_recipe.rb', line 55

def effective_responder_rules
  @effective_responder_rules
end

#idString

[Required] Unique identifier of TargetResponderRecipe that is immutable on creation



19
20
21
# File 'lib/oci/cloud_guard/models/target_responder_recipe.rb', line 19

def id
  @id
end

#ownerString

[Required] Owner of ResponderRecipe



39
40
41
# File 'lib/oci/cloud_guard/models/target_responder_recipe.rb', line 39

def owner
  @owner
end

#responder_recipe_idString

[Required] Unique identifier for Responder Recipe of which this is an extension



23
24
25
# File 'lib/oci/cloud_guard/models/target_responder_recipe.rb', line 23

def responder_recipe_id
  @responder_recipe_id
end

#responder_rulesArray<OCI::CloudGuard::Models::TargetResponderRecipeResponderRule>

List of responder rules associated with the recipe - user input



51
52
53
# File 'lib/oci/cloud_guard/models/target_responder_recipe.rb', line 51

def responder_rules
  @responder_rules
end

#time_createdDateTime

The date and time the target responder recipe rule was created. Format defined by RFC3339.



43
44
45
# File 'lib/oci/cloud_guard/models/target_responder_recipe.rb', line 43

def time_created
  @time_created
end

#time_updatedDateTime

The date and time the target responder recipe rule was updated. Format defined by RFC3339.



47
48
49
# File 'lib/oci/cloud_guard/models/target_responder_recipe.rb', line 47

def time_updated
  @time_updated
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/oci/cloud_guard/models/target_responder_recipe.rb', line 58

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'responder_recipe_id': :'responderRecipeId',
    'compartment_id': :'compartmentId',
    'display_name': :'displayName',
    'description': :'description',
    'owner': :'owner',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'responder_rules': :'responderRules',
    'effective_responder_rules': :'effectiveResponderRules'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/oci/cloud_guard/models/target_responder_recipe.rb', line 76

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'responder_recipe_id': :'String',
    'compartment_id': :'String',
    'display_name': :'String',
    'description': :'String',
    'owner': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'responder_rules': :'Array<OCI::CloudGuard::Models::TargetResponderRecipeResponderRule>',
    'effective_responder_rules': :'Array<OCI::CloudGuard::Models::TargetResponderRecipeResponderRule>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.



184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/oci/cloud_guard/models/target_responder_recipe.rb', line 184

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    responder_recipe_id == other.responder_recipe_id &&
    compartment_id == other.compartment_id &&
    display_name == other.display_name &&
    description == other.description &&
    owner == other.owner &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    responder_rules == other.responder_rules &&
    effective_responder_rules == other.effective_responder_rules
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/oci/cloud_guard/models/target_responder_recipe.rb', line 223

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method


203
204
205
# File 'lib/oci/cloud_guard/models/target_responder_recipe.rb', line 203

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.



212
213
214
# File 'lib/oci/cloud_guard/models/target_responder_recipe.rb', line 212

def hash
  [id, responder_recipe_id, compartment_id, display_name, description, owner, time_created, time_updated, responder_rules, effective_responder_rules].hash
end

#to_hashHash

Returns the object in the form of hash



256
257
258
259
260
261
262
263
264
265
# File 'lib/oci/cloud_guard/models/target_responder_recipe.rb', line 256

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



250
251
252
# File 'lib/oci/cloud_guard/models/target_responder_recipe.rb', line 250

def to_s
  to_hash.to_s
end