Class: OCI::CloudGuard::Models::TargetResponderRecipeSummary
- Inherits:
-
Object
- Object
- OCI::CloudGuard::Models::TargetResponderRecipeSummary
- Defined in:
- lib/oci/cloud_guard/models/target_responder_recipe_summary.rb
Overview
Summary of ResponderRecipe
Constant Summary collapse
- OWNER_ENUM =
[ OWNER_CUSTOMER = 'CUSTOMER'.freeze, OWNER_ORACLE = 'ORACLE'.freeze, OWNER_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** Compartment Identifier.
-
#description ⇒ String
**[Required]** ResponderRecipe Description.
-
#display_name ⇒ String
**[Required]** ResponderRecipe Identifier Name.
-
#id ⇒ String
**[Required]** Unique identifier that is immutable on creation.
-
#lifecycle_details ⇒ String
A message describing the current state in more detail.
-
#lifecycle_state ⇒ String
The current state of the Example.
-
#owner ⇒ String
**[Required]** Owner of ResponderRecipe.
-
#responder_recipe_id ⇒ String
**[Required]** Unique identifier for Responder Recipe of which this is an extension.
-
#time_created ⇒ DateTime
The date and time the target responder recipe was created.
-
#time_updated ⇒ DateTime
The date and time the target responder recipe was updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TargetResponderRecipeSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ TargetResponderRecipeSummary
Initializes the object
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/oci/cloud_guard/models/target_responder_recipe_summary.rb', line 120 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.responder_recipe_id = attributes[:'responderRecipeId'] if attributes[:'responderRecipeId'] raise 'You cannot provide both :responderRecipeId and :responder_recipe_id' if attributes.key?(:'responderRecipeId') && attributes.key?(:'responder_recipe_id') self.responder_recipe_id = attributes[:'responder_recipe_id'] if attributes[:'responder_recipe_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.owner = attributes[:'owner'] if attributes[:'owner'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** Compartment Identifier
34 35 36 |
# File 'lib/oci/cloud_guard/models/target_responder_recipe_summary.rb', line 34 def compartment_id @compartment_id end |
#description ⇒ String
**[Required]** ResponderRecipe Description
46 47 48 |
# File 'lib/oci/cloud_guard/models/target_responder_recipe_summary.rb', line 46 def description @description end |
#display_name ⇒ String
**[Required]** ResponderRecipe Identifier Name
42 43 44 |
# File 'lib/oci/cloud_guard/models/target_responder_recipe_summary.rb', line 42 def display_name @display_name end |
#id ⇒ String
**[Required]** Unique identifier that is immutable on creation
30 31 32 |
# File 'lib/oci/cloud_guard/models/target_responder_recipe_summary.rb', line 30 def id @id end |
#lifecycle_details ⇒ String
A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
66 67 68 |
# File 'lib/oci/cloud_guard/models/target_responder_recipe_summary.rb', line 66 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
The current state of the Example.
62 63 64 |
# File 'lib/oci/cloud_guard/models/target_responder_recipe_summary.rb', line 62 def lifecycle_state @lifecycle_state end |
#owner ⇒ String
**[Required]** Owner of ResponderRecipe
50 51 52 |
# File 'lib/oci/cloud_guard/models/target_responder_recipe_summary.rb', line 50 def owner @owner end |
#responder_recipe_id ⇒ String
**[Required]** Unique identifier for Responder Recipe of which this is an extension
38 39 40 |
# File 'lib/oci/cloud_guard/models/target_responder_recipe_summary.rb', line 38 def responder_recipe_id @responder_recipe_id end |
#time_created ⇒ DateTime
The date and time the target responder recipe was created. Format defined by RFC3339.
54 55 56 |
# File 'lib/oci/cloud_guard/models/target_responder_recipe_summary.rb', line 54 def time_created @time_created end |
#time_updated ⇒ DateTime
The date and time the target responder recipe was updated. Format defined by RFC3339.
58 59 60 |
# File 'lib/oci/cloud_guard/models/target_responder_recipe_summary.rb', line 58 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/oci/cloud_guard/models/target_responder_recipe_summary.rb', line 69 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'responder_recipe_id': :'responderRecipeId', 'display_name': :'displayName', 'description': :'description', 'owner': :'owner', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/oci/cloud_guard/models/target_responder_recipe_summary.rb', line 87 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'responder_recipe_id': :'String', 'display_name': :'String', 'description': :'String', 'owner': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_details': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/oci/cloud_guard/models/target_responder_recipe_summary.rb', line 208 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && responder_recipe_id == other.responder_recipe_id && display_name == other.display_name && description == other.description && owner == other.owner && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/oci/cloud_guard/models/target_responder_recipe_summary.rb', line 247 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
227 228 229 |
# File 'lib/oci/cloud_guard/models/target_responder_recipe_summary.rb', line 227 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
236 237 238 |
# File 'lib/oci/cloud_guard/models/target_responder_recipe_summary.rb', line 236 def hash [id, compartment_id, responder_recipe_id, display_name, description, owner, time_created, time_updated, lifecycle_state, lifecycle_details].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
280 281 282 283 284 285 286 287 288 289 |
# File 'lib/oci/cloud_guard/models/target_responder_recipe_summary.rb', line 280 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
274 275 276 |
# File 'lib/oci/cloud_guard/models/target_responder_recipe_summary.rb', line 274 def to_s to_hash.to_s end |