Class: OCI::CloudGuard::Models::TargetSummary
- Inherits:
-
Object
- Object
- OCI::CloudGuard::Models::TargetSummary
- Defined in:
- lib/oci/cloud_guard/models/target_summary.rb
Overview
Summary of the Target.
Constant Summary collapse
- TARGET_RESOURCE_TYPE_ENUM =
[ TARGET_RESOURCE_TYPE_COMPARTMENT = 'COMPARTMENT'.freeze, TARGET_RESOURCE_TYPE_ERPCLOUD = 'ERPCLOUD'.freeze, TARGET_RESOURCE_TYPE_HCMCLOUD = 'HCMCLOUD'.freeze, TARGET_RESOURCE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] Compartment Identifier where the resource is created.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
DetectorTemplate Identifier, can be renamed.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
[Required] Unique identifier that is immutable on creation.
-
#lifecycle_state ⇒ String
The current state of the resource.
-
#lifecyle_details ⇒ String
A message describing the current state in more detail.
-
#recipe_count ⇒ Integer
[Required] Total number of recipes attached to target.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
System tags for this resource.
-
#target_resource_id ⇒ String
[Required] Resource ID which the target uses to monitor.
-
#target_resource_type ⇒ String
[Required] possible type of targets(compartment/HCMCloud/ERPCloud).
-
#time_created ⇒ DateTime
The date and time the target was created.
-
#time_updated ⇒ DateTime
The date and time the target was updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TargetSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ TargetSummary
Initializes the object
151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/oci/cloud_guard/models/target_summary.rb', line 151 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.target_resource_type = attributes[:'targetResourceType'] if attributes[:'targetResourceType'] raise 'You cannot provide both :targetResourceType and :target_resource_type' if attributes.key?(:'targetResourceType') && attributes.key?(:'target_resource_type') self.target_resource_type = attributes[:'target_resource_type'] if attributes[:'target_resource_type'] self.target_resource_id = attributes[:'targetResourceId'] if attributes[:'targetResourceId'] raise 'You cannot provide both :targetResourceId and :target_resource_id' if attributes.key?(:'targetResourceId') && attributes.key?(:'target_resource_id') self.target_resource_id = attributes[:'target_resource_id'] if attributes[:'target_resource_id'] self.recipe_count = attributes[:'recipeCount'] if attributes[:'recipeCount'] raise 'You cannot provide both :recipeCount and :recipe_count' if attributes.key?(:'recipeCount') && attributes.key?(:'recipe_count') self.recipe_count = attributes[:'recipe_count'] if attributes[:'recipe_count'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecyle_details = attributes[:'lifecyleDetails'] if attributes[:'lifecyleDetails'] raise 'You cannot provide both :lifecyleDetails and :lifecyle_details' if attributes.key?(:'lifecyleDetails') && attributes.key?(:'lifecyle_details') self.lifecyle_details = attributes[:'lifecyle_details'] if attributes[:'lifecyle_details'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] Compartment Identifier where the resource is created
39 40 41 |
# File 'lib/oci/cloud_guard/models/target_summary.rb', line 39 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
79 80 81 |
# File 'lib/oci/cloud_guard/models/target_summary.rb', line 79 def end |
#display_name ⇒ String
DetectorTemplate Identifier, can be renamed
35 36 37 |
# File 'lib/oci/cloud_guard/models/target_summary.rb', line 35 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`
73 74 75 |
# File 'lib/oci/cloud_guard/models/target_summary.rb', line 73 def end |
#id ⇒ String
[Required] Unique identifier that is immutable on creation
31 32 33 |
# File 'lib/oci/cloud_guard/models/target_summary.rb', line 31 def id @id end |
#lifecycle_state ⇒ String
The current state of the resource.
63 64 65 |
# File 'lib/oci/cloud_guard/models/target_summary.rb', line 63 def lifecycle_state @lifecycle_state end |
#lifecyle_details ⇒ String
A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
67 68 69 |
# File 'lib/oci/cloud_guard/models/target_summary.rb', line 67 def lifecyle_details @lifecyle_details end |
#recipe_count ⇒ Integer
[Required] Total number of recipes attached to target
51 52 53 |
# File 'lib/oci/cloud_guard/models/target_summary.rb', line 51 def recipe_count @recipe_count end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
System tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). System tags can be viewed by users, but can only be created by the system.
Example: ‘{"free-tier-retained": "true"}`
88 89 90 |
# File 'lib/oci/cloud_guard/models/target_summary.rb', line 88 def end |
#target_resource_id ⇒ String
[Required] Resource ID which the target uses to monitor
47 48 49 |
# File 'lib/oci/cloud_guard/models/target_summary.rb', line 47 def target_resource_id @target_resource_id end |
#target_resource_type ⇒ String
[Required] possible type of targets(compartment/HCMCloud/ERPCloud)
43 44 45 |
# File 'lib/oci/cloud_guard/models/target_summary.rb', line 43 def target_resource_type @target_resource_type end |
#time_created ⇒ DateTime
The date and time the target was created. Format defined by RFC3339.
55 56 57 |
# File 'lib/oci/cloud_guard/models/target_summary.rb', line 55 def time_created @time_created end |
#time_updated ⇒ DateTime
The date and time the target was updated. Format defined by RFC3339.
59 60 61 |
# File 'lib/oci/cloud_guard/models/target_summary.rb', line 59 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/oci/cloud_guard/models/target_summary.rb', line 91 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'target_resource_type': :'targetResourceType', 'target_resource_id': :'targetResourceId', 'recipe_count': :'recipeCount', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'lifecyle_details': :'lifecyleDetails', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/oci/cloud_guard/models/target_summary.rb', line 112 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'compartment_id': :'String', 'target_resource_type': :'String', 'target_resource_id': :'String', 'recipe_count': :'Integer', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'lifecyle_details': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/oci/cloud_guard/models/target_summary.rb', line 265 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && compartment_id == other.compartment_id && target_resource_type == other.target_resource_type && target_resource_id == other.target_resource_id && recipe_count == other.recipe_count && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && lifecyle_details == other.lifecyle_details && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 |
# File 'lib/oci/cloud_guard/models/target_summary.rb', line 307 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
287 288 289 |
# File 'lib/oci/cloud_guard/models/target_summary.rb', line 287 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
296 297 298 |
# File 'lib/oci/cloud_guard/models/target_summary.rb', line 296 def hash [id, display_name, compartment_id, target_resource_type, target_resource_id, recipe_count, time_created, time_updated, lifecycle_state, lifecyle_details, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
340 341 342 343 344 345 346 347 348 349 |
# File 'lib/oci/cloud_guard/models/target_summary.rb', line 340 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
334 335 336 |
# File 'lib/oci/cloud_guard/models/target_summary.rb', line 334 def to_s to_hash.to_s end |