Class: OCI::CloudGuard::Models::UpdateDataMaskRuleDetails
- Inherits:
-
Object
- Object
- OCI::CloudGuard::Models::UpdateDataMaskRuleDetails
- Defined in:
- lib/oci/cloud_guard/models/update_data_mask_rule_details.rb
Overview
The information to be updated.
Constant Summary collapse
- DATA_MASK_CATEGORIES_ENUM =
[ DATA_MASK_CATEGORIES_ACTOR = 'ACTOR'.freeze, DATA_MASK_CATEGORIES_PII = 'PII'.freeze, DATA_MASK_CATEGORIES_PHI = 'PHI'.freeze, DATA_MASK_CATEGORIES_FINANCIAL = 'FINANCIAL'.freeze, DATA_MASK_CATEGORIES_LOCATION = 'LOCATION'.freeze, DATA_MASK_CATEGORIES_CUSTOM = 'CUSTOM'.freeze ].freeze
- DATA_MASK_RULE_STATUS_ENUM =
[ DATA_MASK_RULE_STATUS_ENABLED = 'ENABLED'.freeze, DATA_MASK_RULE_STATUS_DISABLED = 'DISABLED'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
Compartment Identifier where the resource is created.
-
#data_mask_categories ⇒ Array<String>
Data Mask Categories.
-
#data_mask_rule_status ⇒ String
The status of the dataMaskRule.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
Data Mask Rule Name.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#iam_group_id ⇒ String
IAM Group id associated with the data mask rule.
- #target_selected ⇒ OCI::CloudGuard::Models::TargetSelected
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateDataMaskRuleDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateDataMaskRuleDetails
Initializes the object
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/oci/cloud_guard/models/update_data_mask_rule_details.rb', line 105 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.iam_group_id = attributes[:'iamGroupId'] if attributes[:'iamGroupId'] raise 'You cannot provide both :iamGroupId and :iam_group_id' if attributes.key?(:'iamGroupId') && attributes.key?(:'iam_group_id') self.iam_group_id = attributes[:'iam_group_id'] if attributes[:'iam_group_id'] self.target_selected = attributes[:'targetSelected'] if attributes[:'targetSelected'] raise 'You cannot provide both :targetSelected and :target_selected' if attributes.key?(:'targetSelected') && attributes.key?(:'target_selected') self.target_selected = attributes[:'target_selected'] if attributes[:'target_selected'] self.data_mask_categories = attributes[:'dataMaskCategories'] if attributes[:'dataMaskCategories'] raise 'You cannot provide both :dataMaskCategories and :data_mask_categories' if attributes.key?(:'dataMaskCategories') && attributes.key?(:'data_mask_categories') self.data_mask_categories = attributes[:'data_mask_categories'] if attributes[:'data_mask_categories'] self.data_mask_rule_status = attributes[:'dataMaskRuleStatus'] if attributes[:'dataMaskRuleStatus'] raise 'You cannot provide both :dataMaskRuleStatus and :data_mask_rule_status' if attributes.key?(:'dataMaskRuleStatus') && attributes.key?(:'data_mask_rule_status') self.data_mask_rule_status = attributes[:'data_mask_rule_status'] if attributes[:'data_mask_rule_status'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
Compartment Identifier where the resource is created
30 31 32 |
# File 'lib/oci/cloud_guard/models/update_data_mask_rule_details.rb', line 30 def compartment_id @compartment_id end |
#data_mask_categories ⇒ Array<String>
Data Mask Categories
41 42 43 |
# File 'lib/oci/cloud_guard/models/update_data_mask_rule_details.rb', line 41 def data_mask_categories @data_mask_categories end |
#data_mask_rule_status ⇒ String
The status of the dataMaskRule.
45 46 47 |
# File 'lib/oci/cloud_guard/models/update_data_mask_rule_details.rb', line 45 def data_mask_rule_status @data_mask_rule_status end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
57 58 59 |
# File 'lib/oci/cloud_guard/models/update_data_mask_rule_details.rb', line 57 def @defined_tags end |
#display_name ⇒ String
Data Mask Rule Name
26 27 28 |
# File 'lib/oci/cloud_guard/models/update_data_mask_rule_details.rb', line 26 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`
51 52 53 |
# File 'lib/oci/cloud_guard/models/update_data_mask_rule_details.rb', line 51 def @freeform_tags end |
#iam_group_id ⇒ String
IAM Group id associated with the data mask rule
34 35 36 |
# File 'lib/oci/cloud_guard/models/update_data_mask_rule_details.rb', line 34 def iam_group_id @iam_group_id end |
#target_selected ⇒ OCI::CloudGuard::Models::TargetSelected
37 38 39 |
# File 'lib/oci/cloud_guard/models/update_data_mask_rule_details.rb', line 37 def target_selected @target_selected end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/oci/cloud_guard/models/update_data_mask_rule_details.rb', line 60 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'iam_group_id': :'iamGroupId', 'target_selected': :'targetSelected', 'data_mask_categories': :'dataMaskCategories', 'data_mask_rule_status': :'dataMaskRuleStatus', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/oci/cloud_guard/models/update_data_mask_rule_details.rb', line 76 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'compartment_id': :'String', 'iam_group_id': :'String', 'target_selected': :'OCI::CloudGuard::Models::TargetSelected', 'data_mask_categories': :'Array<String>', 'data_mask_rule_status': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/oci/cloud_guard/models/update_data_mask_rule_details.rb', line 190 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && compartment_id == other.compartment_id && iam_group_id == other.iam_group_id && target_selected == other.target_selected && data_mask_categories == other.data_mask_categories && data_mask_rule_status == other.data_mask_rule_status && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/oci/cloud_guard/models/update_data_mask_rule_details.rb', line 227 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
207 208 209 |
# File 'lib/oci/cloud_guard/models/update_data_mask_rule_details.rb', line 207 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
216 217 218 |
# File 'lib/oci/cloud_guard/models/update_data_mask_rule_details.rb', line 216 def hash [display_name, compartment_id, iam_group_id, target_selected, data_mask_categories, data_mask_rule_status, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
260 261 262 263 264 265 266 267 268 269 |
# File 'lib/oci/cloud_guard/models/update_data_mask_rule_details.rb', line 260 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
254 255 256 |
# File 'lib/oci/cloud_guard/models/update_data_mask_rule_details.rb', line 254 def to_s to_hash.to_s end |