Class: OCI::CloudGuard::Models::UpdateTargetDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/cloud_guard/models/update_target_details.rb

Overview

The information to be updated.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateTargetDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/oci/cloud_guard/models/update_target_details.rb', line 93

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.target_detector_recipes = attributes[:'targetDetectorRecipes'] if attributes[:'targetDetectorRecipes']

  raise 'You cannot provide both :targetDetectorRecipes and :target_detector_recipes' if attributes.key?(:'targetDetectorRecipes') && attributes.key?(:'target_detector_recipes')

  self.target_detector_recipes = attributes[:'target_detector_recipes'] if attributes[:'target_detector_recipes']

  self.target_responder_recipes = attributes[:'targetResponderRecipes'] if attributes[:'targetResponderRecipes']

  raise 'You cannot provide both :targetResponderRecipes and :target_responder_recipes' if attributes.key?(:'targetResponderRecipes') && attributes.key?(:'target_responder_recipes')

  self.target_responder_recipes = attributes[:'target_responder_recipes'] if attributes[:'target_responder_recipes']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


51
52
53
# File 'lib/oci/cloud_guard/models/update_target_details.rb', line 51

def defined_tags
  @defined_tags
end

#display_nameString

DetectorTemplate identifier.

Avoid entering confidential information.

Returns:

  • (String)


25
26
27
# File 'lib/oci/cloud_guard/models/update_target_details.rb', line 25

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`

Avoid entering confidential information.

Returns:

  • (Hash<String, String>)


45
46
47
# File 'lib/oci/cloud_guard/models/update_target_details.rb', line 45

def freeform_tags
  @freeform_tags
end

#lifecycle_stateString

The current state of the Target.

Returns:

  • (String)


29
30
31
# File 'lib/oci/cloud_guard/models/update_target_details.rb', line 29

def lifecycle_state
  @lifecycle_state
end

#target_detector_recipesArray<OCI::CloudGuard::Models::UpdateTargetDetectorRecipe>

The details of target detector recipes to be updated.



33
34
35
# File 'lib/oci/cloud_guard/models/update_target_details.rb', line 33

def target_detector_recipes
  @target_detector_recipes
end

#target_responder_recipesArray<OCI::CloudGuard::Models::UpdateTargetResponderRecipe>

The details of target responder recipes to be updated.



37
38
39
# File 'lib/oci/cloud_guard/models/update_target_details.rb', line 37

def target_responder_recipes
  @target_responder_recipes
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



54
55
56
57
58
59
60
61
62
63
64
65
# File 'lib/oci/cloud_guard/models/update_target_details.rb', line 54

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'displayName',
    'lifecycle_state': :'lifecycleState',
    'target_detector_recipes': :'targetDetectorRecipes',
    'target_responder_recipes': :'targetResponderRecipes',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/oci/cloud_guard/models/update_target_details.rb', line 68

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'String',
    'lifecycle_state': :'String',
    'target_detector_recipes': :'Array<OCI::CloudGuard::Models::UpdateTargetDetectorRecipe>',
    'target_responder_recipes': :'Array<OCI::CloudGuard::Models::UpdateTargetResponderRecipe>',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



151
152
153
154
155
156
157
158
159
160
161
# File 'lib/oci/cloud_guard/models/update_target_details.rb', line 151

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    display_name == other.display_name &&
    lifecycle_state == other.lifecycle_state &&
    target_detector_recipes == other.target_detector_recipes &&
    target_responder_recipes == other.target_responder_recipes &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/oci/cloud_guard/models/update_target_details.rb', line 186

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


166
167
168
# File 'lib/oci/cloud_guard/models/update_target_details.rb', line 166

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



175
176
177
# File 'lib/oci/cloud_guard/models/update_target_details.rb', line 175

def hash
  [display_name, lifecycle_state, target_detector_recipes, target_responder_recipes, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



219
220
221
222
223
224
225
226
227
228
# File 'lib/oci/cloud_guard/models/update_target_details.rb', line 219

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



213
214
215
# File 'lib/oci/cloud_guard/models/update_target_details.rb', line 213

def to_s
  to_hash.to_s
end