Class: OCI::CloudGuard::Models::UpdateTargetResponderRuleDetails
- Inherits:
-
Object
- Object
- OCI::CloudGuard::Models::UpdateTargetResponderRuleDetails
- Defined in:
- lib/oci/cloud_guard/models/update_target_responder_rule_details.rb
Overview
Details of ResponderRule.
Constant Summary collapse
- MODE_ENUM =
[ MODE_AUTOACTION = 'AUTOACTION'.freeze, MODE_USERACTION = 'USERACTION'.freeze ].freeze
Instance Attribute Summary collapse
- #condition ⇒ OCI::CloudGuard::Models::Condition
-
#configurations ⇒ Array<OCI::CloudGuard::Models::ResponderConfiguration>
Configurations associated with the ResponderRule.
-
#mode ⇒ String
Execution Mode for ResponderRule.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateTargetResponderRuleDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateTargetResponderRuleDetails
Initializes the object
57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/oci/cloud_guard/models/update_target_responder_rule_details.rb', line 57 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.condition = attributes[:'condition'] if attributes[:'condition'] self.configurations = attributes[:'configurations'] if attributes[:'configurations'] self.mode = attributes[:'mode'] if attributes[:'mode'] end |
Instance Attribute Details
#condition ⇒ OCI::CloudGuard::Models::Condition
16 17 18 |
# File 'lib/oci/cloud_guard/models/update_target_responder_rule_details.rb', line 16 def condition @condition end |
#configurations ⇒ Array<OCI::CloudGuard::Models::ResponderConfiguration>
Configurations associated with the ResponderRule
20 21 22 |
# File 'lib/oci/cloud_guard/models/update_target_responder_rule_details.rb', line 20 def configurations @configurations end |
#mode ⇒ String
Execution Mode for ResponderRule
24 25 26 |
# File 'lib/oci/cloud_guard/models/update_target_responder_rule_details.rb', line 24 def mode @mode end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
27 28 29 30 31 32 33 34 35 |
# File 'lib/oci/cloud_guard/models/update_target_responder_rule_details.rb', line 27 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'condition': :'condition', 'configurations': :'configurations', 'mode': :'mode' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
38 39 40 41 42 43 44 45 46 |
# File 'lib/oci/cloud_guard/models/update_target_responder_rule_details.rb', line 38 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'condition': :'OCI::CloudGuard::Models::Condition', 'configurations': :'Array<OCI::CloudGuard::Models::ResponderConfiguration>', 'mode': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
85 86 87 88 89 90 91 92 |
# File 'lib/oci/cloud_guard/models/update_target_responder_rule_details.rb', line 85 def ==(other) return true if equal?(other) self.class == other.class && condition == other.condition && configurations == other.configurations && mode == other.mode end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/oci/cloud_guard/models/update_target_responder_rule_details.rb', line 117 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
97 98 99 |
# File 'lib/oci/cloud_guard/models/update_target_responder_rule_details.rb', line 97 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
106 107 108 |
# File 'lib/oci/cloud_guard/models/update_target_responder_rule_details.rb', line 106 def hash [condition, configurations, mode].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
150 151 152 153 154 155 156 157 158 159 |
# File 'lib/oci/cloud_guard/models/update_target_responder_rule_details.rb', line 150 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
144 145 146 |
# File 'lib/oci/cloud_guard/models/update_target_responder_rule_details.rb', line 144 def to_s to_hash.to_s end |