Class: OCI::ComputeInstanceAgent::Models::CreateInstanceAgentCommandDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/compute_instance_agent/models/create_instance_agent_command_details.rb

Overview

Creation details for an Oracle Cloud Agent command.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateInstanceAgentCommandDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/oci/compute_instance_agent/models/create_instance_agent_command_details.rb', line 73

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.execution_time_out_in_seconds = attributes[:'executionTimeOutInSeconds'] if attributes[:'executionTimeOutInSeconds']

  raise 'You cannot provide both :executionTimeOutInSeconds and :execution_time_out_in_seconds' if attributes.key?(:'executionTimeOutInSeconds') && attributes.key?(:'execution_time_out_in_seconds')

  self.execution_time_out_in_seconds = attributes[:'execution_time_out_in_seconds'] if attributes[:'execution_time_out_in_seconds']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.target = attributes[:'target'] if attributes[:'target']

  self.content = attributes[:'content'] if attributes[:'content']
end

Instance Attribute Details

#compartment_idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment to create the command in.

Returns:

  • (String)


12
13
14
# File 'lib/oci/compute_instance_agent/models/create_instance_agent_command_details.rb', line 12

def compartment_id
  @compartment_id
end

#contentOCI::ComputeInstanceAgent::Models::InstanceAgentCommandContent

[Required] The contents of the command.



34
35
36
# File 'lib/oci/compute_instance_agent/models/create_instance_agent_command_details.rb', line 34

def content
  @content
end

#display_nameString

A user-friendly name for the command. It does not have to be unique. Avoid entering confidential information.

Example: ‘Database Backup Script`

Returns:

  • (String)


26
27
28
# File 'lib/oci/compute_instance_agent/models/create_instance_agent_command_details.rb', line 26

def display_name
  @display_name
end

#execution_time_out_in_secondsInteger

[Required] The amount of time that Oracle Cloud Agent is given to run the command on the instance before timing out. The timer starts when Oracle Cloud Agent starts the command. Zero means no timeout.

Returns:

  • (Integer)


18
19
20
# File 'lib/oci/compute_instance_agent/models/create_instance_agent_command_details.rb', line 18

def execution_time_out_in_seconds
  @execution_time_out_in_seconds
end

#targetOCI::ComputeInstanceAgent::Models::InstanceAgentCommandTarget

[Required] The target instance to run the command on.



30
31
32
# File 'lib/oci/compute_instance_agent/models/create_instance_agent_command_details.rb', line 30

def target
  @target
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
47
# File 'lib/oci/compute_instance_agent/models/create_instance_agent_command_details.rb', line 37

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'compartmentId',
    'execution_time_out_in_seconds': :'executionTimeOutInSeconds',
    'display_name': :'displayName',
    'target': :'target',
    'content': :'content'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



50
51
52
53
54
55
56
57
58
59
60
# File 'lib/oci/compute_instance_agent/models/create_instance_agent_command_details.rb', line 50

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'String',
    'execution_time_out_in_seconds': :'Integer',
    'display_name': :'String',
    'target': :'OCI::ComputeInstanceAgent::Models::InstanceAgentCommandTarget',
    'content': :'OCI::ComputeInstanceAgent::Models::InstanceAgentCommandContent'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



109
110
111
112
113
114
115
116
117
118
# File 'lib/oci/compute_instance_agent/models/create_instance_agent_command_details.rb', line 109

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    compartment_id == other.compartment_id &&
    execution_time_out_in_seconds == other.execution_time_out_in_seconds &&
    display_name == other.display_name &&
    target == other.target &&
    content == other.content
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/oci/compute_instance_agent/models/create_instance_agent_command_details.rb', line 143

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


123
124
125
# File 'lib/oci/compute_instance_agent/models/create_instance_agent_command_details.rb', line 123

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



132
133
134
# File 'lib/oci/compute_instance_agent/models/create_instance_agent_command_details.rb', line 132

def hash
  [compartment_id, execution_time_out_in_seconds, display_name, target, content].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



176
177
178
179
180
181
182
183
184
185
# File 'lib/oci/compute_instance_agent/models/create_instance_agent_command_details.rb', line 176

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



170
171
172
# File 'lib/oci/compute_instance_agent/models/create_instance_agent_command_details.rb', line 170

def to_s
  to_hash.to_s
end