Class: OCI::ComputeInstanceAgent::Models::InstanceAgentCommand

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/compute_instance_agent/models/instance_agent_command.rb

Overview

The command payload.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ InstanceAgentCommand

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/oci/compute_instance_agent/models/instance_agent_command.rb', line 101

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.is_canceled = attributes[:'isCanceled'] unless attributes[:'isCanceled'].nil?
  self.is_canceled = false if is_canceled.nil? && !attributes.key?(:'isCanceled') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isCanceled and :is_canceled' if attributes.key?(:'isCanceled') && attributes.key?(:'is_canceled')

  self.is_canceled = attributes[:'is_canceled'] unless attributes[:'is_canceled'].nil?
  self.is_canceled = false if is_canceled.nil? && !attributes.key?(:'isCanceled') && !attributes.key?(:'is_canceled') # rubocop:disable Style/StringLiterals

  self.execution_time_out_in_seconds = attributes[:'executionTimeOutInSeconds'] if attributes[:'executionTimeOutInSeconds']

  raise 'You cannot provide both :executionTimeOutInSeconds and :execution_time_out_in_seconds' if attributes.key?(:'executionTimeOutInSeconds') && attributes.key?(:'execution_time_out_in_seconds')

  self.execution_time_out_in_seconds = attributes[:'execution_time_out_in_seconds'] if attributes[:'execution_time_out_in_seconds']

  self.target = attributes[:'target'] if attributes[:'target']

  self.content = attributes[:'content'] if attributes[:'content']
end

Instance Attribute Details

#compartment_idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment containing the command.

Returns:

  • (String)


16
17
18
# File 'lib/oci/compute_instance_agent/models/instance_agent_command.rb', line 16

def compartment_id
  @compartment_id
end

#contentOCI::ComputeInstanceAgent::Models::InstanceAgentCommandContent

[Required] The contents of the command.



50
51
52
# File 'lib/oci/compute_instance_agent/models/instance_agent_command.rb', line 50

def content
  @content
end

#display_nameString

A user-friendly name. Does not have to be unique. Avoid entering confidential information.

Returns:

  • (String)


20
21
22
# File 'lib/oci/compute_instance_agent/models/instance_agent_command.rb', line 20

def display_name
  @display_name
end

#execution_time_out_in_secondsInteger

The amount of time that Oracle Cloud Agent is given to run the command on the instance before timing out. The timer starts when Oracle Cloud Agent starts the command. Zero means no timeout.

Returns:

  • (Integer)


42
43
44
# File 'lib/oci/compute_instance_agent/models/instance_agent_command.rb', line 42

def execution_time_out_in_seconds
  @execution_time_out_in_seconds
end

#idString

Returns:

  • (String)


12
13
14
# File 'lib/oci/compute_instance_agent/models/instance_agent_command.rb', line 12

def id
  @id
end

#is_canceledBOOLEAN

Whether a request was made to cancel the command. Canceling a command is a best-effort attempt.

Returns:

  • (BOOLEAN)


36
37
38
# File 'lib/oci/compute_instance_agent/models/instance_agent_command.rb', line 36

def is_canceled
  @is_canceled
end

#targetOCI::ComputeInstanceAgent::Models::InstanceAgentCommandTarget

[Required] The target instance that the command runs on.



46
47
48
# File 'lib/oci/compute_instance_agent/models/instance_agent_command.rb', line 46

def target
  @target
end

#time_createdDateTime

The date and time the command was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).

Returns:

  • (DateTime)


26
27
28
# File 'lib/oci/compute_instance_agent/models/instance_agent_command.rb', line 26

def time_created
  @time_created
end

#time_updatedDateTime

The date and time the command was last updated, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).

Returns:

  • (DateTime)


32
33
34
# File 'lib/oci/compute_instance_agent/models/instance_agent_command.rb', line 32

def time_updated
  @time_updated
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/oci/compute_instance_agent/models/instance_agent_command.rb', line 53

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'compartment_id': :'compartmentId',
    'display_name': :'displayName',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'is_canceled': :'isCanceled',
    'execution_time_out_in_seconds': :'executionTimeOutInSeconds',
    'target': :'target',
    'content': :'content'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/oci/compute_instance_agent/models/instance_agent_command.rb', line 70

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'compartment_id': :'String',
    'display_name': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'is_canceled': :'BOOLEAN',
    'execution_time_out_in_seconds': :'Integer',
    'target': :'OCI::ComputeInstanceAgent::Models::InstanceAgentCommandTarget',
    'content': :'OCI::ComputeInstanceAgent::Models::InstanceAgentCommandContent'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/oci/compute_instance_agent/models/instance_agent_command.rb', line 159

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    display_name == other.display_name &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    is_canceled == other.is_canceled &&
    execution_time_out_in_seconds == other.execution_time_out_in_seconds &&
    target == other.target &&
    content == other.content
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/oci/compute_instance_agent/models/instance_agent_command.rb', line 197

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


177
178
179
# File 'lib/oci/compute_instance_agent/models/instance_agent_command.rb', line 177

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



186
187
188
# File 'lib/oci/compute_instance_agent/models/instance_agent_command.rb', line 186

def hash
  [id, compartment_id, display_name, time_created, time_updated, is_canceled, execution_time_out_in_seconds, target, content].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



230
231
232
233
234
235
236
237
238
239
# File 'lib/oci/compute_instance_agent/models/instance_agent_command.rb', line 230

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



224
225
226
# File 'lib/oci/compute_instance_agent/models/instance_agent_command.rb', line 224

def to_s
  to_hash.to_s
end