Class: OCI::ContainerEngine::ContainerEngineClient
- Inherits:
-
Object
- Object
- OCI::ContainerEngine::ContainerEngineClient
- Defined in:
- lib/oci/container_engine/container_engine_client.rb
Overview
API for the Container Engine for Kubernetes service. Use this API to build, deploy, and manage cloud-native applications. For more information, see [Overview of Container Engine for Kubernetes](/iaas/Content/ContEng/Concepts/contengoverview.htm).
Instance Attribute Summary collapse
-
#api_client ⇒ OCI::ApiClient
readonly
Client used to make HTTP requests.
-
#endpoint ⇒ String
readonly
Fully qualified endpoint URL.
-
#region ⇒ String
The region, which will usually correspond to a value in Regions::REGION_ENUM.
-
#retry_config ⇒ OCI::Retry::RetryConfig
readonly
The default retry configuration to apply to all operations in this service client.
Instance Method Summary collapse
-
#cluster_migrate_to_native_vcn(cluster_id, cluster_migrate_to_native_vcn_details, opts = {}) ⇒ Response
Initiates cluster migration to use native VCN.
-
#create_cluster(create_cluster_details, opts = {}) ⇒ Response
Create a new cluster.
-
#create_kubeconfig(cluster_id, opts = {}, &block) ⇒ Response
Create the Kubeconfig YAML for a cluster.
-
#create_node_pool(create_node_pool_details, opts = {}) ⇒ Response
Create a new node pool.
-
#delete_cluster(cluster_id, opts = {}) ⇒ Response
Delete a cluster.
-
#delete_node_pool(node_pool_id, opts = {}) ⇒ Response
Delete a node pool.
-
#delete_work_request(work_request_id, opts = {}) ⇒ Response
Cancel a work request that has not started.
-
#get_cluster(cluster_id, opts = {}) ⇒ Response
Get the details of a cluster.
-
#get_cluster_migrate_to_native_vcn_status(cluster_id, opts = {}) ⇒ Response
Get details on a cluster’s migration to native VCN.
-
#get_cluster_options(cluster_option_id, opts = {}) ⇒ Response
Get options available for clusters.
-
#get_node_pool(node_pool_id, opts = {}) ⇒ Response
Get the details of a node pool.
-
#get_node_pool_options(node_pool_option_id, opts = {}) ⇒ Response
Get options available for node pools.
-
#get_work_request(work_request_id, opts = {}) ⇒ Response
Get the details of a work request.
-
#initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) ⇒ ContainerEngineClient
constructor
Creates a new ContainerEngineClient.
-
#list_clusters(compartment_id, opts = {}) ⇒ Response
List all the cluster objects in a compartment.
-
#list_node_pools(compartment_id, opts = {}) ⇒ Response
List all the node pools in a compartment, and optionally filter by cluster.
-
#list_work_request_errors(compartment_id, work_request_id, opts = {}) ⇒ Response
Get the errors of a work request.
-
#list_work_request_logs(compartment_id, work_request_id, opts = {}) ⇒ Response
Get the logs of a work request.
-
#list_work_requests(compartment_id, opts = {}) ⇒ Response
List all work requests in a compartment.
-
#logger ⇒ Logger
The logger for this client.
-
#update_cluster(cluster_id, update_cluster_details, opts = {}) ⇒ Response
Update the details of a cluster.
-
#update_cluster_endpoint_config(cluster_id, update_cluster_endpoint_config_details, opts = {}) ⇒ Response
Update the details of the cluster endpoint configuration.
-
#update_node_pool(node_pool_id, update_node_pool_details, opts = {}) ⇒ Response
Update the details of a node pool.
Constructor Details
#initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) ⇒ ContainerEngineClient
Creates a new ContainerEngineClient. Notes:
If a config is not specified, then the global OCI.config will be used.
This client is not thread-safe
Either a region or an endpoint must be specified. If an endpoint is specified, it will be used instead of the
region. A region may be specified in the config or via or the region parameter. If specified in both, then the
region parameter will be used.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/oci/container_engine/container_engine_client.rb', line 55 def initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) # If the signer is an InstancePrincipalsSecurityTokenSigner or SecurityTokenSigner and no config was supplied (they are self-sufficient signers) # then create a dummy config to pass to the ApiClient constructor. If customers wish to create a client which uses instance principals # and has config (either populated programmatically or loaded from a file), they must construct that config themselves and then # pass it to this constructor. # # If there is no signer (or the signer is not an instance principals signer) and no config was supplied, this is not valid # so try and load the config from the default file. config = OCI::Config.validate_and_build_config_with_signer(config, signer) signer = OCI::Signer.config_file_auth_builder(config) if signer.nil? @api_client = OCI::ApiClient.new(config, signer, proxy_settings: proxy_settings) @retry_config = retry_config if endpoint @endpoint = endpoint + '/20180222' else region ||= config.region region ||= signer.region if signer.respond_to?(:region) self.region = region end logger.info "ContainerEngineClient endpoint set to '#{@endpoint}'." if logger end |
Instance Attribute Details
#api_client ⇒ OCI::ApiClient (readonly)
Client used to make HTTP requests.
15 16 17 |
# File 'lib/oci/container_engine/container_engine_client.rb', line 15 def api_client @api_client end |
#endpoint ⇒ String (readonly)
Fully qualified endpoint URL
19 20 21 |
# File 'lib/oci/container_engine/container_engine_client.rb', line 19 def endpoint @endpoint end |
#region ⇒ String
The region, which will usually correspond to a value in Regions::REGION_ENUM.
29 30 31 |
# File 'lib/oci/container_engine/container_engine_client.rb', line 29 def region @region end |
#retry_config ⇒ OCI::Retry::RetryConfig (readonly)
The default retry configuration to apply to all operations in this service client. This can be overridden on a per-operation basis. The default retry configuration value is nil, which means that an operation will not perform any retries
25 26 27 |
# File 'lib/oci/container_engine/container_engine_client.rb', line 25 def retry_config @retry_config end |
Instance Method Details
#cluster_migrate_to_native_vcn(cluster_id, cluster_migrate_to_native_vcn_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/containerengine/cluster_migrate_to_native_vcn.rb.html) to see an example of how to use cluster_migrate_to_native_vcn API.
Initiates cluster migration to use native VCN.
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/oci/container_engine/container_engine_client.rb', line 118 def cluster_migrate_to_native_vcn(cluster_id, cluster_migrate_to_native_vcn_details, opts = {}) logger.debug 'Calling operation ContainerEngineClient#cluster_migrate_to_native_vcn.' if logger raise "Missing the required parameter 'cluster_id' when calling cluster_migrate_to_native_vcn." if cluster_id.nil? raise "Missing the required parameter 'cluster_migrate_to_native_vcn_details' when calling cluster_migrate_to_native_vcn." if cluster_migrate_to_native_vcn_details.nil? raise "Parameter value for 'cluster_id' must not be blank" if OCI::Internal::Util.blank_string?(cluster_id) path = '/clusters/{clusterId}/actions/migrateToNativeVcn'.sub('{clusterId}', cluster_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(cluster_migrate_to_native_vcn_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ContainerEngineClient#cluster_migrate_to_native_vcn') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#create_cluster(create_cluster_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/containerengine/create_cluster.rb.html) to see an example of how to use create_cluster API.
Create a new cluster.
178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/oci/container_engine/container_engine_client.rb', line 178 def create_cluster(create_cluster_details, opts = {}) logger.debug 'Calling operation ContainerEngineClient#create_cluster.' if logger raise "Missing the required parameter 'create_cluster_details' when calling create_cluster." if create_cluster_details.nil? path = '/clusters' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = @api_client.object_to_http_body(create_cluster_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ContainerEngineClient#create_cluster') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#create_kubeconfig(cluster_id, opts = {}, &block) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/containerengine/create_kubeconfig.rb.html) to see an example of how to use create_kubeconfig API.
Create the Kubeconfig YAML for a cluster.
237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/oci/container_engine/container_engine_client.rb', line 237 def create_kubeconfig(cluster_id, opts = {}, &block) logger.debug 'Calling operation ContainerEngineClient#create_kubeconfig.' if logger raise "Missing the required parameter 'cluster_id' when calling create_kubeconfig." if cluster_id.nil? raise "Parameter value for 'cluster_id' must not be blank" if OCI::Internal::Util.blank_string?(cluster_id) path = '/clusters/{clusterId}/kubeconfig/content'.sub('{clusterId}', cluster_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = opts[:accept] if opts[:accept] header_params[:accept] ||= 'application/x-yaml' header_params[:'accept-encoding'] = opts[:accept_encoding] if opts[:accept_encoding] header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(opts[:create_cluster_kubeconfig_content_details]) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ContainerEngineClient#create_kubeconfig') do if !block.nil? @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'Stream', &block ) elsif opts[:response_target] if opts[:response_target].respond_to? :write @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'Stream', &proc { |chunk, _response| opts[:response_target].write(chunk) } ) elsif opts[:response_target].is_a?(String) File.open(opts[:response_target], 'wb') do |output| return @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'Stream', &proc { |chunk, _response| output.write(chunk) } ) end end else @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'String' ) end end # rubocop:enable Metrics/BlockLength end |
#create_node_pool(create_node_pool_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/containerengine/create_node_pool.rb.html) to see an example of how to use create_node_pool API.
Create a new node pool.
340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 |
# File 'lib/oci/container_engine/container_engine_client.rb', line 340 def create_node_pool(create_node_pool_details, opts = {}) logger.debug 'Calling operation ContainerEngineClient#create_node_pool.' if logger raise "Missing the required parameter 'create_node_pool_details' when calling create_node_pool." if create_node_pool_details.nil? path = '/nodePools' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = @api_client.object_to_http_body(create_node_pool_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ContainerEngineClient#create_node_pool') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#delete_cluster(cluster_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/containerengine/delete_cluster.rb.html) to see an example of how to use delete_cluster API.
Delete a cluster.
400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 |
# File 'lib/oci/container_engine/container_engine_client.rb', line 400 def delete_cluster(cluster_id, opts = {}) logger.debug 'Calling operation ContainerEngineClient#delete_cluster.' if logger raise "Missing the required parameter 'cluster_id' when calling delete_cluster." if cluster_id.nil? raise "Parameter value for 'cluster_id' must not be blank" if OCI::Internal::Util.blank_string?(cluster_id) path = '/clusters/{clusterId}'.sub('{clusterId}', cluster_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ContainerEngineClient#delete_cluster') do @api_client.call_api( :DELETE, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#delete_node_pool(node_pool_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/containerengine/delete_node_pool.rb.html) to see an example of how to use delete_node_pool API.
Delete a node pool.
460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 |
# File 'lib/oci/container_engine/container_engine_client.rb', line 460 def delete_node_pool(node_pool_id, opts = {}) logger.debug 'Calling operation ContainerEngineClient#delete_node_pool.' if logger raise "Missing the required parameter 'node_pool_id' when calling delete_node_pool." if node_pool_id.nil? raise "Parameter value for 'node_pool_id' must not be blank" if OCI::Internal::Util.blank_string?(node_pool_id) path = '/nodePools/{nodePoolId}'.sub('{nodePoolId}', node_pool_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ContainerEngineClient#delete_node_pool') do @api_client.call_api( :DELETE, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#delete_work_request(work_request_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/containerengine/delete_work_request.rb.html) to see an example of how to use delete_work_request API.
Cancel a work request that has not started.
520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 |
# File 'lib/oci/container_engine/container_engine_client.rb', line 520 def delete_work_request(work_request_id, opts = {}) logger.debug 'Calling operation ContainerEngineClient#delete_work_request.' if logger raise "Missing the required parameter 'work_request_id' when calling delete_work_request." if work_request_id.nil? raise "Parameter value for 'work_request_id' must not be blank" if OCI::Internal::Util.blank_string?(work_request_id) path = '/workRequests/{workRequestId}'.sub('{workRequestId}', work_request_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ContainerEngineClient#delete_work_request') do @api_client.call_api( :DELETE, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#get_cluster(cluster_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/containerengine/get_cluster.rb.html) to see an example of how to use get_cluster API.
Get the details of a cluster.
576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 |
# File 'lib/oci/container_engine/container_engine_client.rb', line 576 def get_cluster(cluster_id, opts = {}) logger.debug 'Calling operation ContainerEngineClient#get_cluster.' if logger raise "Missing the required parameter 'cluster_id' when calling get_cluster." if cluster_id.nil? raise "Parameter value for 'cluster_id' must not be blank" if OCI::Internal::Util.blank_string?(cluster_id) path = '/clusters/{clusterId}'.sub('{clusterId}', cluster_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ContainerEngineClient#get_cluster') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::ContainerEngine::Models::Cluster' ) end # rubocop:enable Metrics/BlockLength end |
#get_cluster_migrate_to_native_vcn_status(cluster_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/containerengine/get_cluster_migrate_to_native_vcn_status.rb.html) to see an example of how to use get_cluster_migrate_to_native_vcn_status API.
Get details on a cluster’s migration to native VCN.
632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 |
# File 'lib/oci/container_engine/container_engine_client.rb', line 632 def get_cluster_migrate_to_native_vcn_status(cluster_id, opts = {}) logger.debug 'Calling operation ContainerEngineClient#get_cluster_migrate_to_native_vcn_status.' if logger raise "Missing the required parameter 'cluster_id' when calling get_cluster_migrate_to_native_vcn_status." if cluster_id.nil? raise "Parameter value for 'cluster_id' must not be blank" if OCI::Internal::Util.blank_string?(cluster_id) path = '/clusters/{clusterId}/migrateToNativeVcnStatus'.sub('{clusterId}', cluster_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ContainerEngineClient#get_cluster_migrate_to_native_vcn_status') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::ContainerEngine::Models::ClusterMigrateToNativeVcnStatus' ) end # rubocop:enable Metrics/BlockLength end |
#get_cluster_options(cluster_option_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/containerengine/get_cluster_options.rb.html) to see an example of how to use get_cluster_options API.
Get options available for clusters.
689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 |
# File 'lib/oci/container_engine/container_engine_client.rb', line 689 def (cluster_option_id, opts = {}) logger.debug 'Calling operation ContainerEngineClient#get_cluster_options.' if logger raise "Missing the required parameter 'cluster_option_id' when calling get_cluster_options." if cluster_option_id.nil? raise "Parameter value for 'cluster_option_id' must not be blank" if OCI::Internal::Util.blank_string?(cluster_option_id) path = '/clusterOptions/{clusterOptionId}'.sub('{clusterOptionId}', cluster_option_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:compartmentId] = opts[:compartment_id] if opts[:compartment_id] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ContainerEngineClient#get_cluster_options') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::ContainerEngine::Models::ClusterOptions' ) end # rubocop:enable Metrics/BlockLength end |
#get_node_pool(node_pool_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/containerengine/get_node_pool.rb.html) to see an example of how to use get_node_pool API.
Get the details of a node pool.
746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 |
# File 'lib/oci/container_engine/container_engine_client.rb', line 746 def get_node_pool(node_pool_id, opts = {}) logger.debug 'Calling operation ContainerEngineClient#get_node_pool.' if logger raise "Missing the required parameter 'node_pool_id' when calling get_node_pool." if node_pool_id.nil? raise "Parameter value for 'node_pool_id' must not be blank" if OCI::Internal::Util.blank_string?(node_pool_id) path = '/nodePools/{nodePoolId}'.sub('{nodePoolId}', node_pool_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ContainerEngineClient#get_node_pool') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::ContainerEngine::Models::NodePool' ) end # rubocop:enable Metrics/BlockLength end |
#get_node_pool_options(node_pool_option_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/containerengine/get_node_pool_options.rb.html) to see an example of how to use get_node_pool_options API.
Get options available for node pools.
803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 |
# File 'lib/oci/container_engine/container_engine_client.rb', line 803 def (node_pool_option_id, opts = {}) logger.debug 'Calling operation ContainerEngineClient#get_node_pool_options.' if logger raise "Missing the required parameter 'node_pool_option_id' when calling get_node_pool_options." if node_pool_option_id.nil? raise "Parameter value for 'node_pool_option_id' must not be blank" if OCI::Internal::Util.blank_string?(node_pool_option_id) path = '/nodePoolOptions/{nodePoolOptionId}'.sub('{nodePoolOptionId}', node_pool_option_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:compartmentId] = opts[:compartment_id] if opts[:compartment_id] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ContainerEngineClient#get_node_pool_options') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::ContainerEngine::Models::NodePoolOptions' ) end # rubocop:enable Metrics/BlockLength end |
#get_work_request(work_request_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/containerengine/get_work_request.rb.html) to see an example of how to use get_work_request API.
Get the details of a work request.
860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 |
# File 'lib/oci/container_engine/container_engine_client.rb', line 860 def get_work_request(work_request_id, opts = {}) logger.debug 'Calling operation ContainerEngineClient#get_work_request.' if logger raise "Missing the required parameter 'work_request_id' when calling get_work_request." if work_request_id.nil? raise "Parameter value for 'work_request_id' must not be blank" if OCI::Internal::Util.blank_string?(work_request_id) path = '/workRequests/{workRequestId}'.sub('{workRequestId}', work_request_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ContainerEngineClient#get_work_request') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::ContainerEngine::Models::WorkRequest' ) end # rubocop:enable Metrics/BlockLength end |
#list_clusters(compartment_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/containerengine/list_clusters.rb.html) to see an example of how to use list_clusters API.
List all the cluster objects in a compartment.
929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 |
# File 'lib/oci/container_engine/container_engine_client.rb', line 929 def list_clusters(compartment_id, opts = {}) logger.debug 'Calling operation ContainerEngineClient#list_clusters.' if logger raise "Missing the required parameter 'compartment_id' when calling list_clusters." if compartment_id.nil? lifecycle_state_allowable_values = %w[CREATING ACTIVE FAILED DELETING DELETED UPDATING] if opts[:lifecycle_state] && !opts[:lifecycle_state].empty? opts[:lifecycle_state].each do |val_to_check| unless lifecycle_state_allowable_values.include?(val_to_check) raise 'Invalid value for "lifecycle_state", must be one of CREATING, ACTIVE, FAILED, DELETING, DELETED, UPDATING.' end end end if opts[:sort_order] && !OCI::ContainerEngine::Models::SORT_ORDER_ENUM.include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of the values in OCI::ContainerEngine::Models::SORT_ORDER_ENUM.' end if opts[:sort_by] && !%w[ID NAME TIME_CREATED].include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of ID, NAME, TIME_CREATED.' end path = '/clusters' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:compartmentId] = compartment_id query_params[:lifecycleState] = OCI::ApiClient.build_collection_params(opts[:lifecycle_state], :multi) if opts[:lifecycle_state] && !opts[:lifecycle_state].empty? query_params[:name] = opts[:name] if opts[:name] query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ContainerEngineClient#list_clusters') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'Array<OCI::ContainerEngine::Models::ClusterSummary>' ) end # rubocop:enable Metrics/BlockLength end |
#list_node_pools(compartment_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/containerengine/list_node_pools.rb.html) to see an example of how to use list_node_pools API.
List all the node pools in a compartment, and optionally filter by cluster.
1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 |
# File 'lib/oci/container_engine/container_engine_client.rb', line 1021 def list_node_pools(compartment_id, opts = {}) logger.debug 'Calling operation ContainerEngineClient#list_node_pools.' if logger raise "Missing the required parameter 'compartment_id' when calling list_node_pools." if compartment_id.nil? if opts[:sort_order] && !OCI::ContainerEngine::Models::SORT_ORDER_ENUM.include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of the values in OCI::ContainerEngine::Models::SORT_ORDER_ENUM.' end if opts[:sort_by] && !%w[ID NAME TIME_CREATED].include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of ID, NAME, TIME_CREATED.' end path = '/nodePools' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:compartmentId] = compartment_id query_params[:clusterId] = opts[:cluster_id] if opts[:cluster_id] query_params[:name] = opts[:name] if opts[:name] query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ContainerEngineClient#list_node_pools') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'Array<OCI::ContainerEngine::Models::NodePoolSummary>' ) end # rubocop:enable Metrics/BlockLength end |
#list_work_request_errors(compartment_id, work_request_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/containerengine/list_work_request_errors.rb.html) to see an example of how to use list_work_request_errors API.
Get the errors of a work request.
1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 |
# File 'lib/oci/container_engine/container_engine_client.rb', line 1092 def list_work_request_errors(compartment_id, work_request_id, opts = {}) logger.debug 'Calling operation ContainerEngineClient#list_work_request_errors.' if logger raise "Missing the required parameter 'compartment_id' when calling list_work_request_errors." if compartment_id.nil? raise "Missing the required parameter 'work_request_id' when calling list_work_request_errors." if work_request_id.nil? raise "Parameter value for 'work_request_id' must not be blank" if OCI::Internal::Util.blank_string?(work_request_id) path = '/workRequests/{workRequestId}/errors'.sub('{workRequestId}', work_request_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:compartmentId] = compartment_id # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ContainerEngineClient#list_work_request_errors') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'Array<OCI::ContainerEngine::Models::WorkRequestError>' ) end # rubocop:enable Metrics/BlockLength end |
#list_work_request_logs(compartment_id, work_request_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/containerengine/list_work_request_logs.rb.html) to see an example of how to use list_work_request_logs API.
Get the logs of a work request.
1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 |
# File 'lib/oci/container_engine/container_engine_client.rb', line 1151 def list_work_request_logs(compartment_id, work_request_id, opts = {}) logger.debug 'Calling operation ContainerEngineClient#list_work_request_logs.' if logger raise "Missing the required parameter 'compartment_id' when calling list_work_request_logs." if compartment_id.nil? raise "Missing the required parameter 'work_request_id' when calling list_work_request_logs." if work_request_id.nil? raise "Parameter value for 'work_request_id' must not be blank" if OCI::Internal::Util.blank_string?(work_request_id) path = '/workRequests/{workRequestId}/logs'.sub('{workRequestId}', work_request_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:compartmentId] = compartment_id # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ContainerEngineClient#list_work_request_logs') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'Array<OCI::ContainerEngine::Models::WorkRequestLogEntry>' ) end # rubocop:enable Metrics/BlockLength end |
#list_work_requests(compartment_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/containerengine/list_work_requests.rb.html) to see an example of how to use list_work_requests API.
List all work requests in a compartment.
1224 1225 1226 1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 1267 1268 1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 |
# File 'lib/oci/container_engine/container_engine_client.rb', line 1224 def list_work_requests(compartment_id, opts = {}) logger.debug 'Calling operation ContainerEngineClient#list_work_requests.' if logger raise "Missing the required parameter 'compartment_id' when calling list_work_requests." if compartment_id.nil? if opts[:resource_type] && !%w[CLUSTER NODEPOOL].include?(opts[:resource_type]) raise 'Invalid value for "resource_type", must be one of CLUSTER, NODEPOOL.' end if opts[:sort_order] && !OCI::ContainerEngine::Models::SORT_ORDER_ENUM.include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of the values in OCI::ContainerEngine::Models::SORT_ORDER_ENUM.' end if opts[:sort_by] && !%w[ID OPERATION_TYPE STATUS TIME_ACCEPTED TIME_STARTED TIME_FINISHED].include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of ID, OPERATION_TYPE, STATUS, TIME_ACCEPTED, TIME_STARTED, TIME_FINISHED.' end path = '/workRequests' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:compartmentId] = compartment_id query_params[:clusterId] = opts[:cluster_id] if opts[:cluster_id] query_params[:resourceId] = opts[:resource_id] if opts[:resource_id] query_params[:resourceType] = opts[:resource_type] if opts[:resource_type] query_params[:status] = OCI::ApiClient.build_collection_params(opts[:status], :multi) if opts[:status] && !opts[:status].empty? query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ContainerEngineClient#list_work_requests') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'Array<OCI::ContainerEngine::Models::WorkRequestSummary>' ) end # rubocop:enable Metrics/BlockLength end |
#logger ⇒ Logger
Returns The logger for this client. May be nil.
94 95 96 |
# File 'lib/oci/container_engine/container_engine_client.rb', line 94 def logger @api_client.config.logger end |
#update_cluster(cluster_id, update_cluster_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/containerengine/update_cluster.rb.html) to see an example of how to use update_cluster API.
Update the details of a cluster.
1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 1329 1330 1331 1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 |
# File 'lib/oci/container_engine/container_engine_client.rb', line 1305 def update_cluster(cluster_id, update_cluster_details, opts = {}) logger.debug 'Calling operation ContainerEngineClient#update_cluster.' if logger raise "Missing the required parameter 'cluster_id' when calling update_cluster." if cluster_id.nil? raise "Missing the required parameter 'update_cluster_details' when calling update_cluster." if update_cluster_details.nil? raise "Parameter value for 'cluster_id' must not be blank" if OCI::Internal::Util.blank_string?(cluster_id) path = '/clusters/{clusterId}'.sub('{clusterId}', cluster_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(update_cluster_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ContainerEngineClient#update_cluster') do @api_client.call_api( :PUT, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#update_cluster_endpoint_config(cluster_id, update_cluster_endpoint_config_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/containerengine/update_cluster_endpoint_config.rb.html) to see an example of how to use update_cluster_endpoint_config API.
Update the details of the cluster endpoint configuration.
1367 1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 |
# File 'lib/oci/container_engine/container_engine_client.rb', line 1367 def update_cluster_endpoint_config(cluster_id, update_cluster_endpoint_config_details, opts = {}) logger.debug 'Calling operation ContainerEngineClient#update_cluster_endpoint_config.' if logger raise "Missing the required parameter 'cluster_id' when calling update_cluster_endpoint_config." if cluster_id.nil? raise "Missing the required parameter 'update_cluster_endpoint_config_details' when calling update_cluster_endpoint_config." if update_cluster_endpoint_config_details.nil? raise "Parameter value for 'cluster_id' must not be blank" if OCI::Internal::Util.blank_string?(cluster_id) path = '/clusters/{clusterId}/actions/updateEndpointConfig'.sub('{clusterId}', cluster_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(update_cluster_endpoint_config_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ContainerEngineClient#update_cluster_endpoint_config') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#update_node_pool(node_pool_id, update_node_pool_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/containerengine/update_node_pool.rb.html) to see an example of how to use update_node_pool API.
Update the details of a node pool.
1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 |
# File 'lib/oci/container_engine/container_engine_client.rb', line 1429 def update_node_pool(node_pool_id, update_node_pool_details, opts = {}) logger.debug 'Calling operation ContainerEngineClient#update_node_pool.' if logger raise "Missing the required parameter 'node_pool_id' when calling update_node_pool." if node_pool_id.nil? raise "Missing the required parameter 'update_node_pool_details' when calling update_node_pool." if update_node_pool_details.nil? raise "Parameter value for 'node_pool_id' must not be blank" if OCI::Internal::Util.blank_string?(node_pool_id) path = '/nodePools/{nodePoolId}'.sub('{nodePoolId}', node_pool_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(update_node_pool_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ContainerEngineClient#update_node_pool') do @api_client.call_api( :PUT, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |