Class: ContainerEngine::Models::Cluster

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/container_engine/models/cluster.rb

Overview

A Kubernetes cluster. Avoid entering confidential information.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Cluster

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/oci/container_engine/models/cluster.rb', line 179

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.name = attributes[:'name'] if attributes[:'name']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.endpoint_config = attributes[:'endpointConfig'] if attributes[:'endpointConfig']

  raise 'You cannot provide both :endpointConfig and :endpoint_config' if attributes.key?(:'endpointConfig') && attributes.key?(:'endpoint_config')

  self.endpoint_config = attributes[:'endpoint_config'] if attributes[:'endpoint_config']

  self.vcn_id = attributes[:'vcnId'] if attributes[:'vcnId']

  raise 'You cannot provide both :vcnId and :vcn_id' if attributes.key?(:'vcnId') && attributes.key?(:'vcn_id')

  self.vcn_id = attributes[:'vcn_id'] if attributes[:'vcn_id']

  self.kubernetes_version = attributes[:'kubernetesVersion'] if attributes[:'kubernetesVersion']

  raise 'You cannot provide both :kubernetesVersion and :kubernetes_version' if attributes.key?(:'kubernetesVersion') && attributes.key?(:'kubernetes_version')

  self.kubernetes_version = attributes[:'kubernetes_version'] if attributes[:'kubernetes_version']

  self.kms_key_id = attributes[:'kmsKeyId'] if attributes[:'kmsKeyId']

  raise 'You cannot provide both :kmsKeyId and :kms_key_id' if attributes.key?(:'kmsKeyId') && attributes.key?(:'kms_key_id')

  self.kms_key_id = attributes[:'kms_key_id'] if attributes[:'kms_key_id']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

  raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

  self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']

  self.options = attributes[:'options'] if attributes[:'options']

  self. = attributes[:'metadata'] if attributes[:'metadata']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.endpoints = attributes[:'endpoints'] if attributes[:'endpoints']

  self.available_kubernetes_upgrades = attributes[:'availableKubernetesUpgrades'] if attributes[:'availableKubernetesUpgrades']

  raise 'You cannot provide both :availableKubernetesUpgrades and :available_kubernetes_upgrades' if attributes.key?(:'availableKubernetesUpgrades') && attributes.key?(:'available_kubernetes_upgrades')

  self.available_kubernetes_upgrades = attributes[:'available_kubernetes_upgrades'] if attributes[:'available_kubernetes_upgrades']

  self.image_policy_config = attributes[:'imagePolicyConfig'] if attributes[:'imagePolicyConfig']

  raise 'You cannot provide both :imagePolicyConfig and :image_policy_config' if attributes.key?(:'imagePolicyConfig') && attributes.key?(:'image_policy_config')

  self.image_policy_config = attributes[:'image_policy_config'] if attributes[:'image_policy_config']

  self.cluster_pod_network_options = attributes[:'clusterPodNetworkOptions'] if attributes[:'clusterPodNetworkOptions']

  raise 'You cannot provide both :clusterPodNetworkOptions and :cluster_pod_network_options' if attributes.key?(:'clusterPodNetworkOptions') && attributes.key?(:'cluster_pod_network_options')

  self.cluster_pod_network_options = attributes[:'cluster_pod_network_options'] if attributes[:'cluster_pod_network_options']
end

Instance Attribute Details

#available_kubernetes_upgradesArray<String>

Available Kubernetes versions to which the clusters masters may be upgraded.

Returns:

  • (Array<String>)


92
93
94
# File 'lib/oci/container_engine/models/cluster.rb', line 92

def available_kubernetes_upgrades
  @available_kubernetes_upgrades
end

#cluster_pod_network_optionsArray<OCI::ContainerEngine::Models::ClusterPodNetworkOptionDetails>

Available CNIs and network options for existing and new node pools of the cluster



101
102
103
# File 'lib/oci/container_engine/models/cluster.rb', line 101

def cluster_pod_network_options
  @cluster_pod_network_options
end

#compartment_idString

The OCID of the compartment in which the cluster exists.

Returns:

  • (String)


31
32
33
# File 'lib/oci/container_engine/models/cluster.rb', line 31

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


62
63
64
# File 'lib/oci/container_engine/models/cluster.rb', line 62

def defined_tags
  @defined_tags
end

#endpoint_configOCI::ContainerEngine::Models::ClusterEndpointConfig

The network configuration for access to the Cluster control plane.



36
37
38
# File 'lib/oci/container_engine/models/cluster.rb', line 36

def endpoint_config
  @endpoint_config
end

#endpointsOCI::ContainerEngine::Models::ClusterEndpoints

Endpoints served up by the cluster masters.



88
89
90
# File 'lib/oci/container_engine/models/cluster.rb', line 88

def endpoints
  @endpoints
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `"Finance"`

Returns:

  • (Hash<String, String>)


55
56
57
# File 'lib/oci/container_engine/models/cluster.rb', line 55

def freeform_tags
  @freeform_tags
end

#idString

The OCID of the cluster.

Returns:

  • (String)


23
24
25
# File 'lib/oci/container_engine/models/cluster.rb', line 23

def id
  @id
end

#image_policy_configOCI::ContainerEngine::Models::ImagePolicyConfig

The image verification policy for signature validation.



97
98
99
# File 'lib/oci/container_engine/models/cluster.rb', line 97

def image_policy_config
  @image_policy_config
end

#kms_key_idString

The OCID of the KMS key to be used as the master encryption key for Kubernetes secret encryption.

Returns:

  • (String)


48
49
50
# File 'lib/oci/container_engine/models/cluster.rb', line 48

def kms_key_id
  @kms_key_id
end

#kubernetes_versionString

The version of Kubernetes running on the cluster masters.

Returns:

  • (String)


44
45
46
# File 'lib/oci/container_engine/models/cluster.rb', line 44

def kubernetes_version
  @kubernetes_version
end

#lifecycle_detailsString

Details about the state of the cluster masters.

Returns:

  • (String)


84
85
86
# File 'lib/oci/container_engine/models/cluster.rb', line 84

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

The state of the cluster masters.

Returns:

  • (String)


80
81
82
# File 'lib/oci/container_engine/models/cluster.rb', line 80

def lifecycle_state
  @lifecycle_state
end

#metadataOCI::ContainerEngine::Models::ClusterMetadata

Metadata about the cluster.



76
77
78
# File 'lib/oci/container_engine/models/cluster.rb', line 76

def 
  @metadata
end

#nameString

The name of the cluster.

Returns:

  • (String)


27
28
29
# File 'lib/oci/container_engine/models/cluster.rb', line 27

def name
  @name
end

#optionsOCI::ContainerEngine::Models::ClusterCreateOptions

Optional attributes for the cluster.



72
73
74
# File 'lib/oci/container_engine/models/cluster.rb', line 72

def options
  @options
end

#system_tagsHash<String, Hash<String, Object>>

Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"free-tier-retained": "true"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


68
69
70
# File 'lib/oci/container_engine/models/cluster.rb', line 68

def system_tags
  @system_tags
end

#vcn_idString

The OCID of the virtual cloud network (VCN) in which the cluster exists.

Returns:

  • (String)


40
41
42
# File 'lib/oci/container_engine/models/cluster.rb', line 40

def vcn_id
  @vcn_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/oci/container_engine/models/cluster.rb', line 104

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'name': :'name',
    'compartment_id': :'compartmentId',
    'endpoint_config': :'endpointConfig',
    'vcn_id': :'vcnId',
    'kubernetes_version': :'kubernetesVersion',
    'kms_key_id': :'kmsKeyId',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags',
    'options': :'options',
    'metadata': :'metadata',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'endpoints': :'endpoints',
    'available_kubernetes_upgrades': :'availableKubernetesUpgrades',
    'image_policy_config': :'imagePolicyConfig',
    'cluster_pod_network_options': :'clusterPodNetworkOptions'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/oci/container_engine/models/cluster.rb', line 130

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'name': :'String',
    'compartment_id': :'String',
    'endpoint_config': :'OCI::ContainerEngine::Models::ClusterEndpointConfig',
    'vcn_id': :'String',
    'kubernetes_version': :'String',
    'kms_key_id': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>',
    'options': :'OCI::ContainerEngine::Models::ClusterCreateOptions',
    'metadata': :'OCI::ContainerEngine::Models::ClusterMetadata',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'endpoints': :'OCI::ContainerEngine::Models::ClusterEndpoints',
    'available_kubernetes_upgrades': :'Array<String>',
    'image_policy_config': :'OCI::ContainerEngine::Models::ImagePolicyConfig',
    'cluster_pod_network_options': :'Array<OCI::ContainerEngine::Models::ClusterPodNetworkOptionDetails>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'lib/oci/container_engine/models/cluster.rb', line 294

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    name == other.name &&
    compartment_id == other.compartment_id &&
    endpoint_config == other.endpoint_config &&
    vcn_id == other.vcn_id &&
    kubernetes_version == other.kubernetes_version &&
    kms_key_id == other.kms_key_id &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags &&
    options == other.options &&
     == other. &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    endpoints == other.endpoints &&
    available_kubernetes_upgrades == other.available_kubernetes_upgrades &&
    image_policy_config == other.image_policy_config &&
    cluster_pod_network_options == other.cluster_pod_network_options
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/oci/container_engine/models/cluster.rb', line 341

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


321
322
323
# File 'lib/oci/container_engine/models/cluster.rb', line 321

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



330
331
332
# File 'lib/oci/container_engine/models/cluster.rb', line 330

def hash
  [id, name, compartment_id, endpoint_config, vcn_id, kubernetes_version, kms_key_id, freeform_tags, defined_tags, system_tags, options, , lifecycle_state, lifecycle_details, endpoints, available_kubernetes_upgrades, image_policy_config, cluster_pod_network_options].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



374
375
376
377
378
379
380
381
382
383
# File 'lib/oci/container_engine/models/cluster.rb', line 374

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



368
369
370
# File 'lib/oci/container_engine/models/cluster.rb', line 368

def to_s
  to_hash.to_s
end