Class: OCI::ContainerEngine::Models::ClusterEndpoints
- Inherits:
-
Object
- Object
- OCI::ContainerEngine::Models::ClusterEndpoints
- Defined in:
- lib/oci/container_engine/models/cluster_endpoints.rb
Overview
The properties that define endpoints for a cluster.
Instance Attribute Summary collapse
-
#kubernetes ⇒ String
The non-native networking Kubernetes API server endpoint.
-
#private_endpoint ⇒ String
The private native networking Kubernetes API server endpoint.
-
#public_endpoint ⇒ String
The public native networking Kubernetes API server endpoint, if one was requested.
-
#vcn_hostname_endpoint ⇒ String
The FQDN assigned to the Kubernetes API private endpoint.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ClusterEndpoints
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ClusterEndpoints
Initializes the object
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/oci/container_engine/models/cluster_endpoints.rb', line 62 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.kubernetes = attributes[:'kubernetes'] if attributes[:'kubernetes'] self.public_endpoint = attributes[:'publicEndpoint'] if attributes[:'publicEndpoint'] raise 'You cannot provide both :publicEndpoint and :public_endpoint' if attributes.key?(:'publicEndpoint') && attributes.key?(:'public_endpoint') self.public_endpoint = attributes[:'public_endpoint'] if attributes[:'public_endpoint'] self.private_endpoint = attributes[:'privateEndpoint'] if attributes[:'privateEndpoint'] raise 'You cannot provide both :privateEndpoint and :private_endpoint' if attributes.key?(:'privateEndpoint') && attributes.key?(:'private_endpoint') self.private_endpoint = attributes[:'private_endpoint'] if attributes[:'private_endpoint'] self.vcn_hostname_endpoint = attributes[:'vcnHostnameEndpoint'] if attributes[:'vcnHostnameEndpoint'] raise 'You cannot provide both :vcnHostnameEndpoint and :vcn_hostname_endpoint' if attributes.key?(:'vcnHostnameEndpoint') && attributes.key?(:'vcn_hostname_endpoint') self.vcn_hostname_endpoint = attributes[:'vcn_hostname_endpoint'] if attributes[:'vcn_hostname_endpoint'] end |
Instance Attribute Details
#kubernetes ⇒ String
The non-native networking Kubernetes API server endpoint.
12 13 14 |
# File 'lib/oci/container_engine/models/cluster_endpoints.rb', line 12 def kubernetes @kubernetes end |
#private_endpoint ⇒ String
The private native networking Kubernetes API server endpoint.
20 21 22 |
# File 'lib/oci/container_engine/models/cluster_endpoints.rb', line 20 def private_endpoint @private_endpoint end |
#public_endpoint ⇒ String
The public native networking Kubernetes API server endpoint, if one was requested.
16 17 18 |
# File 'lib/oci/container_engine/models/cluster_endpoints.rb', line 16 def public_endpoint @public_endpoint end |
#vcn_hostname_endpoint ⇒ String
The FQDN assigned to the Kubernetes API private endpoint. Example: 'yourVcnHostnameEndpoint'
26 27 28 |
# File 'lib/oci/container_engine/models/cluster_endpoints.rb', line 26 def vcn_hostname_endpoint @vcn_hostname_endpoint end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 36 37 38 |
# File 'lib/oci/container_engine/models/cluster_endpoints.rb', line 29 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'kubernetes': :'kubernetes', 'public_endpoint': :'publicEndpoint', 'private_endpoint': :'privateEndpoint', 'vcn_hostname_endpoint': :'vcnHostnameEndpoint' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
41 42 43 44 45 46 47 48 49 50 |
# File 'lib/oci/container_engine/models/cluster_endpoints.rb', line 41 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'kubernetes': :'String', 'public_endpoint': :'String', 'private_endpoint': :'String', 'vcn_hostname_endpoint': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
96 97 98 99 100 101 102 103 104 |
# File 'lib/oci/container_engine/models/cluster_endpoints.rb', line 96 def ==(other) return true if equal?(other) self.class == other.class && kubernetes == other.kubernetes && public_endpoint == other.public_endpoint && private_endpoint == other.private_endpoint && vcn_hostname_endpoint == other.vcn_hostname_endpoint end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/oci/container_engine/models/cluster_endpoints.rb', line 129 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
109 110 111 |
# File 'lib/oci/container_engine/models/cluster_endpoints.rb', line 109 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
118 119 120 |
# File 'lib/oci/container_engine/models/cluster_endpoints.rb', line 118 def hash [kubernetes, public_endpoint, private_endpoint, vcn_hostname_endpoint].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
162 163 164 165 166 167 168 169 170 171 |
# File 'lib/oci/container_engine/models/cluster_endpoints.rb', line 162 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
156 157 158 |
# File 'lib/oci/container_engine/models/cluster_endpoints.rb', line 156 def to_s to_hash.to_s end |