Class: OCI::ContainerEngine::Models::ClusterPodNetworkOptionDetails
- Inherits:
-
Object
- Object
- OCI::ContainerEngine::Models::ClusterPodNetworkOptionDetails
- Defined in:
- lib/oci/container_engine/models/cluster_pod_network_option_details.rb
Overview
The CNI type and relevant network details potentially applicable to the node pools of the cluster This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
FlannelOverlayClusterPodNetworkOptionDetails, OciVcnIpNativeClusterPodNetworkOptionDetails
Constant Summary collapse
- CNI_TYPE_ENUM =
[ CNI_TYPE_OCI_VCN_IP_NATIVE = 'OCI_VCN_IP_NATIVE'.freeze, CNI_TYPE_FLANNEL_OVERLAY = 'FLANNEL_OVERLAY'.freeze, CNI_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#cni_type ⇒ String
**[Required]** The CNI used by the node pools of this cluster.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ClusterPodNetworkOptionDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ClusterPodNetworkOptionDetails
Initializes the object
63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/oci/container_engine/models/cluster_pod_network_option_details.rb', line 63 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.cni_type = attributes[:'cniType'] if attributes[:'cniType'] raise 'You cannot provide both :cniType and :cni_type' if attributes.key?(:'cniType') && attributes.key?(:'cni_type') self.cni_type = attributes[:'cni_type'] if attributes[:'cni_type'] end |
Instance Attribute Details
#cni_type ⇒ String
**[Required]** The CNI used by the node pools of this cluster
20 21 22 |
# File 'lib/oci/container_engine/models/cluster_pod_network_option_details.rb', line 20 def cni_type @cni_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
23 24 25 26 27 28 29 |
# File 'lib/oci/container_engine/models/cluster_pod_network_option_details.rb', line 23 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'cni_type': :'cniType' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
45 46 47 48 49 50 51 52 53 |
# File 'lib/oci/container_engine/models/cluster_pod_network_option_details.rb', line 45 def self.get_subtype(object_hash) type = object_hash[:'cniType'] # rubocop:disable Style/SymbolLiteral return 'OCI::ContainerEngine::Models::FlannelOverlayClusterPodNetworkOptionDetails' if type == 'FLANNEL_OVERLAY' return 'OCI::ContainerEngine::Models::OciVcnIpNativeClusterPodNetworkOptionDetails' if type == 'OCI_VCN_IP_NATIVE' # TODO: Log a warning when the subtype is not found. 'OCI::ContainerEngine::Models::ClusterPodNetworkOptionDetails' end |
.swagger_types ⇒ Object
Attribute type mapping.
32 33 34 35 36 37 38 |
# File 'lib/oci/container_engine/models/cluster_pod_network_option_details.rb', line 32 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'cni_type': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
96 97 98 99 100 101 |
# File 'lib/oci/container_engine/models/cluster_pod_network_option_details.rb', line 96 def ==(other) return true if equal?(other) self.class == other.class && cni_type == other.cni_type end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/oci/container_engine/models/cluster_pod_network_option_details.rb', line 126 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
106 107 108 |
# File 'lib/oci/container_engine/models/cluster_pod_network_option_details.rb', line 106 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
115 116 117 |
# File 'lib/oci/container_engine/models/cluster_pod_network_option_details.rb', line 115 def hash [cni_type].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
159 160 161 162 163 164 165 166 167 168 |
# File 'lib/oci/container_engine/models/cluster_pod_network_option_details.rb', line 159 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
153 154 155 |
# File 'lib/oci/container_engine/models/cluster_pod_network_option_details.rb', line 153 def to_s to_hash.to_s end |