Class: OCI::ContainerEngine::Models::CreateClusterKubeconfigContentDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/container_engine/models/create_cluster_kubeconfig_content_details.rb

Overview

The properties that define a request to create a cluster kubeconfig.

Constant Summary collapse

ENDPOINT_ENUM =
[
  ENDPOINT_LEGACY_KUBERNETES = 'LEGACY_KUBERNETES'.freeze,
  ENDPOINT_PUBLIC_ENDPOINT = 'PUBLIC_ENDPOINT'.freeze,
  ENDPOINT_PRIVATE_ENDPOINT = 'PRIVATE_ENDPOINT'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateClusterKubeconfigContentDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :token_version (String)

    The value to assign to the #token_version property

  • :expiration (Integer)

    The value to assign to the #expiration property

  • :endpoint (String)

    The value to assign to the #endpoint property



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/oci/container_engine/models/create_cluster_kubeconfig_content_details.rb', line 61

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.token_version = attributes[:'tokenVersion'] if attributes[:'tokenVersion']
  self.token_version = "2.0.0" if token_version.nil? && !attributes.key?(:'tokenVersion') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :tokenVersion and :token_version' if attributes.key?(:'tokenVersion') && attributes.key?(:'token_version')

  self.token_version = attributes[:'token_version'] if attributes[:'token_version']
  self.token_version = "2.0.0" if token_version.nil? && !attributes.key?(:'tokenVersion') && !attributes.key?(:'token_version') # rubocop:disable Style/StringLiterals

  self.expiration = attributes[:'expiration'] if attributes[:'expiration']

  self.endpoint = attributes[:'endpoint'] if attributes[:'endpoint']
end

Instance Attribute Details

#endpointString

The endpoint to target. A cluster may have multiple endpoints exposed but the kubeconfig can only target one at a time.

Returns:

  • (String)


28
29
30
# File 'lib/oci/container_engine/models/create_cluster_kubeconfig_content_details.rb', line 28

def endpoint
  @endpoint
end

#expirationInteger

Deprecated. This field is no longer used.

Returns:

  • (Integer)


24
25
26
# File 'lib/oci/container_engine/models/create_cluster_kubeconfig_content_details.rb', line 24

def expiration
  @expiration
end

#token_versionString

The version of the kubeconfig token. Supported value 2.0.0

Returns:

  • (String)


19
20
21
# File 'lib/oci/container_engine/models/create_cluster_kubeconfig_content_details.rb', line 19

def token_version
  @token_version
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
# File 'lib/oci/container_engine/models/create_cluster_kubeconfig_content_details.rb', line 31

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'token_version': :'tokenVersion',
    'expiration': :'expiration',
    'endpoint': :'endpoint'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



42
43
44
45
46
47
48
49
50
# File 'lib/oci/container_engine/models/create_cluster_kubeconfig_content_details.rb', line 42

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'token_version': :'String',
    'expiration': :'Integer',
    'endpoint': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



95
96
97
98
99
100
101
102
# File 'lib/oci/container_engine/models/create_cluster_kubeconfig_content_details.rb', line 95

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    token_version == other.token_version &&
    expiration == other.expiration &&
    endpoint == other.endpoint
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/oci/container_engine/models/create_cluster_kubeconfig_content_details.rb', line 127

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


107
108
109
# File 'lib/oci/container_engine/models/create_cluster_kubeconfig_content_details.rb', line 107

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



116
117
118
# File 'lib/oci/container_engine/models/create_cluster_kubeconfig_content_details.rb', line 116

def hash
  [token_version, expiration, endpoint].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



160
161
162
163
164
165
166
167
168
169
# File 'lib/oci/container_engine/models/create_cluster_kubeconfig_content_details.rb', line 160

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



154
155
156
# File 'lib/oci/container_engine/models/create_cluster_kubeconfig_content_details.rb', line 154

def to_s
  to_hash.to_s
end