Class: OCI::ContainerEngine::Models::NodeEvictionNodePoolSettings

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/container_engine/models/node_eviction_node_pool_settings.rb

Overview

Node Eviction Details configuration

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ NodeEvictionNodePoolSettings

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/oci/container_engine/models/node_eviction_node_pool_settings.rb', line 48

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.eviction_grace_duration = attributes[:'evictionGraceDuration'] if attributes[:'evictionGraceDuration']

  raise 'You cannot provide both :evictionGraceDuration and :eviction_grace_duration' if attributes.key?(:'evictionGraceDuration') && attributes.key?(:'eviction_grace_duration')

  self.eviction_grace_duration = attributes[:'eviction_grace_duration'] if attributes[:'eviction_grace_duration']

  self.is_force_delete_after_grace_duration = attributes[:'isForceDeleteAfterGraceDuration'] unless attributes[:'isForceDeleteAfterGraceDuration'].nil?
  self.is_force_delete_after_grace_duration = false if is_force_delete_after_grace_duration.nil? && !attributes.key?(:'isForceDeleteAfterGraceDuration') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isForceDeleteAfterGraceDuration and :is_force_delete_after_grace_duration' if attributes.key?(:'isForceDeleteAfterGraceDuration') && attributes.key?(:'is_force_delete_after_grace_duration')

  self.is_force_delete_after_grace_duration = attributes[:'is_force_delete_after_grace_duration'] unless attributes[:'is_force_delete_after_grace_duration'].nil?
  self.is_force_delete_after_grace_duration = false if is_force_delete_after_grace_duration.nil? && !attributes.key?(:'isForceDeleteAfterGraceDuration') && !attributes.key?(:'is_force_delete_after_grace_duration') # rubocop:disable Style/StringLiterals
end

Instance Attribute Details

#eviction_grace_durationString

Duration after which OKE will give up eviction of the pods on the node. PT0M will indicate you want to delete the node without cordon and drain. Default PT60M, Min PT0M, Max: PT60M. Format ISO 8601 e.g PT30M

Returns:

  • (String)


14
15
16
# File 'lib/oci/container_engine/models/node_eviction_node_pool_settings.rb', line 14

def eviction_grace_duration
  @eviction_grace_duration
end

#is_force_delete_after_grace_durationBOOLEAN

If the underlying compute instance should be deleted if you cannot evict all the pods in grace period

Returns:

  • (BOOLEAN)


18
19
20
# File 'lib/oci/container_engine/models/node_eviction_node_pool_settings.rb', line 18

def is_force_delete_after_grace_duration
  @is_force_delete_after_grace_duration
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



21
22
23
24
25
26
27
28
# File 'lib/oci/container_engine/models/node_eviction_node_pool_settings.rb', line 21

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'eviction_grace_duration': :'evictionGraceDuration',
    'is_force_delete_after_grace_duration': :'isForceDeleteAfterGraceDuration'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



31
32
33
34
35
36
37
38
# File 'lib/oci/container_engine/models/node_eviction_node_pool_settings.rb', line 31

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'eviction_grace_duration': :'String',
    'is_force_delete_after_grace_duration': :'BOOLEAN'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



76
77
78
79
80
81
82
# File 'lib/oci/container_engine/models/node_eviction_node_pool_settings.rb', line 76

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    eviction_grace_duration == other.eviction_grace_duration &&
    is_force_delete_after_grace_duration == other.is_force_delete_after_grace_duration
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/oci/container_engine/models/node_eviction_node_pool_settings.rb', line 107

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


87
88
89
# File 'lib/oci/container_engine/models/node_eviction_node_pool_settings.rb', line 87

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



96
97
98
# File 'lib/oci/container_engine/models/node_eviction_node_pool_settings.rb', line 96

def hash
  [eviction_grace_duration, is_force_delete_after_grace_duration].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



140
141
142
143
144
145
146
147
148
149
# File 'lib/oci/container_engine/models/node_eviction_node_pool_settings.rb', line 140

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



134
135
136
# File 'lib/oci/container_engine/models/node_eviction_node_pool_settings.rb', line 134

def to_s
  to_hash.to_s
end