Class: OCI::ContainerEngine::Models::NodePoolNodeConfigDetails
- Inherits:
-
Object
- Object
- OCI::ContainerEngine::Models::NodePoolNodeConfigDetails
- Defined in:
- lib/oci/container_engine/models/node_pool_node_config_details.rb
Overview
The size and placement configuration of nodes in the node pool.
Instance Attribute Summary collapse
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#is_pv_encryption_in_transit_enabled ⇒ BOOLEAN
Whether to enable in-transit encryption for the data volume’s paravirtualized attachment.
-
#kms_key_id ⇒ String
The OCID of the Key Management Service key assigned to the boot volume.
-
#nsg_ids ⇒ Array<String>
The OCIDs of the Network Security Group(s) to associate nodes for this node pool with.
-
#placement_configs ⇒ Array<OCI::ContainerEngine::Models::NodePoolPlacementConfigDetails>
The placement configurations for the node pool.
-
#size ⇒ Integer
The number of nodes in the node pool.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NodePoolNodeConfigDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ NodePoolNodeConfigDetails
Initializes the object
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/oci/container_engine/models/node_pool_node_config_details.rb', line 95 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.size = attributes[:'size'] if attributes[:'size'] self.nsg_ids = attributes[:'nsgIds'] if attributes[:'nsgIds'] raise 'You cannot provide both :nsgIds and :nsg_ids' if attributes.key?(:'nsgIds') && attributes.key?(:'nsg_ids') self.nsg_ids = attributes[:'nsg_ids'] if attributes[:'nsg_ids'] self.kms_key_id = attributes[:'kmsKeyId'] if attributes[:'kmsKeyId'] raise 'You cannot provide both :kmsKeyId and :kms_key_id' if attributes.key?(:'kmsKeyId') && attributes.key?(:'kms_key_id') self.kms_key_id = attributes[:'kms_key_id'] if attributes[:'kms_key_id'] self.is_pv_encryption_in_transit_enabled = attributes[:'isPvEncryptionInTransitEnabled'] unless attributes[:'isPvEncryptionInTransitEnabled'].nil? self.is_pv_encryption_in_transit_enabled = false if is_pv_encryption_in_transit_enabled.nil? && !attributes.key?(:'isPvEncryptionInTransitEnabled') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isPvEncryptionInTransitEnabled and :is_pv_encryption_in_transit_enabled' if attributes.key?(:'isPvEncryptionInTransitEnabled') && attributes.key?(:'is_pv_encryption_in_transit_enabled') self.is_pv_encryption_in_transit_enabled = attributes[:'is_pv_encryption_in_transit_enabled'] unless attributes[:'is_pv_encryption_in_transit_enabled'].nil? self.is_pv_encryption_in_transit_enabled = false if is_pv_encryption_in_transit_enabled.nil? && !attributes.key?(:'isPvEncryptionInTransitEnabled') && !attributes.key?(:'is_pv_encryption_in_transit_enabled') # rubocop:disable Style/StringLiterals self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.placement_configs = attributes[:'placementConfigs'] if attributes[:'placementConfigs'] raise 'You cannot provide both :placementConfigs and :placement_configs' if attributes.key?(:'placementConfigs') && attributes.key?(:'placement_configs') self.placement_configs = attributes[:'placement_configs'] if attributes[:'placement_configs'] end |
Instance Attribute Details
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"CostCenter": "42"}`
40 41 42 |
# File 'lib/oci/container_engine/models/node_pool_node_config_details.rb', line 40 def end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"Finance"`
33 34 35 |
# File 'lib/oci/container_engine/models/node_pool_node_config_details.rb', line 33 def end |
#is_pv_encryption_in_transit_enabled ⇒ BOOLEAN
Whether to enable in-transit encryption for the data volume’s paravirtualized attachment. This field applies to both block volumes and boot volumes. The default value is false.
26 27 28 |
# File 'lib/oci/container_engine/models/node_pool_node_config_details.rb', line 26 def is_pv_encryption_in_transit_enabled @is_pv_encryption_in_transit_enabled end |
#kms_key_id ⇒ String
The OCID of the Key Management Service key assigned to the boot volume.
22 23 24 |
# File 'lib/oci/container_engine/models/node_pool_node_config_details.rb', line 22 def kms_key_id @kms_key_id end |
#nsg_ids ⇒ Array<String>
The OCIDs of the Network Security Group(s) to associate nodes for this node pool with. For more information about NSGs, see NetworkSecurityGroup.
18 19 20 |
# File 'lib/oci/container_engine/models/node_pool_node_config_details.rb', line 18 def nsg_ids @nsg_ids end |
#placement_configs ⇒ Array<OCI::ContainerEngine::Models::NodePoolPlacementConfigDetails>
The placement configurations for the node pool. Provide one placement configuration for each availability domain in which you intend to launch a node.
To use the node pool with a regional subnet, provide a placement configuration for each availability domain, and include the regional subnet in each placement configuration.
50 51 52 |
# File 'lib/oci/container_engine/models/node_pool_node_config_details.rb', line 50 def placement_configs @placement_configs end |
#size ⇒ Integer
The number of nodes in the node pool.
13 14 15 |
# File 'lib/oci/container_engine/models/node_pool_node_config_details.rb', line 13 def size @size end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/oci/container_engine/models/node_pool_node_config_details.rb', line 53 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'size': :'size', 'nsg_ids': :'nsgIds', 'kms_key_id': :'kmsKeyId', 'is_pv_encryption_in_transit_enabled': :'isPvEncryptionInTransitEnabled', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'placement_configs': :'placementConfigs' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/oci/container_engine/models/node_pool_node_config_details.rb', line 68 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'size': :'Integer', 'nsg_ids': :'Array<String>', 'kms_key_id': :'String', 'is_pv_encryption_in_transit_enabled': :'BOOLEAN', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'placement_configs': :'Array<OCI::ContainerEngine::Models::NodePoolPlacementConfigDetails>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/oci/container_engine/models/node_pool_node_config_details.rb', line 149 def ==(other) return true if equal?(other) self.class == other.class && size == other.size && nsg_ids == other.nsg_ids && kms_key_id == other.kms_key_id && is_pv_encryption_in_transit_enabled == other.is_pv_encryption_in_transit_enabled && == other. && == other. && placement_configs == other.placement_configs end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/oci/container_engine/models/node_pool_node_config_details.rb', line 185 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
165 166 167 |
# File 'lib/oci/container_engine/models/node_pool_node_config_details.rb', line 165 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
174 175 176 |
# File 'lib/oci/container_engine/models/node_pool_node_config_details.rb', line 174 def hash [size, nsg_ids, kms_key_id, is_pv_encryption_in_transit_enabled, , , placement_configs].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
218 219 220 221 222 223 224 225 226 227 |
# File 'lib/oci/container_engine/models/node_pool_node_config_details.rb', line 218 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
212 213 214 |
# File 'lib/oci/container_engine/models/node_pool_node_config_details.rb', line 212 def to_s to_hash.to_s end |