Class: OCI::ContainerEngine::Models::OciVcnIpNativeNodePoolPodNetworkOptionDetails

Inherits:
NodePoolPodNetworkOptionDetails show all
Defined in:
lib/oci/container_engine/models/oci_vcn_ip_native_node_pool_pod_network_option_details.rb

Overview

Network options specific to using the OCI VCN Native CNI

Constant Summary

Constants inherited from NodePoolPodNetworkOptionDetails

NodePoolPodNetworkOptionDetails::CNI_TYPE_ENUM

Instance Attribute Summary collapse

Attributes inherited from NodePoolPodNetworkOptionDetails

#cni_type

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from NodePoolPodNetworkOptionDetails

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ OciVcnIpNativeNodePoolPodNetworkOptionDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :max_pods_per_node (Integer)

    The value to assign to the #max_pods_per_node property

  • :pod_nsg_ids (Array<String>)

    The value to assign to the #pod_nsg_ids property

  • :pod_subnet_ids (Array<String>)

    The value to assign to the #pod_subnet_ids property



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/oci/container_engine/models/oci_vcn_ip_native_node_pool_pod_network_option_details.rb', line 59

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['cniType'] = 'OCI_VCN_IP_NATIVE'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.max_pods_per_node = attributes[:'maxPodsPerNode'] if attributes[:'maxPodsPerNode']
  self.max_pods_per_node = 31 if max_pods_per_node.nil? && !attributes.key?(:'maxPodsPerNode') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :maxPodsPerNode and :max_pods_per_node' if attributes.key?(:'maxPodsPerNode') && attributes.key?(:'max_pods_per_node')

  self.max_pods_per_node = attributes[:'max_pods_per_node'] if attributes[:'max_pods_per_node']
  self.max_pods_per_node = 31 if max_pods_per_node.nil? && !attributes.key?(:'maxPodsPerNode') && !attributes.key?(:'max_pods_per_node') # rubocop:disable Style/StringLiterals

  self.pod_nsg_ids = attributes[:'podNsgIds'] if attributes[:'podNsgIds']

  raise 'You cannot provide both :podNsgIds and :pod_nsg_ids' if attributes.key?(:'podNsgIds') && attributes.key?(:'pod_nsg_ids')

  self.pod_nsg_ids = attributes[:'pod_nsg_ids'] if attributes[:'pod_nsg_ids']

  self.pod_subnet_ids = attributes[:'podSubnetIds'] if attributes[:'podSubnetIds']

  raise 'You cannot provide both :podSubnetIds and :pod_subnet_ids' if attributes.key?(:'podSubnetIds') && attributes.key?(:'pod_subnet_ids')

  self.pod_subnet_ids = attributes[:'pod_subnet_ids'] if attributes[:'pod_subnet_ids']
end

Instance Attribute Details

#max_pods_per_nodeInteger

The max number of pods per node in the node pool. This value will be limited by the number of VNICs attachable to the node pool shape

Returns:

  • (Integer)


14
15
16
# File 'lib/oci/container_engine/models/oci_vcn_ip_native_node_pool_pod_network_option_details.rb', line 14

def max_pods_per_node
  @max_pods_per_node
end

#pod_nsg_idsArray<String>

The OCIDs of the Network Security Group(s) to associate pods for this node pool with. For more information about NSGs, see NetworkSecurityGroup.

Returns:

  • (Array<String>)


19
20
21
# File 'lib/oci/container_engine/models/oci_vcn_ip_native_node_pool_pod_network_option_details.rb', line 19

def pod_nsg_ids
  @pod_nsg_ids
end

#pod_subnet_idsArray<String>

**[Required]** The OCIDs of the subnets in which to place pods for this node pool. This can be one of the node pool subnet IDs

Returns:

  • (Array<String>)


24
25
26
# File 'lib/oci/container_engine/models/oci_vcn_ip_native_node_pool_pod_network_option_details.rb', line 24

def pod_subnet_ids
  @pod_subnet_ids
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



27
28
29
30
31
32
33
34
35
36
# File 'lib/oci/container_engine/models/oci_vcn_ip_native_node_pool_pod_network_option_details.rb', line 27

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'cni_type': :'cniType',
    'max_pods_per_node': :'maxPodsPerNode',
    'pod_nsg_ids': :'podNsgIds',
    'pod_subnet_ids': :'podSubnetIds'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



39
40
41
42
43
44
45
46
47
48
# File 'lib/oci/container_engine/models/oci_vcn_ip_native_node_pool_pod_network_option_details.rb', line 39

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'cni_type': :'String',
    'max_pods_per_node': :'Integer',
    'pod_nsg_ids': :'Array<String>',
    'pod_subnet_ids': :'Array<String>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



97
98
99
100
101
102
103
104
105
# File 'lib/oci/container_engine/models/oci_vcn_ip_native_node_pool_pod_network_option_details.rb', line 97

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    cni_type == other.cni_type &&
    max_pods_per_node == other.max_pods_per_node &&
    pod_nsg_ids == other.pod_nsg_ids &&
    pod_subnet_ids == other.pod_subnet_ids
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/oci/container_engine/models/oci_vcn_ip_native_node_pool_pod_network_option_details.rb', line 130

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


110
111
112
# File 'lib/oci/container_engine/models/oci_vcn_ip_native_node_pool_pod_network_option_details.rb', line 110

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



119
120
121
# File 'lib/oci/container_engine/models/oci_vcn_ip_native_node_pool_pod_network_option_details.rb', line 119

def hash
  [cni_type, max_pods_per_node, pod_nsg_ids, pod_subnet_ids].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



163
164
165
166
167
168
169
170
171
172
# File 'lib/oci/container_engine/models/oci_vcn_ip_native_node_pool_pod_network_option_details.rb', line 163

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



157
158
159
# File 'lib/oci/container_engine/models/oci_vcn_ip_native_node_pool_pod_network_option_details.rb', line 157

def to_s
  to_hash.to_s
end