Class: OCI::ContainerEngine::Models::UpdateClusterDetails
- Inherits:
-
Object
- Object
- OCI::ContainerEngine::Models::UpdateClusterDetails
- Defined in:
- lib/oci/container_engine/models/update_cluster_details.rb
Overview
The properties that define a request to update a cluster.
Instance Attribute Summary collapse
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#image_policy_config ⇒ OCI::ContainerEngine::Models::UpdateImagePolicyConfigDetails
The image verification policy for signature validation.
-
#kubernetes_version ⇒ String
The version of Kubernetes to which the cluster masters should be upgraded.
-
#name ⇒ String
The new name for the cluster.
- #options ⇒ OCI::ContainerEngine::Models::UpdateClusterOptionsDetails
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateClusterDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateClusterDetails
Initializes the object
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/oci/container_engine/models/update_cluster_details.rb', line 82 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.kubernetes_version = attributes[:'kubernetesVersion'] if attributes[:'kubernetesVersion'] raise 'You cannot provide both :kubernetesVersion and :kubernetes_version' if attributes.key?(:'kubernetesVersion') && attributes.key?(:'kubernetes_version') self.kubernetes_version = attributes[:'kubernetes_version'] if attributes[:'kubernetes_version'] self. = attributes[:'options'] if attributes[:'options'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.image_policy_config = attributes[:'imagePolicyConfig'] if attributes[:'imagePolicyConfig'] raise 'You cannot provide both :imagePolicyConfig and :image_policy_config' if attributes.key?(:'imagePolicyConfig') && attributes.key?(:'image_policy_config') self.image_policy_config = attributes[:'image_policy_config'] if attributes[:'image_policy_config'] end |
Instance Attribute Details
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"CostCenter": "42"}`
33 34 35 |
# File 'lib/oci/container_engine/models/update_cluster_details.rb', line 33 def @defined_tags end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"Finance"`
26 27 28 |
# File 'lib/oci/container_engine/models/update_cluster_details.rb', line 26 def @freeform_tags end |
#image_policy_config ⇒ OCI::ContainerEngine::Models::UpdateImagePolicyConfigDetails
The image verification policy for signature validation. Once a policy is created and enabled with one or more kms keys, the policy will ensure all images deployed has been signed with the key(s) attached to the policy.
40 41 42 |
# File 'lib/oci/container_engine/models/update_cluster_details.rb', line 40 def image_policy_config @image_policy_config end |
#kubernetes_version ⇒ String
The version of Kubernetes to which the cluster masters should be upgraded.
16 17 18 |
# File 'lib/oci/container_engine/models/update_cluster_details.rb', line 16 def kubernetes_version @kubernetes_version end |
#name ⇒ String
The new name for the cluster. Avoid entering confidential information.
12 13 14 |
# File 'lib/oci/container_engine/models/update_cluster_details.rb', line 12 def name @name end |
#options ⇒ OCI::ContainerEngine::Models::UpdateClusterOptionsDetails
19 20 21 |
# File 'lib/oci/container_engine/models/update_cluster_details.rb', line 19 def @options end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/oci/container_engine/models/update_cluster_details.rb', line 43 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'kubernetes_version': :'kubernetesVersion', 'options': :'options', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'image_policy_config': :'imagePolicyConfig' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/oci/container_engine/models/update_cluster_details.rb', line 57 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'kubernetes_version': :'String', 'options': :'OCI::ContainerEngine::Models::UpdateClusterOptionsDetails', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'image_policy_config': :'OCI::ContainerEngine::Models::UpdateImagePolicyConfigDetails' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/oci/container_engine/models/update_cluster_details.rb', line 124 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && kubernetes_version == other.kubernetes_version && == other. && == other. && == other. && image_policy_config == other.image_policy_config end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/oci/container_engine/models/update_cluster_details.rb', line 159 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
139 140 141 |
# File 'lib/oci/container_engine/models/update_cluster_details.rb', line 139 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
148 149 150 |
# File 'lib/oci/container_engine/models/update_cluster_details.rb', line 148 def hash [name, kubernetes_version, , , , image_policy_config].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
192 193 194 195 196 197 198 199 200 201 |
# File 'lib/oci/container_engine/models/update_cluster_details.rb', line 192 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
186 187 188 |
# File 'lib/oci/container_engine/models/update_cluster_details.rb', line 186 def to_s to_hash.to_s end |