Class: OCI::ContainerEngine::Models::UpdateNodePoolNodeConfigDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/container_engine/models/update_node_pool_node_config_details.rb

Overview

The size and placement configuration of nodes in the node pool.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateNodePoolNodeConfigDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/oci/container_engine/models/update_node_pool_node_config_details.rb', line 75

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.size = attributes[:'size'] if attributes[:'size']

  self.nsg_ids = attributes[:'nsgIds'] if attributes[:'nsgIds']

  raise 'You cannot provide both :nsgIds and :nsg_ids' if attributes.key?(:'nsgIds') && attributes.key?(:'nsg_ids')

  self.nsg_ids = attributes[:'nsg_ids'] if attributes[:'nsg_ids']

  self.kms_key_id = attributes[:'kmsKeyId'] if attributes[:'kmsKeyId']

  raise 'You cannot provide both :kmsKeyId and :kms_key_id' if attributes.key?(:'kmsKeyId') && attributes.key?(:'kms_key_id')

  self.kms_key_id = attributes[:'kms_key_id'] if attributes[:'kms_key_id']

  self.is_pv_encryption_in_transit_enabled = attributes[:'isPvEncryptionInTransitEnabled'] unless attributes[:'isPvEncryptionInTransitEnabled'].nil?
  self.is_pv_encryption_in_transit_enabled = false if is_pv_encryption_in_transit_enabled.nil? && !attributes.key?(:'isPvEncryptionInTransitEnabled') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isPvEncryptionInTransitEnabled and :is_pv_encryption_in_transit_enabled' if attributes.key?(:'isPvEncryptionInTransitEnabled') && attributes.key?(:'is_pv_encryption_in_transit_enabled')

  self.is_pv_encryption_in_transit_enabled = attributes[:'is_pv_encryption_in_transit_enabled'] unless attributes[:'is_pv_encryption_in_transit_enabled'].nil?
  self.is_pv_encryption_in_transit_enabled = false if is_pv_encryption_in_transit_enabled.nil? && !attributes.key?(:'isPvEncryptionInTransitEnabled') && !attributes.key?(:'is_pv_encryption_in_transit_enabled') # rubocop:disable Style/StringLiterals

  self.placement_configs = attributes[:'placementConfigs'] if attributes[:'placementConfigs']

  raise 'You cannot provide both :placementConfigs and :placement_configs' if attributes.key?(:'placementConfigs') && attributes.key?(:'placement_configs')

  self.placement_configs = attributes[:'placement_configs'] if attributes[:'placement_configs']
end

Instance Attribute Details

#is_pv_encryption_in_transit_enabledBOOLEAN

Whether to enable in-transit encryption for the data volume’s paravirtualized attachment. This field applies to both block volumes and boot volumes. The default value is false.

Returns:

  • (BOOLEAN)


26
27
28
# File 'lib/oci/container_engine/models/update_node_pool_node_config_details.rb', line 26

def is_pv_encryption_in_transit_enabled
  @is_pv_encryption_in_transit_enabled
end

#kms_key_idString

The OCID of the Key Management Service key assigned to the boot volume.

Returns:

  • (String)


22
23
24
# File 'lib/oci/container_engine/models/update_node_pool_node_config_details.rb', line 22

def kms_key_id
  @kms_key_id
end

#nsg_idsArray<String>

The OCIDs of the Network Security Group(s) to associate nodes for this node pool with. For more information about NSGs, see NetworkSecurityGroup.

Returns:

  • (Array<String>)


18
19
20
# File 'lib/oci/container_engine/models/update_node_pool_node_config_details.rb', line 18

def nsg_ids
  @nsg_ids
end

#placement_configsArray<OCI::ContainerEngine::Models::NodePoolPlacementConfigDetails>

The placement configurations for the node pool. Provide one placement configuration for each availability domain in which you intend to launch a node.

To use the node pool with a regional subnet, provide a placement configuration for each availability domain, and include the regional subnet in each placement configuration.



36
37
38
# File 'lib/oci/container_engine/models/update_node_pool_node_config_details.rb', line 36

def placement_configs
  @placement_configs
end

#sizeInteger

The number of nodes in the node pool.

Returns:

  • (Integer)


13
14
15
# File 'lib/oci/container_engine/models/update_node_pool_node_config_details.rb', line 13

def size
  @size
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



39
40
41
42
43
44
45
46
47
48
49
# File 'lib/oci/container_engine/models/update_node_pool_node_config_details.rb', line 39

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'size': :'size',
    'nsg_ids': :'nsgIds',
    'kms_key_id': :'kmsKeyId',
    'is_pv_encryption_in_transit_enabled': :'isPvEncryptionInTransitEnabled',
    'placement_configs': :'placementConfigs'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



52
53
54
55
56
57
58
59
60
61
62
# File 'lib/oci/container_engine/models/update_node_pool_node_config_details.rb', line 52

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'size': :'Integer',
    'nsg_ids': :'Array<String>',
    'kms_key_id': :'String',
    'is_pv_encryption_in_transit_enabled': :'BOOLEAN',
    'placement_configs': :'Array<OCI::ContainerEngine::Models::NodePoolPlacementConfigDetails>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



117
118
119
120
121
122
123
124
125
126
# File 'lib/oci/container_engine/models/update_node_pool_node_config_details.rb', line 117

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    size == other.size &&
    nsg_ids == other.nsg_ids &&
    kms_key_id == other.kms_key_id &&
    is_pv_encryption_in_transit_enabled == other.is_pv_encryption_in_transit_enabled &&
    placement_configs == other.placement_configs
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/oci/container_engine/models/update_node_pool_node_config_details.rb', line 151

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


131
132
133
# File 'lib/oci/container_engine/models/update_node_pool_node_config_details.rb', line 131

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



140
141
142
# File 'lib/oci/container_engine/models/update_node_pool_node_config_details.rb', line 140

def hash
  [size, nsg_ids, kms_key_id, is_pv_encryption_in_transit_enabled, placement_configs].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



184
185
186
187
188
189
190
191
192
193
# File 'lib/oci/container_engine/models/update_node_pool_node_config_details.rb', line 184

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



178
179
180
# File 'lib/oci/container_engine/models/update_node_pool_node_config_details.rb', line 178

def to_s
  to_hash.to_s
end