Class: OCI::Core::BlockstorageClient
- Inherits:
-
Object
- Object
- OCI::Core::BlockstorageClient
- Defined in:
- lib/oci/core/blockstorage_client.rb
Overview
APIs for Networking Service, Compute Service, and Block Volume Service.
Instance Attribute Summary collapse
-
#api_client ⇒ OCI::ApiClient
readonly
Client used to make HTTP requests.
-
#endpoint ⇒ String
readonly
Fully qualified endpoint URL.
-
#region ⇒ String
The region, which will usually correspond to a value in Regions::REGION_ENUM.
-
#retry_config ⇒ OCI::Retry::RetryConfig
readonly
The default retry configuration to apply to all operations in this service client.
Instance Method Summary collapse
-
#create_volume(create_volume_details, opts = {}) ⇒ Response
Creates a new volume in the specified compartment.
-
#create_volume_backup(create_volume_backup_details, opts = {}) ⇒ Response
Creates a new backup of the specified volume.
-
#create_volume_backup_policy_assignment(create_volume_backup_policy_assignment_details, opts = {}) ⇒ Response
Assigns a policy to the specified asset, such as a volume.
-
#create_volume_group(create_volume_group_details, opts = {}) ⇒ Response
Creates a new volume group in the specified compartment.
-
#create_volume_group_backup(create_volume_group_backup_details, opts = {}) ⇒ Response
Creates a new group backup of the specified volume group.
-
#delete_boot_volume(boot_volume_id, opts = {}) ⇒ Response
Deletes the specified boot volume.
-
#delete_volume(volume_id, opts = {}) ⇒ Response
Deletes the specified volume.
-
#delete_volume_backup(volume_backup_id, opts = {}) ⇒ Response
Deletes a volume backup.
-
#delete_volume_backup_policy_assignment(policy_assignment_id, opts = {}) ⇒ Response
Deletes a volume backup policy assignment (i.e. unassigns the policy from an asset).
-
#delete_volume_group(volume_group_id, opts = {}) ⇒ Response
Deletes the specified volume group.
-
#delete_volume_group_backup(volume_group_backup_id, opts = {}) ⇒ Response
Deletes a volume group backup.
-
#get_boot_volume(boot_volume_id, opts = {}) ⇒ Response
Gets information for the specified boot volume.
-
#get_volume(volume_id, opts = {}) ⇒ Response
Gets information for the specified volume.
-
#get_volume_backup(volume_backup_id, opts = {}) ⇒ Response
Gets information for the specified volume backup.
-
#get_volume_backup_policy(policy_id, opts = {}) ⇒ Response
Gets information for the specified volume backup policy.
-
#get_volume_backup_policy_asset_assignment(asset_id, opts = {}) ⇒ Response
Gets the volume backup policy assignment for the specified asset.
-
#get_volume_backup_policy_assignment(policy_assignment_id, opts = {}) ⇒ Response
Gets information for the specified volume backup policy assignment.
-
#get_volume_group(volume_group_id, opts = {}) ⇒ Response
Gets information for the specified volume group.
-
#get_volume_group_backup(volume_group_backup_id, opts = {}) ⇒ Response
Gets information for the specified volume group backup.
-
#initialize(config: nil, region: nil, signer: nil, proxy_settings: nil, retry_config: nil) ⇒ BlockstorageClient
constructor
Creates a new BlockstorageClient.
-
#list_boot_volumes(availability_domain, compartment_id, opts = {}) ⇒ Response
Lists the boot volumes in the specified compartment and Availability Domain.
-
#list_volume_backup_policies(opts = {}) ⇒ Response
Lists all volume backup policies available to the caller.
-
#list_volume_backups(compartment_id, opts = {}) ⇒ Response
Lists the volume backups in the specified compartment.
-
#list_volume_group_backups(compartment_id, opts = {}) ⇒ Response
Lists the backups for volume groups in the specified compartment.
-
#list_volume_groups(compartment_id, opts = {}) ⇒ Response
Lists the volume groups in the specified compartment and Availability Domain.
-
#list_volumes(compartment_id, opts = {}) ⇒ Response
Lists the volumes in the specified compartment and Availability Domain.
-
#logger ⇒ Logger
The logger for this client.
-
#update_boot_volume(boot_volume_id, update_boot_volume_details, opts = {}) ⇒ Response
Updates the specified boot volume’s display name.
-
#update_volume(volume_id, update_volume_details, opts = {}) ⇒ Response
Updates the specified volume’s display name.
-
#update_volume_backup(volume_backup_id, update_volume_backup_details, opts = {}) ⇒ Response
Updates the display name for the specified volume backup.
-
#update_volume_group(volume_group_id, update_volume_group_details, opts = {}) ⇒ Response
Updates the set of volumes in a volume group along with (optionally) it’s display name.
-
#update_volume_group_backup(volume_group_backup_id, update_volume_group_backup_details, opts = {}) ⇒ Response
Updates the display name for the specified volume group backup.
Constructor Details
#initialize(config: nil, region: nil, signer: nil, proxy_settings: nil, retry_config: nil) ⇒ BlockstorageClient
Creates a new BlockstorageClient. If a config is not specified, then the global OCI.config will be used.
A region must be specified in either the config or the region parameter. If specified in both, then the region parameter will be used.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/oci/core/blockstorage_client.rb', line 48 def initialize(config: nil, region: nil, signer: nil, proxy_settings: nil, retry_config: nil) # If the signer is an InstancePrincipalsSecurityTokenSigner and no config was supplied (which is valid for instance principals) # then create a dummy config to pass to the ApiClient constructor. If customers wish to create a client which uses instance principals # and has config (either populated programmatically or loaded from a file), they must construct that config themselves and then # pass it to this constructor. # # If there is no signer (or the signer is not an instance principals signer) and no config was supplied, this is not valid # so try and load the config from the default file. config ||= OCI.config unless signer.is_a?(OCI::Auth::Signers::InstancePrincipalsSecurityTokenSigner) config ||= OCI::Config.new if signer.is_a?(OCI::Auth::Signers::InstancePrincipalsSecurityTokenSigner) config.validate unless signer.is_a?(OCI::Auth::Signers::InstancePrincipalsSecurityTokenSigner) if signer.nil? signer = OCI::Signer.new( config.user, config.fingerprint, config.tenancy, config.key_file, pass_phrase: config.pass_phrase, private_key_content: config.key_content ) end @api_client = OCI::ApiClient.new(config, signer, proxy_settings: proxy_settings) @retry_config = retry_config region ||= config.region region ||= signer.region if signer.respond_to?(:region) self.region = region end |
Instance Attribute Details
#api_client ⇒ OCI::ApiClient (readonly)
Client used to make HTTP requests.
12 13 14 |
# File 'lib/oci/core/blockstorage_client.rb', line 12 def api_client @api_client end |
#endpoint ⇒ String (readonly)
Fully qualified endpoint URL
16 17 18 |
# File 'lib/oci/core/blockstorage_client.rb', line 16 def endpoint @endpoint end |
#region ⇒ String
The region, which will usually correspond to a value in Regions::REGION_ENUM.
26 27 28 |
# File 'lib/oci/core/blockstorage_client.rb', line 26 def region @region end |
#retry_config ⇒ OCI::Retry::RetryConfig (readonly)
The default retry configuration to apply to all operations in this service client. This can be overridden on a per-operation basis. The default retry configuration value is nil, which means that an operation will not perform any retries
22 23 24 |
# File 'lib/oci/core/blockstorage_client.rb', line 22 def retry_config @retry_config end |
Instance Method Details
#create_volume(create_volume_details, opts = {}) ⇒ Response
Creates a new volume in the specified compartment. Volumes can be created in sizes ranging from 50 GB (51200 MB) to 16 TB (16777216 MB), in 1 GB (1024 MB) increments. By default, volumes are 1 TB (1048576 MB). For general information about block volumes, see [Overview of Block Volume Service](docs.us-phoenix-1.oraclecloud.com/Content/Block/Concepts/overview.htm).
A volume and instance can be in separate compartments but must be in the same Availability Domain. For information about access control and compartments, see [Overview of the IAM Service](docs.us-phoenix-1.oraclecloud.com/Content/Identity/Concepts/overview.htm). For information about Availability Domains, see [Regions and Availability Domains](docs.us-phoenix-1.oraclecloud.com/Content/General/Concepts/regions.htm). To get a list of Availability Domains, use the ListAvailabilityDomains operation in the Identity and Access Management Service API.
You may optionally specify a *display name* for the volume, which is simply a friendly name or description. It does not have to be unique, and you can change it. Avoid entering confidential information.
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/oci/core/blockstorage_client.rb', line 128 def create_volume(create_volume_details, opts = {}) logger.debug 'Calling operation BlockstorageClient#create_volume.' if logger raise "Missing the required parameter 'create_volume_details' when calling create_volume." if create_volume_details.nil? path = '/volumes' operation_signing_strategy = :standard # Query Params query_params = {} # Header Params header_params = {} header_params['accept'] = 'application/json' header_params['content-type'] = 'application/json' header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = @api_client.object_to_http_body(create_volume_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'BlockstorageClient#create_volume') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Core::Models::Volume' ) end # rubocop:enable Metrics/BlockLength end |
#create_volume_backup(create_volume_backup_details, opts = {}) ⇒ Response
Creates a new backup of the specified volume. For general information about volume backups, see [Overview of Block Volume Service Backups](docs.us-phoenix-1.oraclecloud.com/Content/Block/Concepts/blockvolumebackups.htm)
When the request is received, the backup object is in a REQUEST_RECEIVED state. When the data is imaged, it goes into a CREATING state. After the backup is fully uploaded to the cloud, it goes into an AVAILABLE state.
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/oci/core/blockstorage_client.rb', line 190 def create_volume_backup(create_volume_backup_details, opts = {}) logger.debug 'Calling operation BlockstorageClient#create_volume_backup.' if logger raise "Missing the required parameter 'create_volume_backup_details' when calling create_volume_backup." if create_volume_backup_details.nil? path = '/volumeBackups' operation_signing_strategy = :standard # Query Params query_params = {} # Header Params header_params = {} header_params['accept'] = 'application/json' header_params['content-type'] = 'application/json' header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = @api_client.object_to_http_body(create_volume_backup_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'BlockstorageClient#create_volume_backup') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Core::Models::VolumeBackup' ) end # rubocop:enable Metrics/BlockLength end |
#create_volume_backup_policy_assignment(create_volume_backup_policy_assignment_details, opts = {}) ⇒ Response
Assigns a policy to the specified asset, such as a volume. Note that a given asset can only have one policy assigned to it; if this method is called for an asset that previously has a different policy assigned, the prior assignment will be silently deleted.
244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/oci/core/blockstorage_client.rb', line 244 def create_volume_backup_policy_assignment(create_volume_backup_policy_assignment_details, opts = {}) logger.debug 'Calling operation BlockstorageClient#create_volume_backup_policy_assignment.' if logger raise "Missing the required parameter 'create_volume_backup_policy_assignment_details' when calling create_volume_backup_policy_assignment." if create_volume_backup_policy_assignment_details.nil? path = '/volumeBackupPolicyAssignments' operation_signing_strategy = :standard # Query Params query_params = {} # Header Params header_params = {} header_params['accept'] = 'application/json' header_params['content-type'] = 'application/json' post_body = @api_client.object_to_http_body(create_volume_backup_policy_assignment_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'BlockstorageClient#create_volume_backup_policy_assignment') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Core::Models::VolumeBackupPolicyAssignment' ) end # rubocop:enable Metrics/BlockLength end |
#create_volume_group(create_volume_group_details, opts = {}) ⇒ Response
Creates a new volume group in the specified compartment. A volume group can have at most 20 block volumes. A volume group is a collection of volumes and may be created from a list of volumes, cloning an existing volume group or by restoring a volume group backup. You may optionally specify a *display name* for the volume group, which is simply a friendly name or description. It does not have to be unique, and you can change it. Avoid entering confidential information.
304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 |
# File 'lib/oci/core/blockstorage_client.rb', line 304 def create_volume_group(create_volume_group_details, opts = {}) logger.debug 'Calling operation BlockstorageClient#create_volume_group.' if logger raise "Missing the required parameter 'create_volume_group_details' when calling create_volume_group." if create_volume_group_details.nil? path = '/volumeGroups' operation_signing_strategy = :standard # Query Params query_params = {} # Header Params header_params = {} header_params['accept'] = 'application/json' header_params['content-type'] = 'application/json' header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = @api_client.object_to_http_body(create_volume_group_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'BlockstorageClient#create_volume_group') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Core::Models::VolumeGroup' ) end # rubocop:enable Metrics/BlockLength end |
#create_volume_group_backup(create_volume_group_backup_details, opts = {}) ⇒ Response
Creates a new group backup of the specified volume group.
361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 |
# File 'lib/oci/core/blockstorage_client.rb', line 361 def create_volume_group_backup(create_volume_group_backup_details, opts = {}) logger.debug 'Calling operation BlockstorageClient#create_volume_group_backup.' if logger raise "Missing the required parameter 'create_volume_group_backup_details' when calling create_volume_group_backup." if create_volume_group_backup_details.nil? path = '/volumeGroupBackups' operation_signing_strategy = :standard # Query Params query_params = {} # Header Params header_params = {} header_params['accept'] = 'application/json' header_params['content-type'] = 'application/json' header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = @api_client.object_to_http_body(create_volume_group_backup_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'BlockstorageClient#create_volume_group_backup') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Core::Models::VolumeGroupBackup' ) end # rubocop:enable Metrics/BlockLength end |
#delete_boot_volume(boot_volume_id, opts = {}) ⇒ Response
Deletes the specified boot volume. The volume cannot have an active connection to an instance. To disconnect the boot volume from a connected instance, see [Disconnecting From a Boot Volume](docs.us-phoenix-1.oraclecloud.com/Content/Block/Tasks/deletingbootvolume.htm). Warning: All data on the boot volume will be permanently lost when the boot volume is deleted.
419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/oci/core/blockstorage_client.rb', line 419 def delete_boot_volume(boot_volume_id, opts = {}) logger.debug 'Calling operation BlockstorageClient#delete_boot_volume.' if logger raise "Missing the required parameter 'boot_volume_id' when calling delete_boot_volume." if boot_volume_id.nil? raise "Parameter value for 'boot_volume_id' must not be blank" if OCI::Internal::Util.blank_string?(boot_volume_id) path = '/bootVolumes/{bootVolumeId}'.sub('{bootVolumeId}', boot_volume_id.to_s) operation_signing_strategy = :standard # Query Params query_params = {} # Header Params header_params = {} header_params['accept'] = 'application/json' header_params['content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'BlockstorageClient#delete_boot_volume') do @api_client.call_api( :DELETE, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#delete_volume(volume_id, opts = {}) ⇒ Response
Deletes the specified volume. The volume cannot have an active connection to an instance. To disconnect the volume from a connected instance, see [Disconnecting From a Volume](docs.us-phoenix-1.oraclecloud.com/Content/Block/Tasks/disconnectingfromavolume.htm). Warning: All data on the volume will be permanently lost when the volume is deleted.
476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 |
# File 'lib/oci/core/blockstorage_client.rb', line 476 def delete_volume(volume_id, opts = {}) logger.debug 'Calling operation BlockstorageClient#delete_volume.' if logger raise "Missing the required parameter 'volume_id' when calling delete_volume." if volume_id.nil? raise "Parameter value for 'volume_id' must not be blank" if OCI::Internal::Util.blank_string?(volume_id) path = '/volumes/{volumeId}'.sub('{volumeId}', volume_id.to_s) operation_signing_strategy = :standard # Query Params query_params = {} # Header Params header_params = {} header_params['accept'] = 'application/json' header_params['content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'BlockstorageClient#delete_volume') do @api_client.call_api( :DELETE, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#delete_volume_backup(volume_backup_id, opts = {}) ⇒ Response
Deletes a volume backup.
529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 |
# File 'lib/oci/core/blockstorage_client.rb', line 529 def delete_volume_backup(volume_backup_id, opts = {}) logger.debug 'Calling operation BlockstorageClient#delete_volume_backup.' if logger raise "Missing the required parameter 'volume_backup_id' when calling delete_volume_backup." if volume_backup_id.nil? raise "Parameter value for 'volume_backup_id' must not be blank" if OCI::Internal::Util.blank_string?(volume_backup_id) path = '/volumeBackups/{volumeBackupId}'.sub('{volumeBackupId}', volume_backup_id.to_s) operation_signing_strategy = :standard # Query Params query_params = {} # Header Params header_params = {} header_params['accept'] = 'application/json' header_params['content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'BlockstorageClient#delete_volume_backup') do @api_client.call_api( :DELETE, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#delete_volume_backup_policy_assignment(policy_assignment_id, opts = {}) ⇒ Response
Deletes a volume backup policy assignment (i.e. unassigns the policy from an asset).
582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 |
# File 'lib/oci/core/blockstorage_client.rb', line 582 def delete_volume_backup_policy_assignment(policy_assignment_id, opts = {}) logger.debug 'Calling operation BlockstorageClient#delete_volume_backup_policy_assignment.' if logger raise "Missing the required parameter 'policy_assignment_id' when calling delete_volume_backup_policy_assignment." if policy_assignment_id.nil? raise "Parameter value for 'policy_assignment_id' must not be blank" if OCI::Internal::Util.blank_string?(policy_assignment_id) path = '/volumeBackupPolicyAssignments/{policyAssignmentId}'.sub('{policyAssignmentId}', policy_assignment_id.to_s) operation_signing_strategy = :standard # Query Params query_params = {} # Header Params header_params = {} header_params['accept'] = 'application/json' header_params['content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'BlockstorageClient#delete_volume_backup_policy_assignment') do @api_client.call_api( :DELETE, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#delete_volume_group(volume_group_id, opts = {}) ⇒ Response
Deletes the specified volume group. This will NOT delete data volumes.
636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 |
# File 'lib/oci/core/blockstorage_client.rb', line 636 def delete_volume_group(volume_group_id, opts = {}) logger.debug 'Calling operation BlockstorageClient#delete_volume_group.' if logger raise "Missing the required parameter 'volume_group_id' when calling delete_volume_group." if volume_group_id.nil? raise "Parameter value for 'volume_group_id' must not be blank" if OCI::Internal::Util.blank_string?(volume_group_id) path = '/volumeGroups/{volumeGroupId}'.sub('{volumeGroupId}', volume_group_id.to_s) operation_signing_strategy = :standard # Query Params query_params = {} # Header Params header_params = {} header_params['accept'] = 'application/json' header_params['content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'BlockstorageClient#delete_volume_group') do @api_client.call_api( :DELETE, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#delete_volume_group_backup(volume_group_backup_id, opts = {}) ⇒ Response
Deletes a volume group backup. This will NOT delete backups within the volume group backup.
689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 |
# File 'lib/oci/core/blockstorage_client.rb', line 689 def delete_volume_group_backup(volume_group_backup_id, opts = {}) logger.debug 'Calling operation BlockstorageClient#delete_volume_group_backup.' if logger raise "Missing the required parameter 'volume_group_backup_id' when calling delete_volume_group_backup." if volume_group_backup_id.nil? raise "Parameter value for 'volume_group_backup_id' must not be blank" if OCI::Internal::Util.blank_string?(volume_group_backup_id) path = '/volumeGroupBackups/{volumeGroupBackupId}'.sub('{volumeGroupBackupId}', volume_group_backup_id.to_s) operation_signing_strategy = :standard # Query Params query_params = {} # Header Params header_params = {} header_params['accept'] = 'application/json' header_params['content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'BlockstorageClient#delete_volume_group_backup') do @api_client.call_api( :DELETE, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#get_boot_volume(boot_volume_id, opts = {}) ⇒ Response
Gets information for the specified boot volume.
739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 |
# File 'lib/oci/core/blockstorage_client.rb', line 739 def get_boot_volume(boot_volume_id, opts = {}) logger.debug 'Calling operation BlockstorageClient#get_boot_volume.' if logger raise "Missing the required parameter 'boot_volume_id' when calling get_boot_volume." if boot_volume_id.nil? raise "Parameter value for 'boot_volume_id' must not be blank" if OCI::Internal::Util.blank_string?(boot_volume_id) path = '/bootVolumes/{bootVolumeId}'.sub('{bootVolumeId}', boot_volume_id.to_s) operation_signing_strategy = :standard # Query Params query_params = {} # Header Params header_params = {} header_params['accept'] = 'application/json' header_params['content-type'] = 'application/json' post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'BlockstorageClient#get_boot_volume') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Core::Models::BootVolume' ) end # rubocop:enable Metrics/BlockLength end |
#get_volume(volume_id, opts = {}) ⇒ Response
Gets information for the specified volume.
790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 |
# File 'lib/oci/core/blockstorage_client.rb', line 790 def get_volume(volume_id, opts = {}) logger.debug 'Calling operation BlockstorageClient#get_volume.' if logger raise "Missing the required parameter 'volume_id' when calling get_volume." if volume_id.nil? raise "Parameter value for 'volume_id' must not be blank" if OCI::Internal::Util.blank_string?(volume_id) path = '/volumes/{volumeId}'.sub('{volumeId}', volume_id.to_s) operation_signing_strategy = :standard # Query Params query_params = {} # Header Params header_params = {} header_params['accept'] = 'application/json' header_params['content-type'] = 'application/json' post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'BlockstorageClient#get_volume') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Core::Models::Volume' ) end # rubocop:enable Metrics/BlockLength end |
#get_volume_backup(volume_backup_id, opts = {}) ⇒ Response
Gets information for the specified volume backup.
841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 |
# File 'lib/oci/core/blockstorage_client.rb', line 841 def get_volume_backup(volume_backup_id, opts = {}) logger.debug 'Calling operation BlockstorageClient#get_volume_backup.' if logger raise "Missing the required parameter 'volume_backup_id' when calling get_volume_backup." if volume_backup_id.nil? raise "Parameter value for 'volume_backup_id' must not be blank" if OCI::Internal::Util.blank_string?(volume_backup_id) path = '/volumeBackups/{volumeBackupId}'.sub('{volumeBackupId}', volume_backup_id.to_s) operation_signing_strategy = :standard # Query Params query_params = {} # Header Params header_params = {} header_params['accept'] = 'application/json' header_params['content-type'] = 'application/json' post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'BlockstorageClient#get_volume_backup') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Core::Models::VolumeBackup' ) end # rubocop:enable Metrics/BlockLength end |
#get_volume_backup_policy(policy_id, opts = {}) ⇒ Response
Gets information for the specified volume backup policy.
892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 |
# File 'lib/oci/core/blockstorage_client.rb', line 892 def get_volume_backup_policy(policy_id, opts = {}) logger.debug 'Calling operation BlockstorageClient#get_volume_backup_policy.' if logger raise "Missing the required parameter 'policy_id' when calling get_volume_backup_policy." if policy_id.nil? raise "Parameter value for 'policy_id' must not be blank" if OCI::Internal::Util.blank_string?(policy_id) path = '/volumeBackupPolicies/{policyId}'.sub('{policyId}', policy_id.to_s) operation_signing_strategy = :standard # Query Params query_params = {} # Header Params header_params = {} header_params['accept'] = 'application/json' header_params['content-type'] = 'application/json' post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'BlockstorageClient#get_volume_backup_policy') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Core::Models::VolumeBackupPolicy' ) end # rubocop:enable Metrics/BlockLength end |
#get_volume_backup_policy_asset_assignment(asset_id, opts = {}) ⇒ Response
Gets the volume backup policy assignment for the specified asset. Note that the assetId query parameter is required, and that the returned list will contain at most one item (since any given asset can only have one policy assigned to it).
951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 |
# File 'lib/oci/core/blockstorage_client.rb', line 951 def get_volume_backup_policy_asset_assignment(asset_id, opts = {}) logger.debug 'Calling operation BlockstorageClient#get_volume_backup_policy_asset_assignment.' if logger raise "Missing the required parameter 'asset_id' when calling get_volume_backup_policy_asset_assignment." if asset_id.nil? path = '/volumeBackupPolicyAssignments' operation_signing_strategy = :standard # Query Params query_params = {} query_params[:assetId] = asset_id query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] # Header Params header_params = {} header_params['accept'] = 'application/json' header_params['content-type'] = 'application/json' post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'BlockstorageClient#get_volume_backup_policy_asset_assignment') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'Array<OCI::Core::Models::VolumeBackupPolicyAssignment>' ) end # rubocop:enable Metrics/BlockLength end |
#get_volume_backup_policy_assignment(policy_assignment_id, opts = {}) ⇒ Response
Gets information for the specified volume backup policy assignment.
1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 |
# File 'lib/oci/core/blockstorage_client.rb', line 1003 def get_volume_backup_policy_assignment(policy_assignment_id, opts = {}) logger.debug 'Calling operation BlockstorageClient#get_volume_backup_policy_assignment.' if logger raise "Missing the required parameter 'policy_assignment_id' when calling get_volume_backup_policy_assignment." if policy_assignment_id.nil? raise "Parameter value for 'policy_assignment_id' must not be blank" if OCI::Internal::Util.blank_string?(policy_assignment_id) path = '/volumeBackupPolicyAssignments/{policyAssignmentId}'.sub('{policyAssignmentId}', policy_assignment_id.to_s) operation_signing_strategy = :standard # Query Params query_params = {} # Header Params header_params = {} header_params['accept'] = 'application/json' header_params['content-type'] = 'application/json' post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'BlockstorageClient#get_volume_backup_policy_assignment') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Core::Models::VolumeBackupPolicyAssignment' ) end # rubocop:enable Metrics/BlockLength end |
#get_volume_group(volume_group_id, opts = {}) ⇒ Response
Gets information for the specified volume group.
1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 |
# File 'lib/oci/core/blockstorage_client.rb', line 1054 def get_volume_group(volume_group_id, opts = {}) logger.debug 'Calling operation BlockstorageClient#get_volume_group.' if logger raise "Missing the required parameter 'volume_group_id' when calling get_volume_group." if volume_group_id.nil? raise "Parameter value for 'volume_group_id' must not be blank" if OCI::Internal::Util.blank_string?(volume_group_id) path = '/volumeGroups/{volumeGroupId}'.sub('{volumeGroupId}', volume_group_id.to_s) operation_signing_strategy = :standard # Query Params query_params = {} # Header Params header_params = {} header_params['accept'] = 'application/json' header_params['content-type'] = 'application/json' post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'BlockstorageClient#get_volume_group') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Core::Models::VolumeGroup' ) end # rubocop:enable Metrics/BlockLength end |
#get_volume_group_backup(volume_group_backup_id, opts = {}) ⇒ Response
Gets information for the specified volume group backup.
1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 |
# File 'lib/oci/core/blockstorage_client.rb', line 1105 def get_volume_group_backup(volume_group_backup_id, opts = {}) logger.debug 'Calling operation BlockstorageClient#get_volume_group_backup.' if logger raise "Missing the required parameter 'volume_group_backup_id' when calling get_volume_group_backup." if volume_group_backup_id.nil? raise "Parameter value for 'volume_group_backup_id' must not be blank" if OCI::Internal::Util.blank_string?(volume_group_backup_id) path = '/volumeGroupBackups/{volumeGroupBackupId}'.sub('{volumeGroupBackupId}', volume_group_backup_id.to_s) operation_signing_strategy = :standard # Query Params query_params = {} # Header Params header_params = {} header_params['accept'] = 'application/json' header_params['content-type'] = 'application/json' post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'BlockstorageClient#get_volume_group_backup') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Core::Models::VolumeGroupBackup' ) end # rubocop:enable Metrics/BlockLength end |
#list_boot_volumes(availability_domain, compartment_id, opts = {}) ⇒ Response
Lists the boot volumes in the specified compartment and Availability Domain.
1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 |
# File 'lib/oci/core/blockstorage_client.rb', line 1167 def list_boot_volumes(availability_domain, compartment_id, opts = {}) logger.debug 'Calling operation BlockstorageClient#list_boot_volumes.' if logger raise "Missing the required parameter 'availability_domain' when calling list_boot_volumes." if availability_domain.nil? raise "Missing the required parameter 'compartment_id' when calling list_boot_volumes." if compartment_id.nil? path = '/bootVolumes' operation_signing_strategy = :standard # Query Params query_params = {} query_params[:availabilityDomain] = availability_domain query_params[:compartmentId] = compartment_id query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] query_params[:volumeGroupId] = opts[:volume_group_id] if opts[:volume_group_id] # Header Params header_params = {} header_params['accept'] = 'application/json' header_params['content-type'] = 'application/json' post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'BlockstorageClient#list_boot_volumes') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'Array<OCI::Core::Models::BootVolume>' ) end # rubocop:enable Metrics/BlockLength end |
#list_volume_backup_policies(opts = {}) ⇒ Response
Lists all volume backup policies available to the caller.
1226 1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 |
# File 'lib/oci/core/blockstorage_client.rb', line 1226 def list_volume_backup_policies(opts = {}) logger.debug 'Calling operation BlockstorageClient#list_volume_backup_policies.' if logger path = '/volumeBackupPolicies' operation_signing_strategy = :standard # Query Params query_params = {} query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] # Header Params header_params = {} header_params['accept'] = 'application/json' header_params['content-type'] = 'application/json' post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'BlockstorageClient#list_volume_backup_policies') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'Array<OCI::Core::Models::VolumeBackupPolicy>' ) end # rubocop:enable Metrics/BlockLength end |
#list_volume_backups(compartment_id, opts = {}) ⇒ Response
Lists the volume backups in the specified compartment. You can filter the results by volume.
1301 1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 1329 1330 1331 1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 |
# File 'lib/oci/core/blockstorage_client.rb', line 1301 def list_volume_backups(compartment_id, opts = {}) logger.debug 'Calling operation BlockstorageClient#list_volume_backups.' if logger raise "Missing the required parameter 'compartment_id' when calling list_volume_backups." if compartment_id.nil? if opts[:sort_by] && !%w[TIMECREATED DISPLAYNAME].include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of TIMECREATED, DISPLAYNAME.' end if opts[:sort_order] && !%w[ASC DESC].include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of ASC, DESC.' end if opts[:lifecycle_state] && !OCI::Core::Models::VolumeBackup::LIFECYCLE_STATE_ENUM.include?(opts[:lifecycle_state]) raise 'Invalid value for "lifecycle_state", must be one of the values in OCI::Core::Models::VolumeBackup::LIFECYCLE_STATE_ENUM.' end path = '/volumeBackups' operation_signing_strategy = :standard # Query Params query_params = {} query_params[:compartmentId] = compartment_id query_params[:volumeId] = opts[:volume_id] if opts[:volume_id] query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] query_params[:displayName] = opts[:display_name] if opts[:display_name] query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] query_params[:lifecycleState] = opts[:lifecycle_state] if opts[:lifecycle_state] # Header Params header_params = {} header_params['accept'] = 'application/json' header_params['content-type'] = 'application/json' post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'BlockstorageClient#list_volume_backups') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'Array<OCI::Core::Models::VolumeBackup>' ) end # rubocop:enable Metrics/BlockLength end |
#list_volume_group_backups(compartment_id, opts = {}) ⇒ Response
Lists the backups for volume groups in the specified compartment. You can filter the results by volume group.
1393 1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 |
# File 'lib/oci/core/blockstorage_client.rb', line 1393 def list_volume_group_backups(compartment_id, opts = {}) logger.debug 'Calling operation BlockstorageClient#list_volume_group_backups.' if logger raise "Missing the required parameter 'compartment_id' when calling list_volume_group_backups." if compartment_id.nil? if opts[:sort_by] && !%w[TIMECREATED DISPLAYNAME].include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of TIMECREATED, DISPLAYNAME.' end if opts[:sort_order] && !%w[ASC DESC].include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of ASC, DESC.' end path = '/volumeGroupBackups' operation_signing_strategy = :standard # Query Params query_params = {} query_params[:compartmentId] = compartment_id query_params[:volumeGroupId] = opts[:volume_group_id] if opts[:volume_group_id] query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] query_params[:displayName] = opts[:display_name] if opts[:display_name] query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] # Header Params header_params = {} header_params['accept'] = 'application/json' header_params['content-type'] = 'application/json' post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'BlockstorageClient#list_volume_group_backups') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'Array<OCI::Core::Models::VolumeGroupBackup>' ) end # rubocop:enable Metrics/BlockLength end |
#list_volume_groups(compartment_id, opts = {}) ⇒ Response
Lists the volume groups in the specified compartment and Availability Domain.
1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 |
# File 'lib/oci/core/blockstorage_client.rb', line 1484 def list_volume_groups(compartment_id, opts = {}) logger.debug 'Calling operation BlockstorageClient#list_volume_groups.' if logger raise "Missing the required parameter 'compartment_id' when calling list_volume_groups." if compartment_id.nil? if opts[:sort_by] && !%w[TIMECREATED DISPLAYNAME].include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of TIMECREATED, DISPLAYNAME.' end if opts[:sort_order] && !%w[ASC DESC].include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of ASC, DESC.' end if opts[:lifecycle_state] && !OCI::Core::Models::VolumeGroup::LIFECYCLE_STATE_ENUM.include?(opts[:lifecycle_state]) raise 'Invalid value for "lifecycle_state", must be one of the values in OCI::Core::Models::VolumeGroup::LIFECYCLE_STATE_ENUM.' end path = '/volumeGroups' operation_signing_strategy = :standard # Query Params query_params = {} query_params[:compartmentId] = compartment_id query_params[:availabilityDomain] = opts[:availability_domain] if opts[:availability_domain] query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] query_params[:displayName] = opts[:display_name] if opts[:display_name] query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] query_params[:lifecycleState] = opts[:lifecycle_state] if opts[:lifecycle_state] # Header Params header_params = {} header_params['accept'] = 'application/json' header_params['content-type'] = 'application/json' post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'BlockstorageClient#list_volume_groups') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'Array<OCI::Core::Models::VolumeGroup>' ) end # rubocop:enable Metrics/BlockLength end |
#list_volumes(compartment_id, opts = {}) ⇒ Response
Lists the volumes in the specified compartment and Availability Domain.
1582 1583 1584 1585 1586 1587 1588 1589 1590 1591 1592 1593 1594 1595 1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 1606 1607 1608 1609 1610 1611 1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 1630 1631 1632 1633 1634 1635 |
# File 'lib/oci/core/blockstorage_client.rb', line 1582 def list_volumes(compartment_id, opts = {}) logger.debug 'Calling operation BlockstorageClient#list_volumes.' if logger raise "Missing the required parameter 'compartment_id' when calling list_volumes." if compartment_id.nil? if opts[:sort_by] && !%w[TIMECREATED DISPLAYNAME].include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of TIMECREATED, DISPLAYNAME.' end if opts[:sort_order] && !%w[ASC DESC].include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of ASC, DESC.' end if opts[:lifecycle_state] && !OCI::Core::Models::Volume::LIFECYCLE_STATE_ENUM.include?(opts[:lifecycle_state]) raise 'Invalid value for "lifecycle_state", must be one of the values in OCI::Core::Models::Volume::LIFECYCLE_STATE_ENUM.' end path = '/volumes' operation_signing_strategy = :standard # Query Params query_params = {} query_params[:compartmentId] = compartment_id query_params[:availabilityDomain] = opts[:availability_domain] if opts[:availability_domain] query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] query_params[:displayName] = opts[:display_name] if opts[:display_name] query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] query_params[:volumeGroupId] = opts[:volume_group_id] if opts[:volume_group_id] query_params[:lifecycleState] = opts[:lifecycle_state] if opts[:lifecycle_state] # Header Params header_params = {} header_params['accept'] = 'application/json' header_params['content-type'] = 'application/json' post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'BlockstorageClient#list_volumes') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'Array<OCI::Core::Models::Volume>' ) end # rubocop:enable Metrics/BlockLength end |
#logger ⇒ Logger
Returns The logger for this client. May be nil.
93 94 95 |
# File 'lib/oci/core/blockstorage_client.rb', line 93 def logger @api_client.config.logger end |
#update_boot_volume(boot_volume_id, update_boot_volume_details, opts = {}) ⇒ Response
Updates the specified boot volume’s display name.
1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 |
# File 'lib/oci/core/blockstorage_client.rb', line 1656 def update_boot_volume(boot_volume_id, update_boot_volume_details, opts = {}) logger.debug 'Calling operation BlockstorageClient#update_boot_volume.' if logger raise "Missing the required parameter 'boot_volume_id' when calling update_boot_volume." if boot_volume_id.nil? raise "Missing the required parameter 'update_boot_volume_details' when calling update_boot_volume." if update_boot_volume_details.nil? raise "Parameter value for 'boot_volume_id' must not be blank" if OCI::Internal::Util.blank_string?(boot_volume_id) path = '/bootVolumes/{bootVolumeId}'.sub('{bootVolumeId}', boot_volume_id.to_s) operation_signing_strategy = :standard # Query Params query_params = {} # Header Params header_params = {} header_params['accept'] = 'application/json' header_params['content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] post_body = @api_client.object_to_http_body(update_boot_volume_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'BlockstorageClient#update_boot_volume') do @api_client.call_api( :PUT, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Core::Models::BootVolume' ) end # rubocop:enable Metrics/BlockLength end |
#update_volume(volume_id, update_volume_details, opts = {}) ⇒ Response
Updates the specified volume’s display name. Avoid entering confidential information.
1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 |
# File 'lib/oci/core/blockstorage_client.rb', line 1714 def update_volume(volume_id, update_volume_details, opts = {}) logger.debug 'Calling operation BlockstorageClient#update_volume.' if logger raise "Missing the required parameter 'volume_id' when calling update_volume." if volume_id.nil? raise "Missing the required parameter 'update_volume_details' when calling update_volume." if update_volume_details.nil? raise "Parameter value for 'volume_id' must not be blank" if OCI::Internal::Util.blank_string?(volume_id) path = '/volumes/{volumeId}'.sub('{volumeId}', volume_id.to_s) operation_signing_strategy = :standard # Query Params query_params = {} # Header Params header_params = {} header_params['accept'] = 'application/json' header_params['content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] post_body = @api_client.object_to_http_body(update_volume_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'BlockstorageClient#update_volume') do @api_client.call_api( :PUT, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Core::Models::Volume' ) end # rubocop:enable Metrics/BlockLength end |
#update_volume_backup(volume_backup_id, update_volume_backup_details, opts = {}) ⇒ Response
Updates the display name for the specified volume backup. Avoid entering confidential information.
1772 1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 |
# File 'lib/oci/core/blockstorage_client.rb', line 1772 def update_volume_backup(volume_backup_id, update_volume_backup_details, opts = {}) logger.debug 'Calling operation BlockstorageClient#update_volume_backup.' if logger raise "Missing the required parameter 'volume_backup_id' when calling update_volume_backup." if volume_backup_id.nil? raise "Missing the required parameter 'update_volume_backup_details' when calling update_volume_backup." if update_volume_backup_details.nil? raise "Parameter value for 'volume_backup_id' must not be blank" if OCI::Internal::Util.blank_string?(volume_backup_id) path = '/volumeBackups/{volumeBackupId}'.sub('{volumeBackupId}', volume_backup_id.to_s) operation_signing_strategy = :standard # Query Params query_params = {} # Header Params header_params = {} header_params['accept'] = 'application/json' header_params['content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] post_body = @api_client.object_to_http_body(update_volume_backup_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'BlockstorageClient#update_volume_backup') do @api_client.call_api( :PUT, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Core::Models::VolumeBackup' ) end # rubocop:enable Metrics/BlockLength end |
#update_volume_group(volume_group_id, update_volume_group_details, opts = {}) ⇒ Response
Updates the set of volumes in a volume group along with (optionally) it’s display name. This call can be used to add or remove volumes in a volume group. The entire list of volume ids must be specified. Avoid entering confidential information.
1831 1832 1833 1834 1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 1846 1847 1848 1849 1850 1851 1852 1853 1854 1855 1856 1857 1858 1859 1860 1861 1862 1863 1864 1865 1866 |
# File 'lib/oci/core/blockstorage_client.rb', line 1831 def update_volume_group(volume_group_id, update_volume_group_details, opts = {}) logger.debug 'Calling operation BlockstorageClient#update_volume_group.' if logger raise "Missing the required parameter 'volume_group_id' when calling update_volume_group." if volume_group_id.nil? raise "Missing the required parameter 'update_volume_group_details' when calling update_volume_group." if update_volume_group_details.nil? raise "Parameter value for 'volume_group_id' must not be blank" if OCI::Internal::Util.blank_string?(volume_group_id) path = '/volumeGroups/{volumeGroupId}'.sub('{volumeGroupId}', volume_group_id.to_s) operation_signing_strategy = :standard # Query Params query_params = {} # Header Params header_params = {} header_params['accept'] = 'application/json' header_params['content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] post_body = @api_client.object_to_http_body(update_volume_group_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'BlockstorageClient#update_volume_group') do @api_client.call_api( :PUT, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Core::Models::VolumeGroup' ) end # rubocop:enable Metrics/BlockLength end |
#update_volume_group_backup(volume_group_backup_id, update_volume_group_backup_details, opts = {}) ⇒ Response
Updates the display name for the specified volume group backup.
1887 1888 1889 1890 1891 1892 1893 1894 1895 1896 1897 1898 1899 1900 1901 1902 1903 1904 1905 1906 1907 1908 1909 1910 1911 1912 1913 1914 1915 1916 1917 1918 1919 1920 1921 1922 |
# File 'lib/oci/core/blockstorage_client.rb', line 1887 def update_volume_group_backup(volume_group_backup_id, update_volume_group_backup_details, opts = {}) logger.debug 'Calling operation BlockstorageClient#update_volume_group_backup.' if logger raise "Missing the required parameter 'volume_group_backup_id' when calling update_volume_group_backup." if volume_group_backup_id.nil? raise "Missing the required parameter 'update_volume_group_backup_details' when calling update_volume_group_backup." if update_volume_group_backup_details.nil? raise "Parameter value for 'volume_group_backup_id' must not be blank" if OCI::Internal::Util.blank_string?(volume_group_backup_id) path = '/volumeGroupBackups/{volumeGroupBackupId}'.sub('{volumeGroupBackupId}', volume_group_backup_id.to_s) operation_signing_strategy = :standard # Query Params query_params = {} # Header Params header_params = {} header_params['accept'] = 'application/json' header_params['content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] post_body = @api_client.object_to_http_body(update_volume_group_backup_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'BlockstorageClient#update_volume_group_backup') do @api_client.call_api( :PUT, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Core::Models::VolumeGroupBackup' ) end # rubocop:enable Metrics/BlockLength end |