Class: OCI::Core::ComputeManagementClientCompositeOperations
- Inherits:
-
Object
- Object
- OCI::Core::ComputeManagementClientCompositeOperations
- Defined in:
- lib/oci/core/compute_management_client_composite_operations.rb
Overview
This class provides a wrapper around ComputeManagementClient and offers convenience methods for operations that would otherwise need to be chained together. For example, instead of performing an action on a resource (e.g. launching an instance, creating a load balancer) and then using a waiter to wait for the resource to enter a given state, you can call a single method in this class to accomplish the same functionality
Instance Attribute Summary collapse
-
#service_client ⇒ OCI::Core::ComputeManagementClient
readonly
The ComputeManagementClient used to communicate with the service_client.
Instance Method Summary collapse
-
#attach_instance_pool_instance_and_wait_for_state(instance_pool_id, attach_instance_pool_instance_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Core::ComputeManagementClient#attach_instance_pool_instance and then waits for the Models::InstancePoolInstance acted upon to enter the given state(s).
-
#attach_load_balancer_and_wait_for_state(instance_pool_id, attach_load_balancer_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Core::ComputeManagementClient#attach_load_balancer and then waits for the Models::InstancePool acted upon to enter the given state(s).
-
#create_cluster_network_and_wait_for_state(create_cluster_network_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Core::ComputeManagementClient#create_cluster_network and then waits for the Models::ClusterNetwork acted upon to enter the given state(s).
-
#create_instance_pool_and_wait_for_state(create_instance_pool_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Core::ComputeManagementClient#create_instance_pool and then waits for the Models::InstancePool acted upon to enter the given state(s).
-
#detach_instance_pool_instance_and_wait_for_state(instance_pool_id, detach_instance_pool_instance_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Core::ComputeManagementClient#detach_instance_pool_instance and then waits for the Models::WorkRequest to enter the given state(s).
-
#detach_load_balancer_and_wait_for_state(instance_pool_id, detach_load_balancer_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Core::ComputeManagementClient#detach_load_balancer and then waits for the Models::InstancePool acted upon to enter the given state(s).
-
#initialize(service_client = OCI::Core::ComputeManagementClient.new) ⇒ ComputeManagementClientCompositeOperations
constructor
Initializes a new ComputeManagementClientCompositeOperations.
-
#reset_instance_pool_and_wait_for_state(instance_pool_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Core::ComputeManagementClient#reset_instance_pool and then waits for the Models::InstancePool acted upon to enter the given state(s).
-
#softreset_instance_pool_and_wait_for_state(instance_pool_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Core::ComputeManagementClient#softreset_instance_pool and then waits for the Models::InstancePool acted upon to enter the given state(s).
-
#start_instance_pool_and_wait_for_state(instance_pool_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Core::ComputeManagementClient#start_instance_pool and then waits for the Models::InstancePool acted upon to enter the given state(s).
-
#stop_instance_pool_and_wait_for_state(instance_pool_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Core::ComputeManagementClient#stop_instance_pool and then waits for the Models::InstancePool acted upon to enter the given state(s).
-
#terminate_cluster_network_and_wait_for_state(cluster_network_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Core::ComputeManagementClient#terminate_cluster_network and then waits for the Models::WorkRequest to enter the given state(s).
-
#terminate_instance_pool_and_wait_for_state(instance_pool_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Core::ComputeManagementClient#terminate_instance_pool and then waits for the Models::InstancePool acted upon to enter the given state(s).
-
#update_cluster_network_and_wait_for_state(cluster_network_id, update_cluster_network_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Core::ComputeManagementClient#update_cluster_network and then waits for the Models::ClusterNetwork acted upon to enter the given state(s).
-
#update_instance_pool_and_wait_for_state(instance_pool_id, update_instance_pool_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Core::ComputeManagementClient#update_instance_pool and then waits for the Models::InstancePool acted upon to enter the given state(s).
Constructor Details
#initialize(service_client = OCI::Core::ComputeManagementClient.new) ⇒ ComputeManagementClientCompositeOperations
Initializes a new ComputeManagementClientCompositeOperations
20 21 22 |
# File 'lib/oci/core/compute_management_client_composite_operations.rb', line 20 def initialize(service_client = OCI::Core::ComputeManagementClient.new) @service_client = service_client end |
Instance Attribute Details
#service_client ⇒ OCI::Core::ComputeManagementClient (readonly)
The OCI::Core::ComputeManagementClient used to communicate with the service_client
14 15 16 |
# File 'lib/oci/core/compute_management_client_composite_operations.rb', line 14 def service_client @service_client end |
Instance Method Details
#attach_instance_pool_instance_and_wait_for_state(instance_pool_id, attach_instance_pool_instance_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Core::ComputeManagementClient#attach_instance_pool_instance and then waits for the Models::InstancePoolInstance acted upon to enter the given state(s).
40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/oci/core/compute_management_client_composite_operations.rb', line 40 def attach_instance_pool_instance_and_wait_for_state(instance_pool_id, attach_instance_pool_instance_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) operation_result = @service_client.attach_instance_pool_instance(instance_pool_id, attach_instance_pool_instance_details, base_operation_opts) return operation_result if wait_for_states.empty? lowered_wait_for_states = wait_for_states.map(&:downcase) wait_for_resource_id = operation_result.data.id begin waiter_result = @service_client.get_instance_pool_instance(wait_for_resource_id).wait_until( eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) }, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) result_to_return = waiter_result return result_to_return rescue StandardError raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result]) end end |
#attach_load_balancer_and_wait_for_state(instance_pool_id, attach_load_balancer_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Core::ComputeManagementClient#attach_load_balancer and then waits for the Models::InstancePool acted upon to enter the given state(s).
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/oci/core/compute_management_client_composite_operations.rb', line 80 def attach_load_balancer_and_wait_for_state(instance_pool_id, attach_load_balancer_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) operation_result = @service_client.attach_load_balancer(instance_pool_id, attach_load_balancer_details, base_operation_opts) return operation_result if wait_for_states.empty? lowered_wait_for_states = wait_for_states.map(&:downcase) wait_for_resource_id = operation_result.data.id begin waiter_result = @service_client.get_instance_pool(wait_for_resource_id).wait_until( eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) }, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) result_to_return = waiter_result return result_to_return rescue StandardError raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result]) end end |
#create_cluster_network_and_wait_for_state(create_cluster_network_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Core::ComputeManagementClient#create_cluster_network and then waits for the Models::ClusterNetwork acted upon to enter the given state(s).
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/oci/core/compute_management_client_composite_operations.rb', line 119 def create_cluster_network_and_wait_for_state(create_cluster_network_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) operation_result = @service_client.create_cluster_network(create_cluster_network_details, base_operation_opts) return operation_result if wait_for_states.empty? lowered_wait_for_states = wait_for_states.map(&:downcase) wait_for_resource_id = operation_result.data.id begin waiter_result = @service_client.get_cluster_network(wait_for_resource_id).wait_until( eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) }, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) result_to_return = waiter_result return result_to_return rescue StandardError raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result]) end end |
#create_instance_pool_and_wait_for_state(create_instance_pool_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Core::ComputeManagementClient#create_instance_pool and then waits for the Models::InstancePool acted upon to enter the given state(s).
158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/oci/core/compute_management_client_composite_operations.rb', line 158 def create_instance_pool_and_wait_for_state(create_instance_pool_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) operation_result = @service_client.create_instance_pool(create_instance_pool_details, base_operation_opts) return operation_result if wait_for_states.empty? lowered_wait_for_states = wait_for_states.map(&:downcase) wait_for_resource_id = operation_result.data.id begin waiter_result = @service_client.get_instance_pool(wait_for_resource_id).wait_until( eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) }, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) result_to_return = waiter_result return result_to_return rescue StandardError raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result]) end end |
#detach_instance_pool_instance_and_wait_for_state(instance_pool_id, detach_instance_pool_instance_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Core::ComputeManagementClient#detach_instance_pool_instance and then waits for the Models::WorkRequest to enter the given state(s).
198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/oci/core/compute_management_client_composite_operations.rb', line 198 def detach_instance_pool_instance_and_wait_for_state(instance_pool_id, detach_instance_pool_instance_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) operation_result = @service_client.detach_instance_pool_instance(instance_pool_id, detach_instance_pool_instance_details, base_operation_opts) use_util = OCI::Core::Util.respond_to?(:wait_on_work_request) return operation_result if wait_for_states.empty? && !use_util lowered_wait_for_states = wait_for_states.map(&:downcase) wait_for_resource_id = operation_result.headers['opc-work-request-id'] begin if use_util waiter_result = OCI::Core::Util.wait_on_work_request( @service_client, wait_for_resource_id, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) else waiter_result = @service_client.get_work_request(wait_for_resource_id).wait_until( eval_proc: ->(response) { response.data.respond_to?(:status) && lowered_wait_for_states.include?(response.data.status.downcase) }, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) end result_to_return = waiter_result return result_to_return rescue StandardError raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result]) end end |
#detach_load_balancer_and_wait_for_state(instance_pool_id, detach_load_balancer_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Core::ComputeManagementClient#detach_load_balancer and then waits for the Models::InstancePool acted upon to enter the given state(s).
248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 |
# File 'lib/oci/core/compute_management_client_composite_operations.rb', line 248 def detach_load_balancer_and_wait_for_state(instance_pool_id, detach_load_balancer_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) operation_result = @service_client.detach_load_balancer(instance_pool_id, detach_load_balancer_details, base_operation_opts) return operation_result if wait_for_states.empty? lowered_wait_for_states = wait_for_states.map(&:downcase) wait_for_resource_id = operation_result.data.id begin waiter_result = @service_client.get_instance_pool(wait_for_resource_id).wait_until( eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) }, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) result_to_return = waiter_result return result_to_return rescue StandardError raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result]) end end |
#reset_instance_pool_and_wait_for_state(instance_pool_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Core::ComputeManagementClient#reset_instance_pool and then waits for the Models::InstancePool acted upon to enter the given state(s).
287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 |
# File 'lib/oci/core/compute_management_client_composite_operations.rb', line 287 def reset_instance_pool_and_wait_for_state(instance_pool_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) operation_result = @service_client.reset_instance_pool(instance_pool_id, base_operation_opts) return operation_result if wait_for_states.empty? lowered_wait_for_states = wait_for_states.map(&:downcase) wait_for_resource_id = operation_result.data.id begin waiter_result = @service_client.get_instance_pool(wait_for_resource_id).wait_until( eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) }, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) result_to_return = waiter_result return result_to_return rescue StandardError raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result]) end end |
#softreset_instance_pool_and_wait_for_state(instance_pool_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Core::ComputeManagementClient#softreset_instance_pool and then waits for the Models::InstancePool acted upon to enter the given state(s).
326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 |
# File 'lib/oci/core/compute_management_client_composite_operations.rb', line 326 def softreset_instance_pool_and_wait_for_state(instance_pool_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) operation_result = @service_client.softreset_instance_pool(instance_pool_id, base_operation_opts) return operation_result if wait_for_states.empty? lowered_wait_for_states = wait_for_states.map(&:downcase) wait_for_resource_id = operation_result.data.id begin waiter_result = @service_client.get_instance_pool(wait_for_resource_id).wait_until( eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) }, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) result_to_return = waiter_result return result_to_return rescue StandardError raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result]) end end |
#start_instance_pool_and_wait_for_state(instance_pool_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Core::ComputeManagementClient#start_instance_pool and then waits for the Models::InstancePool acted upon to enter the given state(s).
365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 |
# File 'lib/oci/core/compute_management_client_composite_operations.rb', line 365 def start_instance_pool_and_wait_for_state(instance_pool_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) operation_result = @service_client.start_instance_pool(instance_pool_id, base_operation_opts) return operation_result if wait_for_states.empty? lowered_wait_for_states = wait_for_states.map(&:downcase) wait_for_resource_id = operation_result.data.id begin waiter_result = @service_client.get_instance_pool(wait_for_resource_id).wait_until( eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) }, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) result_to_return = waiter_result return result_to_return rescue StandardError raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result]) end end |
#stop_instance_pool_and_wait_for_state(instance_pool_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Core::ComputeManagementClient#stop_instance_pool and then waits for the Models::InstancePool acted upon to enter the given state(s).
404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 |
# File 'lib/oci/core/compute_management_client_composite_operations.rb', line 404 def stop_instance_pool_and_wait_for_state(instance_pool_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) operation_result = @service_client.stop_instance_pool(instance_pool_id, base_operation_opts) return operation_result if wait_for_states.empty? lowered_wait_for_states = wait_for_states.map(&:downcase) wait_for_resource_id = operation_result.data.id begin waiter_result = @service_client.get_instance_pool(wait_for_resource_id).wait_until( eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) }, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) result_to_return = waiter_result return result_to_return rescue StandardError raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result]) end end |
#terminate_cluster_network_and_wait_for_state(cluster_network_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Core::ComputeManagementClient#terminate_cluster_network and then waits for the Models::WorkRequest to enter the given state(s).
443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 |
# File 'lib/oci/core/compute_management_client_composite_operations.rb', line 443 def terminate_cluster_network_and_wait_for_state(cluster_network_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) operation_result = @service_client.terminate_cluster_network(cluster_network_id, base_operation_opts) use_util = OCI::Core::Util.respond_to?(:wait_on_work_request) return operation_result if wait_for_states.empty? && !use_util lowered_wait_for_states = wait_for_states.map(&:downcase) wait_for_resource_id = operation_result.headers['opc-work-request-id'] begin if use_util waiter_result = OCI::Core::Util.wait_on_work_request( @service_client, wait_for_resource_id, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) else waiter_result = @service_client.get_work_request(wait_for_resource_id).wait_until( eval_proc: ->(response) { response.data.respond_to?(:status) && lowered_wait_for_states.include?(response.data.status.downcase) }, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) end result_to_return = waiter_result return result_to_return rescue StandardError raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result]) end end |
#terminate_instance_pool_and_wait_for_state(instance_pool_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Core::ComputeManagementClient#terminate_instance_pool and then waits for the Models::InstancePool acted upon to enter the given state(s).
492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 |
# File 'lib/oci/core/compute_management_client_composite_operations.rb', line 492 def terminate_instance_pool_and_wait_for_state(instance_pool_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) initial_get_result = @service_client.get_instance_pool(instance_pool_id) operation_result = @service_client.terminate_instance_pool(instance_pool_id, base_operation_opts) return operation_result if wait_for_states.empty? lowered_wait_for_states = wait_for_states.map(&:downcase) begin waiter_result = initial_get_result.wait_until( eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) }, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200, succeed_on_not_found: true ) result_to_return = waiter_result return result_to_return rescue StandardError raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result]) end end |
#update_cluster_network_and_wait_for_state(cluster_network_id, update_cluster_network_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Core::ComputeManagementClient#update_cluster_network and then waits for the Models::ClusterNetwork acted upon to enter the given state(s).
533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 |
# File 'lib/oci/core/compute_management_client_composite_operations.rb', line 533 def update_cluster_network_and_wait_for_state(cluster_network_id, update_cluster_network_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) operation_result = @service_client.update_cluster_network(cluster_network_id, update_cluster_network_details, base_operation_opts) return operation_result if wait_for_states.empty? lowered_wait_for_states = wait_for_states.map(&:downcase) wait_for_resource_id = operation_result.data.id begin waiter_result = @service_client.get_cluster_network(wait_for_resource_id).wait_until( eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) }, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) result_to_return = waiter_result return result_to_return rescue StandardError raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result]) end end |
#update_instance_pool_and_wait_for_state(instance_pool_id, update_instance_pool_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Core::ComputeManagementClient#update_instance_pool and then waits for the Models::InstancePool acted upon to enter the given state(s).
573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/oci/core/compute_management_client_composite_operations.rb', line 573 def update_instance_pool_and_wait_for_state(instance_pool_id, update_instance_pool_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) operation_result = @service_client.update_instance_pool(instance_pool_id, update_instance_pool_details, base_operation_opts) return operation_result if wait_for_states.empty? lowered_wait_for_states = wait_for_states.map(&:downcase) wait_for_resource_id = operation_result.data.id begin waiter_result = @service_client.get_instance_pool(wait_for_resource_id).wait_until( eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) }, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) result_to_return = waiter_result return result_to_return rescue StandardError raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result]) end end |