Class: OCI::Core::Models::AllowedIkeIPSecParameters
- Inherits:
-
Object
- Object
- OCI::Core::Models::AllowedIkeIPSecParameters
- Defined in:
- lib/oci/core/models/allowed_ike_ip_sec_parameters.rb
Overview
Lists the current allowed and default IPSec tunnel parameters.
Instance Attribute Summary collapse
-
#allowed_phase_one_parameters ⇒ OCI::Core::Models::AllowedPhaseOneParameters
This attribute is required.
-
#allowed_phase_two_parameters ⇒ OCI::Core::Models::AllowedPhaseTwoParameters
This attribute is required.
-
#default_phase_one_parameters ⇒ OCI::Core::Models::DefaultPhaseOneParameters
This attribute is required.
-
#default_phase_two_parameters ⇒ OCI::Core::Models::DefaultPhaseTwoParameters
This attribute is required.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AllowedIkeIPSecParameters
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ AllowedIkeIPSecParameters
Initializes the object
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/oci/core/models/allowed_ike_ip_sec_parameters.rb', line 60 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.allowed_phase_one_parameters = attributes[:'allowedPhaseOneParameters'] if attributes[:'allowedPhaseOneParameters'] raise 'You cannot provide both :allowedPhaseOneParameters and :allowed_phase_one_parameters' if attributes.key?(:'allowedPhaseOneParameters') && attributes.key?(:'allowed_phase_one_parameters') self.allowed_phase_one_parameters = attributes[:'allowed_phase_one_parameters'] if attributes[:'allowed_phase_one_parameters'] self.allowed_phase_two_parameters = attributes[:'allowedPhaseTwoParameters'] if attributes[:'allowedPhaseTwoParameters'] raise 'You cannot provide both :allowedPhaseTwoParameters and :allowed_phase_two_parameters' if attributes.key?(:'allowedPhaseTwoParameters') && attributes.key?(:'allowed_phase_two_parameters') self.allowed_phase_two_parameters = attributes[:'allowed_phase_two_parameters'] if attributes[:'allowed_phase_two_parameters'] self.default_phase_one_parameters = attributes[:'defaultPhaseOneParameters'] if attributes[:'defaultPhaseOneParameters'] raise 'You cannot provide both :defaultPhaseOneParameters and :default_phase_one_parameters' if attributes.key?(:'defaultPhaseOneParameters') && attributes.key?(:'default_phase_one_parameters') self.default_phase_one_parameters = attributes[:'default_phase_one_parameters'] if attributes[:'default_phase_one_parameters'] self.default_phase_two_parameters = attributes[:'defaultPhaseTwoParameters'] if attributes[:'defaultPhaseTwoParameters'] raise 'You cannot provide both :defaultPhaseTwoParameters and :default_phase_two_parameters' if attributes.key?(:'defaultPhaseTwoParameters') && attributes.key?(:'default_phase_two_parameters') self.default_phase_two_parameters = attributes[:'default_phase_two_parameters'] if attributes[:'default_phase_two_parameters'] end |
Instance Attribute Details
#allowed_phase_one_parameters ⇒ OCI::Core::Models::AllowedPhaseOneParameters
This attribute is required.
12 13 14 |
# File 'lib/oci/core/models/allowed_ike_ip_sec_parameters.rb', line 12 def allowed_phase_one_parameters @allowed_phase_one_parameters end |
#allowed_phase_two_parameters ⇒ OCI::Core::Models::AllowedPhaseTwoParameters
This attribute is required.
16 17 18 |
# File 'lib/oci/core/models/allowed_ike_ip_sec_parameters.rb', line 16 def allowed_phase_two_parameters @allowed_phase_two_parameters end |
#default_phase_one_parameters ⇒ OCI::Core::Models::DefaultPhaseOneParameters
This attribute is required.
20 21 22 |
# File 'lib/oci/core/models/allowed_ike_ip_sec_parameters.rb', line 20 def default_phase_one_parameters @default_phase_one_parameters end |
#default_phase_two_parameters ⇒ OCI::Core::Models::DefaultPhaseTwoParameters
This attribute is required.
24 25 26 |
# File 'lib/oci/core/models/allowed_ike_ip_sec_parameters.rb', line 24 def default_phase_two_parameters @default_phase_two_parameters end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
27 28 29 30 31 32 33 34 35 36 |
# File 'lib/oci/core/models/allowed_ike_ip_sec_parameters.rb', line 27 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'allowed_phase_one_parameters': :'allowedPhaseOneParameters', 'allowed_phase_two_parameters': :'allowedPhaseTwoParameters', 'default_phase_one_parameters': :'defaultPhaseOneParameters', 'default_phase_two_parameters': :'defaultPhaseTwoParameters' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
39 40 41 42 43 44 45 46 47 48 |
# File 'lib/oci/core/models/allowed_ike_ip_sec_parameters.rb', line 39 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'allowed_phase_one_parameters': :'OCI::Core::Models::AllowedPhaseOneParameters', 'allowed_phase_two_parameters': :'OCI::Core::Models::AllowedPhaseTwoParameters', 'default_phase_one_parameters': :'OCI::Core::Models::DefaultPhaseOneParameters', 'default_phase_two_parameters': :'OCI::Core::Models::DefaultPhaseTwoParameters' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
98 99 100 101 102 103 104 105 106 |
# File 'lib/oci/core/models/allowed_ike_ip_sec_parameters.rb', line 98 def ==(other) return true if equal?(other) self.class == other.class && allowed_phase_one_parameters == other.allowed_phase_one_parameters && allowed_phase_two_parameters == other.allowed_phase_two_parameters && default_phase_one_parameters == other.default_phase_one_parameters && default_phase_two_parameters == other.default_phase_two_parameters end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/oci/core/models/allowed_ike_ip_sec_parameters.rb', line 131 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
111 112 113 |
# File 'lib/oci/core/models/allowed_ike_ip_sec_parameters.rb', line 111 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
120 121 122 |
# File 'lib/oci/core/models/allowed_ike_ip_sec_parameters.rb', line 120 def hash [allowed_phase_one_parameters, allowed_phase_two_parameters, default_phase_one_parameters, default_phase_two_parameters].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
164 165 166 167 168 169 170 171 172 173 |
# File 'lib/oci/core/models/allowed_ike_ip_sec_parameters.rb', line 164 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
158 159 160 |
# File 'lib/oci/core/models/allowed_ike_ip_sec_parameters.rb', line 158 def to_s to_hash.to_s end |