Class: OCI::Core::Models::AmdMilanBmLaunchInstancePlatformConfig

Inherits:
LaunchInstancePlatformConfig show all
Defined in:
lib/oci/core/models/amd_milan_bm_launch_instance_platform_config.rb

Overview

The platform configuration used when launching a bare metal instance with an E4 shape (the AMD Milan platform).

Constant Summary collapse

NUMA_NODES_PER_SOCKET_ENUM =
[
  NUMA_NODES_PER_SOCKET_NPS0 = 'NPS0'.freeze,
  NUMA_NODES_PER_SOCKET_NPS1 = 'NPS1'.freeze,
  NUMA_NODES_PER_SOCKET_NPS2 = 'NPS2'.freeze,
  NUMA_NODES_PER_SOCKET_NPS4 = 'NPS4'.freeze
].freeze

Constants inherited from LaunchInstancePlatformConfig

LaunchInstancePlatformConfig::TYPE_ENUM

Instance Attribute Summary collapse

Attributes inherited from LaunchInstancePlatformConfig

#is_measured_boot_enabled, #is_secure_boot_enabled, #is_trusted_platform_module_enabled, #type

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from LaunchInstancePlatformConfig

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ AmdMilanBmLaunchInstancePlatformConfig

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/oci/core/models/amd_milan_bm_launch_instance_platform_config.rb', line 61

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['type'] = 'AMD_MILAN_BM'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.numa_nodes_per_socket = attributes[:'numaNodesPerSocket'] if attributes[:'numaNodesPerSocket']
  self.numa_nodes_per_socket = "NPS1" if numa_nodes_per_socket.nil? && !attributes.key?(:'numaNodesPerSocket') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :numaNodesPerSocket and :numa_nodes_per_socket' if attributes.key?(:'numaNodesPerSocket') && attributes.key?(:'numa_nodes_per_socket')

  self.numa_nodes_per_socket = attributes[:'numa_nodes_per_socket'] if attributes[:'numa_nodes_per_socket']
  self.numa_nodes_per_socket = "NPS1" if numa_nodes_per_socket.nil? && !attributes.key?(:'numaNodesPerSocket') && !attributes.key?(:'numa_nodes_per_socket') # rubocop:disable Style/StringLiterals
end

Instance Attribute Details

#numa_nodes_per_socketString

The number of NUMA nodes per socket (NPS).

Returns:

  • (String)


23
24
25
# File 'lib/oci/core/models/amd_milan_bm_launch_instance_platform_config.rb', line 23

def numa_nodes_per_socket
  @numa_nodes_per_socket
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



26
27
28
29
30
31
32
33
34
35
36
# File 'lib/oci/core/models/amd_milan_bm_launch_instance_platform_config.rb', line 26

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'type': :'type',
    'is_secure_boot_enabled': :'isSecureBootEnabled',
    'is_trusted_platform_module_enabled': :'isTrustedPlatformModuleEnabled',
    'is_measured_boot_enabled': :'isMeasuredBootEnabled',
    'numa_nodes_per_socket': :'numaNodesPerSocket'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



39
40
41
42
43
44
45
46
47
48
49
# File 'lib/oci/core/models/amd_milan_bm_launch_instance_platform_config.rb', line 39

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'type': :'String',
    'is_secure_boot_enabled': :'BOOLEAN',
    'is_trusted_platform_module_enabled': :'BOOLEAN',
    'is_measured_boot_enabled': :'BOOLEAN',
    'numa_nodes_per_socket': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



95
96
97
98
99
100
101
102
103
104
# File 'lib/oci/core/models/amd_milan_bm_launch_instance_platform_config.rb', line 95

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    type == other.type &&
    is_secure_boot_enabled == other.is_secure_boot_enabled &&
    is_trusted_platform_module_enabled == other.is_trusted_platform_module_enabled &&
    is_measured_boot_enabled == other.is_measured_boot_enabled &&
    numa_nodes_per_socket == other.numa_nodes_per_socket
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/oci/core/models/amd_milan_bm_launch_instance_platform_config.rb', line 129

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


109
110
111
# File 'lib/oci/core/models/amd_milan_bm_launch_instance_platform_config.rb', line 109

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



118
119
120
# File 'lib/oci/core/models/amd_milan_bm_launch_instance_platform_config.rb', line 118

def hash
  [type, is_secure_boot_enabled, is_trusted_platform_module_enabled, is_measured_boot_enabled, numa_nodes_per_socket].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



162
163
164
165
166
167
168
169
170
171
# File 'lib/oci/core/models/amd_milan_bm_launch_instance_platform_config.rb', line 162

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



156
157
158
# File 'lib/oci/core/models/amd_milan_bm_launch_instance_platform_config.rb', line 156

def to_s
  to_hash.to_s
end