Class: OCI::Core::Models::AppCatalogListing
- Inherits:
-
Object
- Object
- OCI::Core::Models::AppCatalogListing
- Defined in:
- lib/oci/core/models/app_catalog_listing.rb
Overview
Listing details.
Instance Attribute Summary collapse
-
#contact_url ⇒ String
Listing’s contact URL.
-
#description ⇒ String
Description of the listing.
-
#display_name ⇒ String
A user-friendly name.
-
#listing_id ⇒ String
The OCID of the listing.
-
#publisher_logo_url ⇒ String
Publisher’s logo URL.
-
#publisher_name ⇒ String
Name of the publisher who published this listing.
-
#summary ⇒ String
Summary of the listing.
-
#time_published ⇒ DateTime
Date and time the listing was published, in [RFC3339](tools.ietf.org/html/rfc3339) format.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AppCatalogListing
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ AppCatalogListing
Initializes the object
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/oci/core/models/app_catalog_listing.rb', line 92 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.contact_url = attributes[:'contactUrl'] if attributes[:'contactUrl'] raise 'You cannot provide both :contactUrl and :contact_url' if attributes.key?(:'contactUrl') && attributes.key?(:'contact_url') self.contact_url = attributes[:'contact_url'] if attributes[:'contact_url'] self.description = attributes[:'description'] if attributes[:'description'] self.listing_id = attributes[:'listingId'] if attributes[:'listingId'] raise 'You cannot provide both :listingId and :listing_id' if attributes.key?(:'listingId') && attributes.key?(:'listing_id') self.listing_id = attributes[:'listing_id'] if attributes[:'listing_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.time_published = attributes[:'timePublished'] if attributes[:'timePublished'] raise 'You cannot provide both :timePublished and :time_published' if attributes.key?(:'timePublished') && attributes.key?(:'time_published') self.time_published = attributes[:'time_published'] if attributes[:'time_published'] self.publisher_logo_url = attributes[:'publisherLogoUrl'] if attributes[:'publisherLogoUrl'] raise 'You cannot provide both :publisherLogoUrl and :publisher_logo_url' if attributes.key?(:'publisherLogoUrl') && attributes.key?(:'publisher_logo_url') self.publisher_logo_url = attributes[:'publisher_logo_url'] if attributes[:'publisher_logo_url'] self.publisher_name = attributes[:'publisherName'] if attributes[:'publisherName'] raise 'You cannot provide both :publisherName and :publisher_name' if attributes.key?(:'publisherName') && attributes.key?(:'publisher_name') self.publisher_name = attributes[:'publisher_name'] if attributes[:'publisher_name'] self.summary = attributes[:'summary'] if attributes[:'summary'] end |
Instance Attribute Details
#contact_url ⇒ String
Listing’s contact URL.
12 13 14 |
# File 'lib/oci/core/models/app_catalog_listing.rb', line 12 def contact_url @contact_url end |
#description ⇒ String
Description of the listing.
16 17 18 |
# File 'lib/oci/core/models/app_catalog_listing.rb', line 16 def description @description end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
26 27 28 |
# File 'lib/oci/core/models/app_catalog_listing.rb', line 26 def display_name @display_name end |
#listing_id ⇒ String
The OCID of the listing.
20 21 22 |
# File 'lib/oci/core/models/app_catalog_listing.rb', line 20 def listing_id @listing_id end |
#publisher_logo_url ⇒ String
Publisher’s logo URL.
36 37 38 |
# File 'lib/oci/core/models/app_catalog_listing.rb', line 36 def publisher_logo_url @publisher_logo_url end |
#publisher_name ⇒ String
Name of the publisher who published this listing.
40 41 42 |
# File 'lib/oci/core/models/app_catalog_listing.rb', line 40 def publisher_name @publisher_name end |
#summary ⇒ String
Summary of the listing.
44 45 46 |
# File 'lib/oci/core/models/app_catalog_listing.rb', line 44 def summary @summary end |
#time_published ⇒ DateTime
Date and time the listing was published, in [RFC3339](tools.ietf.org/html/rfc3339) format. Example: 2018-03-20T12:32:53.532Z
32 33 34 |
# File 'lib/oci/core/models/app_catalog_listing.rb', line 32 def time_published @time_published end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/oci/core/models/app_catalog_listing.rb', line 47 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'contact_url': :'contactUrl', 'description': :'description', 'listing_id': :'listingId', 'display_name': :'displayName', 'time_published': :'timePublished', 'publisher_logo_url': :'publisherLogoUrl', 'publisher_name': :'publisherName', 'summary': :'summary' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/oci/core/models/app_catalog_listing.rb', line 63 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'contact_url': :'String', 'description': :'String', 'listing_id': :'String', 'display_name': :'String', 'time_published': :'DateTime', 'publisher_logo_url': :'String', 'publisher_name': :'String', 'summary': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/oci/core/models/app_catalog_listing.rb', line 146 def ==(other) return true if equal?(other) self.class == other.class && contact_url == other.contact_url && description == other.description && listing_id == other.listing_id && display_name == other.display_name && time_published == other.time_published && publisher_logo_url == other.publisher_logo_url && publisher_name == other.publisher_name && summary == other.summary end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/oci/core/models/app_catalog_listing.rb', line 183 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
163 164 165 |
# File 'lib/oci/core/models/app_catalog_listing.rb', line 163 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
172 173 174 |
# File 'lib/oci/core/models/app_catalog_listing.rb', line 172 def hash [contact_url, description, listing_id, display_name, time_published, publisher_logo_url, publisher_name, summary].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
216 217 218 219 220 221 222 223 224 225 |
# File 'lib/oci/core/models/app_catalog_listing.rb', line 216 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
210 211 212 |
# File 'lib/oci/core/models/app_catalog_listing.rb', line 210 def to_s to_hash.to_s end |