Class: OCI::Core::Models::AppCatalogSubscription
- Inherits:
-
Object
- Object
- OCI::Core::Models::AppCatalogSubscription
- Defined in:
- lib/oci/core/models/app_catalog_subscription.rb
Overview
a subscription for a listing resource version.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
The compartmentID of the subscription.
-
#display_name ⇒ String
A user-friendly name.
-
#listing_id ⇒ String
The ocid of the listing resource.
-
#listing_resource_id ⇒ String
Listing resource id.
-
#listing_resource_version ⇒ String
Listing resource version.
-
#publisher_name ⇒ String
Name of the publisher who published this listing.
-
#summary ⇒ String
The short summary to the listing.
-
#time_created ⇒ DateTime
Date and time at which the subscription was created, in [RFC3339](tools.ietf.org/html/rfc3339) format.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AppCatalogSubscription
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ AppCatalogSubscription
Initializes the object
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/oci/core/models/app_catalog_subscription.rb', line 92 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.publisher_name = attributes[:'publisherName'] if attributes[:'publisherName'] raise 'You cannot provide both :publisherName and :publisher_name' if attributes.key?(:'publisherName') && attributes.key?(:'publisher_name') self.publisher_name = attributes[:'publisher_name'] if attributes[:'publisher_name'] self.listing_id = attributes[:'listingId'] if attributes[:'listingId'] raise 'You cannot provide both :listingId and :listing_id' if attributes.key?(:'listingId') && attributes.key?(:'listing_id') self.listing_id = attributes[:'listing_id'] if attributes[:'listing_id'] self.listing_resource_version = attributes[:'listingResourceVersion'] if attributes[:'listingResourceVersion'] raise 'You cannot provide both :listingResourceVersion and :listing_resource_version' if attributes.key?(:'listingResourceVersion') && attributes.key?(:'listing_resource_version') self.listing_resource_version = attributes[:'listing_resource_version'] if attributes[:'listing_resource_version'] self.listing_resource_id = attributes[:'listingResourceId'] if attributes[:'listingResourceId'] raise 'You cannot provide both :listingResourceId and :listing_resource_id' if attributes.key?(:'listingResourceId') && attributes.key?(:'listing_resource_id') self.listing_resource_id = attributes[:'listing_resource_id'] if attributes[:'listing_resource_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.summary = attributes[:'summary'] if attributes[:'summary'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] end |
Instance Attribute Details
#compartment_id ⇒ String
The compartmentID of the subscription.
38 39 40 |
# File 'lib/oci/core/models/app_catalog_subscription.rb', line 38 def compartment_id @compartment_id end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
30 31 32 |
# File 'lib/oci/core/models/app_catalog_subscription.rb', line 30 def display_name @display_name end |
#listing_id ⇒ String
The ocid of the listing resource.
16 17 18 |
# File 'lib/oci/core/models/app_catalog_subscription.rb', line 16 def listing_id @listing_id end |
#listing_resource_id ⇒ String
Listing resource id.
24 25 26 |
# File 'lib/oci/core/models/app_catalog_subscription.rb', line 24 def listing_resource_id @listing_resource_id end |
#listing_resource_version ⇒ String
Listing resource version.
20 21 22 |
# File 'lib/oci/core/models/app_catalog_subscription.rb', line 20 def listing_resource_version @listing_resource_version end |
#publisher_name ⇒ String
Name of the publisher who published this listing.
12 13 14 |
# File 'lib/oci/core/models/app_catalog_subscription.rb', line 12 def publisher_name @publisher_name end |
#summary ⇒ String
The short summary to the listing.
34 35 36 |
# File 'lib/oci/core/models/app_catalog_subscription.rb', line 34 def summary @summary end |
#time_created ⇒ DateTime
Date and time at which the subscription was created, in [RFC3339](tools.ietf.org/html/rfc3339) format. Example: 2018-03-20T12:32:53.532Z
44 45 46 |
# File 'lib/oci/core/models/app_catalog_subscription.rb', line 44 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/oci/core/models/app_catalog_subscription.rb', line 47 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'publisher_name': :'publisherName', 'listing_id': :'listingId', 'listing_resource_version': :'listingResourceVersion', 'listing_resource_id': :'listingResourceId', 'display_name': :'displayName', 'summary': :'summary', 'compartment_id': :'compartmentId', 'time_created': :'timeCreated' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/oci/core/models/app_catalog_subscription.rb', line 63 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'publisher_name': :'String', 'listing_id': :'String', 'listing_resource_version': :'String', 'listing_resource_id': :'String', 'display_name': :'String', 'summary': :'String', 'compartment_id': :'String', 'time_created': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/oci/core/models/app_catalog_subscription.rb', line 150 def ==(other) return true if equal?(other) self.class == other.class && publisher_name == other.publisher_name && listing_id == other.listing_id && listing_resource_version == other.listing_resource_version && listing_resource_id == other.listing_resource_id && display_name == other.display_name && summary == other.summary && compartment_id == other.compartment_id && time_created == other.time_created end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/oci/core/models/app_catalog_subscription.rb', line 187 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
167 168 169 |
# File 'lib/oci/core/models/app_catalog_subscription.rb', line 167 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
176 177 178 |
# File 'lib/oci/core/models/app_catalog_subscription.rb', line 176 def hash [publisher_name, listing_id, listing_resource_version, listing_resource_id, display_name, summary, compartment_id, time_created].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
220 221 222 223 224 225 226 227 228 229 |
# File 'lib/oci/core/models/app_catalog_subscription.rb', line 220 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
214 215 216 |
# File 'lib/oci/core/models/app_catalog_subscription.rb', line 214 def to_s to_hash.to_s end |