Class: OCI::Core::Models::AttachIScsiVolumeDetails
- Inherits:
-
AttachVolumeDetails
- Object
- AttachVolumeDetails
- OCI::Core::Models::AttachIScsiVolumeDetails
- Defined in:
- lib/oci/core/models/attach_i_scsi_volume_details.rb
Overview
AttachIScsiVolumeDetails model.
Constant Summary collapse
- ENCRYPTION_IN_TRANSIT_TYPE_ENUM =
[ ENCRYPTION_IN_TRANSIT_TYPE_NONE = 'NONE'.freeze, ENCRYPTION_IN_TRANSIT_TYPE_BM_ENCRYPTION_IN_TRANSIT = 'BM_ENCRYPTION_IN_TRANSIT'.freeze ].freeze
Instance Attribute Summary collapse
-
#encryption_in_transit_type ⇒ String
Refer the top-level definition of encryptionInTransitType.
-
#is_agent_auto_iscsi_login_enabled ⇒ BOOLEAN
Whether to enable Oracle Cloud Agent to perform the iSCSI login and logout commands after the volume attach or detach operations for non multipath-enabled iSCSI attachments.
-
#use_chap ⇒ BOOLEAN
Whether to use CHAP authentication for the volume attachment.
Attributes inherited from AttachVolumeDetails
#device, #display_name, #instance_id, #is_read_only, #is_shareable, #type, #volume_id
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AttachIScsiVolumeDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from AttachVolumeDetails
Constructor Details
#initialize(attributes = {}) ⇒ AttachIScsiVolumeDetails
Initializes the object
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/oci/core/models/attach_i_scsi_volume_details.rb', line 83 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['type'] = 'iscsi' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.use_chap = attributes[:'useChap'] unless attributes[:'useChap'].nil? raise 'You cannot provide both :useChap and :use_chap' if attributes.key?(:'useChap') && attributes.key?(:'use_chap') self.use_chap = attributes[:'use_chap'] unless attributes[:'use_chap'].nil? self.encryption_in_transit_type = attributes[:'encryptionInTransitType'] if attributes[:'encryptionInTransitType'] self.encryption_in_transit_type = "NONE" if encryption_in_transit_type.nil? && !attributes.key?(:'encryptionInTransitType') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :encryptionInTransitType and :encryption_in_transit_type' if attributes.key?(:'encryptionInTransitType') && attributes.key?(:'encryption_in_transit_type') self.encryption_in_transit_type = attributes[:'encryption_in_transit_type'] if attributes[:'encryption_in_transit_type'] self.encryption_in_transit_type = "NONE" if encryption_in_transit_type.nil? && !attributes.key?(:'encryptionInTransitType') && !attributes.key?(:'encryption_in_transit_type') # rubocop:disable Style/StringLiterals self.is_agent_auto_iscsi_login_enabled = attributes[:'isAgentAutoIscsiLoginEnabled'] unless attributes[:'isAgentAutoIscsiLoginEnabled'].nil? raise 'You cannot provide both :isAgentAutoIscsiLoginEnabled and :is_agent_auto_iscsi_login_enabled' if attributes.key?(:'isAgentAutoIscsiLoginEnabled') && attributes.key?(:'is_agent_auto_iscsi_login_enabled') self.is_agent_auto_iscsi_login_enabled = attributes[:'is_agent_auto_iscsi_login_enabled'] unless attributes[:'is_agent_auto_iscsi_login_enabled'].nil? end |
Instance Attribute Details
#encryption_in_transit_type ⇒ String
Refer the top-level definition of encryptionInTransitType. The default value is NONE.
25 26 27 |
# File 'lib/oci/core/models/attach_i_scsi_volume_details.rb', line 25 def encryption_in_transit_type @encryption_in_transit_type end |
#is_agent_auto_iscsi_login_enabled ⇒ BOOLEAN
Whether to enable Oracle Cloud Agent to perform the iSCSI login and logout commands after the volume attach or detach operations for non multipath-enabled iSCSI attachments.
30 31 32 |
# File 'lib/oci/core/models/attach_i_scsi_volume_details.rb', line 30 def is_agent_auto_iscsi_login_enabled @is_agent_auto_iscsi_login_enabled end |
#use_chap ⇒ BOOLEAN
Whether to use CHAP authentication for the volume attachment. Defaults to false.
19 20 21 |
# File 'lib/oci/core/models/attach_i_scsi_volume_details.rb', line 19 def use_chap @use_chap end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 |
# File 'lib/oci/core/models/attach_i_scsi_volume_details.rb', line 33 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'device': :'device', 'display_name': :'displayName', 'instance_id': :'instanceId', 'is_read_only': :'isReadOnly', 'is_shareable': :'isShareable', 'type': :'type', 'volume_id': :'volumeId', 'use_chap': :'useChap', 'encryption_in_transit_type': :'encryptionInTransitType', 'is_agent_auto_iscsi_login_enabled': :'isAgentAutoIscsiLoginEnabled' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/oci/core/models/attach_i_scsi_volume_details.rb', line 51 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'device': :'String', 'display_name': :'String', 'instance_id': :'String', 'is_read_only': :'BOOLEAN', 'is_shareable': :'BOOLEAN', 'type': :'String', 'volume_id': :'String', 'use_chap': :'BOOLEAN', 'encryption_in_transit_type': :'String', 'is_agent_auto_iscsi_login_enabled': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/oci/core/models/attach_i_scsi_volume_details.rb', line 129 def ==(other) return true if equal?(other) self.class == other.class && device == other.device && display_name == other.display_name && instance_id == other.instance_id && is_read_only == other.is_read_only && is_shareable == other.is_shareable && type == other.type && volume_id == other.volume_id && use_chap == other.use_chap && encryption_in_transit_type == other.encryption_in_transit_type && is_agent_auto_iscsi_login_enabled == other.is_agent_auto_iscsi_login_enabled end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/oci/core/models/attach_i_scsi_volume_details.rb', line 168 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
148 149 150 |
# File 'lib/oci/core/models/attach_i_scsi_volume_details.rb', line 148 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
157 158 159 |
# File 'lib/oci/core/models/attach_i_scsi_volume_details.rb', line 157 def hash [device, display_name, instance_id, is_read_only, is_shareable, type, volume_id, use_chap, encryption_in_transit_type, is_agent_auto_iscsi_login_enabled].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
201 202 203 204 205 206 207 208 209 210 |
# File 'lib/oci/core/models/attach_i_scsi_volume_details.rb', line 201 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
195 196 197 |
# File 'lib/oci/core/models/attach_i_scsi_volume_details.rb', line 195 def to_s to_hash.to_s end |