Class: OCI::Core::Models::AttachLoadBalancerDetails
- Inherits:
-
Object
- Object
- OCI::Core::Models::AttachLoadBalancerDetails
- Defined in:
- lib/oci/core/models/attach_load_balancer_details.rb
Overview
Represents a load balancer that is to be attached to an instance pool.
Instance Attribute Summary collapse
-
#backend_set_name ⇒ String
[Required] The name of the backend set on the load balancer to add instances to.
-
#load_balancer_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the load balancer to attach to the instance pool.
-
#port ⇒ Integer
[Required] The port value to use when creating the backend set.
-
#vnic_selection ⇒ String
[Required] Indicates which VNIC on each instance in the pool should be used to associate with the load balancer.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AttachLoadBalancerDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ AttachLoadBalancerDetails
Initializes the object
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/oci/core/models/attach_load_balancer_details.rb', line 64 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.load_balancer_id = attributes[:'loadBalancerId'] if attributes[:'loadBalancerId'] raise 'You cannot provide both :loadBalancerId and :load_balancer_id' if attributes.key?(:'loadBalancerId') && attributes.key?(:'load_balancer_id') self.load_balancer_id = attributes[:'load_balancer_id'] if attributes[:'load_balancer_id'] self.backend_set_name = attributes[:'backendSetName'] if attributes[:'backendSetName'] raise 'You cannot provide both :backendSetName and :backend_set_name' if attributes.key?(:'backendSetName') && attributes.key?(:'backend_set_name') self.backend_set_name = attributes[:'backend_set_name'] if attributes[:'backend_set_name'] self.port = attributes[:'port'] if attributes[:'port'] self.vnic_selection = attributes[:'vnicSelection'] if attributes[:'vnicSelection'] raise 'You cannot provide both :vnicSelection and :vnic_selection' if attributes.key?(:'vnicSelection') && attributes.key?(:'vnic_selection') self.vnic_selection = attributes[:'vnic_selection'] if attributes[:'vnic_selection'] end |
Instance Attribute Details
#backend_set_name ⇒ String
[Required] The name of the backend set on the load balancer to add instances to.
17 18 19 |
# File 'lib/oci/core/models/attach_load_balancer_details.rb', line 17 def backend_set_name @backend_set_name end |
#load_balancer_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the load balancer to attach to the instance pool.
13 14 15 |
# File 'lib/oci/core/models/attach_load_balancer_details.rb', line 13 def load_balancer_id @load_balancer_id end |
#port ⇒ Integer
[Required] The port value to use when creating the backend set.
21 22 23 |
# File 'lib/oci/core/models/attach_load_balancer_details.rb', line 21 def port @port end |
#vnic_selection ⇒ String
[Required] Indicates which VNIC on each instance in the pool should be used to associate with the load balancer. Possible values are "PrimaryVnic" or the displayName of one of the secondary VNICs on the instance configuration that is associated with the instance pool.
28 29 30 |
# File 'lib/oci/core/models/attach_load_balancer_details.rb', line 28 def vnic_selection @vnic_selection end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 40 |
# File 'lib/oci/core/models/attach_load_balancer_details.rb', line 31 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'load_balancer_id': :'loadBalancerId', 'backend_set_name': :'backendSetName', 'port': :'port', 'vnic_selection': :'vnicSelection' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
43 44 45 46 47 48 49 50 51 52 |
# File 'lib/oci/core/models/attach_load_balancer_details.rb', line 43 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'load_balancer_id': :'String', 'backend_set_name': :'String', 'port': :'Integer', 'vnic_selection': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
98 99 100 101 102 103 104 105 106 |
# File 'lib/oci/core/models/attach_load_balancer_details.rb', line 98 def ==(other) return true if equal?(other) self.class == other.class && load_balancer_id == other.load_balancer_id && backend_set_name == other.backend_set_name && port == other.port && vnic_selection == other.vnic_selection end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/oci/core/models/attach_load_balancer_details.rb', line 131 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
111 112 113 |
# File 'lib/oci/core/models/attach_load_balancer_details.rb', line 111 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
120 121 122 |
# File 'lib/oci/core/models/attach_load_balancer_details.rb', line 120 def hash [load_balancer_id, backend_set_name, port, vnic_selection].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
164 165 166 167 168 169 170 171 172 173 |
# File 'lib/oci/core/models/attach_load_balancer_details.rb', line 164 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
158 159 160 |
# File 'lib/oci/core/models/attach_load_balancer_details.rb', line 158 def to_s to_hash.to_s end |