Class: OCI::Core::Models::BgpSessionInfo

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/core/models/bgp_session_info.rb

Overview

Information for establishing a BGP session for the IPSec tunnel.

Constant Summary collapse

BGP_STATE_ENUM =
[
  BGP_STATE_UP = 'UP'.freeze,
  BGP_STATE_DOWN = 'DOWN'.freeze,
  BGP_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
BGP_IPV6_STATE_ENUM =
[
  BGP_IPV6_STATE_UP = 'UP'.freeze,
  BGP_IPV6_STATE_DOWN = 'DOWN'.freeze,
  BGP_IPV6_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ BgpSessionInfo

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/oci/core/models/bgp_session_info.rb', line 160

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.oracle_interface_ip = attributes[:'oracleInterfaceIp'] if attributes[:'oracleInterfaceIp']

  raise 'You cannot provide both :oracleInterfaceIp and :oracle_interface_ip' if attributes.key?(:'oracleInterfaceIp') && attributes.key?(:'oracle_interface_ip')

  self.oracle_interface_ip = attributes[:'oracle_interface_ip'] if attributes[:'oracle_interface_ip']

  self.customer_interface_ip = attributes[:'customerInterfaceIp'] if attributes[:'customerInterfaceIp']

  raise 'You cannot provide both :customerInterfaceIp and :customer_interface_ip' if attributes.key?(:'customerInterfaceIp') && attributes.key?(:'customer_interface_ip')

  self.customer_interface_ip = attributes[:'customer_interface_ip'] if attributes[:'customer_interface_ip']

  self.oracle_interface_ipv6 = attributes[:'oracleInterfaceIpv6'] if attributes[:'oracleInterfaceIpv6']

  raise 'You cannot provide both :oracleInterfaceIpv6 and :oracle_interface_ipv6' if attributes.key?(:'oracleInterfaceIpv6') && attributes.key?(:'oracle_interface_ipv6')

  self.oracle_interface_ipv6 = attributes[:'oracle_interface_ipv6'] if attributes[:'oracle_interface_ipv6']

  self.customer_interface_ipv6 = attributes[:'customerInterfaceIpv6'] if attributes[:'customerInterfaceIpv6']

  raise 'You cannot provide both :customerInterfaceIpv6 and :customer_interface_ipv6' if attributes.key?(:'customerInterfaceIpv6') && attributes.key?(:'customer_interface_ipv6')

  self.customer_interface_ipv6 = attributes[:'customer_interface_ipv6'] if attributes[:'customer_interface_ipv6']

  self.oracle_bgp_asn = attributes[:'oracleBgpAsn'] if attributes[:'oracleBgpAsn']

  raise 'You cannot provide both :oracleBgpAsn and :oracle_bgp_asn' if attributes.key?(:'oracleBgpAsn') && attributes.key?(:'oracle_bgp_asn')

  self.oracle_bgp_asn = attributes[:'oracle_bgp_asn'] if attributes[:'oracle_bgp_asn']

  self.customer_bgp_asn = attributes[:'customerBgpAsn'] if attributes[:'customerBgpAsn']

  raise 'You cannot provide both :customerBgpAsn and :customer_bgp_asn' if attributes.key?(:'customerBgpAsn') && attributes.key?(:'customer_bgp_asn')

  self.customer_bgp_asn = attributes[:'customer_bgp_asn'] if attributes[:'customer_bgp_asn']

  self.bgp_state = attributes[:'bgpState'] if attributes[:'bgpState']

  raise 'You cannot provide both :bgpState and :bgp_state' if attributes.key?(:'bgpState') && attributes.key?(:'bgp_state')

  self.bgp_state = attributes[:'bgp_state'] if attributes[:'bgp_state']

  self.bgp_ipv6_state = attributes[:'bgpIpv6State'] if attributes[:'bgpIpv6State']

  raise 'You cannot provide both :bgpIpv6State and :bgp_ipv6_state' if attributes.key?(:'bgpIpv6State') && attributes.key?(:'bgp_ipv6_state')

  self.bgp_ipv6_state = attributes[:'bgp_ipv6_state'] if attributes[:'bgp_ipv6_state']
end

Instance Attribute Details

#bgp_ipv6_stateString

The state of the BGP IPv6 session.

Returns:

  • (String)


112
113
114
# File 'lib/oci/core/models/bgp_session_info.rb', line 112

def bgp_ipv6_state
  @bgp_ipv6_state
end

#bgp_stateString

The state of the BGP session.

Returns:

  • (String)


107
108
109
# File 'lib/oci/core/models/bgp_session_info.rb', line 107

def bgp_state
  @bgp_state
end

#customer_bgp_asnString

If the tunnel’s routing attribute is set to BGP (see IPSecConnectionTunnel), this ASN is required and used for the tunnel’s BGP session. This is the ASN of the network on the CPE end of the BGP session. Can be a 2-byte or 4-byte ASN. Uses "asplain" format.

If the tunnel uses static routing, the customerBgpAsn must be null.

Example: 12345 (2-byte) or 1587232876 (4-byte)

Returns:

  • (String)


102
103
104
# File 'lib/oci/core/models/bgp_session_info.rb', line 102

def customer_bgp_asn
  @customer_bgp_asn
end

#customer_interface_ipString

The IP address for the CPE end of the inside tunnel interface.

If the tunnel’s routing attribute is set to BGP (see IPSecConnectionTunnel), this IP address is required and used for the tunnel’s BGP session.

If routing is instead set to STATIC, this IP address is optional. You can set this IP address so you can troubleshoot or monitor the tunnel.

The value must be a /30 or /31.

Example: 10.0.0.5/31

Returns:

  • (String)


53
54
55
# File 'lib/oci/core/models/bgp_session_info.rb', line 53

def customer_interface_ip
  @customer_interface_ip
end

#customer_interface_ipv6String

The IPv6 address for the CPE end of the inside tunnel interface. This IP address is optional.

If the tunnel’s routing attribute is set to BGP (see IPSecConnectionTunnel), this IP address is used for the tunnel’s BGP session.

If routing is instead set to STATIC, you can set this IP address to troubleshoot or monitor the tunnel.

Only subnet masks from /64 up to /127 are allowed.

Example: 2001:db8::1/64

Returns:

  • (String)


85
86
87
# File 'lib/oci/core/models/bgp_session_info.rb', line 85

def customer_interface_ipv6
  @customer_interface_ipv6
end

#oracle_bgp_asnString

The Oracle BGP ASN.

Returns:

  • (String)


90
91
92
# File 'lib/oci/core/models/bgp_session_info.rb', line 90

def oracle_bgp_asn
  @oracle_bgp_asn
end

#oracle_interface_ipString

The IP address for the Oracle end of the inside tunnel interface.

If the tunnel’s routing attribute is set to BGP (see IPSecConnectionTunnel), this IP address is required and used for the tunnel’s BGP session.

If routing is instead set to STATIC, this IP address is optional. You can set this IP address so you can troubleshoot or monitor the tunnel.

The value must be a /30 or /31.

Example: 10.0.0.4/31

Returns:

  • (String)


37
38
39
# File 'lib/oci/core/models/bgp_session_info.rb', line 37

def oracle_interface_ip
  @oracle_interface_ip
end

#oracle_interface_ipv6String

The IPv6 address for the Oracle end of the inside tunnel interface. This IP address is optional.

If the tunnel’s routing attribute is set to BGP (see IPSecConnectionTunnel), this IP address is used for the tunnel’s BGP session.

If routing is instead set to STATIC, you can set this IP address to troubleshoot or monitor the tunnel.

Only subnet masks from /64 up to /127 are allowed.

Example: 2001:db8::1/64

Returns:

  • (String)


69
70
71
# File 'lib/oci/core/models/bgp_session_info.rb', line 69

def oracle_interface_ipv6
  @oracle_interface_ipv6
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/oci/core/models/bgp_session_info.rb', line 115

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'oracle_interface_ip': :'oracleInterfaceIp',
    'customer_interface_ip': :'customerInterfaceIp',
    'oracle_interface_ipv6': :'oracleInterfaceIpv6',
    'customer_interface_ipv6': :'customerInterfaceIpv6',
    'oracle_bgp_asn': :'oracleBgpAsn',
    'customer_bgp_asn': :'customerBgpAsn',
    'bgp_state': :'bgpState',
    'bgp_ipv6_state': :'bgpIpv6State'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/oci/core/models/bgp_session_info.rb', line 131

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'oracle_interface_ip': :'String',
    'customer_interface_ip': :'String',
    'oracle_interface_ipv6': :'String',
    'customer_interface_ipv6': :'String',
    'oracle_bgp_asn': :'String',
    'customer_bgp_asn': :'String',
    'bgp_state': :'String',
    'bgp_ipv6_state': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



248
249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/oci/core/models/bgp_session_info.rb', line 248

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    oracle_interface_ip == other.oracle_interface_ip &&
    customer_interface_ip == other.customer_interface_ip &&
    oracle_interface_ipv6 == other.oracle_interface_ipv6 &&
    customer_interface_ipv6 == other.customer_interface_ipv6 &&
    oracle_bgp_asn == other.oracle_bgp_asn &&
    customer_bgp_asn == other.customer_bgp_asn &&
    bgp_state == other.bgp_state &&
    bgp_ipv6_state == other.bgp_ipv6_state
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
# File 'lib/oci/core/models/bgp_session_info.rb', line 285

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


265
266
267
# File 'lib/oci/core/models/bgp_session_info.rb', line 265

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



274
275
276
# File 'lib/oci/core/models/bgp_session_info.rb', line 274

def hash
  [oracle_interface_ip, customer_interface_ip, oracle_interface_ipv6, customer_interface_ipv6, oracle_bgp_asn, customer_bgp_asn, bgp_state, bgp_ipv6_state].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



318
319
320
321
322
323
324
325
326
327
# File 'lib/oci/core/models/bgp_session_info.rb', line 318

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



312
313
314
# File 'lib/oci/core/models/bgp_session_info.rb', line 312

def to_s
  to_hash.to_s
end