Class: OCI::Core::Models::BootVolume

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/core/models/boot_volume.rb

Overview

A detachable boot volume device that contains the image used to boot a Compute instance. For more information, see [Overview of Boot Volumes](docs.cloud.oracle.com/iaas/Content/Block/Concepts/bootvolumes.htm).

To use any of the API operations, you must be authorized in an IAM policy. If you’re not authorized, talk to an administrator. If you’re an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/iaas/Content/Identity/Concepts/policygetstarted.htm).

Warning: Oracle recommends that you avoid using any confidential information when you supply string values using the API.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze,
  LIFECYCLE_STATE_RESTORING = 'RESTORING'.freeze,
  LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze,
  LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze,
  LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze,
  LIFECYCLE_STATE_FAULTY = 'FAULTY'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ BootVolume

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/oci/core/models/boot_volume.rb', line 223

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain']

  raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain')

  self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

  raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

  self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.id = attributes[:'id'] if attributes[:'id']

  self.image_id = attributes[:'imageId'] if attributes[:'imageId']

  raise 'You cannot provide both :imageId and :image_id' if attributes.key?(:'imageId') && attributes.key?(:'image_id')

  self.image_id = attributes[:'image_id'] if attributes[:'image_id']

  self.is_hydrated = attributes[:'isHydrated'] unless attributes[:'isHydrated'].nil?

  raise 'You cannot provide both :isHydrated and :is_hydrated' if attributes.key?(:'isHydrated') && attributes.key?(:'is_hydrated')

  self.is_hydrated = attributes[:'is_hydrated'] unless attributes[:'is_hydrated'].nil?

  self.vpus_per_gb = attributes[:'vpusPerGB'] if attributes[:'vpusPerGB']

  raise 'You cannot provide both :vpusPerGB and :vpus_per_gb' if attributes.key?(:'vpusPerGB') && attributes.key?(:'vpus_per_gb')

  self.vpus_per_gb = attributes[:'vpus_per_gb'] if attributes[:'vpus_per_gb']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.size_in_gbs = attributes[:'sizeInGBs'] if attributes[:'sizeInGBs']

  raise 'You cannot provide both :sizeInGBs and :size_in_gbs' if attributes.key?(:'sizeInGBs') && attributes.key?(:'size_in_gbs')

  self.size_in_gbs = attributes[:'size_in_gbs'] if attributes[:'size_in_gbs']

  self.size_in_mbs = attributes[:'sizeInMBs'] if attributes[:'sizeInMBs']

  raise 'You cannot provide both :sizeInMBs and :size_in_mbs' if attributes.key?(:'sizeInMBs') && attributes.key?(:'size_in_mbs')

  self.size_in_mbs = attributes[:'size_in_mbs'] if attributes[:'size_in_mbs']

  self.source_details = attributes[:'sourceDetails'] if attributes[:'sourceDetails']

  raise 'You cannot provide both :sourceDetails and :source_details' if attributes.key?(:'sourceDetails') && attributes.key?(:'source_details')

  self.source_details = attributes[:'source_details'] if attributes[:'source_details']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.volume_group_id = attributes[:'volumeGroupId'] if attributes[:'volumeGroupId']

  raise 'You cannot provide both :volumeGroupId and :volume_group_id' if attributes.key?(:'volumeGroupId') && attributes.key?(:'volume_group_id')

  self.volume_group_id = attributes[:'volume_group_id'] if attributes[:'volume_group_id']

  self.kms_key_id = attributes[:'kmsKeyId'] if attributes[:'kmsKeyId']

  raise 'You cannot provide both :kmsKeyId and :kms_key_id' if attributes.key?(:'kmsKeyId') && attributes.key?(:'kms_key_id')

  self.kms_key_id = attributes[:'kms_key_id'] if attributes[:'kms_key_id']

  self.is_auto_tune_enabled = attributes[:'isAutoTuneEnabled'] unless attributes[:'isAutoTuneEnabled'].nil?

  raise 'You cannot provide both :isAutoTuneEnabled and :is_auto_tune_enabled' if attributes.key?(:'isAutoTuneEnabled') && attributes.key?(:'is_auto_tune_enabled')

  self.is_auto_tune_enabled = attributes[:'is_auto_tune_enabled'] unless attributes[:'is_auto_tune_enabled'].nil?

  self.auto_tuned_vpus_per_gb = attributes[:'autoTunedVpusPerGB'] if attributes[:'autoTunedVpusPerGB']

  raise 'You cannot provide both :autoTunedVpusPerGB and :auto_tuned_vpus_per_gb' if attributes.key?(:'autoTunedVpusPerGB') && attributes.key?(:'auto_tuned_vpus_per_gb')

  self.auto_tuned_vpus_per_gb = attributes[:'auto_tuned_vpus_per_gb'] if attributes[:'auto_tuned_vpus_per_gb']

  self.boot_volume_replicas = attributes[:'bootVolumeReplicas'] if attributes[:'bootVolumeReplicas']

  raise 'You cannot provide both :bootVolumeReplicas and :boot_volume_replicas' if attributes.key?(:'bootVolumeReplicas') && attributes.key?(:'boot_volume_replicas')

  self.boot_volume_replicas = attributes[:'boot_volume_replicas'] if attributes[:'boot_volume_replicas']
end

Instance Attribute Details

#auto_tuned_vpus_per_gbInteger

The number of Volume Performance Units per GB that this boot volume is effectively tuned to when it’s idle.

Returns:

  • (Integer)


135
136
137
# File 'lib/oci/core/models/boot_volume.rb', line 135

def auto_tuned_vpus_per_gb
  @auto_tuned_vpus_per_gb
end

#availability_domainString

[Required] The availability domain of the boot volume.

Example: Uocm:PHX-AD-1

Returns:

  • (String)


35
36
37
# File 'lib/oci/core/models/boot_volume.rb', line 35

def availability_domain
  @availability_domain
end

#boot_volume_replicasArray<OCI::Core::Models::BootVolumeReplicaInfo>

The list of boot volume replicas of this boot volume



139
140
141
# File 'lib/oci/core/models/boot_volume.rb', line 139

def boot_volume_replicas
  @boot_volume_replicas
end

#compartment_idString

[Required] The OCID of the compartment that contains the boot volume.

Returns:

  • (String)


39
40
41
# File 'lib/oci/core/models/boot_volume.rb', line 39

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).

Example: ‘{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


47
48
49
# File 'lib/oci/core/models/boot_volume.rb', line 47

def defined_tags
  @defined_tags
end

#display_nameString

A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.

Returns:

  • (String)


59
60
61
# File 'lib/oci/core/models/boot_volume.rb', line 59

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).

Example: ‘"Finance"`

Returns:

  • (Hash<String, String>)


67
68
69
# File 'lib/oci/core/models/boot_volume.rb', line 67

def freeform_tags
  @freeform_tags
end

#idString

[Required] The boot volume’s Oracle ID (OCID).

Returns:

  • (String)


71
72
73
# File 'lib/oci/core/models/boot_volume.rb', line 71

def id
  @id
end

#image_idString

The image OCID used to create the boot volume.

Returns:

  • (String)


75
76
77
# File 'lib/oci/core/models/boot_volume.rb', line 75

def image_id
  @image_id
end

#is_auto_tune_enabledBOOLEAN

Specifies whether the auto-tune performance is enabled for this boot volume.

Returns:

  • (BOOLEAN)


130
131
132
# File 'lib/oci/core/models/boot_volume.rb', line 130

def is_auto_tune_enabled
  @is_auto_tune_enabled
end

#is_hydratedBOOLEAN

Specifies whether the boot volume’s data has finished copying from the source boot volume or boot volume backup.

Returns:

  • (BOOLEAN)


81
82
83
# File 'lib/oci/core/models/boot_volume.rb', line 81

def is_hydrated
  @is_hydrated
end

#kms_key_idString

The OCID of the Key Management master encryption key assigned to the boot volume.

Returns:

  • (String)


125
126
127
# File 'lib/oci/core/models/boot_volume.rb', line 125

def kms_key_id
  @kms_key_id
end

#lifecycle_stateString

[Required] The current state of a boot volume.

Returns:

  • (String)


98
99
100
# File 'lib/oci/core/models/boot_volume.rb', line 98

def lifecycle_state
  @lifecycle_state
end

#size_in_gbsInteger

The size of the boot volume in GBs.

Returns:

  • (Integer)


102
103
104
# File 'lib/oci/core/models/boot_volume.rb', line 102

def size_in_gbs
  @size_in_gbs
end

#size_in_mbsInteger

[Required] The size of the volume in MBs. The value must be a multiple of 1024. This field is deprecated. Please use sizeInGBs.

Returns:

  • (Integer)


108
109
110
# File 'lib/oci/core/models/boot_volume.rb', line 108

def size_in_mbs
  @size_in_mbs
end

#source_detailsOCI::Core::Models::BootVolumeSourceDetails



111
112
113
# File 'lib/oci/core/models/boot_volume.rb', line 111

def source_details
  @source_details
end

#system_tagsHash<String, Hash<String, Object>>

System tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


53
54
55
# File 'lib/oci/core/models/boot_volume.rb', line 53

def system_tags
  @system_tags
end

#time_createdDateTime

[Required] The date and time the boot volume was created. Format defined by [RFC3339](tools.ietf.org/html/rfc3339).

Returns:

  • (DateTime)


117
118
119
# File 'lib/oci/core/models/boot_volume.rb', line 117

def time_created
  @time_created
end

#volume_group_idString

The OCID of the source volume group.

Returns:

  • (String)


121
122
123
# File 'lib/oci/core/models/boot_volume.rb', line 121

def volume_group_id
  @volume_group_id
end

#vpus_per_gbInteger

The number of volume performance units (VPUs) that will be applied to this boot volume per GB, representing the Block Volume service’s elastic performance options. See [Block Volume Elastic Performance](docs.cloud.oracle.com/iaas/Content/Block/Concepts/blockvolumeelasticperformance.htm) for more information.

Allowed values:

* `10`: Represents Balanced option.

* `20`: Represents Higher Performance option.

Returns:

  • (Integer)


94
95
96
# File 'lib/oci/core/models/boot_volume.rb', line 94

def vpus_per_gb
  @vpus_per_gb
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/oci/core/models/boot_volume.rb', line 142

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'availability_domain': :'availabilityDomain',
    'compartment_id': :'compartmentId',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags',
    'display_name': :'displayName',
    'freeform_tags': :'freeformTags',
    'id': :'id',
    'image_id': :'imageId',
    'is_hydrated': :'isHydrated',
    'vpus_per_gb': :'vpusPerGB',
    'lifecycle_state': :'lifecycleState',
    'size_in_gbs': :'sizeInGBs',
    'size_in_mbs': :'sizeInMBs',
    'source_details': :'sourceDetails',
    'time_created': :'timeCreated',
    'volume_group_id': :'volumeGroupId',
    'kms_key_id': :'kmsKeyId',
    'is_auto_tune_enabled': :'isAutoTuneEnabled',
    'auto_tuned_vpus_per_gb': :'autoTunedVpusPerGB',
    'boot_volume_replicas': :'bootVolumeReplicas'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/oci/core/models/boot_volume.rb', line 170

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'availability_domain': :'String',
    'compartment_id': :'String',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>',
    'display_name': :'String',
    'freeform_tags': :'Hash<String, String>',
    'id': :'String',
    'image_id': :'String',
    'is_hydrated': :'BOOLEAN',
    'vpus_per_gb': :'Integer',
    'lifecycle_state': :'String',
    'size_in_gbs': :'Integer',
    'size_in_mbs': :'Integer',
    'source_details': :'OCI::Core::Models::BootVolumeSourceDetails',
    'time_created': :'DateTime',
    'volume_group_id': :'String',
    'kms_key_id': :'String',
    'is_auto_tune_enabled': :'BOOLEAN',
    'auto_tuned_vpus_per_gb': :'Integer',
    'boot_volume_replicas': :'Array<OCI::Core::Models::BootVolumeReplicaInfo>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
# File 'lib/oci/core/models/boot_volume.rb', line 366

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    availability_domain == other.availability_domain &&
    compartment_id == other.compartment_id &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags &&
    display_name == other.display_name &&
    freeform_tags == other.freeform_tags &&
    id == other.id &&
    image_id == other.image_id &&
    is_hydrated == other.is_hydrated &&
    vpus_per_gb == other.vpus_per_gb &&
    lifecycle_state == other.lifecycle_state &&
    size_in_gbs == other.size_in_gbs &&
    size_in_mbs == other.size_in_mbs &&
    source_details == other.source_details &&
    time_created == other.time_created &&
    volume_group_id == other.volume_group_id &&
    kms_key_id == other.kms_key_id &&
    is_auto_tune_enabled == other.is_auto_tune_enabled &&
    auto_tuned_vpus_per_gb == other.auto_tuned_vpus_per_gb &&
    boot_volume_replicas == other.boot_volume_replicas
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
# File 'lib/oci/core/models/boot_volume.rb', line 415

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


395
396
397
# File 'lib/oci/core/models/boot_volume.rb', line 395

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



404
405
406
# File 'lib/oci/core/models/boot_volume.rb', line 404

def hash
  [availability_domain, compartment_id, defined_tags, system_tags, display_name, freeform_tags, id, image_id, is_hydrated, vpus_per_gb, lifecycle_state, size_in_gbs, size_in_mbs, source_details, time_created, volume_group_id, kms_key_id, is_auto_tune_enabled, auto_tuned_vpus_per_gb, boot_volume_replicas].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



448
449
450
451
452
453
454
455
456
457
# File 'lib/oci/core/models/boot_volume.rb', line 448

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



442
443
444
# File 'lib/oci/core/models/boot_volume.rb', line 442

def to_s
  to_hash.to_s
end