Class: OCI::Core::Models::BootVolumeAttachment
- Inherits:
-
Object
- Object
- OCI::Core::Models::BootVolumeAttachment
- Defined in:
- lib/oci/core/models/boot_volume_attachment.rb
Overview
Represents an attachment between a boot volume and an instance.
Warning: Oracle recommends that you avoid using any confidential information when you supply string values using the API.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_ATTACHING = 'ATTACHING'.freeze, LIFECYCLE_STATE_ATTACHED = 'ATTACHED'.freeze, LIFECYCLE_STATE_DETACHING = 'DETACHING'.freeze, LIFECYCLE_STATE_DETACHED = 'DETACHED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- ENCRYPTION_IN_TRANSIT_TYPE_ENUM =
[ ENCRYPTION_IN_TRANSIT_TYPE_NONE = 'NONE'.freeze, ENCRYPTION_IN_TRANSIT_TYPE_BM_ENCRYPTION_IN_TRANSIT = 'BM_ENCRYPTION_IN_TRANSIT'.freeze, ENCRYPTION_IN_TRANSIT_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#availability_domain ⇒ String
[Required] The availability domain of an instance.
-
#boot_volume_id ⇒ String
[Required] The OCID of the boot volume.
-
#compartment_id ⇒ String
[Required] The OCID of the compartment.
-
#display_name ⇒ String
A user-friendly name.
-
#encryption_in_transit_type ⇒ String
Refer the top-level definition of encryptionInTransitType.
-
#id ⇒ String
[Required] The OCID of the boot volume attachment.
-
#instance_id ⇒ String
[Required] The OCID of the instance the boot volume is attached to.
-
#is_pv_encryption_in_transit_enabled ⇒ BOOLEAN
Whether in-transit encryption for the boot volume’s paravirtualized attachment is enabled or not.
-
#lifecycle_state ⇒ String
[Required] The current state of the boot volume attachment.
-
#time_created ⇒ DateTime
[Required] The date and time the boot volume was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BootVolumeAttachment
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ BootVolumeAttachment
Initializes the object
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/oci/core/models/boot_volume_attachment.rb', line 132 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain'] raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain') self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain'] self.boot_volume_id = attributes[:'bootVolumeId'] if attributes[:'bootVolumeId'] raise 'You cannot provide both :bootVolumeId and :boot_volume_id' if attributes.key?(:'bootVolumeId') && attributes.key?(:'boot_volume_id') self.boot_volume_id = attributes[:'boot_volume_id'] if attributes[:'boot_volume_id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.id = attributes[:'id'] if attributes[:'id'] self.instance_id = attributes[:'instanceId'] if attributes[:'instanceId'] raise 'You cannot provide both :instanceId and :instance_id' if attributes.key?(:'instanceId') && attributes.key?(:'instance_id') self.instance_id = attributes[:'instance_id'] if attributes[:'instance_id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.is_pv_encryption_in_transit_enabled = attributes[:'isPvEncryptionInTransitEnabled'] unless attributes[:'isPvEncryptionInTransitEnabled'].nil? raise 'You cannot provide both :isPvEncryptionInTransitEnabled and :is_pv_encryption_in_transit_enabled' if attributes.key?(:'isPvEncryptionInTransitEnabled') && attributes.key?(:'is_pv_encryption_in_transit_enabled') self.is_pv_encryption_in_transit_enabled = attributes[:'is_pv_encryption_in_transit_enabled'] unless attributes[:'is_pv_encryption_in_transit_enabled'].nil? self.encryption_in_transit_type = attributes[:'encryptionInTransitType'] if attributes[:'encryptionInTransitType'] self.encryption_in_transit_type = "NONE" if encryption_in_transit_type.nil? && !attributes.key?(:'encryptionInTransitType') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :encryptionInTransitType and :encryption_in_transit_type' if attributes.key?(:'encryptionInTransitType') && attributes.key?(:'encryption_in_transit_type') self.encryption_in_transit_type = attributes[:'encryption_in_transit_type'] if attributes[:'encryption_in_transit_type'] self.encryption_in_transit_type = "NONE" if encryption_in_transit_type.nil? && !attributes.key?(:'encryptionInTransitType') && !attributes.key?(:'encryption_in_transit_type') # rubocop:disable Style/StringLiterals end |
Instance Attribute Details
#availability_domain ⇒ String
[Required] The availability domain of an instance.
Example: Uocm:PHX-AD-1
34 35 36 |
# File 'lib/oci/core/models/boot_volume_attachment.rb', line 34 def availability_domain @availability_domain end |
#boot_volume_id ⇒ String
[Required] The OCID of the boot volume.
38 39 40 |
# File 'lib/oci/core/models/boot_volume_attachment.rb', line 38 def boot_volume_id @boot_volume_id end |
#compartment_id ⇒ String
[Required] The OCID of the compartment.
42 43 44 |
# File 'lib/oci/core/models/boot_volume_attachment.rb', line 42 def compartment_id @compartment_id end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
48 49 50 |
# File 'lib/oci/core/models/boot_volume_attachment.rb', line 48 def display_name @display_name end |
#encryption_in_transit_type ⇒ String
Refer the top-level definition of encryptionInTransitType. The default value is NONE.
78 79 80 |
# File 'lib/oci/core/models/boot_volume_attachment.rb', line 78 def encryption_in_transit_type @encryption_in_transit_type end |
#id ⇒ String
[Required] The OCID of the boot volume attachment.
52 53 54 |
# File 'lib/oci/core/models/boot_volume_attachment.rb', line 52 def id @id end |
#instance_id ⇒ String
[Required] The OCID of the instance the boot volume is attached to.
56 57 58 |
# File 'lib/oci/core/models/boot_volume_attachment.rb', line 56 def instance_id @instance_id end |
#is_pv_encryption_in_transit_enabled ⇒ BOOLEAN
Whether in-transit encryption for the boot volume’s paravirtualized attachment is enabled or not.
72 73 74 |
# File 'lib/oci/core/models/boot_volume_attachment.rb', line 72 def is_pv_encryption_in_transit_enabled @is_pv_encryption_in_transit_enabled end |
#lifecycle_state ⇒ String
[Required] The current state of the boot volume attachment.
60 61 62 |
# File 'lib/oci/core/models/boot_volume_attachment.rb', line 60 def lifecycle_state @lifecycle_state end |
#time_created ⇒ DateTime
[Required] The date and time the boot volume was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Example: 2016-08-25T21:10:29.600Z
67 68 69 |
# File 'lib/oci/core/models/boot_volume_attachment.rb', line 67 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/oci/core/models/boot_volume_attachment.rb', line 81 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'availability_domain': :'availabilityDomain', 'boot_volume_id': :'bootVolumeId', 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'id': :'id', 'instance_id': :'instanceId', 'lifecycle_state': :'lifecycleState', 'time_created': :'timeCreated', 'is_pv_encryption_in_transit_enabled': :'isPvEncryptionInTransitEnabled', 'encryption_in_transit_type': :'encryptionInTransitType' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/oci/core/models/boot_volume_attachment.rb', line 99 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'availability_domain': :'String', 'boot_volume_id': :'String', 'compartment_id': :'String', 'display_name': :'String', 'id': :'String', 'instance_id': :'String', 'lifecycle_state': :'String', 'time_created': :'DateTime', 'is_pv_encryption_in_transit_enabled': :'BOOLEAN', 'encryption_in_transit_type': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/oci/core/models/boot_volume_attachment.rb', line 230 def ==(other) return true if equal?(other) self.class == other.class && availability_domain == other.availability_domain && boot_volume_id == other.boot_volume_id && compartment_id == other.compartment_id && display_name == other.display_name && id == other.id && instance_id == other.instance_id && lifecycle_state == other.lifecycle_state && time_created == other.time_created && is_pv_encryption_in_transit_enabled == other.is_pv_encryption_in_transit_enabled && encryption_in_transit_type == other.encryption_in_transit_type end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'lib/oci/core/models/boot_volume_attachment.rb', line 269 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
249 250 251 |
# File 'lib/oci/core/models/boot_volume_attachment.rb', line 249 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
258 259 260 |
# File 'lib/oci/core/models/boot_volume_attachment.rb', line 258 def hash [availability_domain, boot_volume_id, compartment_id, display_name, id, instance_id, lifecycle_state, time_created, is_pv_encryption_in_transit_enabled, encryption_in_transit_type].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
302 303 304 305 306 307 308 309 310 311 |
# File 'lib/oci/core/models/boot_volume_attachment.rb', line 302 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
296 297 298 |
# File 'lib/oci/core/models/boot_volume_attachment.rb', line 296 def to_s to_hash.to_s end |