Class: OCI::Core::Models::BootVolumeBackup
- Inherits:
-
Object
- Object
- OCI::Core::Models::BootVolumeBackup
- Defined in:
- lib/oci/core/models/boot_volume_backup.rb
Overview
A point-in-time copy of a boot volume that can then be used to create a new boot volume or recover a boot volume. For more information, see [Overview of Boot Volume Backups](docs.cloud.oracle.com/iaas/Content/Block/Concepts/bootvolumebackups.htm) To use any of the API operations, you must be authorized in an IAM policy. If you’re not authorized, talk to an administrator. If you’re an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/iaas/Content/Identity/Concepts/policygetstarted.htm).
Warning: Oracle recommends that you avoid using any confidential information when you supply string values using the API.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze, LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze, LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze, LIFECYCLE_STATE_FAULTY = 'FAULTY'.freeze, LIFECYCLE_STATE_REQUEST_RECEIVED = 'REQUEST_RECEIVED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- SOURCE_TYPE_ENUM =
[ SOURCE_TYPE_MANUAL = 'MANUAL'.freeze, SOURCE_TYPE_SCHEDULED = 'SCHEDULED'.freeze, SOURCE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- TYPE_ENUM =
[ TYPE_FULL = 'FULL'.freeze, TYPE_INCREMENTAL = 'INCREMENTAL'.freeze, TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#boot_volume_id ⇒ String
The OCID of the boot volume.
-
#compartment_id ⇒ String
[Required] The OCID of the compartment that contains the boot volume backup.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
[Required] A user-friendly name.
-
#expiration_time ⇒ DateTime
The date and time the volume backup will expire and be automatically deleted.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] The OCID of the boot volume backup.
-
#image_id ⇒ String
The image OCID used to create the boot volume the backup is taken from.
-
#kms_key_id ⇒ String
The OCID of the Key Management master encryption assigned to the boot volume backup.
-
#lifecycle_state ⇒ String
[Required] The current state of a boot volume backup.
-
#size_in_gbs ⇒ Integer
The size of the boot volume, in GBs.
-
#source_boot_volume_backup_id ⇒ String
The OCID of the source boot volume backup.
-
#source_type ⇒ String
Specifies whether the backup was created manually, or via scheduled backup policy.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
System tags for this resource.
-
#time_created ⇒ DateTime
[Required] The date and time the boot volume backup was created.
-
#time_request_received ⇒ DateTime
The date and time the request to create the boot volume backup was received.
-
#type ⇒ String
The type of a volume backup.
-
#unique_size_in_gbs ⇒ Integer
The size used by the backup, in GBs.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BootVolumeBackup
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ BootVolumeBackup
Initializes the object
220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 |
# File 'lib/oci/core/models/boot_volume_backup.rb', line 220 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.boot_volume_id = attributes[:'bootVolumeId'] if attributes[:'bootVolumeId'] raise 'You cannot provide both :bootVolumeId and :boot_volume_id' if attributes.key?(:'bootVolumeId') && attributes.key?(:'boot_volume_id') self.boot_volume_id = attributes[:'boot_volume_id'] if attributes[:'boot_volume_id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.expiration_time = attributes[:'expirationTime'] if attributes[:'expirationTime'] raise 'You cannot provide both :expirationTime and :expiration_time' if attributes.key?(:'expirationTime') && attributes.key?(:'expiration_time') self.expiration_time = attributes[:'expiration_time'] if attributes[:'expiration_time'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.id = attributes[:'id'] if attributes[:'id'] self.image_id = attributes[:'imageId'] if attributes[:'imageId'] raise 'You cannot provide both :imageId and :image_id' if attributes.key?(:'imageId') && attributes.key?(:'image_id') self.image_id = attributes[:'image_id'] if attributes[:'image_id'] self.kms_key_id = attributes[:'kmsKeyId'] if attributes[:'kmsKeyId'] raise 'You cannot provide both :kmsKeyId and :kms_key_id' if attributes.key?(:'kmsKeyId') && attributes.key?(:'kms_key_id') self.kms_key_id = attributes[:'kms_key_id'] if attributes[:'kms_key_id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.size_in_gbs = attributes[:'sizeInGBs'] if attributes[:'sizeInGBs'] raise 'You cannot provide both :sizeInGBs and :size_in_gbs' if attributes.key?(:'sizeInGBs') && attributes.key?(:'size_in_gbs') self.size_in_gbs = attributes[:'size_in_gbs'] if attributes[:'size_in_gbs'] self.source_boot_volume_backup_id = attributes[:'sourceBootVolumeBackupId'] if attributes[:'sourceBootVolumeBackupId'] raise 'You cannot provide both :sourceBootVolumeBackupId and :source_boot_volume_backup_id' if attributes.key?(:'sourceBootVolumeBackupId') && attributes.key?(:'source_boot_volume_backup_id') self.source_boot_volume_backup_id = attributes[:'source_boot_volume_backup_id'] if attributes[:'source_boot_volume_backup_id'] self.source_type = attributes[:'sourceType'] if attributes[:'sourceType'] raise 'You cannot provide both :sourceType and :source_type' if attributes.key?(:'sourceType') && attributes.key?(:'source_type') self.source_type = attributes[:'source_type'] if attributes[:'source_type'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_request_received = attributes[:'timeRequestReceived'] if attributes[:'timeRequestReceived'] raise 'You cannot provide both :timeRequestReceived and :time_request_received' if attributes.key?(:'timeRequestReceived') && attributes.key?(:'time_request_received') self.time_request_received = attributes[:'time_request_received'] if attributes[:'time_request_received'] self.type = attributes[:'type'] if attributes[:'type'] self.unique_size_in_gbs = attributes[:'uniqueSizeInGBs'] if attributes[:'uniqueSizeInGBs'] raise 'You cannot provide both :uniqueSizeInGBs and :unique_size_in_gbs' if attributes.key?(:'uniqueSizeInGBs') && attributes.key?(:'unique_size_in_gbs') self.unique_size_in_gbs = attributes[:'unique_size_in_gbs'] if attributes[:'unique_size_in_gbs'] end |
Instance Attribute Details
#boot_volume_id ⇒ String
The OCID of the boot volume.
45 46 47 |
# File 'lib/oci/core/models/boot_volume_backup.rb', line 45 def boot_volume_id @boot_volume_id end |
#compartment_id ⇒ String
[Required] The OCID of the compartment that contains the boot volume backup.
49 50 51 |
# File 'lib/oci/core/models/boot_volume_backup.rb', line 49 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
57 58 59 |
# File 'lib/oci/core/models/boot_volume_backup.rb', line 57 def @defined_tags end |
#display_name ⇒ String
[Required] A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
69 70 71 |
# File 'lib/oci/core/models/boot_volume_backup.rb', line 69 def display_name @display_name end |
#expiration_time ⇒ DateTime
The date and time the volume backup will expire and be automatically deleted. Format defined by [RFC3339](tools.ietf.org/html/rfc3339). This parameter will always be present for backups that were created automatically by a scheduled-backup policy. For manually created backups, it will be absent, signifying that there is no expiration time and the backup will last forever until manually deleted.
78 79 80 |
# File 'lib/oci/core/models/boot_volume_backup.rb', line 78 def expiration_time @expiration_time end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
86 87 88 |
# File 'lib/oci/core/models/boot_volume_backup.rb', line 86 def @freeform_tags end |
#id ⇒ String
[Required] The OCID of the boot volume backup.
90 91 92 |
# File 'lib/oci/core/models/boot_volume_backup.rb', line 90 def id @id end |
#image_id ⇒ String
The image OCID used to create the boot volume the backup is taken from.
95 96 97 |
# File 'lib/oci/core/models/boot_volume_backup.rb', line 95 def image_id @image_id end |
#kms_key_id ⇒ String
The OCID of the Key Management master encryption assigned to the boot volume backup. For more information about the Key Management service and encryption keys, see [Overview of Key Management](docs.cloud.oracle.com/iaas/Content/KeyManagement/Concepts/keyoverview.htm) and [Using Keys](docs.cloud.oracle.com/iaas/Content/KeyManagement/Tasks/usingkeys.htm).
103 104 105 |
# File 'lib/oci/core/models/boot_volume_backup.rb', line 103 def kms_key_id @kms_key_id end |
#lifecycle_state ⇒ String
[Required] The current state of a boot volume backup.
107 108 109 |
# File 'lib/oci/core/models/boot_volume_backup.rb', line 107 def lifecycle_state @lifecycle_state end |
#size_in_gbs ⇒ Integer
The size of the boot volume, in GBs.
112 113 114 |
# File 'lib/oci/core/models/boot_volume_backup.rb', line 112 def size_in_gbs @size_in_gbs end |
#source_boot_volume_backup_id ⇒ String
The OCID of the source boot volume backup.
116 117 118 |
# File 'lib/oci/core/models/boot_volume_backup.rb', line 116 def source_boot_volume_backup_id @source_boot_volume_backup_id end |
#source_type ⇒ String
Specifies whether the backup was created manually, or via scheduled backup policy.
121 122 123 |
# File 'lib/oci/core/models/boot_volume_backup.rb', line 121 def source_type @source_type end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
System tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
63 64 65 |
# File 'lib/oci/core/models/boot_volume_backup.rb', line 63 def @system_tags end |
#time_created ⇒ DateTime
[Required] The date and time the boot volume backup was created. This is the time the actual point-in-time image of the volume data was taken. Format defined by [RFC3339](tools.ietf.org/html/rfc3339).
127 128 129 |
# File 'lib/oci/core/models/boot_volume_backup.rb', line 127 def time_created @time_created end |
#time_request_received ⇒ DateTime
The date and time the request to create the boot volume backup was received. Format defined by [RFC3339](tools.ietf.org/html/rfc3339).
132 133 134 |
# File 'lib/oci/core/models/boot_volume_backup.rb', line 132 def time_request_received @time_request_received end |
#type ⇒ String
The type of a volume backup.
136 137 138 |
# File 'lib/oci/core/models/boot_volume_backup.rb', line 136 def type @type end |
#unique_size_in_gbs ⇒ Integer
The size used by the backup, in GBs. It is typically smaller than sizeInGBs, depending on the space consumed on the boot volume and whether the backup is full or incremental.
142 143 144 |
# File 'lib/oci/core/models/boot_volume_backup.rb', line 142 def unique_size_in_gbs @unique_size_in_gbs end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/oci/core/models/boot_volume_backup.rb', line 145 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'boot_volume_id': :'bootVolumeId', 'compartment_id': :'compartmentId', 'defined_tags': :'definedTags', 'system_tags': :'systemTags', 'display_name': :'displayName', 'expiration_time': :'expirationTime', 'freeform_tags': :'freeformTags', 'id': :'id', 'image_id': :'imageId', 'kms_key_id': :'kmsKeyId', 'lifecycle_state': :'lifecycleState', 'size_in_gbs': :'sizeInGBs', 'source_boot_volume_backup_id': :'sourceBootVolumeBackupId', 'source_type': :'sourceType', 'time_created': :'timeCreated', 'time_request_received': :'timeRequestReceived', 'type': :'type', 'unique_size_in_gbs': :'uniqueSizeInGBs' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/oci/core/models/boot_volume_backup.rb', line 171 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'boot_volume_id': :'String', 'compartment_id': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'expiration_time': :'DateTime', 'freeform_tags': :'Hash<String, String>', 'id': :'String', 'image_id': :'String', 'kms_key_id': :'String', 'lifecycle_state': :'String', 'size_in_gbs': :'Integer', 'source_boot_volume_backup_id': :'String', 'source_type': :'String', 'time_created': :'DateTime', 'time_request_received': :'DateTime', 'type': :'String', 'unique_size_in_gbs': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 |
# File 'lib/oci/core/models/boot_volume_backup.rb', line 373 def ==(other) return true if equal?(other) self.class == other.class && boot_volume_id == other.boot_volume_id && compartment_id == other.compartment_id && == other. && == other. && display_name == other.display_name && expiration_time == other.expiration_time && == other. && id == other.id && image_id == other.image_id && kms_key_id == other.kms_key_id && lifecycle_state == other.lifecycle_state && size_in_gbs == other.size_in_gbs && source_boot_volume_backup_id == other.source_boot_volume_backup_id && source_type == other.source_type && time_created == other.time_created && time_request_received == other.time_request_received && type == other.type && unique_size_in_gbs == other.unique_size_in_gbs end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 |
# File 'lib/oci/core/models/boot_volume_backup.rb', line 420 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
400 401 402 |
# File 'lib/oci/core/models/boot_volume_backup.rb', line 400 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
409 410 411 |
# File 'lib/oci/core/models/boot_volume_backup.rb', line 409 def hash [boot_volume_id, compartment_id, , , display_name, expiration_time, , id, image_id, kms_key_id, lifecycle_state, size_in_gbs, source_boot_volume_backup_id, source_type, time_created, time_request_received, type, unique_size_in_gbs].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
453 454 455 456 457 458 459 460 461 462 |
# File 'lib/oci/core/models/boot_volume_backup.rb', line 453 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
447 448 449 |
# File 'lib/oci/core/models/boot_volume_backup.rb', line 447 def to_s to_hash.to_s end |