Class: OCI::Core::Models::ByoipRange
- Inherits:
-
Object
- Object
- OCI::Core::Models::ByoipRange
- Defined in:
- lib/oci/core/models/byoip_range.rb
Overview
Oracle offers the ability to Bring Your Own IP (BYOIP), importing public IP addresses that you currently own to Oracle Cloud Infrastructure. A ByoipRange resource is a record of the imported address block (a BYOIP CIDR block) and also some associated metadata. The process used to [Bring Your Own IP](docs.cloud.oracle.com/iaas/Content/Network/Concepts/BYOIP.htm) is explained in the documentation.
Constant Summary collapse
- LIFECYCLE_DETAILS_ENUM =
[ LIFECYCLE_DETAILS_CREATING = 'CREATING'.freeze, LIFECYCLE_DETAILS_VALIDATING = 'VALIDATING'.freeze, LIFECYCLE_DETAILS_PROVISIONED = 'PROVISIONED'.freeze, LIFECYCLE_DETAILS_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_DETAILS_FAILED = 'FAILED'.freeze, LIFECYCLE_DETAILS_DELETING = 'DELETING'.freeze, LIFECYCLE_DETAILS_DELETED = 'DELETED'.freeze, LIFECYCLE_DETAILS_ADVERTISING = 'ADVERTISING'.freeze, LIFECYCLE_DETAILS_WITHDRAWING = 'WITHDRAWING'.freeze, LIFECYCLE_DETAILS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#cidr_block ⇒ String
[Required] The public IPv4 CIDR block being imported from on-premises to the Oracle cloud.
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the BYOIP CIDR block.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
A user-friendly name.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the
ByoipRangeresource. -
#lifecycle_details ⇒ String
The
ByoipRangeresource’s current status. -
#lifecycle_state ⇒ String
[Required] The
ByoipRangeresource’s current state. -
#time_advertised ⇒ DateTime
The date and time the
ByoipRangeresource was advertised to the internet by BGP, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339). -
#time_created ⇒ DateTime
[Required] The date and time the
ByoipRangeresource was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339). -
#time_validated ⇒ DateTime
The date and time the
ByoipRangeresource was validated, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339). -
#time_withdrawn ⇒ DateTime
The date and time the
ByoipRangeresource was withdrawn from advertisement by BGP to the internet, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339). -
#validation_token ⇒ String
[Required] The validation token is an internally-generated ASCII string used in the validation process.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ByoipRange
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ByoipRange
Initializes the object
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/oci/core/models/byoip_range.rb', line 170 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.cidr_block = attributes[:'cidrBlock'] if attributes[:'cidrBlock'] raise 'You cannot provide both :cidrBlock and :cidr_block' if attributes.key?(:'cidrBlock') && attributes.key?(:'cidr_block') self.cidr_block = attributes[:'cidr_block'] if attributes[:'cidr_block'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.id = attributes[:'id'] if attributes[:'id'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_validated = attributes[:'timeValidated'] if attributes[:'timeValidated'] raise 'You cannot provide both :timeValidated and :time_validated' if attributes.key?(:'timeValidated') && attributes.key?(:'time_validated') self.time_validated = attributes[:'time_validated'] if attributes[:'time_validated'] self.time_advertised = attributes[:'timeAdvertised'] if attributes[:'timeAdvertised'] raise 'You cannot provide both :timeAdvertised and :time_advertised' if attributes.key?(:'timeAdvertised') && attributes.key?(:'time_advertised') self.time_advertised = attributes[:'time_advertised'] if attributes[:'time_advertised'] self.time_withdrawn = attributes[:'timeWithdrawn'] if attributes[:'timeWithdrawn'] raise 'You cannot provide both :timeWithdrawn and :time_withdrawn' if attributes.key?(:'timeWithdrawn') && attributes.key?(:'time_withdrawn') self.time_withdrawn = attributes[:'time_withdrawn'] if attributes[:'time_withdrawn'] self.validation_token = attributes[:'validationToken'] if attributes[:'validationToken'] raise 'You cannot provide both :validationToken and :validation_token' if attributes.key?(:'validationToken') && attributes.key?(:'validation_token') self.validation_token = attributes[:'validation_token'] if attributes[:'validation_token'] end |
Instance Attribute Details
#cidr_block ⇒ String
[Required] The public IPv4 CIDR block being imported from on-premises to the Oracle cloud.
36 37 38 |
# File 'lib/oci/core/models/byoip_range.rb', line 36 def cidr_block @cidr_block end |
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the BYOIP CIDR block.
41 42 43 |
# File 'lib/oci/core/models/byoip_range.rb', line 41 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
49 50 51 |
# File 'lib/oci/core/models/byoip_range.rb', line 49 def end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
55 56 57 |
# File 'lib/oci/core/models/byoip_range.rb', line 55 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
63 64 65 |
# File 'lib/oci/core/models/byoip_range.rb', line 63 def end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the ByoipRange resource.
67 68 69 |
# File 'lib/oci/core/models/byoip_range.rb', line 67 def id @id end |
#lifecycle_details ⇒ String
The ByoipRange resource’s current status.
71 72 73 |
# File 'lib/oci/core/models/byoip_range.rb', line 71 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
[Required] The ByoipRange resource’s current state.
75 76 77 |
# File 'lib/oci/core/models/byoip_range.rb', line 75 def lifecycle_state @lifecycle_state end |
#time_advertised ⇒ DateTime
The date and time the ByoipRange resource was advertised to the internet by BGP, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Example: 2016-08-25T21:10:29.600Z
96 97 98 |
# File 'lib/oci/core/models/byoip_range.rb', line 96 def time_advertised @time_advertised end |
#time_created ⇒ DateTime
[Required] The date and time the ByoipRange resource was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Example: 2016-08-25T21:10:29.600Z
82 83 84 |
# File 'lib/oci/core/models/byoip_range.rb', line 82 def time_created @time_created end |
#time_validated ⇒ DateTime
The date and time the ByoipRange resource was validated, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Example: 2016-08-25T21:10:29.600Z
89 90 91 |
# File 'lib/oci/core/models/byoip_range.rb', line 89 def time_validated @time_validated end |
#time_withdrawn ⇒ DateTime
The date and time the ByoipRange resource was withdrawn from advertisement by BGP to the internet, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Example: 2016-08-25T21:10:29.600Z
103 104 105 |
# File 'lib/oci/core/models/byoip_range.rb', line 103 def time_withdrawn @time_withdrawn end |
#validation_token ⇒ String
[Required] The validation token is an internally-generated ASCII string used in the validation process. See [Importing a CIDR block](docs.cloud.oracle.com/iaas/Content/Network/Concepts/BYOIP.htm#import_cidr) for details.
107 108 109 |
# File 'lib/oci/core/models/byoip_range.rb', line 107 def validation_token @validation_token end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/oci/core/models/byoip_range.rb', line 110 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'cidr_block': :'cidrBlock', 'compartment_id': :'compartmentId', 'defined_tags': :'definedTags', 'display_name': :'displayName', 'freeform_tags': :'freeformTags', 'id': :'id', 'lifecycle_details': :'lifecycleDetails', 'lifecycle_state': :'lifecycleState', 'time_created': :'timeCreated', 'time_validated': :'timeValidated', 'time_advertised': :'timeAdvertised', 'time_withdrawn': :'timeWithdrawn', 'validation_token': :'validationToken' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/oci/core/models/byoip_range.rb', line 131 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'cidr_block': :'String', 'compartment_id': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'freeform_tags': :'Hash<String, String>', 'id': :'String', 'lifecycle_details': :'String', 'lifecycle_state': :'String', 'time_created': :'DateTime', 'time_validated': :'DateTime', 'time_advertised': :'DateTime', 'time_withdrawn': :'DateTime', 'validation_token': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 |
# File 'lib/oci/core/models/byoip_range.rb', line 284 def ==(other) return true if equal?(other) self.class == other.class && cidr_block == other.cidr_block && compartment_id == other.compartment_id && == other. && display_name == other.display_name && == other. && id == other.id && lifecycle_details == other.lifecycle_details && lifecycle_state == other.lifecycle_state && time_created == other.time_created && time_validated == other.time_validated && time_advertised == other.time_advertised && time_withdrawn == other.time_withdrawn && validation_token == other.validation_token end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'lib/oci/core/models/byoip_range.rb', line 326 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
306 307 308 |
# File 'lib/oci/core/models/byoip_range.rb', line 306 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
315 316 317 |
# File 'lib/oci/core/models/byoip_range.rb', line 315 def hash [cidr_block, compartment_id, , display_name, , id, lifecycle_details, lifecycle_state, time_created, time_validated, time_advertised, time_withdrawn, validation_token].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
359 360 361 362 363 364 365 366 367 368 |
# File 'lib/oci/core/models/byoip_range.rb', line 359 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
353 354 355 |
# File 'lib/oci/core/models/byoip_range.rb', line 353 def to_s to_hash.to_s end |