Class: OCI::Core::Models::ByoipRangeSummary
- Inherits:
-
Object
- Object
- OCI::Core::Models::ByoipRangeSummary
- Defined in:
- lib/oci/core/models/byoip_range_summary.rb
Overview
Information about a `ByoipRange` resource.
Instance Attribute Summary collapse
-
#byoip_range_vcn_ipv6_allocations ⇒ Array<OCI::Core::Models::ByoipRangeVcnIpv6AllocationSummary>
A list of `ByoipRangeVcnIpv6AllocationSummary` objects.
-
#cidr_block ⇒ String
The public IPv4 address range you are importing to the Oracle cloud.
-
#compartment_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the `ByoipRange` resource.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
A user-friendly name.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the `ByoipRange` resource.
-
#ipv6_cidr_block ⇒ String
The IPv6 CIDR block being imported to the Oracle cloud.
-
#lifecycle_details ⇒ String
The Byoip Range's current lifeCycle substate.
-
#lifecycle_state ⇒ String
The `ByoipRange` resource's current state.
-
#time_created ⇒ DateTime
The date and time the `ByoipRange` resource was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ByoipRangeSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ByoipRangeSummary
Initializes the object
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/oci/core/models/byoip_range_summary.rb', line 127 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.byoip_range_vcn_ipv6_allocations = attributes[:'byoipRangeVcnIpv6Allocations'] if attributes[:'byoipRangeVcnIpv6Allocations'] raise 'You cannot provide both :byoipRangeVcnIpv6Allocations and :byoip_range_vcn_ipv6_allocations' if attributes.key?(:'byoipRangeVcnIpv6Allocations') && attributes.key?(:'byoip_range_vcn_ipv6_allocations') self.byoip_range_vcn_ipv6_allocations = attributes[:'byoip_range_vcn_ipv6_allocations'] if attributes[:'byoip_range_vcn_ipv6_allocations'] self.cidr_block = attributes[:'cidrBlock'] if attributes[:'cidrBlock'] raise 'You cannot provide both :cidrBlock and :cidr_block' if attributes.key?(:'cidrBlock') && attributes.key?(:'cidr_block') self.cidr_block = attributes[:'cidr_block'] if attributes[:'cidr_block'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.id = attributes[:'id'] if attributes[:'id'] self.ipv6_cidr_block = attributes[:'ipv6CidrBlock'] if attributes[:'ipv6CidrBlock'] raise 'You cannot provide both :ipv6CidrBlock and :ipv6_cidr_block' if attributes.key?(:'ipv6CidrBlock') && attributes.key?(:'ipv6_cidr_block') self.ipv6_cidr_block = attributes[:'ipv6_cidr_block'] if attributes[:'ipv6_cidr_block'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] end |
Instance Attribute Details
#byoip_range_vcn_ipv6_allocations ⇒ Array<OCI::Core::Models::ByoipRangeVcnIpv6AllocationSummary>
A list of `ByoipRangeVcnIpv6AllocationSummary` objects.
13 14 15 |
# File 'lib/oci/core/models/byoip_range_summary.rb', line 13 def byoip_range_vcn_ipv6_allocations @byoip_range_vcn_ipv6_allocations end |
#cidr_block ⇒ String
The public IPv4 address range you are importing to the Oracle cloud.
17 18 19 |
# File 'lib/oci/core/models/byoip_range_summary.rb', line 17 def cidr_block @cidr_block end |
#compartment_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the `ByoipRange` resource.
22 23 24 |
# File 'lib/oci/core/models/byoip_range_summary.rb', line 22 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: `{"CostCenter": "42"}`
30 31 32 |
# File 'lib/oci/core/models/byoip_range_summary.rb', line 30 def @defined_tags end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
36 37 38 |
# File 'lib/oci/core/models/byoip_range_summary.rb', line 36 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: `"Finance"`
44 45 46 |
# File 'lib/oci/core/models/byoip_range_summary.rb', line 44 def @freeform_tags end |
#id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the `ByoipRange` resource.
48 49 50 |
# File 'lib/oci/core/models/byoip_range_summary.rb', line 48 def id @id end |
#ipv6_cidr_block ⇒ String
The IPv6 CIDR block being imported to the Oracle cloud. This CIDR block must be /48 or larger, and can be subdivided into sub-ranges used across multiple VCNs. A BYOIPv6 prefix can be assigned across multiple VCNs, and each VCN must be /64 or larger. You may specify a ULA or private IPv6 prefix of /64 or larger to use in the VCN. IPv6-enabled subnets will remain a fixed /64 in size.
55 56 57 |
# File 'lib/oci/core/models/byoip_range_summary.rb', line 55 def ipv6_cidr_block @ipv6_cidr_block end |
#lifecycle_details ⇒ String
The Byoip Range's current lifeCycle substate.
63 64 65 |
# File 'lib/oci/core/models/byoip_range_summary.rb', line 63 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
The `ByoipRange` resource's current state.
59 60 61 |
# File 'lib/oci/core/models/byoip_range_summary.rb', line 59 def lifecycle_state @lifecycle_state end |
#time_created ⇒ DateTime
The date and time the `ByoipRange` resource was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Example: `2016-08-25T21:10:29.600Z`
70 71 72 |
# File 'lib/oci/core/models/byoip_range_summary.rb', line 70 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/oci/core/models/byoip_range_summary.rb', line 73 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'byoip_range_vcn_ipv6_allocations': :'byoipRangeVcnIpv6Allocations', 'cidr_block': :'cidrBlock', 'compartment_id': :'compartmentId', 'defined_tags': :'definedTags', 'display_name': :'displayName', 'freeform_tags': :'freeformTags', 'id': :'id', 'ipv6_cidr_block': :'ipv6CidrBlock', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'time_created': :'timeCreated' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/oci/core/models/byoip_range_summary.rb', line 92 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'byoip_range_vcn_ipv6_allocations': :'Array<OCI::Core::Models::ByoipRangeVcnIpv6AllocationSummary>', 'cidr_block': :'String', 'compartment_id': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'freeform_tags': :'Hash<String, String>', 'id': :'String', 'ipv6_cidr_block': :'String', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'time_created': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/oci/core/models/byoip_range_summary.rb', line 203 def ==(other) return true if equal?(other) self.class == other.class && byoip_range_vcn_ipv6_allocations == other.byoip_range_vcn_ipv6_allocations && cidr_block == other.cidr_block && compartment_id == other.compartment_id && == other. && display_name == other.display_name && == other. && id == other.id && ipv6_cidr_block == other.ipv6_cidr_block && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && time_created == other.time_created end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 |
# File 'lib/oci/core/models/byoip_range_summary.rb', line 243 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
223 224 225 |
# File 'lib/oci/core/models/byoip_range_summary.rb', line 223 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
232 233 234 |
# File 'lib/oci/core/models/byoip_range_summary.rb', line 232 def hash [byoip_range_vcn_ipv6_allocations, cidr_block, compartment_id, , display_name, , id, ipv6_cidr_block, lifecycle_state, lifecycle_details, time_created].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
276 277 278 279 280 281 282 283 284 285 |
# File 'lib/oci/core/models/byoip_range_summary.rb', line 276 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
270 271 272 |
# File 'lib/oci/core/models/byoip_range_summary.rb', line 270 def to_s to_hash.to_s end |