Class: OCI::Core::Models::ClusterNetworkPlacementConfigurationDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/core/models/cluster_network_placement_configuration_details.rb

Overview

The location for where the instance pools in a cluster network will place instances.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ClusterNetworkPlacementConfigurationDetails

Initializes the object

Options Hash (attributes):

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/oci/core/models/cluster_network_placement_configuration_details.rb', line 58

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain']

  raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain')

  self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain']

  self.primary_subnet_id = attributes[:'primarySubnetId'] if attributes[:'primarySubnetId']

  raise 'You cannot provide both :primarySubnetId and :primary_subnet_id' if attributes.key?(:'primarySubnetId') && attributes.key?(:'primary_subnet_id')

  self.primary_subnet_id = attributes[:'primary_subnet_id'] if attributes[:'primary_subnet_id']

  self.secondary_vnic_subnets = attributes[:'secondaryVnicSubnets'] if attributes[:'secondaryVnicSubnets']

  raise 'You cannot provide both :secondaryVnicSubnets and :secondary_vnic_subnets' if attributes.key?(:'secondaryVnicSubnets') && attributes.key?(:'secondary_vnic_subnets')

  self.secondary_vnic_subnets = attributes[:'secondary_vnic_subnets'] if attributes[:'secondary_vnic_subnets']
end

Instance Attribute Details

#availability_domainString

[Required] The availability domain to place instances.

Example: Uocm:PHX-AD-1

Returns:



15
16
17
# File 'lib/oci/core/models/cluster_network_placement_configuration_details.rb', line 15

def availability_domain
  @availability_domain
end

#primary_subnet_idString

[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the primary subnet to place instances.

Returns:



21
22
23
# File 'lib/oci/core/models/cluster_network_placement_configuration_details.rb', line 21

def primary_subnet_id
  @primary_subnet_id
end

#secondary_vnic_subnetsArray<OCI::Core::Models::InstancePoolPlacementSecondaryVnicSubnet>

The set of secondary VNIC data for instances in the pool.

Returns:



25
26
27
# File 'lib/oci/core/models/cluster_network_placement_configuration_details.rb', line 25

def secondary_vnic_subnets
  @secondary_vnic_subnets
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



28
29
30
31
32
33
34
35
36
# File 'lib/oci/core/models/cluster_network_placement_configuration_details.rb', line 28

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'availability_domain': :'availabilityDomain',
    'primary_subnet_id': :'primarySubnetId',
    'secondary_vnic_subnets': :'secondaryVnicSubnets'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



39
40
41
42
43
44
45
46
47
# File 'lib/oci/core/models/cluster_network_placement_configuration_details.rb', line 39

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'availability_domain': :'String',
    'primary_subnet_id': :'String',
    'secondary_vnic_subnets': :'Array<OCI::Core::Models::InstancePoolPlacementSecondaryVnicSubnet>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • the other object to be compared



90
91
92
93
94
95
96
97
# File 'lib/oci/core/models/cluster_network_placement_configuration_details.rb', line 90

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    availability_domain == other.availability_domain &&
    primary_subnet_id == other.primary_subnet_id &&
    secondary_vnic_subnets == other.secondary_vnic_subnets
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/oci/core/models/cluster_network_placement_configuration_details.rb', line 122

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method

Parameters:

  • the other object to be compared

Returns:



102
103
104
# File 'lib/oci/core/models/cluster_network_placement_configuration_details.rb', line 102

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • Hash code



111
112
113
# File 'lib/oci/core/models/cluster_network_placement_configuration_details.rb', line 111

def hash
  [availability_domain, primary_subnet_id, secondary_vnic_subnets].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



155
156
157
158
159
160
161
162
163
164
# File 'lib/oci/core/models/cluster_network_placement_configuration_details.rb', line 155

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



149
150
151
# File 'lib/oci/core/models/cluster_network_placement_configuration_details.rb', line 149

def to_s
  to_hash.to_s
end