Class: OCI::Core::Models::ComputeCapacityReservation
- Inherits:
-
Object
- Object
- OCI::Core::Models::ComputeCapacityReservation
- Defined in:
- lib/oci/core/models/compute_capacity_reservation.rb
Overview
A template that defines the settings to use when creating compute capacity reservations.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_MOVING = 'MOVING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#availability_domain ⇒ String
[Required] The availability domain of the compute capacity reservation.
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the compute capacity reservation.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
A user-friendly name.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compute capacity reservation.
-
#instance_reservation_configs ⇒ Array<OCI::Core::Models::InstanceReservationConfig>
The capacity configurations for the capacity reservation.
-
#is_default_reservation ⇒ BOOLEAN
Whether this capacity reservation is the default.
-
#lifecycle_state ⇒ String
[Required] The current state of the compute capacity reservation.
-
#reserved_instance_count ⇒ Integer
The number of instances for which capacity will be held with this compute capacity reservation.
-
#time_created ⇒ DateTime
[Required] The date and time the compute capacity reservation was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#time_updated ⇒ DateTime
The date and time the compute capacity reservation was updated, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#used_instance_count ⇒ Integer
The total number of instances currently consuming space in this compute capacity reservation.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ComputeCapacityReservation
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ComputeCapacityReservation
Initializes the object
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/oci/core/models/compute_capacity_reservation.rb', line 170 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain'] raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain') self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.id = attributes[:'id'] if attributes[:'id'] self.is_default_reservation = attributes[:'isDefaultReservation'] unless attributes[:'isDefaultReservation'].nil? self.is_default_reservation = false if is_default_reservation.nil? && !attributes.key?(:'isDefaultReservation') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isDefaultReservation and :is_default_reservation' if attributes.key?(:'isDefaultReservation') && attributes.key?(:'is_default_reservation') self.is_default_reservation = attributes[:'is_default_reservation'] unless attributes[:'is_default_reservation'].nil? self.is_default_reservation = false if is_default_reservation.nil? && !attributes.key?(:'isDefaultReservation') && !attributes.key?(:'is_default_reservation') # rubocop:disable Style/StringLiterals self.instance_reservation_configs = attributes[:'instanceReservationConfigs'] if attributes[:'instanceReservationConfigs'] raise 'You cannot provide both :instanceReservationConfigs and :instance_reservation_configs' if attributes.key?(:'instanceReservationConfigs') && attributes.key?(:'instance_reservation_configs') self.instance_reservation_configs = attributes[:'instance_reservation_configs'] if attributes[:'instance_reservation_configs'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.reserved_instance_count = attributes[:'reservedInstanceCount'] if attributes[:'reservedInstanceCount'] raise 'You cannot provide both :reservedInstanceCount and :reserved_instance_count' if attributes.key?(:'reservedInstanceCount') && attributes.key?(:'reserved_instance_count') self.reserved_instance_count = attributes[:'reserved_instance_count'] if attributes[:'reserved_instance_count'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.used_instance_count = attributes[:'usedInstanceCount'] if attributes[:'usedInstanceCount'] raise 'You cannot provide both :usedInstanceCount and :used_instance_count' if attributes.key?(:'usedInstanceCount') && attributes.key?(:'used_instance_count') self.used_instance_count = attributes[:'used_instance_count'] if attributes[:'used_instance_count'] end |
Instance Attribute Details
#availability_domain ⇒ String
[Required] The availability domain of the compute capacity reservation.
Example: Uocm:PHX-AD-1
27 28 29 |
# File 'lib/oci/core/models/compute_capacity_reservation.rb', line 27 def availability_domain @availability_domain end |
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the compute capacity reservation.
33 34 35 |
# File 'lib/oci/core/models/compute_capacity_reservation.rb', line 33 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
41 42 43 |
# File 'lib/oci/core/models/compute_capacity_reservation.rb', line 41 def @defined_tags end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
47 48 49 |
# File 'lib/oci/core/models/compute_capacity_reservation.rb', line 47 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
55 56 57 |
# File 'lib/oci/core/models/compute_capacity_reservation.rb', line 55 def @freeform_tags end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compute capacity reservation.
59 60 61 |
# File 'lib/oci/core/models/compute_capacity_reservation.rb', line 59 def id @id end |
#instance_reservation_configs ⇒ Array<OCI::Core::Models::InstanceReservationConfig>
The capacity configurations for the capacity reservation.
To use the reservation for the desired shape, specify the shape, count, and optionally the fault domain where you want this configuration.
73 74 75 |
# File 'lib/oci/core/models/compute_capacity_reservation.rb', line 73 def instance_reservation_configs @instance_reservation_configs end |
#is_default_reservation ⇒ BOOLEAN
Whether this capacity reservation is the default. For more information, see [Capacity Reservations](docs.cloud.oracle.com/iaas/Content/Compute/Tasks/reserve-capacity.htm#default).
65 66 67 |
# File 'lib/oci/core/models/compute_capacity_reservation.rb', line 65 def is_default_reservation @is_default_reservation end |
#lifecycle_state ⇒ String
[Required] The current state of the compute capacity reservation.
77 78 79 |
# File 'lib/oci/core/models/compute_capacity_reservation.rb', line 77 def lifecycle_state @lifecycle_state end |
#reserved_instance_count ⇒ Integer
The number of instances for which capacity will be held with this compute capacity reservation. This number is the sum of the values of the reservedCount fields for all of the instance capacity configurations under this reservation. The purpose of this field is to calculate the percentage usage of the reservation.
85 86 87 |
# File 'lib/oci/core/models/compute_capacity_reservation.rb', line 85 def reserved_instance_count @reserved_instance_count end |
#time_created ⇒ DateTime
[Required] The date and time the compute capacity reservation was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Example: 2016-08-25T21:10:29.600Z
99 100 101 |
# File 'lib/oci/core/models/compute_capacity_reservation.rb', line 99 def time_created @time_created end |
#time_updated ⇒ DateTime
The date and time the compute capacity reservation was updated, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Example: 2016-08-25T21:10:29.600Z
92 93 94 |
# File 'lib/oci/core/models/compute_capacity_reservation.rb', line 92 def time_updated @time_updated end |
#used_instance_count ⇒ Integer
The total number of instances currently consuming space in this compute capacity reservation. This number is the sum of the values of the usedCount fields for all of the instance capacity configurations under this reservation. The purpose of this field is to calculate the percentage usage of the reservation.
107 108 109 |
# File 'lib/oci/core/models/compute_capacity_reservation.rb', line 107 def used_instance_count @used_instance_count end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/oci/core/models/compute_capacity_reservation.rb', line 110 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'availability_domain': :'availabilityDomain', 'compartment_id': :'compartmentId', 'defined_tags': :'definedTags', 'display_name': :'displayName', 'freeform_tags': :'freeformTags', 'id': :'id', 'is_default_reservation': :'isDefaultReservation', 'instance_reservation_configs': :'instanceReservationConfigs', 'lifecycle_state': :'lifecycleState', 'reserved_instance_count': :'reservedInstanceCount', 'time_updated': :'timeUpdated', 'time_created': :'timeCreated', 'used_instance_count': :'usedInstanceCount' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/oci/core/models/compute_capacity_reservation.rb', line 131 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'availability_domain': :'String', 'compartment_id': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'freeform_tags': :'Hash<String, String>', 'id': :'String', 'is_default_reservation': :'BOOLEAN', 'instance_reservation_configs': :'Array<OCI::Core::Models::InstanceReservationConfig>', 'lifecycle_state': :'String', 'reserved_instance_count': :'Integer', 'time_updated': :'DateTime', 'time_created': :'DateTime', 'used_instance_count': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 |
# File 'lib/oci/core/models/compute_capacity_reservation.rb', line 273 def ==(other) return true if equal?(other) self.class == other.class && availability_domain == other.availability_domain && compartment_id == other.compartment_id && == other. && display_name == other.display_name && == other. && id == other.id && is_default_reservation == other.is_default_reservation && instance_reservation_configs == other.instance_reservation_configs && lifecycle_state == other.lifecycle_state && reserved_instance_count == other.reserved_instance_count && time_updated == other.time_updated && time_created == other.time_created && used_instance_count == other.used_instance_count end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 |
# File 'lib/oci/core/models/compute_capacity_reservation.rb', line 315 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
295 296 297 |
# File 'lib/oci/core/models/compute_capacity_reservation.rb', line 295 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
304 305 306 |
# File 'lib/oci/core/models/compute_capacity_reservation.rb', line 304 def hash [availability_domain, compartment_id, , display_name, , id, is_default_reservation, instance_reservation_configs, lifecycle_state, reserved_instance_count, time_updated, time_created, used_instance_count].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
348 349 350 351 352 353 354 355 356 357 |
# File 'lib/oci/core/models/compute_capacity_reservation.rb', line 348 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
342 343 344 |
# File 'lib/oci/core/models/compute_capacity_reservation.rb', line 342 def to_s to_hash.to_s end |