Class: OCI::Core::Models::ComputeCapacityReservationSummary
- Inherits:
-
Object
- Object
- OCI::Core::Models::ComputeCapacityReservationSummary
- Defined in:
- lib/oci/core/models/compute_capacity_reservation_summary.rb
Overview
Summary information for a compute capacity reservation.
Instance Attribute Summary collapse
-
#availability_domain ⇒ String
[Required] The availability domain of the capacity reservation.
-
#compartment_id ⇒ String
The OCID of the compartment.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
A user-friendly name.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] The OCID of the instance reservation configuration.
-
#is_default_reservation ⇒ BOOLEAN
Whether this capacity reservation is the default.
-
#lifecycle_state ⇒ String
The current state of the capacity reservation.
-
#reserved_instance_count ⇒ Integer
The number of instances for which capacity will be held in this compute capacity reservation.
-
#time_created ⇒ DateTime
[Required] The date and time the capacity reservation was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#used_instance_count ⇒ Integer
The total number of instances currently consuming space in this compute capacity reservation.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ComputeCapacityReservationSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ComputeCapacityReservationSummary
Initializes the object
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/oci/core/models/compute_capacity_reservation_summary.rb', line 132 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain'] raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain') self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain'] self.reserved_instance_count = attributes[:'reservedInstanceCount'] if attributes[:'reservedInstanceCount'] raise 'You cannot provide both :reservedInstanceCount and :reserved_instance_count' if attributes.key?(:'reservedInstanceCount') && attributes.key?(:'reserved_instance_count') self.reserved_instance_count = attributes[:'reserved_instance_count'] if attributes[:'reserved_instance_count'] self.used_instance_count = attributes[:'usedInstanceCount'] if attributes[:'usedInstanceCount'] raise 'You cannot provide both :usedInstanceCount and :used_instance_count' if attributes.key?(:'usedInstanceCount') && attributes.key?(:'used_instance_count') self.used_instance_count = attributes[:'used_instance_count'] if attributes[:'used_instance_count'] self.is_default_reservation = attributes[:'isDefaultReservation'] unless attributes[:'isDefaultReservation'].nil? self.is_default_reservation = false if is_default_reservation.nil? && !attributes.key?(:'isDefaultReservation') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isDefaultReservation and :is_default_reservation' if attributes.key?(:'isDefaultReservation') && attributes.key?(:'is_default_reservation') self.is_default_reservation = attributes[:'is_default_reservation'] unless attributes[:'is_default_reservation'].nil? self.is_default_reservation = false if is_default_reservation.nil? && !attributes.key?(:'isDefaultReservation') && !attributes.key?(:'is_default_reservation') # rubocop:disable Style/StringLiterals self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] end |
Instance Attribute Details
#availability_domain ⇒ String
[Required] The availability domain of the capacity reservation.
47 48 49 |
# File 'lib/oci/core/models/compute_capacity_reservation_summary.rb', line 47 def availability_domain @availability_domain end |
#compartment_id ⇒ String
The OCID of the compartment.
17 18 19 |
# File 'lib/oci/core/models/compute_capacity_reservation_summary.rb', line 17 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
31 32 33 |
# File 'lib/oci/core/models/compute_capacity_reservation_summary.rb', line 31 def @defined_tags end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
23 24 25 |
# File 'lib/oci/core/models/compute_capacity_reservation_summary.rb', line 23 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
39 40 41 |
# File 'lib/oci/core/models/compute_capacity_reservation_summary.rb', line 39 def @freeform_tags end |
#id ⇒ String
[Required] The OCID of the instance reservation configuration.
13 14 15 |
# File 'lib/oci/core/models/compute_capacity_reservation_summary.rb', line 13 def id @id end |
#is_default_reservation ⇒ BOOLEAN
Whether this capacity reservation is the default. For more information, see [Capacity Reservations](docs.cloud.oracle.com/iaas/Content/Compute/Tasks/reserve-capacity.htm#default).
69 70 71 |
# File 'lib/oci/core/models/compute_capacity_reservation_summary.rb', line 69 def is_default_reservation @is_default_reservation end |
#lifecycle_state ⇒ String
The current state of the capacity reservation.
43 44 45 |
# File 'lib/oci/core/models/compute_capacity_reservation_summary.rb', line 43 def lifecycle_state @lifecycle_state end |
#reserved_instance_count ⇒ Integer
The number of instances for which capacity will be held in this compute capacity reservation. This number is the sum of the values of the reservedCount fields for all of the instance capacity configurations under this reservation. The purpose of this field is to calculate the percentage usage of the reservation.
55 56 57 |
# File 'lib/oci/core/models/compute_capacity_reservation_summary.rb', line 55 def reserved_instance_count @reserved_instance_count end |
#time_created ⇒ DateTime
[Required] The date and time the capacity reservation was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339). Example: 2016-08-25T21:10:29.600Z
75 76 77 |
# File 'lib/oci/core/models/compute_capacity_reservation_summary.rb', line 75 def time_created @time_created end |
#used_instance_count ⇒ Integer
The total number of instances currently consuming space in this compute capacity reservation. This number is the sum of the values of the usedCount fields for all of the instance capacity configurations under this reservation. The purpose of this field is to calculate the percentage usage of the reservation.
63 64 65 |
# File 'lib/oci/core/models/compute_capacity_reservation_summary.rb', line 63 def used_instance_count @used_instance_count end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/oci/core/models/compute_capacity_reservation_summary.rb', line 78 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'defined_tags': :'definedTags', 'freeform_tags': :'freeformTags', 'lifecycle_state': :'lifecycleState', 'availability_domain': :'availabilityDomain', 'reserved_instance_count': :'reservedInstanceCount', 'used_instance_count': :'usedInstanceCount', 'is_default_reservation': :'isDefaultReservation', 'time_created': :'timeCreated' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/oci/core/models/compute_capacity_reservation_summary.rb', line 97 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'display_name': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'freeform_tags': :'Hash<String, String>', 'lifecycle_state': :'String', 'availability_domain': :'String', 'reserved_instance_count': :'Integer', 'used_instance_count': :'Integer', 'is_default_reservation': :'BOOLEAN', 'time_created': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/oci/core/models/compute_capacity_reservation_summary.rb', line 210 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && display_name == other.display_name && == other. && == other. && lifecycle_state == other.lifecycle_state && availability_domain == other.availability_domain && reserved_instance_count == other.reserved_instance_count && used_instance_count == other.used_instance_count && is_default_reservation == other.is_default_reservation && time_created == other.time_created end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 |
# File 'lib/oci/core/models/compute_capacity_reservation_summary.rb', line 250 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
230 231 232 |
# File 'lib/oci/core/models/compute_capacity_reservation_summary.rb', line 230 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
239 240 241 |
# File 'lib/oci/core/models/compute_capacity_reservation_summary.rb', line 239 def hash [id, compartment_id, display_name, , , lifecycle_state, availability_domain, reserved_instance_count, used_instance_count, is_default_reservation, time_created].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
283 284 285 286 287 288 289 290 291 292 |
# File 'lib/oci/core/models/compute_capacity_reservation_summary.rb', line 283 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
277 278 279 |
# File 'lib/oci/core/models/compute_capacity_reservation_summary.rb', line 277 def to_s to_hash.to_s end |