Class: OCI::Core::Models::CreateClusterNetworkInstancePoolDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/core/models/create_cluster_network_instance_pool_details.rb

Overview

The data to create an instance pool in a cluster network.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateClusterNetworkInstancePoolDetails

Initializes the object

Options Hash (attributes):

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property

  • :display_name (String)

    The value to assign to the #display_name property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :instance_configuration_id (String)

    The value to assign to the #instance_configuration_id property

  • :size (Integer)

    The value to assign to the #size property



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/oci/core/models/create_cluster_network_instance_pool_details.rb', line 79

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.instance_configuration_id = attributes[:'instanceConfigurationId'] if attributes[:'instanceConfigurationId']

  raise 'You cannot provide both :instanceConfigurationId and :instance_configuration_id' if attributes.key?(:'instanceConfigurationId') && attributes.key?(:'instance_configuration_id')

  self.instance_configuration_id = attributes[:'instance_configuration_id'] if attributes[:'instance_configuration_id']

  self.size = attributes[:'size'] if attributes[:'size']
end

Instance Attribute Details

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).

Example: ‘{"CostCenter": "42"}`



16
17
18
# File 'lib/oci/core/models/create_cluster_network_instance_pool_details.rb', line 16

def defined_tags
  @defined_tags
end

#display_nameString

A user-friendly name. Does not have to be unique. Avoid entering confidential information.



21
22
23
# File 'lib/oci/core/models/create_cluster_network_instance_pool_details.rb', line 21

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).

Example: ‘"Finance"`



29
30
31
# File 'lib/oci/core/models/create_cluster_network_instance_pool_details.rb', line 29

def freeform_tags
  @freeform_tags
end

#instance_configuration_idString

[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the instance configuration associated with the instance pool.



35
36
37
# File 'lib/oci/core/models/create_cluster_network_instance_pool_details.rb', line 35

def instance_configuration_id
  @instance_configuration_id
end

#sizeInteger

[Required] The number of instances that should be in the instance pool.



40
41
42
# File 'lib/oci/core/models/create_cluster_network_instance_pool_details.rb', line 40

def size
  @size
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
# File 'lib/oci/core/models/create_cluster_network_instance_pool_details.rb', line 43

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'defined_tags': :'definedTags',
    'display_name': :'displayName',
    'freeform_tags': :'freeformTags',
    'instance_configuration_id': :'instanceConfigurationId',
    'size': :'size'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



56
57
58
59
60
61
62
63
64
65
66
# File 'lib/oci/core/models/create_cluster_network_instance_pool_details.rb', line 56

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'display_name': :'String',
    'freeform_tags': :'Hash<String, String>',
    'instance_configuration_id': :'String',
    'size': :'Integer'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.



119
120
121
122
123
124
125
126
127
128
# File 'lib/oci/core/models/create_cluster_network_instance_pool_details.rb', line 119

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    defined_tags == other.defined_tags &&
    display_name == other.display_name &&
    freeform_tags == other.freeform_tags &&
    instance_configuration_id == other.instance_configuration_id &&
    size == other.size
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/oci/core/models/create_cluster_network_instance_pool_details.rb', line 153

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method


133
134
135
# File 'lib/oci/core/models/create_cluster_network_instance_pool_details.rb', line 133

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.



142
143
144
# File 'lib/oci/core/models/create_cluster_network_instance_pool_details.rb', line 142

def hash
  [defined_tags, display_name, freeform_tags, instance_configuration_id, size].hash
end

#to_hashHash

Returns the object in the form of hash



186
187
188
189
190
191
192
193
194
195
# File 'lib/oci/core/models/create_cluster_network_instance_pool_details.rb', line 186

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



180
181
182
# File 'lib/oci/core/models/create_cluster_network_instance_pool_details.rb', line 180

def to_s
  to_hash.to_s
end