Class: OCI::Core::Models::CreateComputeImageCapabilitySchemaDetails
- Inherits:
-
Object
- Object
- OCI::Core::Models::CreateComputeImageCapabilitySchemaDetails
- Defined in:
- lib/oci/core/models/create_compute_image_capability_schema_details.rb
Overview
Create Image Capability Schema for an image.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The OCID of the compartment that contains the resource.
-
#compute_global_image_capability_schema_version_name ⇒ String
[Required] The name of the compute global image capability schema version.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
A user-friendly name.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#image_id ⇒ String
[Required] The ocid of the image.
-
#schema_data ⇒ Hash<String, OCI::Core::Models::ImageCapabilitySchemaDescriptor>
[Required] The map of each capability name to its ImageCapabilitySchemaDescriptor.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateComputeImageCapabilitySchemaDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateComputeImageCapabilitySchemaDetails
Initializes the object
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/oci/core/models/create_compute_image_capability_schema_details.rb', line 94 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.compute_global_image_capability_schema_version_name = attributes[:'computeGlobalImageCapabilitySchemaVersionName'] if attributes[:'computeGlobalImageCapabilitySchemaVersionName'] raise 'You cannot provide both :computeGlobalImageCapabilitySchemaVersionName and :compute_global_image_capability_schema_version_name' if attributes.key?(:'computeGlobalImageCapabilitySchemaVersionName') && attributes.key?(:'compute_global_image_capability_schema_version_name') self.compute_global_image_capability_schema_version_name = attributes[:'compute_global_image_capability_schema_version_name'] if attributes[:'compute_global_image_capability_schema_version_name'] self.image_id = attributes[:'imageId'] if attributes[:'imageId'] raise 'You cannot provide both :imageId and :image_id' if attributes.key?(:'imageId') && attributes.key?(:'image_id') self.image_id = attributes[:'image_id'] if attributes[:'image_id'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.schema_data = attributes[:'schemaData'] if attributes[:'schemaData'] raise 'You cannot provide both :schemaData and :schema_data' if attributes.key?(:'schemaData') && attributes.key?(:'schema_data') self.schema_data = attributes[:'schema_data'] if attributes[:'schema_data'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The OCID of the compartment that contains the resource.
13 14 15 |
# File 'lib/oci/core/models/create_compute_image_capability_schema_details.rb', line 13 def compartment_id @compartment_id end |
#compute_global_image_capability_schema_version_name ⇒ String
[Required] The name of the compute global image capability schema version
18 19 20 |
# File 'lib/oci/core/models/create_compute_image_capability_schema_details.rb', line 18 def compute_global_image_capability_schema_version_name @compute_global_image_capability_schema_version_name end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
45 46 47 |
# File 'lib/oci/core/models/create_compute_image_capability_schema_details.rb', line 45 def @defined_tags end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
37 38 39 |
# File 'lib/oci/core/models/create_compute_image_capability_schema_details.rb', line 37 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
31 32 33 |
# File 'lib/oci/core/models/create_compute_image_capability_schema_details.rb', line 31 def @freeform_tags end |
#image_id ⇒ String
[Required] The ocid of the image
23 24 25 |
# File 'lib/oci/core/models/create_compute_image_capability_schema_details.rb', line 23 def image_id @image_id end |
#schema_data ⇒ Hash<String, OCI::Core::Models::ImageCapabilitySchemaDescriptor>
[Required] The map of each capability name to its ImageCapabilitySchemaDescriptor.
49 50 51 |
# File 'lib/oci/core/models/create_compute_image_capability_schema_details.rb', line 49 def schema_data @schema_data end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/oci/core/models/create_compute_image_capability_schema_details.rb', line 52 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'compute_global_image_capability_schema_version_name': :'computeGlobalImageCapabilitySchemaVersionName', 'image_id': :'imageId', 'freeform_tags': :'freeformTags', 'display_name': :'displayName', 'defined_tags': :'definedTags', 'schema_data': :'schemaData' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/oci/core/models/create_compute_image_capability_schema_details.rb', line 67 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'compute_global_image_capability_schema_version_name': :'String', 'image_id': :'String', 'freeform_tags': :'Hash<String, String>', 'display_name': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'schema_data': :'Hash<String, OCI::Core::Models::ImageCapabilitySchemaDescriptor>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/oci/core/models/create_compute_image_capability_schema_details.rb', line 150 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && compute_global_image_capability_schema_version_name == other.compute_global_image_capability_schema_version_name && image_id == other.image_id && == other. && display_name == other.display_name && == other. && schema_data == other.schema_data end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/oci/core/models/create_compute_image_capability_schema_details.rb', line 186 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
166 167 168 |
# File 'lib/oci/core/models/create_compute_image_capability_schema_details.rb', line 166 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
175 176 177 |
# File 'lib/oci/core/models/create_compute_image_capability_schema_details.rb', line 175 def hash [compartment_id, compute_global_image_capability_schema_version_name, image_id, , display_name, , schema_data].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
219 220 221 222 223 224 225 226 227 228 |
# File 'lib/oci/core/models/create_compute_image_capability_schema_details.rb', line 219 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
213 214 215 |
# File 'lib/oci/core/models/create_compute_image_capability_schema_details.rb', line 213 def to_s to_hash.to_s end |