Class: OCI::Core::Models::CreateDhcpDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/core/models/create_dhcp_details.rb

Overview

CreateDhcpDetails model.

Constant Summary collapse

DOMAIN_NAME_TYPE_ENUM =
[
  DOMAIN_NAME_TYPE_SUBNET_DOMAIN = 'SUBNET_DOMAIN'.freeze,
  DOMAIN_NAME_TYPE_VCN_DOMAIN = 'VCN_DOMAIN'.freeze,
  DOMAIN_NAME_TYPE_CUSTOM_DOMAIN = 'CUSTOM_DOMAIN'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateDhcpDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property

  • :display_name (String)

    The value to assign to the #display_name property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :options (Array<OCI::Core::Models::DhcpOption>)

    The value to assign to the #options property

  • :vcn_id (String)

    The value to assign to the #vcn_id property

  • :domain_name_type (String)

    The value to assign to the #domain_name_type property



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/oci/core/models/create_dhcp_details.rb', line 97

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.options = attributes[:'options'] if attributes[:'options']

  self.vcn_id = attributes[:'vcnId'] if attributes[:'vcnId']

  raise 'You cannot provide both :vcnId and :vcn_id' if attributes.key?(:'vcnId') && attributes.key?(:'vcn_id')

  self.vcn_id = attributes[:'vcn_id'] if attributes[:'vcn_id']

  self.domain_name_type = attributes[:'domainNameType'] if attributes[:'domainNameType']

  raise 'You cannot provide both :domainNameType and :domain_name_type' if attributes.key?(:'domainNameType') && attributes.key?(:'domain_name_type')

  self.domain_name_type = attributes[:'domain_name_type'] if attributes[:'domain_name_type']
end

Instance Attribute Details

#compartment_idString

[Required] The OCID of the compartment to contain the set of DHCP options.

Returns:

  • (String)


18
19
20
# File 'lib/oci/core/models/create_dhcp_details.rb', line 18

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).

Example: ‘{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


26
27
28
# File 'lib/oci/core/models/create_dhcp_details.rb', line 26

def defined_tags
  @defined_tags
end

#display_nameString

A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.

Returns:

  • (String)


32
33
34
# File 'lib/oci/core/models/create_dhcp_details.rb', line 32

def display_name
  @display_name
end

#domain_name_typeString

The search domain name type of DHCP options

Returns:

  • (String)


52
53
54
# File 'lib/oci/core/models/create_dhcp_details.rb', line 52

def domain_name_type
  @domain_name_type
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).

Example: ‘"Finance"`

Returns:

  • (Hash<String, String>)


40
41
42
# File 'lib/oci/core/models/create_dhcp_details.rb', line 40

def freeform_tags
  @freeform_tags
end

#optionsArray<OCI::Core::Models::DhcpOption>

[Required] A set of DHCP options.

Returns:



44
45
46
# File 'lib/oci/core/models/create_dhcp_details.rb', line 44

def options
  @options
end

#vcn_idString

[Required] The OCID of the VCN the set of DHCP options belongs to.

Returns:

  • (String)


48
49
50
# File 'lib/oci/core/models/create_dhcp_details.rb', line 48

def vcn_id
  @vcn_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/oci/core/models/create_dhcp_details.rb', line 55

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'compartmentId',
    'defined_tags': :'definedTags',
    'display_name': :'displayName',
    'freeform_tags': :'freeformTags',
    'options': :'options',
    'vcn_id': :'vcnId',
    'domain_name_type': :'domainNameType'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/oci/core/models/create_dhcp_details.rb', line 70

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'String',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'display_name': :'String',
    'freeform_tags': :'Hash<String, String>',
    'options': :'Array<OCI::Core::Models::DhcpOption>',
    'vcn_id': :'String',
    'domain_name_type': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



157
158
159
160
161
162
163
164
165
166
167
168
# File 'lib/oci/core/models/create_dhcp_details.rb', line 157

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    compartment_id == other.compartment_id &&
    defined_tags == other.defined_tags &&
    display_name == other.display_name &&
    freeform_tags == other.freeform_tags &&
    options == other.options &&
    vcn_id == other.vcn_id &&
    domain_name_type == other.domain_name_type
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/oci/core/models/create_dhcp_details.rb', line 193

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


173
174
175
# File 'lib/oci/core/models/create_dhcp_details.rb', line 173

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



182
183
184
# File 'lib/oci/core/models/create_dhcp_details.rb', line 182

def hash
  [compartment_id, defined_tags, display_name, freeform_tags, options, vcn_id, domain_name_type].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



226
227
228
229
230
231
232
233
234
235
# File 'lib/oci/core/models/create_dhcp_details.rb', line 226

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



220
221
222
# File 'lib/oci/core/models/create_dhcp_details.rb', line 220

def to_s
  to_hash.to_s
end