Class: OCI::Core::Models::CreateDrgAttachmentDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/core/models/create_drg_attachment_details.rb

Overview

CreateDrgAttachmentDetails model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateDrgAttachmentDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/oci/core/models/create_drg_attachment_details.rb', line 112

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.drg_id = attributes[:'drgId'] if attributes[:'drgId']

  raise 'You cannot provide both :drgId and :drg_id' if attributes.key?(:'drgId') && attributes.key?(:'drg_id')

  self.drg_id = attributes[:'drg_id'] if attributes[:'drg_id']

  self.drg_route_table_id = attributes[:'drgRouteTableId'] if attributes[:'drgRouteTableId']

  raise 'You cannot provide both :drgRouteTableId and :drg_route_table_id' if attributes.key?(:'drgRouteTableId') && attributes.key?(:'drg_route_table_id')

  self.drg_route_table_id = attributes[:'drg_route_table_id'] if attributes[:'drg_route_table_id']

  self.network_details = attributes[:'networkDetails'] if attributes[:'networkDetails']

  raise 'You cannot provide both :networkDetails and :network_details' if attributes.key?(:'networkDetails') && attributes.key?(:'network_details')

  self.network_details = attributes[:'network_details'] if attributes[:'network_details']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.route_table_id = attributes[:'routeTableId'] if attributes[:'routeTableId']

  raise 'You cannot provide both :routeTableId and :route_table_id' if attributes.key?(:'routeTableId') && attributes.key?(:'route_table_id')

  self.route_table_id = attributes[:'route_table_id'] if attributes[:'route_table_id']

  self.vcn_id = attributes[:'vcnId'] if attributes[:'vcnId']

  raise 'You cannot provide both :vcnId and :vcn_id' if attributes.key?(:'vcnId') && attributes.key?(:'vcn_id')

  self.vcn_id = attributes[:'vcn_id'] if attributes[:'vcn_id']
end

Instance Attribute Details

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).

Example: `{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


36
37
38
# File 'lib/oci/core/models/create_drg_attachment_details.rb', line 36

def defined_tags
  @defined_tags
end

#display_nameString

A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.

Returns:

  • (String)


14
15
16
# File 'lib/oci/core/models/create_drg_attachment_details.rb', line 14

def display_name
  @display_name
end

#drg_idString

Returns:

  • (String)


18
19
20
# File 'lib/oci/core/models/create_drg_attachment_details.rb', line 18

def drg_id
  @drg_id
end

#drg_route_table_idString

The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the DRG route table that is assigned to this attachment.

The DRG route table manages traffic inside the DRG.

Returns:

  • (String)


25
26
27
# File 'lib/oci/core/models/create_drg_attachment_details.rb', line 25

def drg_route_table_id
  @drg_route_table_id
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).

Example: `"Finance"`

Returns:

  • (Hash<String, String>)


44
45
46
# File 'lib/oci/core/models/create_drg_attachment_details.rb', line 44

def freeform_tags
  @freeform_tags
end

#network_detailsOCI::Core::Models::DrgAttachmentNetworkCreateDetails



28
29
30
# File 'lib/oci/core/models/create_drg_attachment_details.rb', line 28

def network_details
  @network_details
end

#route_table_idString

The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the route table used by the DRG attachment.

If you don't specify a route table here, the DRG attachment is created without an associated route table. The Networking service does NOT automatically associate the attached VCN's default route table with the DRG attachment. For information about why you would associate a route table with a DRG attachment, see:

* [Transit Routing: Access to Multiple VCNs in Same Region](https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/transitrouting.htm)
* [Transit Routing: Private Access to Oracle Services](https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/transitroutingoracleservices.htm)

This field is deprecated. Instead, use the networkDetails field to specify the VCN route table for this attachment.

Returns:

  • (String)


58
59
60
# File 'lib/oci/core/models/create_drg_attachment_details.rb', line 58

def route_table_id
  @route_table_id
end

#vcn_idString

The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the VCN. This field is deprecated. Instead, use the `networkDetails` field to specify the [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the attached resource.

Returns:

  • (String)


64
65
66
# File 'lib/oci/core/models/create_drg_attachment_details.rb', line 64

def vcn_id
  @vcn_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/oci/core/models/create_drg_attachment_details.rb', line 67

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'displayName',
    'drg_id': :'drgId',
    'drg_route_table_id': :'drgRouteTableId',
    'network_details': :'networkDetails',
    'defined_tags': :'definedTags',
    'freeform_tags': :'freeformTags',
    'route_table_id': :'routeTableId',
    'vcn_id': :'vcnId'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/oci/core/models/create_drg_attachment_details.rb', line 83

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'String',
    'drg_id': :'String',
    'drg_route_table_id': :'String',
    'network_details': :'OCI::Core::Models::DrgAttachmentNetworkCreateDetails',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'freeform_tags': :'Hash<String, String>',
    'route_table_id': :'String',
    'vcn_id': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/oci/core/models/create_drg_attachment_details.rb', line 174

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    display_name == other.display_name &&
    drg_id == other.drg_id &&
    drg_route_table_id == other.drg_route_table_id &&
    network_details == other.network_details &&
    defined_tags == other.defined_tags &&
    freeform_tags == other.freeform_tags &&
    route_table_id == other.route_table_id &&
    vcn_id == other.vcn_id
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/oci/core/models/create_drg_attachment_details.rb', line 211

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


191
192
193
# File 'lib/oci/core/models/create_drg_attachment_details.rb', line 191

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



200
201
202
# File 'lib/oci/core/models/create_drg_attachment_details.rb', line 200

def hash
  [display_name, drg_id, drg_route_table_id, network_details, defined_tags, freeform_tags, route_table_id, vcn_id].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



244
245
246
247
248
249
250
251
252
253
# File 'lib/oci/core/models/create_drg_attachment_details.rb', line 244

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



238
239
240
# File 'lib/oci/core/models/create_drg_attachment_details.rb', line 238

def to_s
  to_hash.to_s
end