Class: OCI::Core::Models::CreateDrgRouteTableDetails
- Inherits:
-
Object
- Object
- OCI::Core::Models::CreateDrgRouteTableDetails
- Defined in:
- lib/oci/core/models/create_drg_route_table_details.rb
Overview
Details used in a request to create a DRG route table.
Instance Attribute Summary collapse
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
A user-friendly name.
-
#drg_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the DRG the DRG route table belongs to.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#import_drg_route_distribution_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the import route distribution used to specify how incoming route advertisements through referenced attachments are inserted into the DRG route table.
-
#is_ecmp_enabled ⇒ BOOLEAN
If you want traffic to be routed using ECMP across your virtual circuits or IPSec tunnels to your on-premises networks, enable ECMP on the DRG route table.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateDrgRouteTableDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateDrgRouteTableDetails
Initializes the object
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/oci/core/models/create_drg_route_table_details.rb', line 90 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.drg_id = attributes[:'drgId'] if attributes[:'drgId'] raise 'You cannot provide both :drgId and :drg_id' if attributes.key?(:'drgId') && attributes.key?(:'drg_id') self.drg_id = attributes[:'drg_id'] if attributes[:'drg_id'] self.import_drg_route_distribution_id = attributes[:'importDrgRouteDistributionId'] if attributes[:'importDrgRouteDistributionId'] raise 'You cannot provide both :importDrgRouteDistributionId and :import_drg_route_distribution_id' if attributes.key?(:'importDrgRouteDistributionId') && attributes.key?(:'import_drg_route_distribution_id') self.import_drg_route_distribution_id = attributes[:'import_drg_route_distribution_id'] if attributes[:'import_drg_route_distribution_id'] self.is_ecmp_enabled = attributes[:'isEcmpEnabled'] unless attributes[:'isEcmpEnabled'].nil? self.is_ecmp_enabled = false if is_ecmp_enabled.nil? && !attributes.key?(:'isEcmpEnabled') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isEcmpEnabled and :is_ecmp_enabled' if attributes.key?(:'isEcmpEnabled') && attributes.key?(:'is_ecmp_enabled') self.is_ecmp_enabled = attributes[:'is_ecmp_enabled'] unless attributes[:'is_ecmp_enabled'].nil? self.is_ecmp_enabled = false if is_ecmp_enabled.nil? && !attributes.key?(:'isEcmpEnabled') && !attributes.key?(:'is_ecmp_enabled') # rubocop:disable Style/StringLiterals end |
Instance Attribute Details
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
17 18 19 |
# File 'lib/oci/core/models/create_drg_route_table_details.rb', line 17 def end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
23 24 25 |
# File 'lib/oci/core/models/create_drg_route_table_details.rb', line 23 def display_name @display_name end |
#drg_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the DRG the DRG route table belongs to.
36 37 38 |
# File 'lib/oci/core/models/create_drg_route_table_details.rb', line 36 def drg_id @drg_id end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
31 32 33 |
# File 'lib/oci/core/models/create_drg_route_table_details.rb', line 31 def end |
#import_drg_route_distribution_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the import route distribution used to specify how incoming route advertisements through referenced attachments are inserted into the DRG route table.
42 43 44 |
# File 'lib/oci/core/models/create_drg_route_table_details.rb', line 42 def import_drg_route_distribution_id @import_drg_route_distribution_id end |
#is_ecmp_enabled ⇒ BOOLEAN
If you want traffic to be routed using ECMP across your virtual circuits or IPSec tunnels to your on-premises networks, enable ECMP on the DRG route table.
48 49 50 |
# File 'lib/oci/core/models/create_drg_route_table_details.rb', line 48 def is_ecmp_enabled @is_ecmp_enabled end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/oci/core/models/create_drg_route_table_details.rb', line 51 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'defined_tags': :'definedTags', 'display_name': :'displayName', 'freeform_tags': :'freeformTags', 'drg_id': :'drgId', 'import_drg_route_distribution_id': :'importDrgRouteDistributionId', 'is_ecmp_enabled': :'isEcmpEnabled' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/oci/core/models/create_drg_route_table_details.rb', line 65 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'defined_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'freeform_tags': :'Hash<String, String>', 'drg_id': :'String', 'import_drg_route_distribution_id': :'String', 'is_ecmp_enabled': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/oci/core/models/create_drg_route_table_details.rb', line 142 def ==(other) return true if equal?(other) self.class == other.class && == other. && display_name == other.display_name && == other. && drg_id == other.drg_id && import_drg_route_distribution_id == other.import_drg_route_distribution_id && is_ecmp_enabled == other.is_ecmp_enabled end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/oci/core/models/create_drg_route_table_details.rb', line 177 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
157 158 159 |
# File 'lib/oci/core/models/create_drg_route_table_details.rb', line 157 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
166 167 168 |
# File 'lib/oci/core/models/create_drg_route_table_details.rb', line 166 def hash [, display_name, , drg_id, import_drg_route_distribution_id, is_ecmp_enabled].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
210 211 212 213 214 215 216 217 218 219 |
# File 'lib/oci/core/models/create_drg_route_table_details.rb', line 210 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
204 205 206 |
# File 'lib/oci/core/models/create_drg_route_table_details.rb', line 204 def to_s to_hash.to_s end |