Class: OCI::Core::Models::CreateSecurityListDetails
- Inherits:
-
Object
- Object
- OCI::Core::Models::CreateSecurityListDetails
- Defined in:
- lib/oci/core/models/create_security_list_details.rb
Overview
CreateSecurityListDetails model.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment to contain the security list.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
A user-friendly name.
-
#egress_security_rules ⇒ Array<OCI::Core::Models::EgressSecurityRule>
[Required] Rules for allowing egress IP packets.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#ingress_security_rules ⇒ Array<OCI::Core::Models::IngressSecurityRule>
[Required] Rules for allowing ingress IP packets.
-
#vcn_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the VCN the security list belongs to.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateSecurityListDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateSecurityListDetails
Initializes the object
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/oci/core/models/create_security_list_details.rb', line 91 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.egress_security_rules = attributes[:'egressSecurityRules'] if attributes[:'egressSecurityRules'] raise 'You cannot provide both :egressSecurityRules and :egress_security_rules' if attributes.key?(:'egressSecurityRules') && attributes.key?(:'egress_security_rules') self.egress_security_rules = attributes[:'egress_security_rules'] if attributes[:'egress_security_rules'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.ingress_security_rules = attributes[:'ingressSecurityRules'] if attributes[:'ingressSecurityRules'] raise 'You cannot provide both :ingressSecurityRules and :ingress_security_rules' if attributes.key?(:'ingressSecurityRules') && attributes.key?(:'ingress_security_rules') self.ingress_security_rules = attributes[:'ingress_security_rules'] if attributes[:'ingress_security_rules'] self.vcn_id = attributes[:'vcnId'] if attributes[:'vcnId'] raise 'You cannot provide both :vcnId and :vcn_id' if attributes.key?(:'vcnId') && attributes.key?(:'vcn_id') self.vcn_id = attributes[:'vcn_id'] if attributes[:'vcn_id'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment to contain the security list.
12 13 14 |
# File 'lib/oci/core/models/create_security_list_details.rb', line 12 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
20 21 22 |
# File 'lib/oci/core/models/create_security_list_details.rb', line 20 def @defined_tags end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
26 27 28 |
# File 'lib/oci/core/models/create_security_list_details.rb', line 26 def display_name @display_name end |
#egress_security_rules ⇒ Array<OCI::Core::Models::EgressSecurityRule>
[Required] Rules for allowing egress IP packets.
30 31 32 |
# File 'lib/oci/core/models/create_security_list_details.rb', line 30 def egress_security_rules @egress_security_rules end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
38 39 40 |
# File 'lib/oci/core/models/create_security_list_details.rb', line 38 def @freeform_tags end |
#ingress_security_rules ⇒ Array<OCI::Core::Models::IngressSecurityRule>
[Required] Rules for allowing ingress IP packets.
42 43 44 |
# File 'lib/oci/core/models/create_security_list_details.rb', line 42 def ingress_security_rules @ingress_security_rules end |
#vcn_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the VCN the security list belongs to.
46 47 48 |
# File 'lib/oci/core/models/create_security_list_details.rb', line 46 def vcn_id @vcn_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/oci/core/models/create_security_list_details.rb', line 49 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'defined_tags': :'definedTags', 'display_name': :'displayName', 'egress_security_rules': :'egressSecurityRules', 'freeform_tags': :'freeformTags', 'ingress_security_rules': :'ingressSecurityRules', 'vcn_id': :'vcnId' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/oci/core/models/create_security_list_details.rb', line 64 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'egress_security_rules': :'Array<OCI::Core::Models::EgressSecurityRule>', 'freeform_tags': :'Hash<String, String>', 'ingress_security_rules': :'Array<OCI::Core::Models::IngressSecurityRule>', 'vcn_id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/oci/core/models/create_security_list_details.rb', line 147 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && == other. && display_name == other.display_name && egress_security_rules == other.egress_security_rules && == other. && ingress_security_rules == other.ingress_security_rules && vcn_id == other.vcn_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/oci/core/models/create_security_list_details.rb', line 183 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
163 164 165 |
# File 'lib/oci/core/models/create_security_list_details.rb', line 163 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
172 173 174 |
# File 'lib/oci/core/models/create_security_list_details.rb', line 172 def hash [compartment_id, , display_name, egress_security_rules, , ingress_security_rules, vcn_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
216 217 218 219 220 221 222 223 224 225 |
# File 'lib/oci/core/models/create_security_list_details.rb', line 216 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
210 211 212 |
# File 'lib/oci/core/models/create_security_list_details.rb', line 210 def to_s to_hash.to_s end |