Class: OCI::Core::Models::CreateVlanDetails
- Inherits:
-
Object
- Object
- OCI::Core::Models::CreateVlanDetails
- Defined in:
- lib/oci/core/models/create_vlan_details.rb
Overview
CreateVlanDetails model.
Instance Attribute Summary collapse
-
#availability_domain ⇒ String
Controls whether the VLAN is regional or specific to an availability domain.
-
#cidr_block ⇒ String
[Required] The range of IPv4 addresses that will be used for layer 3 communication with hosts outside the VLAN.
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment to contain the VLAN.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
A user-friendly name.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#nsg_ids ⇒ Array<String>
A list of the OCIDs of the network security groups (NSGs) to add all VNICs in the VLAN to.
-
#route_table_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the route table the VLAN will use.
-
#vcn_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the VCN to contain the VLAN.
-
#vlan_tag ⇒ Integer
The IEEE 802.1Q VLAN tag for this VLAN.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateVlanDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateVlanDetails
Initializes the object
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/oci/core/models/create_vlan_details.rb', line 138 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain'] raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain') self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain'] self.cidr_block = attributes[:'cidrBlock'] if attributes[:'cidrBlock'] raise 'You cannot provide both :cidrBlock and :cidr_block' if attributes.key?(:'cidrBlock') && attributes.key?(:'cidr_block') self.cidr_block = attributes[:'cidr_block'] if attributes[:'cidr_block'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.nsg_ids = attributes[:'nsgIds'] if attributes[:'nsgIds'] raise 'You cannot provide both :nsgIds and :nsg_ids' if attributes.key?(:'nsgIds') && attributes.key?(:'nsg_ids') self.nsg_ids = attributes[:'nsg_ids'] if attributes[:'nsg_ids'] self.route_table_id = attributes[:'routeTableId'] if attributes[:'routeTableId'] raise 'You cannot provide both :routeTableId and :route_table_id' if attributes.key?(:'routeTableId') && attributes.key?(:'route_table_id') self.route_table_id = attributes[:'route_table_id'] if attributes[:'route_table_id'] self.vcn_id = attributes[:'vcnId'] if attributes[:'vcnId'] raise 'You cannot provide both :vcnId and :vcn_id' if attributes.key?(:'vcnId') && attributes.key?(:'vcn_id') self.vcn_id = attributes[:'vcn_id'] if attributes[:'vcn_id'] self.vlan_tag = attributes[:'vlanTag'] if attributes[:'vlanTag'] raise 'You cannot provide both :vlanTag and :vlan_tag' if attributes.key?(:'vlanTag') && attributes.key?(:'vlan_tag') self.vlan_tag = attributes[:'vlan_tag'] if attributes[:'vlan_tag'] end |
Instance Attribute Details
#availability_domain ⇒ String
Controls whether the VLAN is regional or specific to an availability domain. A regional VLAN has the flexibility to implement failover across availability domains. Previously, all VLANs were AD-specific.
To create a regional VLAN, omit this attribute. Resources created subsequently in this VLAN (such as a Compute instance) can be created in any availability domain in the region.
To create an AD-specific VLAN, use this attribute to specify the availability domain. Resources created in this VLAN must be in that availability domain.
Example: Uocm:PHX-AD-1
23 24 25 |
# File 'lib/oci/core/models/create_vlan_details.rb', line 23 def availability_domain @availability_domain end |
#cidr_block ⇒ String
[Required] The range of IPv4 addresses that will be used for layer 3 communication with hosts outside the VLAN. The CIDR must maintain the following rules -
-
The CIDR block is valid and correctly formatted.
-
The new range is within one of the parent VCN ranges.
Example: 192.0.2.0/24
34 35 36 |
# File 'lib/oci/core/models/create_vlan_details.rb', line 34 def cidr_block @cidr_block end |
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment to contain the VLAN.
38 39 40 |
# File 'lib/oci/core/models/create_vlan_details.rb', line 38 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
46 47 48 |
# File 'lib/oci/core/models/create_vlan_details.rb', line 46 def end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
52 53 54 |
# File 'lib/oci/core/models/create_vlan_details.rb', line 52 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
60 61 62 |
# File 'lib/oci/core/models/create_vlan_details.rb', line 60 def end |
#nsg_ids ⇒ Array<String>
A list of the OCIDs of the network security groups (NSGs) to add all VNICs in the VLAN to. For more information about NSGs, see NetworkSecurityGroup.
67 68 69 |
# File 'lib/oci/core/models/create_vlan_details.rb', line 67 def nsg_ids @nsg_ids end |
#route_table_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the route table the VLAN will use. If you don’t provide a value, the VLAN uses the VCN’s default route table.
73 74 75 |
# File 'lib/oci/core/models/create_vlan_details.rb', line 73 def route_table_id @route_table_id end |
#vcn_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the VCN to contain the VLAN.
77 78 79 |
# File 'lib/oci/core/models/create_vlan_details.rb', line 77 def vcn_id @vcn_id end |
#vlan_tag ⇒ Integer
The IEEE 802.1Q VLAN tag for this VLAN. The value must be unique across all VLANs in the VCN. If you don’t provide a value, Oracle assigns one. You cannot change the value later. VLAN tag 0 is reserved for use by Oracle.
84 85 86 |
# File 'lib/oci/core/models/create_vlan_details.rb', line 84 def vlan_tag @vlan_tag end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/oci/core/models/create_vlan_details.rb', line 87 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'availability_domain': :'availabilityDomain', 'cidr_block': :'cidrBlock', 'compartment_id': :'compartmentId', 'defined_tags': :'definedTags', 'display_name': :'displayName', 'freeform_tags': :'freeformTags', 'nsg_ids': :'nsgIds', 'route_table_id': :'routeTableId', 'vcn_id': :'vcnId', 'vlan_tag': :'vlanTag' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/oci/core/models/create_vlan_details.rb', line 105 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'availability_domain': :'String', 'cidr_block': :'String', 'compartment_id': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'freeform_tags': :'Hash<String, String>', 'nsg_ids': :'Array<String>', 'route_table_id': :'String', 'vcn_id': :'String', 'vlan_tag': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/oci/core/models/create_vlan_details.rb', line 212 def ==(other) return true if equal?(other) self.class == other.class && availability_domain == other.availability_domain && cidr_block == other.cidr_block && compartment_id == other.compartment_id && == other. && display_name == other.display_name && == other. && nsg_ids == other.nsg_ids && route_table_id == other.route_table_id && vcn_id == other.vcn_id && vlan_tag == other.vlan_tag end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/oci/core/models/create_vlan_details.rb', line 251 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
231 232 233 |
# File 'lib/oci/core/models/create_vlan_details.rb', line 231 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
240 241 242 |
# File 'lib/oci/core/models/create_vlan_details.rb', line 240 def hash [availability_domain, cidr_block, compartment_id, , display_name, , nsg_ids, route_table_id, vcn_id, vlan_tag].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
284 285 286 287 288 289 290 291 292 293 |
# File 'lib/oci/core/models/create_vlan_details.rb', line 284 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
278 279 280 |
# File 'lib/oci/core/models/create_vlan_details.rb', line 278 def to_s to_hash.to_s end |