Class: OCI::Core::Models::CreateVnicDetails
- Inherits:
-
Object
- Object
- OCI::Core::Models::CreateVnicDetails
- Defined in:
- lib/oci/core/models/create_vnic_details.rb
Overview
Contains properties for a VNIC. You use this object when creating the primary VNIC during instance launch or when creating a secondary VNIC. For more information about VNICs, see [Virtual Network Interface Cards (VNICs)](docs.cloud.oracle.com/iaas/Content/Network/Tasks/managingVNICs.htm).
Instance Attribute Summary collapse
-
#assign_private_dns_record ⇒ BOOLEAN
Whether the VNIC should be assigned a DNS record.
-
#assign_public_ip ⇒ BOOLEAN
Whether the VNIC should be assigned a public IP address.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
A user-friendly name for the VNIC.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#hostname_label ⇒ String
The hostname for the VNIC’s primary private IP.
-
#nsg_ids ⇒ Array<String>
A list of the OCIDs of the network security groups (NSGs) to add the VNIC to.
-
#private_ip ⇒ String
A private IP address of your choice to assign to the VNIC.
-
#skip_source_dest_check ⇒ BOOLEAN
Whether the source/destination check is disabled on the VNIC.
-
#subnet_id ⇒ String
The OCID of the subnet to create the VNIC in.
-
#vlan_id ⇒ String
Provide this attribute only if you are an Oracle Cloud VMware Solution customer and creating a secondary VNIC in a VLAN.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateVnicDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateVnicDetails
Initializes the object
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 |
# File 'lib/oci/core/models/create_vnic_details.rb', line 221 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.assign_public_ip = attributes[:'assignPublicIp'] unless attributes[:'assignPublicIp'].nil? raise 'You cannot provide both :assignPublicIp and :assign_public_ip' if attributes.key?(:'assignPublicIp') && attributes.key?(:'assign_public_ip') self.assign_public_ip = attributes[:'assign_public_ip'] unless attributes[:'assign_public_ip'].nil? self.assign_private_dns_record = attributes[:'assignPrivateDnsRecord'] unless attributes[:'assignPrivateDnsRecord'].nil? raise 'You cannot provide both :assignPrivateDnsRecord and :assign_private_dns_record' if attributes.key?(:'assignPrivateDnsRecord') && attributes.key?(:'assign_private_dns_record') self.assign_private_dns_record = attributes[:'assign_private_dns_record'] unless attributes[:'assign_private_dns_record'].nil? self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.hostname_label = attributes[:'hostnameLabel'] if attributes[:'hostnameLabel'] raise 'You cannot provide both :hostnameLabel and :hostname_label' if attributes.key?(:'hostnameLabel') && attributes.key?(:'hostname_label') self.hostname_label = attributes[:'hostname_label'] if attributes[:'hostname_label'] self.nsg_ids = attributes[:'nsgIds'] if attributes[:'nsgIds'] raise 'You cannot provide both :nsgIds and :nsg_ids' if attributes.key?(:'nsgIds') && attributes.key?(:'nsg_ids') self.nsg_ids = attributes[:'nsg_ids'] if attributes[:'nsg_ids'] self.private_ip = attributes[:'privateIp'] if attributes[:'privateIp'] raise 'You cannot provide both :privateIp and :private_ip' if attributes.key?(:'privateIp') && attributes.key?(:'private_ip') self.private_ip = attributes[:'private_ip'] if attributes[:'private_ip'] self.skip_source_dest_check = attributes[:'skipSourceDestCheck'] unless attributes[:'skipSourceDestCheck'].nil? raise 'You cannot provide both :skipSourceDestCheck and :skip_source_dest_check' if attributes.key?(:'skipSourceDestCheck') && attributes.key?(:'skip_source_dest_check') self.skip_source_dest_check = attributes[:'skip_source_dest_check'] unless attributes[:'skip_source_dest_check'].nil? self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId'] raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id') self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id'] self.vlan_id = attributes[:'vlanId'] if attributes[:'vlanId'] raise 'You cannot provide both :vlanId and :vlan_id' if attributes.key?(:'vlanId') && attributes.key?(:'vlan_id') self.vlan_id = attributes[:'vlan_id'] if attributes[:'vlan_id'] end |
Instance Attribute Details
#assign_private_dns_record ⇒ BOOLEAN
Whether the VNIC should be assigned a DNS record. If set to false, there will be no DNS record registration for the VNIC. If set to true, the DNS record will be registered. The default value is true.
If you specify a hostnameLabel, then assignPrivateDnsRecord must be set to true.
48 49 50 |
# File 'lib/oci/core/models/create_vnic_details.rb', line 48 def assign_private_dns_record @assign_private_dns_record end |
#assign_public_ip ⇒ BOOLEAN
Whether the VNIC should be assigned a public IP address. Defaults to whether the subnet is public or private. If not set and the VNIC is being created in a private subnet (that is, where prohibitPublicIpOnVnic = true in the Subnet), then no public IP address is assigned. If not set and the subnet is public (prohibitPublicIpOnVnic = false), then a public IP address is assigned. If set to true and prohibitPublicIpOnVnic = true, an error is returned.
Note: This public IP address is associated with the primary private IP on the VNIC. For more information, see [IP Addresses](docs.cloud.oracle.com/iaas/Content/Network/Tasks/managingIPaddresses.htm).
Note: There’s a limit to the number of PublicIp a VNIC or instance can have. If you try to create a secondary VNIC with an assigned public IP for an instance that has already reached its public IP limit, an error is returned. For information about the public IP limits, see [Public IP Addresses](docs.cloud.oracle.com/iaas/Content/Network/Tasks/managingpublicIPs.htm).
Example: false
If you specify a vlanId, then assignPublicIp must be set to false. See Vlan.
39 40 41 |
# File 'lib/oci/core/models/create_vnic_details.rb', line 39 def assign_public_ip @assign_public_ip end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
56 57 58 |
# File 'lib/oci/core/models/create_vnic_details.rb', line 56 def end |
#display_name ⇒ String
A user-friendly name for the VNIC. Does not have to be unique. Avoid entering confidential information.
62 63 64 |
# File 'lib/oci/core/models/create_vnic_details.rb', line 62 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
70 71 72 |
# File 'lib/oci/core/models/create_vnic_details.rb', line 70 def end |
#hostname_label ⇒ String
The hostname for the VNIC’s primary private IP. Used for DNS. The value is the hostname portion of the primary private IP’s fully qualified domain name (FQDN) (for example, bminstance-1 in FQDN bminstance-1.subnet123.vcn1.oraclevcn.com). Must be unique across all VNICs in the subnet and comply with [RFC 952](tools.ietf.org/html/rfc952) and [RFC 1123](tools.ietf.org/html/rfc1123). The value appears in the Vnic object and also the PrivateIp object returned by list_private_ips and get_private_ip.
For more information, see [DNS in Your Virtual Cloud Network](docs.cloud.oracle.com/iaas/Content/Network/Concepts/dns.htm).
When launching an instance, use this hostnameLabel instead of the deprecated hostnameLabel in launch_instance_details. If you provide both, the values must match.
Example: bminstance-1
If you specify a vlanId, the hostnameLabel cannot be specified. VNICs on a VLAN can not be assigned a hostname. See Vlan.
97 98 99 |
# File 'lib/oci/core/models/create_vnic_details.rb', line 97 def hostname_label @hostname_label end |
#nsg_ids ⇒ Array<String>
A list of the OCIDs of the network security groups (NSGs) to add the VNIC to. For more information about NSGs, see NetworkSecurityGroup.
If a vlanId is specified, the nsgIds cannot be specified. The vlanId indicates that the VNIC will belong to a VLAN instead of a subnet. With VLANs, all VNICs in the VLAN belong to the NSGs that are associated with the VLAN. See Vlan.
109 110 111 |
# File 'lib/oci/core/models/create_vnic_details.rb', line 109 def nsg_ids @nsg_ids end |
#private_ip ⇒ String
A private IP address of your choice to assign to the VNIC. Must be an available IP address within the subnet’s CIDR. If you don’t specify a value, Oracle automatically assigns a private IP address from the subnet. This is the VNIC’s primary private IP address. The value appears in the Vnic object and also the PrivateIp object returned by list_private_ips and get_private_ip.
If you specify a vlanId, the privateIp cannot be specified. See Vlan.
Example: 10.0.3.3
127 128 129 |
# File 'lib/oci/core/models/create_vnic_details.rb', line 127 def private_ip @private_ip end |
#skip_source_dest_check ⇒ BOOLEAN
Whether the source/destination check is disabled on the VNIC. Defaults to false, which means the check is performed. For information about why you would skip the source/destination check, see [Using a Private IP as a Route Target](docs.cloud.oracle.com/iaas/Content/Network/Tasks/managingroutetables.htm#privateip).
If you specify a vlanId, the skipSourceDestCheck cannot be specified because the source/destination check is always disabled for VNICs in a VLAN. See Vlan.
Example: true
142 143 144 |
# File 'lib/oci/core/models/create_vnic_details.rb', line 142 def skip_source_dest_check @skip_source_dest_check end |
#subnet_id ⇒ String
The OCID of the subnet to create the VNIC in. When launching an instance, use this subnetId instead of the deprecated subnetId in launch_instance_details. At least one of them is required; if you provide both, the values must match.
If you are an Oracle Cloud VMware Solution customer and creating a secondary VNIC in a VLAN instead of a subnet, provide a vlanId instead of a subnetId. If you provide both a vlanId and subnetId, the request fails.
154 155 156 |
# File 'lib/oci/core/models/create_vnic_details.rb', line 154 def subnet_id @subnet_id end |
#vlan_id ⇒ String
Provide this attribute only if you are an Oracle Cloud VMware Solution customer and creating a secondary VNIC in a VLAN. The value is the OCID of the VLAN. See Vlan.
Provide a vlanId instead of a subnetId. If you provide both a vlanId and subnetId, the request fails.
164 165 166 |
# File 'lib/oci/core/models/create_vnic_details.rb', line 164 def vlan_id @vlan_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/oci/core/models/create_vnic_details.rb', line 167 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'assign_public_ip': :'assignPublicIp', 'assign_private_dns_record': :'assignPrivateDnsRecord', 'defined_tags': :'definedTags', 'display_name': :'displayName', 'freeform_tags': :'freeformTags', 'hostname_label': :'hostnameLabel', 'nsg_ids': :'nsgIds', 'private_ip': :'privateIp', 'skip_source_dest_check': :'skipSourceDestCheck', 'subnet_id': :'subnetId', 'vlan_id': :'vlanId' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/oci/core/models/create_vnic_details.rb', line 186 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'assign_public_ip': :'BOOLEAN', 'assign_private_dns_record': :'BOOLEAN', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'freeform_tags': :'Hash<String, String>', 'hostname_label': :'String', 'nsg_ids': :'Array<String>', 'private_ip': :'String', 'skip_source_dest_check': :'BOOLEAN', 'subnet_id': :'String', 'vlan_id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 |
# File 'lib/oci/core/models/create_vnic_details.rb', line 301 def ==(other) return true if equal?(other) self.class == other.class && assign_public_ip == other.assign_public_ip && assign_private_dns_record == other.assign_private_dns_record && == other. && display_name == other.display_name && == other. && hostname_label == other.hostname_label && nsg_ids == other.nsg_ids && private_ip == other.private_ip && skip_source_dest_check == other.skip_source_dest_check && subnet_id == other.subnet_id && vlan_id == other.vlan_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 |
# File 'lib/oci/core/models/create_vnic_details.rb', line 341 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
321 322 323 |
# File 'lib/oci/core/models/create_vnic_details.rb', line 321 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
330 331 332 |
# File 'lib/oci/core/models/create_vnic_details.rb', line 330 def hash [assign_public_ip, assign_private_dns_record, , display_name, , hostname_label, nsg_ids, private_ip, skip_source_dest_check, subnet_id, vlan_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
374 375 376 377 378 379 380 381 382 383 |
# File 'lib/oci/core/models/create_vnic_details.rb', line 374 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
368 369 370 |
# File 'lib/oci/core/models/create_vnic_details.rb', line 368 def to_s to_hash.to_s end |