Method: OCI::Core::Models::CreateVolumeDetails#source_details

Defined in:
lib/oci/core/models/create_volume_details.rb

#source_detailsOCI::Core::Models::VolumeSourceDetails

Specifies the volume source details for a new Block volume. The volume source is either another Block volume in the same availability domain or a Block volume backup. This is an optional field. If not specified or set to null, the new Block volume will be empty. When specified, the new Block volume will contain data from the source volume or backup.



67
68
69
# File 'lib/oci/core/models/create_volume_details.rb', line 67

def source_details
  @source_details
end