Class: OCI::Core::Models::CrossConnect
- Inherits:
-
Object
- Object
- OCI::Core::Models::CrossConnect
- Defined in:
- lib/oci/core/models/cross_connect.rb
Overview
For use with Oracle Cloud Infrastructure FastConnect. A cross-connect represents a physical connection between an existing network and Oracle. Customers who are colocated with Oracle in a FastConnect location create and use cross-connects. For more information, see [FastConnect Overview](docs.cloud.oracle.com/iaas/Content/Network/Concepts/fastconnect.htm).
Oracle recommends you create each cross-connect in a CrossConnectGroup so you can use link aggregation with the connection.
Note: If you’re a provider who is setting up a physical connection to Oracle so customers can use FastConnect over the connection, be aware that your connection is modeled the same way as a colocated customer’s (with CrossConnect and CrossConnectGroup objects, and so on).
To use any of the API operations, you must be authorized in an IAM policy. If you’re not authorized, talk to an administrator. If you’re an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/iaas/Content/Identity/Concepts/policygetstarted.htm).
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_PENDING_CUSTOMER = 'PENDING_CUSTOMER'.freeze, LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze, LIFECYCLE_STATE_PROVISIONED = 'PROVISIONED'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze, LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the cross-connect group.
-
#cross_connect_group_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the cross-connect group this cross-connect belongs to (if any).
-
#customer_reference_name ⇒ String
A reference name or identifier for the physical fiber connection that this cross-connect uses.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
A user-friendly name.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
The cross-connect’s Oracle ID (OCID).
-
#lifecycle_state ⇒ String
The cross-connect’s current state.
-
#location_name ⇒ String
The name of the FastConnect location where this cross-connect is installed.
- #macsec_properties ⇒ OCI::Core::Models::MacsecProperties
-
#port_name ⇒ String
A string identifying the meet-me room port for this cross-connect.
-
#port_speed_shape_name ⇒ String
The port speed for this cross-connect.
-
#time_created ⇒ DateTime
The date and time the cross-connect was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CrossConnect
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CrossConnect
Initializes the object
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/oci/core/models/cross_connect.rb', line 169 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.cross_connect_group_id = attributes[:'crossConnectGroupId'] if attributes[:'crossConnectGroupId'] raise 'You cannot provide both :crossConnectGroupId and :cross_connect_group_id' if attributes.key?(:'crossConnectGroupId') && attributes.key?(:'cross_connect_group_id') self.cross_connect_group_id = attributes[:'cross_connect_group_id'] if attributes[:'cross_connect_group_id'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.id = attributes[:'id'] if attributes[:'id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.location_name = attributes[:'locationName'] if attributes[:'locationName'] raise 'You cannot provide both :locationName and :location_name' if attributes.key?(:'locationName') && attributes.key?(:'location_name') self.location_name = attributes[:'location_name'] if attributes[:'location_name'] self.port_name = attributes[:'portName'] if attributes[:'portName'] raise 'You cannot provide both :portName and :port_name' if attributes.key?(:'portName') && attributes.key?(:'port_name') self.port_name = attributes[:'port_name'] if attributes[:'port_name'] self.port_speed_shape_name = attributes[:'portSpeedShapeName'] if attributes[:'portSpeedShapeName'] raise 'You cannot provide both :portSpeedShapeName and :port_speed_shape_name' if attributes.key?(:'portSpeedShapeName') && attributes.key?(:'port_speed_shape_name') self.port_speed_shape_name = attributes[:'port_speed_shape_name'] if attributes[:'port_speed_shape_name'] self.customer_reference_name = attributes[:'customerReferenceName'] if attributes[:'customerReferenceName'] raise 'You cannot provide both :customerReferenceName and :customer_reference_name' if attributes.key?(:'customerReferenceName') && attributes.key?(:'customer_reference_name') self.customer_reference_name = attributes[:'customer_reference_name'] if attributes[:'customer_reference_name'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.macsec_properties = attributes[:'macsecProperties'] if attributes[:'macsecProperties'] raise 'You cannot provide both :macsecProperties and :macsec_properties' if attributes.key?(:'macsecProperties') && attributes.key?(:'macsec_properties') self.macsec_properties = attributes[:'macsec_properties'] if attributes[:'macsec_properties'] end |
Instance Attribute Details
#compartment_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the cross-connect group.
39 40 41 |
# File 'lib/oci/core/models/cross_connect.rb', line 39 def compartment_id @compartment_id end |
#cross_connect_group_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the cross-connect group this cross-connect belongs to (if any).
44 45 46 |
# File 'lib/oci/core/models/cross_connect.rb', line 44 def cross_connect_group_id @cross_connect_group_id end |
#customer_reference_name ⇒ String
A reference name or identifier for the physical fiber connection that this cross-connect uses.
96 97 98 |
# File 'lib/oci/core/models/cross_connect.rb', line 96 def customer_reference_name @customer_reference_name end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
52 53 54 |
# File 'lib/oci/core/models/cross_connect.rb', line 52 def end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
58 59 60 |
# File 'lib/oci/core/models/cross_connect.rb', line 58 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
66 67 68 |
# File 'lib/oci/core/models/cross_connect.rb', line 66 def end |
#id ⇒ String
The cross-connect’s Oracle ID (OCID).
70 71 72 |
# File 'lib/oci/core/models/cross_connect.rb', line 70 def id @id end |
#lifecycle_state ⇒ String
The cross-connect’s current state.
74 75 76 |
# File 'lib/oci/core/models/cross_connect.rb', line 74 def lifecycle_state @lifecycle_state end |
#location_name ⇒ String
The name of the FastConnect location where this cross-connect is installed.
79 80 81 |
# File 'lib/oci/core/models/cross_connect.rb', line 79 def location_name @location_name end |
#macsec_properties ⇒ OCI::Core::Models::MacsecProperties
106 107 108 |
# File 'lib/oci/core/models/cross_connect.rb', line 106 def macsec_properties @macsec_properties end |
#port_name ⇒ String
A string identifying the meet-me room port for this cross-connect.
83 84 85 |
# File 'lib/oci/core/models/cross_connect.rb', line 83 def port_name @port_name end |
#port_speed_shape_name ⇒ String
The port speed for this cross-connect.
Example: ‘10 Gbps`
90 91 92 |
# File 'lib/oci/core/models/cross_connect.rb', line 90 def port_speed_shape_name @port_speed_shape_name end |
#time_created ⇒ DateTime
The date and time the cross-connect was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Example: 2016-08-25T21:10:29.600Z
103 104 105 |
# File 'lib/oci/core/models/cross_connect.rb', line 103 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/oci/core/models/cross_connect.rb', line 109 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'cross_connect_group_id': :'crossConnectGroupId', 'defined_tags': :'definedTags', 'display_name': :'displayName', 'freeform_tags': :'freeformTags', 'id': :'id', 'lifecycle_state': :'lifecycleState', 'location_name': :'locationName', 'port_name': :'portName', 'port_speed_shape_name': :'portSpeedShapeName', 'customer_reference_name': :'customerReferenceName', 'time_created': :'timeCreated', 'macsec_properties': :'macsecProperties' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/oci/core/models/cross_connect.rb', line 130 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'cross_connect_group_id': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'freeform_tags': :'Hash<String, String>', 'id': :'String', 'lifecycle_state': :'String', 'location_name': :'String', 'port_name': :'String', 'port_speed_shape_name': :'String', 'customer_reference_name': :'String', 'time_created': :'DateTime', 'macsec_properties': :'OCI::Core::Models::MacsecProperties' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 |
# File 'lib/oci/core/models/cross_connect.rb', line 270 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && cross_connect_group_id == other.cross_connect_group_id && == other. && display_name == other.display_name && == other. && id == other.id && lifecycle_state == other.lifecycle_state && location_name == other.location_name && port_name == other.port_name && port_speed_shape_name == other.port_speed_shape_name && customer_reference_name == other.customer_reference_name && time_created == other.time_created && macsec_properties == other.macsec_properties end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'lib/oci/core/models/cross_connect.rb', line 312 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
292 293 294 |
# File 'lib/oci/core/models/cross_connect.rb', line 292 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
301 302 303 |
# File 'lib/oci/core/models/cross_connect.rb', line 301 def hash [compartment_id, cross_connect_group_id, , display_name, , id, lifecycle_state, location_name, port_name, port_speed_shape_name, customer_reference_name, time_created, macsec_properties].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
345 346 347 348 349 350 351 352 353 354 |
# File 'lib/oci/core/models/cross_connect.rb', line 345 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
339 340 341 |
# File 'lib/oci/core/models/cross_connect.rb', line 339 def to_s to_hash.to_s end |