Class: OCI::Core::Models::CrossConnectGroup
- Inherits:
-
Object
- Object
- OCI::Core::Models::CrossConnectGroup
- Defined in:
- lib/oci/core/models/cross_connect_group.rb
Overview
For use with Oracle Cloud Infrastructure FastConnect. A cross-connect group is a link aggregation group (LAG), which can contain one or more CrossConnect. Customers who are colocated with Oracle in a FastConnect location create and use cross-connect groups. For more information, see [FastConnect Overview](docs.cloud.oracle.com/iaas/Content/Network/Concepts/fastconnect.htm).
*Note:* If you're a provider who is setting up a physical connection to Oracle so customers can use FastConnect over the connection, be aware that your connection is modeled the same way as a colocated customer's (with `CrossConnect` and `CrossConnectGroup` objects, and so on).
To use any of the API operations, you must be authorized in an IAM policy. If you're not authorized, talk to an administrator. If you're an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/iaas/Content/Identity/Concepts/policygetstarted.htm).
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze, LIFECYCLE_STATE_PROVISIONED = 'PROVISIONED'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze, LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the cross-connect group.
-
#customer_reference_name ⇒ String
A reference name or identifier for the physical fiber connection that this cross-connect group uses.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
A user-friendly name.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
The cross-connect group's Oracle ID (OCID).
-
#lifecycle_state ⇒ String
The cross-connect group's current state.
- #macsec_properties ⇒ OCI::Core::Models::MacsecProperties
-
#oci_logical_device_name ⇒ String
The FastConnect device that terminates the logical connection.
-
#oci_physical_device_name ⇒ String
The FastConnect device that terminates the physical connection.
-
#time_created ⇒ DateTime
The date and time the cross-connect group was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CrossConnectGroup
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CrossConnectGroup
Initializes the object
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/oci/core/models/cross_connect_group.rb', line 149 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.id = attributes[:'id'] if attributes[:'id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.customer_reference_name = attributes[:'customerReferenceName'] if attributes[:'customerReferenceName'] raise 'You cannot provide both :customerReferenceName and :customer_reference_name' if attributes.key?(:'customerReferenceName') && attributes.key?(:'customer_reference_name') self.customer_reference_name = attributes[:'customer_reference_name'] if attributes[:'customer_reference_name'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.macsec_properties = attributes[:'macsecProperties'] if attributes[:'macsecProperties'] raise 'You cannot provide both :macsecProperties and :macsec_properties' if attributes.key?(:'macsecProperties') && attributes.key?(:'macsec_properties') self.macsec_properties = attributes[:'macsec_properties'] if attributes[:'macsec_properties'] self.oci_physical_device_name = attributes[:'ociPhysicalDeviceName'] if attributes[:'ociPhysicalDeviceName'] raise 'You cannot provide both :ociPhysicalDeviceName and :oci_physical_device_name' if attributes.key?(:'ociPhysicalDeviceName') && attributes.key?(:'oci_physical_device_name') self.oci_physical_device_name = attributes[:'oci_physical_device_name'] if attributes[:'oci_physical_device_name'] self.oci_logical_device_name = attributes[:'ociLogicalDeviceName'] if attributes[:'ociLogicalDeviceName'] raise 'You cannot provide both :ociLogicalDeviceName and :oci_logical_device_name' if attributes.key?(:'ociLogicalDeviceName') && attributes.key?(:'oci_logical_device_name') self.oci_logical_device_name = attributes[:'oci_logical_device_name'] if attributes[:'oci_logical_device_name'] end |
Instance Attribute Details
#compartment_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the cross-connect group.
35 36 37 |
# File 'lib/oci/core/models/cross_connect_group.rb', line 35 def compartment_id @compartment_id end |
#customer_reference_name ⇒ String
A reference name or identifier for the physical fiber connection that this cross-connect group uses.
71 72 73 |
# File 'lib/oci/core/models/cross_connect_group.rb', line 71 def customer_reference_name @customer_reference_name end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: `{"CostCenter": "42"}`
43 44 45 |
# File 'lib/oci/core/models/cross_connect_group.rb', line 43 def @defined_tags end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
49 50 51 |
# File 'lib/oci/core/models/cross_connect_group.rb', line 49 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: `"Finance"`
57 58 59 |
# File 'lib/oci/core/models/cross_connect_group.rb', line 57 def @freeform_tags end |
#id ⇒ String
The cross-connect group's Oracle ID (OCID).
61 62 63 |
# File 'lib/oci/core/models/cross_connect_group.rb', line 61 def id @id end |
#lifecycle_state ⇒ String
The cross-connect group's current state.
65 66 67 |
# File 'lib/oci/core/models/cross_connect_group.rb', line 65 def lifecycle_state @lifecycle_state end |
#macsec_properties ⇒ OCI::Core::Models::MacsecProperties
81 82 83 |
# File 'lib/oci/core/models/cross_connect_group.rb', line 81 def macsec_properties @macsec_properties end |
#oci_logical_device_name ⇒ String
The FastConnect device that terminates the logical connection. This device might be different than the device that terminates the physical connection.
92 93 94 |
# File 'lib/oci/core/models/cross_connect_group.rb', line 92 def oci_logical_device_name @oci_logical_device_name end |
#oci_physical_device_name ⇒ String
The FastConnect device that terminates the physical connection.
86 87 88 |
# File 'lib/oci/core/models/cross_connect_group.rb', line 86 def oci_physical_device_name @oci_physical_device_name end |
#time_created ⇒ DateTime
The date and time the cross-connect group was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Example: `2016-08-25T21:10:29.600Z`
78 79 80 |
# File 'lib/oci/core/models/cross_connect_group.rb', line 78 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/oci/core/models/cross_connect_group.rb', line 95 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'defined_tags': :'definedTags', 'display_name': :'displayName', 'freeform_tags': :'freeformTags', 'id': :'id', 'lifecycle_state': :'lifecycleState', 'customer_reference_name': :'customerReferenceName', 'time_created': :'timeCreated', 'macsec_properties': :'macsecProperties', 'oci_physical_device_name': :'ociPhysicalDeviceName', 'oci_logical_device_name': :'ociLogicalDeviceName' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/oci/core/models/cross_connect_group.rb', line 114 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'freeform_tags': :'Hash<String, String>', 'id': :'String', 'lifecycle_state': :'String', 'customer_reference_name': :'String', 'time_created': :'DateTime', 'macsec_properties': :'OCI::Core::Models::MacsecProperties', 'oci_physical_device_name': :'String', 'oci_logical_device_name': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/oci/core/models/cross_connect_group.rb', line 238 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && == other. && display_name == other.display_name && == other. && id == other.id && lifecycle_state == other.lifecycle_state && customer_reference_name == other.customer_reference_name && time_created == other.time_created && macsec_properties == other.macsec_properties && oci_physical_device_name == other.oci_physical_device_name && oci_logical_device_name == other.oci_logical_device_name end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/oci/core/models/cross_connect_group.rb', line 278 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
258 259 260 |
# File 'lib/oci/core/models/cross_connect_group.rb', line 258 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
267 268 269 |
# File 'lib/oci/core/models/cross_connect_group.rb', line 267 def hash [compartment_id, , display_name, , id, lifecycle_state, customer_reference_name, time_created, macsec_properties, oci_physical_device_name, oci_logical_device_name].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
311 312 313 314 315 316 317 318 319 320 |
# File 'lib/oci/core/models/cross_connect_group.rb', line 311 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
305 306 307 |
# File 'lib/oci/core/models/cross_connect_group.rb', line 305 def to_s to_hash.to_s end |