Class: OCI::Core::Models::DedicatedVmHost

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/core/models/dedicated_vm_host.rb

Overview

A dedicated virtual machine host lets you host multiple VM instances on a dedicated server that is not shared with other tenancies.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DedicatedVmHost

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :availability_domain (String)

    The value to assign to the #availability_domain property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :dedicated_vm_host_shape (String)

    The value to assign to the #dedicated_vm_host_shape property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property

  • :display_name (String)

    The value to assign to the #display_name property

  • :fault_domain (String)

    The value to assign to the #fault_domain property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :id (String)

    The value to assign to the #id property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :total_ocpus (Float)

    The value to assign to the #total_ocpus property

  • :remaining_ocpus (Float)

    The value to assign to the #remaining_ocpus property

  • :total_memory_in_gbs (Float)

    The value to assign to the #total_memory_in_gbs property

  • :remaining_memory_in_gbs (Float)

    The value to assign to the #remaining_memory_in_gbs property



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/oci/core/models/dedicated_vm_host.rb', line 175

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain']

  raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain')

  self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.dedicated_vm_host_shape = attributes[:'dedicatedVmHostShape'] if attributes[:'dedicatedVmHostShape']

  raise 'You cannot provide both :dedicatedVmHostShape and :dedicated_vm_host_shape' if attributes.key?(:'dedicatedVmHostShape') && attributes.key?(:'dedicated_vm_host_shape')

  self.dedicated_vm_host_shape = attributes[:'dedicated_vm_host_shape'] if attributes[:'dedicated_vm_host_shape']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.fault_domain = attributes[:'faultDomain'] if attributes[:'faultDomain']

  raise 'You cannot provide both :faultDomain and :fault_domain' if attributes.key?(:'faultDomain') && attributes.key?(:'fault_domain')

  self.fault_domain = attributes[:'fault_domain'] if attributes[:'fault_domain']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.id = attributes[:'id'] if attributes[:'id']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.total_ocpus = attributes[:'totalOcpus'] if attributes[:'totalOcpus']

  raise 'You cannot provide both :totalOcpus and :total_ocpus' if attributes.key?(:'totalOcpus') && attributes.key?(:'total_ocpus')

  self.total_ocpus = attributes[:'total_ocpus'] if attributes[:'total_ocpus']

  self.remaining_ocpus = attributes[:'remainingOcpus'] if attributes[:'remainingOcpus']

  raise 'You cannot provide both :remainingOcpus and :remaining_ocpus' if attributes.key?(:'remainingOcpus') && attributes.key?(:'remaining_ocpus')

  self.remaining_ocpus = attributes[:'remaining_ocpus'] if attributes[:'remaining_ocpus']

  self.total_memory_in_gbs = attributes[:'totalMemoryInGBs'] if attributes[:'totalMemoryInGBs']

  raise 'You cannot provide both :totalMemoryInGBs and :total_memory_in_gbs' if attributes.key?(:'totalMemoryInGBs') && attributes.key?(:'total_memory_in_gbs')

  self.total_memory_in_gbs = attributes[:'total_memory_in_gbs'] if attributes[:'total_memory_in_gbs']

  self.remaining_memory_in_gbs = attributes[:'remainingMemoryInGBs'] if attributes[:'remainingMemoryInGBs']

  raise 'You cannot provide both :remainingMemoryInGBs and :remaining_memory_in_gbs' if attributes.key?(:'remainingMemoryInGBs') && attributes.key?(:'remaining_memory_in_gbs')

  self.remaining_memory_in_gbs = attributes[:'remaining_memory_in_gbs'] if attributes[:'remaining_memory_in_gbs']
end

Instance Attribute Details

#availability_domainString

[Required] The availability domain the dedicated virtual machine host is running in.

Example: Uocm:PHX-AD-1

Returns:

  • (String)


28
29
30
# File 'lib/oci/core/models/dedicated_vm_host.rb', line 28

def availability_domain
  @availability_domain
end

#compartment_idString

[Required] The OCID of the compartment that contains the dedicated virtual machine host.

Returns:

  • (String)


32
33
34
# File 'lib/oci/core/models/dedicated_vm_host.rb', line 32

def compartment_id
  @compartment_id
end

#dedicated_vm_host_shapeString

[Required] The dedicated virtual machine host shape. The shape determines the number of CPUs and other resources available for VMs.

Returns:

  • (String)


38
39
40
# File 'lib/oci/core/models/dedicated_vm_host.rb', line 38

def dedicated_vm_host_shape
  @dedicated_vm_host_shape
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).

Example: ‘{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


46
47
48
# File 'lib/oci/core/models/dedicated_vm_host.rb', line 46

def defined_tags
  @defined_tags
end

#display_nameString

[Required] A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.

Returns:

  • (String)


52
53
54
# File 'lib/oci/core/models/dedicated_vm_host.rb', line 52

def display_name
  @display_name
end

#fault_domainString

The fault domain for the dedicated virtual machine host’s assigned instances. For more information, see [Fault Domains](docs.cloud.oracle.com/iaas/Content/General/Concepts/regions.htm#fault).

If you do not specify the fault domain, the system selects one for you. To change the fault domain for a dedicated virtual machine host, delete it, and then create a new dedicated virtual machine host in the preferred fault domain.

To get a list of fault domains, use the ListFaultDomains operation in the [Identity and Access Management Service API](docs.cloud.oracle.com/iaas/api/#/en/identity/20160918/).

Example: FAULT-DOMAIN-1

Returns:

  • (String)


65
66
67
# File 'lib/oci/core/models/dedicated_vm_host.rb', line 65

def fault_domain
  @fault_domain
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).

Example: ‘"Finance"`

Returns:

  • (Hash<String, String>)


73
74
75
# File 'lib/oci/core/models/dedicated_vm_host.rb', line 73

def freeform_tags
  @freeform_tags
end

#idString

[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the dedicated VM host.

Returns:

  • (String)


77
78
79
# File 'lib/oci/core/models/dedicated_vm_host.rb', line 77

def id
  @id
end

#lifecycle_stateString

[Required] The current state of the dedicated VM host.

Returns:

  • (String)


82
83
84
# File 'lib/oci/core/models/dedicated_vm_host.rb', line 82

def lifecycle_state
  @lifecycle_state
end

#remaining_memory_in_gbsFloat

The remaining memory of the dedicated VM host, in GBs.

Returns:

  • (Float)


109
110
111
# File 'lib/oci/core/models/dedicated_vm_host.rb', line 109

def remaining_memory_in_gbs
  @remaining_memory_in_gbs
end

#remaining_ocpusFloat

[Required] The available OCPUs of the dedicated VM host.

Returns:

  • (Float)


99
100
101
# File 'lib/oci/core/models/dedicated_vm_host.rb', line 99

def remaining_ocpus
  @remaining_ocpus
end

#time_createdDateTime

[Required] The date and time the dedicated VM host was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).

Example: 2016-08-25T21:10:29.600Z

Returns:

  • (DateTime)


89
90
91
# File 'lib/oci/core/models/dedicated_vm_host.rb', line 89

def time_created
  @time_created
end

#total_memory_in_gbsFloat

The total memory of the dedicated VM host, in GBs.

Returns:

  • (Float)


104
105
106
# File 'lib/oci/core/models/dedicated_vm_host.rb', line 104

def total_memory_in_gbs
  @total_memory_in_gbs
end

#total_ocpusFloat

[Required] The total OCPUs of the dedicated VM host.

Returns:

  • (Float)


94
95
96
# File 'lib/oci/core/models/dedicated_vm_host.rb', line 94

def total_ocpus
  @total_ocpus
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/oci/core/models/dedicated_vm_host.rb', line 112

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'availability_domain': :'availabilityDomain',
    'compartment_id': :'compartmentId',
    'dedicated_vm_host_shape': :'dedicatedVmHostShape',
    'defined_tags': :'definedTags',
    'display_name': :'displayName',
    'fault_domain': :'faultDomain',
    'freeform_tags': :'freeformTags',
    'id': :'id',
    'lifecycle_state': :'lifecycleState',
    'time_created': :'timeCreated',
    'total_ocpus': :'totalOcpus',
    'remaining_ocpus': :'remainingOcpus',
    'total_memory_in_gbs': :'totalMemoryInGBs',
    'remaining_memory_in_gbs': :'remainingMemoryInGBs'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/oci/core/models/dedicated_vm_host.rb', line 134

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'availability_domain': :'String',
    'compartment_id': :'String',
    'dedicated_vm_host_shape': :'String',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'display_name': :'String',
    'fault_domain': :'String',
    'freeform_tags': :'Hash<String, String>',
    'id': :'String',
    'lifecycle_state': :'String',
    'time_created': :'DateTime',
    'total_ocpus': :'Float',
    'remaining_ocpus': :'Float',
    'total_memory_in_gbs': :'Float',
    'remaining_memory_in_gbs': :'Float'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
# File 'lib/oci/core/models/dedicated_vm_host.rb', line 282

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    availability_domain == other.availability_domain &&
    compartment_id == other.compartment_id &&
    dedicated_vm_host_shape == other.dedicated_vm_host_shape &&
    defined_tags == other.defined_tags &&
    display_name == other.display_name &&
    fault_domain == other.fault_domain &&
    freeform_tags == other.freeform_tags &&
    id == other.id &&
    lifecycle_state == other.lifecycle_state &&
    time_created == other.time_created &&
    total_ocpus == other.total_ocpus &&
    remaining_ocpus == other.remaining_ocpus &&
    total_memory_in_gbs == other.total_memory_in_gbs &&
    remaining_memory_in_gbs == other.remaining_memory_in_gbs
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
# File 'lib/oci/core/models/dedicated_vm_host.rb', line 325

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


305
306
307
# File 'lib/oci/core/models/dedicated_vm_host.rb', line 305

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



314
315
316
# File 'lib/oci/core/models/dedicated_vm_host.rb', line 314

def hash
  [availability_domain, compartment_id, dedicated_vm_host_shape, defined_tags, display_name, fault_domain, freeform_tags, id, lifecycle_state, time_created, total_ocpus, remaining_ocpus, total_memory_in_gbs, remaining_memory_in_gbs].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



358
359
360
361
362
363
364
365
366
367
# File 'lib/oci/core/models/dedicated_vm_host.rb', line 358

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



352
353
354
# File 'lib/oci/core/models/dedicated_vm_host.rb', line 352

def to_s
  to_hash.to_s
end