Class: OCI::Core::Models::DefaultPhaseTwoParameters
- Inherits:
-
Object
- Object
- OCI::Core::Models::DefaultPhaseTwoParameters
- Defined in:
- lib/oci/core/models/default_phase_two_parameters.rb
Overview
Phase Two Parameters
Instance Attribute Summary collapse
-
#default_authentication_algorithms ⇒ Array<String>
Default Phase Two Authentication Algorithms.
-
#default_encryption_algorithms ⇒ Array<String>
Default Phase Two Encryption Algorithms.
-
#default_pfs_dh_group ⇒ String
Default PFS DH Group.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DefaultPhaseTwoParameters
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DefaultPhaseTwoParameters
Initializes the object
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/oci/core/models/default_phase_two_parameters.rb', line 53 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.default_encryption_algorithms = attributes[:'defaultEncryptionAlgorithms'] if attributes[:'defaultEncryptionAlgorithms'] raise 'You cannot provide both :defaultEncryptionAlgorithms and :default_encryption_algorithms' if attributes.key?(:'defaultEncryptionAlgorithms') && attributes.key?(:'default_encryption_algorithms') self.default_encryption_algorithms = attributes[:'default_encryption_algorithms'] if attributes[:'default_encryption_algorithms'] self.default_authentication_algorithms = attributes[:'defaultAuthenticationAlgorithms'] if attributes[:'defaultAuthenticationAlgorithms'] raise 'You cannot provide both :defaultAuthenticationAlgorithms and :default_authentication_algorithms' if attributes.key?(:'defaultAuthenticationAlgorithms') && attributes.key?(:'default_authentication_algorithms') self.default_authentication_algorithms = attributes[:'default_authentication_algorithms'] if attributes[:'default_authentication_algorithms'] self.default_pfs_dh_group = attributes[:'defaultPfsDhGroup'] if attributes[:'defaultPfsDhGroup'] raise 'You cannot provide both :defaultPfsDhGroup and :default_pfs_dh_group' if attributes.key?(:'defaultPfsDhGroup') && attributes.key?(:'default_pfs_dh_group') self.default_pfs_dh_group = attributes[:'default_pfs_dh_group'] if attributes[:'default_pfs_dh_group'] end |
Instance Attribute Details
#default_authentication_algorithms ⇒ Array<String>
Default Phase Two Authentication Algorithms
16 17 18 |
# File 'lib/oci/core/models/default_phase_two_parameters.rb', line 16 def default_authentication_algorithms @default_authentication_algorithms end |
#default_encryption_algorithms ⇒ Array<String>
Default Phase Two Encryption Algorithms
12 13 14 |
# File 'lib/oci/core/models/default_phase_two_parameters.rb', line 12 def default_encryption_algorithms @default_encryption_algorithms end |
#default_pfs_dh_group ⇒ String
Default PFS DH Group
20 21 22 |
# File 'lib/oci/core/models/default_phase_two_parameters.rb', line 20 def default_pfs_dh_group @default_pfs_dh_group end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
23 24 25 26 27 28 29 30 31 |
# File 'lib/oci/core/models/default_phase_two_parameters.rb', line 23 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'default_encryption_algorithms': :'defaultEncryptionAlgorithms', 'default_authentication_algorithms': :'defaultAuthenticationAlgorithms', 'default_pfs_dh_group': :'defaultPfsDhGroup' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
34 35 36 37 38 39 40 41 42 |
# File 'lib/oci/core/models/default_phase_two_parameters.rb', line 34 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'default_encryption_algorithms': :'Array<String>', 'default_authentication_algorithms': :'Array<String>', 'default_pfs_dh_group': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
85 86 87 88 89 90 91 92 |
# File 'lib/oci/core/models/default_phase_two_parameters.rb', line 85 def ==(other) return true if equal?(other) self.class == other.class && default_encryption_algorithms == other.default_encryption_algorithms && default_authentication_algorithms == other.default_authentication_algorithms && default_pfs_dh_group == other.default_pfs_dh_group end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/oci/core/models/default_phase_two_parameters.rb', line 117 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
97 98 99 |
# File 'lib/oci/core/models/default_phase_two_parameters.rb', line 97 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
106 107 108 |
# File 'lib/oci/core/models/default_phase_two_parameters.rb', line 106 def hash [default_encryption_algorithms, default_authentication_algorithms, default_pfs_dh_group].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
150 151 152 153 154 155 156 157 158 159 |
# File 'lib/oci/core/models/default_phase_two_parameters.rb', line 150 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
144 145 146 |
# File 'lib/oci/core/models/default_phase_two_parameters.rb', line 144 def to_s to_hash.to_s end |