Class: OCI::Core::Models::DhcpOptions
- Inherits:
-
Object
- Object
- OCI::Core::Models::DhcpOptions
- Defined in:
- lib/oci/core/models/dhcp_options.rb
Overview
A set of DHCP options. Used by the VCN to automatically provide configuration information to the instances when they boot up. There are two options you can set:
-
DhcpDnsOption: Lets you specify how DNS (hostname resolution) is
handled in the subnets in your VCN.
-
DhcpSearchDomainOption: Lets you specify
a search domain name to use for DNS queries.
For more information, see [DNS in Your Virtual Cloud Network](docs.cloud.oracle.com/iaas/Content/Network/Concepts/dns.htm) and [DHCP Options](docs.cloud.oracle.com/iaas/Content/Network/Tasks/managingDHCP.htm).
To use any of the API operations, you must be authorized in an IAM policy. If you’re not authorized, talk to an administrator. If you’re an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/iaas/Content/Identity/Concepts/policygetstarted.htm).
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze, LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze, LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze, LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- DOMAIN_NAME_TYPE_ENUM =
[ DOMAIN_NAME_TYPE_SUBNET_DOMAIN = 'SUBNET_DOMAIN'.freeze, DOMAIN_NAME_TYPE_VCN_DOMAIN = 'VCN_DOMAIN'.freeze, DOMAIN_NAME_TYPE_CUSTOM_DOMAIN = 'CUSTOM_DOMAIN'.freeze, DOMAIN_NAME_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the set of DHCP options.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
A user-friendly name.
-
#domain_name_type ⇒ String
The search domain name type of DHCP options.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] Oracle ID ([OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)) for the set of DHCP options.
-
#lifecycle_state ⇒ String
[Required] The current state of the set of DHCP options.
-
#options ⇒ Array<OCI::Core::Models::DhcpOption>
[Required] The collection of individual DHCP options.
-
#time_created ⇒ DateTime
[Required] Date and time the set of DHCP options was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#vcn_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the VCN the set of DHCP options belongs to.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DhcpOptions
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DhcpOptions
Initializes the object
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/oci/core/models/dhcp_options.rb', line 146 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.id = attributes[:'id'] if attributes[:'id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self. = attributes[:'options'] if attributes[:'options'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.vcn_id = attributes[:'vcnId'] if attributes[:'vcnId'] raise 'You cannot provide both :vcnId and :vcn_id' if attributes.key?(:'vcnId') && attributes.key?(:'vcn_id') self.vcn_id = attributes[:'vcn_id'] if attributes[:'vcn_id'] self.domain_name_type = attributes[:'domainNameType'] if attributes[:'domainNameType'] raise 'You cannot provide both :domainNameType and :domain_name_type' if attributes.key?(:'domainNameType') && attributes.key?(:'domain_name_type') self.domain_name_type = attributes[:'domain_name_type'] if attributes[:'domain_name_type'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the set of DHCP options.
43 44 45 |
# File 'lib/oci/core/models/dhcp_options.rb', line 43 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
51 52 53 |
# File 'lib/oci/core/models/dhcp_options.rb', line 51 def end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
57 58 59 |
# File 'lib/oci/core/models/dhcp_options.rb', line 57 def display_name @display_name end |
#domain_name_type ⇒ String
The search domain name type of DHCP options
92 93 94 |
# File 'lib/oci/core/models/dhcp_options.rb', line 92 def domain_name_type @domain_name_type end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
65 66 67 |
# File 'lib/oci/core/models/dhcp_options.rb', line 65 def end |
#id ⇒ String
[Required] Oracle ID ([OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)) for the set of DHCP options.
69 70 71 |
# File 'lib/oci/core/models/dhcp_options.rb', line 69 def id @id end |
#lifecycle_state ⇒ String
[Required] The current state of the set of DHCP options.
73 74 75 |
# File 'lib/oci/core/models/dhcp_options.rb', line 73 def lifecycle_state @lifecycle_state end |
#options ⇒ Array<OCI::Core::Models::DhcpOption>
[Required] The collection of individual DHCP options.
77 78 79 |
# File 'lib/oci/core/models/dhcp_options.rb', line 77 def end |
#time_created ⇒ DateTime
[Required] Date and time the set of DHCP options was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Example: 2016-08-25T21:10:29.600Z
84 85 86 |
# File 'lib/oci/core/models/dhcp_options.rb', line 84 def time_created @time_created end |
#vcn_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the VCN the set of DHCP options belongs to.
88 89 90 |
# File 'lib/oci/core/models/dhcp_options.rb', line 88 def vcn_id @vcn_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/oci/core/models/dhcp_options.rb', line 95 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'defined_tags': :'definedTags', 'display_name': :'displayName', 'freeform_tags': :'freeformTags', 'id': :'id', 'lifecycle_state': :'lifecycleState', 'options': :'options', 'time_created': :'timeCreated', 'vcn_id': :'vcnId', 'domain_name_type': :'domainNameType' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/oci/core/models/dhcp_options.rb', line 113 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'freeform_tags': :'Hash<String, String>', 'id': :'String', 'lifecycle_state': :'String', 'options': :'Array<OCI::Core::Models::DhcpOption>', 'time_created': :'DateTime', 'vcn_id': :'String', 'domain_name_type': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/oci/core/models/dhcp_options.rb', line 238 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && == other. && display_name == other.display_name && == other. && id == other.id && lifecycle_state == other.lifecycle_state && == other. && time_created == other.time_created && vcn_id == other.vcn_id && domain_name_type == other.domain_name_type end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/oci/core/models/dhcp_options.rb', line 277 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
257 258 259 |
# File 'lib/oci/core/models/dhcp_options.rb', line 257 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
266 267 268 |
# File 'lib/oci/core/models/dhcp_options.rb', line 266 def hash [compartment_id, , display_name, , id, lifecycle_state, , time_created, vcn_id, domain_name_type].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
310 311 312 313 314 315 316 317 318 319 |
# File 'lib/oci/core/models/dhcp_options.rb', line 310 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
304 305 306 |
# File 'lib/oci/core/models/dhcp_options.rb', line 304 def to_s to_hash.to_s end |