Class: OCI::Core::Models::DpdConfig
- Inherits:
-
Object
- Object
- OCI::Core::Models::DpdConfig
- Defined in:
- lib/oci/core/models/dpd_config.rb
Overview
DPD Configuration Details
Constant Summary collapse
- DPD_MODE_ENUM =
[ DPD_MODE_INITIATE_AND_RESPOND = 'INITIATE_AND_RESPOND'.freeze, DPD_MODE_RESPOND_ONLY = 'RESPOND_ONLY'.freeze ].freeze
Instance Attribute Summary collapse
-
#dpd_mode ⇒ String
dpd mode.
-
#dpd_timeout_in_sec ⇒ Integer
DPD Timeout in seconds.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DpdConfig
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DpdConfig
Initializes the object
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/oci/core/models/dpd_config.rb', line 51 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.dpd_mode = attributes[:'dpdMode'] if attributes[:'dpdMode'] raise 'You cannot provide both :dpdMode and :dpd_mode' if attributes.key?(:'dpdMode') && attributes.key?(:'dpd_mode') self.dpd_mode = attributes[:'dpd_mode'] if attributes[:'dpd_mode'] self.dpd_timeout_in_sec = attributes[:'dpdTimeoutInSec'] if attributes[:'dpdTimeoutInSec'] raise 'You cannot provide both :dpdTimeoutInSec and :dpd_timeout_in_sec' if attributes.key?(:'dpdTimeoutInSec') && attributes.key?(:'dpd_timeout_in_sec') self.dpd_timeout_in_sec = attributes[:'dpd_timeout_in_sec'] if attributes[:'dpd_timeout_in_sec'] end |
Instance Attribute Details
#dpd_mode ⇒ String
dpd mode
17 18 19 |
# File 'lib/oci/core/models/dpd_config.rb', line 17 def dpd_mode @dpd_mode end |
#dpd_timeout_in_sec ⇒ Integer
DPD Timeout in seconds.
21 22 23 |
# File 'lib/oci/core/models/dpd_config.rb', line 21 def dpd_timeout_in_sec @dpd_timeout_in_sec end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
24 25 26 27 28 29 30 31 |
# File 'lib/oci/core/models/dpd_config.rb', line 24 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'dpd_mode': :'dpdMode', 'dpd_timeout_in_sec': :'dpdTimeoutInSec' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
34 35 36 37 38 39 40 41 |
# File 'lib/oci/core/models/dpd_config.rb', line 34 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'dpd_mode': :'String', 'dpd_timeout_in_sec': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
85 86 87 88 89 90 91 |
# File 'lib/oci/core/models/dpd_config.rb', line 85 def ==(other) return true if equal?(other) self.class == other.class && dpd_mode == other.dpd_mode && dpd_timeout_in_sec == other.dpd_timeout_in_sec end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/oci/core/models/dpd_config.rb', line 116 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
96 97 98 |
# File 'lib/oci/core/models/dpd_config.rb', line 96 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
105 106 107 |
# File 'lib/oci/core/models/dpd_config.rb', line 105 def hash [dpd_mode, dpd_timeout_in_sec].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
149 150 151 152 153 154 155 156 157 158 |
# File 'lib/oci/core/models/dpd_config.rb', line 149 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
143 144 145 |
# File 'lib/oci/core/models/dpd_config.rb', line 143 def to_s to_hash.to_s end |