Class: OCI::Core::Models::DrgAttachment
- Inherits:
-
Object
- Object
- OCI::Core::Models::DrgAttachment
- Defined in:
- lib/oci/core/models/drg_attachment.rb
Overview
A DRG attachment serves as a link between a DRG and a network resource. A DRG can be attached to a VCN, IPSec tunnel, remote peering connection, or virtual circuit.
For more information, see [Overview of the Networking Service](docs.cloud.oracle.com/iaas/Content/Network/Concepts/overview.htm).
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_ATTACHING = 'ATTACHING'.freeze, LIFECYCLE_STATE_ATTACHED = 'ATTACHED'.freeze, LIFECYCLE_STATE_DETACHING = 'DETACHING'.freeze, LIFECYCLE_STATE_DETACHED = 'DETACHED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the DRG attachment.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
A user-friendly name.
-
#drg_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the DRG.
-
#drg_route_table_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the DRG route table that is assigned to this attachment.
-
#export_drg_route_distribution_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the export route distribution used to specify how routes in the assigned DRG route table are advertised to the attachment.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
**[Required]** The DRG attachment's Oracle ID ([OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)).
-
#is_cross_tenancy ⇒ BOOLEAN
Indicates whether the DRG attachment and attached network live in a different tenancy than the DRG.
-
#lifecycle_state ⇒ String
**[Required]** The DRG attachment's current state.
- #network_details ⇒ OCI::Core::Models::DrgAttachmentNetworkDetails
-
#route_table_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the route table the DRG attachment is using.
-
#time_created ⇒ DateTime
The date and time the DRG attachment was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#vcn_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the VCN.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DrgAttachment
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DrgAttachment
Initializes the object
174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/oci/core/models/drg_attachment.rb', line 174 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.drg_id = attributes[:'drgId'] if attributes[:'drgId'] raise 'You cannot provide both :drgId and :drg_id' if attributes.key?(:'drgId') && attributes.key?(:'drg_id') self.drg_id = attributes[:'drg_id'] if attributes[:'drg_id'] self.id = attributes[:'id'] if attributes[:'id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.drg_route_table_id = attributes[:'drgRouteTableId'] if attributes[:'drgRouteTableId'] raise 'You cannot provide both :drgRouteTableId and :drg_route_table_id' if attributes.key?(:'drgRouteTableId') && attributes.key?(:'drg_route_table_id') self.drg_route_table_id = attributes[:'drg_route_table_id'] if attributes[:'drg_route_table_id'] self.network_details = attributes[:'networkDetails'] if attributes[:'networkDetails'] raise 'You cannot provide both :networkDetails and :network_details' if attributes.key?(:'networkDetails') && attributes.key?(:'network_details') self.network_details = attributes[:'network_details'] if attributes[:'network_details'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.route_table_id = attributes[:'routeTableId'] if attributes[:'routeTableId'] raise 'You cannot provide both :routeTableId and :route_table_id' if attributes.key?(:'routeTableId') && attributes.key?(:'route_table_id') self.route_table_id = attributes[:'route_table_id'] if attributes[:'route_table_id'] self.vcn_id = attributes[:'vcnId'] if attributes[:'vcnId'] raise 'You cannot provide both :vcnId and :vcn_id' if attributes.key?(:'vcnId') && attributes.key?(:'vcn_id') self.vcn_id = attributes[:'vcn_id'] if attributes[:'vcn_id'] self.export_drg_route_distribution_id = attributes[:'exportDrgRouteDistributionId'] if attributes[:'exportDrgRouteDistributionId'] raise 'You cannot provide both :exportDrgRouteDistributionId and :export_drg_route_distribution_id' if attributes.key?(:'exportDrgRouteDistributionId') && attributes.key?(:'export_drg_route_distribution_id') self.export_drg_route_distribution_id = attributes[:'export_drg_route_distribution_id'] if attributes[:'export_drg_route_distribution_id'] self.is_cross_tenancy = attributes[:'isCrossTenancy'] unless attributes[:'isCrossTenancy'].nil? raise 'You cannot provide both :isCrossTenancy and :is_cross_tenancy' if attributes.key?(:'isCrossTenancy') && attributes.key?(:'is_cross_tenancy') self.is_cross_tenancy = attributes[:'is_cross_tenancy'] unless attributes[:'is_cross_tenancy'].nil? end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the DRG attachment.
25 26 27 |
# File 'lib/oci/core/models/drg_attachment.rb', line 25 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: `{"CostCenter": "42"}`
68 69 70 |
# File 'lib/oci/core/models/drg_attachment.rb', line 68 def @defined_tags end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
31 32 33 |
# File 'lib/oci/core/models/drg_attachment.rb', line 31 def display_name @display_name end |
#drg_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the DRG.
35 36 37 |
# File 'lib/oci/core/models/drg_attachment.rb', line 35 def drg_id @drg_id end |
#drg_route_table_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the DRG route table that is assigned to this attachment.
The DRG route table manages traffic inside the DRG.
57 58 59 |
# File 'lib/oci/core/models/drg_attachment.rb', line 57 def drg_route_table_id @drg_route_table_id end |
#export_drg_route_distribution_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the export route distribution used to specify how routes in the assigned DRG route table are advertised to the attachment. If this value is null, no routes are advertised through this attachment.
101 102 103 |
# File 'lib/oci/core/models/drg_attachment.rb', line 101 def export_drg_route_distribution_id @export_drg_route_distribution_id end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: `"Finance"`
76 77 78 |
# File 'lib/oci/core/models/drg_attachment.rb', line 76 def @freeform_tags end |
#id ⇒ String
**[Required]** The DRG attachment's Oracle ID ([OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)).
39 40 41 |
# File 'lib/oci/core/models/drg_attachment.rb', line 39 def id @id end |
#is_cross_tenancy ⇒ BOOLEAN
Indicates whether the DRG attachment and attached network live in a different tenancy than the DRG.
Example: `false`
108 109 110 |
# File 'lib/oci/core/models/drg_attachment.rb', line 108 def is_cross_tenancy @is_cross_tenancy end |
#lifecycle_state ⇒ String
**[Required]** The DRG attachment's current state.
43 44 45 |
# File 'lib/oci/core/models/drg_attachment.rb', line 43 def lifecycle_state @lifecycle_state end |
#network_details ⇒ OCI::Core::Models::DrgAttachmentNetworkDetails
60 61 62 |
# File 'lib/oci/core/models/drg_attachment.rb', line 60 def network_details @network_details end |
#route_table_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the route table the DRG attachment is using.
For information about why you would associate a route table with a DRG attachment, see:
* [Transit Routing: Access to Multiple VCNs in Same Region](https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/transitrouting.htm)
* [Transit Routing: Private Access to Oracle Services](https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/transitroutingoracleservices.htm)
This field is deprecated. Instead, use the `networkDetails` field to view the [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the attached resource.
88 89 90 |
# File 'lib/oci/core/models/drg_attachment.rb', line 88 def route_table_id @route_table_id end |
#time_created ⇒ DateTime
The date and time the DRG attachment was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Example: `2016-08-25T21:10:29.600Z`
50 51 52 |
# File 'lib/oci/core/models/drg_attachment.rb', line 50 def time_created @time_created end |
#vcn_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the VCN. This field is deprecated. Instead, use the `networkDetails` field to view the [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the attached resource.
94 95 96 |
# File 'lib/oci/core/models/drg_attachment.rb', line 94 def vcn_id @vcn_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/oci/core/models/drg_attachment.rb', line 111 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'drg_id': :'drgId', 'id': :'id', 'lifecycle_state': :'lifecycleState', 'time_created': :'timeCreated', 'drg_route_table_id': :'drgRouteTableId', 'network_details': :'networkDetails', 'defined_tags': :'definedTags', 'freeform_tags': :'freeformTags', 'route_table_id': :'routeTableId', 'vcn_id': :'vcnId', 'export_drg_route_distribution_id': :'exportDrgRouteDistributionId', 'is_cross_tenancy': :'isCrossTenancy' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/oci/core/models/drg_attachment.rb', line 133 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'display_name': :'String', 'drg_id': :'String', 'id': :'String', 'lifecycle_state': :'String', 'time_created': :'DateTime', 'drg_route_table_id': :'String', 'network_details': :'OCI::Core::Models::DrgAttachmentNetworkDetails', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'freeform_tags': :'Hash<String, String>', 'route_table_id': :'String', 'vcn_id': :'String', 'export_drg_route_distribution_id': :'String', 'is_cross_tenancy': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/oci/core/models/drg_attachment.rb', line 281 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && display_name == other.display_name && drg_id == other.drg_id && id == other.id && lifecycle_state == other.lifecycle_state && time_created == other.time_created && drg_route_table_id == other.drg_route_table_id && network_details == other.network_details && == other. && == other. && route_table_id == other.route_table_id && vcn_id == other.vcn_id && export_drg_route_distribution_id == other.export_drg_route_distribution_id && is_cross_tenancy == other.is_cross_tenancy end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 |
# File 'lib/oci/core/models/drg_attachment.rb', line 324 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
304 305 306 |
# File 'lib/oci/core/models/drg_attachment.rb', line 304 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
313 314 315 |
# File 'lib/oci/core/models/drg_attachment.rb', line 313 def hash [compartment_id, display_name, drg_id, id, lifecycle_state, time_created, drg_route_table_id, network_details, , , route_table_id, vcn_id, export_drg_route_distribution_id, is_cross_tenancy].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
357 358 359 360 361 362 363 364 365 366 |
# File 'lib/oci/core/models/drg_attachment.rb', line 357 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
351 352 353 |
# File 'lib/oci/core/models/drg_attachment.rb', line 351 def to_s to_hash.to_s end |