Class: OCI::Core::Models::EncryptionDomainConfig

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/core/models/encryption_domain_config.rb

Overview

Configuration information used by the encryption domain policy.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ EncryptionDomainConfig

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/oci/core/models/encryption_domain_config.rb', line 46

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.oracle_traffic_selector = attributes[:'oracleTrafficSelector'] if attributes[:'oracleTrafficSelector']

  raise 'You cannot provide both :oracleTrafficSelector and :oracle_traffic_selector' if attributes.key?(:'oracleTrafficSelector') && attributes.key?(:'oracle_traffic_selector')

  self.oracle_traffic_selector = attributes[:'oracle_traffic_selector'] if attributes[:'oracle_traffic_selector']

  self.cpe_traffic_selector = attributes[:'cpeTrafficSelector'] if attributes[:'cpeTrafficSelector']

  raise 'You cannot provide both :cpeTrafficSelector and :cpe_traffic_selector' if attributes.key?(:'cpeTrafficSelector') && attributes.key?(:'cpe_traffic_selector')

  self.cpe_traffic_selector = attributes[:'cpe_traffic_selector'] if attributes[:'cpe_traffic_selector']
end

Instance Attribute Details

#cpe_traffic_selectorArray<String>

Lists IPv4 or IPv6-enabled subnets in your on-premises network.

Returns:

  • (Array<String>)


16
17
18
# File 'lib/oci/core/models/encryption_domain_config.rb', line 16

def cpe_traffic_selector
  @cpe_traffic_selector
end

#oracle_traffic_selectorArray<String>

Lists IPv4 or IPv6-enabled subnets in your Oracle tenancy.

Returns:

  • (Array<String>)


12
13
14
# File 'lib/oci/core/models/encryption_domain_config.rb', line 12

def oracle_traffic_selector
  @oracle_traffic_selector
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



19
20
21
22
23
24
25
26
# File 'lib/oci/core/models/encryption_domain_config.rb', line 19

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'oracle_traffic_selector': :'oracleTrafficSelector',
    'cpe_traffic_selector': :'cpeTrafficSelector'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



29
30
31
32
33
34
35
36
# File 'lib/oci/core/models/encryption_domain_config.rb', line 29

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'oracle_traffic_selector': :'Array<String>',
    'cpe_traffic_selector': :'Array<String>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



72
73
74
75
76
77
78
# File 'lib/oci/core/models/encryption_domain_config.rb', line 72

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    oracle_traffic_selector == other.oracle_traffic_selector &&
    cpe_traffic_selector == other.cpe_traffic_selector
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/oci/core/models/encryption_domain_config.rb', line 103

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


83
84
85
# File 'lib/oci/core/models/encryption_domain_config.rb', line 83

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



92
93
94
# File 'lib/oci/core/models/encryption_domain_config.rb', line 92

def hash
  [oracle_traffic_selector, cpe_traffic_selector].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



136
137
138
139
140
141
142
143
144
145
# File 'lib/oci/core/models/encryption_domain_config.rb', line 136

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



130
131
132
# File 'lib/oci/core/models/encryption_domain_config.rb', line 130

def to_s
  to_hash.to_s
end