Class: OCI::Core::Models::ExportImageViaObjectStorageTupleDetails
- Inherits:
-
ExportImageDetails
- Object
- ExportImageDetails
- OCI::Core::Models::ExportImageViaObjectStorageTupleDetails
- Defined in:
- lib/oci/core/models/export_image_via_object_storage_tuple_details.rb
Overview
ExportImageViaObjectStorageTupleDetails model.
Constant Summary
Constants inherited from ExportImageDetails
OCI::Core::Models::ExportImageDetails::EXPORT_FORMAT_ENUM
Instance Attribute Summary collapse
-
#bucket_name ⇒ String
[Required] The Object Storage bucket to export the image to.
-
#namespace_name ⇒ String
[Required] The Object Storage namespace to export the image to.
-
#object_name ⇒ String
[Required] The Object Storage object name for the exported image.
Attributes inherited from ExportImageDetails
#destination_type, #export_format
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ExportImageViaObjectStorageTupleDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from ExportImageDetails
Constructor Details
#initialize(attributes = {}) ⇒ ExportImageViaObjectStorageTupleDetails
Initializes the object
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/oci/core/models/export_image_via_object_storage_tuple_details.rb', line 59 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['destinationType'] = 'objectStorageTuple' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.bucket_name = attributes[:'bucketName'] if attributes[:'bucketName'] raise 'You cannot provide both :bucketName and :bucket_name' if attributes.key?(:'bucketName') && attributes.key?(:'bucket_name') self.bucket_name = attributes[:'bucket_name'] if attributes[:'bucket_name'] self.namespace_name = attributes[:'namespaceName'] if attributes[:'namespaceName'] raise 'You cannot provide both :namespaceName and :namespace_name' if attributes.key?(:'namespaceName') && attributes.key?(:'namespace_name') self.namespace_name = attributes[:'namespace_name'] if attributes[:'namespace_name'] self.object_name = attributes[:'objectName'] if attributes[:'objectName'] raise 'You cannot provide both :objectName and :object_name' if attributes.key?(:'objectName') && attributes.key?(:'object_name') self.object_name = attributes[:'object_name'] if attributes[:'object_name'] end |
Instance Attribute Details
#bucket_name ⇒ String
[Required] The Object Storage bucket to export the image to.
13 14 15 |
# File 'lib/oci/core/models/export_image_via_object_storage_tuple_details.rb', line 13 def bucket_name @bucket_name end |
#namespace_name ⇒ String
[Required] The Object Storage namespace to export the image to.
17 18 19 |
# File 'lib/oci/core/models/export_image_via_object_storage_tuple_details.rb', line 17 def namespace_name @namespace_name end |
#object_name ⇒ String
[Required] The Object Storage object name for the exported image.
21 22 23 |
# File 'lib/oci/core/models/export_image_via_object_storage_tuple_details.rb', line 21 def object_name @object_name end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
24 25 26 27 28 29 30 31 32 33 34 |
# File 'lib/oci/core/models/export_image_via_object_storage_tuple_details.rb', line 24 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'destination_type': :'destinationType', 'export_format': :'exportFormat', 'bucket_name': :'bucketName', 'namespace_name': :'namespaceName', 'object_name': :'objectName' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
37 38 39 40 41 42 43 44 45 46 47 |
# File 'lib/oci/core/models/export_image_via_object_storage_tuple_details.rb', line 37 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'destination_type': :'String', 'export_format': :'String', 'bucket_name': :'String', 'namespace_name': :'String', 'object_name': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
95 96 97 98 99 100 101 102 103 104 |
# File 'lib/oci/core/models/export_image_via_object_storage_tuple_details.rb', line 95 def ==(other) return true if equal?(other) self.class == other.class && destination_type == other.destination_type && export_format == other.export_format && bucket_name == other.bucket_name && namespace_name == other.namespace_name && object_name == other.object_name end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/oci/core/models/export_image_via_object_storage_tuple_details.rb', line 129 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
109 110 111 |
# File 'lib/oci/core/models/export_image_via_object_storage_tuple_details.rb', line 109 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
118 119 120 |
# File 'lib/oci/core/models/export_image_via_object_storage_tuple_details.rb', line 118 def hash [destination_type, export_format, bucket_name, namespace_name, object_name].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
162 163 164 165 166 167 168 169 170 171 |
# File 'lib/oci/core/models/export_image_via_object_storage_tuple_details.rb', line 162 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
156 157 158 |
# File 'lib/oci/core/models/export_image_via_object_storage_tuple_details.rb', line 156 def to_s to_hash.to_s end |