Class: OCI::Core::Models::IPSecConnection

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/core/models/ip_sec_connection.rb

Overview

A connection between a DRG and CPE. This connection consists of multiple IPSec tunnels. Creating this connection is one of the steps required when setting up an IPSec VPN. For more information, see [IPSec VPN](docs.cloud.oracle.com/Content/Network/Tasks/managingIPsec.htm).

To use any of the API operations, you must be authorized in an IAM policy. If you’re not authorized, talk to an administrator. If you’re an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm).

Warning: Oracle recommends that you avoid using any confidential information when you supply string values using the API.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =

rubocop:disable Metrics/LineLength

[
  LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze,
  LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze,
  LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze,
  LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
CPE_LOCAL_IDENTIFIER_TYPE_ENUM =
[
  CPE_LOCAL_IDENTIFIER_TYPE_IP_ADDRESS = 'IP_ADDRESS'.freeze,
  CPE_LOCAL_IDENTIFIER_TYPE_HOSTNAME = 'HOSTNAME'.freeze,
  CPE_LOCAL_IDENTIFIER_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ IPSecConnection

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :cpe_id (String)

    The value to assign to the #cpe_id property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property

  • :display_name (String)

    The value to assign to the #display_name property

  • :drg_id (String)

    The value to assign to the #drg_id property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :id (String)

    The value to assign to the #id property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :cpe_local_identifier (String)

    The value to assign to the #cpe_local_identifier property

  • :cpe_local_identifier_type (String)

    The value to assign to the #cpe_local_identifier_type property

  • :static_routes (Array<String>)

    The value to assign to the #static_routes property

  • :time_created (DateTime)

    The value to assign to the #time_created property



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
# File 'lib/oci/core/models/ip_sec_connection.rb', line 171

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.cpe_id = attributes[:'cpeId'] if attributes[:'cpeId']

  raise 'You cannot provide both :cpeId and :cpe_id' if attributes.key?(:'cpeId') && attributes.key?(:'cpe_id')

  self.cpe_id = attributes[:'cpe_id'] if attributes[:'cpe_id']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.drg_id = attributes[:'drgId'] if attributes[:'drgId']

  raise 'You cannot provide both :drgId and :drg_id' if attributes.key?(:'drgId') && attributes.key?(:'drg_id')

  self.drg_id = attributes[:'drg_id'] if attributes[:'drg_id']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.id = attributes[:'id'] if attributes[:'id']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.cpe_local_identifier = attributes[:'cpeLocalIdentifier'] if attributes[:'cpeLocalIdentifier']

  raise 'You cannot provide both :cpeLocalIdentifier and :cpe_local_identifier' if attributes.key?(:'cpeLocalIdentifier') && attributes.key?(:'cpe_local_identifier')

  self.cpe_local_identifier = attributes[:'cpe_local_identifier'] if attributes[:'cpe_local_identifier']

  self.cpe_local_identifier_type = attributes[:'cpeLocalIdentifierType'] if attributes[:'cpeLocalIdentifierType']

  raise 'You cannot provide both :cpeLocalIdentifierType and :cpe_local_identifier_type' if attributes.key?(:'cpeLocalIdentifierType') && attributes.key?(:'cpe_local_identifier_type')

  self.cpe_local_identifier_type = attributes[:'cpe_local_identifier_type'] if attributes[:'cpe_local_identifier_type']

  self.static_routes = attributes[:'staticRoutes'] if attributes[:'staticRoutes']

  raise 'You cannot provide both :staticRoutes and :static_routes' if attributes.key?(:'staticRoutes') && attributes.key?(:'static_routes')

  self.static_routes = attributes[:'static_routes'] if attributes[:'static_routes']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']
end

Instance Attribute Details

#compartment_idString

[Required] The OCID of the compartment containing the IPSec connection.

Returns:

  • (String)


37
38
39
# File 'lib/oci/core/models/ip_sec_connection.rb', line 37

def compartment_id
  @compartment_id
end

#cpe_idString

[Required] The OCID of the Cpe object.

Returns:

  • (String)


41
42
43
# File 'lib/oci/core/models/ip_sec_connection.rb', line 41

def cpe_id
  @cpe_id
end

#cpe_local_identifierString

Your identifier for your CPE device. Can be either an IP address or a hostname (specifically, the fully qualified domain name (FQDN)). The type of identifier here must correspond to the value for cpeLocalIdentifierType.

If you don’t provide a value when creating the IPSec connection, the ipAddress attribute for the Cpe object specified by cpeId is used as the cpeLocalIdentifier.

Example IP address: 10.0.3.3

Example hostname: cpe.example.com

Returns:

  • (String)


90
91
92
# File 'lib/oci/core/models/ip_sec_connection.rb', line 90

def cpe_local_identifier
  @cpe_local_identifier
end

#cpe_local_identifier_typeString

The type of identifier for your CPE device. The value here must correspond to the value for cpeLocalIdentifier.

Returns:

  • (String)


96
97
98
# File 'lib/oci/core/models/ip_sec_connection.rb', line 96

def cpe_local_identifier_type
  @cpe_local_identifier_type
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: ‘{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


49
50
51
# File 'lib/oci/core/models/ip_sec_connection.rb', line 49

def defined_tags
  @defined_tags
end

#display_nameString

A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.

Returns:

  • (String)


55
56
57
# File 'lib/oci/core/models/ip_sec_connection.rb', line 55

def display_name
  @display_name
end

#drg_idString

[Required] The OCID of the DRG.

Returns:

  • (String)


59
60
61
# File 'lib/oci/core/models/ip_sec_connection.rb', line 59

def drg_id
  @drg_id
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: ‘"Finance"`

Returns:

  • (Hash<String, String>)


68
69
70
# File 'lib/oci/core/models/ip_sec_connection.rb', line 68

def freeform_tags
  @freeform_tags
end

#idString

[Required] The IPSec connection’s Oracle ID (OCID).

Returns:

  • (String)


72
73
74
# File 'lib/oci/core/models/ip_sec_connection.rb', line 72

def id
  @id
end

#lifecycle_stateString

[Required] The IPSec connection’s current state.

Returns:

  • (String)


76
77
78
# File 'lib/oci/core/models/ip_sec_connection.rb', line 76

def lifecycle_state
  @lifecycle_state
end

#static_routesArray<String>

[Required] Static routes to the CPE. At least one route must be included. The CIDR must not be a multicast address or class E address.

Example: 10.0.1.0/24

Returns:

  • (Array<String>)


104
105
106
# File 'lib/oci/core/models/ip_sec_connection.rb', line 104

def static_routes
  @static_routes
end

#time_createdDateTime

The date and time the IPSec connection was created, in the format defined by RFC3339.

Example: 2016-08-25T21:10:29.600Z

Returns:

  • (DateTime)


111
112
113
# File 'lib/oci/core/models/ip_sec_connection.rb', line 111

def time_created
  @time_created
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/oci/core/models/ip_sec_connection.rb', line 114

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'compartmentId',
    'cpe_id': :'cpeId',
    'defined_tags': :'definedTags',
    'display_name': :'displayName',
    'drg_id': :'drgId',
    'freeform_tags': :'freeformTags',
    'id': :'id',
    'lifecycle_state': :'lifecycleState',
    'cpe_local_identifier': :'cpeLocalIdentifier',
    'cpe_local_identifier_type': :'cpeLocalIdentifierType',
    'static_routes': :'staticRoutes',
    'time_created': :'timeCreated'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/oci/core/models/ip_sec_connection.rb', line 134

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'String',
    'cpe_id': :'String',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'display_name': :'String',
    'drg_id': :'String',
    'freeform_tags': :'Hash<String, String>',
    'id': :'String',
    'lifecycle_state': :'String',
    'cpe_local_identifier': :'String',
    'cpe_local_identifier_type': :'String',
    'static_routes': :'Array<String>',
    'time_created': :'DateTime'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/oci/core/models/ip_sec_connection.rb', line 283

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    compartment_id == other.compartment_id &&
    cpe_id == other.cpe_id &&
    defined_tags == other.defined_tags &&
    display_name == other.display_name &&
    drg_id == other.drg_id &&
    freeform_tags == other.freeform_tags &&
    id == other.id &&
    lifecycle_state == other.lifecycle_state &&
    cpe_local_identifier == other.cpe_local_identifier &&
    cpe_local_identifier_type == other.cpe_local_identifier_type &&
    static_routes == other.static_routes &&
    time_created == other.time_created
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'lib/oci/core/models/ip_sec_connection.rb', line 324

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


304
305
306
# File 'lib/oci/core/models/ip_sec_connection.rb', line 304

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



313
314
315
# File 'lib/oci/core/models/ip_sec_connection.rb', line 313

def hash
  [compartment_id, cpe_id, defined_tags, display_name, drg_id, freeform_tags, id, lifecycle_state, cpe_local_identifier, cpe_local_identifier_type, static_routes, time_created].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



357
358
359
360
361
362
363
364
365
366
# File 'lib/oci/core/models/ip_sec_connection.rb', line 357

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



351
352
353
# File 'lib/oci/core/models/ip_sec_connection.rb', line 351

def to_s
  to_hash.to_s
end