Class: OCI::Core::Models::IPSecConnectionTunnelErrorDetails
- Inherits:
-
Object
- Object
- OCI::Core::Models::IPSecConnectionTunnelErrorDetails
- Defined in:
- lib/oci/core/models/ip_sec_connection_tunnel_error_details.rb
Overview
Ipsec tunnels error details
Instance Attribute Summary collapse
-
#error_code ⇒ String
[Required] unique code describes error type.
-
#error_description ⇒ String
[Required] detailed description of the error.
-
#id ⇒ String
[Required] unique id generated for each error report.
-
#oci_resources_link ⇒ String
[Required] link to oracle resources.
-
#solution ⇒ String
[Required] how to resolve the error.
-
#timestamp ⇒ DateTime
[Required] timestamp when error occurred.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IPSecConnectionTunnelErrorDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ IPSecConnectionTunnelErrorDetails
Initializes the object
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/oci/core/models/ip_sec_connection_tunnel_error_details.rb', line 74 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.error_code = attributes[:'errorCode'] if attributes[:'errorCode'] raise 'You cannot provide both :errorCode and :error_code' if attributes.key?(:'errorCode') && attributes.key?(:'error_code') self.error_code = attributes[:'error_code'] if attributes[:'error_code'] self.error_description = attributes[:'errorDescription'] if attributes[:'errorDescription'] raise 'You cannot provide both :errorDescription and :error_description' if attributes.key?(:'errorDescription') && attributes.key?(:'error_description') self.error_description = attributes[:'error_description'] if attributes[:'error_description'] self.solution = attributes[:'solution'] if attributes[:'solution'] self.oci_resources_link = attributes[:'ociResourcesLink'] if attributes[:'ociResourcesLink'] raise 'You cannot provide both :ociResourcesLink and :oci_resources_link' if attributes.key?(:'ociResourcesLink') && attributes.key?(:'oci_resources_link') self.oci_resources_link = attributes[:'oci_resources_link'] if attributes[:'oci_resources_link'] self. = attributes[:'timestamp'] if attributes[:'timestamp'] end |
Instance Attribute Details
#error_code ⇒ String
[Required] unique code describes error type
16 17 18 |
# File 'lib/oci/core/models/ip_sec_connection_tunnel_error_details.rb', line 16 def error_code @error_code end |
#error_description ⇒ String
[Required] detailed description of the error
20 21 22 |
# File 'lib/oci/core/models/ip_sec_connection_tunnel_error_details.rb', line 20 def error_description @error_description end |
#id ⇒ String
[Required] unique id generated for each error report
12 13 14 |
# File 'lib/oci/core/models/ip_sec_connection_tunnel_error_details.rb', line 12 def id @id end |
#oci_resources_link ⇒ String
[Required] link to oracle resources
28 29 30 |
# File 'lib/oci/core/models/ip_sec_connection_tunnel_error_details.rb', line 28 def oci_resources_link @oci_resources_link end |
#solution ⇒ String
[Required] how to resolve the error
24 25 26 |
# File 'lib/oci/core/models/ip_sec_connection_tunnel_error_details.rb', line 24 def solution @solution end |
#timestamp ⇒ DateTime
[Required] timestamp when error occurred.
32 33 34 |
# File 'lib/oci/core/models/ip_sec_connection_tunnel_error_details.rb', line 32 def end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/oci/core/models/ip_sec_connection_tunnel_error_details.rb', line 35 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'error_code': :'errorCode', 'error_description': :'errorDescription', 'solution': :'solution', 'oci_resources_link': :'ociResourcesLink', 'timestamp': :'timestamp' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/oci/core/models/ip_sec_connection_tunnel_error_details.rb', line 49 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'error_code': :'String', 'error_description': :'String', 'solution': :'String', 'oci_resources_link': :'String', 'timestamp': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/oci/core/models/ip_sec_connection_tunnel_error_details.rb', line 112 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && error_code == other.error_code && error_description == other.error_description && solution == other.solution && oci_resources_link == other.oci_resources_link && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/oci/core/models/ip_sec_connection_tunnel_error_details.rb', line 147 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
127 128 129 |
# File 'lib/oci/core/models/ip_sec_connection_tunnel_error_details.rb', line 127 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
136 137 138 |
# File 'lib/oci/core/models/ip_sec_connection_tunnel_error_details.rb', line 136 def hash [id, error_code, error_description, solution, oci_resources_link, ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
180 181 182 183 184 185 186 187 188 189 |
# File 'lib/oci/core/models/ip_sec_connection_tunnel_error_details.rb', line 180 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
174 175 176 |
# File 'lib/oci/core/models/ip_sec_connection_tunnel_error_details.rb', line 174 def to_s to_hash.to_s end |