Class: OCI::Core::Models::ImageShapeCompatibilityEntry

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/core/models/image_shape_compatibility_entry.rb

Overview

An image and shape that are compatible.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ImageShapeCompatibilityEntry

Initializes the object

Options Hash (attributes):

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/oci/core/models/image_shape_compatibility_entry.rb', line 58

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.image_id = attributes[:'imageId'] if attributes[:'imageId']

  raise 'You cannot provide both :imageId and :image_id' if attributes.key?(:'imageId') && attributes.key?(:'image_id')

  self.image_id = attributes[:'image_id'] if attributes[:'image_id']

  self.shape = attributes[:'shape'] if attributes[:'shape']

  self.memory_constraints = attributes[:'memoryConstraints'] if attributes[:'memoryConstraints']

  raise 'You cannot provide both :memoryConstraints and :memory_constraints' if attributes.key?(:'memoryConstraints') && attributes.key?(:'memory_constraints')

  self.memory_constraints = attributes[:'memory_constraints'] if attributes[:'memory_constraints']

  self.ocpu_constraints = attributes[:'ocpuConstraints'] if attributes[:'ocpuConstraints']

  raise 'You cannot provide both :ocpuConstraints and :ocpu_constraints' if attributes.key?(:'ocpuConstraints') && attributes.key?(:'ocpu_constraints')

  self.ocpu_constraints = attributes[:'ocpu_constraints'] if attributes[:'ocpu_constraints']
end

Instance Attribute Details

#image_idString

[Required] The image OCID.

Returns:



12
13
14
# File 'lib/oci/core/models/image_shape_compatibility_entry.rb', line 12

def image_id
  @image_id
end

#memory_constraintsOCI::Core::Models::ImageMemoryConstraints

Returns:



19
20
21
# File 'lib/oci/core/models/image_shape_compatibility_entry.rb', line 19

def memory_constraints
  @memory_constraints
end

#ocpu_constraintsOCI::Core::Models::ImageOcpuConstraints

Returns:



22
23
24
# File 'lib/oci/core/models/image_shape_compatibility_entry.rb', line 22

def ocpu_constraints
  @ocpu_constraints
end

#shapeString

[Required] The shape name.

Returns:



16
17
18
# File 'lib/oci/core/models/image_shape_compatibility_entry.rb', line 16

def shape
  @shape
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



25
26
27
28
29
30
31
32
33
34
# File 'lib/oci/core/models/image_shape_compatibility_entry.rb', line 25

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'image_id': :'imageId',
    'shape': :'shape',
    'memory_constraints': :'memoryConstraints',
    'ocpu_constraints': :'ocpuConstraints'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



37
38
39
40
41
42
43
44
45
46
# File 'lib/oci/core/models/image_shape_compatibility_entry.rb', line 37

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'image_id': :'String',
    'shape': :'String',
    'memory_constraints': :'OCI::Core::Models::ImageMemoryConstraints',
    'ocpu_constraints': :'OCI::Core::Models::ImageOcpuConstraints'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • the other object to be compared



92
93
94
95
96
97
98
99
100
# File 'lib/oci/core/models/image_shape_compatibility_entry.rb', line 92

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    image_id == other.image_id &&
    shape == other.shape &&
    memory_constraints == other.memory_constraints &&
    ocpu_constraints == other.ocpu_constraints
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/oci/core/models/image_shape_compatibility_entry.rb', line 125

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method

Parameters:

  • the other object to be compared

Returns:



105
106
107
# File 'lib/oci/core/models/image_shape_compatibility_entry.rb', line 105

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • Hash code



114
115
116
# File 'lib/oci/core/models/image_shape_compatibility_entry.rb', line 114

def hash
  [image_id, shape, memory_constraints, ocpu_constraints].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



158
159
160
161
162
163
164
165
166
167
# File 'lib/oci/core/models/image_shape_compatibility_entry.rb', line 158

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



152
153
154
# File 'lib/oci/core/models/image_shape_compatibility_entry.rb', line 152

def to_s
  to_hash.to_s
end