Class: OCI::Core::Models::ImageSourceDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/core/models/image_source_details.rb

Overview

ImageSourceDetails model. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class

Constant Summary collapse

SOURCE_IMAGE_TYPE_ENUM =
[
  SOURCE_IMAGE_TYPE_QCOW2 = 'QCOW2'.freeze,
  SOURCE_IMAGE_TYPE_VMDK = 'VMDK'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ImageSourceDetails

Initializes the object

Options Hash (attributes):



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/oci/core/models/image_source_details.rb', line 83

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.operating_system = attributes[:'operatingSystem'] if attributes[:'operatingSystem']

  raise 'You cannot provide both :operatingSystem and :operating_system' if attributes.key?(:'operatingSystem') && attributes.key?(:'operating_system')

  self.operating_system = attributes[:'operating_system'] if attributes[:'operating_system']

  self.operating_system_version = attributes[:'operatingSystemVersion'] if attributes[:'operatingSystemVersion']

  raise 'You cannot provide both :operatingSystemVersion and :operating_system_version' if attributes.key?(:'operatingSystemVersion') && attributes.key?(:'operating_system_version')

  self.operating_system_version = attributes[:'operating_system_version'] if attributes[:'operating_system_version']

  self.source_image_type = attributes[:'sourceImageType'] if attributes[:'sourceImageType']

  raise 'You cannot provide both :sourceImageType and :source_image_type' if attributes.key?(:'sourceImageType') && attributes.key?(:'source_image_type')

  self.source_image_type = attributes[:'source_image_type'] if attributes[:'source_image_type']

  self.source_type = attributes[:'sourceType'] if attributes[:'sourceType']

  raise 'You cannot provide both :sourceType and :source_type' if attributes.key?(:'sourceType') && attributes.key?(:'source_type')

  self.source_type = attributes[:'source_type'] if attributes[:'source_type']
end

Instance Attribute Details

#operating_systemString



16
17
18
# File 'lib/oci/core/models/image_source_details.rb', line 16

def operating_system
  @operating_system
end

#operating_system_versionString



19
20
21
# File 'lib/oci/core/models/image_source_details.rb', line 19

def operating_system_version
  @operating_system_version
end

#source_image_typeString

The format of the image to be imported. Only monolithic images are supported. This attribute is not used for exported Oracle images with the OCI image format.



25
26
27
# File 'lib/oci/core/models/image_source_details.rb', line 25

def source_image_type
  @source_image_type
end

#source_typeString

[Required] The source type for the image. Use objectStorageTuple when specifying the namespace, bucket name, and object name. Use objectStorageUri when specifying the Object Storage URL.



31
32
33
# File 'lib/oci/core/models/image_source_details.rb', line 31

def source_type
  @source_type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
43
# File 'lib/oci/core/models/image_source_details.rb', line 34

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'operating_system': :'operatingSystem',
    'operating_system_version': :'operatingSystemVersion',
    'source_image_type': :'sourceImageType',
    'source_type': :'sourceType'
    # rubocop:enable Style/SymbolLiteral
  }
end

.get_subtype(object_hash) ⇒ Object

Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.



62
63
64
65
66
67
68
69
70
# File 'lib/oci/core/models/image_source_details.rb', line 62

def self.get_subtype(object_hash)
  type = object_hash[:'sourceType'] # rubocop:disable Style/SymbolLiteral

  return 'OCI::Core::Models::ImageSourceViaObjectStorageTupleDetails' if type == 'objectStorageTuple'
  return 'OCI::Core::Models::ImageSourceViaObjectStorageUriDetails' if type == 'objectStorageUri'

  # TODO: Log a warning when the subtype is not found.
  'OCI::Core::Models::ImageSourceDetails'
end

.swagger_typesObject

Attribute type mapping.



46
47
48
49
50
51
52
53
54
55
# File 'lib/oci/core/models/image_source_details.rb', line 46

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'operating_system': :'String',
    'operating_system_version': :'String',
    'source_image_type': :'String',
    'source_type': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.



129
130
131
132
133
134
135
136
137
# File 'lib/oci/core/models/image_source_details.rb', line 129

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    operating_system == other.operating_system &&
    operating_system_version == other.operating_system_version &&
    source_image_type == other.source_image_type &&
    source_type == other.source_type
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/oci/core/models/image_source_details.rb', line 162

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method


142
143
144
# File 'lib/oci/core/models/image_source_details.rb', line 142

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.



151
152
153
# File 'lib/oci/core/models/image_source_details.rb', line 151

def hash
  [operating_system, operating_system_version, source_image_type, source_type].hash
end

#to_hashHash

Returns the object in the form of hash



195
196
197
198
199
200
201
202
203
204
# File 'lib/oci/core/models/image_source_details.rb', line 195

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



189
190
191
# File 'lib/oci/core/models/image_source_details.rb', line 189

def to_s
  to_hash.to_s
end