Method: OCI::Core::Models::Instance#ipxe_script
- Defined in:
- lib/oci/core/models/instance.rb
#ipxe_script ⇒ String
When a bare metal or virtual machine instance boots, the iPXE firmware that runs on the instance is configured to run an iPXE script to continue the boot process.
If you want more control over the boot process, you can provide your own custom iPXE script that will run when the instance boots; however, you should be aware that the same iPXE script will run every time an instance boots; not only after the initial LaunchInstance call.
The default iPXE script connects to the instance’s local boot volume over iSCSI and performs a network boot. If you use a custom iPXE script and want to network-boot from the instance’s local boot volume over iSCSI the same way as the default iPXE script, you should use the following iSCSI IP address: 169.254.0.2, and boot volume IQN: iqn.2015-02.oracle.boot.
For more information about the Bring Your Own Image feature of Oracle Cloud Infrastructure, see [Bring Your Own Image](docs.cloud.oracle.com/Content/Compute/References/bringyourownimage.htm).
For more information about iPXE, see ipxe.org.
132 133 134 |
# File 'lib/oci/core/models/instance.rb', line 132 def ipxe_script @ipxe_script end |