Class: OCI::Core::Models::InstanceConfiguration

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/core/models/instance_configuration.rb

Overview

Instance Configuration

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ InstanceConfiguration

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/oci/core/models/instance_configuration.rb', line 101

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.id = attributes[:'id'] if attributes[:'id']

  self.instance_details = attributes[:'instanceDetails'] if attributes[:'instanceDetails']

  raise 'You cannot provide both :instanceDetails and :instance_details' if attributes.key?(:'instanceDetails') && attributes.key?(:'instance_details')

  self.instance_details = attributes[:'instance_details'] if attributes[:'instance_details']

  self.deferred_fields = attributes[:'deferredFields'] if attributes[:'deferredFields']

  raise 'You cannot provide both :deferredFields and :deferred_fields' if attributes.key?(:'deferredFields') && attributes.key?(:'deferred_fields')

  self.deferred_fields = attributes[:'deferred_fields'] if attributes[:'deferred_fields']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']
end

Instance Attribute Details

#compartment_idString

[Required] The OCID of the compartment containing the instance configuration.

Returns:



13
14
15
# File 'lib/oci/core/models/instance_configuration.rb', line 13

def compartment_id
  @compartment_id
end

#deferred_fieldsArray<String>

The required details when using the launch_instance_configuration operation. These attributes are optional when using the create_instance_configuration operation.

Returns:



47
48
49
# File 'lib/oci/core/models/instance_configuration.rb', line 47

def deferred_fields
  @deferred_fields
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: ‘{"CostCenter": "42"}`

Returns:



21
22
23
# File 'lib/oci/core/models/instance_configuration.rb', line 21

def defined_tags
  @defined_tags
end

#display_nameString

A user-friendly name for the instance configuration

Returns:



26
27
28
# File 'lib/oci/core/models/instance_configuration.rb', line 26

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: ‘"Finance"`

Returns:



34
35
36
# File 'lib/oci/core/models/instance_configuration.rb', line 34

def freeform_tags
  @freeform_tags
end

#idString

[Required] The OCID of the instance configuration

Returns:



38
39
40
# File 'lib/oci/core/models/instance_configuration.rb', line 38

def id
  @id
end

#instance_detailsOCI::Core::Models::InstanceConfigurationInstanceDetails

Returns:



41
42
43
# File 'lib/oci/core/models/instance_configuration.rb', line 41

def instance_details
  @instance_details
end

#time_createdDateTime

[Required] The date and time the instance configuration was created, in the format defined by RFC3339. Example: 2016-08-25T21:10:29.600Z

Returns:



53
54
55
# File 'lib/oci/core/models/instance_configuration.rb', line 53

def time_created
  @time_created
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/oci/core/models/instance_configuration.rb', line 56

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'compartmentId',
    'defined_tags': :'definedTags',
    'display_name': :'displayName',
    'freeform_tags': :'freeformTags',
    'id': :'id',
    'instance_details': :'instanceDetails',
    'deferred_fields': :'deferredFields',
    'time_created': :'timeCreated'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/oci/core/models/instance_configuration.rb', line 72

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'String',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'display_name': :'String',
    'freeform_tags': :'Hash<String, String>',
    'id': :'String',
    'instance_details': :'OCI::Core::Models::InstanceConfigurationInstanceDetails',
    'deferred_fields': :'Array<String>',
    'time_created': :'DateTime'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • the other object to be compared



159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/oci/core/models/instance_configuration.rb', line 159

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    compartment_id == other.compartment_id &&
    defined_tags == other.defined_tags &&
    display_name == other.display_name &&
    freeform_tags == other.freeform_tags &&
    id == other.id &&
    instance_details == other.instance_details &&
    deferred_fields == other.deferred_fields &&
    time_created == other.time_created
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/oci/core/models/instance_configuration.rb', line 196

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • the other object to be compared

Returns:

See Also:

  • `==` method


176
177
178
# File 'lib/oci/core/models/instance_configuration.rb', line 176

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • Hash code



185
186
187
# File 'lib/oci/core/models/instance_configuration.rb', line 185

def hash
  [compartment_id, defined_tags, display_name, freeform_tags, id, instance_details, deferred_fields, time_created].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



229
230
231
232
233
234
235
236
237
238
# File 'lib/oci/core/models/instance_configuration.rb', line 229

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



223
224
225
# File 'lib/oci/core/models/instance_configuration.rb', line 223

def to_s
  to_hash.to_s
end