Class: OCI::Core::Models::InstanceConfigurationAmdMilanBmLaunchInstancePlatformConfig
- Inherits:
-
InstanceConfigurationLaunchInstancePlatformConfig
- Object
- InstanceConfigurationLaunchInstancePlatformConfig
- OCI::Core::Models::InstanceConfigurationAmdMilanBmLaunchInstancePlatformConfig
- Defined in:
- lib/oci/core/models/instance_configuration_amd_milan_bm_launch_instance_platform_config.rb
Overview
The platform configuration used when launching a bare metal instance with an E4 shape (the AMD Milan platform).
Constant Summary collapse
- NUMA_NODES_PER_SOCKET_ENUM =
[ NUMA_NODES_PER_SOCKET_NPS0 = 'NPS0'.freeze, NUMA_NODES_PER_SOCKET_NPS1 = 'NPS1'.freeze, NUMA_NODES_PER_SOCKET_NPS2 = 'NPS2'.freeze, NUMA_NODES_PER_SOCKET_NPS4 = 'NPS4'.freeze, NUMA_NODES_PER_SOCKET_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Constants inherited from InstanceConfigurationLaunchInstancePlatformConfig
OCI::Core::Models::InstanceConfigurationLaunchInstancePlatformConfig::TYPE_ENUM
Instance Attribute Summary collapse
-
#numa_nodes_per_socket ⇒ String
The number of NUMA nodes per socket.
Attributes inherited from InstanceConfigurationLaunchInstancePlatformConfig
#is_measured_boot_enabled, #is_secure_boot_enabled, #is_trusted_platform_module_enabled, #type
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ InstanceConfigurationAmdMilanBmLaunchInstancePlatformConfig
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from InstanceConfigurationLaunchInstancePlatformConfig
Constructor Details
#initialize(attributes = {}) ⇒ InstanceConfigurationAmdMilanBmLaunchInstancePlatformConfig
Initializes the object
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/oci/core/models/instance_configuration_amd_milan_bm_launch_instance_platform_config.rb', line 63 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['type'] = 'AMD_MILAN_BM' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.numa_nodes_per_socket = attributes[:'numaNodesPerSocket'] if attributes[:'numaNodesPerSocket'] self.numa_nodes_per_socket = "NPS1" if numa_nodes_per_socket.nil? && !attributes.key?(:'numaNodesPerSocket') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :numaNodesPerSocket and :numa_nodes_per_socket' if attributes.key?(:'numaNodesPerSocket') && attributes.key?(:'numa_nodes_per_socket') self.numa_nodes_per_socket = attributes[:'numa_nodes_per_socket'] if attributes[:'numa_nodes_per_socket'] self.numa_nodes_per_socket = "NPS1" if numa_nodes_per_socket.nil? && !attributes.key?(:'numaNodesPerSocket') && !attributes.key?(:'numa_nodes_per_socket') # rubocop:disable Style/StringLiterals end |
Instance Attribute Details
#numa_nodes_per_socket ⇒ String
The number of NUMA nodes per socket.
25 26 27 |
# File 'lib/oci/core/models/instance_configuration_amd_milan_bm_launch_instance_platform_config.rb', line 25 def numa_nodes_per_socket @numa_nodes_per_socket end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 35 36 37 38 |
# File 'lib/oci/core/models/instance_configuration_amd_milan_bm_launch_instance_platform_config.rb', line 28 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'type': :'type', 'is_secure_boot_enabled': :'isSecureBootEnabled', 'is_trusted_platform_module_enabled': :'isTrustedPlatformModuleEnabled', 'is_measured_boot_enabled': :'isMeasuredBootEnabled', 'numa_nodes_per_socket': :'numaNodesPerSocket' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/oci/core/models/instance_configuration_amd_milan_bm_launch_instance_platform_config.rb', line 41 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'type': :'String', 'is_secure_boot_enabled': :'BOOLEAN', 'is_trusted_platform_module_enabled': :'BOOLEAN', 'is_measured_boot_enabled': :'BOOLEAN', 'numa_nodes_per_socket': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
102 103 104 105 106 107 108 109 110 111 |
# File 'lib/oci/core/models/instance_configuration_amd_milan_bm_launch_instance_platform_config.rb', line 102 def ==(other) return true if equal?(other) self.class == other.class && type == other.type && is_secure_boot_enabled == other.is_secure_boot_enabled && is_trusted_platform_module_enabled == other.is_trusted_platform_module_enabled && is_measured_boot_enabled == other.is_measured_boot_enabled && numa_nodes_per_socket == other.numa_nodes_per_socket end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/oci/core/models/instance_configuration_amd_milan_bm_launch_instance_platform_config.rb', line 136 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
116 117 118 |
# File 'lib/oci/core/models/instance_configuration_amd_milan_bm_launch_instance_platform_config.rb', line 116 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
125 126 127 |
# File 'lib/oci/core/models/instance_configuration_amd_milan_bm_launch_instance_platform_config.rb', line 125 def hash [type, is_secure_boot_enabled, is_trusted_platform_module_enabled, is_measured_boot_enabled, numa_nodes_per_socket].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
169 170 171 172 173 174 175 176 177 178 |
# File 'lib/oci/core/models/instance_configuration_amd_milan_bm_launch_instance_platform_config.rb', line 169 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
163 164 165 |
# File 'lib/oci/core/models/instance_configuration_amd_milan_bm_launch_instance_platform_config.rb', line 163 def to_s to_hash.to_s end |