Class: OCI::Core::Models::InstanceConfigurationBlockVolumeDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/core/models/instance_configuration_block_volume_details.rb

Overview

Create new block volumes or attach to an existing volume. Specify either createDetails or volumeId.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ InstanceConfigurationBlockVolumeDetails

Initializes the object

Options Hash (attributes):

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/oci/core/models/instance_configuration_block_volume_details.rb', line 51

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.attach_details = attributes[:'attachDetails'] if attributes[:'attachDetails']

  raise 'You cannot provide both :attachDetails and :attach_details' if attributes.key?(:'attachDetails') && attributes.key?(:'attach_details')

  self.attach_details = attributes[:'attach_details'] if attributes[:'attach_details']

  self.create_details = attributes[:'createDetails'] if attributes[:'createDetails']

  raise 'You cannot provide both :createDetails and :create_details' if attributes.key?(:'createDetails') && attributes.key?(:'create_details')

  self.create_details = attributes[:'create_details'] if attributes[:'create_details']

  self.volume_id = attributes[:'volumeId'] if attributes[:'volumeId']

  raise 'You cannot provide both :volumeId and :volume_id' if attributes.key?(:'volumeId') && attributes.key?(:'volume_id')

  self.volume_id = attributes[:'volume_id'] if attributes[:'volume_id']
end

Instance Attribute Details

#attach_detailsOCI::Core::Models::InstanceConfigurationAttachVolumeDetails

Returns:



11
12
13
# File 'lib/oci/core/models/instance_configuration_block_volume_details.rb', line 11

def attach_details
  @attach_details
end

#create_detailsOCI::Core::Models::InstanceConfigurationCreateVolumeDetails

Returns:



14
15
16
# File 'lib/oci/core/models/instance_configuration_block_volume_details.rb', line 14

def create_details
  @create_details
end

#volume_idString

The OCID of the volume.

Returns:



18
19
20
# File 'lib/oci/core/models/instance_configuration_block_volume_details.rb', line 18

def volume_id
  @volume_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



21
22
23
24
25
26
27
28
29
# File 'lib/oci/core/models/instance_configuration_block_volume_details.rb', line 21

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'attach_details': :'attachDetails',
    'create_details': :'createDetails',
    'volume_id': :'volumeId'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



32
33
34
35
36
37
38
39
40
# File 'lib/oci/core/models/instance_configuration_block_volume_details.rb', line 32

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'attach_details': :'OCI::Core::Models::InstanceConfigurationAttachVolumeDetails',
    'create_details': :'OCI::Core::Models::InstanceConfigurationCreateVolumeDetails',
    'volume_id': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • the other object to be compared



83
84
85
86
87
88
89
90
# File 'lib/oci/core/models/instance_configuration_block_volume_details.rb', line 83

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    attach_details == other.attach_details &&
    create_details == other.create_details &&
    volume_id == other.volume_id
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/oci/core/models/instance_configuration_block_volume_details.rb', line 115

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method

Parameters:

  • the other object to be compared

Returns:



95
96
97
# File 'lib/oci/core/models/instance_configuration_block_volume_details.rb', line 95

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • Hash code



104
105
106
# File 'lib/oci/core/models/instance_configuration_block_volume_details.rb', line 104

def hash
  [attach_details, create_details, volume_id].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



148
149
150
151
152
153
154
155
156
157
# File 'lib/oci/core/models/instance_configuration_block_volume_details.rb', line 148

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



142
143
144
# File 'lib/oci/core/models/instance_configuration_block_volume_details.rb', line 142

def to_s
  to_hash.to_s
end