Class: OCI::Core::Models::InstanceConfigurationCreateVnicDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/core/models/instance_configuration_create_vnic_details.rb

Overview

Contains the properties of the VNIC for an instance configuration. See CreateVnicDetails and [Instance Configurations](docs.cloud.oracle.com/iaas/Content/Compute/Concepts/instancemanagement.htm#config) for more information.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ InstanceConfigurationCreateVnicDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :assign_public_ip (BOOLEAN)

    The value to assign to the #assign_public_ip property

  • :assign_private_dns_record (BOOLEAN)

    The value to assign to the #assign_private_dns_record property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property

  • :display_name (String)

    The value to assign to the #display_name property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :hostname_label (String)

    The value to assign to the #hostname_label property

  • :nsg_ids (Array<String>)

    The value to assign to the #nsg_ids property

  • :private_ip (String)

    The value to assign to the #private_ip property

  • :skip_source_dest_check (BOOLEAN)

    The value to assign to the #skip_source_dest_check property

  • :subnet_id (String)

    The value to assign to the #subnet_id property



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/oci/core/models/instance_configuration_create_vnic_details.rb', line 129

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.assign_public_ip = attributes[:'assignPublicIp'] unless attributes[:'assignPublicIp'].nil?

  raise 'You cannot provide both :assignPublicIp and :assign_public_ip' if attributes.key?(:'assignPublicIp') && attributes.key?(:'assign_public_ip')

  self.assign_public_ip = attributes[:'assign_public_ip'] unless attributes[:'assign_public_ip'].nil?

  self.assign_private_dns_record = attributes[:'assignPrivateDnsRecord'] unless attributes[:'assignPrivateDnsRecord'].nil?

  raise 'You cannot provide both :assignPrivateDnsRecord and :assign_private_dns_record' if attributes.key?(:'assignPrivateDnsRecord') && attributes.key?(:'assign_private_dns_record')

  self.assign_private_dns_record = attributes[:'assign_private_dns_record'] unless attributes[:'assign_private_dns_record'].nil?

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.hostname_label = attributes[:'hostnameLabel'] if attributes[:'hostnameLabel']

  raise 'You cannot provide both :hostnameLabel and :hostname_label' if attributes.key?(:'hostnameLabel') && attributes.key?(:'hostname_label')

  self.hostname_label = attributes[:'hostname_label'] if attributes[:'hostname_label']

  self.nsg_ids = attributes[:'nsgIds'] if attributes[:'nsgIds']

  raise 'You cannot provide both :nsgIds and :nsg_ids' if attributes.key?(:'nsgIds') && attributes.key?(:'nsg_ids')

  self.nsg_ids = attributes[:'nsg_ids'] if attributes[:'nsg_ids']

  self.private_ip = attributes[:'privateIp'] if attributes[:'privateIp']

  raise 'You cannot provide both :privateIp and :private_ip' if attributes.key?(:'privateIp') && attributes.key?(:'private_ip')

  self.private_ip = attributes[:'private_ip'] if attributes[:'private_ip']

  self.skip_source_dest_check = attributes[:'skipSourceDestCheck'] unless attributes[:'skipSourceDestCheck'].nil?

  raise 'You cannot provide both :skipSourceDestCheck and :skip_source_dest_check' if attributes.key?(:'skipSourceDestCheck') && attributes.key?(:'skip_source_dest_check')

  self.skip_source_dest_check = attributes[:'skip_source_dest_check'] unless attributes[:'skip_source_dest_check'].nil?

  self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId']

  raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id')

  self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id']
end

Instance Attribute Details

#assign_private_dns_recordBOOLEAN

Whether the VNIC should be assigned a private DNS record. See the assignPrivateDnsRecord attribute of CreateVnicDetails for more information.

Returns:

  • (BOOLEAN)


22
23
24
# File 'lib/oci/core/models/instance_configuration_create_vnic_details.rb', line 22

def assign_private_dns_record
  @assign_private_dns_record
end

#assign_public_ipBOOLEAN

Whether the VNIC should be assigned a public IP address. See the assignPublicIp attribute of CreateVnicDetails for more information.

Returns:

  • (BOOLEAN)


16
17
18
# File 'lib/oci/core/models/instance_configuration_create_vnic_details.rb', line 16

def assign_public_ip
  @assign_public_ip
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).

Example: ‘{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


30
31
32
# File 'lib/oci/core/models/instance_configuration_create_vnic_details.rb', line 30

def defined_tags
  @defined_tags
end

#display_nameString

A user-friendly name for the VNIC. Does not have to be unique. Avoid entering confidential information.

Returns:

  • (String)


36
37
38
# File 'lib/oci/core/models/instance_configuration_create_vnic_details.rb', line 36

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).

Example: ‘"Finance"`

Returns:

  • (Hash<String, String>)


44
45
46
# File 'lib/oci/core/models/instance_configuration_create_vnic_details.rb', line 44

def freeform_tags
  @freeform_tags
end

#hostname_labelString

The hostname for the VNIC’s primary private IP. See the hostnameLabel attribute of CreateVnicDetails for more information.

Returns:

  • (String)


50
51
52
# File 'lib/oci/core/models/instance_configuration_create_vnic_details.rb', line 50

def hostname_label
  @hostname_label
end

#nsg_idsArray<String>

A list of the OCIDs of the network security groups (NSGs) to add the VNIC to. For more information about NSGs, see NetworkSecurityGroup.

Returns:

  • (Array<String>)


57
58
59
# File 'lib/oci/core/models/instance_configuration_create_vnic_details.rb', line 57

def nsg_ids
  @nsg_ids
end

#private_ipString

A private IP address of your choice to assign to the VNIC. See the privateIp attribute of CreateVnicDetails for more information.

Returns:

  • (String)


63
64
65
# File 'lib/oci/core/models/instance_configuration_create_vnic_details.rb', line 63

def private_ip
  @private_ip
end

#skip_source_dest_checkBOOLEAN

Whether the source/destination check is disabled on the VNIC. See the skipSourceDestCheck attribute of CreateVnicDetails for more information.

Returns:

  • (BOOLEAN)


69
70
71
# File 'lib/oci/core/models/instance_configuration_create_vnic_details.rb', line 69

def skip_source_dest_check
  @skip_source_dest_check
end

#subnet_idString

The OCID of the subnet to create the VNIC in. See the subnetId attribute of CreateVnicDetails for more information.

Returns:

  • (String)


75
76
77
# File 'lib/oci/core/models/instance_configuration_create_vnic_details.rb', line 75

def subnet_id
  @subnet_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/oci/core/models/instance_configuration_create_vnic_details.rb', line 78

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'assign_public_ip': :'assignPublicIp',
    'assign_private_dns_record': :'assignPrivateDnsRecord',
    'defined_tags': :'definedTags',
    'display_name': :'displayName',
    'freeform_tags': :'freeformTags',
    'hostname_label': :'hostnameLabel',
    'nsg_ids': :'nsgIds',
    'private_ip': :'privateIp',
    'skip_source_dest_check': :'skipSourceDestCheck',
    'subnet_id': :'subnetId'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/oci/core/models/instance_configuration_create_vnic_details.rb', line 96

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'assign_public_ip': :'BOOLEAN',
    'assign_private_dns_record': :'BOOLEAN',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'display_name': :'String',
    'freeform_tags': :'Hash<String, String>',
    'hostname_label': :'String',
    'nsg_ids': :'Array<String>',
    'private_ip': :'String',
    'skip_source_dest_check': :'BOOLEAN',
    'subnet_id': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/oci/core/models/instance_configuration_create_vnic_details.rb', line 203

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    assign_public_ip == other.assign_public_ip &&
    assign_private_dns_record == other.assign_private_dns_record &&
    defined_tags == other.defined_tags &&
    display_name == other.display_name &&
    freeform_tags == other.freeform_tags &&
    hostname_label == other.hostname_label &&
    nsg_ids == other.nsg_ids &&
    private_ip == other.private_ip &&
    skip_source_dest_check == other.skip_source_dest_check &&
    subnet_id == other.subnet_id
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/oci/core/models/instance_configuration_create_vnic_details.rb', line 242

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


222
223
224
# File 'lib/oci/core/models/instance_configuration_create_vnic_details.rb', line 222

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



231
232
233
# File 'lib/oci/core/models/instance_configuration_create_vnic_details.rb', line 231

def hash
  [assign_public_ip, assign_private_dns_record, defined_tags, display_name, freeform_tags, hostname_label, nsg_ids, private_ip, skip_source_dest_check, subnet_id].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



275
276
277
278
279
280
281
282
283
284
# File 'lib/oci/core/models/instance_configuration_create_vnic_details.rb', line 275

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



269
270
271
# File 'lib/oci/core/models/instance_configuration_create_vnic_details.rb', line 269

def to_s
  to_hash.to_s
end