Class: OCI::Core::Models::InstanceConfigurationInstanceSourceViaImageDetails
- Inherits:
-
InstanceConfigurationInstanceSourceDetails
- Object
- InstanceConfigurationInstanceSourceDetails
- OCI::Core::Models::InstanceConfigurationInstanceSourceViaImageDetails
- Defined in:
- lib/oci/core/models/instance_configuration_instance_source_via_image_details.rb
Overview
InstanceConfigurationInstanceSourceViaImageDetails model.
Instance Attribute Summary collapse
-
#boot_volume_size_in_gbs ⇒ Integer
The size of the boot volume in GBs.
-
#boot_volume_vpus_per_gb ⇒ Integer
The number of volume performance units (VPUs) that will be applied to this volume per GB, representing the Block Volume service's elastic performance options.
-
#image_id ⇒ String
The OCID of the image used to boot the instance.
Attributes inherited from InstanceConfigurationInstanceSourceDetails
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ InstanceConfigurationInstanceSourceViaImageDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from InstanceConfigurationInstanceSourceDetails
Constructor Details
#initialize(attributes = {}) ⇒ InstanceConfigurationInstanceSourceViaImageDetails
Initializes the object
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/oci/core/models/instance_configuration_instance_source_via_image_details.rb', line 69 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['sourceType'] = 'image' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.boot_volume_size_in_gbs = attributes[:'bootVolumeSizeInGBs'] if attributes[:'bootVolumeSizeInGBs'] raise 'You cannot provide both :bootVolumeSizeInGBs and :boot_volume_size_in_gbs' if attributes.key?(:'bootVolumeSizeInGBs') && attributes.key?(:'boot_volume_size_in_gbs') self.boot_volume_size_in_gbs = attributes[:'boot_volume_size_in_gbs'] if attributes[:'boot_volume_size_in_gbs'] self.image_id = attributes[:'imageId'] if attributes[:'imageId'] raise 'You cannot provide both :imageId and :image_id' if attributes.key?(:'imageId') && attributes.key?(:'image_id') self.image_id = attributes[:'image_id'] if attributes[:'image_id'] self.boot_volume_vpus_per_gb = attributes[:'bootVolumeVpusPerGB'] if attributes[:'bootVolumeVpusPerGB'] raise 'You cannot provide both :bootVolumeVpusPerGB and :boot_volume_vpus_per_gb' if attributes.key?(:'bootVolumeVpusPerGB') && attributes.key?(:'boot_volume_vpus_per_gb') self.boot_volume_vpus_per_gb = attributes[:'boot_volume_vpus_per_gb'] if attributes[:'boot_volume_vpus_per_gb'] end |
Instance Attribute Details
#boot_volume_size_in_gbs ⇒ Integer
The size of the boot volume in GBs. The minimum value is 50 GB and the maximum value is 32,768 GB (32 TB).
15 16 17 |
# File 'lib/oci/core/models/instance_configuration_instance_source_via_image_details.rb', line 15 def boot_volume_size_in_gbs @boot_volume_size_in_gbs end |
#boot_volume_vpus_per_gb ⇒ Integer
The number of volume performance units (VPUs) that will be applied to this volume per GB, representing the Block Volume service's elastic performance options. See [Block Volume Performance Levels](docs.cloud.oracle.com/iaas/Content/Block/Concepts/blockvolumeperformance.htm#perf_levels) for more information.
Allowed values:
* `10`: Represents Balanced option.
* `20`: Represents Higher Performance option.
* `30`-`120`: Represents the Ultra High Performance option.
34 35 36 |
# File 'lib/oci/core/models/instance_configuration_instance_source_via_image_details.rb', line 34 def boot_volume_vpus_per_gb @boot_volume_vpus_per_gb end |
#image_id ⇒ String
The OCID of the image used to boot the instance.
19 20 21 |
# File 'lib/oci/core/models/instance_configuration_instance_source_via_image_details.rb', line 19 def image_id @image_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/oci/core/models/instance_configuration_instance_source_via_image_details.rb', line 37 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'source_type': :'sourceType', 'boot_volume_size_in_gbs': :'bootVolumeSizeInGBs', 'image_id': :'imageId', 'boot_volume_vpus_per_gb': :'bootVolumeVpusPerGB' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
49 50 51 52 53 54 55 56 57 58 |
# File 'lib/oci/core/models/instance_configuration_instance_source_via_image_details.rb', line 49 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'source_type': :'String', 'boot_volume_size_in_gbs': :'Integer', 'image_id': :'String', 'boot_volume_vpus_per_gb': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
105 106 107 108 109 110 111 112 113 |
# File 'lib/oci/core/models/instance_configuration_instance_source_via_image_details.rb', line 105 def ==(other) return true if equal?(other) self.class == other.class && source_type == other.source_type && boot_volume_size_in_gbs == other.boot_volume_size_in_gbs && image_id == other.image_id && boot_volume_vpus_per_gb == other.boot_volume_vpus_per_gb end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/oci/core/models/instance_configuration_instance_source_via_image_details.rb', line 138 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
118 119 120 |
# File 'lib/oci/core/models/instance_configuration_instance_source_via_image_details.rb', line 118 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
127 128 129 |
# File 'lib/oci/core/models/instance_configuration_instance_source_via_image_details.rb', line 127 def hash [source_type, boot_volume_size_in_gbs, image_id, boot_volume_vpus_per_gb].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
171 172 173 174 175 176 177 178 179 180 |
# File 'lib/oci/core/models/instance_configuration_instance_source_via_image_details.rb', line 171 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
165 166 167 |
# File 'lib/oci/core/models/instance_configuration_instance_source_via_image_details.rb', line 165 def to_s to_hash.to_s end |