Class: OCI::Core::Models::InstanceConfigurationLaunchInstanceDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/core/models/instance_configuration_launch_instance_details.rb

Overview

Instance launch details for creating an instance from an instance configuration. Use the sourceDetails parameter to specify whether a boot volume or an image should be used to launch a new instance.

See LaunchInstanceDetails for more information.

Constant Summary collapse

LAUNCH_MODE_ENUM =
[
  LAUNCH_MODE_NATIVE = 'NATIVE'.freeze,
  LAUNCH_MODE_EMULATED = 'EMULATED'.freeze,
  LAUNCH_MODE_PARAVIRTUALIZED = 'PARAVIRTUALIZED'.freeze,
  LAUNCH_MODE_CUSTOM = 'CUSTOM'.freeze,
  LAUNCH_MODE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
PREFERRED_MAINTENANCE_ACTION_ENUM =
[
  PREFERRED_MAINTENANCE_ACTION_LIVE_MIGRATE = 'LIVE_MIGRATE'.freeze,
  PREFERRED_MAINTENANCE_ACTION_REBOOT = 'REBOOT'.freeze,
  PREFERRED_MAINTENANCE_ACTION_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ InstanceConfigurationLaunchInstanceDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
# File 'lib/oci/core/models/instance_configuration_launch_instance_details.rb', line 336

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain']

  raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain')

  self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain']

  self.capacity_reservation_id = attributes[:'capacityReservationId'] if attributes[:'capacityReservationId']

  raise 'You cannot provide both :capacityReservationId and :capacity_reservation_id' if attributes.key?(:'capacityReservationId') && attributes.key?(:'capacity_reservation_id')

  self.capacity_reservation_id = attributes[:'capacity_reservation_id'] if attributes[:'capacity_reservation_id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.create_vnic_details = attributes[:'createVnicDetails'] if attributes[:'createVnicDetails']

  raise 'You cannot provide both :createVnicDetails and :create_vnic_details' if attributes.key?(:'createVnicDetails') && attributes.key?(:'create_vnic_details')

  self.create_vnic_details = attributes[:'create_vnic_details'] if attributes[:'create_vnic_details']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self. = attributes[:'extendedMetadata'] if attributes[:'extendedMetadata']

  raise 'You cannot provide both :extendedMetadata and :extended_metadata' if attributes.key?(:'extendedMetadata') && attributes.key?(:'extended_metadata')

  self. = attributes[:'extended_metadata'] if attributes[:'extended_metadata']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.ipxe_script = attributes[:'ipxeScript'] if attributes[:'ipxeScript']

  raise 'You cannot provide both :ipxeScript and :ipxe_script' if attributes.key?(:'ipxeScript') && attributes.key?(:'ipxe_script')

  self.ipxe_script = attributes[:'ipxe_script'] if attributes[:'ipxe_script']

  self. = attributes[:'metadata'] if attributes[:'metadata']

  self.shape = attributes[:'shape'] if attributes[:'shape']

  self.shape_config = attributes[:'shapeConfig'] if attributes[:'shapeConfig']

  raise 'You cannot provide both :shapeConfig and :shape_config' if attributes.key?(:'shapeConfig') && attributes.key?(:'shape_config')

  self.shape_config = attributes[:'shape_config'] if attributes[:'shape_config']

  self.platform_config = attributes[:'platformConfig'] if attributes[:'platformConfig']

  raise 'You cannot provide both :platformConfig and :platform_config' if attributes.key?(:'platformConfig') && attributes.key?(:'platform_config')

  self.platform_config = attributes[:'platform_config'] if attributes[:'platform_config']

  self.source_details = attributes[:'sourceDetails'] if attributes[:'sourceDetails']

  raise 'You cannot provide both :sourceDetails and :source_details' if attributes.key?(:'sourceDetails') && attributes.key?(:'source_details')

  self.source_details = attributes[:'source_details'] if attributes[:'source_details']

  self.fault_domain = attributes[:'faultDomain'] if attributes[:'faultDomain']

  raise 'You cannot provide both :faultDomain and :fault_domain' if attributes.key?(:'faultDomain') && attributes.key?(:'fault_domain')

  self.fault_domain = attributes[:'fault_domain'] if attributes[:'fault_domain']

  self.dedicated_vm_host_id = attributes[:'dedicatedVmHostId'] if attributes[:'dedicatedVmHostId']

  raise 'You cannot provide both :dedicatedVmHostId and :dedicated_vm_host_id' if attributes.key?(:'dedicatedVmHostId') && attributes.key?(:'dedicated_vm_host_id')

  self.dedicated_vm_host_id = attributes[:'dedicated_vm_host_id'] if attributes[:'dedicated_vm_host_id']

  self.launch_mode = attributes[:'launchMode'] if attributes[:'launchMode']

  raise 'You cannot provide both :launchMode and :launch_mode' if attributes.key?(:'launchMode') && attributes.key?(:'launch_mode')

  self.launch_mode = attributes[:'launch_mode'] if attributes[:'launch_mode']

  self.launch_options = attributes[:'launchOptions'] if attributes[:'launchOptions']

  raise 'You cannot provide both :launchOptions and :launch_options' if attributes.key?(:'launchOptions') && attributes.key?(:'launch_options')

  self.launch_options = attributes[:'launch_options'] if attributes[:'launch_options']

  self.agent_config = attributes[:'agentConfig'] if attributes[:'agentConfig']

  raise 'You cannot provide both :agentConfig and :agent_config' if attributes.key?(:'agentConfig') && attributes.key?(:'agent_config')

  self.agent_config = attributes[:'agent_config'] if attributes[:'agent_config']

  self.is_pv_encryption_in_transit_enabled = attributes[:'isPvEncryptionInTransitEnabled'] unless attributes[:'isPvEncryptionInTransitEnabled'].nil?

  raise 'You cannot provide both :isPvEncryptionInTransitEnabled and :is_pv_encryption_in_transit_enabled' if attributes.key?(:'isPvEncryptionInTransitEnabled') && attributes.key?(:'is_pv_encryption_in_transit_enabled')

  self.is_pv_encryption_in_transit_enabled = attributes[:'is_pv_encryption_in_transit_enabled'] unless attributes[:'is_pv_encryption_in_transit_enabled'].nil?

  self.preferred_maintenance_action = attributes[:'preferredMaintenanceAction'] if attributes[:'preferredMaintenanceAction']

  raise 'You cannot provide both :preferredMaintenanceAction and :preferred_maintenance_action' if attributes.key?(:'preferredMaintenanceAction') && attributes.key?(:'preferred_maintenance_action')

  self.preferred_maintenance_action = attributes[:'preferred_maintenance_action'] if attributes[:'preferred_maintenance_action']

  self.instance_options = attributes[:'instanceOptions'] if attributes[:'instanceOptions']

  raise 'You cannot provide both :instanceOptions and :instance_options' if attributes.key?(:'instanceOptions') && attributes.key?(:'instance_options')

  self.instance_options = attributes[:'instance_options'] if attributes[:'instance_options']

  self.availability_config = attributes[:'availabilityConfig'] if attributes[:'availabilityConfig']

  raise 'You cannot provide both :availabilityConfig and :availability_config' if attributes.key?(:'availabilityConfig') && attributes.key?(:'availability_config')

  self.availability_config = attributes[:'availability_config'] if attributes[:'availability_config']

  self.preemptible_instance_config = attributes[:'preemptibleInstanceConfig'] if attributes[:'preemptibleInstanceConfig']

  raise 'You cannot provide both :preemptibleInstanceConfig and :preemptible_instance_config' if attributes.key?(:'preemptibleInstanceConfig') && attributes.key?(:'preemptible_instance_config')

  self.preemptible_instance_config = attributes[:'preemptible_instance_config'] if attributes[:'preemptible_instance_config']
end

Instance Attribute Details

#agent_configOCI::Core::Models::InstanceConfigurationLaunchInstanceAgentConfigDetails



220
221
222
# File 'lib/oci/core/models/instance_configuration_launch_instance_details.rb', line 220

def agent_config
  @agent_config
end

#availability_configOCI::Core::Models::InstanceConfigurationAvailabilityConfig



237
238
239
# File 'lib/oci/core/models/instance_configuration_launch_instance_details.rb', line 237

def availability_config
  @availability_config
end

#availability_domainString

The availability domain of the instance.

Example: Uocm:PHX-AD-1

Returns:

  • (String)


34
35
36
# File 'lib/oci/core/models/instance_configuration_launch_instance_details.rb', line 34

def availability_domain
  @availability_domain
end

#capacity_reservation_idString

The OCID of the compute capacity reservation this instance is launched under.

Returns:

  • (String)


38
39
40
# File 'lib/oci/core/models/instance_configuration_launch_instance_details.rb', line 38

def capacity_reservation_id
  @capacity_reservation_id
end

#compartment_idString

The OCID of the compartment containing the instance. Instances created from instance configurations are placed in the same compartment as the instance that was used to create the instance configuration.

Returns:

  • (String)


45
46
47
# File 'lib/oci/core/models/instance_configuration_launch_instance_details.rb', line 45

def compartment_id
  @compartment_id
end

#create_vnic_detailsOCI::Core::Models::InstanceConfigurationCreateVnicDetails



48
49
50
# File 'lib/oci/core/models/instance_configuration_launch_instance_details.rb', line 48

def create_vnic_details
  @create_vnic_details
end

#dedicated_vm_host_idString

The OCID of dedicated VM host.

Dedicated VM hosts can be used when launching individual instances from an instance configuration. They cannot be used to launch instance pools.

Returns:

  • (String)


205
206
207
# File 'lib/oci/core/models/instance_configuration_launch_instance_details.rb', line 205

def dedicated_vm_host_id
  @dedicated_vm_host_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).

Example: ‘{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


56
57
58
# File 'lib/oci/core/models/instance_configuration_launch_instance_details.rb', line 56

def defined_tags
  @defined_tags
end

#display_nameString

A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.

Returns:

  • (String)


62
63
64
# File 'lib/oci/core/models/instance_configuration_launch_instance_details.rb', line 62

def display_name
  @display_name
end

#extended_metadataHash<String, Object>

Additional metadata key/value pairs that you provide. They serve the same purpose and functionality as fields in the metadata object.

They are distinguished from metadata fields in that these can be nested JSON objects (whereas metadata fields are string/string maps only).

The combined size of the metadata and extendedMetadata objects can be a maximum of 32,000 bytes.

Returns:

  • (Hash<String, Object>)


74
75
76
# File 'lib/oci/core/models/instance_configuration_launch_instance_details.rb', line 74

def 
  @extended_metadata
end

#fault_domainString

A fault domain is a grouping of hardware and infrastructure within an availability domain. Each availability domain contains three fault domains. Fault domains let you distribute your instances so that they are not on the same physical hardware within a single availability domain. A hardware failure or Compute hardware maintenance that affects one fault domain does not affect instances in other fault domains.

If you do not specify the fault domain, the system selects one for you.

To get a list of fault domains, use the list_fault_domains operation in the Identity and Access Management Service API.

Example: FAULT-DOMAIN-1

Returns:

  • (String)


197
198
199
# File 'lib/oci/core/models/instance_configuration_launch_instance_details.rb', line 197

def fault_domain
  @fault_domain
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).

Example: ‘"Finance"`

Returns:

  • (Hash<String, String>)


82
83
84
# File 'lib/oci/core/models/instance_configuration_launch_instance_details.rb', line 82

def freeform_tags
  @freeform_tags
end

#instance_optionsOCI::Core::Models::InstanceConfigurationInstanceOptions



234
235
236
# File 'lib/oci/core/models/instance_configuration_launch_instance_details.rb', line 234

def instance_options
  @instance_options
end

#ipxe_scriptString

This is an advanced option.

When a bare metal or virtual machine instance boots, the iPXE firmware that runs on the instance is configured to run an iPXE script to continue the boot process.

If you want more control over the boot process, you can provide your own custom iPXE script that will run when the instance boots; however, you should be aware that the same iPXE script will run every time an instance boots; not only after the initial LaunchInstance call.

The default iPXE script connects to the instance’s local boot volume over iSCSI and performs a network boot. If you use a custom iPXE script and want to network-boot from the instance’s local boot volume over iSCSI the same way as the default iPXE script, you should use the following iSCSI IP address: 169.254.0.2, and boot volume IQN: iqn.2015-02.oracle.boot.

For more information about the Bring Your Own Image feature of Oracle Cloud Infrastructure, see [Bring Your Own Image](docs.cloud.oracle.com/iaas/Content/Compute/References/bringyourownimage.htm).

For more information about iPXE, see ipxe.org.

Returns:

  • (String)


110
111
112
# File 'lib/oci/core/models/instance_configuration_launch_instance_details.rb', line 110

def ipxe_script
  @ipxe_script
end

#is_pv_encryption_in_transit_enabledBOOLEAN

Whether to enable in-transit encryption for the data volume’s paravirtualized attachment. The default value is false.

Returns:

  • (BOOLEAN)


224
225
226
# File 'lib/oci/core/models/instance_configuration_launch_instance_details.rb', line 224

def is_pv_encryption_in_transit_enabled
  @is_pv_encryption_in_transit_enabled
end

#launch_modeString

Specifies the configuration mode for launching virtual machine (VM) instances. The configuration modes are:

  • NATIVE - VM instances launch with iSCSI boot and VFIO devices. The default value for platform images.

  • EMULATED - VM instances launch with emulated devices, such as the E1000 network driver and emulated SCSI disk controller.

  • PARAVIRTUALIZED - VM instances launch with paravirtualized devices using VirtIO drivers.

  • CUSTOM - VM instances launch with custom configuration settings specified in the LaunchOptions parameter.

Returns:

  • (String)


214
215
216
# File 'lib/oci/core/models/instance_configuration_launch_instance_details.rb', line 214

def launch_mode
  @launch_mode
end

#launch_optionsOCI::Core::Models::InstanceConfigurationLaunchOptions



217
218
219
# File 'lib/oci/core/models/instance_configuration_launch_instance_details.rb', line 217

def launch_options
  @launch_options
end

#metadataHash<String, String>

Custom metadata key/value pairs that you provide, such as the SSH public key required to connect to the instance.

A metadata service runs on every launched instance. The service is an HTTP endpoint listening on 169.254.169.254. You can use the service to:

  • Provide information to [Cloud-Init](cloudinit.readthedocs.org/en/latest/) to be used for various system initialization tasks.

  • Get information about the instance, including the custom metadata that you provide when you launch the instance.

**Providing Cloud-Init Metadata**

You can use the following metadata key names to provide information to
Cloud-Init:

**\"ssh_authorized_keys\"** - Provide one or more public SSH keys to be
included in the `~/.ssh/authorized_keys` file for the default user on the
instance. Use a newline character to separate multiple keys. The SSH
keys must be in the format necessary for the `authorized_keys` file, as shown
in the example below.

**\"user_data\"** - Provide your own base64-encoded data to be used by
Cloud-Init to run custom scripts or provide custom Cloud-Init configuration. For
information about how to take advantage of user data, see the
[Cloud-Init Documentation](http://cloudinit.readthedocs.org/en/latest/topics/format.html).

**Metadata Example**

     \"metadata\" : {
        \"quake_bot_level\" : \"Severe\",
        \"ssh_authorized_keys\" : \"ssh-rsa <your_public_SSH_key>== rsa-key-20160227\",
        \"user_data\" : \"<your_public_SSH_key>==\"
     }
**Getting Metadata on the Instance**

To get information about your instance, connect to the instance using SSH and issue any of the
following GET requests:

    curl -H \"Authorization: Bearer Oracle\" http://169.254.169.254/opc/v2/instance/
    curl -H \"Authorization: Bearer Oracle\" http://169.254.169.254/opc/v2/instance/metadata/
    curl -H \"Authorization: Bearer Oracle\" http://169.254.169.254/opc/v2/instance/metadata/<any-key-name>

You'll get back a response that includes all the instance information; only the metadata information; or
the metadata information for the specified key name, respectively.

The combined size of the `metadata` and `extendedMetadata` objects can be a maximum of 32,000 bytes.

Returns:

  • (Hash<String, String>)


162
163
164
# File 'lib/oci/core/models/instance_configuration_launch_instance_details.rb', line 162

def 
  @metadata
end

#platform_configOCI::Core::Models::InstanceConfigurationLaunchInstancePlatformConfig



176
177
178
# File 'lib/oci/core/models/instance_configuration_launch_instance_details.rb', line 176

def platform_config
  @platform_config
end

#preemptible_instance_configOCI::Core::Models::PreemptibleInstanceConfigDetails



240
241
242
# File 'lib/oci/core/models/instance_configuration_launch_instance_details.rb', line 240

def preemptible_instance_config
  @preemptible_instance_config
end

#preferred_maintenance_actionString

The preferred maintenance action for an instance. The default is LIVE_MIGRATE, if live migration is supported.

  • LIVE_MIGRATE - Run maintenance using a live migration.

  • REBOOT - Run maintenance using a reboot.

Returns:

  • (String)


231
232
233
# File 'lib/oci/core/models/instance_configuration_launch_instance_details.rb', line 231

def preferred_maintenance_action
  @preferred_maintenance_action
end

#shapeString

The shape of an instance. The shape determines the number of CPUs, amount of memory, and other resources allocated to the instance.

You can enumerate all available shapes by calling list_shapes.

Returns:

  • (String)


170
171
172
# File 'lib/oci/core/models/instance_configuration_launch_instance_details.rb', line 170

def shape
  @shape
end

#shape_configOCI::Core::Models::InstanceConfigurationLaunchInstanceShapeConfigDetails



173
174
175
# File 'lib/oci/core/models/instance_configuration_launch_instance_details.rb', line 173

def shape_config
  @shape_config
end

#source_detailsOCI::Core::Models::InstanceConfigurationInstanceSourceDetails



179
180
181
# File 'lib/oci/core/models/instance_configuration_launch_instance_details.rb', line 179

def source_details
  @source_details
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/oci/core/models/instance_configuration_launch_instance_details.rb', line 243

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'availability_domain': :'availabilityDomain',
    'capacity_reservation_id': :'capacityReservationId',
    'compartment_id': :'compartmentId',
    'create_vnic_details': :'createVnicDetails',
    'defined_tags': :'definedTags',
    'display_name': :'displayName',
    'extended_metadata': :'extendedMetadata',
    'freeform_tags': :'freeformTags',
    'ipxe_script': :'ipxeScript',
    'metadata': :'metadata',
    'shape': :'shape',
    'shape_config': :'shapeConfig',
    'platform_config': :'platformConfig',
    'source_details': :'sourceDetails',
    'fault_domain': :'faultDomain',
    'dedicated_vm_host_id': :'dedicatedVmHostId',
    'launch_mode': :'launchMode',
    'launch_options': :'launchOptions',
    'agent_config': :'agentConfig',
    'is_pv_encryption_in_transit_enabled': :'isPvEncryptionInTransitEnabled',
    'preferred_maintenance_action': :'preferredMaintenanceAction',
    'instance_options': :'instanceOptions',
    'availability_config': :'availabilityConfig',
    'preemptible_instance_config': :'preemptibleInstanceConfig'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/oci/core/models/instance_configuration_launch_instance_details.rb', line 275

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'availability_domain': :'String',
    'capacity_reservation_id': :'String',
    'compartment_id': :'String',
    'create_vnic_details': :'OCI::Core::Models::InstanceConfigurationCreateVnicDetails',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'display_name': :'String',
    'extended_metadata': :'Hash<String, Object>',
    'freeform_tags': :'Hash<String, String>',
    'ipxe_script': :'String',
    'metadata': :'Hash<String, String>',
    'shape': :'String',
    'shape_config': :'OCI::Core::Models::InstanceConfigurationLaunchInstanceShapeConfigDetails',
    'platform_config': :'OCI::Core::Models::InstanceConfigurationLaunchInstancePlatformConfig',
    'source_details': :'OCI::Core::Models::InstanceConfigurationInstanceSourceDetails',
    'fault_domain': :'String',
    'dedicated_vm_host_id': :'String',
    'launch_mode': :'String',
    'launch_options': :'OCI::Core::Models::InstanceConfigurationLaunchOptions',
    'agent_config': :'OCI::Core::Models::InstanceConfigurationLaunchInstanceAgentConfigDetails',
    'is_pv_encryption_in_transit_enabled': :'BOOLEAN',
    'preferred_maintenance_action': :'String',
    'instance_options': :'OCI::Core::Models::InstanceConfigurationInstanceOptions',
    'availability_config': :'OCI::Core::Models::InstanceConfigurationAvailabilityConfig',
    'preemptible_instance_config': :'OCI::Core::Models::PreemptibleInstanceConfigDetails'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
# File 'lib/oci/core/models/instance_configuration_launch_instance_details.rb', line 512

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    availability_domain == other.availability_domain &&
    capacity_reservation_id == other.capacity_reservation_id &&
    compartment_id == other.compartment_id &&
    create_vnic_details == other.create_vnic_details &&
    defined_tags == other.defined_tags &&
    display_name == other.display_name &&
     == other. &&
    freeform_tags == other.freeform_tags &&
    ipxe_script == other.ipxe_script &&
     == other. &&
    shape == other.shape &&
    shape_config == other.shape_config &&
    platform_config == other.platform_config &&
    source_details == other.source_details &&
    fault_domain == other.fault_domain &&
    dedicated_vm_host_id == other.dedicated_vm_host_id &&
    launch_mode == other.launch_mode &&
    launch_options == other.launch_options &&
    agent_config == other.agent_config &&
    is_pv_encryption_in_transit_enabled == other.is_pv_encryption_in_transit_enabled &&
    preferred_maintenance_action == other.preferred_maintenance_action &&
    instance_options == other.instance_options &&
    availability_config == other.availability_config &&
    preemptible_instance_config == other.preemptible_instance_config
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
# File 'lib/oci/core/models/instance_configuration_launch_instance_details.rb', line 565

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


545
546
547
# File 'lib/oci/core/models/instance_configuration_launch_instance_details.rb', line 545

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



554
555
556
# File 'lib/oci/core/models/instance_configuration_launch_instance_details.rb', line 554

def hash
  [availability_domain, capacity_reservation_id, compartment_id, create_vnic_details, defined_tags, display_name, , freeform_tags, ipxe_script, , shape, shape_config, platform_config, source_details, fault_domain, dedicated_vm_host_id, launch_mode, launch_options, agent_config, is_pv_encryption_in_transit_enabled, preferred_maintenance_action, instance_options, availability_config, preemptible_instance_config].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



598
599
600
601
602
603
604
605
606
607
# File 'lib/oci/core/models/instance_configuration_launch_instance_details.rb', line 598

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



592
593
594
# File 'lib/oci/core/models/instance_configuration_launch_instance_details.rb', line 592

def to_s
  to_hash.to_s
end