Class: OCI::Core::Models::InstanceConfigurationLaunchInstanceShapeConfigDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/core/models/instance_configuration_launch_instance_shape_config_details.rb

Overview

The shape configuration requested for the instance.

If the parameter is provided, the instance is created with the resources that you specify. If some properties are missing or the entire parameter is not provided, the instance is created with the default configuration values for the `shape` that you specify.

Each shape only supports certain configurable values. If the values that you provide are not valid for the specified `shape`, an error is returned.

Constant Summary collapse

BASELINE_OCPU_UTILIZATION_ENUM =
[
  BASELINE_OCPU_UTILIZATION_BASELINE_1_8 = 'BASELINE_1_8'.freeze,
  BASELINE_OCPU_UTILIZATION_BASELINE_1_2 = 'BASELINE_1_2'.freeze,
  BASELINE_OCPU_UTILIZATION_BASELINE_1_1 = 'BASELINE_1_1'.freeze,
  BASELINE_OCPU_UTILIZATION_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ InstanceConfigurationLaunchInstanceShapeConfigDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :ocpus (Float)

    The value to assign to the #ocpus property

  • :memory_in_gbs (Float)

    The value to assign to the #memory_in_gbs property

  • :baseline_ocpu_utilization (String)

    The value to assign to the #baseline_ocpu_utilization property

  • :nvmes (Integer)

    The value to assign to the #nvmes property



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/oci/core/models/instance_configuration_launch_instance_shape_config_details.rb', line 87

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.ocpus = attributes[:'ocpus'] if attributes[:'ocpus']

  self.memory_in_gbs = attributes[:'memoryInGBs'] if attributes[:'memoryInGBs']

  raise 'You cannot provide both :memoryInGBs and :memory_in_gbs' if attributes.key?(:'memoryInGBs') && attributes.key?(:'memory_in_gbs')

  self.memory_in_gbs = attributes[:'memory_in_gbs'] if attributes[:'memory_in_gbs']

  self.baseline_ocpu_utilization = attributes[:'baselineOcpuUtilization'] if attributes[:'baselineOcpuUtilization']

  raise 'You cannot provide both :baselineOcpuUtilization and :baseline_ocpu_utilization' if attributes.key?(:'baselineOcpuUtilization') && attributes.key?(:'baseline_ocpu_utilization')

  self.baseline_ocpu_utilization = attributes[:'baseline_ocpu_utilization'] if attributes[:'baseline_ocpu_utilization']

  self.nvmes = attributes[:'nvmes'] if attributes[:'nvmes']
end

Instance Attribute Details

#baseline_ocpu_utilizationString

The baseline OCPU utilization for a subcore burstable VM instance. Leave this attribute blank for a non-burstable instance, or explicitly specify non-burstable with `BASELINE_1_1`.

The following values are supported:

  • `BASELINE_1_8` - baseline usage is 1/8 of an OCPU.

  • `BASELINE_1_2` - baseline usage is 1/2 of an OCPU.

  • `BASELINE_1_1` - baseline usage is an entire OCPU. This represents a non-burstable instance.

Returns:

  • (String)


46
47
48
# File 'lib/oci/core/models/instance_configuration_launch_instance_shape_config_details.rb', line 46

def baseline_ocpu_utilization
  @baseline_ocpu_utilization
end

#memory_in_gbsFloat

The total amount of memory available to the instance, in gigabytes.

Returns:

  • (Float)


35
36
37
# File 'lib/oci/core/models/instance_configuration_launch_instance_shape_config_details.rb', line 35

def memory_in_gbs
  @memory_in_gbs
end

#nvmesInteger

The number of NVMe drives to be used for storage. A single drive has 6.8 TB available.

Returns:

  • (Integer)


51
52
53
# File 'lib/oci/core/models/instance_configuration_launch_instance_shape_config_details.rb', line 51

def nvmes
  @nvmes
end

#ocpusFloat

The total number of OCPUs available to the instance.

Returns:

  • (Float)


30
31
32
# File 'lib/oci/core/models/instance_configuration_launch_instance_shape_config_details.rb', line 30

def ocpus
  @ocpus
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



54
55
56
57
58
59
60
61
62
63
# File 'lib/oci/core/models/instance_configuration_launch_instance_shape_config_details.rb', line 54

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'ocpus': :'ocpus',
    'memory_in_gbs': :'memoryInGBs',
    'baseline_ocpu_utilization': :'baselineOcpuUtilization',
    'nvmes': :'nvmes'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



66
67
68
69
70
71
72
73
74
75
# File 'lib/oci/core/models/instance_configuration_launch_instance_shape_config_details.rb', line 66

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'ocpus': :'Float',
    'memory_in_gbs': :'Float',
    'baseline_ocpu_utilization': :'String',
    'nvmes': :'Integer'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



130
131
132
133
134
135
136
137
138
# File 'lib/oci/core/models/instance_configuration_launch_instance_shape_config_details.rb', line 130

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    ocpus == other.ocpus &&
    memory_in_gbs == other.memory_in_gbs &&
    baseline_ocpu_utilization == other.baseline_ocpu_utilization &&
    nvmes == other.nvmes
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'lib/oci/core/models/instance_configuration_launch_instance_shape_config_details.rb', line 163

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


143
144
145
# File 'lib/oci/core/models/instance_configuration_launch_instance_shape_config_details.rb', line 143

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



152
153
154
# File 'lib/oci/core/models/instance_configuration_launch_instance_shape_config_details.rb', line 152

def hash
  [ocpus, memory_in_gbs, baseline_ocpu_utilization, nvmes].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



196
197
198
199
200
201
202
203
204
205
# File 'lib/oci/core/models/instance_configuration_launch_instance_shape_config_details.rb', line 196

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



190
191
192
# File 'lib/oci/core/models/instance_configuration_launch_instance_shape_config_details.rb', line 190

def to_s
  to_hash.to_s
end