Class: OCI::Core::Models::InstanceShapeConfig

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/core/models/instance_shape_config.rb

Overview

The shape configuration for an instance. The shape configuration determines the resources allocated to an instance.

Constant Summary collapse

BASELINE_OCPU_UTILIZATION_ENUM =
[
  BASELINE_OCPU_UTILIZATION_BASELINE_1_8 = 'BASELINE_1_8'.freeze,
  BASELINE_OCPU_UTILIZATION_BASELINE_1_2 = 'BASELINE_1_2'.freeze,
  BASELINE_OCPU_UTILIZATION_BASELINE_1_1 = 'BASELINE_1_1'.freeze,
  BASELINE_OCPU_UTILIZATION_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ InstanceShapeConfig

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/oci/core/models/instance_shape_config.rb', line 142

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.ocpus = attributes[:'ocpus'] if attributes[:'ocpus']

  self.memory_in_gbs = attributes[:'memoryInGBs'] if attributes[:'memoryInGBs']

  raise 'You cannot provide both :memoryInGBs and :memory_in_gbs' if attributes.key?(:'memoryInGBs') && attributes.key?(:'memory_in_gbs')

  self.memory_in_gbs = attributes[:'memory_in_gbs'] if attributes[:'memory_in_gbs']

  self.baseline_ocpu_utilization = attributes[:'baselineOcpuUtilization'] if attributes[:'baselineOcpuUtilization']

  raise 'You cannot provide both :baselineOcpuUtilization and :baseline_ocpu_utilization' if attributes.key?(:'baselineOcpuUtilization') && attributes.key?(:'baseline_ocpu_utilization')

  self.baseline_ocpu_utilization = attributes[:'baseline_ocpu_utilization'] if attributes[:'baseline_ocpu_utilization']

  self.processor_description = attributes[:'processorDescription'] if attributes[:'processorDescription']

  raise 'You cannot provide both :processorDescription and :processor_description' if attributes.key?(:'processorDescription') && attributes.key?(:'processor_description')

  self.processor_description = attributes[:'processor_description'] if attributes[:'processor_description']

  self.networking_bandwidth_in_gbps = attributes[:'networkingBandwidthInGbps'] if attributes[:'networkingBandwidthInGbps']

  raise 'You cannot provide both :networkingBandwidthInGbps and :networking_bandwidth_in_gbps' if attributes.key?(:'networkingBandwidthInGbps') && attributes.key?(:'networking_bandwidth_in_gbps')

  self.networking_bandwidth_in_gbps = attributes[:'networking_bandwidth_in_gbps'] if attributes[:'networking_bandwidth_in_gbps']

  self.max_vnic_attachments = attributes[:'maxVnicAttachments'] if attributes[:'maxVnicAttachments']

  raise 'You cannot provide both :maxVnicAttachments and :max_vnic_attachments' if attributes.key?(:'maxVnicAttachments') && attributes.key?(:'max_vnic_attachments')

  self.max_vnic_attachments = attributes[:'max_vnic_attachments'] if attributes[:'max_vnic_attachments']

  self.gpus = attributes[:'gpus'] if attributes[:'gpus']

  self.gpu_description = attributes[:'gpuDescription'] if attributes[:'gpuDescription']

  raise 'You cannot provide both :gpuDescription and :gpu_description' if attributes.key?(:'gpuDescription') && attributes.key?(:'gpu_description')

  self.gpu_description = attributes[:'gpu_description'] if attributes[:'gpu_description']

  self.local_disks = attributes[:'localDisks'] if attributes[:'localDisks']

  raise 'You cannot provide both :localDisks and :local_disks' if attributes.key?(:'localDisks') && attributes.key?(:'local_disks')

  self.local_disks = attributes[:'local_disks'] if attributes[:'local_disks']

  self.local_disks_total_size_in_gbs = attributes[:'localDisksTotalSizeInGBs'] if attributes[:'localDisksTotalSizeInGBs']

  raise 'You cannot provide both :localDisksTotalSizeInGBs and :local_disks_total_size_in_gbs' if attributes.key?(:'localDisksTotalSizeInGBs') && attributes.key?(:'local_disks_total_size_in_gbs')

  self.local_disks_total_size_in_gbs = attributes[:'local_disks_total_size_in_gbs'] if attributes[:'local_disks_total_size_in_gbs']

  self.local_disk_description = attributes[:'localDiskDescription'] if attributes[:'localDiskDescription']

  raise 'You cannot provide both :localDiskDescription and :local_disk_description' if attributes.key?(:'localDiskDescription') && attributes.key?(:'local_disk_description')

  self.local_disk_description = attributes[:'local_disk_description'] if attributes[:'local_disk_description']
end

Instance Attribute Details

#baseline_ocpu_utilizationString

The baseline OCPU utilization for a subcore burstable VM instance. Leave this attribute blank for a non-burstable instance, or explicitly specify non-burstable with BASELINE_1_1.

The following values are supported:

  • BASELINE_1_8 - baseline usage is 1/8 of an OCPU.

  • BASELINE_1_2 - baseline usage is 1/2 of an OCPU.

  • BASELINE_1_1 - baseline usage is the entire OCPU. This represents a non-burstable instance.

Returns:

  • (String)


39
40
41
# File 'lib/oci/core/models/instance_shape_config.rb', line 39

def baseline_ocpu_utilization
  @baseline_ocpu_utilization
end

#gpu_descriptionString

A short description of the instance’s graphics processing unit (GPU).

If the instance does not have any GPUs, this field is null.

Returns:

  • (String)


66
67
68
# File 'lib/oci/core/models/instance_shape_config.rb', line 66

def gpu_description
  @gpu_description
end

#gpusInteger

The number of GPUs available to the instance.

Returns:

  • (Integer)


59
60
61
# File 'lib/oci/core/models/instance_shape_config.rb', line 59

def gpus
  @gpus
end

#local_disk_descriptionString

A short description of the local disks available to this instance.

If the instance does not have any local disks, this field is null.

Returns:

  • (String)


85
86
87
# File 'lib/oci/core/models/instance_shape_config.rb', line 85

def local_disk_description
  @local_disk_description
end

#local_disksInteger

The number of local disks available to the instance.

Returns:

  • (Integer)


71
72
73
# File 'lib/oci/core/models/instance_shape_config.rb', line 71

def local_disks
  @local_disks
end

#local_disks_total_size_in_gbsFloat

The aggregate size of all local disks, in gigabytes.

If the instance does not have any local disks, this field is null.

Returns:

  • (Float)


78
79
80
# File 'lib/oci/core/models/instance_shape_config.rb', line 78

def local_disks_total_size_in_gbs
  @local_disks_total_size_in_gbs
end

#max_vnic_attachmentsInteger

The maximum number of VNIC attachments for the instance.

Returns:

  • (Integer)


54
55
56
# File 'lib/oci/core/models/instance_shape_config.rb', line 54

def max_vnic_attachments
  @max_vnic_attachments
end

#memory_in_gbsFloat

The total amount of memory available to the instance, in gigabytes.

Returns:

  • (Float)


28
29
30
# File 'lib/oci/core/models/instance_shape_config.rb', line 28

def memory_in_gbs
  @memory_in_gbs
end

#networking_bandwidth_in_gbpsFloat

The networking bandwidth available to the instance, in gigabits per second.

Returns:

  • (Float)


49
50
51
# File 'lib/oci/core/models/instance_shape_config.rb', line 49

def networking_bandwidth_in_gbps
  @networking_bandwidth_in_gbps
end

#ocpusFloat

The total number of OCPUs available to the instance.

Returns:

  • (Float)


23
24
25
# File 'lib/oci/core/models/instance_shape_config.rb', line 23

def ocpus
  @ocpus
end

#processor_descriptionString

A short description of the instance’s processor (CPU).

Returns:

  • (String)


44
45
46
# File 'lib/oci/core/models/instance_shape_config.rb', line 44

def processor_description
  @processor_description
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/oci/core/models/instance_shape_config.rb', line 88

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'ocpus': :'ocpus',
    'memory_in_gbs': :'memoryInGBs',
    'baseline_ocpu_utilization': :'baselineOcpuUtilization',
    'processor_description': :'processorDescription',
    'networking_bandwidth_in_gbps': :'networkingBandwidthInGbps',
    'max_vnic_attachments': :'maxVnicAttachments',
    'gpus': :'gpus',
    'gpu_description': :'gpuDescription',
    'local_disks': :'localDisks',
    'local_disks_total_size_in_gbs': :'localDisksTotalSizeInGBs',
    'local_disk_description': :'localDiskDescription'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/oci/core/models/instance_shape_config.rb', line 107

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'ocpus': :'Float',
    'memory_in_gbs': :'Float',
    'baseline_ocpu_utilization': :'String',
    'processor_description': :'String',
    'networking_bandwidth_in_gbps': :'Float',
    'max_vnic_attachments': :'Integer',
    'gpus': :'Integer',
    'gpu_description': :'String',
    'local_disks': :'Integer',
    'local_disks_total_size_in_gbs': :'Float',
    'local_disk_description': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/oci/core/models/instance_shape_config.rb', line 227

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    ocpus == other.ocpus &&
    memory_in_gbs == other.memory_in_gbs &&
    baseline_ocpu_utilization == other.baseline_ocpu_utilization &&
    processor_description == other.processor_description &&
    networking_bandwidth_in_gbps == other.networking_bandwidth_in_gbps &&
    max_vnic_attachments == other.max_vnic_attachments &&
    gpus == other.gpus &&
    gpu_description == other.gpu_description &&
    local_disks == other.local_disks &&
    local_disks_total_size_in_gbs == other.local_disks_total_size_in_gbs &&
    local_disk_description == other.local_disk_description
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
# File 'lib/oci/core/models/instance_shape_config.rb', line 267

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


247
248
249
# File 'lib/oci/core/models/instance_shape_config.rb', line 247

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



256
257
258
# File 'lib/oci/core/models/instance_shape_config.rb', line 256

def hash
  [ocpus, memory_in_gbs, baseline_ocpu_utilization, processor_description, networking_bandwidth_in_gbps, max_vnic_attachments, gpus, gpu_description, local_disks, local_disks_total_size_in_gbs, local_disk_description].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



300
301
302
303
304
305
306
307
308
309
# File 'lib/oci/core/models/instance_shape_config.rb', line 300

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



294
295
296
# File 'lib/oci/core/models/instance_shape_config.rb', line 294

def to_s
  to_hash.to_s
end