Class: OCI::Core::Models::InstanceSourceViaImageDetails

Inherits:
InstanceSourceDetails show all
Defined in:
lib/oci/core/models/instance_source_via_image_details.rb

Overview

InstanceSourceViaImageDetails model.

Instance Attribute Summary collapse

Attributes inherited from InstanceSourceDetails

#source_type

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from InstanceSourceDetails

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ InstanceSourceViaImageDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :boot_volume_size_in_gbs (Integer)

    The value to assign to the #boot_volume_size_in_gbs property

  • :image_id (String)

    The value to assign to the #image_id property

  • :kms_key_id (String)

    The value to assign to the #kms_key_id property

  • :boot_volume_vpus_per_gb (Integer)

    The value to assign to the #boot_volume_vpus_per_gb property



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/oci/core/models/instance_source_via_image_details.rb', line 77

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['sourceType'] = 'image'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.boot_volume_size_in_gbs = attributes[:'bootVolumeSizeInGBs'] if attributes[:'bootVolumeSizeInGBs']

  raise 'You cannot provide both :bootVolumeSizeInGBs and :boot_volume_size_in_gbs' if attributes.key?(:'bootVolumeSizeInGBs') && attributes.key?(:'boot_volume_size_in_gbs')

  self.boot_volume_size_in_gbs = attributes[:'boot_volume_size_in_gbs'] if attributes[:'boot_volume_size_in_gbs']

  self.image_id = attributes[:'imageId'] if attributes[:'imageId']

  raise 'You cannot provide both :imageId and :image_id' if attributes.key?(:'imageId') && attributes.key?(:'image_id')

  self.image_id = attributes[:'image_id'] if attributes[:'image_id']

  self.kms_key_id = attributes[:'kmsKeyId'] if attributes[:'kmsKeyId']

  raise 'You cannot provide both :kmsKeyId and :kms_key_id' if attributes.key?(:'kmsKeyId') && attributes.key?(:'kms_key_id')

  self.kms_key_id = attributes[:'kms_key_id'] if attributes[:'kms_key_id']

  self.boot_volume_vpus_per_gb = attributes[:'bootVolumeVpusPerGB'] if attributes[:'bootVolumeVpusPerGB']

  raise 'You cannot provide both :bootVolumeVpusPerGB and :boot_volume_vpus_per_gb' if attributes.key?(:'bootVolumeVpusPerGB') && attributes.key?(:'boot_volume_vpus_per_gb')

  self.boot_volume_vpus_per_gb = attributes[:'boot_volume_vpus_per_gb'] if attributes[:'boot_volume_vpus_per_gb']
end

Instance Attribute Details

#boot_volume_size_in_gbsInteger

The size of the boot volume in GBs. Minimum value is 50 GB and maximum value is 32,768 GB (32 TB).

Returns:

  • (Integer)


14
15
16
# File 'lib/oci/core/models/instance_source_via_image_details.rb', line 14

def boot_volume_size_in_gbs
  @boot_volume_size_in_gbs
end

#boot_volume_vpus_per_gbInteger

The number of volume performance units (VPUs) that will be applied to this volume per GB, representing the Block Volume service's elastic performance options. See [Block Volume Performance Levels](docs.cloud.oracle.com/iaas/Content/Block/Concepts/blockvolumeperformance.htm#perf_levels) for more information.

Allowed values:

* `10`: Represents Balanced option.

* `20`: Represents Higher Performance option.

* `30`-`120`: Represents the Ultra High Performance option.

For volumes with the auto-tuned performance feature enabled, this is set to the default (minimum) VPUs/GB.

Returns:

  • (Integer)


39
40
41
# File 'lib/oci/core/models/instance_source_via_image_details.rb', line 39

def boot_volume_vpus_per_gb
  @boot_volume_vpus_per_gb
end

#image_idString

**[Required]** The OCID of the image used to boot the instance.

Returns:

  • (String)


18
19
20
# File 'lib/oci/core/models/instance_source_via_image_details.rb', line 18

def image_id
  @image_id
end

#kms_key_idString

The OCID of the Key Management key to assign as the master encryption key for the boot volume.

Returns:

  • (String)


22
23
24
# File 'lib/oci/core/models/instance_source_via_image_details.rb', line 22

def kms_key_id
  @kms_key_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



42
43
44
45
46
47
48
49
50
51
52
# File 'lib/oci/core/models/instance_source_via_image_details.rb', line 42

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'source_type': :'sourceType',
    'boot_volume_size_in_gbs': :'bootVolumeSizeInGBs',
    'image_id': :'imageId',
    'kms_key_id': :'kmsKeyId',
    'boot_volume_vpus_per_gb': :'bootVolumeVpusPerGB'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
62
63
64
65
# File 'lib/oci/core/models/instance_source_via_image_details.rb', line 55

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'source_type': :'String',
    'boot_volume_size_in_gbs': :'Integer',
    'image_id': :'String',
    'kms_key_id': :'String',
    'boot_volume_vpus_per_gb': :'Integer'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



119
120
121
122
123
124
125
126
127
128
# File 'lib/oci/core/models/instance_source_via_image_details.rb', line 119

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    source_type == other.source_type &&
    boot_volume_size_in_gbs == other.boot_volume_size_in_gbs &&
    image_id == other.image_id &&
    kms_key_id == other.kms_key_id &&
    boot_volume_vpus_per_gb == other.boot_volume_vpus_per_gb
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/oci/core/models/instance_source_via_image_details.rb', line 153

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


133
134
135
# File 'lib/oci/core/models/instance_source_via_image_details.rb', line 133

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



142
143
144
# File 'lib/oci/core/models/instance_source_via_image_details.rb', line 142

def hash
  [source_type, boot_volume_size_in_gbs, image_id, kms_key_id, boot_volume_vpus_per_gb].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



186
187
188
189
190
191
192
193
194
195
# File 'lib/oci/core/models/instance_source_via_image_details.rb', line 186

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



180
181
182
# File 'lib/oci/core/models/instance_source_via_image_details.rb', line 180

def to_s
  to_hash.to_s
end