Class: OCI::Core::Models::Ipv6
- Inherits:
-
Object
- Object
- OCI::Core::Models::Ipv6
- Defined in:
- lib/oci/core/models/ipv6.rb
Overview
An IPv6 is a conceptual term that refers to an IPv6 address and related properties. The `IPv6` object is the API representation of an IPv6.
You can create and assign an IPv6 to any VNIC that is in an IPv6-enabled subnet in an IPv6-enabled VCN.
*Note:* IPv6 addressing is supported for all commercial and government regions. For important details about IPv6 addressing in a VCN, see [IPv6 Addresses](docs.cloud.oracle.com/iaas/Content/Network/Concepts/ipv6.htm).
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze, LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze, LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze, LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the IPv6.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
**[Required]** A user-friendly name.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the IPv6.
-
#ip_address ⇒ String
**[Required]** The IPv6 address of the `IPv6` object.
-
#lifecycle_state ⇒ String
**[Required]** The IPv6's current state.
-
#subnet_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the subnet the VNIC is in.
-
#time_created ⇒ DateTime
**[Required]** The date and time the IPv6 was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#vnic_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the VNIC the IPv6 is assigned to.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Ipv6
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Ipv6
Initializes the object
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/oci/core/models/ipv6.rb', line 140 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.id = attributes[:'id'] if attributes[:'id'] self.ip_address = attributes[:'ipAddress'] if attributes[:'ipAddress'] raise 'You cannot provide both :ipAddress and :ip_address' if attributes.key?(:'ipAddress') && attributes.key?(:'ip_address') self.ip_address = attributes[:'ip_address'] if attributes[:'ip_address'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId'] raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id') self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.vnic_id = attributes[:'vnicId'] if attributes[:'vnicId'] raise 'You cannot provide both :vnicId and :vnic_id' if attributes.key?(:'vnicId') && attributes.key?(:'vnic_id') self.vnic_id = attributes[:'vnic_id'] if attributes[:'vnic_id'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the IPv6. This is the same as the VNIC's compartment.
31 32 33 |
# File 'lib/oci/core/models/ipv6.rb', line 31 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: `{"CostCenter": "42"}`
39 40 41 |
# File 'lib/oci/core/models/ipv6.rb', line 39 def @defined_tags end |
#display_name ⇒ String
**[Required]** A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
45 46 47 |
# File 'lib/oci/core/models/ipv6.rb', line 45 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: `"Finance"`
53 54 55 |
# File 'lib/oci/core/models/ipv6.rb', line 53 def @freeform_tags end |
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the IPv6.
57 58 59 |
# File 'lib/oci/core/models/ipv6.rb', line 57 def id @id end |
#ip_address ⇒ String
**[Required]** The IPv6 address of the `IPv6` object. The address is within the IPv6 CIDR block of the VNIC's subnet (see the `ipv6CidrBlock` attribute for the Subnet object.
Example: `2001:0db8:0123:1111:abcd:ef01:2345:6789`
65 66 67 |
# File 'lib/oci/core/models/ipv6.rb', line 65 def ip_address @ip_address end |
#lifecycle_state ⇒ String
**[Required]** The IPv6's current state.
69 70 71 |
# File 'lib/oci/core/models/ipv6.rb', line 69 def lifecycle_state @lifecycle_state end |
#subnet_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the subnet the VNIC is in.
73 74 75 |
# File 'lib/oci/core/models/ipv6.rb', line 73 def subnet_id @subnet_id end |
#time_created ⇒ DateTime
**[Required]** The date and time the IPv6 was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Example: `2016-08-25T21:10:29.600Z`
80 81 82 |
# File 'lib/oci/core/models/ipv6.rb', line 80 def time_created @time_created end |
#vnic_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the VNIC the IPv6 is assigned to. The VNIC and IPv6 must be in the same subnet.
86 87 88 |
# File 'lib/oci/core/models/ipv6.rb', line 86 def vnic_id @vnic_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/oci/core/models/ipv6.rb', line 89 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'defined_tags': :'definedTags', 'display_name': :'displayName', 'freeform_tags': :'freeformTags', 'id': :'id', 'ip_address': :'ipAddress', 'lifecycle_state': :'lifecycleState', 'subnet_id': :'subnetId', 'time_created': :'timeCreated', 'vnic_id': :'vnicId' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/oci/core/models/ipv6.rb', line 107 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'freeform_tags': :'Hash<String, String>', 'id': :'String', 'ip_address': :'String', 'lifecycle_state': :'String', 'subnet_id': :'String', 'time_created': :'DateTime', 'vnic_id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/oci/core/models/ipv6.rb', line 223 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && == other. && display_name == other.display_name && == other. && id == other.id && ip_address == other.ip_address && lifecycle_state == other.lifecycle_state && subnet_id == other.subnet_id && time_created == other.time_created && vnic_id == other.vnic_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/oci/core/models/ipv6.rb', line 262 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
242 243 244 |
# File 'lib/oci/core/models/ipv6.rb', line 242 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
251 252 253 |
# File 'lib/oci/core/models/ipv6.rb', line 251 def hash [compartment_id, , display_name, , id, ip_address, lifecycle_state, subnet_id, time_created, vnic_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
295 296 297 298 299 300 301 302 303 304 |
# File 'lib/oci/core/models/ipv6.rb', line 295 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
289 290 291 |
# File 'lib/oci/core/models/ipv6.rb', line 289 def to_s to_hash.to_s end |