Class: OCI::Core::Models::LaunchInstancePlatformConfig
- Inherits:
-
Object
- Object
- OCI::Core::Models::LaunchInstancePlatformConfig
- Defined in:
- lib/oci/core/models/launch_instance_platform_config.rb
Overview
The platform configuration requested for the instance.
If you provide the parameter, the instance is created with the platform configuration that you specify. For any values that you omit, the instance uses the default configuration values for the `shape` that you specify. If you don't provide the parameter, the default values for the `shape` are used.
Each shape only supports certain configurable values. If the values that you provide are not valid for the specified `shape`, an error is returned.
For more information about shielded instances, see [Shielded Instances](docs.cloud.oracle.com/iaas/Content/Compute/References/shielded-instances.htm).
For more information about BIOS settings for bare metal instances, see [BIOS Settings for Bare Metal Instances](docs.cloud.oracle.com/iaas/Content/Compute/References/bios-settings.htm).
This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
AmdMilanBmLaunchInstancePlatformConfig, AmdRomeBmGpuLaunchInstancePlatformConfig, AmdRomeBmLaunchInstancePlatformConfig, AmdVmLaunchInstancePlatformConfig, IntelIcelakeBmLaunchInstancePlatformConfig, IntelSkylakeBmLaunchInstancePlatformConfig, IntelVmLaunchInstancePlatformConfig
Constant Summary collapse
- TYPE_ENUM =
[ TYPE_AMD_MILAN_BM = 'AMD_MILAN_BM'.freeze, TYPE_AMD_ROME_BM = 'AMD_ROME_BM'.freeze, TYPE_AMD_ROME_BM_GPU = 'AMD_ROME_BM_GPU'.freeze, TYPE_INTEL_ICELAKE_BM = 'INTEL_ICELAKE_BM'.freeze, TYPE_INTEL_SKYLAKE_BM = 'INTEL_SKYLAKE_BM'.freeze, TYPE_AMD_VM = 'AMD_VM'.freeze, TYPE_INTEL_VM = 'INTEL_VM'.freeze ].freeze
Instance Attribute Summary collapse
-
#is_measured_boot_enabled ⇒ BOOLEAN
Whether the Measured Boot feature is enabled on the instance.
-
#is_secure_boot_enabled ⇒ BOOLEAN
Whether Secure Boot is enabled on the instance.
-
#is_trusted_platform_module_enabled ⇒ BOOLEAN
Whether the Trusted Platform Module (TPM) is enabled on the instance.
-
#type ⇒ String
**[Required]** The type of platform being configured.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LaunchInstancePlatformConfig
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ LaunchInstancePlatformConfig
Initializes the object
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/oci/core/models/launch_instance_platform_config.rb', line 110 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.type = attributes[:'type'] if attributes[:'type'] self.is_secure_boot_enabled = attributes[:'isSecureBootEnabled'] unless attributes[:'isSecureBootEnabled'].nil? self.is_secure_boot_enabled = false if is_secure_boot_enabled.nil? && !attributes.key?(:'isSecureBootEnabled') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isSecureBootEnabled and :is_secure_boot_enabled' if attributes.key?(:'isSecureBootEnabled') && attributes.key?(:'is_secure_boot_enabled') self.is_secure_boot_enabled = attributes[:'is_secure_boot_enabled'] unless attributes[:'is_secure_boot_enabled'].nil? self.is_secure_boot_enabled = false if is_secure_boot_enabled.nil? && !attributes.key?(:'isSecureBootEnabled') && !attributes.key?(:'is_secure_boot_enabled') # rubocop:disable Style/StringLiterals self.is_trusted_platform_module_enabled = attributes[:'isTrustedPlatformModuleEnabled'] unless attributes[:'isTrustedPlatformModuleEnabled'].nil? self.is_trusted_platform_module_enabled = false if is_trusted_platform_module_enabled.nil? && !attributes.key?(:'isTrustedPlatformModuleEnabled') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isTrustedPlatformModuleEnabled and :is_trusted_platform_module_enabled' if attributes.key?(:'isTrustedPlatformModuleEnabled') && attributes.key?(:'is_trusted_platform_module_enabled') self.is_trusted_platform_module_enabled = attributes[:'is_trusted_platform_module_enabled'] unless attributes[:'is_trusted_platform_module_enabled'].nil? self.is_trusted_platform_module_enabled = false if is_trusted_platform_module_enabled.nil? && !attributes.key?(:'isTrustedPlatformModuleEnabled') && !attributes.key?(:'is_trusted_platform_module_enabled') # rubocop:disable Style/StringLiterals self.is_measured_boot_enabled = attributes[:'isMeasuredBootEnabled'] unless attributes[:'isMeasuredBootEnabled'].nil? self.is_measured_boot_enabled = false if is_measured_boot_enabled.nil? && !attributes.key?(:'isMeasuredBootEnabled') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isMeasuredBootEnabled and :is_measured_boot_enabled' if attributes.key?(:'isMeasuredBootEnabled') && attributes.key?(:'is_measured_boot_enabled') self.is_measured_boot_enabled = attributes[:'is_measured_boot_enabled'] unless attributes[:'is_measured_boot_enabled'].nil? self.is_measured_boot_enabled = false if is_measured_boot_enabled.nil? && !attributes.key?(:'isMeasuredBootEnabled') && !attributes.key?(:'is_measured_boot_enabled') # rubocop:disable Style/StringLiterals end |
Instance Attribute Details
#is_measured_boot_enabled ⇒ BOOLEAN
Whether the Measured Boot feature is enabled on the instance.
53 54 55 |
# File 'lib/oci/core/models/launch_instance_platform_config.rb', line 53 def is_measured_boot_enabled @is_measured_boot_enabled end |
#is_secure_boot_enabled ⇒ BOOLEAN
Whether Secure Boot is enabled on the instance.
43 44 45 |
# File 'lib/oci/core/models/launch_instance_platform_config.rb', line 43 def is_secure_boot_enabled @is_secure_boot_enabled end |
#is_trusted_platform_module_enabled ⇒ BOOLEAN
Whether the Trusted Platform Module (TPM) is enabled on the instance.
48 49 50 |
# File 'lib/oci/core/models/launch_instance_platform_config.rb', line 48 def is_trusted_platform_module_enabled @is_trusted_platform_module_enabled end |
#type ⇒ String
**[Required]** The type of platform being configured.
38 39 40 |
# File 'lib/oci/core/models/launch_instance_platform_config.rb', line 38 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
56 57 58 59 60 61 62 63 64 65 |
# File 'lib/oci/core/models/launch_instance_platform_config.rb', line 56 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'type': :'type', 'is_secure_boot_enabled': :'isSecureBootEnabled', 'is_trusted_platform_module_enabled': :'isTrustedPlatformModuleEnabled', 'is_measured_boot_enabled': :'isMeasuredBootEnabled' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/oci/core/models/launch_instance_platform_config.rb', line 84 def self.get_subtype(object_hash) type = object_hash[:'type'] # rubocop:disable Style/SymbolLiteral return 'OCI::Core::Models::AmdRomeBmGpuLaunchInstancePlatformConfig' if type == 'AMD_ROME_BM_GPU' return 'OCI::Core::Models::AmdRomeBmLaunchInstancePlatformConfig' if type == 'AMD_ROME_BM' return 'OCI::Core::Models::IntelIcelakeBmLaunchInstancePlatformConfig' if type == 'INTEL_ICELAKE_BM' return 'OCI::Core::Models::AmdVmLaunchInstancePlatformConfig' if type == 'AMD_VM' return 'OCI::Core::Models::IntelVmLaunchInstancePlatformConfig' if type == 'INTEL_VM' return 'OCI::Core::Models::IntelSkylakeBmLaunchInstancePlatformConfig' if type == 'INTEL_SKYLAKE_BM' return 'OCI::Core::Models::AmdMilanBmLaunchInstancePlatformConfig' if type == 'AMD_MILAN_BM' # TODO: Log a warning when the subtype is not found. 'OCI::Core::Models::LaunchInstancePlatformConfig' end |
.swagger_types ⇒ Object
Attribute type mapping.
68 69 70 71 72 73 74 75 76 77 |
# File 'lib/oci/core/models/launch_instance_platform_config.rb', line 68 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'type': :'String', 'is_secure_boot_enabled': :'BOOLEAN', 'is_trusted_platform_module_enabled': :'BOOLEAN', 'is_measured_boot_enabled': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
158 159 160 161 162 163 164 165 166 |
# File 'lib/oci/core/models/launch_instance_platform_config.rb', line 158 def ==(other) return true if equal?(other) self.class == other.class && type == other.type && is_secure_boot_enabled == other.is_secure_boot_enabled && is_trusted_platform_module_enabled == other.is_trusted_platform_module_enabled && is_measured_boot_enabled == other.is_measured_boot_enabled end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/oci/core/models/launch_instance_platform_config.rb', line 191 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
171 172 173 |
# File 'lib/oci/core/models/launch_instance_platform_config.rb', line 171 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
180 181 182 |
# File 'lib/oci/core/models/launch_instance_platform_config.rb', line 180 def hash [type, is_secure_boot_enabled, is_trusted_platform_module_enabled, is_measured_boot_enabled].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
224 225 226 227 228 229 230 231 232 233 |
# File 'lib/oci/core/models/launch_instance_platform_config.rb', line 224 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
218 219 220 |
# File 'lib/oci/core/models/launch_instance_platform_config.rb', line 218 def to_s to_hash.to_s end |