Class: OCI::Core::Models::LaunchOptions

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/core/models/launch_options.rb

Overview

Options for tuning compatibility and performance of VM shapes.

Constant Summary collapse

BOOT_VOLUME_TYPE_ENUM =

rubocop:disable Metrics/LineLength

[
  BOOT_VOLUME_TYPE_ISCSI = 'ISCSI'.freeze,
  BOOT_VOLUME_TYPE_SCSI = 'SCSI'.freeze,
  BOOT_VOLUME_TYPE_IDE = 'IDE'.freeze,
  BOOT_VOLUME_TYPE_VFIO = 'VFIO'.freeze,
  BOOT_VOLUME_TYPE_PARAVIRTUALIZED = 'PARAVIRTUALIZED'.freeze,
  BOOT_VOLUME_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
FIRMWARE_ENUM =
[
  FIRMWARE_BIOS = 'BIOS'.freeze,
  FIRMWARE_UEFI_64 = 'UEFI_64'.freeze,
  FIRMWARE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
NETWORK_TYPE_ENUM =
[
  NETWORK_TYPE_E1000 = 'E1000'.freeze,
  NETWORK_TYPE_VFIO = 'VFIO'.freeze,
  NETWORK_TYPE_PARAVIRTUALIZED = 'PARAVIRTUALIZED'.freeze,
  NETWORK_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
REMOTE_DATA_VOLUME_TYPE_ENUM =
[
  REMOTE_DATA_VOLUME_TYPE_ISCSI = 'ISCSI'.freeze,
  REMOTE_DATA_VOLUME_TYPE_SCSI = 'SCSI'.freeze,
  REMOTE_DATA_VOLUME_TYPE_IDE = 'IDE'.freeze,
  REMOTE_DATA_VOLUME_TYPE_VFIO = 'VFIO'.freeze,
  REMOTE_DATA_VOLUME_TYPE_PARAVIRTUALIZED = 'PARAVIRTUALIZED'.freeze,
  REMOTE_DATA_VOLUME_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ LaunchOptions

Initializes the object

Options Hash (attributes):

  • :boot_volume_type (String)

    The value to assign to the #boot_volume_type property

  • :firmware (String)

    The value to assign to the #firmware property

  • :network_type (String)

    The value to assign to the #network_type property

  • :remote_data_volume_type (String)

    The value to assign to the #remote_data_volume_type property

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
# File 'lib/oci/core/models/launch_options.rb', line 117

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.boot_volume_type = attributes[:'bootVolumeType'] if attributes[:'bootVolumeType']

  raise 'You cannot provide both :bootVolumeType and :boot_volume_type' if attributes.key?(:'bootVolumeType') && attributes.key?(:'boot_volume_type')

  self.boot_volume_type = attributes[:'boot_volume_type'] if attributes[:'boot_volume_type']

  self.firmware = attributes[:'firmware'] if attributes[:'firmware']

  self.network_type = attributes[:'networkType'] if attributes[:'networkType']

  raise 'You cannot provide both :networkType and :network_type' if attributes.key?(:'networkType') && attributes.key?(:'network_type')

  self.network_type = attributes[:'network_type'] if attributes[:'network_type']

  self.remote_data_volume_type = attributes[:'remoteDataVolumeType'] if attributes[:'remoteDataVolumeType']

  raise 'You cannot provide both :remoteDataVolumeType and :remote_data_volume_type' if attributes.key?(:'remoteDataVolumeType') && attributes.key?(:'remote_data_volume_type')

  self.remote_data_volume_type = attributes[:'remote_data_volume_type'] if attributes[:'remote_data_volume_type']
end

Instance Attribute Details

#boot_volume_typeString

[Required] Emulation type for volume.

  • ISCSI - ISCSI attached block storage device. This is the default for Boot Volumes and Remote Block

Storage volumes on Oracle provided images.

  • SCSI - Emulated SCSI disk.

  • IDE - Emulated IDE disk.

  • VFIO - Direct attached Virtual Function storage. This is the default option for Local data

volumes on Oracle provided images.

  • PARAVIRTUALIZED - Paravirtualized disk.

Returns:



52
53
54
# File 'lib/oci/core/models/launch_options.rb', line 52

def boot_volume_type
  @boot_volume_type
end

#firmwareString

[Required] Firmware used to boot VM. Select the option that matches your operating system.

  • BIOS - Boot VM using BIOS style firmware. This is compatible with both 32 bit and 64 bit operating

systems that boot using MBR style bootloaders.

  • UEFI_64 - Boot VM using UEFI style firmware compatible with 64 bit operating systems. This is the

default for Oracle provided images.

Returns:



61
62
63
# File 'lib/oci/core/models/launch_options.rb', line 61

def firmware
  @firmware
end

#network_typeString

[Required] Emulation type for NIC.

  • E1000 - Emulated Gigabit ethernet controller. Compatible with Linux e1000 network driver.

  • VFIO - Direct attached Virtual Function network controller. Default for Oracle provided images.

  • PARAVIRTUALIZED - VM instances launch with paravirtualized devices using virtio drivers.

Returns:



69
70
71
# File 'lib/oci/core/models/launch_options.rb', line 69

def network_type
  @network_type
end

#remote_data_volume_typeString

[Required] Emulation type for volume.

  • ISCSI - ISCSI attached block storage device. This is the default for Boot Volumes and Remote Block

Storage volumes on Oracle provided images.

  • SCSI - Emulated SCSI disk.

  • IDE - Emulated IDE disk.

  • VFIO - Direct attached Virtual Function storage. This is the default option for Local data

volumes on Oracle provided images.

  • PARAVIRTUALIZED - Paravirtualized disk.

Returns:



81
82
83
# File 'lib/oci/core/models/launch_options.rb', line 81

def remote_data_volume_type
  @remote_data_volume_type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



84
85
86
87
88
89
90
91
92
93
# File 'lib/oci/core/models/launch_options.rb', line 84

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'boot_volume_type': :'bootVolumeType',
    'firmware': :'firmware',
    'network_type': :'networkType',
    'remote_data_volume_type': :'remoteDataVolumeType'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



96
97
98
99
100
101
102
103
104
105
# File 'lib/oci/core/models/launch_options.rb', line 96

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'boot_volume_type': :'String',
    'firmware': :'String',
    'network_type': :'String',
    'remote_data_volume_type': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • the other object to be compared



211
212
213
214
215
216
217
218
219
# File 'lib/oci/core/models/launch_options.rb', line 211

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    boot_volume_type == other.boot_volume_type &&
    firmware == other.firmware &&
    network_type == other.network_type &&
    remote_data_volume_type == other.remote_data_volume_type
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
# File 'lib/oci/core/models/launch_options.rb', line 244

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method

Parameters:

  • the other object to be compared

Returns:



224
225
226
# File 'lib/oci/core/models/launch_options.rb', line 224

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • Hash code



233
234
235
# File 'lib/oci/core/models/launch_options.rb', line 233

def hash
  [boot_volume_type, firmware, network_type, remote_data_volume_type].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



277
278
279
280
281
282
283
284
285
286
# File 'lib/oci/core/models/launch_options.rb', line 277

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



271
272
273
# File 'lib/oci/core/models/launch_options.rb', line 271

def to_s
  to_hash.to_s
end