Class: OCI::Core::Models::MacsecKey
- Inherits:
-
Object
- Object
- OCI::Core::Models::MacsecKey
- Defined in:
- lib/oci/core/models/macsec_key.rb
Overview
An object defining the Secrets-in-Vault OCIDs representing the MACsec key.
Instance Attribute Summary collapse
-
#connectivity_association_key_secret_id ⇒ String
[Required] Secret [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) containing the Connectivity Association Key (CAK) of this MACsec key.
-
#connectivity_association_key_secret_version ⇒ Integer
The secret version of the
connectivityAssociationKeysecret in Vault. -
#connectivity_association_name_secret_id ⇒ String
[Required] Secret [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) containing the Connectivity association Key Name (CKN) of this MACsec key.
-
#connectivity_association_name_secret_version ⇒ Integer
The secret version of the connectivity association name secret in Vault.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MacsecKey
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ MacsecKey
Initializes the object
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/oci/core/models/macsec_key.rb', line 60 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.connectivity_association_name_secret_id = attributes[:'connectivityAssociationNameSecretId'] if attributes[:'connectivityAssociationNameSecretId'] raise 'You cannot provide both :connectivityAssociationNameSecretId and :connectivity_association_name_secret_id' if attributes.key?(:'connectivityAssociationNameSecretId') && attributes.key?(:'connectivity_association_name_secret_id') self.connectivity_association_name_secret_id = attributes[:'connectivity_association_name_secret_id'] if attributes[:'connectivity_association_name_secret_id'] self.connectivity_association_name_secret_version = attributes[:'connectivityAssociationNameSecretVersion'] if attributes[:'connectivityAssociationNameSecretVersion'] raise 'You cannot provide both :connectivityAssociationNameSecretVersion and :connectivity_association_name_secret_version' if attributes.key?(:'connectivityAssociationNameSecretVersion') && attributes.key?(:'connectivity_association_name_secret_version') self.connectivity_association_name_secret_version = attributes[:'connectivity_association_name_secret_version'] if attributes[:'connectivity_association_name_secret_version'] self.connectivity_association_key_secret_id = attributes[:'connectivityAssociationKeySecretId'] if attributes[:'connectivityAssociationKeySecretId'] raise 'You cannot provide both :connectivityAssociationKeySecretId and :connectivity_association_key_secret_id' if attributes.key?(:'connectivityAssociationKeySecretId') && attributes.key?(:'connectivity_association_key_secret_id') self.connectivity_association_key_secret_id = attributes[:'connectivity_association_key_secret_id'] if attributes[:'connectivity_association_key_secret_id'] self.connectivity_association_key_secret_version = attributes[:'connectivityAssociationKeySecretVersion'] if attributes[:'connectivityAssociationKeySecretVersion'] raise 'You cannot provide both :connectivityAssociationKeySecretVersion and :connectivity_association_key_secret_version' if attributes.key?(:'connectivityAssociationKeySecretVersion') && attributes.key?(:'connectivity_association_key_secret_version') self.connectivity_association_key_secret_version = attributes[:'connectivity_association_key_secret_version'] if attributes[:'connectivity_association_key_secret_version'] end |
Instance Attribute Details
#connectivity_association_key_secret_id ⇒ String
[Required] Secret [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) containing the Connectivity Association Key (CAK) of this MACsec key.
20 21 22 |
# File 'lib/oci/core/models/macsec_key.rb', line 20 def connectivity_association_key_secret_id @connectivity_association_key_secret_id end |
#connectivity_association_key_secret_version ⇒ Integer
The secret version of the connectivityAssociationKey secret in Vault.
24 25 26 |
# File 'lib/oci/core/models/macsec_key.rb', line 24 def connectivity_association_key_secret_version @connectivity_association_key_secret_version end |
#connectivity_association_name_secret_id ⇒ String
[Required] Secret [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) containing the Connectivity association Key Name (CKN) of this MACsec key.
12 13 14 |
# File 'lib/oci/core/models/macsec_key.rb', line 12 def connectivity_association_name_secret_id @connectivity_association_name_secret_id end |
#connectivity_association_name_secret_version ⇒ Integer
The secret version of the connectivity association name secret in Vault.
16 17 18 |
# File 'lib/oci/core/models/macsec_key.rb', line 16 def connectivity_association_name_secret_version @connectivity_association_name_secret_version end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
27 28 29 30 31 32 33 34 35 36 |
# File 'lib/oci/core/models/macsec_key.rb', line 27 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'connectivity_association_name_secret_id': :'connectivityAssociationNameSecretId', 'connectivity_association_name_secret_version': :'connectivityAssociationNameSecretVersion', 'connectivity_association_key_secret_id': :'connectivityAssociationKeySecretId', 'connectivity_association_key_secret_version': :'connectivityAssociationKeySecretVersion' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
39 40 41 42 43 44 45 46 47 48 |
# File 'lib/oci/core/models/macsec_key.rb', line 39 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'connectivity_association_name_secret_id': :'String', 'connectivity_association_name_secret_version': :'Integer', 'connectivity_association_key_secret_id': :'String', 'connectivity_association_key_secret_version': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
98 99 100 101 102 103 104 105 106 |
# File 'lib/oci/core/models/macsec_key.rb', line 98 def ==(other) return true if equal?(other) self.class == other.class && connectivity_association_name_secret_id == other.connectivity_association_name_secret_id && connectivity_association_name_secret_version == other.connectivity_association_name_secret_version && connectivity_association_key_secret_id == other.connectivity_association_key_secret_id && connectivity_association_key_secret_version == other.connectivity_association_key_secret_version end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/oci/core/models/macsec_key.rb', line 131 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
111 112 113 |
# File 'lib/oci/core/models/macsec_key.rb', line 111 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
120 121 122 |
# File 'lib/oci/core/models/macsec_key.rb', line 120 def hash [connectivity_association_name_secret_id, connectivity_association_name_secret_version, connectivity_association_key_secret_id, connectivity_association_key_secret_version].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
164 165 166 167 168 169 170 171 172 173 |
# File 'lib/oci/core/models/macsec_key.rb', line 164 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
158 159 160 |
# File 'lib/oci/core/models/macsec_key.rb', line 158 def to_s to_hash.to_s end |