Class: OCI::Core::Models::MeasuredBootEntry
- Inherits:
-
Object
- Object
- OCI::Core::Models::MeasuredBootEntry
- Defined in:
- lib/oci/core/models/measured_boot_entry.rb
Overview
One Trusted Platform Module (TPM) Platform Configuration Register (PCR) entry. The entry might be measured during boot, or specified in a policy.
Instance Attribute Summary collapse
-
#hash_algorithm ⇒ String
The type of algorithm used to calculate the hash.
-
#pcr_index ⇒ String
The index of the policy.
-
#value ⇒ String
The hashed PCR value.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MeasuredBootEntry
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ MeasuredBootEntry
Initializes the object
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/oci/core/models/measured_boot_entry.rb', line 55 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.pcr_index = attributes[:'pcrIndex'] if attributes[:'pcrIndex'] raise 'You cannot provide both :pcrIndex and :pcr_index' if attributes.key?(:'pcrIndex') && attributes.key?(:'pcr_index') self.pcr_index = attributes[:'pcr_index'] if attributes[:'pcr_index'] self.value = attributes[:'value'] if attributes[:'value'] self.hash_algorithm = attributes[:'hashAlgorithm'] if attributes[:'hashAlgorithm'] raise 'You cannot provide both :hashAlgorithm and :hash_algorithm' if attributes.key?(:'hashAlgorithm') && attributes.key?(:'hash_algorithm') self.hash_algorithm = attributes[:'hash_algorithm'] if attributes[:'hash_algorithm'] end |
Instance Attribute Details
#hash_algorithm ⇒ String
The type of algorithm used to calculate the hash.
22 23 24 |
# File 'lib/oci/core/models/measured_boot_entry.rb', line 22 def hash_algorithm @hash_algorithm end |
#pcr_index ⇒ String
The index of the policy.
14 15 16 |
# File 'lib/oci/core/models/measured_boot_entry.rb', line 14 def pcr_index @pcr_index end |
#value ⇒ String
The hashed PCR value.
18 19 20 |
# File 'lib/oci/core/models/measured_boot_entry.rb', line 18 def value @value end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
25 26 27 28 29 30 31 32 33 |
# File 'lib/oci/core/models/measured_boot_entry.rb', line 25 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'pcr_index': :'pcrIndex', 'value': :'value', 'hash_algorithm': :'hashAlgorithm' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
36 37 38 39 40 41 42 43 44 |
# File 'lib/oci/core/models/measured_boot_entry.rb', line 36 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'pcr_index': :'String', 'value': :'String', 'hash_algorithm': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
83 84 85 86 87 88 89 90 |
# File 'lib/oci/core/models/measured_boot_entry.rb', line 83 def ==(other) return true if equal?(other) self.class == other.class && pcr_index == other.pcr_index && value == other.value && hash_algorithm == other.hash_algorithm end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/oci/core/models/measured_boot_entry.rb', line 115 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
95 96 97 |
# File 'lib/oci/core/models/measured_boot_entry.rb', line 95 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
104 105 106 |
# File 'lib/oci/core/models/measured_boot_entry.rb', line 104 def hash [pcr_index, value, hash_algorithm].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
148 149 150 151 152 153 154 155 156 157 |
# File 'lib/oci/core/models/measured_boot_entry.rb', line 148 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
142 143 144 |
# File 'lib/oci/core/models/measured_boot_entry.rb', line 142 def to_s to_hash.to_s end |