Class: OCI::Core::Models::MultipathDevice
- Inherits:
-
Object
- Object
- OCI::Core::Models::MultipathDevice
- Defined in:
- lib/oci/core/models/multipath_device.rb
Overview
Secondary multipath device, it uses the charUsername and chapSecret from primary volume attachment
Instance Attribute Summary collapse
-
#ipv4 ⇒ String
[Required] The volume’s iSCSI IP address.
-
#iqn ⇒ String
[Required] The target volume’s iSCSI Qualified Name in the format defined by [RFC 3720](tools.ietf.org/html/rfc3720#page-32).
-
#port ⇒ Integer
The volume’s iSCSI port, usually port 860 or 3260.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MultipathDevice
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ MultipathDevice
Initializes the object
63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/oci/core/models/multipath_device.rb', line 63 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.ipv4 = attributes[:'ipv4'] if attributes[:'ipv4'] self.iqn = attributes[:'iqn'] if attributes[:'iqn'] self.port = attributes[:'port'] if attributes[:'port'] end |
Instance Attribute Details
#ipv4 ⇒ String
[Required] The volume’s iSCSI IP address.
Example: 169.254.2.2
15 16 17 |
# File 'lib/oci/core/models/multipath_device.rb', line 15 def ipv4 @ipv4 end |
#iqn ⇒ String
[Required] The target volume’s iSCSI Qualified Name in the format defined by [RFC 3720](tools.ietf.org/html/rfc3720#page-32).
Example: iqn.2015-12.com.oracleiaas:40b7ee03-883f-46c6-a951-63d2841d2195
23 24 25 |
# File 'lib/oci/core/models/multipath_device.rb', line 23 def iqn @iqn end |
#port ⇒ Integer
The volume’s iSCSI port, usually port 860 or 3260.
Example: 3260
30 31 32 |
# File 'lib/oci/core/models/multipath_device.rb', line 30 def port @port end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 41 |
# File 'lib/oci/core/models/multipath_device.rb', line 33 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'ipv4': :'ipv4', 'iqn': :'iqn', 'port': :'port' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
44 45 46 47 48 49 50 51 52 |
# File 'lib/oci/core/models/multipath_device.rb', line 44 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'ipv4': :'String', 'iqn': :'String', 'port': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
83 84 85 86 87 88 89 90 |
# File 'lib/oci/core/models/multipath_device.rb', line 83 def ==(other) return true if equal?(other) self.class == other.class && ipv4 == other.ipv4 && iqn == other.iqn && port == other.port end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/oci/core/models/multipath_device.rb', line 115 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
95 96 97 |
# File 'lib/oci/core/models/multipath_device.rb', line 95 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
104 105 106 |
# File 'lib/oci/core/models/multipath_device.rb', line 104 def hash [ipv4, iqn, port].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
148 149 150 151 152 153 154 155 156 157 |
# File 'lib/oci/core/models/multipath_device.rb', line 148 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
142 143 144 |
# File 'lib/oci/core/models/multipath_device.rb', line 142 def to_s to_hash.to_s end |