Class: OCI::Core::Models::NetworkSecurityGroup
- Inherits:
-
Object
- Object
- OCI::Core::Models::NetworkSecurityGroup
- Defined in:
- lib/oci/core/models/network_security_group.rb
Overview
A *network security group* (NSG) provides virtual firewall rules for a specific set of Vnic in a VCN. Compare NSGs with SecurityList, which provide virtual firewall rules to all the VNICs in a subnet.
A network security group consists of two items:
* The set of {Vnic} that all have the same security rule needs (for
example, a group of Compute instances all running the same application)
* A set of NSG {SecurityRule} that apply to the VNICs in the group
After creating an NSG, you can add VNICs and security rules to it. For example, when you create an instance, you can specify one or more NSGs to add the instance to (see create_vnic_details). Or you can add an existing instance to an NSG with update_vnic.
To add security rules to an NSG, see add_network_security_group_security_rules.
To list the VNICs in an NSG, see list_network_security_group_vnics.
To list the security rules in an NSG, see list_network_security_group_security_rules.
For more information about network security groups, see [Network Security Groups](docs.cloud.oracle.com/iaas/Content/Network/Concepts/networksecuritygroups.htm).
Important: Oracle Cloud Infrastructure Compute service images automatically include firewall rules (for example, Linux iptables, Windows firewall). If there are issues with some type of access to an instance, make sure all of the following are set correctly:
* Any security rules in any NSGs the instance's VNIC belongs to
* Any {SecurityList} associated with the instance's subnet
* The instance's OS firewall rules
To use any of the API operations, you must be authorized in an IAM policy. If you’re not authorized, talk to an administrator. If you’re an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/iaas/Content/Identity/Concepts/policygetstarted.htm).
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze, LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze, LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze, LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment the network security group is in.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
A user-friendly name.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the network security group.
-
#lifecycle_state ⇒ String
[Required] The network security group’s current state.
-
#time_created ⇒ DateTime
[Required] The date and time the network security group was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#vcn_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the network security group’s VCN.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NetworkSecurityGroup
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ NetworkSecurityGroup
Initializes the object
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/oci/core/models/network_security_group.rb', line 149 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.id = attributes[:'id'] if attributes[:'id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.vcn_id = attributes[:'vcnId'] if attributes[:'vcnId'] raise 'You cannot provide both :vcnId and :vcn_id' if attributes.key?(:'vcnId') && attributes.key?(:'vcn_id') self.vcn_id = attributes[:'vcn_id'] if attributes[:'vcn_id'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment the network security group is in.
60 61 62 |
# File 'lib/oci/core/models/network_security_group.rb', line 60 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
68 69 70 |
# File 'lib/oci/core/models/network_security_group.rb', line 68 def end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
74 75 76 |
# File 'lib/oci/core/models/network_security_group.rb', line 74 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
82 83 84 |
# File 'lib/oci/core/models/network_security_group.rb', line 82 def end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the network security group.
86 87 88 |
# File 'lib/oci/core/models/network_security_group.rb', line 86 def id @id end |
#lifecycle_state ⇒ String
[Required] The network security group’s current state.
90 91 92 |
# File 'lib/oci/core/models/network_security_group.rb', line 90 def lifecycle_state @lifecycle_state end |
#time_created ⇒ DateTime
[Required] The date and time the network security group was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Example: 2016-08-25T21:10:29.600Z
97 98 99 |
# File 'lib/oci/core/models/network_security_group.rb', line 97 def time_created @time_created end |
#vcn_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the network security group’s VCN.
101 102 103 |
# File 'lib/oci/core/models/network_security_group.rb', line 101 def vcn_id @vcn_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/oci/core/models/network_security_group.rb', line 104 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'defined_tags': :'definedTags', 'display_name': :'displayName', 'freeform_tags': :'freeformTags', 'id': :'id', 'lifecycle_state': :'lifecycleState', 'time_created': :'timeCreated', 'vcn_id': :'vcnId' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/oci/core/models/network_security_group.rb', line 120 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'freeform_tags': :'Hash<String, String>', 'id': :'String', 'lifecycle_state': :'String', 'time_created': :'DateTime', 'vcn_id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/oci/core/models/network_security_group.rb', line 220 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && == other. && display_name == other.display_name && == other. && id == other.id && lifecycle_state == other.lifecycle_state && time_created == other.time_created && vcn_id == other.vcn_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/oci/core/models/network_security_group.rb', line 257 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
237 238 239 |
# File 'lib/oci/core/models/network_security_group.rb', line 237 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
246 247 248 |
# File 'lib/oci/core/models/network_security_group.rb', line 246 def hash [compartment_id, , display_name, , id, lifecycle_state, time_created, vcn_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
290 291 292 293 294 295 296 297 298 299 |
# File 'lib/oci/core/models/network_security_group.rb', line 290 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
284 285 286 |
# File 'lib/oci/core/models/network_security_group.rb', line 284 def to_s to_hash.to_s end |