Class: OCI::Core::Models::RemotePeeringConnection
- Inherits:
-
Object
- Object
- OCI::Core::Models::RemotePeeringConnection
- Defined in:
- lib/oci/core/models/remote_peering_connection.rb
Overview
A remote peering connection (RPC) is an object on a DRG that lets the VCN that is attached to the DRG peer with a VCN in a different region. Peering means that the two VCNs can communicate using private IP addresses, but without the traffic traversing the internet or routing through your on-premises network. For more information, see [VCN Peering](docs.cloud.oracle.com/iaas/Content/Network/Tasks/VCNpeering.htm).
To use any of the API operations, you must be authorized in an IAM policy. If you’re not authorized, talk to an administrator. If you’re an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/iaas/Content/Identity/Concepts/policygetstarted.htm).
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze, LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze, LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze, LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- PEERING_STATUS_ENUM =
[ PEERING_STATUS_INVALID = 'INVALID'.freeze, PEERING_STATUS_NEW = 'NEW'.freeze, PEERING_STATUS_PENDING = 'PENDING'.freeze, PEERING_STATUS_PEERED = 'PEERED'.freeze, PEERING_STATUS_REVOKED = 'REVOKED'.freeze, PEERING_STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment that contains the RPC.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
[Required] A user-friendly name.
-
#drg_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the DRG that this RPC belongs to.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the RPC.
-
#is_cross_tenancy_peering ⇒ BOOLEAN
[Required] Whether the VCN at the other end of the peering is in a different tenancy.
-
#lifecycle_state ⇒ String
[Required] The RPC’s current lifecycle state.
-
#peer_id ⇒ String
If this RPC is peered, this value is the [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the other RPC.
-
#peer_region_name ⇒ String
If this RPC is peered, this value is the region that contains the other RPC.
-
#peer_tenancy_id ⇒ String
If this RPC is peered, this value is the [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the other RPC’s tenancy.
-
#peering_status ⇒ String
[Required] Whether the RPC is peered with another RPC.
-
#time_created ⇒ DateTime
[Required] The date and time the RPC was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RemotePeeringConnection
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ RemotePeeringConnection
Initializes the object
174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/oci/core/models/remote_peering_connection.rb', line 174 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.drg_id = attributes[:'drgId'] if attributes[:'drgId'] raise 'You cannot provide both :drgId and :drg_id' if attributes.key?(:'drgId') && attributes.key?(:'drg_id') self.drg_id = attributes[:'drg_id'] if attributes[:'drg_id'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.id = attributes[:'id'] if attributes[:'id'] self.is_cross_tenancy_peering = attributes[:'isCrossTenancyPeering'] unless attributes[:'isCrossTenancyPeering'].nil? raise 'You cannot provide both :isCrossTenancyPeering and :is_cross_tenancy_peering' if attributes.key?(:'isCrossTenancyPeering') && attributes.key?(:'is_cross_tenancy_peering') self.is_cross_tenancy_peering = attributes[:'is_cross_tenancy_peering'] unless attributes[:'is_cross_tenancy_peering'].nil? self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.peer_id = attributes[:'peerId'] if attributes[:'peerId'] raise 'You cannot provide both :peerId and :peer_id' if attributes.key?(:'peerId') && attributes.key?(:'peer_id') self.peer_id = attributes[:'peer_id'] if attributes[:'peer_id'] self.peer_region_name = attributes[:'peerRegionName'] if attributes[:'peerRegionName'] raise 'You cannot provide both :peerRegionName and :peer_region_name' if attributes.key?(:'peerRegionName') && attributes.key?(:'peer_region_name') self.peer_region_name = attributes[:'peer_region_name'] if attributes[:'peer_region_name'] self.peer_tenancy_id = attributes[:'peerTenancyId'] if attributes[:'peerTenancyId'] raise 'You cannot provide both :peerTenancyId and :peer_tenancy_id' if attributes.key?(:'peerTenancyId') && attributes.key?(:'peer_tenancy_id') self.peer_tenancy_id = attributes[:'peer_tenancy_id'] if attributes[:'peer_tenancy_id'] self.peering_status = attributes[:'peeringStatus'] if attributes[:'peeringStatus'] raise 'You cannot provide both :peeringStatus and :peering_status' if attributes.key?(:'peeringStatus') && attributes.key?(:'peering_status') self.peering_status = attributes[:'peering_status'] if attributes[:'peering_status'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment that contains the RPC.
39 40 41 |
# File 'lib/oci/core/models/remote_peering_connection.rb', line 39 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
47 48 49 |
# File 'lib/oci/core/models/remote_peering_connection.rb', line 47 def @defined_tags end |
#display_name ⇒ String
[Required] A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
53 54 55 |
# File 'lib/oci/core/models/remote_peering_connection.rb', line 53 def display_name @display_name end |
#drg_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the DRG that this RPC belongs to.
57 58 59 |
# File 'lib/oci/core/models/remote_peering_connection.rb', line 57 def drg_id @drg_id end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
65 66 67 |
# File 'lib/oci/core/models/remote_peering_connection.rb', line 65 def @freeform_tags end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the RPC.
69 70 71 |
# File 'lib/oci/core/models/remote_peering_connection.rb', line 69 def id @id end |
#is_cross_tenancy_peering ⇒ BOOLEAN
[Required] Whether the VCN at the other end of the peering is in a different tenancy.
Example: false
76 77 78 |
# File 'lib/oci/core/models/remote_peering_connection.rb', line 76 def is_cross_tenancy_peering @is_cross_tenancy_peering end |
#lifecycle_state ⇒ String
[Required] The RPC’s current lifecycle state.
80 81 82 |
# File 'lib/oci/core/models/remote_peering_connection.rb', line 80 def lifecycle_state @lifecycle_state end |
#peer_id ⇒ String
If this RPC is peered, this value is the [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the other RPC.
85 86 87 |
# File 'lib/oci/core/models/remote_peering_connection.rb', line 85 def peer_id @peer_id end |
#peer_region_name ⇒ String
If this RPC is peered, this value is the region that contains the other RPC.
Example: us-ashburn-1
92 93 94 |
# File 'lib/oci/core/models/remote_peering_connection.rb', line 92 def peer_region_name @peer_region_name end |
#peer_tenancy_id ⇒ String
If this RPC is peered, this value is the [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the other RPC’s tenancy.
97 98 99 |
# File 'lib/oci/core/models/remote_peering_connection.rb', line 97 def peer_tenancy_id @peer_tenancy_id end |
#peering_status ⇒ String
[Required] Whether the RPC is peered with another RPC. NEW means the RPC has not yet been peered. PENDING means the peering is being established. REVOKED means the RPC at the other end of the peering has been deleted.
104 105 106 |
# File 'lib/oci/core/models/remote_peering_connection.rb', line 104 def peering_status @peering_status end |
#time_created ⇒ DateTime
[Required] The date and time the RPC was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Example: 2016-08-25T21:10:29.600Z
111 112 113 |
# File 'lib/oci/core/models/remote_peering_connection.rb', line 111 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/oci/core/models/remote_peering_connection.rb', line 114 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'defined_tags': :'definedTags', 'display_name': :'displayName', 'drg_id': :'drgId', 'freeform_tags': :'freeformTags', 'id': :'id', 'is_cross_tenancy_peering': :'isCrossTenancyPeering', 'lifecycle_state': :'lifecycleState', 'peer_id': :'peerId', 'peer_region_name': :'peerRegionName', 'peer_tenancy_id': :'peerTenancyId', 'peering_status': :'peeringStatus', 'time_created': :'timeCreated' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/oci/core/models/remote_peering_connection.rb', line 135 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'drg_id': :'String', 'freeform_tags': :'Hash<String, String>', 'id': :'String', 'is_cross_tenancy_peering': :'BOOLEAN', 'lifecycle_state': :'String', 'peer_id': :'String', 'peer_region_name': :'String', 'peer_tenancy_id': :'String', 'peering_status': :'String', 'time_created': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'lib/oci/core/models/remote_peering_connection.rb', line 288 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && == other. && display_name == other.display_name && drg_id == other.drg_id && == other. && id == other.id && is_cross_tenancy_peering == other.is_cross_tenancy_peering && lifecycle_state == other.lifecycle_state && peer_id == other.peer_id && peer_region_name == other.peer_region_name && peer_tenancy_id == other.peer_tenancy_id && peering_status == other.peering_status && time_created == other.time_created end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 |
# File 'lib/oci/core/models/remote_peering_connection.rb', line 330 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
310 311 312 |
# File 'lib/oci/core/models/remote_peering_connection.rb', line 310 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
319 320 321 |
# File 'lib/oci/core/models/remote_peering_connection.rb', line 319 def hash [compartment_id, , display_name, drg_id, , id, is_cross_tenancy_peering, lifecycle_state, peer_id, peer_region_name, peer_tenancy_id, peering_status, time_created].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
363 364 365 366 367 368 369 370 371 372 |
# File 'lib/oci/core/models/remote_peering_connection.rb', line 363 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
357 358 359 |
# File 'lib/oci/core/models/remote_peering_connection.rb', line 357 def to_s to_hash.to_s end |