Class: OCI::Core::Models::RemoveVcnIpv6CidrDetails
- Inherits:
-
Object
- Object
- OCI::Core::Models::RemoveVcnIpv6CidrDetails
- Defined in:
- lib/oci/core/models/remove_vcn_ipv6_cidr_details.rb
Overview
Details used when removing ULA or private IPv6 prefix or an IPv6 GUA assigned by Oracle or BYOIPv6 prefix. You can only remove one of these per request.
Instance Attribute Summary collapse
-
#ipv6_cidr_block ⇒ String
This field is not required and should only be specified when removing ULA or private IPv6 prefix or an IPv6 GUA assigned by Oracle or BYOIPv6 prefix from a VCN's IPv6 address space.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RemoveVcnIpv6CidrDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ RemoveVcnIpv6CidrDetails
Initializes the object
45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/oci/core/models/remove_vcn_ipv6_cidr_details.rb', line 45 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.ipv6_cidr_block = attributes[:'ipv6CidrBlock'] if attributes[:'ipv6CidrBlock'] raise 'You cannot provide both :ipv6CidrBlock and :ipv6_cidr_block' if attributes.key?(:'ipv6CidrBlock') && attributes.key?(:'ipv6_cidr_block') self.ipv6_cidr_block = attributes[:'ipv6_cidr_block'] if attributes[:'ipv6_cidr_block'] end |
Instance Attribute Details
#ipv6_cidr_block ⇒ String
This field is not required and should only be specified when removing ULA or private IPv6 prefix or an IPv6 GUA assigned by Oracle or BYOIPv6 prefix from a VCN's IPv6 address space. See[IPv6 Addresses](docs.cloud.oracle.com/iaas/Content/Network/Concepts/ipv6.htm).
Example: `2001:0db8:0123::/56`
18 19 20 |
# File 'lib/oci/core/models/remove_vcn_ipv6_cidr_details.rb', line 18 def ipv6_cidr_block @ipv6_cidr_block end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
21 22 23 24 25 26 27 |
# File 'lib/oci/core/models/remove_vcn_ipv6_cidr_details.rb', line 21 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'ipv6_cidr_block': :'ipv6CidrBlock' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
30 31 32 33 34 35 36 |
# File 'lib/oci/core/models/remove_vcn_ipv6_cidr_details.rb', line 30 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'ipv6_cidr_block': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
65 66 67 68 69 70 |
# File 'lib/oci/core/models/remove_vcn_ipv6_cidr_details.rb', line 65 def ==(other) return true if equal?(other) self.class == other.class && ipv6_cidr_block == other.ipv6_cidr_block end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/oci/core/models/remove_vcn_ipv6_cidr_details.rb', line 95 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
75 76 77 |
# File 'lib/oci/core/models/remove_vcn_ipv6_cidr_details.rb', line 75 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
84 85 86 |
# File 'lib/oci/core/models/remove_vcn_ipv6_cidr_details.rb', line 84 def hash [ipv6_cidr_block].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
128 129 130 131 132 133 134 135 136 137 |
# File 'lib/oci/core/models/remove_vcn_ipv6_cidr_details.rb', line 128 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
122 123 124 |
# File 'lib/oci/core/models/remove_vcn_ipv6_cidr_details.rb', line 122 def to_s to_hash.to_s end |