Class: OCI::Core::Models::RouteRule

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/core/models/route_rule.rb

Overview

A mapping between a destination IP address range and a virtual device to route matching packets to (a target).

Constant Summary collapse

DESTINATION_TYPE_ENUM =

rubocop:disable Metrics/LineLength

[
  DESTINATION_TYPE_CIDR_BLOCK = 'CIDR_BLOCK'.freeze,
  DESTINATION_TYPE_SERVICE_CIDR_BLOCK = 'SERVICE_CIDR_BLOCK'.freeze,
  DESTINATION_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ RouteRule

Initializes the object

Options Hash (attributes):

  • :cidr_block (String)

    The value to assign to the #cidr_block property

  • :destination (String)

    The value to assign to the #destination property

  • :destination_type (String)

    The value to assign to the #destination_type property

  • :network_entity_id (String)

    The value to assign to the #network_entity_id property

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/oci/core/models/route_rule.rb', line 95

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.cidr_block = attributes[:'cidrBlock'] if attributes[:'cidrBlock']

  raise 'You cannot provide both :cidrBlock and :cidr_block' if attributes.key?(:'cidrBlock') && attributes.key?(:'cidr_block')

  self.cidr_block = attributes[:'cidr_block'] if attributes[:'cidr_block']

  self.destination = attributes[:'destination'] if attributes[:'destination']

  self.destination_type = attributes[:'destinationType'] if attributes[:'destinationType']
  self.destination_type = "CIDR_BLOCK" if destination_type.nil? && !attributes.key?(:'destinationType') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :destinationType and :destination_type' if attributes.key?(:'destinationType') && attributes.key?(:'destination_type')

  self.destination_type = attributes[:'destination_type'] if attributes[:'destination_type']
  self.destination_type = "CIDR_BLOCK" if destination_type.nil? && !attributes.key?(:'destinationType') && !attributes.key?(:'destination_type') # rubocop:disable Style/StringLiterals

  self.network_entity_id = attributes[:'networkEntityId'] if attributes[:'networkEntityId']

  raise 'You cannot provide both :networkEntityId and :network_entity_id' if attributes.key?(:'networkEntityId') && attributes.key?(:'network_entity_id')

  self.network_entity_id = attributes[:'network_entity_id'] if attributes[:'network_entity_id']
end

Instance Attribute Details

#cidr_blockString

Deprecated. Instead use destination and destinationType. Requests that include both cidrBlock and destination will be rejected.

A destination IP address range in CIDR notation. Matching packets will be routed to the indicated network entity (the target).

Example: 0.0.0.0/0

Returns:



27
28
29
# File 'lib/oci/core/models/route_rule.rb', line 27

def cidr_block
  @cidr_block
end

#destinationString

Conceptually, this is the range of IP addresses used for matching when routing traffic. Required if you provide a destinationType.

Allowed values:

* IP address range in CIDR notation. For example: `192.168.1.0/24`

* The `cidrBlock` value for a {Service}, if you're
  setting up a route rule for traffic destined for a particular service through
  a service gateway. For example: `oci-phx-objectstorage`

Returns:



41
42
43
# File 'lib/oci/core/models/route_rule.rb', line 41

def destination
  @destination
end

#destination_typeString

Type of destination for the rule. Required if you provide a destination.

* `CIDR_BLOCK`: If the rule's `destination` is an IP address range in CIDR notation.

* `SERVICE_CIDR_BLOCK`: If the rule's `destination` is the `cidrBlock` value for a
  {Service} (the rule is for traffic destined for a
  particular service through a service gateway).

Returns:



52
53
54
# File 'lib/oci/core/models/route_rule.rb', line 52

def destination_type
  @destination_type
end

#network_entity_idString

[Required] The OCID for the route rule’s target. For information about the type of targets you can specify, see [Route Tables](docs.us-phoenix-1.oraclecloud.com/Content/Network/Tasks/managingroutetables.htm).

Returns:



59
60
61
# File 'lib/oci/core/models/route_rule.rb', line 59

def network_entity_id
  @network_entity_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



62
63
64
65
66
67
68
69
70
71
# File 'lib/oci/core/models/route_rule.rb', line 62

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'cidr_block': :'cidrBlock',
    'destination': :'destination',
    'destination_type': :'destinationType',
    'network_entity_id': :'networkEntityId'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



74
75
76
77
78
79
80
81
82
83
# File 'lib/oci/core/models/route_rule.rb', line 74

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'cidr_block': :'String',
    'destination': :'String',
    'destination_type': :'String',
    'network_entity_id': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • the other object to be compared



146
147
148
149
150
151
152
153
154
# File 'lib/oci/core/models/route_rule.rb', line 146

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    cidr_block == other.cidr_block &&
    destination == other.destination &&
    destination_type == other.destination_type &&
    network_entity_id == other.network_entity_id
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/oci/core/models/route_rule.rb', line 179

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method

Parameters:

  • the other object to be compared

Returns:



159
160
161
# File 'lib/oci/core/models/route_rule.rb', line 159

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • Hash code



168
169
170
# File 'lib/oci/core/models/route_rule.rb', line 168

def hash
  [cidr_block, destination, destination_type, network_entity_id].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



212
213
214
215
216
217
218
219
220
221
# File 'lib/oci/core/models/route_rule.rb', line 212

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



206
207
208
# File 'lib/oci/core/models/route_rule.rb', line 206

def to_s
  to_hash.to_s
end