Method: OCI::Core::Models::SecurityRule#is_valid

Defined in:
lib/oci/core/models/security_rule.rb

#is_validBOOLEAN

Whether the rule is valid. The value is True when the rule is first created. If the rule’s source or destination is a network security group, the value changes to False if that network security group is deleted.

Returns:

  • (BOOLEAN)


112
113
114
# File 'lib/oci/core/models/security_rule.rb', line 112

def is_valid
  @is_valid
end