Class: OCI::Core::Models::Service
- Inherits:
-
Object
- Object
- OCI::Core::Models::Service
- Defined in:
- lib/oci/core/models/service.rb
Overview
An object that represents one or multiple Oracle services that you can enable for a ServiceGateway. In the User Guide topic [Access to Oracle Services: Service Gateway](docs.cloud.oracle.com/Content/Network/Tasks/servicegateway.htm), the term *service CIDR label* is used to refer to the string that represents the regional public IP address ranges of the Oracle service or services covered by a given Service object. That unique string is the value of the Service object’s cidrBlock attribute.
Instance Attribute Summary collapse
-
#cidr_block ⇒ String
[Required] A string that represents the regional public IP address ranges for the Oracle service or services covered by this
Serviceobject. -
#description ⇒ String
[Required] Description of the Oracle service or services covered by this
Serviceobject. -
#id ⇒ String
[Required] The
Serviceobject’s [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm). -
#name ⇒ String
[Required] Name of the
Serviceobject.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Service
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Service
Initializes the object
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/oci/core/models/service.rb', line 82 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.cidr_block = attributes[:'cidrBlock'] if attributes[:'cidrBlock'] raise 'You cannot provide both :cidrBlock and :cidr_block' if attributes.key?(:'cidrBlock') && attributes.key?(:'cidr_block') self.cidr_block = attributes[:'cidr_block'] if attributes[:'cidr_block'] self.description = attributes[:'description'] if attributes[:'description'] self.id = attributes[:'id'] if attributes[:'id'] self.name = attributes[:'name'] if attributes[:'name'] end |
Instance Attribute Details
#cidr_block ⇒ String
[Required] A string that represents the regional public IP address ranges for the Oracle service or services covered by this Service object. Also known as the Service object’s *service CIDR label*.
When you set up a route rule to route traffic to the service gateway, use this value as the rule’s destination. See RouteTable. Also, when you set up a security list rule to cover traffic with the service gateway, use the cidrBlock value as the rule’s destination (for an egress rule) or the source (for an ingress rule). See OCI::Core::Models::SecurityList.
Example: oci-phx-objectstorage
28 29 30 |
# File 'lib/oci/core/models/service.rb', line 28 def cidr_block @cidr_block end |
#description ⇒ String
[Required] Description of the Oracle service or services covered by this Service object.
Example: ‘OCI PHX Object Storage`
35 36 37 |
# File 'lib/oci/core/models/service.rb', line 35 def description @description end |
#id ⇒ String
[Required] The Service object’s [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm).
39 40 41 |
# File 'lib/oci/core/models/service.rb', line 39 def id @id end |
#name ⇒ String
[Required] Name of the Service object. This name can change and is not guaranteed to be unique.
Example: ‘OCI PHX Object Storage`
46 47 48 |
# File 'lib/oci/core/models/service.rb', line 46 def name @name end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
49 50 51 52 53 54 55 56 57 58 |
# File 'lib/oci/core/models/service.rb', line 49 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'cidr_block': :'cidrBlock', 'description': :'description', 'id': :'id', 'name': :'name' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
61 62 63 64 65 66 67 68 69 70 |
# File 'lib/oci/core/models/service.rb', line 61 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'cidr_block': :'String', 'description': :'String', 'id': :'String', 'name': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
108 109 110 111 112 113 114 115 116 |
# File 'lib/oci/core/models/service.rb', line 108 def ==(other) return true if equal?(other) self.class == other.class && cidr_block == other.cidr_block && description == other.description && id == other.id && name == other.name end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/oci/core/models/service.rb', line 141 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
121 122 123 |
# File 'lib/oci/core/models/service.rb', line 121 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
130 131 132 |
# File 'lib/oci/core/models/service.rb', line 130 def hash [cidr_block, description, id, name].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
174 175 176 177 178 179 180 181 182 183 |
# File 'lib/oci/core/models/service.rb', line 174 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
168 169 170 |
# File 'lib/oci/core/models/service.rb', line 168 def to_s to_hash.to_s end |