Class: OCI::Core::Models::SoftResetActionDetails

Inherits:
InstancePowerActionDetails show all
Defined in:
lib/oci/core/models/soft_reset_action_details.rb

Overview

Parameters for the softReset instance_action. If omitted, default values are used.

Instance Attribute Summary collapse

Attributes inherited from InstancePowerActionDetails

#action_type

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from InstancePowerActionDetails

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ SoftResetActionDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/oci/core/models/soft_reset_action_details.rb', line 56

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['actionType'] = 'softreset'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.allow_dense_reboot_migration = attributes[:'allowDenseRebootMigration'] unless attributes[:'allowDenseRebootMigration'].nil?
  self.allow_dense_reboot_migration = false if allow_dense_reboot_migration.nil? && !attributes.key?(:'allowDenseRebootMigration') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :allowDenseRebootMigration and :allow_dense_reboot_migration' if attributes.key?(:'allowDenseRebootMigration') && attributes.key?(:'allow_dense_reboot_migration')

  self.allow_dense_reboot_migration = attributes[:'allow_dense_reboot_migration'] unless attributes[:'allow_dense_reboot_migration'].nil?
  self.allow_dense_reboot_migration = false if allow_dense_reboot_migration.nil? && !attributes.key?(:'allowDenseRebootMigration') && !attributes.key?(:'allow_dense_reboot_migration') # rubocop:disable Style/StringLiterals
end

Instance Attribute Details

#allow_dense_reboot_migrationBOOLEAN

For instances that use a DenseIO shape, the flag denoting whether [reboot migration](docs.cloud.oracle.com/iaas/Content/Compute/References/infrastructure-maintenance.htm#reboot) is performed for the instance. The default value is `false`.

If the instance has a date in the Maintenance reboot field and you do nothing (or set this flag to `false`), the instance will be rebuilt at the scheduled maintenance time. The instance will experience 2-6 hours of downtime during the maintenance process. The local NVMe-based SSD will be preserved.

If you want to minimize downtime and can delete the SSD, you can set this flag to `true` and proactively reboot the instance before the scheduled maintenance time. The instance will be reboot migrated to a healthy host and the SSD will be deleted. A short downtime occurs during the migration.

*Caution:* When `true`, the SSD is permanently deleted. We recommend that you create a backup of the SSD before proceeding.

Returns:

  • (BOOLEAN)


27
28
29
# File 'lib/oci/core/models/soft_reset_action_details.rb', line 27

def allow_dense_reboot_migration
  @allow_dense_reboot_migration
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



30
31
32
33
34
35
36
37
# File 'lib/oci/core/models/soft_reset_action_details.rb', line 30

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'action_type': :'actionType',
    'allow_dense_reboot_migration': :'allowDenseRebootMigration'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



40
41
42
43
44
45
46
47
# File 'lib/oci/core/models/soft_reset_action_details.rb', line 40

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'action_type': :'String',
    'allow_dense_reboot_migration': :'BOOLEAN'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



82
83
84
85
86
87
88
# File 'lib/oci/core/models/soft_reset_action_details.rb', line 82

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    action_type == other.action_type &&
    allow_dense_reboot_migration == other.allow_dense_reboot_migration
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/oci/core/models/soft_reset_action_details.rb', line 113

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


93
94
95
# File 'lib/oci/core/models/soft_reset_action_details.rb', line 93

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



102
103
104
# File 'lib/oci/core/models/soft_reset_action_details.rb', line 102

def hash
  [action_type, allow_dense_reboot_migration].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



146
147
148
149
150
151
152
153
154
155
# File 'lib/oci/core/models/soft_reset_action_details.rb', line 146

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



140
141
142
# File 'lib/oci/core/models/soft_reset_action_details.rb', line 140

def to_s
  to_hash.to_s
end