Method: OCI::Core::Models::Subnet#dns_label
- Defined in:
- lib/oci/core/models/subnet.rb
#dns_label ⇒ String
A DNS label for the subnet, used in conjunction with the VNIC’s hostname and VCN’s DNS label to form a fully qualified domain name (FQDN) for each VNIC within this subnet (for example, bminstance-1.subnet123.vcn1.oraclevcn.com). Must be an alphanumeric string that begins with a letter and is unique within the VCN. The value cannot be changed.
The absence of this parameter means the Internet and VCN Resolver will not resolve hostnames of instances in this subnet.
For more information, see [DNS in Your Virtual Cloud Network](docs.cloud.oracle.com/Content/Network/Concepts/dns.htm).
Example: subnet123
83 84 85 |
# File 'lib/oci/core/models/subnet.rb', line 83 def dns_label @dns_label end |