Class: OCI::Core::Models::Topology

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/core/models/topology.rb

Overview

Defines the representation of a virtual network topology. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class

Direct Known Subclasses

NetworkingTopology, SubnetTopology, VcnTopology

Constant Summary collapse

TYPE_ENUM =
[
  TYPE_NETWORKING = 'NETWORKING'.freeze,
  TYPE_VCN = 'VCN'.freeze,
  TYPE_SUBNET = 'SUBNET'.freeze,
  TYPE_PATH = 'PATH'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Topology

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/oci/core/models/topology.rb', line 85

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.type = attributes[:'type'] if attributes[:'type']

  self.entities = attributes[:'entities'] if attributes[:'entities']

  self.relationships = attributes[:'relationships'] if attributes[:'relationships']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']
end

Instance Attribute Details

#entitiesArray<Object>

**[Required]** Lists entities comprising the virtual network topology.

Returns:

  • (Array<Object>)


24
25
26
# File 'lib/oci/core/models/topology.rb', line 24

def entities
  @entities
end

#relationshipsArray<OCI::Core::Models::TopologyEntityRelationship>

**[Required]** Lists relationships between entities in the virtual network topology.



28
29
30
# File 'lib/oci/core/models/topology.rb', line 28

def relationships
  @relationships
end

#time_createdDateTime

**[Required]** Records when the virtual network topology was created, in [RFC3339](tools.ietf.org/html/rfc3339) format for date and time.

Returns:

  • (DateTime)


32
33
34
# File 'lib/oci/core/models/topology.rb', line 32

def time_created
  @time_created
end

#typeString

**[Required]** Type of the topology object.

Returns:

  • (String)


20
21
22
# File 'lib/oci/core/models/topology.rb', line 20

def type
  @type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
44
# File 'lib/oci/core/models/topology.rb', line 35

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'type': :'type',
    'entities': :'entities',
    'relationships': :'relationships',
    'time_created': :'timeCreated'
    # rubocop:enable Style/SymbolLiteral
  }
end

.get_subtype(object_hash) ⇒ Object

Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.



63
64
65
66
67
68
69
70
71
72
# File 'lib/oci/core/models/topology.rb', line 63

def self.get_subtype(object_hash)
  type = object_hash[:'type'] # rubocop:disable Style/SymbolLiteral

  return 'OCI::Core::Models::VcnTopology' if type == 'VCN'
  return 'OCI::Core::Models::NetworkingTopology' if type == 'NETWORKING'
  return 'OCI::Core::Models::SubnetTopology' if type == 'SUBNET'

  # TODO: Log a warning when the subtype is not found.
  'OCI::Core::Models::Topology'
end

.swagger_typesObject

Attribute type mapping.



47
48
49
50
51
52
53
54
55
56
# File 'lib/oci/core/models/topology.rb', line 47

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'type': :'String',
    'entities': :'Array<Object>',
    'relationships': :'Array<OCI::Core::Models::TopologyEntityRelationship>',
    'time_created': :'DateTime'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



119
120
121
122
123
124
125
126
127
# File 'lib/oci/core/models/topology.rb', line 119

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    type == other.type &&
    entities == other.entities &&
    relationships == other.relationships &&
    time_created == other.time_created
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/oci/core/models/topology.rb', line 152

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


132
133
134
# File 'lib/oci/core/models/topology.rb', line 132

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



141
142
143
# File 'lib/oci/core/models/topology.rb', line 141

def hash
  [type, entities, relationships, time_created].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



185
186
187
188
189
190
191
192
193
194
# File 'lib/oci/core/models/topology.rb', line 185

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



179
180
181
# File 'lib/oci/core/models/topology.rb', line 179

def to_s
  to_hash.to_s
end