Class: OCI::Core::Models::TopologyAssociatedWithEntityRelationship
- Inherits:
-
TopologyEntityRelationship
- Object
- TopologyEntityRelationship
- OCI::Core::Models::TopologyAssociatedWithEntityRelationship
- Defined in:
- lib/oci/core/models/topology_associated_with_entity_relationship.rb
Overview
Defines the associatedWith relationship between virtual network topology entities. An AssociatedWith relationship is defined when there is no obvious contains relationship but entities are still related. For example, a DRG is associated with a VCN because a DRG is not managed by VCN but can be attached to a VCN.
Constant Summary
Constants inherited from TopologyEntityRelationship
OCI::Core::Models::TopologyEntityRelationship::TYPE_ENUM
Instance Attribute Summary
Attributes inherited from TopologyEntityRelationship
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TopologyAssociatedWithEntityRelationship
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from TopologyEntityRelationship
Constructor Details
#initialize(attributes = {}) ⇒ TopologyAssociatedWithEntityRelationship
Initializes the object
45 46 47 48 49 50 51 |
# File 'lib/oci/core/models/topology_associated_with_entity_relationship.rb', line 45 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['type'] = 'ASSOCIATED_WITH' super(attributes) end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
16 17 18 19 20 21 22 23 24 |
# File 'lib/oci/core/models/topology_associated_with_entity_relationship.rb', line 16 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id1': :'id1', 'id2': :'id2', 'type': :'type' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
27 28 29 30 31 32 33 34 35 |
# File 'lib/oci/core/models/topology_associated_with_entity_relationship.rb', line 27 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id1': :'String', 'id2': :'String', 'type': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
60 61 62 63 64 65 66 67 |
# File 'lib/oci/core/models/topology_associated_with_entity_relationship.rb', line 60 def ==(other) return true if equal?(other) self.class == other.class && id1 == other.id1 && id2 == other.id2 && type == other.type end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/oci/core/models/topology_associated_with_entity_relationship.rb', line 92 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
72 73 74 |
# File 'lib/oci/core/models/topology_associated_with_entity_relationship.rb', line 72 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
81 82 83 |
# File 'lib/oci/core/models/topology_associated_with_entity_relationship.rb', line 81 def hash [id1, id2, type].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
125 126 127 128 129 130 131 132 133 134 |
# File 'lib/oci/core/models/topology_associated_with_entity_relationship.rb', line 125 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
119 120 121 |
# File 'lib/oci/core/models/topology_associated_with_entity_relationship.rb', line 119 def to_s to_hash.to_s end |