Class: OCI::Core::Models::UpdateDrgAttachmentDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/core/models/update_drg_attachment_details.rb

Overview

UpdateDrgAttachmentDetails model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateDrgAttachmentDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/oci/core/models/update_drg_attachment_details.rb', line 105

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.drg_route_table_id = attributes[:'drgRouteTableId'] if attributes[:'drgRouteTableId']

  raise 'You cannot provide both :drgRouteTableId and :drg_route_table_id' if attributes.key?(:'drgRouteTableId') && attributes.key?(:'drg_route_table_id')

  self.drg_route_table_id = attributes[:'drg_route_table_id'] if attributes[:'drg_route_table_id']

  self.network_details = attributes[:'networkDetails'] if attributes[:'networkDetails']

  raise 'You cannot provide both :networkDetails and :network_details' if attributes.key?(:'networkDetails') && attributes.key?(:'network_details')

  self.network_details = attributes[:'network_details'] if attributes[:'network_details']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.export_drg_route_distribution_id = attributes[:'exportDrgRouteDistributionId'] if attributes[:'exportDrgRouteDistributionId']

  raise 'You cannot provide both :exportDrgRouteDistributionId and :export_drg_route_distribution_id' if attributes.key?(:'exportDrgRouteDistributionId') && attributes.key?(:'export_drg_route_distribution_id')

  self.export_drg_route_distribution_id = attributes[:'export_drg_route_distribution_id'] if attributes[:'export_drg_route_distribution_id']

  self.route_table_id = attributes[:'routeTableId'] if attributes[:'routeTableId']

  raise 'You cannot provide both :routeTableId and :route_table_id' if attributes.key?(:'routeTableId') && attributes.key?(:'route_table_id')

  self.route_table_id = attributes[:'route_table_id'] if attributes[:'route_table_id']
end

Instance Attribute Details

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).

Example: `{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


35
36
37
# File 'lib/oci/core/models/update_drg_attachment_details.rb', line 35

def defined_tags
  @defined_tags
end

#display_nameString

A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.

Returns:

  • (String)


14
15
16
# File 'lib/oci/core/models/update_drg_attachment_details.rb', line 14

def display_name
  @display_name
end

#drg_route_table_idString

The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the DRG route table that is assigned to this attachment.

The DRG route table manages traffic inside the DRG.

You can't remove a DRG route table from a DRG attachment, but you can reassign which DRG route table it uses.

Returns:

  • (String)


24
25
26
# File 'lib/oci/core/models/update_drg_attachment_details.rb', line 24

def drg_route_table_id
  @drg_route_table_id
end

#export_drg_route_distribution_idString

The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the export route distribution used to specify how routes in the assigned DRG route table are advertised out through the attachment. If this value is null, no routes are advertised through this attachment.

Returns:

  • (String)


50
51
52
# File 'lib/oci/core/models/update_drg_attachment_details.rb', line 50

def export_drg_route_distribution_id
  @export_drg_route_distribution_id
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).

Example: `"Finance"`

Returns:

  • (Hash<String, String>)


43
44
45
# File 'lib/oci/core/models/update_drg_attachment_details.rb', line 43

def freeform_tags
  @freeform_tags
end

#network_detailsOCI::Core::Models::DrgAttachmentNetworkUpdateDetails



27
28
29
# File 'lib/oci/core/models/update_drg_attachment_details.rb', line 27

def network_details
  @network_details
end

#route_table_idString

This is the [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the route table that is used to route the traffic as it enters a VCN through this attachment.

For information about why you would associate a route table with a DRG attachment, see:

* [Transit Routing: Access to Multiple VCNs in Same Region](https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/transitrouting.htm)
* [Transit Routing: Private Access to Oracle Services](https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/transitroutingoracleservices.htm)

Returns:

  • (String)


60
61
62
# File 'lib/oci/core/models/update_drg_attachment_details.rb', line 60

def route_table_id
  @route_table_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/oci/core/models/update_drg_attachment_details.rb', line 63

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'displayName',
    'drg_route_table_id': :'drgRouteTableId',
    'network_details': :'networkDetails',
    'defined_tags': :'definedTags',
    'freeform_tags': :'freeformTags',
    'export_drg_route_distribution_id': :'exportDrgRouteDistributionId',
    'route_table_id': :'routeTableId'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/oci/core/models/update_drg_attachment_details.rb', line 78

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'String',
    'drg_route_table_id': :'String',
    'network_details': :'OCI::Core::Models::DrgAttachmentNetworkUpdateDetails',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'freeform_tags': :'Hash<String, String>',
    'export_drg_route_distribution_id': :'String',
    'route_table_id': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/oci/core/models/update_drg_attachment_details.rb', line 161

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    display_name == other.display_name &&
    drg_route_table_id == other.drg_route_table_id &&
    network_details == other.network_details &&
    defined_tags == other.defined_tags &&
    freeform_tags == other.freeform_tags &&
    export_drg_route_distribution_id == other.export_drg_route_distribution_id &&
    route_table_id == other.route_table_id
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/oci/core/models/update_drg_attachment_details.rb', line 197

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


177
178
179
# File 'lib/oci/core/models/update_drg_attachment_details.rb', line 177

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



186
187
188
# File 'lib/oci/core/models/update_drg_attachment_details.rb', line 186

def hash
  [display_name, drg_route_table_id, network_details, defined_tags, freeform_tags, export_drg_route_distribution_id, route_table_id].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



230
231
232
233
234
235
236
237
238
239
# File 'lib/oci/core/models/update_drg_attachment_details.rb', line 230

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



224
225
226
# File 'lib/oci/core/models/update_drg_attachment_details.rb', line 224

def to_s
  to_hash.to_s
end