Class: OCI::Core::Models::UpdateIPSecConnectionDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/core/models/update_ip_sec_connection_details.rb

Overview

UpdateIPSecConnectionDetails model.

Constant Summary collapse

CPE_LOCAL_IDENTIFIER_TYPE_ENUM =
[
  CPE_LOCAL_IDENTIFIER_TYPE_IP_ADDRESS = 'IP_ADDRESS'.freeze,
  CPE_LOCAL_IDENTIFIER_TYPE_HOSTNAME = 'HOSTNAME'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateIPSecConnectionDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property

  • :display_name (String)

    The value to assign to the #display_name property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :cpe_local_identifier (String)

    The value to assign to the #cpe_local_identifier property

  • :cpe_local_identifier_type (String)

    The value to assign to the #cpe_local_identifier_type property

  • :static_routes (Array<String>)

    The value to assign to the #static_routes property



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/oci/core/models/update_ip_sec_connection_details.rb', line 110

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.cpe_local_identifier = attributes[:'cpeLocalIdentifier'] if attributes[:'cpeLocalIdentifier']

  raise 'You cannot provide both :cpeLocalIdentifier and :cpe_local_identifier' if attributes.key?(:'cpeLocalIdentifier') && attributes.key?(:'cpe_local_identifier')

  self.cpe_local_identifier = attributes[:'cpe_local_identifier'] if attributes[:'cpe_local_identifier']

  self.cpe_local_identifier_type = attributes[:'cpeLocalIdentifierType'] if attributes[:'cpeLocalIdentifierType']

  raise 'You cannot provide both :cpeLocalIdentifierType and :cpe_local_identifier_type' if attributes.key?(:'cpeLocalIdentifierType') && attributes.key?(:'cpe_local_identifier_type')

  self.cpe_local_identifier_type = attributes[:'cpe_local_identifier_type'] if attributes[:'cpe_local_identifier_type']

  self.static_routes = attributes[:'staticRoutes'] if attributes[:'staticRoutes']

  raise 'You cannot provide both :staticRoutes and :static_routes' if attributes.key?(:'staticRoutes') && attributes.key?(:'static_routes')

  self.static_routes = attributes[:'static_routes'] if attributes[:'static_routes']
end

Instance Attribute Details

#cpe_local_identifierString

Your identifier for your CPE device. Can be either an IP address or a hostname (specifically, the fully qualified domain name (FQDN)). The type of identifier you provide here must correspond to the value for cpeLocalIdentifierType.

For information about why you’d provide this value, see [If Your CPE Is Behind a NAT Device](docs.cloud.oracle.com/iaas/Content/Network/Tasks/overviewIPsec.htm#nat).

Example IP address: 10.0.3.3

Example hostname: cpe.example.com

Returns:

  • (String)


49
50
51
# File 'lib/oci/core/models/update_ip_sec_connection_details.rb', line 49

def cpe_local_identifier
  @cpe_local_identifier
end

#cpe_local_identifier_typeString

The type of identifier for your CPE device. The value you provide here must correspond to the value for cpeLocalIdentifier.

Returns:

  • (String)


55
56
57
# File 'lib/oci/core/models/update_ip_sec_connection_details.rb', line 55

def cpe_local_identifier_type
  @cpe_local_identifier_type
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).

Example: ‘{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


21
22
23
# File 'lib/oci/core/models/update_ip_sec_connection_details.rb', line 21

def defined_tags
  @defined_tags
end

#display_nameString

A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.

Returns:

  • (String)


27
28
29
# File 'lib/oci/core/models/update_ip_sec_connection_details.rb', line 27

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).

Example: ‘"Finance"`

Returns:

  • (Hash<String, String>)


35
36
37
# File 'lib/oci/core/models/update_ip_sec_connection_details.rb', line 35

def freeform_tags
  @freeform_tags
end

#static_routesArray<String>

Static routes to the CPE. If you provide this attribute, it replaces the entire current set of static routes. A static route’s CIDR must not be a multicast address or class E address. The CIDR can be either IPv4 or IPv6. IPv6 addressing is supported for all commercial and government regions. See [IPv6 Addresses](docs.cloud.oracle.com/iaas/Content/Network/Concepts/ipv6.htm).

Example: 10.0.1.0/24

Example: 2001:db8::/32

Returns:

  • (Array<String>)


68
69
70
# File 'lib/oci/core/models/update_ip_sec_connection_details.rb', line 68

def static_routes
  @static_routes
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/oci/core/models/update_ip_sec_connection_details.rb', line 71

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'defined_tags': :'definedTags',
    'display_name': :'displayName',
    'freeform_tags': :'freeformTags',
    'cpe_local_identifier': :'cpeLocalIdentifier',
    'cpe_local_identifier_type': :'cpeLocalIdentifierType',
    'static_routes': :'staticRoutes'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/oci/core/models/update_ip_sec_connection_details.rb', line 85

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'display_name': :'String',
    'freeform_tags': :'Hash<String, String>',
    'cpe_local_identifier': :'String',
    'cpe_local_identifier_type': :'String',
    'static_routes': :'Array<String>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



168
169
170
171
172
173
174
175
176
177
178
# File 'lib/oci/core/models/update_ip_sec_connection_details.rb', line 168

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    defined_tags == other.defined_tags &&
    display_name == other.display_name &&
    freeform_tags == other.freeform_tags &&
    cpe_local_identifier == other.cpe_local_identifier &&
    cpe_local_identifier_type == other.cpe_local_identifier_type &&
    static_routes == other.static_routes
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/oci/core/models/update_ip_sec_connection_details.rb', line 203

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


183
184
185
# File 'lib/oci/core/models/update_ip_sec_connection_details.rb', line 183

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



192
193
194
# File 'lib/oci/core/models/update_ip_sec_connection_details.rb', line 192

def hash
  [defined_tags, display_name, freeform_tags, cpe_local_identifier, cpe_local_identifier_type, static_routes].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



236
237
238
239
240
241
242
243
244
245
# File 'lib/oci/core/models/update_ip_sec_connection_details.rb', line 236

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



230
231
232
# File 'lib/oci/core/models/update_ip_sec_connection_details.rb', line 230

def to_s
  to_hash.to_s
end