Class: OCI::Core::Models::UpdateIPSecTunnelBgpSessionDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/core/models/update_ip_sec_tunnel_bgp_session_details.rb

Overview

UpdateIPSecTunnelBgpSessionDetails model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateIPSecTunnelBgpSessionDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/oci/core/models/update_ip_sec_tunnel_bgp_session_details.rb', line 128

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.oracle_interface_ip = attributes[:'oracleInterfaceIp'] if attributes[:'oracleInterfaceIp']

  raise 'You cannot provide both :oracleInterfaceIp and :oracle_interface_ip' if attributes.key?(:'oracleInterfaceIp') && attributes.key?(:'oracle_interface_ip')

  self.oracle_interface_ip = attributes[:'oracle_interface_ip'] if attributes[:'oracle_interface_ip']

  self.customer_interface_ip = attributes[:'customerInterfaceIp'] if attributes[:'customerInterfaceIp']

  raise 'You cannot provide both :customerInterfaceIp and :customer_interface_ip' if attributes.key?(:'customerInterfaceIp') && attributes.key?(:'customer_interface_ip')

  self.customer_interface_ip = attributes[:'customer_interface_ip'] if attributes[:'customer_interface_ip']

  self.oracle_interface_ipv6 = attributes[:'oracleInterfaceIpv6'] if attributes[:'oracleInterfaceIpv6']

  raise 'You cannot provide both :oracleInterfaceIpv6 and :oracle_interface_ipv6' if attributes.key?(:'oracleInterfaceIpv6') && attributes.key?(:'oracle_interface_ipv6')

  self.oracle_interface_ipv6 = attributes[:'oracle_interface_ipv6'] if attributes[:'oracle_interface_ipv6']

  self.customer_interface_ipv6 = attributes[:'customerInterfaceIpv6'] if attributes[:'customerInterfaceIpv6']

  raise 'You cannot provide both :customerInterfaceIpv6 and :customer_interface_ipv6' if attributes.key?(:'customerInterfaceIpv6') && attributes.key?(:'customer_interface_ipv6')

  self.customer_interface_ipv6 = attributes[:'customer_interface_ipv6'] if attributes[:'customer_interface_ipv6']

  self.customer_bgp_asn = attributes[:'customerBgpAsn'] if attributes[:'customerBgpAsn']

  raise 'You cannot provide both :customerBgpAsn and :customer_bgp_asn' if attributes.key?(:'customerBgpAsn') && attributes.key?(:'customer_bgp_asn')

  self.customer_bgp_asn = attributes[:'customer_bgp_asn'] if attributes[:'customer_bgp_asn']
end

Instance Attribute Details

#customer_bgp_asnString

The BGP ASN of the network on the CPE end of the BGP session. Can be a 2-byte or 4-byte ASN. Uses \“asplain\” format.

If you are switching the tunnel from using BGP dynamic routing to static routing, the customerBgpAsn must be null.

Example: 12345 (2-byte) or 1587232876 (4-byte)

Returns:

  • (String)


89
90
91
# File 'lib/oci/core/models/update_ip_sec_tunnel_bgp_session_details.rb', line 89

def customer_bgp_asn
  @customer_bgp_asn
end

#customer_interface_ipString

The IP address for the CPE end of the inside tunnel interface.

If the tunnel’s routing attribute is set to BGP (see update_ip_sec_connection_tunnel_details), this IP address is used for the tunnel’s BGP session.

If routing is instead set to STATIC, you can set this IP address to troubleshoot or monitor the tunnel.

The value must be a /30 or /31.

If you are switching the tunnel from using BGP dynamic routing to static routing and want to remove the value for customerInterfaceIp, you can set the value to an empty string.

Example: 10.0.0.5/31

Returns:

  • (String)


46
47
48
# File 'lib/oci/core/models/update_ip_sec_tunnel_bgp_session_details.rb', line 46

def customer_interface_ip
  @customer_interface_ip
end

#customer_interface_ipv6String

The IPv6 address for the CPE end of the inside tunnel interface. This IP address is optional.

If the tunnel’s routing attribute is set to BGP (see IPSecConnectionTunnel), this IP address is used for the tunnel’s BGP session.

If routing is instead set to STATIC, you can set this IP address to troubleshoot or monitor the tunnel.

Only subnet masks from /64 up to /127 are allowed.

Example: 2001:db8::1/64

Returns:

  • (String)


78
79
80
# File 'lib/oci/core/models/update_ip_sec_tunnel_bgp_session_details.rb', line 78

def customer_interface_ipv6
  @customer_interface_ipv6
end

#oracle_interface_ipString

The IP address for the Oracle end of the inside tunnel interface.

If the tunnel’s routing attribute is set to BGP (see update_ip_sec_connection_tunnel_details), this IP address is used for the tunnel’s BGP session.

If routing is instead set to STATIC, you can set this IP address to troubleshoot or monitor the tunnel.

The value must be a /30 or /31.

If you are switching the tunnel from using BGP dynamic routing to static routing and want to remove the value for oracleInterfaceIp, you can set the value to an empty string.

Example: 10.0.0.4/31

Returns:

  • (String)


27
28
29
# File 'lib/oci/core/models/update_ip_sec_tunnel_bgp_session_details.rb', line 27

def oracle_interface_ip
  @oracle_interface_ip
end

#oracle_interface_ipv6String

The IPv6 address for the Oracle end of the inside tunnel interface. This IP address is optional.

If the tunnel’s routing attribute is set to BGP (see IPSecConnectionTunnel), this IP address is used for the tunnel’s BGP session.

If routing is instead set to STATIC, you can set this IP address to troubleshoot or monitor the tunnel.

Only subnet masks from /64 up to /127 are allowed.

Example: 2001:db8::1/64

Returns:

  • (String)


62
63
64
# File 'lib/oci/core/models/update_ip_sec_tunnel_bgp_session_details.rb', line 62

def oracle_interface_ipv6
  @oracle_interface_ipv6
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



92
93
94
95
96
97
98
99
100
101
102
# File 'lib/oci/core/models/update_ip_sec_tunnel_bgp_session_details.rb', line 92

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'oracle_interface_ip': :'oracleInterfaceIp',
    'customer_interface_ip': :'customerInterfaceIp',
    'oracle_interface_ipv6': :'oracleInterfaceIpv6',
    'customer_interface_ipv6': :'customerInterfaceIpv6',
    'customer_bgp_asn': :'customerBgpAsn'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



105
106
107
108
109
110
111
112
113
114
115
# File 'lib/oci/core/models/update_ip_sec_tunnel_bgp_session_details.rb', line 105

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'oracle_interface_ip': :'String',
    'customer_interface_ip': :'String',
    'oracle_interface_ipv6': :'String',
    'customer_interface_ipv6': :'String',
    'customer_bgp_asn': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



172
173
174
175
176
177
178
179
180
181
# File 'lib/oci/core/models/update_ip_sec_tunnel_bgp_session_details.rb', line 172

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    oracle_interface_ip == other.oracle_interface_ip &&
    customer_interface_ip == other.customer_interface_ip &&
    oracle_interface_ipv6 == other.oracle_interface_ipv6 &&
    customer_interface_ipv6 == other.customer_interface_ipv6 &&
    customer_bgp_asn == other.customer_bgp_asn
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/oci/core/models/update_ip_sec_tunnel_bgp_session_details.rb', line 206

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


186
187
188
# File 'lib/oci/core/models/update_ip_sec_tunnel_bgp_session_details.rb', line 186

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



195
196
197
# File 'lib/oci/core/models/update_ip_sec_tunnel_bgp_session_details.rb', line 195

def hash
  [oracle_interface_ip, customer_interface_ip, oracle_interface_ipv6, customer_interface_ipv6, customer_bgp_asn].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



239
240
241
242
243
244
245
246
247
248
# File 'lib/oci/core/models/update_ip_sec_tunnel_bgp_session_details.rb', line 239

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



233
234
235
# File 'lib/oci/core/models/update_ip_sec_tunnel_bgp_session_details.rb', line 233

def to_s
  to_hash.to_s
end