Class: OCI::Core::Models::UpdateInstanceAgentConfigDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/core/models/update_instance_agent_config_details.rb

Overview

Configuration options for the Oracle Cloud Agent software running on the instance.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateInstanceAgentConfigDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/oci/core/models/update_instance_agent_config_details.rb', line 94

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.is_monitoring_disabled = attributes[:'isMonitoringDisabled'] unless attributes[:'isMonitoringDisabled'].nil?
  self.is_monitoring_disabled = false if is_monitoring_disabled.nil? && !attributes.key?(:'isMonitoringDisabled') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isMonitoringDisabled and :is_monitoring_disabled' if attributes.key?(:'isMonitoringDisabled') && attributes.key?(:'is_monitoring_disabled')

  self.is_monitoring_disabled = attributes[:'is_monitoring_disabled'] unless attributes[:'is_monitoring_disabled'].nil?
  self.is_monitoring_disabled = false if is_monitoring_disabled.nil? && !attributes.key?(:'isMonitoringDisabled') && !attributes.key?(:'is_monitoring_disabled') # rubocop:disable Style/StringLiterals

  self.is_management_disabled = attributes[:'isManagementDisabled'] unless attributes[:'isManagementDisabled'].nil?
  self.is_management_disabled = false if is_management_disabled.nil? && !attributes.key?(:'isManagementDisabled') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isManagementDisabled and :is_management_disabled' if attributes.key?(:'isManagementDisabled') && attributes.key?(:'is_management_disabled')

  self.is_management_disabled = attributes[:'is_management_disabled'] unless attributes[:'is_management_disabled'].nil?
  self.is_management_disabled = false if is_management_disabled.nil? && !attributes.key?(:'isManagementDisabled') && !attributes.key?(:'is_management_disabled') # rubocop:disable Style/StringLiterals

  self.are_all_plugins_disabled = attributes[:'areAllPluginsDisabled'] unless attributes[:'areAllPluginsDisabled'].nil?
  self.are_all_plugins_disabled = false if are_all_plugins_disabled.nil? && !attributes.key?(:'areAllPluginsDisabled') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :areAllPluginsDisabled and :are_all_plugins_disabled' if attributes.key?(:'areAllPluginsDisabled') && attributes.key?(:'are_all_plugins_disabled')

  self.are_all_plugins_disabled = attributes[:'are_all_plugins_disabled'] unless attributes[:'are_all_plugins_disabled'].nil?
  self.are_all_plugins_disabled = false if are_all_plugins_disabled.nil? && !attributes.key?(:'areAllPluginsDisabled') && !attributes.key?(:'are_all_plugins_disabled') # rubocop:disable Style/StringLiterals

  self.plugins_config = attributes[:'pluginsConfig'] if attributes[:'pluginsConfig']

  raise 'You cannot provide both :pluginsConfig and :plugins_config' if attributes.key?(:'pluginsConfig') && attributes.key?(:'plugins_config')

  self.plugins_config = attributes[:'plugins_config'] if attributes[:'plugins_config']
end

Instance Attribute Details

#are_all_plugins_disabledBOOLEAN

Whether Oracle Cloud Agent can run all the available plugins. This includes the management and monitoring plugins.

To get a list of available plugins, use the list_instanceagent_available_plugins operation in the Oracle Cloud Agent API. For more information about the available plugins, see [Managing Plugins with Oracle Cloud Agent](docs.cloud.oracle.com/iaas/Content/Compute/Tasks/manage-plugins.htm).

Returns:

  • (BOOLEAN)


54
55
56
# File 'lib/oci/core/models/update_instance_agent_config_details.rb', line 54

def are_all_plugins_disabled
  @are_all_plugins_disabled
end

#is_management_disabledBOOLEAN

Whether Oracle Cloud Agent can run all the available management plugins.

These are the management plugins: OS Management Service Agent and Compute Instance Run Command.

The management plugins are controlled by this parameter and by the per-plugin configuration in the pluginsConfig object.

  • If isManagementDisabled is true, all of the management plugins are disabled, regardless of

the per-plugin configuration.

  • If isManagementDisabled is false, all of the management plugins are enabled. You

can optionally disable individual management plugins by providing a value in the pluginsConfig object.

Returns:

  • (BOOLEAN)


43
44
45
# File 'lib/oci/core/models/update_instance_agent_config_details.rb', line 43

def is_management_disabled
  @is_management_disabled
end

#is_monitoring_disabledBOOLEAN

Whether Oracle Cloud Agent can gather performance metrics and monitor the instance using the monitoring plugins.

These are the monitoring plugins: Compute Instance Monitoring and Custom Logs Monitoring.

The monitoring plugins are controlled by this parameter and by the per-plugin configuration in the pluginsConfig object.

  • If isMonitoringDisabled is true, all of the monitoring plugins are disabled, regardless of

the per-plugin configuration.

  • If isMonitoringDisabled is false, all of the monitoring plugins are enabled. You

can optionally disable individual monitoring plugins by providing a value in the pluginsConfig object.

Returns:

  • (BOOLEAN)


26
27
28
# File 'lib/oci/core/models/update_instance_agent_config_details.rb', line 26

def is_monitoring_disabled
  @is_monitoring_disabled
end

#plugins_configArray<OCI::Core::Models::InstanceAgentPluginConfigDetails>

The configuration of plugins associated with this instance.



58
59
60
# File 'lib/oci/core/models/update_instance_agent_config_details.rb', line 58

def plugins_config
  @plugins_config
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
# File 'lib/oci/core/models/update_instance_agent_config_details.rb', line 61

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'is_monitoring_disabled': :'isMonitoringDisabled',
    'is_management_disabled': :'isManagementDisabled',
    'are_all_plugins_disabled': :'areAllPluginsDisabled',
    'plugins_config': :'pluginsConfig'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



73
74
75
76
77
78
79
80
81
82
# File 'lib/oci/core/models/update_instance_agent_config_details.rb', line 73

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'is_monitoring_disabled': :'BOOLEAN',
    'is_management_disabled': :'BOOLEAN',
    'are_all_plugins_disabled': :'BOOLEAN',
    'plugins_config': :'Array<OCI::Core::Models::InstanceAgentPluginConfigDetails>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



138
139
140
141
142
143
144
145
146
# File 'lib/oci/core/models/update_instance_agent_config_details.rb', line 138

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    is_monitoring_disabled == other.is_monitoring_disabled &&
    is_management_disabled == other.is_management_disabled &&
    are_all_plugins_disabled == other.are_all_plugins_disabled &&
    plugins_config == other.plugins_config
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/oci/core/models/update_instance_agent_config_details.rb', line 171

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


151
152
153
# File 'lib/oci/core/models/update_instance_agent_config_details.rb', line 151

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



160
161
162
# File 'lib/oci/core/models/update_instance_agent_config_details.rb', line 160

def hash
  [is_monitoring_disabled, is_management_disabled, are_all_plugins_disabled, plugins_config].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



204
205
206
207
208
209
210
211
212
213
# File 'lib/oci/core/models/update_instance_agent_config_details.rb', line 204

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



198
199
200
# File 'lib/oci/core/models/update_instance_agent_config_details.rb', line 198

def to_s
  to_hash.to_s
end