Class: OCI::Core::Models::UpdateInstanceAvailabilityConfigDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/core/models/update_instance_availability_config_details.rb

Overview

Options for defining the availability of a VM instance after a maintenance event that impacts the underlying hardware, including whether to live migrate supported VM instances when possible.

Constant Summary collapse

RECOVERY_ACTION_ENUM =
[
  RECOVERY_ACTION_RESTORE_INSTANCE = 'RESTORE_INSTANCE'.freeze,
  RECOVERY_ACTION_STOP_INSTANCE = 'STOP_INSTANCE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateInstanceAvailabilityConfigDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/oci/core/models/update_instance_availability_config_details.rb', line 60

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.is_live_migration_preferred = attributes[:'isLiveMigrationPreferred'] unless attributes[:'isLiveMigrationPreferred'].nil?

  raise 'You cannot provide both :isLiveMigrationPreferred and :is_live_migration_preferred' if attributes.key?(:'isLiveMigrationPreferred') && attributes.key?(:'is_live_migration_preferred')

  self.is_live_migration_preferred = attributes[:'is_live_migration_preferred'] unless attributes[:'is_live_migration_preferred'].nil?

  self.recovery_action = attributes[:'recoveryAction'] if attributes[:'recoveryAction']
  self.recovery_action = "RESTORE_INSTANCE" if recovery_action.nil? && !attributes.key?(:'recoveryAction') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :recoveryAction and :recovery_action' if attributes.key?(:'recoveryAction') && attributes.key?(:'recovery_action')

  self.recovery_action = attributes[:'recovery_action'] if attributes[:'recovery_action']
  self.recovery_action = "RESTORE_INSTANCE" if recovery_action.nil? && !attributes.key?(:'recoveryAction') && !attributes.key?(:'recovery_action') # rubocop:disable Style/StringLiterals
end

Instance Attribute Details

#is_live_migration_preferredBOOLEAN

Whether to live migrate supported VM instances to a healthy physical VM host without disrupting running instances during infrastructure maintenance events. If null, Oracle chooses the best option for migrating the VM during infrastructure maintenance events.

Returns:

  • (BOOLEAN)


22
23
24
# File 'lib/oci/core/models/update_instance_availability_config_details.rb', line 22

def is_live_migration_preferred
  @is_live_migration_preferred
end

#recovery_actionString

The lifecycle state for an instance when it is recovered after infrastructure maintenance.

  • RESTORE_INSTANCE - The instance is restored to the lifecycle state it was in before the maintenance event.

If the instance was running, it is automatically rebooted. This is the default action when a value is not set.

  • STOP_INSTANCE - The instance is recovered in the stopped state.

Returns:

  • (String)


30
31
32
# File 'lib/oci/core/models/update_instance_availability_config_details.rb', line 30

def recovery_action
  @recovery_action
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



33
34
35
36
37
38
39
40
# File 'lib/oci/core/models/update_instance_availability_config_details.rb', line 33

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'is_live_migration_preferred': :'isLiveMigrationPreferred',
    'recovery_action': :'recoveryAction'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



43
44
45
46
47
48
49
50
# File 'lib/oci/core/models/update_instance_availability_config_details.rb', line 43

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'is_live_migration_preferred': :'BOOLEAN',
    'recovery_action': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



96
97
98
99
100
101
102
# File 'lib/oci/core/models/update_instance_availability_config_details.rb', line 96

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    is_live_migration_preferred == other.is_live_migration_preferred &&
    recovery_action == other.recovery_action
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/oci/core/models/update_instance_availability_config_details.rb', line 127

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


107
108
109
# File 'lib/oci/core/models/update_instance_availability_config_details.rb', line 107

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



116
117
118
# File 'lib/oci/core/models/update_instance_availability_config_details.rb', line 116

def hash
  [is_live_migration_preferred, recovery_action].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



160
161
162
163
164
165
166
167
168
169
# File 'lib/oci/core/models/update_instance_availability_config_details.rb', line 160

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



154
155
156
# File 'lib/oci/core/models/update_instance_availability_config_details.rb', line 154

def to_s
  to_hash.to_s
end