Class: OCI::Core::Models::UpdateInstanceDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/core/models/update_instance_details.rb

Overview

UpdateInstanceDetails model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateInstanceDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
# File 'lib/oci/core/models/update_instance_details.rb', line 145

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.capacity_reservation_id = attributes[:'capacityReservationId'] if attributes[:'capacityReservationId']

  raise 'You cannot provide both :capacityReservationId and :capacity_reservation_id' if attributes.key?(:'capacityReservationId') && attributes.key?(:'capacity_reservation_id')

  self.capacity_reservation_id = attributes[:'capacity_reservation_id'] if attributes[:'capacity_reservation_id']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.agent_config = attributes[:'agentConfig'] if attributes[:'agentConfig']

  raise 'You cannot provide both :agentConfig and :agent_config' if attributes.key?(:'agentConfig') && attributes.key?(:'agent_config')

  self.agent_config = attributes[:'agent_config'] if attributes[:'agent_config']

  self.shape = attributes[:'shape'] if attributes[:'shape']

  self.shape_config = attributes[:'shapeConfig'] if attributes[:'shapeConfig']

  raise 'You cannot provide both :shapeConfig and :shape_config' if attributes.key?(:'shapeConfig') && attributes.key?(:'shape_config')

  self.shape_config = attributes[:'shape_config'] if attributes[:'shape_config']

  self.instance_options = attributes[:'instanceOptions'] if attributes[:'instanceOptions']

  raise 'You cannot provide both :instanceOptions and :instance_options' if attributes.key?(:'instanceOptions') && attributes.key?(:'instance_options')

  self.instance_options = attributes[:'instance_options'] if attributes[:'instance_options']

  self.fault_domain = attributes[:'faultDomain'] if attributes[:'faultDomain']

  raise 'You cannot provide both :faultDomain and :fault_domain' if attributes.key?(:'faultDomain') && attributes.key?(:'fault_domain')

  self.fault_domain = attributes[:'fault_domain'] if attributes[:'fault_domain']

  self.launch_options = attributes[:'launchOptions'] if attributes[:'launchOptions']

  raise 'You cannot provide both :launchOptions and :launch_options' if attributes.key?(:'launchOptions') && attributes.key?(:'launch_options')

  self.launch_options = attributes[:'launch_options'] if attributes[:'launch_options']

  self.availability_config = attributes[:'availabilityConfig'] if attributes[:'availabilityConfig']

  raise 'You cannot provide both :availabilityConfig and :availability_config' if attributes.key?(:'availabilityConfig') && attributes.key?(:'availability_config')

  self.availability_config = attributes[:'availability_config'] if attributes[:'availability_config']
end

Instance Attribute Details

#agent_configOCI::Core::Models::UpdateInstanceAgentConfigDetails



42
43
44
# File 'lib/oci/core/models/update_instance_details.rb', line 42

def agent_config
  @agent_config
end

#availability_configOCI::Core::Models::UpdateInstanceAvailabilityConfigDetails



88
89
90
# File 'lib/oci/core/models/update_instance_details.rb', line 88

def availability_config
  @availability_config
end

#capacity_reservation_idString

The OCID of the compute capacity reservation this instance is launched under. You can remove the instance from a reservation by specifying an empty string as input for this field. For more information, see [Capacity Reservations](docs.cloud.oracle.com/iaas/Content/Compute/Tasks/reserve-capacity.htm#default).

Returns:

  • (String)


15
16
17
# File 'lib/oci/core/models/update_instance_details.rb', line 15

def capacity_reservation_id
  @capacity_reservation_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).

Example: ‘{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


23
24
25
# File 'lib/oci/core/models/update_instance_details.rb', line 23

def defined_tags
  @defined_tags
end

#display_nameString

A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.

Example: ‘My bare metal instance`

Returns:

  • (String)


31
32
33
# File 'lib/oci/core/models/update_instance_details.rb', line 31

def display_name
  @display_name
end

#fault_domainString

A fault domain is a grouping of hardware and infrastructure within an availability domain. Each availability domain contains three fault domains. Fault domains let you distribute your instances so that they are not on the same physical hardware within a single availability domain. A hardware failure or Compute hardware maintenance that affects one fault domain does not affect instances in other fault domains.

To get a list of fault domains, use the list_fault_domains operation in the Identity and Access Management Service API.

Example: FAULT-DOMAIN-1

Returns:

  • (String)


82
83
84
# File 'lib/oci/core/models/update_instance_details.rb', line 82

def fault_domain
  @fault_domain
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).

Example: ‘"Finance"`

Returns:

  • (Hash<String, String>)


39
40
41
# File 'lib/oci/core/models/update_instance_details.rb', line 39

def freeform_tags
  @freeform_tags
end

#instance_optionsOCI::Core::Models::InstanceOptions



67
68
69
# File 'lib/oci/core/models/update_instance_details.rb', line 67

def instance_options
  @instance_options
end

#launch_optionsOCI::Core::Models::UpdateLaunchOptions



85
86
87
# File 'lib/oci/core/models/update_instance_details.rb', line 85

def launch_options
  @launch_options
end

#shapeString

The shape of the instance. The shape determines the number of CPUs and the amount of memory allocated to the instance. For more information about how to change shapes, and a list of shapes that are supported, see [Editing an Instance](docs.cloud.oracle.com/iaas/Content/Compute/Tasks/resizinginstances.htm).

For details about the CPUs, memory, and other properties of each shape, see [Compute Shapes](docs.cloud.oracle.com/iaas/Content/Compute/References/computeshapes.htm).

The new shape must be compatible with the image that was used to launch the instance. You can enumerate all available shapes and determine image compatibility by calling list_shapes.

If the instance is running when you change the shape, the instance is rebooted.

Example: VM.Standard2.1

Returns:

  • (String)


61
62
63
# File 'lib/oci/core/models/update_instance_details.rb', line 61

def shape
  @shape
end

#shape_configOCI::Core::Models::UpdateInstanceShapeConfigDetails



64
65
66
# File 'lib/oci/core/models/update_instance_details.rb', line 64

def shape_config
  @shape_config
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/oci/core/models/update_instance_details.rb', line 91

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'capacity_reservation_id': :'capacityReservationId',
    'defined_tags': :'definedTags',
    'display_name': :'displayName',
    'freeform_tags': :'freeformTags',
    'agent_config': :'agentConfig',
    'shape': :'shape',
    'shape_config': :'shapeConfig',
    'instance_options': :'instanceOptions',
    'fault_domain': :'faultDomain',
    'launch_options': :'launchOptions',
    'availability_config': :'availabilityConfig'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/oci/core/models/update_instance_details.rb', line 110

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'capacity_reservation_id': :'String',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'display_name': :'String',
    'freeform_tags': :'Hash<String, String>',
    'agent_config': :'OCI::Core::Models::UpdateInstanceAgentConfigDetails',
    'shape': :'String',
    'shape_config': :'OCI::Core::Models::UpdateInstanceShapeConfigDetails',
    'instance_options': :'OCI::Core::Models::InstanceOptions',
    'fault_domain': :'String',
    'launch_options': :'OCI::Core::Models::UpdateLaunchOptions',
    'availability_config': :'OCI::Core::Models::UpdateInstanceAvailabilityConfigDetails'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/oci/core/models/update_instance_details.rb', line 221

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    capacity_reservation_id == other.capacity_reservation_id &&
    defined_tags == other.defined_tags &&
    display_name == other.display_name &&
    freeform_tags == other.freeform_tags &&
    agent_config == other.agent_config &&
    shape == other.shape &&
    shape_config == other.shape_config &&
    instance_options == other.instance_options &&
    fault_domain == other.fault_domain &&
    launch_options == other.launch_options &&
    availability_config == other.availability_config
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/oci/core/models/update_instance_details.rb', line 261

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


241
242
243
# File 'lib/oci/core/models/update_instance_details.rb', line 241

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



250
251
252
# File 'lib/oci/core/models/update_instance_details.rb', line 250

def hash
  [capacity_reservation_id, defined_tags, display_name, freeform_tags, agent_config, shape, shape_config, instance_options, fault_domain, launch_options, availability_config].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



294
295
296
297
298
299
300
301
302
303
# File 'lib/oci/core/models/update_instance_details.rb', line 294

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



288
289
290
# File 'lib/oci/core/models/update_instance_details.rb', line 288

def to_s
  to_hash.to_s
end