Class: OCI::Core::Models::UpdateInstancePoolPlacementConfigurationDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/core/models/update_instance_pool_placement_configuration_details.rb

Overview

The location for where an instance pool will place instances.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateInstancePoolPlacementConfigurationDetails

Initializes the object

Options Hash (attributes):

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/oci/core/models/update_instance_pool_placement_configuration_details.rb', line 54

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain']

  raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain')

  self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain']

  self.primary_subnet_id = attributes[:'primarySubnetId'] if attributes[:'primarySubnetId']

  raise 'You cannot provide both :primarySubnetId and :primary_subnet_id' if attributes.key?(:'primarySubnetId') && attributes.key?(:'primary_subnet_id')

  self.primary_subnet_id = attributes[:'primary_subnet_id'] if attributes[:'primary_subnet_id']

  self.secondary_vnic_subnets = attributes[:'secondaryVnicSubnets'] if attributes[:'secondaryVnicSubnets']

  raise 'You cannot provide both :secondaryVnicSubnets and :secondary_vnic_subnets' if attributes.key?(:'secondaryVnicSubnets') && attributes.key?(:'secondary_vnic_subnets')

  self.secondary_vnic_subnets = attributes[:'secondary_vnic_subnets'] if attributes[:'secondary_vnic_subnets']
end

Instance Attribute Details

#availability_domainString

[Required] The availability domain to place instances. Example: Uocm:PHX-AD-1

Returns:



13
14
15
# File 'lib/oci/core/models/update_instance_pool_placement_configuration_details.rb', line 13

def availability_domain
  @availability_domain
end

#primary_subnet_idString

[Required] The OCID of the primary subnet to place instances.

Returns:



17
18
19
# File 'lib/oci/core/models/update_instance_pool_placement_configuration_details.rb', line 17

def primary_subnet_id
  @primary_subnet_id
end

#secondary_vnic_subnetsArray<OCI::Core::Models::InstancePoolPlacementSecondaryVnicSubnet>

The set of subnet OCIDs for secondary VNICs for instances in the pool.

Returns:



21
22
23
# File 'lib/oci/core/models/update_instance_pool_placement_configuration_details.rb', line 21

def secondary_vnic_subnets
  @secondary_vnic_subnets
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



24
25
26
27
28
29
30
31
32
# File 'lib/oci/core/models/update_instance_pool_placement_configuration_details.rb', line 24

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'availability_domain': :'availabilityDomain',
    'primary_subnet_id': :'primarySubnetId',
    'secondary_vnic_subnets': :'secondaryVnicSubnets'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



35
36
37
38
39
40
41
42
43
# File 'lib/oci/core/models/update_instance_pool_placement_configuration_details.rb', line 35

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'availability_domain': :'String',
    'primary_subnet_id': :'String',
    'secondary_vnic_subnets': :'Array<OCI::Core::Models::InstancePoolPlacementSecondaryVnicSubnet>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • the other object to be compared



86
87
88
89
90
91
92
93
# File 'lib/oci/core/models/update_instance_pool_placement_configuration_details.rb', line 86

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    availability_domain == other.availability_domain &&
    primary_subnet_id == other.primary_subnet_id &&
    secondary_vnic_subnets == other.secondary_vnic_subnets
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/oci/core/models/update_instance_pool_placement_configuration_details.rb', line 118

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method

Parameters:

  • the other object to be compared

Returns:



98
99
100
# File 'lib/oci/core/models/update_instance_pool_placement_configuration_details.rb', line 98

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • Hash code



107
108
109
# File 'lib/oci/core/models/update_instance_pool_placement_configuration_details.rb', line 107

def hash
  [availability_domain, primary_subnet_id, secondary_vnic_subnets].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



151
152
153
154
155
156
157
158
159
160
# File 'lib/oci/core/models/update_instance_pool_placement_configuration_details.rb', line 151

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



145
146
147
# File 'lib/oci/core/models/update_instance_pool_placement_configuration_details.rb', line 145

def to_s
  to_hash.to_s
end