Class: OCI::Core::Models::UpdateInstanceShapeConfigDetails
- Inherits:
-
Object
- Object
- OCI::Core::Models::UpdateInstanceShapeConfigDetails
- Defined in:
- lib/oci/core/models/update_instance_shape_config_details.rb
Overview
The shape configuration requested for the instance. If provided, the instance will be updated with the resources specified. In the case where some properties are missing, the missing values will be set to the default for the provided `shape`.
Each shape only supports certain configurable values. If the `shape` is provided and the configuration values are invalid for that new `shape`, an error will be returned. If no `shape` is provided and the configuration values are invalid for the instance's existing shape, an error will be returned.
Constant Summary collapse
- BASELINE_OCPU_UTILIZATION_ENUM =
[ BASELINE_OCPU_UTILIZATION_BASELINE_1_8 = 'BASELINE_1_8'.freeze, BASELINE_OCPU_UTILIZATION_BASELINE_1_2 = 'BASELINE_1_2'.freeze, BASELINE_OCPU_UTILIZATION_BASELINE_1_1 = 'BASELINE_1_1'.freeze ].freeze
Instance Attribute Summary collapse
-
#baseline_ocpu_utilization ⇒ String
The baseline OCPU utilization for a subcore burstable VM instance.
-
#memory_in_gbs ⇒ Float
The total amount of memory available to the instance, in gigabytes.
-
#nvmes ⇒ Integer
The number of NVMe drives to be used for storage.
-
#ocpus ⇒ Float
The total number of OCPUs available to the instance.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateInstanceShapeConfigDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateInstanceShapeConfigDetails
Initializes the object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/oci/core/models/update_instance_shape_config_details.rb', line 84 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.ocpus = attributes[:'ocpus'] if attributes[:'ocpus'] self.memory_in_gbs = attributes[:'memoryInGBs'] if attributes[:'memoryInGBs'] raise 'You cannot provide both :memoryInGBs and :memory_in_gbs' if attributes.key?(:'memoryInGBs') && attributes.key?(:'memory_in_gbs') self.memory_in_gbs = attributes[:'memory_in_gbs'] if attributes[:'memory_in_gbs'] self.baseline_ocpu_utilization = attributes[:'baselineOcpuUtilization'] if attributes[:'baselineOcpuUtilization'] raise 'You cannot provide both :baselineOcpuUtilization and :baseline_ocpu_utilization' if attributes.key?(:'baselineOcpuUtilization') && attributes.key?(:'baseline_ocpu_utilization') self.baseline_ocpu_utilization = attributes[:'baseline_ocpu_utilization'] if attributes[:'baseline_ocpu_utilization'] self.nvmes = attributes[:'nvmes'] if attributes[:'nvmes'] end |
Instance Attribute Details
#baseline_ocpu_utilization ⇒ String
The baseline OCPU utilization for a subcore burstable VM instance. Leave this attribute blank for a non-burstable instance, or explicitly specify non-burstable with `BASELINE_1_1`.
The following values are supported:
-
`BASELINE_1_8` - baseline usage is 1/8 of an OCPU.
-
`BASELINE_1_2` - baseline usage is 1/2 of an OCPU.
-
`BASELINE_1_1` - baseline usage is an entire OCPU. This represents a non-burstable instance.
43 44 45 |
# File 'lib/oci/core/models/update_instance_shape_config_details.rb', line 43 def baseline_ocpu_utilization @baseline_ocpu_utilization end |
#memory_in_gbs ⇒ Float
The total amount of memory available to the instance, in gigabytes.
32 33 34 |
# File 'lib/oci/core/models/update_instance_shape_config_details.rb', line 32 def memory_in_gbs @memory_in_gbs end |
#nvmes ⇒ Integer
The number of NVMe drives to be used for storage. A single drive has 6.8 TB available.
48 49 50 |
# File 'lib/oci/core/models/update_instance_shape_config_details.rb', line 48 def nvmes @nvmes end |
#ocpus ⇒ Float
The total number of OCPUs available to the instance.
27 28 29 |
# File 'lib/oci/core/models/update_instance_shape_config_details.rb', line 27 def ocpus @ocpus end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
51 52 53 54 55 56 57 58 59 60 |
# File 'lib/oci/core/models/update_instance_shape_config_details.rb', line 51 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'ocpus': :'ocpus', 'memory_in_gbs': :'memoryInGBs', 'baseline_ocpu_utilization': :'baselineOcpuUtilization', 'nvmes': :'nvmes' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 69 70 71 72 |
# File 'lib/oci/core/models/update_instance_shape_config_details.rb', line 63 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'ocpus': :'Float', 'memory_in_gbs': :'Float', 'baseline_ocpu_utilization': :'String', 'nvmes': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
122 123 124 125 126 127 128 129 130 |
# File 'lib/oci/core/models/update_instance_shape_config_details.rb', line 122 def ==(other) return true if equal?(other) self.class == other.class && ocpus == other.ocpus && memory_in_gbs == other.memory_in_gbs && baseline_ocpu_utilization == other.baseline_ocpu_utilization && nvmes == other.nvmes end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/oci/core/models/update_instance_shape_config_details.rb', line 155 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
135 136 137 |
# File 'lib/oci/core/models/update_instance_shape_config_details.rb', line 135 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
144 145 146 |
# File 'lib/oci/core/models/update_instance_shape_config_details.rb', line 144 def hash [ocpus, memory_in_gbs, baseline_ocpu_utilization, nvmes].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
188 189 190 191 192 193 194 195 196 197 |
# File 'lib/oci/core/models/update_instance_shape_config_details.rb', line 188 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
182 183 184 |
# File 'lib/oci/core/models/update_instance_shape_config_details.rb', line 182 def to_s to_hash.to_s end |