Class: OCI::Core::Models::UpdateServiceGatewayDetails
- Inherits:
-
Object
- Object
- OCI::Core::Models::UpdateServiceGatewayDetails
- Defined in:
- lib/oci/core/models/update_service_gateway_details.rb
Overview
UpdateServiceGatewayDetails model.
Instance Attribute Summary collapse
-
#block_traffic ⇒ BOOLEAN
Whether the service gateway blocks all traffic through it.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
A user-friendly name.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#services ⇒ Array<OCI::Core::Models::ServiceIdRequestDetails>
List of all the
Serviceobjects you want enabled on this service gateway.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateServiceGatewayDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateServiceGatewayDetails
Initializes the object
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/oci/core/models/update_service_gateway_details.rb', line 91 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.block_traffic = attributes[:'blockTraffic'] unless attributes[:'blockTraffic'].nil? self.block_traffic = true if block_traffic.nil? && !attributes.key?(:'blockTraffic') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :blockTraffic and :block_traffic' if attributes.key?(:'blockTraffic') && attributes.key?(:'block_traffic') self.block_traffic = attributes[:'block_traffic'] unless attributes[:'block_traffic'].nil? self.block_traffic = true if block_traffic.nil? && !attributes.key?(:'blockTraffic') && !attributes.key?(:'block_traffic') # rubocop:disable Style/StringLiterals self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.services = attributes[:'services'] if attributes[:'services'] end |
Instance Attribute Details
#block_traffic ⇒ BOOLEAN
Whether the service gateway blocks all traffic through it. The default is false. When this is true, traffic is not routed to any services, regardless of route rules.
Example: true
15 16 17 |
# File 'lib/oci/core/models/update_service_gateway_details.rb', line 15 def block_traffic @block_traffic end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
23 24 25 |
# File 'lib/oci/core/models/update_service_gateway_details.rb', line 23 def @defined_tags end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
29 30 31 |
# File 'lib/oci/core/models/update_service_gateway_details.rb', line 29 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
37 38 39 |
# File 'lib/oci/core/models/update_service_gateway_details.rb', line 37 def @freeform_tags end |
#services ⇒ Array<OCI::Core::Models::ServiceIdRequestDetails>
List of all the Service objects you want enabled on this service gateway. Sending an empty list means you want to disable all services. Omitting this parameter entirely keeps the existing list of services intact.
You can also enable or disable a particular Service by using attach_service_id or detach_service_id.
For each enabled Service, make sure there’s a route rule with the Service object’s cidrBlock as the rule’s destination and the service gateway as the rule’s target. See RouteTable.
52 53 54 |
# File 'lib/oci/core/models/update_service_gateway_details.rb', line 52 def services @services end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/oci/core/models/update_service_gateway_details.rb', line 55 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'block_traffic': :'blockTraffic', 'defined_tags': :'definedTags', 'display_name': :'displayName', 'freeform_tags': :'freeformTags', 'services': :'services' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/oci/core/models/update_service_gateway_details.rb', line 68 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'block_traffic': :'BOOLEAN', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'freeform_tags': :'Hash<String, String>', 'services': :'Array<OCI::Core::Models::ServiceIdRequestDetails>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
133 134 135 136 137 138 139 140 141 142 |
# File 'lib/oci/core/models/update_service_gateway_details.rb', line 133 def ==(other) return true if equal?(other) self.class == other.class && block_traffic == other.block_traffic && == other. && display_name == other.display_name && == other. && services == other.services end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/oci/core/models/update_service_gateway_details.rb', line 167 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
147 148 149 |
# File 'lib/oci/core/models/update_service_gateway_details.rb', line 147 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
156 157 158 |
# File 'lib/oci/core/models/update_service_gateway_details.rb', line 156 def hash [block_traffic, , display_name, , services].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
200 201 202 203 204 205 206 207 208 209 |
# File 'lib/oci/core/models/update_service_gateway_details.rb', line 200 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
194 195 196 |
# File 'lib/oci/core/models/update_service_gateway_details.rb', line 194 def to_s to_hash.to_s end |