Class: OCI::Core::Models::UpdateSubnetDetails
- Inherits:
-
Object
- Object
- OCI::Core::Models::UpdateSubnetDetails
- Defined in:
- lib/oci/core/models/update_subnet_details.rb
Overview
UpdateSubnetDetails model.
Instance Attribute Summary collapse
-
#cidr_block ⇒ String
The CIDR block of the subnet.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#dhcp_options_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the set of DHCP options the subnet will use.
-
#display_name ⇒ String
A user-friendly name.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#ipv6_cidr_block ⇒ String
This is the IPv6 CIDR block for the subnet's IP address space.
-
#ipv6_cidr_blocks ⇒ Array<String>
The list of all IPv6 CIDR blocks (Oracle allocated IPv6 GUA, ULA or private IPv6 CIDR blocks, BYOIPv6 CIDR blocks) for the subnet that meets the following criteria: - The CIDR blocks must be valid.
-
#route_table_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the route table the subnet will use.
-
#security_list_ids ⇒ Array<String>
The OCIDs of the security list or lists the subnet will use.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateSubnetDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateSubnetDetails
Initializes the object
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/oci/core/models/update_subnet_details.rb', line 135 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'dhcpOptionsId'] if attributes[:'dhcpOptionsId'] raise 'You cannot provide both :dhcpOptionsId and :dhcp_options_id' if attributes.key?(:'dhcpOptionsId') && attributes.key?(:'dhcp_options_id') self. = attributes[:'dhcp_options_id'] if attributes[:'dhcp_options_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.route_table_id = attributes[:'routeTableId'] if attributes[:'routeTableId'] raise 'You cannot provide both :routeTableId and :route_table_id' if attributes.key?(:'routeTableId') && attributes.key?(:'route_table_id') self.route_table_id = attributes[:'route_table_id'] if attributes[:'route_table_id'] self.security_list_ids = attributes[:'securityListIds'] if attributes[:'securityListIds'] raise 'You cannot provide both :securityListIds and :security_list_ids' if attributes.key?(:'securityListIds') && attributes.key?(:'security_list_ids') self.security_list_ids = attributes[:'security_list_ids'] if attributes[:'security_list_ids'] self.cidr_block = attributes[:'cidrBlock'] if attributes[:'cidrBlock'] raise 'You cannot provide both :cidrBlock and :cidr_block' if attributes.key?(:'cidrBlock') && attributes.key?(:'cidr_block') self.cidr_block = attributes[:'cidr_block'] if attributes[:'cidr_block'] self.ipv6_cidr_block = attributes[:'ipv6CidrBlock'] if attributes[:'ipv6CidrBlock'] raise 'You cannot provide both :ipv6CidrBlock and :ipv6_cidr_block' if attributes.key?(:'ipv6CidrBlock') && attributes.key?(:'ipv6_cidr_block') self.ipv6_cidr_block = attributes[:'ipv6_cidr_block'] if attributes[:'ipv6_cidr_block'] self.ipv6_cidr_blocks = attributes[:'ipv6CidrBlocks'] if attributes[:'ipv6CidrBlocks'] raise 'You cannot provide both :ipv6CidrBlocks and :ipv6_cidr_blocks' if attributes.key?(:'ipv6CidrBlocks') && attributes.key?(:'ipv6_cidr_blocks') self.ipv6_cidr_blocks = attributes[:'ipv6_cidr_blocks'] if attributes[:'ipv6_cidr_blocks'] end |
Instance Attribute Details
#cidr_block ⇒ String
The CIDR block of the subnet. The new CIDR block must meet the following criteria:
-
Must be valid.
-
The CIDR block's IP range must be completely within one of the VCN's CIDR block ranges.
-
The old and new CIDR block ranges must use the same network address. Example: `10.0.0.0/25` and `10.0.0.0/24`.
-
Must contain all IP addresses in use in the old CIDR range.
-
The new CIDR range's broadcast address (last IP address of CIDR range) must not be an IP address in use in the old CIDR range.
*Note:* If you are changing the CIDR block, you cannot create VNICs or private IPs for this resource while the update is in progress.
Example: `172.16.0.0/16`
63 64 65 |
# File 'lib/oci/core/models/update_subnet_details.rb', line 63 def cidr_block @cidr_block end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: `{"CostCenter": "42"}`
16 17 18 |
# File 'lib/oci/core/models/update_subnet_details.rb', line 16 def @defined_tags end |
#dhcp_options_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the set of DHCP options the subnet will use.
21 22 23 |
# File 'lib/oci/core/models/update_subnet_details.rb', line 21 def @dhcp_options_id end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
27 28 29 |
# File 'lib/oci/core/models/update_subnet_details.rb', line 27 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: `"Finance"`
35 36 37 |
# File 'lib/oci/core/models/update_subnet_details.rb', line 35 def @freeform_tags end |
#ipv6_cidr_block ⇒ String
This is the IPv6 CIDR block for the subnet's IP address space. The subnet size is always /64. See [IPv6 Addresses](docs.cloud.oracle.com/iaas/Content/Network/Concepts/ipv6.htm). The provided CIDR must maintain the following rules -
-
The IPv6 CIDR block is valid and correctly formatted.
-
The IPv6 CIDR is within the parent VCN IPv6 range.
Example: `2001:0db8:0123:1111::/64`
76 77 78 |
# File 'lib/oci/core/models/update_subnet_details.rb', line 76 def ipv6_cidr_block @ipv6_cidr_block end |
#ipv6_cidr_blocks ⇒ Array<String>
The list of all IPv6 CIDR blocks (Oracle allocated IPv6 GUA, ULA or private IPv6 CIDR blocks, BYOIPv6 CIDR blocks) for the subnet that meets the following criteria:
-
The CIDR blocks must be valid.
-
Multiple CIDR blocks must not overlap each other or the on-premises network CIDR block.
-
The number of CIDR blocks must not exceed the limit of IPv6 CIDR blocks allowed to a subnet.
84 85 86 |
# File 'lib/oci/core/models/update_subnet_details.rb', line 84 def ipv6_cidr_blocks @ipv6_cidr_blocks end |
#route_table_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the route table the subnet will use.
40 41 42 |
# File 'lib/oci/core/models/update_subnet_details.rb', line 40 def route_table_id @route_table_id end |
#security_list_ids ⇒ Array<String>
The OCIDs of the security list or lists the subnet will use. This replaces the entire current set of security lists. Remember that security lists are associated *with the subnet*, but the rules are applied to the individual VNICs in the subnet.
48 49 50 |
# File 'lib/oci/core/models/update_subnet_details.rb', line 48 def security_list_ids @security_list_ids end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/oci/core/models/update_subnet_details.rb', line 87 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'defined_tags': :'definedTags', 'dhcp_options_id': :'dhcpOptionsId', 'display_name': :'displayName', 'freeform_tags': :'freeformTags', 'route_table_id': :'routeTableId', 'security_list_ids': :'securityListIds', 'cidr_block': :'cidrBlock', 'ipv6_cidr_block': :'ipv6CidrBlock', 'ipv6_cidr_blocks': :'ipv6CidrBlocks' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/oci/core/models/update_subnet_details.rb', line 104 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'defined_tags': :'Hash<String, Hash<String, Object>>', 'dhcp_options_id': :'String', 'display_name': :'String', 'freeform_tags': :'Hash<String, String>', 'route_table_id': :'String', 'security_list_ids': :'Array<String>', 'cidr_block': :'String', 'ipv6_cidr_block': :'String', 'ipv6_cidr_blocks': :'Array<String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/oci/core/models/update_subnet_details.rb', line 203 def ==(other) return true if equal?(other) self.class == other.class && == other. && == other. && display_name == other.display_name && == other. && route_table_id == other.route_table_id && security_list_ids == other.security_list_ids && cidr_block == other.cidr_block && ipv6_cidr_block == other.ipv6_cidr_block && ipv6_cidr_blocks == other.ipv6_cidr_blocks end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 |
# File 'lib/oci/core/models/update_subnet_details.rb', line 241 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
221 222 223 |
# File 'lib/oci/core/models/update_subnet_details.rb', line 221 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
230 231 232 |
# File 'lib/oci/core/models/update_subnet_details.rb', line 230 def hash [, , display_name, , route_table_id, security_list_ids, cidr_block, ipv6_cidr_block, ipv6_cidr_blocks].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
274 275 276 277 278 279 280 281 282 283 |
# File 'lib/oci/core/models/update_subnet_details.rb', line 274 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
268 269 270 |
# File 'lib/oci/core/models/update_subnet_details.rb', line 268 def to_s to_hash.to_s end |