Class: OCI::Core::Models::UpdateVolumeAttachmentDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/core/models/update_volume_attachment_details.rb

Overview

details for updating a volume attachment.

Constant Summary collapse

ISCSI_LOGIN_STATE_ENUM =
[
   = 'UNKNOWN'.freeze,
   = 'LOGGING_IN'.freeze,
   = 'LOGIN_SUCCEEDED'.freeze,
   = 'LOGIN_FAILED'.freeze,
   = 'LOGGING_OUT'.freeze,
   = 'LOGOUT_SUCCEEDED'.freeze,
   = 'LOGOUT_FAILED'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateVolumeAttachmentDetails

Initializes the object

Options Hash (attributes):



51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/oci/core/models/update_volume_attachment_details.rb', line 51

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self. = attributes[:'iscsiLoginState'] if attributes[:'iscsiLoginState']

  raise 'You cannot provide both :iscsiLoginState and :iscsi_login_state' if attributes.key?(:'iscsiLoginState') && attributes.key?(:'iscsi_login_state')

  self. = attributes[:'iscsi_login_state'] if attributes[:'iscsi_login_state']
end

Instance Attribute Details

#iscsi_login_stateString

The iscsi login state of the volume attachment. For a multipath volume attachment, all iscsi sessions need to be all logged-in or logged-out to be in logged-in or logged-out state.



24
25
26
# File 'lib/oci/core/models/update_volume_attachment_details.rb', line 24

def 
  
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



27
28
29
30
31
32
33
# File 'lib/oci/core/models/update_volume_attachment_details.rb', line 27

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'iscsi_login_state': :'iscsiLoginState'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



36
37
38
39
40
41
42
# File 'lib/oci/core/models/update_volume_attachment_details.rb', line 36

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'iscsi_login_state': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.



79
80
81
82
83
84
# File 'lib/oci/core/models/update_volume_attachment_details.rb', line 79

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
     == other.
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/oci/core/models/update_volume_attachment_details.rb', line 109

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method


89
90
91
# File 'lib/oci/core/models/update_volume_attachment_details.rb', line 89

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.



98
99
100
# File 'lib/oci/core/models/update_volume_attachment_details.rb', line 98

def hash
  [].hash
end

#to_hashHash

Returns the object in the form of hash



142
143
144
145
146
147
148
149
150
151
# File 'lib/oci/core/models/update_volume_attachment_details.rb', line 142

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



136
137
138
# File 'lib/oci/core/models/update_volume_attachment_details.rb', line 136

def to_s
  to_hash.to_s
end