Class: OCI::Core::Models::UpdateVolumeDetails
- Inherits:
-
Object
- Object
- OCI::Core::Models::UpdateVolumeDetails
- Defined in:
- lib/oci/core/models/update_volume_details.rb
Overview
UpdateVolumeDetails model.
Instance Attribute Summary collapse
-
#block_volume_replicas ⇒ Array<OCI::Core::Models::BlockVolumeReplicaDetails>
The list of block volume replicas that this volume will be updated to have in the specified destination availability domains.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
A user-friendly name.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#is_auto_tune_enabled ⇒ BOOLEAN
Specifies whether the auto-tune performance is enabled for this volume.
-
#size_in_gbs ⇒ Integer
The size to resize the volume to in GBs.
-
#vpus_per_gb ⇒ Integer
The number of volume performance units (VPUs) that will be applied to this volume per GB, representing the Block Volume service’s elastic performance options.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateVolumeDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateVolumeDetails
Initializes the object
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/oci/core/models/update_volume_details.rb', line 105 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.vpus_per_gb = attributes[:'vpusPerGB'] if attributes[:'vpusPerGB'] raise 'You cannot provide both :vpusPerGB and :vpus_per_gb' if attributes.key?(:'vpusPerGB') && attributes.key?(:'vpus_per_gb') self.vpus_per_gb = attributes[:'vpus_per_gb'] if attributes[:'vpus_per_gb'] self.size_in_gbs = attributes[:'sizeInGBs'] if attributes[:'sizeInGBs'] raise 'You cannot provide both :sizeInGBs and :size_in_gbs' if attributes.key?(:'sizeInGBs') && attributes.key?(:'size_in_gbs') self.size_in_gbs = attributes[:'size_in_gbs'] if attributes[:'size_in_gbs'] self.is_auto_tune_enabled = attributes[:'isAutoTuneEnabled'] unless attributes[:'isAutoTuneEnabled'].nil? raise 'You cannot provide both :isAutoTuneEnabled and :is_auto_tune_enabled' if attributes.key?(:'isAutoTuneEnabled') && attributes.key?(:'is_auto_tune_enabled') self.is_auto_tune_enabled = attributes[:'is_auto_tune_enabled'] unless attributes[:'is_auto_tune_enabled'].nil? self.block_volume_replicas = attributes[:'blockVolumeReplicas'] if attributes[:'blockVolumeReplicas'] raise 'You cannot provide both :blockVolumeReplicas and :block_volume_replicas' if attributes.key?(:'blockVolumeReplicas') && attributes.key?(:'block_volume_replicas') self.block_volume_replicas = attributes[:'block_volume_replicas'] if attributes[:'block_volume_replicas'] end |
Instance Attribute Details
#block_volume_replicas ⇒ Array<OCI::Core::Models::BlockVolumeReplicaDetails>
The list of block volume replicas that this volume will be updated to have in the specified destination availability domains.
60 61 62 |
# File 'lib/oci/core/models/update_volume_details.rb', line 60 def block_volume_replicas @block_volume_replicas end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
16 17 18 |
# File 'lib/oci/core/models/update_volume_details.rb', line 16 def end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
22 23 24 |
# File 'lib/oci/core/models/update_volume_details.rb', line 22 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
30 31 32 |
# File 'lib/oci/core/models/update_volume_details.rb', line 30 def end |
#is_auto_tune_enabled ⇒ BOOLEAN
Specifies whether the auto-tune performance is enabled for this volume.
54 55 56 |
# File 'lib/oci/core/models/update_volume_details.rb', line 54 def is_auto_tune_enabled @is_auto_tune_enabled end |
#size_in_gbs ⇒ Integer
The size to resize the volume to in GBs. Has to be larger than the current size.
49 50 51 |
# File 'lib/oci/core/models/update_volume_details.rb', line 49 def size_in_gbs @size_in_gbs end |
#vpus_per_gb ⇒ Integer
The number of volume performance units (VPUs) that will be applied to this volume per GB, representing the Block Volume service’s elastic performance options. See [Block Volume Elastic Performance](docs.cloud.oracle.com/iaas/Content/Block/Concepts/blockvolumeelasticperformance.htm) for more information.
Allowed values:
* `0`: Represents Lower Cost option.
* `10`: Represents Balanced option.
* `20`: Represents Higher Performance option.
45 46 47 |
# File 'lib/oci/core/models/update_volume_details.rb', line 45 def vpus_per_gb @vpus_per_gb end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/oci/core/models/update_volume_details.rb', line 63 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'defined_tags': :'definedTags', 'display_name': :'displayName', 'freeform_tags': :'freeformTags', 'vpus_per_gb': :'vpusPerGB', 'size_in_gbs': :'sizeInGBs', 'is_auto_tune_enabled': :'isAutoTuneEnabled', 'block_volume_replicas': :'blockVolumeReplicas' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/oci/core/models/update_volume_details.rb', line 78 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'defined_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'freeform_tags': :'Hash<String, String>', 'vpus_per_gb': :'Integer', 'size_in_gbs': :'Integer', 'is_auto_tune_enabled': :'BOOLEAN', 'block_volume_replicas': :'Array<OCI::Core::Models::BlockVolumeReplicaDetails>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/oci/core/models/update_volume_details.rb', line 161 def ==(other) return true if equal?(other) self.class == other.class && == other. && display_name == other.display_name && == other. && vpus_per_gb == other.vpus_per_gb && size_in_gbs == other.size_in_gbs && is_auto_tune_enabled == other.is_auto_tune_enabled && block_volume_replicas == other.block_volume_replicas end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/oci/core/models/update_volume_details.rb', line 197 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
177 178 179 |
# File 'lib/oci/core/models/update_volume_details.rb', line 177 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
186 187 188 |
# File 'lib/oci/core/models/update_volume_details.rb', line 186 def hash [, display_name, , vpus_per_gb, size_in_gbs, is_auto_tune_enabled, block_volume_replicas].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
230 231 232 233 234 235 236 237 238 239 |
# File 'lib/oci/core/models/update_volume_details.rb', line 230 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
224 225 226 |
# File 'lib/oci/core/models/update_volume_details.rb', line 224 def to_s to_hash.to_s end |