Class: OCI::Core::Models::UpdateVolumeGroupDetails
- Inherits:
-
Object
- Object
- OCI::Core::Models::UpdateVolumeGroupDetails
- Defined in:
- lib/oci/core/models/update_volume_group_details.rb
Overview
UpdateVolumeGroupDetails model.
Instance Attribute Summary collapse
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
A user-friendly name.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#volume_group_replicas ⇒ Array<OCI::Core::Models::VolumeGroupReplicaDetails>
The list of volume group replicas that this volume group will be updated to have in the specified destination availability domains.
-
#volume_ids ⇒ Array<String>
OCIDs for the volumes in this volume group.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateVolumeGroupDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateVolumeGroupDetails
Initializes the object
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/oci/core/models/update_volume_group_details.rb', line 79 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.volume_ids = attributes[:'volumeIds'] if attributes[:'volumeIds'] raise 'You cannot provide both :volumeIds and :volume_ids' if attributes.key?(:'volumeIds') && attributes.key?(:'volume_ids') self.volume_ids = attributes[:'volume_ids'] if attributes[:'volume_ids'] self.volume_group_replicas = attributes[:'volumeGroupReplicas'] if attributes[:'volumeGroupReplicas'] raise 'You cannot provide both :volumeGroupReplicas and :volume_group_replicas' if attributes.key?(:'volumeGroupReplicas') && attributes.key?(:'volume_group_replicas') self.volume_group_replicas = attributes[:'volume_group_replicas'] if attributes[:'volume_group_replicas'] end |
Instance Attribute Details
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
16 17 18 |
# File 'lib/oci/core/models/update_volume_group_details.rb', line 16 def end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
22 23 24 |
# File 'lib/oci/core/models/update_volume_group_details.rb', line 22 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
30 31 32 |
# File 'lib/oci/core/models/update_volume_group_details.rb', line 30 def end |
#volume_group_replicas ⇒ Array<OCI::Core::Models::VolumeGroupReplicaDetails>
The list of volume group replicas that this volume group will be updated to have in the specified destination availability domains.
40 41 42 |
# File 'lib/oci/core/models/update_volume_group_details.rb', line 40 def volume_group_replicas @volume_group_replicas end |
#volume_ids ⇒ Array<String>
OCIDs for the volumes in this volume group.
34 35 36 |
# File 'lib/oci/core/models/update_volume_group_details.rb', line 34 def volume_ids @volume_ids end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/oci/core/models/update_volume_group_details.rb', line 43 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'defined_tags': :'definedTags', 'display_name': :'displayName', 'freeform_tags': :'freeformTags', 'volume_ids': :'volumeIds', 'volume_group_replicas': :'volumeGroupReplicas' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/oci/core/models/update_volume_group_details.rb', line 56 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'defined_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'freeform_tags': :'Hash<String, String>', 'volume_ids': :'Array<String>', 'volume_group_replicas': :'Array<OCI::Core::Models::VolumeGroupReplicaDetails>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
123 124 125 126 127 128 129 130 131 132 |
# File 'lib/oci/core/models/update_volume_group_details.rb', line 123 def ==(other) return true if equal?(other) self.class == other.class && == other. && display_name == other.display_name && == other. && volume_ids == other.volume_ids && volume_group_replicas == other.volume_group_replicas end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/oci/core/models/update_volume_group_details.rb', line 157 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
137 138 139 |
# File 'lib/oci/core/models/update_volume_group_details.rb', line 137 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
146 147 148 |
# File 'lib/oci/core/models/update_volume_group_details.rb', line 146 def hash [, display_name, , volume_ids, volume_group_replicas].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
190 191 192 193 194 195 196 197 198 199 |
# File 'lib/oci/core/models/update_volume_group_details.rb', line 190 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
184 185 186 |
# File 'lib/oci/core/models/update_volume_group_details.rb', line 184 def to_s to_hash.to_s end |