Class: OCI::Core::Models::UpdateVtapDetails
- Inherits:
-
Object
- Object
- OCI::Core::Models::UpdateVtapDetails
- Defined in:
- lib/oci/core/models/update_vtap_details.rb
Overview
These details can be included in a request to update a virtual test access point (VTAP).
Constant Summary collapse
- ENCAPSULATION_PROTOCOL_ENUM =
[ ENCAPSULATION_PROTOCOL_VXLAN = 'VXLAN'.freeze ].freeze
- TRAFFIC_MODE_ENUM =
[ TRAFFIC_MODE_DEFAULT = 'DEFAULT'.freeze, TRAFFIC_MODE_PRIORITY = 'PRIORITY'.freeze ].freeze
- TARGET_TYPE_ENUM =
[ TARGET_TYPE_VNIC = 'VNIC'.freeze, TARGET_TYPE_NETWORK_LOAD_BALANCER = 'NETWORK_LOAD_BALANCER'.freeze, TARGET_TYPE_IP_ADDRESS = 'IP_ADDRESS'.freeze ].freeze
- SOURCE_TYPE_ENUM =
[ SOURCE_TYPE_VNIC = 'VNIC'.freeze, SOURCE_TYPE_SUBNET = 'SUBNET'.freeze, SOURCE_TYPE_LOAD_BALANCER = 'LOAD_BALANCER'.freeze, SOURCE_TYPE_DB_SYSTEM = 'DB_SYSTEM'.freeze, SOURCE_TYPE_EXADATA_VM_CLUSTER = 'EXADATA_VM_CLUSTER'.freeze, SOURCE_TYPE_AUTONOMOUS_DATA_WAREHOUSE = 'AUTONOMOUS_DATA_WAREHOUSE'.freeze ].freeze
Instance Attribute Summary collapse
-
#capture_filter_id ⇒ String
The capture filter's Oracle ID ([OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)).
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
A user-friendly name.
-
#encapsulation_protocol ⇒ String
Defines an encapsulation header type for the VTAP's mirrored traffic.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#is_vtap_enabled ⇒ BOOLEAN
Used to start or stop a `Vtap` resource.
-
#max_packet_size ⇒ Integer
The maximum size of the packets to be included in the filter.
-
#source_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the source point where packets are captured.
-
#source_private_endpoint_ip ⇒ String
The IP Address of the source private endpoint.
-
#source_private_endpoint_subnet_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the subnet that source private endpoint belongs to.
-
#source_type ⇒ String
The source type for the VTAP.
-
#target_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the destination resource where mirrored packets are sent.
-
#target_ip ⇒ String
The IP address of the destination resource where mirrored packets are sent.
-
#target_type ⇒ String
The target type for the VTAP.
-
#traffic_mode ⇒ String
Used to control the priority of traffic.
-
#vxlan_network_identifier ⇒ Integer
The virtual extensible LAN (VXLAN) network identifier (or VXLAN segment ID) that uniquely identifies the VXLAN.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateVtapDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateVtapDetails
Initializes the object
192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/oci/core/models/update_vtap_details.rb', line 192 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.source_id = attributes[:'sourceId'] if attributes[:'sourceId'] raise 'You cannot provide both :sourceId and :source_id' if attributes.key?(:'sourceId') && attributes.key?(:'source_id') self.source_id = attributes[:'source_id'] if attributes[:'source_id'] self.target_id = attributes[:'targetId'] if attributes[:'targetId'] raise 'You cannot provide both :targetId and :target_id' if attributes.key?(:'targetId') && attributes.key?(:'target_id') self.target_id = attributes[:'target_id'] if attributes[:'target_id'] self.target_ip = attributes[:'targetIp'] if attributes[:'targetIp'] raise 'You cannot provide both :targetIp and :target_ip' if attributes.key?(:'targetIp') && attributes.key?(:'target_ip') self.target_ip = attributes[:'target_ip'] if attributes[:'target_ip'] self.capture_filter_id = attributes[:'captureFilterId'] if attributes[:'captureFilterId'] raise 'You cannot provide both :captureFilterId and :capture_filter_id' if attributes.key?(:'captureFilterId') && attributes.key?(:'capture_filter_id') self.capture_filter_id = attributes[:'capture_filter_id'] if attributes[:'capture_filter_id'] self.encapsulation_protocol = attributes[:'encapsulationProtocol'] if attributes[:'encapsulationProtocol'] raise 'You cannot provide both :encapsulationProtocol and :encapsulation_protocol' if attributes.key?(:'encapsulationProtocol') && attributes.key?(:'encapsulation_protocol') self.encapsulation_protocol = attributes[:'encapsulation_protocol'] if attributes[:'encapsulation_protocol'] self.vxlan_network_identifier = attributes[:'vxlanNetworkIdentifier'] if attributes[:'vxlanNetworkIdentifier'] raise 'You cannot provide both :vxlanNetworkIdentifier and :vxlan_network_identifier' if attributes.key?(:'vxlanNetworkIdentifier') && attributes.key?(:'vxlan_network_identifier') self.vxlan_network_identifier = attributes[:'vxlan_network_identifier'] if attributes[:'vxlan_network_identifier'] self.is_vtap_enabled = attributes[:'isVtapEnabled'] unless attributes[:'isVtapEnabled'].nil? self.is_vtap_enabled = false if is_vtap_enabled.nil? && !attributes.key?(:'isVtapEnabled') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isVtapEnabled and :is_vtap_enabled' if attributes.key?(:'isVtapEnabled') && attributes.key?(:'is_vtap_enabled') self.is_vtap_enabled = attributes[:'is_vtap_enabled'] unless attributes[:'is_vtap_enabled'].nil? self.is_vtap_enabled = false if is_vtap_enabled.nil? && !attributes.key?(:'isVtapEnabled') && !attributes.key?(:'is_vtap_enabled') # rubocop:disable Style/StringLiterals self.traffic_mode = attributes[:'trafficMode'] if attributes[:'trafficMode'] self.traffic_mode = "DEFAULT" if traffic_mode.nil? && !attributes.key?(:'trafficMode') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :trafficMode and :traffic_mode' if attributes.key?(:'trafficMode') && attributes.key?(:'traffic_mode') self.traffic_mode = attributes[:'traffic_mode'] if attributes[:'traffic_mode'] self.traffic_mode = "DEFAULT" if traffic_mode.nil? && !attributes.key?(:'trafficMode') && !attributes.key?(:'traffic_mode') # rubocop:disable Style/StringLiterals self.max_packet_size = attributes[:'maxPacketSize'] if attributes[:'maxPacketSize'] raise 'You cannot provide both :maxPacketSize and :max_packet_size' if attributes.key?(:'maxPacketSize') && attributes.key?(:'max_packet_size') self.max_packet_size = attributes[:'max_packet_size'] if attributes[:'max_packet_size'] self.source_private_endpoint_ip = attributes[:'sourcePrivateEndpointIp'] if attributes[:'sourcePrivateEndpointIp'] raise 'You cannot provide both :sourcePrivateEndpointIp and :source_private_endpoint_ip' if attributes.key?(:'sourcePrivateEndpointIp') && attributes.key?(:'source_private_endpoint_ip') self.source_private_endpoint_ip = attributes[:'source_private_endpoint_ip'] if attributes[:'source_private_endpoint_ip'] self.source_private_endpoint_subnet_id = attributes[:'sourcePrivateEndpointSubnetId'] if attributes[:'sourcePrivateEndpointSubnetId'] raise 'You cannot provide both :sourcePrivateEndpointSubnetId and :source_private_endpoint_subnet_id' if attributes.key?(:'sourcePrivateEndpointSubnetId') && attributes.key?(:'source_private_endpoint_subnet_id') self.source_private_endpoint_subnet_id = attributes[:'source_private_endpoint_subnet_id'] if attributes[:'source_private_endpoint_subnet_id'] self.target_type = attributes[:'targetType'] if attributes[:'targetType'] raise 'You cannot provide both :targetType and :target_type' if attributes.key?(:'targetType') && attributes.key?(:'target_type') self.target_type = attributes[:'target_type'] if attributes[:'target_type'] self.source_type = attributes[:'sourceType'] if attributes[:'sourceType'] raise 'You cannot provide both :sourceType and :source_type' if attributes.key?(:'sourceType') && attributes.key?(:'source_type') self.source_type = attributes[:'source_type'] if attributes[:'source_type'] end |
Instance Attribute Details
#capture_filter_id ⇒ String
The capture filter's Oracle ID ([OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)).
74 75 76 |
# File 'lib/oci/core/models/update_vtap_details.rb', line 74 def capture_filter_id @capture_filter_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: `{"CostCenter": "42"}`
40 41 42 |
# File 'lib/oci/core/models/update_vtap_details.rb', line 40 def @defined_tags end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
46 47 48 |
# File 'lib/oci/core/models/update_vtap_details.rb', line 46 def display_name @display_name end |
#encapsulation_protocol ⇒ String
Defines an encapsulation header type for the VTAP's mirrored traffic.
79 80 81 |
# File 'lib/oci/core/models/update_vtap_details.rb', line 79 def encapsulation_protocol @encapsulation_protocol end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: `"Finance"`
54 55 56 |
# File 'lib/oci/core/models/update_vtap_details.rb', line 54 def @freeform_tags end |
#is_vtap_enabled ⇒ BOOLEAN
Used to start or stop a `Vtap` resource.
-
`TRUE` directs the VTAP to start mirroring traffic.
-
`FALSE` (Default) directs the VTAP to stop mirroring traffic.
92 93 94 |
# File 'lib/oci/core/models/update_vtap_details.rb', line 92 def is_vtap_enabled @is_vtap_enabled end |
#max_packet_size ⇒ Integer
The maximum size of the packets to be included in the filter.
100 101 102 |
# File 'lib/oci/core/models/update_vtap_details.rb', line 100 def max_packet_size @max_packet_size end |
#source_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the source point where packets are captured.
59 60 61 |
# File 'lib/oci/core/models/update_vtap_details.rb', line 59 def source_id @source_id end |
#source_private_endpoint_ip ⇒ String
The IP Address of the source private endpoint.
105 106 107 |
# File 'lib/oci/core/models/update_vtap_details.rb', line 105 def source_private_endpoint_ip @source_private_endpoint_ip end |
#source_private_endpoint_subnet_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the subnet that source private endpoint belongs to.
110 111 112 |
# File 'lib/oci/core/models/update_vtap_details.rb', line 110 def source_private_endpoint_subnet_id @source_private_endpoint_subnet_id end |
#source_type ⇒ String
The source type for the VTAP.
120 121 122 |
# File 'lib/oci/core/models/update_vtap_details.rb', line 120 def source_type @source_type end |
#target_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the destination resource where mirrored packets are sent.
64 65 66 |
# File 'lib/oci/core/models/update_vtap_details.rb', line 64 def target_id @target_id end |
#target_ip ⇒ String
The IP address of the destination resource where mirrored packets are sent.
69 70 71 |
# File 'lib/oci/core/models/update_vtap_details.rb', line 69 def target_ip @target_ip end |
#target_type ⇒ String
The target type for the VTAP.
115 116 117 |
# File 'lib/oci/core/models/update_vtap_details.rb', line 115 def target_type @target_type end |
#traffic_mode ⇒ String
Used to control the priority of traffic. It is an optional field. If it not passed, the value is DEFAULT
96 97 98 |
# File 'lib/oci/core/models/update_vtap_details.rb', line 96 def traffic_mode @traffic_mode end |
#vxlan_network_identifier ⇒ Integer
The virtual extensible LAN (VXLAN) network identifier (or VXLAN segment ID) that uniquely identifies the VXLAN.
84 85 86 |
# File 'lib/oci/core/models/update_vtap_details.rb', line 84 def vxlan_network_identifier @vxlan_network_identifier end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/oci/core/models/update_vtap_details.rb', line 123 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'defined_tags': :'definedTags', 'display_name': :'displayName', 'freeform_tags': :'freeformTags', 'source_id': :'sourceId', 'target_id': :'targetId', 'target_ip': :'targetIp', 'capture_filter_id': :'captureFilterId', 'encapsulation_protocol': :'encapsulationProtocol', 'vxlan_network_identifier': :'vxlanNetworkIdentifier', 'is_vtap_enabled': :'isVtapEnabled', 'traffic_mode': :'trafficMode', 'max_packet_size': :'maxPacketSize', 'source_private_endpoint_ip': :'sourcePrivateEndpointIp', 'source_private_endpoint_subnet_id': :'sourcePrivateEndpointSubnetId', 'target_type': :'targetType', 'source_type': :'sourceType' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/oci/core/models/update_vtap_details.rb', line 147 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'defined_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'freeform_tags': :'Hash<String, String>', 'source_id': :'String', 'target_id': :'String', 'target_ip': :'String', 'capture_filter_id': :'String', 'encapsulation_protocol': :'String', 'vxlan_network_identifier': :'Integer', 'is_vtap_enabled': :'BOOLEAN', 'traffic_mode': :'String', 'max_packet_size': :'Integer', 'source_private_endpoint_ip': :'String', 'source_private_endpoint_subnet_id': :'String', 'target_type': :'String', 'source_type': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 |
# File 'lib/oci/core/models/update_vtap_details.rb', line 338 def ==(other) return true if equal?(other) self.class == other.class && == other. && display_name == other.display_name && == other. && source_id == other.source_id && target_id == other.target_id && target_ip == other.target_ip && capture_filter_id == other.capture_filter_id && encapsulation_protocol == other.encapsulation_protocol && vxlan_network_identifier == other.vxlan_network_identifier && is_vtap_enabled == other.is_vtap_enabled && traffic_mode == other.traffic_mode && max_packet_size == other.max_packet_size && source_private_endpoint_ip == other.source_private_endpoint_ip && source_private_endpoint_subnet_id == other.source_private_endpoint_subnet_id && target_type == other.target_type && source_type == other.source_type end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 |
# File 'lib/oci/core/models/update_vtap_details.rb', line 383 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
363 364 365 |
# File 'lib/oci/core/models/update_vtap_details.rb', line 363 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
372 373 374 |
# File 'lib/oci/core/models/update_vtap_details.rb', line 372 def hash [, display_name, , source_id, target_id, target_ip, capture_filter_id, encapsulation_protocol, vxlan_network_identifier, is_vtap_enabled, traffic_mode, max_packet_size, source_private_endpoint_ip, source_private_endpoint_subnet_id, target_type, source_type].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
416 417 418 419 420 421 422 423 424 425 |
# File 'lib/oci/core/models/update_vtap_details.rb', line 416 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
410 411 412 |
# File 'lib/oci/core/models/update_vtap_details.rb', line 410 def to_s to_hash.to_s end |