Class: OCI::Core::Models::Vcn
- Inherits:
-
Object
- Object
- OCI::Core::Models::Vcn
- Defined in:
- lib/oci/core/models/vcn.rb
Overview
A virtual cloud network (VCN). For more information, see [Overview of the Networking Service](docs.cloud.oracle.com/iaas/Content/Network/Concepts/overview.htm).
To use any of the API operations, you must be authorized in an IAM policy. If you’re not authorized, talk to an administrator. If you’re an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/iaas/Content/Identity/Concepts/policygetstarted.htm).
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze, LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze, LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze, LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#cidr_block ⇒ String
[Required] Deprecated.
-
#cidr_blocks ⇒ Array<String>
[Required] The list of IPv4 CIDR blocks the VCN will use.
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the VCN.
-
#default_dhcp_options_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) for the VCN’s default set of DHCP options.
-
#default_route_table_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) for the VCN’s default route table.
-
#default_security_list_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) for the VCN’s default security list.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
A user-friendly name.
-
#dns_label ⇒ String
A DNS label for the VCN, used in conjunction with the VNIC’s hostname and subnet’s DNS label to form a fully qualified domain name (FQDN) for each VNIC within this subnet (for example,
bminstance-1.subnet123.vcn1.oraclevcn.com). -
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] The VCN’s Oracle ID ([OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)).
-
#ipv6_cidr_blocks ⇒ Array<String>
For an IPv6-enabled VCN, this is the list of IPv6 CIDR blocks for the VCN’s IP address space.
-
#lifecycle_state ⇒ String
[Required] The VCN’s current state.
-
#time_created ⇒ DateTime
The date and time the VCN was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#vcn_domain_name ⇒ String
The VCN’s domain name, which consists of the VCN’s DNS label, and the
oraclevcn.comdomain.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Vcn
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Vcn
Initializes the object
193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/oci/core/models/vcn.rb', line 193 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.cidr_block = attributes[:'cidrBlock'] if attributes[:'cidrBlock'] raise 'You cannot provide both :cidrBlock and :cidr_block' if attributes.key?(:'cidrBlock') && attributes.key?(:'cidr_block') self.cidr_block = attributes[:'cidr_block'] if attributes[:'cidr_block'] self.cidr_blocks = attributes[:'cidrBlocks'] if attributes[:'cidrBlocks'] raise 'You cannot provide both :cidrBlocks and :cidr_blocks' if attributes.key?(:'cidrBlocks') && attributes.key?(:'cidr_blocks') self.cidr_blocks = attributes[:'cidr_blocks'] if attributes[:'cidr_blocks'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self. = attributes[:'defaultDhcpOptionsId'] if attributes[:'defaultDhcpOptionsId'] raise 'You cannot provide both :defaultDhcpOptionsId and :default_dhcp_options_id' if attributes.key?(:'defaultDhcpOptionsId') && attributes.key?(:'default_dhcp_options_id') self. = attributes[:'default_dhcp_options_id'] if attributes[:'default_dhcp_options_id'] self.default_route_table_id = attributes[:'defaultRouteTableId'] if attributes[:'defaultRouteTableId'] raise 'You cannot provide both :defaultRouteTableId and :default_route_table_id' if attributes.key?(:'defaultRouteTableId') && attributes.key?(:'default_route_table_id') self.default_route_table_id = attributes[:'default_route_table_id'] if attributes[:'default_route_table_id'] self.default_security_list_id = attributes[:'defaultSecurityListId'] if attributes[:'defaultSecurityListId'] raise 'You cannot provide both :defaultSecurityListId and :default_security_list_id' if attributes.key?(:'defaultSecurityListId') && attributes.key?(:'default_security_list_id') self.default_security_list_id = attributes[:'default_security_list_id'] if attributes[:'default_security_list_id'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.dns_label = attributes[:'dnsLabel'] if attributes[:'dnsLabel'] raise 'You cannot provide both :dnsLabel and :dns_label' if attributes.key?(:'dnsLabel') && attributes.key?(:'dns_label') self.dns_label = attributes[:'dns_label'] if attributes[:'dns_label'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.id = attributes[:'id'] if attributes[:'id'] self.ipv6_cidr_blocks = attributes[:'ipv6CidrBlocks'] if attributes[:'ipv6CidrBlocks'] raise 'You cannot provide both :ipv6CidrBlocks and :ipv6_cidr_blocks' if attributes.key?(:'ipv6CidrBlocks') && attributes.key?(:'ipv6_cidr_blocks') self.ipv6_cidr_blocks = attributes[:'ipv6_cidr_blocks'] if attributes[:'ipv6_cidr_blocks'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.vcn_domain_name = attributes[:'vcnDomainName'] if attributes[:'vcnDomainName'] raise 'You cannot provide both :vcnDomainName and :vcn_domain_name' if attributes.key?(:'vcnDomainName') && attributes.key?(:'vcn_domain_name') self.vcn_domain_name = attributes[:'vcn_domain_name'] if attributes[:'vcn_domain_name'] end |
Instance Attribute Details
#cidr_block ⇒ String
[Required] Deprecated. The first CIDR IP address from cidrBlocks.
Example: 172.16.0.0/16
31 32 33 |
# File 'lib/oci/core/models/vcn.rb', line 31 def cidr_block @cidr_block end |
#cidr_blocks ⇒ Array<String>
[Required] The list of IPv4 CIDR blocks the VCN will use.
36 37 38 |
# File 'lib/oci/core/models/vcn.rb', line 36 def cidr_blocks @cidr_blocks end |
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the VCN.
40 41 42 |
# File 'lib/oci/core/models/vcn.rb', line 40 def compartment_id @compartment_id end |
#default_dhcp_options_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) for the VCN’s default set of DHCP options.
45 46 47 |
# File 'lib/oci/core/models/vcn.rb', line 45 def @default_dhcp_options_id end |
#default_route_table_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) for the VCN’s default route table.
49 50 51 |
# File 'lib/oci/core/models/vcn.rb', line 49 def default_route_table_id @default_route_table_id end |
#default_security_list_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) for the VCN’s default security list.
53 54 55 |
# File 'lib/oci/core/models/vcn.rb', line 53 def default_security_list_id @default_security_list_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
61 62 63 |
# File 'lib/oci/core/models/vcn.rb', line 61 def @defined_tags end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
67 68 69 |
# File 'lib/oci/core/models/vcn.rb', line 67 def display_name @display_name end |
#dns_label ⇒ String
A DNS label for the VCN, used in conjunction with the VNIC’s hostname and subnet’s DNS label to form a fully qualified domain name (FQDN) for each VNIC within this subnet (for example, bminstance-1.subnet123.vcn1.oraclevcn.com). Must be an alphanumeric string that begins with a letter. The value cannot be changed.
The absence of this parameter means the Internet and VCN Resolver will not work for this VCN.
For more information, see [DNS in Your Virtual Cloud Network](docs.cloud.oracle.com/iaas/Content/Network/Concepts/dns.htm).
Example: vcn1
84 85 86 |
# File 'lib/oci/core/models/vcn.rb', line 84 def dns_label @dns_label end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
92 93 94 |
# File 'lib/oci/core/models/vcn.rb', line 92 def @freeform_tags end |
#id ⇒ String
[Required] The VCN’s Oracle ID ([OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)).
96 97 98 |
# File 'lib/oci/core/models/vcn.rb', line 96 def id @id end |
#ipv6_cidr_blocks ⇒ Array<String>
For an IPv6-enabled VCN, this is the list of IPv6 CIDR blocks for the VCN’s IP address space. The CIDRs are provided by Oracle and the sizes are always /56.
102 103 104 |
# File 'lib/oci/core/models/vcn.rb', line 102 def ipv6_cidr_blocks @ipv6_cidr_blocks end |
#lifecycle_state ⇒ String
[Required] The VCN’s current state.
106 107 108 |
# File 'lib/oci/core/models/vcn.rb', line 106 def lifecycle_state @lifecycle_state end |
#time_created ⇒ DateTime
The date and time the VCN was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Example: 2016-08-25T21:10:29.600Z
113 114 115 |
# File 'lib/oci/core/models/vcn.rb', line 113 def time_created @time_created end |
#vcn_domain_name ⇒ String
The VCN’s domain name, which consists of the VCN’s DNS label, and the oraclevcn.com domain.
For more information, see [DNS in Your Virtual Cloud Network](docs.cloud.oracle.com/iaas/Content/Network/Concepts/dns.htm).
Example: vcn1.oraclevcn.com
124 125 126 |
# File 'lib/oci/core/models/vcn.rb', line 124 def vcn_domain_name @vcn_domain_name end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/oci/core/models/vcn.rb', line 127 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'cidr_block': :'cidrBlock', 'cidr_blocks': :'cidrBlocks', 'compartment_id': :'compartmentId', 'default_dhcp_options_id': :'defaultDhcpOptionsId', 'default_route_table_id': :'defaultRouteTableId', 'default_security_list_id': :'defaultSecurityListId', 'defined_tags': :'definedTags', 'display_name': :'displayName', 'dns_label': :'dnsLabel', 'freeform_tags': :'freeformTags', 'id': :'id', 'ipv6_cidr_blocks': :'ipv6CidrBlocks', 'lifecycle_state': :'lifecycleState', 'time_created': :'timeCreated', 'vcn_domain_name': :'vcnDomainName' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/oci/core/models/vcn.rb', line 150 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'cidr_block': :'String', 'cidr_blocks': :'Array<String>', 'compartment_id': :'String', 'default_dhcp_options_id': :'String', 'default_route_table_id': :'String', 'default_security_list_id': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'dns_label': :'String', 'freeform_tags': :'Hash<String, String>', 'id': :'String', 'ipv6_cidr_blocks': :'Array<String>', 'lifecycle_state': :'String', 'time_created': :'DateTime', 'vcn_domain_name': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 |
# File 'lib/oci/core/models/vcn.rb', line 306 def ==(other) return true if equal?(other) self.class == other.class && cidr_block == other.cidr_block && cidr_blocks == other.cidr_blocks && compartment_id == other.compartment_id && == other. && default_route_table_id == other.default_route_table_id && default_security_list_id == other.default_security_list_id && == other. && display_name == other.display_name && dns_label == other.dns_label && == other. && id == other.id && ipv6_cidr_blocks == other.ipv6_cidr_blocks && lifecycle_state == other.lifecycle_state && time_created == other.time_created && vcn_domain_name == other.vcn_domain_name end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 |
# File 'lib/oci/core/models/vcn.rb', line 350 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
330 331 332 |
# File 'lib/oci/core/models/vcn.rb', line 330 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
339 340 341 |
# File 'lib/oci/core/models/vcn.rb', line 339 def hash [cidr_block, cidr_blocks, compartment_id, , default_route_table_id, default_security_list_id, , display_name, dns_label, , id, ipv6_cidr_blocks, lifecycle_state, time_created, vcn_domain_name].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
383 384 385 386 387 388 389 390 391 392 |
# File 'lib/oci/core/models/vcn.rb', line 383 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
377 378 379 |
# File 'lib/oci/core/models/vcn.rb', line 377 def to_s to_hash.to_s end |