Class: OCI::Core::Models::VcnDrgAttachmentNetworkDetails
- Inherits:
-
DrgAttachmentNetworkDetails
- Object
- DrgAttachmentNetworkDetails
- OCI::Core::Models::VcnDrgAttachmentNetworkDetails
- Defined in:
- lib/oci/core/models/vcn_drg_attachment_network_details.rb
Overview
Specifies details within the VCN.
Constant Summary collapse
- VCN_ROUTE_TYPE_ENUM =
[ VCN_ROUTE_TYPE_VCN_CIDRS = 'VCN_CIDRS'.freeze, VCN_ROUTE_TYPE_SUBNET_CIDRS = 'SUBNET_CIDRS'.freeze, VCN_ROUTE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Constants inherited from DrgAttachmentNetworkDetails
DrgAttachmentNetworkDetails::TYPE_ENUM
Instance Attribute Summary collapse
-
#route_table_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the route table the DRG attachment is using.
-
#vcn_route_type ⇒ String
Indicates whether the VCN CIDRs or the individual subnet CIDRs are imported from the attachment.
Attributes inherited from DrgAttachmentNetworkDetails
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VcnDrgAttachmentNetworkDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from DrgAttachmentNetworkDetails
Constructor Details
#initialize(attributes = {}) ⇒ VcnDrgAttachmentNetworkDetails
Initializes the object
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/oci/core/models/vcn_drg_attachment_network_details.rb', line 67 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['type'] = 'VCN' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.route_table_id = attributes[:'routeTableId'] if attributes[:'routeTableId'] raise 'You cannot provide both :routeTableId and :route_table_id' if attributes.key?(:'routeTableId') && attributes.key?(:'route_table_id') self.route_table_id = attributes[:'route_table_id'] if attributes[:'route_table_id'] self.vcn_route_type = attributes[:'vcnRouteType'] if attributes[:'vcnRouteType'] self.vcn_route_type = "SUBNET_CIDRS" if vcn_route_type.nil? && !attributes.key?(:'vcnRouteType') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :vcnRouteType and :vcn_route_type' if attributes.key?(:'vcnRouteType') && attributes.key?(:'vcn_route_type') self.vcn_route_type = attributes[:'vcn_route_type'] if attributes[:'vcn_route_type'] self.vcn_route_type = "SUBNET_CIDRS" if vcn_route_type.nil? && !attributes.key?(:'vcnRouteType') && !attributes.key?(:'vcn_route_type') # rubocop:disable Style/StringLiterals end |
Instance Attribute Details
#route_table_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the route table the DRG attachment is using.
For information about why you would associate a route table with a DRG attachment, see:
* [Transit Routing: Access to Multiple VCNs in Same Region](https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/transitrouting.htm)
* [Transit Routing: Private Access to Oracle Services](https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/transitroutingoracleservices.htm)
26 27 28 |
# File 'lib/oci/core/models/vcn_drg_attachment_network_details.rb', line 26 def route_table_id @route_table_id end |
#vcn_route_type ⇒ String
Indicates whether the VCN CIDRs or the individual subnet CIDRs are imported from the attachment. Routes from the VCN ingress route table are always imported.
32 33 34 |
# File 'lib/oci/core/models/vcn_drg_attachment_network_details.rb', line 32 def vcn_route_type @vcn_route_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 |
# File 'lib/oci/core/models/vcn_drg_attachment_network_details.rb', line 35 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'type': :'type', 'id': :'id', 'route_table_id': :'routeTableId', 'vcn_route_type': :'vcnRouteType' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/oci/core/models/vcn_drg_attachment_network_details.rb', line 47 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'type': :'String', 'id': :'String', 'route_table_id': :'String', 'vcn_route_type': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
112 113 114 115 116 117 118 119 120 |
# File 'lib/oci/core/models/vcn_drg_attachment_network_details.rb', line 112 def ==(other) return true if equal?(other) self.class == other.class && type == other.type && id == other.id && route_table_id == other.route_table_id && vcn_route_type == other.vcn_route_type end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/oci/core/models/vcn_drg_attachment_network_details.rb', line 145 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
125 126 127 |
# File 'lib/oci/core/models/vcn_drg_attachment_network_details.rb', line 125 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
134 135 136 |
# File 'lib/oci/core/models/vcn_drg_attachment_network_details.rb', line 134 def hash [type, id, route_table_id, vcn_route_type].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
178 179 180 181 182 183 184 185 186 187 |
# File 'lib/oci/core/models/vcn_drg_attachment_network_details.rb', line 178 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
172 173 174 |
# File 'lib/oci/core/models/vcn_drg_attachment_network_details.rb', line 172 def to_s to_hash.to_s end |