Class: OCI::Core::Models::VirtualCircuit

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/core/models/virtual_circuit.rb

Overview

For use with Oracle Cloud Infrastructure FastConnect.

A virtual circuit is an isolated network path that runs over one or more physical network connections to provide a single, logical connection between the edge router on the customer's existing network and Oracle Cloud Infrastructure. Private virtual circuits support private peering, and public virtual circuits support public peering. For more information, see [FastConnect Overview](docs.cloud.oracle.com/iaas/Content/Network/Concepts/fastconnect.htm).

Each virtual circuit is made up of information shared between a customer, Oracle, and a provider (if the customer is using FastConnect via a provider). Who fills in a given property of a virtual circuit depends on whether the BGP session related to that virtual circuit goes from the customer's edge router to Oracle, or from the provider's edge router to Oracle. Also, in the case where the customer is using a provider, values for some of the properties may not be present immediately, but may get filled in as the provider and Oracle each do their part to provision the virtual circuit.

To use any of the API operations, you must be authorized in an IAM policy. If you're not authorized, talk to an administrator. If you're an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/iaas/Content/Identity/Concepts/policygetstarted.htm).

Constant Summary collapse

BGP_MANAGEMENT_ENUM =
[
  BGP_MANAGEMENT_CUSTOMER_MANAGED = 'CUSTOMER_MANAGED'.freeze,
  BGP_MANAGEMENT_PROVIDER_MANAGED = 'PROVIDER_MANAGED'.freeze,
  BGP_MANAGEMENT_ORACLE_MANAGED = 'ORACLE_MANAGED'.freeze,
  BGP_MANAGEMENT_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
BGP_SESSION_STATE_ENUM =
[
  BGP_SESSION_STATE_UP = 'UP'.freeze,
  BGP_SESSION_STATE_DOWN = 'DOWN'.freeze,
  BGP_SESSION_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
BGP_IPV6_SESSION_STATE_ENUM =
[
  BGP_IPV6_SESSION_STATE_UP = 'UP'.freeze,
  BGP_IPV6_SESSION_STATE_DOWN = 'DOWN'.freeze,
  BGP_IPV6_SESSION_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
ROUTING_POLICY_ENUM =
[
  ROUTING_POLICY_ORACLE_SERVICE_NETWORK = 'ORACLE_SERVICE_NETWORK'.freeze,
  ROUTING_POLICY_REGIONAL = 'REGIONAL'.freeze,
  ROUTING_POLICY_MARKET_LEVEL = 'MARKET_LEVEL'.freeze,
  ROUTING_POLICY_GLOBAL = 'GLOBAL'.freeze,
  ROUTING_POLICY_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
BGP_ADMIN_STATE_ENUM =
[
  BGP_ADMIN_STATE_ENABLED = 'ENABLED'.freeze,
  BGP_ADMIN_STATE_DISABLED = 'DISABLED'.freeze,
  BGP_ADMIN_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_PENDING_PROVIDER = 'PENDING_PROVIDER'.freeze,
  LIFECYCLE_STATE_VERIFYING = 'VERIFYING'.freeze,
  LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze,
  LIFECYCLE_STATE_PROVISIONED = 'PROVISIONED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
  LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze,
  LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
PROVIDER_STATE_ENUM =
[
  PROVIDER_STATE_ACTIVE = 'ACTIVE'.freeze,
  PROVIDER_STATE_INACTIVE = 'INACTIVE'.freeze,
  PROVIDER_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
SERVICE_TYPE_ENUM =
[
  SERVICE_TYPE_COLOCATED = 'COLOCATED'.freeze,
  SERVICE_TYPE_LAYER2 = 'LAYER2'.freeze,
  SERVICE_TYPE_LAYER3 = 'LAYER3'.freeze,
  SERVICE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
TYPE_ENUM =
[
  TYPE_PUBLIC = 'PUBLIC'.freeze,
  TYPE_PRIVATE = 'PRIVATE'.freeze,
  TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
IP_MTU_ENUM =
[
  IP_MTU_MTU_1500 = 'MTU_1500'.freeze,
  IP_MTU_MTU_9000 = 'MTU_9000'.freeze,
  IP_MTU_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ VirtualCircuit

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :bandwidth_shape_name (String)

    The value to assign to the #bandwidth_shape_name property

  • :bgp_management (String)

    The value to assign to the #bgp_management property

  • :bgp_session_state (String)

    The value to assign to the #bgp_session_state property

  • :bgp_ipv6_session_state (String)

    The value to assign to the #bgp_ipv6_session_state property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :cross_connect_mappings (Array<OCI::Core::Models::CrossConnectMapping>)

    The value to assign to the #cross_connect_mappings property

  • :routing_policy (Array<String>)

    The value to assign to the #routing_policy property

  • :bgp_admin_state (String)

    The value to assign to the #bgp_admin_state property

  • :is_bfd_enabled (BOOLEAN)

    The value to assign to the #is_bfd_enabled property

  • :customer_bgp_asn (Integer)

    The value to assign to the #customer_bgp_asn property

  • :customer_asn (Integer)

    The value to assign to the #customer_asn property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property

  • :display_name (String)

    The value to assign to the #display_name property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :gateway_id (String)

    The value to assign to the #gateway_id property

  • :id (String)

    The value to assign to the #id property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :oracle_bgp_asn (Integer)

    The value to assign to the #oracle_bgp_asn property

  • :provider_name (String)

    The value to assign to the #provider_name property

  • :provider_service_id (String)

    The value to assign to the #provider_service_id property

  • :provider_service_key_name (String)

    The value to assign to the #provider_service_key_name property

  • :provider_service_name (String)

    The value to assign to the #provider_service_name property

  • :provider_state (String)

    The value to assign to the #provider_state property

  • :public_prefixes (Array<String>)

    The value to assign to the #public_prefixes property

  • :reference_comment (String)

    The value to assign to the #reference_comment property

  • :region (String)

    The value to assign to the #region property

  • :service_type (String)

    The value to assign to the #service_type property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :type (String)

    The value to assign to the #type property

  • :ip_mtu (String)

    The value to assign to the #ip_mtu property



393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
# File 'lib/oci/core/models/virtual_circuit.rb', line 393

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.bandwidth_shape_name = attributes[:'bandwidthShapeName'] if attributes[:'bandwidthShapeName']

  raise 'You cannot provide both :bandwidthShapeName and :bandwidth_shape_name' if attributes.key?(:'bandwidthShapeName') && attributes.key?(:'bandwidth_shape_name')

  self.bandwidth_shape_name = attributes[:'bandwidth_shape_name'] if attributes[:'bandwidth_shape_name']

  self.bgp_management = attributes[:'bgpManagement'] if attributes[:'bgpManagement']

  raise 'You cannot provide both :bgpManagement and :bgp_management' if attributes.key?(:'bgpManagement') && attributes.key?(:'bgp_management')

  self.bgp_management = attributes[:'bgp_management'] if attributes[:'bgp_management']

  self.bgp_session_state = attributes[:'bgpSessionState'] if attributes[:'bgpSessionState']

  raise 'You cannot provide both :bgpSessionState and :bgp_session_state' if attributes.key?(:'bgpSessionState') && attributes.key?(:'bgp_session_state')

  self.bgp_session_state = attributes[:'bgp_session_state'] if attributes[:'bgp_session_state']

  self.bgp_ipv6_session_state = attributes[:'bgpIpv6SessionState'] if attributes[:'bgpIpv6SessionState']

  raise 'You cannot provide both :bgpIpv6SessionState and :bgp_ipv6_session_state' if attributes.key?(:'bgpIpv6SessionState') && attributes.key?(:'bgp_ipv6_session_state')

  self.bgp_ipv6_session_state = attributes[:'bgp_ipv6_session_state'] if attributes[:'bgp_ipv6_session_state']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.cross_connect_mappings = attributes[:'crossConnectMappings'] if attributes[:'crossConnectMappings']

  raise 'You cannot provide both :crossConnectMappings and :cross_connect_mappings' if attributes.key?(:'crossConnectMappings') && attributes.key?(:'cross_connect_mappings')

  self.cross_connect_mappings = attributes[:'cross_connect_mappings'] if attributes[:'cross_connect_mappings']

  self.routing_policy = attributes[:'routingPolicy'] if attributes[:'routingPolicy']

  raise 'You cannot provide both :routingPolicy and :routing_policy' if attributes.key?(:'routingPolicy') && attributes.key?(:'routing_policy')

  self.routing_policy = attributes[:'routing_policy'] if attributes[:'routing_policy']

  self.bgp_admin_state = attributes[:'bgpAdminState'] if attributes[:'bgpAdminState']

  raise 'You cannot provide both :bgpAdminState and :bgp_admin_state' if attributes.key?(:'bgpAdminState') && attributes.key?(:'bgp_admin_state')

  self.bgp_admin_state = attributes[:'bgp_admin_state'] if attributes[:'bgp_admin_state']

  self.is_bfd_enabled = attributes[:'isBfdEnabled'] unless attributes[:'isBfdEnabled'].nil?
  self.is_bfd_enabled = false if is_bfd_enabled.nil? && !attributes.key?(:'isBfdEnabled') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isBfdEnabled and :is_bfd_enabled' if attributes.key?(:'isBfdEnabled') && attributes.key?(:'is_bfd_enabled')

  self.is_bfd_enabled = attributes[:'is_bfd_enabled'] unless attributes[:'is_bfd_enabled'].nil?
  self.is_bfd_enabled = false if is_bfd_enabled.nil? && !attributes.key?(:'isBfdEnabled') && !attributes.key?(:'is_bfd_enabled') # rubocop:disable Style/StringLiterals

  self.customer_bgp_asn = attributes[:'customerBgpAsn'] if attributes[:'customerBgpAsn']

  raise 'You cannot provide both :customerBgpAsn and :customer_bgp_asn' if attributes.key?(:'customerBgpAsn') && attributes.key?(:'customer_bgp_asn')

  self.customer_bgp_asn = attributes[:'customer_bgp_asn'] if attributes[:'customer_bgp_asn']

  self.customer_asn = attributes[:'customerAsn'] if attributes[:'customerAsn']

  raise 'You cannot provide both :customerAsn and :customer_asn' if attributes.key?(:'customerAsn') && attributes.key?(:'customer_asn')

  self.customer_asn = attributes[:'customer_asn'] if attributes[:'customer_asn']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.gateway_id = attributes[:'gatewayId'] if attributes[:'gatewayId']

  raise 'You cannot provide both :gatewayId and :gateway_id' if attributes.key?(:'gatewayId') && attributes.key?(:'gateway_id')

  self.gateway_id = attributes[:'gateway_id'] if attributes[:'gateway_id']

  self.id = attributes[:'id'] if attributes[:'id']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.oracle_bgp_asn = attributes[:'oracleBgpAsn'] if attributes[:'oracleBgpAsn']

  raise 'You cannot provide both :oracleBgpAsn and :oracle_bgp_asn' if attributes.key?(:'oracleBgpAsn') && attributes.key?(:'oracle_bgp_asn')

  self.oracle_bgp_asn = attributes[:'oracle_bgp_asn'] if attributes[:'oracle_bgp_asn']

  self.provider_name = attributes[:'providerName'] if attributes[:'providerName']

  raise 'You cannot provide both :providerName and :provider_name' if attributes.key?(:'providerName') && attributes.key?(:'provider_name')

  self.provider_name = attributes[:'provider_name'] if attributes[:'provider_name']

  self.provider_service_id = attributes[:'providerServiceId'] if attributes[:'providerServiceId']

  raise 'You cannot provide both :providerServiceId and :provider_service_id' if attributes.key?(:'providerServiceId') && attributes.key?(:'provider_service_id')

  self.provider_service_id = attributes[:'provider_service_id'] if attributes[:'provider_service_id']

  self.provider_service_key_name = attributes[:'providerServiceKeyName'] if attributes[:'providerServiceKeyName']

  raise 'You cannot provide both :providerServiceKeyName and :provider_service_key_name' if attributes.key?(:'providerServiceKeyName') && attributes.key?(:'provider_service_key_name')

  self.provider_service_key_name = attributes[:'provider_service_key_name'] if attributes[:'provider_service_key_name']

  self.provider_service_name = attributes[:'providerServiceName'] if attributes[:'providerServiceName']

  raise 'You cannot provide both :providerServiceName and :provider_service_name' if attributes.key?(:'providerServiceName') && attributes.key?(:'provider_service_name')

  self.provider_service_name = attributes[:'provider_service_name'] if attributes[:'provider_service_name']

  self.provider_state = attributes[:'providerState'] if attributes[:'providerState']

  raise 'You cannot provide both :providerState and :provider_state' if attributes.key?(:'providerState') && attributes.key?(:'provider_state')

  self.provider_state = attributes[:'provider_state'] if attributes[:'provider_state']

  self.public_prefixes = attributes[:'publicPrefixes'] if attributes[:'publicPrefixes']

  raise 'You cannot provide both :publicPrefixes and :public_prefixes' if attributes.key?(:'publicPrefixes') && attributes.key?(:'public_prefixes')

  self.public_prefixes = attributes[:'public_prefixes'] if attributes[:'public_prefixes']

  self.reference_comment = attributes[:'referenceComment'] if attributes[:'referenceComment']

  raise 'You cannot provide both :referenceComment and :reference_comment' if attributes.key?(:'referenceComment') && attributes.key?(:'reference_comment')

  self.reference_comment = attributes[:'reference_comment'] if attributes[:'reference_comment']

  self.region = attributes[:'region'] if attributes[:'region']

  self.service_type = attributes[:'serviceType'] if attributes[:'serviceType']

  raise 'You cannot provide both :serviceType and :service_type' if attributes.key?(:'serviceType') && attributes.key?(:'service_type')

  self.service_type = attributes[:'service_type'] if attributes[:'service_type']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.type = attributes[:'type'] if attributes[:'type']

  self.ip_mtu = attributes[:'ipMtu'] if attributes[:'ipMtu']

  raise 'You cannot provide both :ipMtu and :ip_mtu' if attributes.key?(:'ipMtu') && attributes.key?(:'ip_mtu')

  self.ip_mtu = attributes[:'ip_mtu'] if attributes[:'ip_mtu']
end

Instance Attribute Details

#bandwidth_shape_nameString

The provisioned data rate of the connection. To get a list of the available bandwidth levels (that is, shapes), see list_fast_connect_provider_virtual_circuit_bandwidth_shapes.

Example: `10 Gbps`

Returns:

  • (String)


107
108
109
# File 'lib/oci/core/models/virtual_circuit.rb', line 107

def bandwidth_shape_name
  @bandwidth_shape_name
end

#bgp_admin_stateString

Set to `ENABLED` (the default) to activate the BGP session of the virtual circuit, set to `DISABLED` to deactivate the virtual circuit.

Returns:

  • (String)


145
146
147
# File 'lib/oci/core/models/virtual_circuit.rb', line 145

def bgp_admin_state
  @bgp_admin_state
end

#bgp_ipv6_session_stateString

The state of the Ipv6 BGP session associated with the virtual circuit.

Returns:

  • (String)


121
122
123
# File 'lib/oci/core/models/virtual_circuit.rb', line 121

def bgp_ipv6_session_state
  @bgp_ipv6_session_state
end

#bgp_managementString

Deprecated. Instead use the information in FastConnectProviderService.

Returns:

  • (String)


113
114
115
# File 'lib/oci/core/models/virtual_circuit.rb', line 113

def bgp_management
  @bgp_management
end

#bgp_session_stateString

The state of the Ipv4 BGP session associated with the virtual circuit.

Returns:

  • (String)


117
118
119
# File 'lib/oci/core/models/virtual_circuit.rb', line 117

def bgp_session_state
  @bgp_session_state
end

#compartment_idString

The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the virtual circuit.

Returns:

  • (String)


125
126
127
# File 'lib/oci/core/models/virtual_circuit.rb', line 125

def compartment_id
  @compartment_id
end

#cross_connect_mappingsArray<OCI::Core::Models::CrossConnectMapping>

An array of mappings, each containing properties for a cross-connect or cross-connect group that is associated with this virtual circuit.



132
133
134
# File 'lib/oci/core/models/virtual_circuit.rb', line 132

def cross_connect_mappings
  @cross_connect_mappings
end

#customer_asnInteger

The BGP ASN of the network at the other end of the BGP session from Oracle. If the session is between the customer's edge router and Oracle, the value is the customer's ASN. If the BGP session is between the provider's edge router and Oracle, the value is the provider's ASN. Can be a 2-byte or 4-byte ASN. Uses "asplain" format.

Returns:

  • (Integer)


166
167
168
# File 'lib/oci/core/models/virtual_circuit.rb', line 166

def customer_asn
  @customer_asn
end

#customer_bgp_asnInteger

Deprecated. Instead use `customerAsn`. If you specify values for both, the request will be rejected.

Returns:

  • (Integer)


156
157
158
# File 'lib/oci/core/models/virtual_circuit.rb', line 156

def customer_bgp_asn
  @customer_bgp_asn
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).

Example: `{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


174
175
176
# File 'lib/oci/core/models/virtual_circuit.rb', line 174

def defined_tags
  @defined_tags
end

#display_nameString

A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.

Returns:

  • (String)


180
181
182
# File 'lib/oci/core/models/virtual_circuit.rb', line 180

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).

Example: `"Finance"`

Returns:

  • (Hash<String, String>)


188
189
190
# File 'lib/oci/core/models/virtual_circuit.rb', line 188

def freeform_tags
  @freeform_tags
end

#gateway_idString

The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the customer's Drg that this virtual circuit uses. Applicable only to private virtual circuits.

Returns:

  • (String)


194
195
196
# File 'lib/oci/core/models/virtual_circuit.rb', line 194

def gateway_id
  @gateway_id
end

#idString

The virtual circuit's Oracle ID ([OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)).

Returns:

  • (String)


198
199
200
# File 'lib/oci/core/models/virtual_circuit.rb', line 198

def id
  @id
end

#ip_mtuString

The layer 3 IP MTU to use on this virtual circuit.

Returns:

  • (String)


279
280
281
# File 'lib/oci/core/models/virtual_circuit.rb', line 279

def ip_mtu
  @ip_mtu
end

#is_bfd_enabledBOOLEAN

Set to `true` to enable BFD for IPv4 BGP peering, or set to `false` to disable BFD. If this is not set, the default is `false`.

Returns:

  • (BOOLEAN)


150
151
152
# File 'lib/oci/core/models/virtual_circuit.rb', line 150

def is_bfd_enabled
  @is_bfd_enabled
end

#lifecycle_stateString

The virtual circuit's current state. For information about the different states, see [FastConnect Overview](docs.cloud.oracle.com/iaas/Content/Network/Concepts/fastconnect.htm).

Returns:

  • (String)


205
206
207
# File 'lib/oci/core/models/virtual_circuit.rb', line 205

def lifecycle_state
  @lifecycle_state
end

#oracle_bgp_asnInteger

The Oracle BGP ASN.

Returns:

  • (Integer)


209
210
211
# File 'lib/oci/core/models/virtual_circuit.rb', line 209

def oracle_bgp_asn
  @oracle_bgp_asn
end

#provider_nameString

Deprecated. Instead use `providerServiceId`.

Returns:

  • (String)


214
215
216
# File 'lib/oci/core/models/virtual_circuit.rb', line 214

def provider_name
  @provider_name
end

#provider_service_idString

The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the service offered by the provider (if the customer is connecting via a provider).

Returns:

  • (String)


219
220
221
# File 'lib/oci/core/models/virtual_circuit.rb', line 219

def provider_service_id
  @provider_service_id
end

#provider_service_key_nameString

The service key name offered by the provider (if the customer is connecting via a provider).

Returns:

  • (String)


224
225
226
# File 'lib/oci/core/models/virtual_circuit.rb', line 224

def provider_service_key_name
  @provider_service_key_name
end

#provider_service_nameString

Deprecated. Instead use `providerServiceId`.

Returns:

  • (String)


229
230
231
# File 'lib/oci/core/models/virtual_circuit.rb', line 229

def provider_service_name
  @provider_service_name
end

#provider_stateString

The provider's state in relation to this virtual circuit (if the customer is connecting via a provider). ACTIVE means the provider has provisioned the virtual circuit from their end. INACTIVE means the provider has not yet provisioned the virtual circuit, or has de-provisioned it.

Returns:

  • (String)


238
239
240
# File 'lib/oci/core/models/virtual_circuit.rb', line 238

def provider_state
  @provider_state
end

#public_prefixesArray<String>

For a public virtual circuit. The public IP prefixes (CIDRs) the customer wants to advertise across the connection. All prefix sizes are allowed.

Returns:

  • (Array<String>)


244
245
246
# File 'lib/oci/core/models/virtual_circuit.rb', line 244

def public_prefixes
  @public_prefixes
end

#reference_commentString

Provider-supplied reference information about this virtual circuit (if the customer is connecting via a provider).

Returns:

  • (String)


250
251
252
# File 'lib/oci/core/models/virtual_circuit.rb', line 250

def reference_comment
  @reference_comment
end

#regionString

The Oracle Cloud Infrastructure region where this virtual circuit is located.

Returns:

  • (String)


256
257
258
# File 'lib/oci/core/models/virtual_circuit.rb', line 256

def region
  @region
end

#routing_policyArray<String>

The routing policy sets how routing information about the Oracle cloud is shared over a public virtual circuit. Policies available are: `ORACLE_SERVICE_NETWORK`, `REGIONAL`, `MARKET_LEVEL`, and `GLOBAL`. See [Route Filtering](docs.cloud.oracle.com/iaas/Content/Network/Concepts/routingonprem.htm#route_filtering) for details. By default, routing information is shared for all routes in the same market.

Returns:

  • (Array<String>)


140
141
142
# File 'lib/oci/core/models/virtual_circuit.rb', line 140

def routing_policy
  @routing_policy
end

#service_typeString

Provider service type.

Returns:

  • (String)


261
262
263
# File 'lib/oci/core/models/virtual_circuit.rb', line 261

def service_type
  @service_type
end

#time_createdDateTime

The date and time the virtual circuit was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).

Example: `2016-08-25T21:10:29.600Z`

Returns:

  • (DateTime)


269
270
271
# File 'lib/oci/core/models/virtual_circuit.rb', line 269

def time_created
  @time_created
end

#typeString

Whether the virtual circuit supports private or public peering. For more information, see [FastConnect Overview](docs.cloud.oracle.com/iaas/Content/Network/Concepts/fastconnect.htm).

Returns:

  • (String)


275
276
277
# File 'lib/oci/core/models/virtual_circuit.rb', line 275

def type
  @type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
# File 'lib/oci/core/models/virtual_circuit.rb', line 282

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'bandwidth_shape_name': :'bandwidthShapeName',
    'bgp_management': :'bgpManagement',
    'bgp_session_state': :'bgpSessionState',
    'bgp_ipv6_session_state': :'bgpIpv6SessionState',
    'compartment_id': :'compartmentId',
    'cross_connect_mappings': :'crossConnectMappings',
    'routing_policy': :'routingPolicy',
    'bgp_admin_state': :'bgpAdminState',
    'is_bfd_enabled': :'isBfdEnabled',
    'customer_bgp_asn': :'customerBgpAsn',
    'customer_asn': :'customerAsn',
    'defined_tags': :'definedTags',
    'display_name': :'displayName',
    'freeform_tags': :'freeformTags',
    'gateway_id': :'gatewayId',
    'id': :'id',
    'lifecycle_state': :'lifecycleState',
    'oracle_bgp_asn': :'oracleBgpAsn',
    'provider_name': :'providerName',
    'provider_service_id': :'providerServiceId',
    'provider_service_key_name': :'providerServiceKeyName',
    'provider_service_name': :'providerServiceName',
    'provider_state': :'providerState',
    'public_prefixes': :'publicPrefixes',
    'reference_comment': :'referenceComment',
    'region': :'region',
    'service_type': :'serviceType',
    'time_created': :'timeCreated',
    'type': :'type',
    'ip_mtu': :'ipMtu'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
# File 'lib/oci/core/models/virtual_circuit.rb', line 320

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'bandwidth_shape_name': :'String',
    'bgp_management': :'String',
    'bgp_session_state': :'String',
    'bgp_ipv6_session_state': :'String',
    'compartment_id': :'String',
    'cross_connect_mappings': :'Array<OCI::Core::Models::CrossConnectMapping>',
    'routing_policy': :'Array<String>',
    'bgp_admin_state': :'String',
    'is_bfd_enabled': :'BOOLEAN',
    'customer_bgp_asn': :'Integer',
    'customer_asn': :'Integer',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'display_name': :'String',
    'freeform_tags': :'Hash<String, String>',
    'gateway_id': :'String',
    'id': :'String',
    'lifecycle_state': :'String',
    'oracle_bgp_asn': :'Integer',
    'provider_name': :'String',
    'provider_service_id': :'String',
    'provider_service_key_name': :'String',
    'provider_service_name': :'String',
    'provider_state': :'String',
    'public_prefixes': :'Array<String>',
    'reference_comment': :'String',
    'region': :'String',
    'service_type': :'String',
    'time_created': :'DateTime',
    'type': :'String',
    'ip_mtu': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
# File 'lib/oci/core/models/virtual_circuit.rb', line 714

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    bandwidth_shape_name == other.bandwidth_shape_name &&
    bgp_management == other.bgp_management &&
    bgp_session_state == other.bgp_session_state &&
    bgp_ipv6_session_state == other.bgp_ipv6_session_state &&
    compartment_id == other.compartment_id &&
    cross_connect_mappings == other.cross_connect_mappings &&
    routing_policy == other.routing_policy &&
    bgp_admin_state == other.bgp_admin_state &&
    is_bfd_enabled == other.is_bfd_enabled &&
    customer_bgp_asn == other.customer_bgp_asn &&
    customer_asn == other.customer_asn &&
    defined_tags == other.defined_tags &&
    display_name == other.display_name &&
    freeform_tags == other.freeform_tags &&
    gateway_id == other.gateway_id &&
    id == other.id &&
    lifecycle_state == other.lifecycle_state &&
    oracle_bgp_asn == other.oracle_bgp_asn &&
    provider_name == other.provider_name &&
    provider_service_id == other.provider_service_id &&
    provider_service_key_name == other.provider_service_key_name &&
    provider_service_name == other.provider_service_name &&
    provider_state == other.provider_state &&
    public_prefixes == other.public_prefixes &&
    reference_comment == other.reference_comment &&
    region == other.region &&
    service_type == other.service_type &&
    time_created == other.time_created &&
    type == other.type &&
    ip_mtu == other.ip_mtu
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
# File 'lib/oci/core/models/virtual_circuit.rb', line 773

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


753
754
755
# File 'lib/oci/core/models/virtual_circuit.rb', line 753

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



762
763
764
# File 'lib/oci/core/models/virtual_circuit.rb', line 762

def hash
  [bandwidth_shape_name, bgp_management, bgp_session_state, bgp_ipv6_session_state, compartment_id, cross_connect_mappings, routing_policy, bgp_admin_state, is_bfd_enabled, customer_bgp_asn, customer_asn, defined_tags, display_name, freeform_tags, gateway_id, id, lifecycle_state, oracle_bgp_asn, provider_name, provider_service_id, provider_service_key_name, provider_service_name, provider_state, public_prefixes, reference_comment, region, service_type, time_created, type, ip_mtu].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



806
807
808
809
810
811
812
813
814
815
# File 'lib/oci/core/models/virtual_circuit.rb', line 806

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



800
801
802
# File 'lib/oci/core/models/virtual_circuit.rb', line 800

def to_s
  to_hash.to_s
end