Class: OCI::Core::Models::Vnic
- Inherits:
-
Object
- Object
- OCI::Core::Models::Vnic
- Defined in:
- lib/oci/core/models/vnic.rb
Overview
A virtual network interface card. Each VNIC resides in a subnet in a VCN. An instance attaches to a VNIC to obtain a network connection into the VCN through that subnet. Each instance has a *primary VNIC* that is automatically created and attached during launch. You can add *secondary VNICs* to an instance after it’s launched. For more information, see [Virtual Network Interface Cards (VNICs)](docs.cloud.oracle.com/iaas/Content/Network/Tasks/managingVNICs.htm).
Each VNIC has a *primary private IP* that is automatically assigned during launch. You can add *secondary private IPs* to a VNIC after it’s created. For more information, see create_private_ip and [IP Addresses](docs.cloud.oracle.com/iaas/Content/Network/Tasks/managingIPaddresses.htm).
If you are an Oracle Cloud VMware Solution customer, you will have secondary VNICs that reside in a VLAN instead of a subnet. These VNICs have other differences, which are called out in the descriptions of the relevant attributes in the Vnic object. Also see Vlan.
To use any of the API operations, you must be authorized in an IAM policy. If you’re not authorized, talk to an administrator. If you’re an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/iaas/Content/Identity/Concepts/policygetstarted.htm).
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze, LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze, LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze, LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#availability_domain ⇒ String
[Required] The VNIC’s availability domain.
-
#compartment_id ⇒ String
[Required] The OCID of the compartment containing the VNIC.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
A user-friendly name.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#hostname_label ⇒ String
The hostname for the VNIC’s primary private IP.
-
#id ⇒ String
[Required] The OCID of the VNIC.
-
#is_primary ⇒ BOOLEAN
Whether the VNIC is the primary VNIC (the VNIC that is automatically created and attached during instance launch).
-
#lifecycle_state ⇒ String
[Required] The current state of the VNIC.
-
#mac_address ⇒ String
The MAC address of the VNIC.
-
#nsg_ids ⇒ Array<String>
A list of the OCIDs of the network security groups that the VNIC belongs to.
-
#private_ip ⇒ String
The private IP address of the primary
privateIpobject on the VNIC. -
#public_ip ⇒ String
The public IP address of the VNIC, if one is assigned.
-
#skip_source_dest_check ⇒ BOOLEAN
Whether the source/destination check is disabled on the VNIC.
-
#subnet_id ⇒ String
The OCID of the subnet the VNIC is in.
-
#time_created ⇒ DateTime
[Required] The date and time the VNIC was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#vlan_id ⇒ String
If the VNIC belongs to a VLAN as part of the Oracle Cloud VMware Solution (instead of belonging to a subnet), the
vlanIdis the OCID of the VLAN the VNIC is in.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Vnic
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Vnic
Initializes the object
244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 |
# File 'lib/oci/core/models/vnic.rb', line 244 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain'] raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain') self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.hostname_label = attributes[:'hostnameLabel'] if attributes[:'hostnameLabel'] raise 'You cannot provide both :hostnameLabel and :hostname_label' if attributes.key?(:'hostnameLabel') && attributes.key?(:'hostname_label') self.hostname_label = attributes[:'hostname_label'] if attributes[:'hostname_label'] self.id = attributes[:'id'] if attributes[:'id'] self.is_primary = attributes[:'isPrimary'] unless attributes[:'isPrimary'].nil? raise 'You cannot provide both :isPrimary and :is_primary' if attributes.key?(:'isPrimary') && attributes.key?(:'is_primary') self.is_primary = attributes[:'is_primary'] unless attributes[:'is_primary'].nil? self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.mac_address = attributes[:'macAddress'] if attributes[:'macAddress'] raise 'You cannot provide both :macAddress and :mac_address' if attributes.key?(:'macAddress') && attributes.key?(:'mac_address') self.mac_address = attributes[:'mac_address'] if attributes[:'mac_address'] self.nsg_ids = attributes[:'nsgIds'] if attributes[:'nsgIds'] raise 'You cannot provide both :nsgIds and :nsg_ids' if attributes.key?(:'nsgIds') && attributes.key?(:'nsg_ids') self.nsg_ids = attributes[:'nsg_ids'] if attributes[:'nsg_ids'] self.vlan_id = attributes[:'vlanId'] if attributes[:'vlanId'] raise 'You cannot provide both :vlanId and :vlan_id' if attributes.key?(:'vlanId') && attributes.key?(:'vlan_id') self.vlan_id = attributes[:'vlan_id'] if attributes[:'vlan_id'] self.private_ip = attributes[:'privateIp'] if attributes[:'privateIp'] raise 'You cannot provide both :privateIp and :private_ip' if attributes.key?(:'privateIp') && attributes.key?(:'private_ip') self.private_ip = attributes[:'private_ip'] if attributes[:'private_ip'] self.public_ip = attributes[:'publicIp'] if attributes[:'publicIp'] raise 'You cannot provide both :publicIp and :public_ip' if attributes.key?(:'publicIp') && attributes.key?(:'public_ip') self.public_ip = attributes[:'public_ip'] if attributes[:'public_ip'] self.skip_source_dest_check = attributes[:'skipSourceDestCheck'] unless attributes[:'skipSourceDestCheck'].nil? raise 'You cannot provide both :skipSourceDestCheck and :skip_source_dest_check' if attributes.key?(:'skipSourceDestCheck') && attributes.key?(:'skip_source_dest_check') self.skip_source_dest_check = attributes[:'skip_source_dest_check'] unless attributes[:'skip_source_dest_check'].nil? self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId'] raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id') self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] end |
Instance Attribute Details
#availability_domain ⇒ String
[Required] The VNIC’s availability domain.
Example: Uocm:PHX-AD-1
45 46 47 |
# File 'lib/oci/core/models/vnic.rb', line 45 def availability_domain @availability_domain end |
#compartment_id ⇒ String
[Required] The OCID of the compartment containing the VNIC.
49 50 51 |
# File 'lib/oci/core/models/vnic.rb', line 49 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
57 58 59 |
# File 'lib/oci/core/models/vnic.rb', line 57 def @defined_tags end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique. Avoid entering confidential information.
63 64 65 |
# File 'lib/oci/core/models/vnic.rb', line 63 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
71 72 73 |
# File 'lib/oci/core/models/vnic.rb', line 71 def @freeform_tags end |
#hostname_label ⇒ String
The hostname for the VNIC’s primary private IP. Used for DNS. The value is the hostname portion of the primary private IP’s fully qualified domain name (FQDN) (for example, bminstance-1 in FQDN bminstance-1.subnet123.vcn1.oraclevcn.com). Must be unique across all VNICs in the subnet and comply with [RFC 952](tools.ietf.org/html/rfc952) and [RFC 1123](tools.ietf.org/html/rfc1123).
For more information, see [DNS in Your Virtual Cloud Network](docs.cloud.oracle.com/iaas/Content/Network/Concepts/dns.htm).
Example: bminstance-1
86 87 88 |
# File 'lib/oci/core/models/vnic.rb', line 86 def hostname_label @hostname_label end |
#id ⇒ String
[Required] The OCID of the VNIC.
90 91 92 |
# File 'lib/oci/core/models/vnic.rb', line 90 def id @id end |
#is_primary ⇒ BOOLEAN
Whether the VNIC is the primary VNIC (the VNIC that is automatically created and attached during instance launch).
96 97 98 |
# File 'lib/oci/core/models/vnic.rb', line 96 def is_primary @is_primary end |
#lifecycle_state ⇒ String
[Required] The current state of the VNIC.
100 101 102 |
# File 'lib/oci/core/models/vnic.rb', line 100 def lifecycle_state @lifecycle_state end |
#mac_address ⇒ String
The MAC address of the VNIC.
If the VNIC belongs to a VLAN as part of the Oracle Cloud VMware Solution, the MAC address is learned. If the VNIC belongs to a subnet, the MAC address is a static, Oracle-provided value.
Example: 00:00:00:00:00:01
111 112 113 |
# File 'lib/oci/core/models/vnic.rb', line 111 def mac_address @mac_address end |
#nsg_ids ⇒ Array<String>
A list of the OCIDs of the network security groups that the VNIC belongs to.
If the VNIC belongs to a VLAN as part of the Oracle Cloud VMware Solution (instead of belonging to a subnet), the value of the nsgIds attribute is ignored. Instead, the VNIC belongs to the NSGs that are associated with the VLAN itself. See OCI::Core::Models::Vlan.
For more information about NSGs, see NetworkSecurityGroup.
123 124 125 |
# File 'lib/oci/core/models/vnic.rb', line 123 def nsg_ids @nsg_ids end |
#private_ip ⇒ String
The private IP address of the primary privateIp object on the VNIC. The address is within the CIDR of the VNIC’s subnet.
Example: 10.0.3.3
138 139 140 |
# File 'lib/oci/core/models/vnic.rb', line 138 def private_ip @private_ip end |
#public_ip ⇒ String
The public IP address of the VNIC, if one is assigned.
143 144 145 |
# File 'lib/oci/core/models/vnic.rb', line 143 def public_ip @public_ip end |
#skip_source_dest_check ⇒ BOOLEAN
Whether the source/destination check is disabled on the VNIC. Defaults to false, which means the check is performed. For information about why you would skip the source/destination check, see [Using a Private IP as a Route Target](docs.cloud.oracle.com/iaas/Content/Network/Tasks/managingroutetables.htm#privateip).
If the VNIC belongs to a VLAN as part of the Oracle Cloud VMware Solution (instead of belonging to a subnet), the skipSourceDestCheck attribute is true. This is because the source/destination check is always disabled for VNICs in a VLAN.
Example: true
158 159 160 |
# File 'lib/oci/core/models/vnic.rb', line 158 def skip_source_dest_check @skip_source_dest_check end |
#subnet_id ⇒ String
The OCID of the subnet the VNIC is in.
162 163 164 |
# File 'lib/oci/core/models/vnic.rb', line 162 def subnet_id @subnet_id end |
#time_created ⇒ DateTime
[Required] The date and time the VNIC was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Example: 2016-08-25T21:10:29.600Z
169 170 171 |
# File 'lib/oci/core/models/vnic.rb', line 169 def time_created @time_created end |
#vlan_id ⇒ String
If the VNIC belongs to a VLAN as part of the Oracle Cloud VMware Solution (instead of belonging to a subnet), the vlanId is the OCID of the VLAN the VNIC is in. See OCI::Core::Models::Vlan. If the VNIC is instead in a subnet, subnetId has a value.
130 131 132 |
# File 'lib/oci/core/models/vnic.rb', line 130 def vlan_id @vlan_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/oci/core/models/vnic.rb', line 172 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'availability_domain': :'availabilityDomain', 'compartment_id': :'compartmentId', 'defined_tags': :'definedTags', 'display_name': :'displayName', 'freeform_tags': :'freeformTags', 'hostname_label': :'hostnameLabel', 'id': :'id', 'is_primary': :'isPrimary', 'lifecycle_state': :'lifecycleState', 'mac_address': :'macAddress', 'nsg_ids': :'nsgIds', 'vlan_id': :'vlanId', 'private_ip': :'privateIp', 'public_ip': :'publicIp', 'skip_source_dest_check': :'skipSourceDestCheck', 'subnet_id': :'subnetId', 'time_created': :'timeCreated' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/oci/core/models/vnic.rb', line 197 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'availability_domain': :'String', 'compartment_id': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'freeform_tags': :'Hash<String, String>', 'hostname_label': :'String', 'id': :'String', 'is_primary': :'BOOLEAN', 'lifecycle_state': :'String', 'mac_address': :'String', 'nsg_ids': :'Array<String>', 'vlan_id': :'String', 'private_ip': :'String', 'public_ip': :'String', 'skip_source_dest_check': :'BOOLEAN', 'subnet_id': :'String', 'time_created': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 |
# File 'lib/oci/core/models/vnic.rb', line 369 def ==(other) return true if equal?(other) self.class == other.class && availability_domain == other.availability_domain && compartment_id == other.compartment_id && == other. && display_name == other.display_name && == other. && hostname_label == other.hostname_label && id == other.id && is_primary == other.is_primary && lifecycle_state == other.lifecycle_state && mac_address == other.mac_address && nsg_ids == other.nsg_ids && vlan_id == other.vlan_id && private_ip == other.private_ip && public_ip == other.public_ip && skip_source_dest_check == other.skip_source_dest_check && subnet_id == other.subnet_id && time_created == other.time_created end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 |
# File 'lib/oci/core/models/vnic.rb', line 415 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
395 396 397 |
# File 'lib/oci/core/models/vnic.rb', line 395 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
404 405 406 |
# File 'lib/oci/core/models/vnic.rb', line 404 def hash [availability_domain, compartment_id, , display_name, , hostname_label, id, is_primary, lifecycle_state, mac_address, nsg_ids, vlan_id, private_ip, public_ip, skip_source_dest_check, subnet_id, time_created].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
448 449 450 451 452 453 454 455 456 457 |
# File 'lib/oci/core/models/vnic.rb', line 448 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
442 443 444 |
# File 'lib/oci/core/models/vnic.rb', line 442 def to_s to_hash.to_s end |