Class: OCI::Core::Models::VnicAttachment
- Inherits:
-
Object
- Object
- OCI::Core::Models::VnicAttachment
- Defined in:
- lib/oci/core/models/vnic_attachment.rb
Overview
Represents an attachment between a VNIC and an instance. For more information, see [Virtual Network Interface Cards (VNICs)](docs.cloud.oracle.com/iaas/Content/Network/Tasks/managingVNICs.htm).
*Warning:* Oracle recommends that you avoid using any confidential information when you supply string values using the API.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_ATTACHING = 'ATTACHING'.freeze, LIFECYCLE_STATE_ATTACHED = 'ATTACHED'.freeze, LIFECYCLE_STATE_DETACHING = 'DETACHING'.freeze, LIFECYCLE_STATE_DETACHED = 'DETACHED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#availability_domain ⇒ String
**[Required]** The availability domain of the instance.
-
#compartment_id ⇒ String
**[Required]** The OCID of the compartment the VNIC attachment is in, which is the same compartment the instance is in.
-
#display_name ⇒ String
A user-friendly name.
-
#id ⇒ String
**[Required]** The OCID of the VNIC attachment.
-
#instance_id ⇒ String
**[Required]** The OCID of the instance.
-
#lifecycle_state ⇒ String
**[Required]** The current state of the VNIC attachment.
-
#nic_index ⇒ Integer
Which physical network interface card (NIC) the VNIC uses.
-
#subnet_id ⇒ String
The OCID of the subnet to create the VNIC in.
-
#time_created ⇒ DateTime
**[Required]** The date and time the VNIC attachment was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#vlan_id ⇒ String
The OCID of the VLAN to create the VNIC in.
-
#vlan_tag ⇒ Integer
The Oracle-assigned VLAN tag of the attached VNIC.
-
#vnic_id ⇒ String
The OCID of the VNIC.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VnicAttachment
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ VnicAttachment
Initializes the object
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/oci/core/models/vnic_attachment.rb', line 159 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain'] raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain') self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.id = attributes[:'id'] if attributes[:'id'] self.instance_id = attributes[:'instanceId'] if attributes[:'instanceId'] raise 'You cannot provide both :instanceId and :instance_id' if attributes.key?(:'instanceId') && attributes.key?(:'instance_id') self.instance_id = attributes[:'instance_id'] if attributes[:'instance_id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.nic_index = attributes[:'nicIndex'] if attributes[:'nicIndex'] raise 'You cannot provide both :nicIndex and :nic_index' if attributes.key?(:'nicIndex') && attributes.key?(:'nic_index') self.nic_index = attributes[:'nic_index'] if attributes[:'nic_index'] self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId'] raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id') self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id'] self.vlan_id = attributes[:'vlanId'] if attributes[:'vlanId'] raise 'You cannot provide both :vlanId and :vlan_id' if attributes.key?(:'vlanId') && attributes.key?(:'vlan_id') self.vlan_id = attributes[:'vlan_id'] if attributes[:'vlan_id'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.vlan_tag = attributes[:'vlanTag'] if attributes[:'vlanTag'] raise 'You cannot provide both :vlanTag and :vlan_tag' if attributes.key?(:'vlanTag') && attributes.key?(:'vlan_tag') self.vlan_tag = attributes[:'vlan_tag'] if attributes[:'vlan_tag'] self.vnic_id = attributes[:'vnicId'] if attributes[:'vnicId'] raise 'You cannot provide both :vnicId and :vnic_id' if attributes.key?(:'vnicId') && attributes.key?(:'vnic_id') self.vnic_id = attributes[:'vnic_id'] if attributes[:'vnic_id'] end |
Instance Attribute Details
#availability_domain ⇒ String
**[Required]** The availability domain of the instance.
Example: `Uocm:PHX-AD-1`
29 30 31 |
# File 'lib/oci/core/models/vnic_attachment.rb', line 29 def availability_domain @availability_domain end |
#compartment_id ⇒ String
**[Required]** The OCID of the compartment the VNIC attachment is in, which is the same compartment the instance is in.
35 36 37 |
# File 'lib/oci/core/models/vnic_attachment.rb', line 35 def compartment_id @compartment_id end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
41 42 43 |
# File 'lib/oci/core/models/vnic_attachment.rb', line 41 def display_name @display_name end |
#id ⇒ String
**[Required]** The OCID of the VNIC attachment.
45 46 47 |
# File 'lib/oci/core/models/vnic_attachment.rb', line 45 def id @id end |
#instance_id ⇒ String
**[Required]** The OCID of the instance.
49 50 51 |
# File 'lib/oci/core/models/vnic_attachment.rb', line 49 def instance_id @instance_id end |
#lifecycle_state ⇒ String
**[Required]** The current state of the VNIC attachment.
53 54 55 |
# File 'lib/oci/core/models/vnic_attachment.rb', line 53 def lifecycle_state @lifecycle_state end |
#nic_index ⇒ Integer
Which physical network interface card (NIC) the VNIC uses. Certain bare metal instance shapes have two active physical NICs (0 and 1). If you add a secondary VNIC to one of these instances, you can specify which NIC the VNIC will use. For more information, see [Virtual Network Interface Cards (VNICs)](docs.cloud.oracle.com/iaas/Content/Network/Tasks/managingVNICs.htm).
62 63 64 |
# File 'lib/oci/core/models/vnic_attachment.rb', line 62 def nic_index @nic_index end |
#subnet_id ⇒ String
The OCID of the subnet to create the VNIC in.
66 67 68 |
# File 'lib/oci/core/models/vnic_attachment.rb', line 66 def subnet_id @subnet_id end |
#time_created ⇒ DateTime
**[Required]** The date and time the VNIC attachment was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Example: `2016-08-25T21:10:29.600Z`
82 83 84 |
# File 'lib/oci/core/models/vnic_attachment.rb', line 82 def time_created @time_created end |
#vlan_id ⇒ String
The OCID of the VLAN to create the VNIC in. Creating the VNIC in a VLAN (instead of a subnet) is possible only if you are an Oracle Cloud VMware Solution customer. See OCI::Core::Models::Vlan.
An error is returned if the instance already has a VNIC attached to it from this VLAN.
75 76 77 |
# File 'lib/oci/core/models/vnic_attachment.rb', line 75 def vlan_id @vlan_id end |
#vlan_tag ⇒ Integer
The Oracle-assigned VLAN tag of the attached VNIC. Available after the attachment process is complete.
However, if the VNIC belongs to a VLAN as part of the Oracle Cloud VMware Solution, the `vlanTag` value is instead the value of the `vlanTag` attribute for the VLAN. See OCI::Core::Models::Vlan.
Example: `0`
94 95 96 |
# File 'lib/oci/core/models/vnic_attachment.rb', line 94 def vlan_tag @vlan_tag end |
#vnic_id ⇒ String
The OCID of the VNIC. Available after the attachment process is complete.
99 100 101 |
# File 'lib/oci/core/models/vnic_attachment.rb', line 99 def vnic_id @vnic_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/oci/core/models/vnic_attachment.rb', line 102 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'availability_domain': :'availabilityDomain', 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'id': :'id', 'instance_id': :'instanceId', 'lifecycle_state': :'lifecycleState', 'nic_index': :'nicIndex', 'subnet_id': :'subnetId', 'vlan_id': :'vlanId', 'time_created': :'timeCreated', 'vlan_tag': :'vlanTag', 'vnic_id': :'vnicId' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/oci/core/models/vnic_attachment.rb', line 122 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'availability_domain': :'String', 'compartment_id': :'String', 'display_name': :'String', 'id': :'String', 'instance_id': :'String', 'lifecycle_state': :'String', 'nic_index': :'Integer', 'subnet_id': :'String', 'vlan_id': :'String', 'time_created': :'DateTime', 'vlan_tag': :'Integer', 'vnic_id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/oci/core/models/vnic_attachment.rb', line 254 def ==(other) return true if equal?(other) self.class == other.class && availability_domain == other.availability_domain && compartment_id == other.compartment_id && display_name == other.display_name && id == other.id && instance_id == other.instance_id && lifecycle_state == other.lifecycle_state && nic_index == other.nic_index && subnet_id == other.subnet_id && vlan_id == other.vlan_id && time_created == other.time_created && vlan_tag == other.vlan_tag && vnic_id == other.vnic_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/oci/core/models/vnic_attachment.rb', line 295 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
275 276 277 |
# File 'lib/oci/core/models/vnic_attachment.rb', line 275 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
284 285 286 |
# File 'lib/oci/core/models/vnic_attachment.rb', line 284 def hash [availability_domain, compartment_id, display_name, id, instance_id, lifecycle_state, nic_index, subnet_id, vlan_id, time_created, vlan_tag, vnic_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
328 329 330 331 332 333 334 335 336 337 |
# File 'lib/oci/core/models/vnic_attachment.rb', line 328 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
322 323 324 |
# File 'lib/oci/core/models/vnic_attachment.rb', line 322 def to_s to_hash.to_s end |