Class: OCI::Core::Models::Volume
- Inherits:
-
Object
- Object
- OCI::Core::Models::Volume
- Defined in:
- lib/oci/core/models/volume.rb
Overview
A detachable block volume device that allows you to dynamically expand the storage capacity of an instance. For more information, see [Overview of Cloud Volume Storage](docs.cloud.oracle.com/iaas/Content/Block/Concepts/overview.htm).
To use any of the API operations, you must be authorized in an IAM policy. If you're not authorized, talk to an administrator. If you're an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/iaas/Content/Identity/Concepts/policygetstarted.htm).
*Warning:* Oracle recommends that you avoid using any confidential information when you supply string values using the API.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze, LIFECYCLE_STATE_RESTORING = 'RESTORING'.freeze, LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze, LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze, LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze, LIFECYCLE_STATE_FAULTY = 'FAULTY'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#auto_tuned_vpus_per_gb ⇒ Integer
The number of Volume Performance Units per GB that this volume is effectively tuned to when it's idle.
-
#availability_domain ⇒ String
**[Required]** The availability domain of the volume.
-
#block_volume_replicas ⇒ Array<OCI::Core::Models::BlockVolumeReplicaInfo>
The list of block volume replicas of this volume.
-
#compartment_id ⇒ String
**[Required]** The OCID of the compartment that contains the volume.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
**[Required]** A user-friendly name.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
**[Required]** The OCID of the volume.
-
#is_auto_tune_enabled ⇒ BOOLEAN
Specifies whether the auto-tune performance is enabled for this volume.
-
#is_hydrated ⇒ BOOLEAN
Specifies whether the cloned volume's data has finished copying from the source volume or backup.
-
#kms_key_id ⇒ String
The OCID of the Key Management key which is the master encryption key for the volume.
-
#lifecycle_state ⇒ String
**[Required]** The current state of a volume.
-
#size_in_gbs ⇒ Integer
The size of the volume in GBs.
-
#size_in_mbs ⇒ Integer
**[Required]** The size of the volume in MBs.
- #source_details ⇒ OCI::Core::Models::VolumeSourceDetails
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
System tags for this resource.
-
#time_created ⇒ DateTime
**[Required]** The date and time the volume was created.
-
#volume_group_id ⇒ String
The OCID of the source volume group.
-
#vpus_per_gb ⇒ Integer
The number of volume performance units (VPUs) that will be applied to this volume per GB, representing the Block Volume service's elastic performance options.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Volume
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Volume
Initializes the object
219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'lib/oci/core/models/volume.rb', line 219 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain'] raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain') self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] self.id = attributes[:'id'] if attributes[:'id'] self.is_hydrated = attributes[:'isHydrated'] unless attributes[:'isHydrated'].nil? raise 'You cannot provide both :isHydrated and :is_hydrated' if attributes.key?(:'isHydrated') && attributes.key?(:'is_hydrated') self.is_hydrated = attributes[:'is_hydrated'] unless attributes[:'is_hydrated'].nil? self.kms_key_id = attributes[:'kmsKeyId'] if attributes[:'kmsKeyId'] raise 'You cannot provide both :kmsKeyId and :kms_key_id' if attributes.key?(:'kmsKeyId') && attributes.key?(:'kms_key_id') self.kms_key_id = attributes[:'kms_key_id'] if attributes[:'kms_key_id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.vpus_per_gb = attributes[:'vpusPerGB'] if attributes[:'vpusPerGB'] raise 'You cannot provide both :vpusPerGB and :vpus_per_gb' if attributes.key?(:'vpusPerGB') && attributes.key?(:'vpus_per_gb') self.vpus_per_gb = attributes[:'vpus_per_gb'] if attributes[:'vpus_per_gb'] self.size_in_gbs = attributes[:'sizeInGBs'] if attributes[:'sizeInGBs'] raise 'You cannot provide both :sizeInGBs and :size_in_gbs' if attributes.key?(:'sizeInGBs') && attributes.key?(:'size_in_gbs') self.size_in_gbs = attributes[:'size_in_gbs'] if attributes[:'size_in_gbs'] self.size_in_mbs = attributes[:'sizeInMBs'] if attributes[:'sizeInMBs'] raise 'You cannot provide both :sizeInMBs and :size_in_mbs' if attributes.key?(:'sizeInMBs') && attributes.key?(:'size_in_mbs') self.size_in_mbs = attributes[:'size_in_mbs'] if attributes[:'size_in_mbs'] self.source_details = attributes[:'sourceDetails'] if attributes[:'sourceDetails'] raise 'You cannot provide both :sourceDetails and :source_details' if attributes.key?(:'sourceDetails') && attributes.key?(:'source_details') self.source_details = attributes[:'source_details'] if attributes[:'source_details'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.volume_group_id = attributes[:'volumeGroupId'] if attributes[:'volumeGroupId'] raise 'You cannot provide both :volumeGroupId and :volume_group_id' if attributes.key?(:'volumeGroupId') && attributes.key?(:'volume_group_id') self.volume_group_id = attributes[:'volume_group_id'] if attributes[:'volume_group_id'] self.is_auto_tune_enabled = attributes[:'isAutoTuneEnabled'] unless attributes[:'isAutoTuneEnabled'].nil? raise 'You cannot provide both :isAutoTuneEnabled and :is_auto_tune_enabled' if attributes.key?(:'isAutoTuneEnabled') && attributes.key?(:'is_auto_tune_enabled') self.is_auto_tune_enabled = attributes[:'is_auto_tune_enabled'] unless attributes[:'is_auto_tune_enabled'].nil? self.auto_tuned_vpus_per_gb = attributes[:'autoTunedVpusPerGB'] if attributes[:'autoTunedVpusPerGB'] raise 'You cannot provide both :autoTunedVpusPerGB and :auto_tuned_vpus_per_gb' if attributes.key?(:'autoTunedVpusPerGB') && attributes.key?(:'auto_tuned_vpus_per_gb') self.auto_tuned_vpus_per_gb = attributes[:'auto_tuned_vpus_per_gb'] if attributes[:'auto_tuned_vpus_per_gb'] self.block_volume_replicas = attributes[:'blockVolumeReplicas'] if attributes[:'blockVolumeReplicas'] raise 'You cannot provide both :blockVolumeReplicas and :block_volume_replicas' if attributes.key?(:'blockVolumeReplicas') && attributes.key?(:'block_volume_replicas') self.block_volume_replicas = attributes[:'block_volume_replicas'] if attributes[:'block_volume_replicas'] end |
Instance Attribute Details
#auto_tuned_vpus_per_gb ⇒ Integer
The number of Volume Performance Units per GB that this volume is effectively tuned to when it's idle.
134 135 136 |
# File 'lib/oci/core/models/volume.rb', line 134 def auto_tuned_vpus_per_gb @auto_tuned_vpus_per_gb end |
#availability_domain ⇒ String
**[Required]** The availability domain of the volume.
Example: `Uocm:PHX-AD-1`
36 37 38 |
# File 'lib/oci/core/models/volume.rb', line 36 def availability_domain @availability_domain end |
#block_volume_replicas ⇒ Array<OCI::Core::Models::BlockVolumeReplicaInfo>
The list of block volume replicas of this volume.
138 139 140 |
# File 'lib/oci/core/models/volume.rb', line 138 def block_volume_replicas @block_volume_replicas end |
#compartment_id ⇒ String
**[Required]** The OCID of the compartment that contains the volume.
40 41 42 |
# File 'lib/oci/core/models/volume.rb', line 40 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: `{"CostCenter": "42"}`
48 49 50 |
# File 'lib/oci/core/models/volume.rb', line 48 def @defined_tags end |
#display_name ⇒ String
**[Required]** A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
54 55 56 |
# File 'lib/oci/core/models/volume.rb', line 54 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: `"Finance"`
62 63 64 |
# File 'lib/oci/core/models/volume.rb', line 62 def @freeform_tags end |
#id ⇒ String
**[Required]** The OCID of the volume.
72 73 74 |
# File 'lib/oci/core/models/volume.rb', line 72 def id @id end |
#is_auto_tune_enabled ⇒ BOOLEAN
Specifies whether the auto-tune performance is enabled for this volume.
129 130 131 |
# File 'lib/oci/core/models/volume.rb', line 129 def is_auto_tune_enabled @is_auto_tune_enabled end |
#is_hydrated ⇒ BOOLEAN
Specifies whether the cloned volume's data has finished copying from the source volume or backup.
77 78 79 |
# File 'lib/oci/core/models/volume.rb', line 77 def is_hydrated @is_hydrated end |
#kms_key_id ⇒ String
The OCID of the Key Management key which is the master encryption key for the volume.
82 83 84 |
# File 'lib/oci/core/models/volume.rb', line 82 def kms_key_id @kms_key_id end |
#lifecycle_state ⇒ String
**[Required]** The current state of a volume.
86 87 88 |
# File 'lib/oci/core/models/volume.rb', line 86 def lifecycle_state @lifecycle_state end |
#size_in_gbs ⇒ Integer
The size of the volume in GBs.
107 108 109 |
# File 'lib/oci/core/models/volume.rb', line 107 def size_in_gbs @size_in_gbs end |
#size_in_mbs ⇒ Integer
**[Required]** The size of the volume in MBs. This field is deprecated. Use sizeInGBs instead.
113 114 115 |
# File 'lib/oci/core/models/volume.rb', line 113 def size_in_mbs @size_in_mbs end |
#source_details ⇒ OCI::Core::Models::VolumeSourceDetails
116 117 118 |
# File 'lib/oci/core/models/volume.rb', line 116 def source_details @source_details end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
System tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
68 69 70 |
# File 'lib/oci/core/models/volume.rb', line 68 def @system_tags end |
#time_created ⇒ DateTime
**[Required]** The date and time the volume was created. Format defined by [RFC3339](tools.ietf.org/html/rfc3339).
120 121 122 |
# File 'lib/oci/core/models/volume.rb', line 120 def time_created @time_created end |
#volume_group_id ⇒ String
The OCID of the source volume group.
124 125 126 |
# File 'lib/oci/core/models/volume.rb', line 124 def volume_group_id @volume_group_id end |
#vpus_per_gb ⇒ Integer
The number of volume performance units (VPUs) that will be applied to this volume per GB, representing the Block Volume service's elastic performance options. See [Block Volume Performance Levels](docs.cloud.oracle.com/iaas/Content/Block/Concepts/blockvolumeperformance.htm#perf_levels) for more information.
Allowed values:
* `0`: Represents Lower Cost option.
* `10`: Represents Balanced option.
* `20`: Represents Higher Performance option.
* `30`-`120`: Represents the Ultra High Performance option.
103 104 105 |
# File 'lib/oci/core/models/volume.rb', line 103 def vpus_per_gb @vpus_per_gb end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/oci/core/models/volume.rb', line 141 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'availability_domain': :'availabilityDomain', 'compartment_id': :'compartmentId', 'defined_tags': :'definedTags', 'display_name': :'displayName', 'freeform_tags': :'freeformTags', 'system_tags': :'systemTags', 'id': :'id', 'is_hydrated': :'isHydrated', 'kms_key_id': :'kmsKeyId', 'lifecycle_state': :'lifecycleState', 'vpus_per_gb': :'vpusPerGB', 'size_in_gbs': :'sizeInGBs', 'size_in_mbs': :'sizeInMBs', 'source_details': :'sourceDetails', 'time_created': :'timeCreated', 'volume_group_id': :'volumeGroupId', 'is_auto_tune_enabled': :'isAutoTuneEnabled', 'auto_tuned_vpus_per_gb': :'autoTunedVpusPerGB', 'block_volume_replicas': :'blockVolumeReplicas' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/oci/core/models/volume.rb', line 168 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'availability_domain': :'String', 'compartment_id': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'freeform_tags': :'Hash<String, String>', 'system_tags': :'Hash<String, Hash<String, Object>>', 'id': :'String', 'is_hydrated': :'BOOLEAN', 'kms_key_id': :'String', 'lifecycle_state': :'String', 'vpus_per_gb': :'Integer', 'size_in_gbs': :'Integer', 'size_in_mbs': :'Integer', 'source_details': :'OCI::Core::Models::VolumeSourceDetails', 'time_created': :'DateTime', 'volume_group_id': :'String', 'is_auto_tune_enabled': :'BOOLEAN', 'auto_tuned_vpus_per_gb': :'Integer', 'block_volume_replicas': :'Array<OCI::Core::Models::BlockVolumeReplicaInfo>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 |
# File 'lib/oci/core/models/volume.rb', line 356 def ==(other) return true if equal?(other) self.class == other.class && availability_domain == other.availability_domain && compartment_id == other.compartment_id && == other. && display_name == other.display_name && == other. && == other. && id == other.id && is_hydrated == other.is_hydrated && kms_key_id == other.kms_key_id && lifecycle_state == other.lifecycle_state && vpus_per_gb == other.vpus_per_gb && size_in_gbs == other.size_in_gbs && size_in_mbs == other.size_in_mbs && source_details == other.source_details && time_created == other.time_created && volume_group_id == other.volume_group_id && is_auto_tune_enabled == other.is_auto_tune_enabled && auto_tuned_vpus_per_gb == other.auto_tuned_vpus_per_gb && block_volume_replicas == other.block_volume_replicas end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 |
# File 'lib/oci/core/models/volume.rb', line 404 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
384 385 386 |
# File 'lib/oci/core/models/volume.rb', line 384 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
393 394 395 |
# File 'lib/oci/core/models/volume.rb', line 393 def hash [availability_domain, compartment_id, , display_name, , , id, is_hydrated, kms_key_id, lifecycle_state, vpus_per_gb, size_in_gbs, size_in_mbs, source_details, time_created, volume_group_id, is_auto_tune_enabled, auto_tuned_vpus_per_gb, block_volume_replicas].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
437 438 439 440 441 442 443 444 445 446 |
# File 'lib/oci/core/models/volume.rb', line 437 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
431 432 433 |
# File 'lib/oci/core/models/volume.rb', line 431 def to_s to_hash.to_s end |