Class: OCI::Core::Models::VolumeAttachment
- Inherits:
-
Object
- Object
- OCI::Core::Models::VolumeAttachment
- Defined in:
- lib/oci/core/models/volume_attachment.rb
Overview
A base object for all types of attachments between a storage volume and an instance. For specific details about iSCSI attachments, see IScsiVolumeAttachment.
For general information about volume attachments, see [Overview of Block Volume Storage](docs.us-phoenix-1.oraclecloud.com/Content/Block/Concepts/overview.htm).
Warning: Oracle recommends that you avoid using any confidential information when you supply string values using the API.
This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
rubocop:disable Metrics/LineLength
[ LIFECYCLE_STATE_ATTACHING = 'ATTACHING'.freeze, LIFECYCLE_STATE_ATTACHED = 'ATTACHED'.freeze, LIFECYCLE_STATE_DETACHING = 'DETACHING'.freeze, LIFECYCLE_STATE_DETACHED = 'DETACHED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#attachment_type ⇒ String
[Required] The type of volume attachment.
-
#availability_domain ⇒ String
[Required] The availability domain of an instance.
-
#compartment_id ⇒ String
[Required] The OCID of the compartment.
-
#display_name ⇒ String
A user-friendly name.
-
#id ⇒ String
[Required] The OCID of the volume attachment.
-
#instance_id ⇒ String
[Required] The OCID of the instance the volume is attached to.
-
#is_read_only ⇒ BOOLEAN
Whether the attachment was created in read-only mode.
-
#lifecycle_state ⇒ String
[Required] The current state of the volume attachment.
-
#time_created ⇒ DateTime
[Required] The date and time the volume was created, in the format defined by RFC3339.
-
#volume_id ⇒ String
[Required] The OCID of the volume.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VolumeAttachment
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ VolumeAttachment
Initializes the object
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/oci/core/models/volume_attachment.rb', line 146 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self. = attributes[:'attachmentType'] if attributes[:'attachmentType'] raise 'You cannot provide both :attachmentType and :attachment_type' if attributes.key?(:'attachmentType') && attributes.key?(:'attachment_type') self. = attributes[:'attachment_type'] if attributes[:'attachment_type'] self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain'] raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain') self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.id = attributes[:'id'] if attributes[:'id'] self.instance_id = attributes[:'instanceId'] if attributes[:'instanceId'] raise 'You cannot provide both :instanceId and :instance_id' if attributes.key?(:'instanceId') && attributes.key?(:'instance_id') self.instance_id = attributes[:'instance_id'] if attributes[:'instance_id'] self.is_read_only = attributes[:'isReadOnly'] unless attributes[:'isReadOnly'].nil? raise 'You cannot provide both :isReadOnly and :is_read_only' if attributes.key?(:'isReadOnly') && attributes.key?(:'is_read_only') self.is_read_only = attributes[:'is_read_only'] unless attributes[:'is_read_only'].nil? self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.volume_id = attributes[:'volumeId'] if attributes[:'volumeId'] raise 'You cannot provide both :volumeId and :volume_id' if attributes.key?(:'volumeId') && attributes.key?(:'volume_id') self.volume_id = attributes[:'volume_id'] if attributes[:'volume_id'] end |
Instance Attribute Details
#attachment_type ⇒ String
[Required] The type of volume attachment.
30 31 32 |
# File 'lib/oci/core/models/volume_attachment.rb', line 30 def @attachment_type end |
#availability_domain ⇒ String
[Required] The availability domain of an instance.
Example: Uocm:PHX-AD-1
37 38 39 |
# File 'lib/oci/core/models/volume_attachment.rb', line 37 def availability_domain @availability_domain end |
#compartment_id ⇒ String
[Required] The OCID of the compartment.
41 42 43 |
# File 'lib/oci/core/models/volume_attachment.rb', line 41 def compartment_id @compartment_id end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it cannot be changed. Avoid entering confidential information.
Example: ‘My volume attachment`
49 50 51 |
# File 'lib/oci/core/models/volume_attachment.rb', line 49 def display_name @display_name end |
#id ⇒ String
[Required] The OCID of the volume attachment.
53 54 55 |
# File 'lib/oci/core/models/volume_attachment.rb', line 53 def id @id end |
#instance_id ⇒ String
[Required] The OCID of the instance the volume is attached to.
57 58 59 |
# File 'lib/oci/core/models/volume_attachment.rb', line 57 def instance_id @instance_id end |
#is_read_only ⇒ BOOLEAN
Whether the attachment was created in read-only mode.
61 62 63 |
# File 'lib/oci/core/models/volume_attachment.rb', line 61 def is_read_only @is_read_only end |
#lifecycle_state ⇒ String
[Required] The current state of the volume attachment.
65 66 67 |
# File 'lib/oci/core/models/volume_attachment.rb', line 65 def lifecycle_state @lifecycle_state end |
#time_created ⇒ DateTime
[Required] The date and time the volume was created, in the format defined by RFC3339.
Example: 2016-08-25T21:10:29.600Z
72 73 74 |
# File 'lib/oci/core/models/volume_attachment.rb', line 72 def time_created @time_created end |
#volume_id ⇒ String
[Required] The OCID of the volume.
76 77 78 |
# File 'lib/oci/core/models/volume_attachment.rb', line 76 def volume_id @volume_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/oci/core/models/volume_attachment.rb', line 79 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'attachment_type': :'attachmentType', 'availability_domain': :'availabilityDomain', 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'id': :'id', 'instance_id': :'instanceId', 'is_read_only': :'isReadOnly', 'lifecycle_state': :'lifecycleState', 'time_created': :'timeCreated', 'volume_id': :'volumeId' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
119 120 121 122 123 124 125 126 127 |
# File 'lib/oci/core/models/volume_attachment.rb', line 119 def self.get_subtype(object_hash) type = object_hash[:'attachmentType'] # rubocop:disable Style/SymbolLiteral return 'OCI::Core::Models::IScsiVolumeAttachment' if type == 'iscsi' return 'OCI::Core::Models::ParavirtualizedVolumeAttachment' if type == 'paravirtualized' # TODO: Log a warning when the subtype is not found. 'OCI::Core::Models::VolumeAttachment' end |
.swagger_types ⇒ Object
Attribute type mapping.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/oci/core/models/volume_attachment.rb', line 97 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'attachment_type': :'String', 'availability_domain': :'String', 'compartment_id': :'String', 'display_name': :'String', 'id': :'String', 'instance_id': :'String', 'is_read_only': :'BOOLEAN', 'lifecycle_state': :'String', 'time_created': :'DateTime', 'volume_id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/oci/core/models/volume_attachment.rb', line 231 def ==(other) return true if equal?(other) self.class == other.class && == other. && availability_domain == other.availability_domain && compartment_id == other.compartment_id && display_name == other.display_name && id == other.id && instance_id == other.instance_id && is_read_only == other.is_read_only && lifecycle_state == other.lifecycle_state && time_created == other.time_created && volume_id == other.volume_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 |
# File 'lib/oci/core/models/volume_attachment.rb', line 270 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
250 251 252 |
# File 'lib/oci/core/models/volume_attachment.rb', line 250 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
259 260 261 |
# File 'lib/oci/core/models/volume_attachment.rb', line 259 def hash [, availability_domain, compartment_id, display_name, id, instance_id, is_read_only, lifecycle_state, time_created, volume_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
303 304 305 306 307 308 309 310 311 312 |
# File 'lib/oci/core/models/volume_attachment.rb', line 303 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
297 298 299 |
# File 'lib/oci/core/models/volume_attachment.rb', line 297 def to_s to_hash.to_s end |