Class: OCI::Core::Models::VolumeBackup
- Inherits:
-
Object
- Object
- OCI::Core::Models::VolumeBackup
- Defined in:
- lib/oci/core/models/volume_backup.rb
Overview
A point-in-time copy of a volume that can then be used to create a new block volume or recover a block volume. For more information, see [Overview of Cloud Volume Storage](docs.cloud.oracle.com/Content/Block/Concepts/overview.htm).
To use any of the API operations, you must be authorized in an IAM policy. If you’re not authorized, talk to an administrator. If you’re an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm).
Warning: Oracle recommends that you avoid using any confidential information when you supply string values using the API.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze, LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze, LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze, LIFECYCLE_STATE_FAULTY = 'FAULTY'.freeze, LIFECYCLE_STATE_REQUEST_RECEIVED = 'REQUEST_RECEIVED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- SOURCE_TYPE_ENUM =
[ SOURCE_TYPE_MANUAL = 'MANUAL'.freeze, SOURCE_TYPE_SCHEDULED = 'SCHEDULED'.freeze, SOURCE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- TYPE_ENUM =
[ TYPE_FULL = 'FULL'.freeze, TYPE_INCREMENTAL = 'INCREMENTAL'.freeze, TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The OCID of the compartment that contains the volume backup.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
[Required] A user-friendly name for the volume backup.
-
#expiration_time ⇒ DateTime
The date and time the volume backup will expire and be automatically deleted.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] The OCID of the volume backup.
-
#lifecycle_state ⇒ String
[Required] The current state of a volume backup.
-
#size_in_gbs ⇒ Integer
The size of the volume, in GBs.
-
#size_in_mbs ⇒ Integer
The size of the volume in MBs.
-
#source_type ⇒ String
Specifies whether the backup was created manually, or via scheduled backup policy.
-
#source_volume_backup_id ⇒ String
The OCID of the source volume backup.
-
#time_created ⇒ DateTime
[Required] The date and time the volume backup was created.
-
#time_request_received ⇒ DateTime
The date and time the request to create the volume backup was received.
-
#type ⇒ String
[Required] The type of a volume backup.
-
#unique_size_in_gbs ⇒ Integer
The size used by the backup, in GBs.
-
#unique_size_in_mbs ⇒ Integer
The size used by the backup, in MBs.
-
#volume_id ⇒ String
The OCID of the volume.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VolumeBackup
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ VolumeBackup
Initializes the object
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 |
# File 'lib/oci/core/models/volume_backup.rb', line 209 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.expiration_time = attributes[:'expirationTime'] if attributes[:'expirationTime'] raise 'You cannot provide both :expirationTime and :expiration_time' if attributes.key?(:'expirationTime') && attributes.key?(:'expiration_time') self.expiration_time = attributes[:'expiration_time'] if attributes[:'expiration_time'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.id = attributes[:'id'] if attributes[:'id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.size_in_gbs = attributes[:'sizeInGBs'] if attributes[:'sizeInGBs'] raise 'You cannot provide both :sizeInGBs and :size_in_gbs' if attributes.key?(:'sizeInGBs') && attributes.key?(:'size_in_gbs') self.size_in_gbs = attributes[:'size_in_gbs'] if attributes[:'size_in_gbs'] self.size_in_mbs = attributes[:'sizeInMBs'] if attributes[:'sizeInMBs'] raise 'You cannot provide both :sizeInMBs and :size_in_mbs' if attributes.key?(:'sizeInMBs') && attributes.key?(:'size_in_mbs') self.size_in_mbs = attributes[:'size_in_mbs'] if attributes[:'size_in_mbs'] self.source_type = attributes[:'sourceType'] if attributes[:'sourceType'] raise 'You cannot provide both :sourceType and :source_type' if attributes.key?(:'sourceType') && attributes.key?(:'source_type') self.source_type = attributes[:'source_type'] if attributes[:'source_type'] self.source_volume_backup_id = attributes[:'sourceVolumeBackupId'] if attributes[:'sourceVolumeBackupId'] raise 'You cannot provide both :sourceVolumeBackupId and :source_volume_backup_id' if attributes.key?(:'sourceVolumeBackupId') && attributes.key?(:'source_volume_backup_id') self.source_volume_backup_id = attributes[:'source_volume_backup_id'] if attributes[:'source_volume_backup_id'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_request_received = attributes[:'timeRequestReceived'] if attributes[:'timeRequestReceived'] raise 'You cannot provide both :timeRequestReceived and :time_request_received' if attributes.key?(:'timeRequestReceived') && attributes.key?(:'time_request_received') self.time_request_received = attributes[:'time_request_received'] if attributes[:'time_request_received'] self.type = attributes[:'type'] if attributes[:'type'] self.unique_size_in_gbs = attributes[:'uniqueSizeInGBs'] if attributes[:'uniqueSizeInGBs'] raise 'You cannot provide both :uniqueSizeInGBs and :unique_size_in_gbs' if attributes.key?(:'uniqueSizeInGBs') && attributes.key?(:'unique_size_in_gbs') self.unique_size_in_gbs = attributes[:'unique_size_in_gbs'] if attributes[:'unique_size_in_gbs'] self.unique_size_in_mbs = attributes[:'uniqueSizeInMbs'] if attributes[:'uniqueSizeInMbs'] raise 'You cannot provide both :uniqueSizeInMbs and :unique_size_in_mbs' if attributes.key?(:'uniqueSizeInMbs') && attributes.key?(:'unique_size_in_mbs') self.unique_size_in_mbs = attributes[:'unique_size_in_mbs'] if attributes[:'unique_size_in_mbs'] self.volume_id = attributes[:'volumeId'] if attributes[:'volumeId'] raise 'You cannot provide both :volumeId and :volume_id' if attributes.key?(:'volumeId') && attributes.key?(:'volume_id') self.volume_id = attributes[:'volume_id'] if attributes[:'volume_id'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The OCID of the compartment that contains the volume backup.
44 45 46 |
# File 'lib/oci/core/models/volume_backup.rb', line 44 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
52 53 54 |
# File 'lib/oci/core/models/volume_backup.rb', line 52 def end |
#display_name ⇒ String
[Required] A user-friendly name for the volume backup. Does not have to be unique and it’s changeable. Avoid entering confidential information.
58 59 60 |
# File 'lib/oci/core/models/volume_backup.rb', line 58 def display_name @display_name end |
#expiration_time ⇒ DateTime
The date and time the volume backup will expire and be automatically deleted. Format defined by RFC3339. This parameter will always be present for backups that were created automatically by a scheduled-backup policy. For manually created backups, it will be absent, signifying that there is no expiration time and the backup will last forever until manually deleted.
67 68 69 |
# File 'lib/oci/core/models/volume_backup.rb', line 67 def expiration_time @expiration_time end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
75 76 77 |
# File 'lib/oci/core/models/volume_backup.rb', line 75 def end |
#id ⇒ String
[Required] The OCID of the volume backup.
79 80 81 |
# File 'lib/oci/core/models/volume_backup.rb', line 79 def id @id end |
#lifecycle_state ⇒ String
[Required] The current state of a volume backup.
83 84 85 |
# File 'lib/oci/core/models/volume_backup.rb', line 83 def lifecycle_state @lifecycle_state end |
#size_in_gbs ⇒ Integer
The size of the volume, in GBs.
88 89 90 |
# File 'lib/oci/core/models/volume_backup.rb', line 88 def size_in_gbs @size_in_gbs end |
#size_in_mbs ⇒ Integer
The size of the volume in MBs. The value must be a multiple of 1024. This field is deprecated. Please use sizeInGBs.
94 95 96 |
# File 'lib/oci/core/models/volume_backup.rb', line 94 def size_in_mbs @size_in_mbs end |
#source_type ⇒ String
Specifies whether the backup was created manually, or via scheduled backup policy.
98 99 100 |
# File 'lib/oci/core/models/volume_backup.rb', line 98 def source_type @source_type end |
#source_volume_backup_id ⇒ String
The OCID of the source volume backup.
102 103 104 |
# File 'lib/oci/core/models/volume_backup.rb', line 102 def source_volume_backup_id @source_volume_backup_id end |
#time_created ⇒ DateTime
[Required] The date and time the volume backup was created. This is the time the actual point-in-time image of the volume data was taken. Format defined by RFC3339.
108 109 110 |
# File 'lib/oci/core/models/volume_backup.rb', line 108 def time_created @time_created end |
#time_request_received ⇒ DateTime
The date and time the request to create the volume backup was received. Format defined by RFC3339.
113 114 115 |
# File 'lib/oci/core/models/volume_backup.rb', line 113 def time_request_received @time_request_received end |
#type ⇒ String
[Required] The type of a volume backup.
117 118 119 |
# File 'lib/oci/core/models/volume_backup.rb', line 117 def type @type end |
#unique_size_in_gbs ⇒ Integer
The size used by the backup, in GBs. It is typically smaller than sizeInGBs, depending on the space consumed on the volume and whether the backup is full or incremental.
123 124 125 |
# File 'lib/oci/core/models/volume_backup.rb', line 123 def unique_size_in_gbs @unique_size_in_gbs end |
#unique_size_in_mbs ⇒ Integer
The size used by the backup, in MBs. It is typically smaller than sizeInMBs, depending on the space consumed on the volume and whether the backup is full or incremental. This field is deprecated. Please use uniqueSizeInGBs.
130 131 132 |
# File 'lib/oci/core/models/volume_backup.rb', line 130 def unique_size_in_mbs @unique_size_in_mbs end |
#volume_id ⇒ String
The OCID of the volume.
134 135 136 |
# File 'lib/oci/core/models/volume_backup.rb', line 134 def volume_id @volume_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/oci/core/models/volume_backup.rb', line 137 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'defined_tags': :'definedTags', 'display_name': :'displayName', 'expiration_time': :'expirationTime', 'freeform_tags': :'freeformTags', 'id': :'id', 'lifecycle_state': :'lifecycleState', 'size_in_gbs': :'sizeInGBs', 'size_in_mbs': :'sizeInMBs', 'source_type': :'sourceType', 'source_volume_backup_id': :'sourceVolumeBackupId', 'time_created': :'timeCreated', 'time_request_received': :'timeRequestReceived', 'type': :'type', 'unique_size_in_gbs': :'uniqueSizeInGBs', 'unique_size_in_mbs': :'uniqueSizeInMbs', 'volume_id': :'volumeId' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/oci/core/models/volume_backup.rb', line 162 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'expiration_time': :'DateTime', 'freeform_tags': :'Hash<String, String>', 'id': :'String', 'lifecycle_state': :'String', 'size_in_gbs': :'Integer', 'size_in_mbs': :'Integer', 'source_type': :'String', 'source_volume_backup_id': :'String', 'time_created': :'DateTime', 'time_request_received': :'DateTime', 'type': :'String', 'unique_size_in_gbs': :'Integer', 'unique_size_in_mbs': :'Integer', 'volume_id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 |
# File 'lib/oci/core/models/volume_backup.rb', line 356 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && == other. && display_name == other.display_name && expiration_time == other.expiration_time && == other. && id == other.id && lifecycle_state == other.lifecycle_state && size_in_gbs == other.size_in_gbs && size_in_mbs == other.size_in_mbs && source_type == other.source_type && source_volume_backup_id == other.source_volume_backup_id && time_created == other.time_created && time_request_received == other.time_request_received && type == other.type && unique_size_in_gbs == other.unique_size_in_gbs && unique_size_in_mbs == other.unique_size_in_mbs && volume_id == other.volume_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 |
# File 'lib/oci/core/models/volume_backup.rb', line 402 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
382 383 384 |
# File 'lib/oci/core/models/volume_backup.rb', line 382 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
391 392 393 |
# File 'lib/oci/core/models/volume_backup.rb', line 391 def hash [compartment_id, , display_name, expiration_time, , id, lifecycle_state, size_in_gbs, size_in_mbs, source_type, source_volume_backup_id, time_created, time_request_received, type, unique_size_in_gbs, unique_size_in_mbs, volume_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
435 436 437 438 439 440 441 442 443 444 |
# File 'lib/oci/core/models/volume_backup.rb', line 435 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
429 430 431 |
# File 'lib/oci/core/models/volume_backup.rb', line 429 def to_s to_hash.to_s end |