Class: OCI::Core::Models::VolumeGroup
- Inherits:
-
Object
- Object
- OCI::Core::Models::VolumeGroup
- Defined in:
- lib/oci/core/models/volume_group.rb
Overview
Specifies a volume group which is a collection of volumes. For more information, see [Volume Groups](docs.cloud.oracle.com/iaas/Content/Block/Concepts/volumegroups.htm).
Warning: Oracle recommends that you avoid using any confidential information when you supply string values using the API.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze, LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze, LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze, LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze, LIFECYCLE_STATE_FAULTY = 'FAULTY'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#availability_domain ⇒ String
[Required] The availability domain of the volume group.
-
#compartment_id ⇒ String
[Required] The OCID of the compartment that contains the volume group.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
[Required] A user-friendly name.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] The OCID for the volume group.
-
#is_hydrated ⇒ BOOLEAN
Specifies whether the newly created cloned volume group’s data has finished copying from the source volume group or backup.
-
#lifecycle_state ⇒ String
[Required] The current state of a volume group.
-
#size_in_gbs ⇒ Integer
The aggregate size of the volume group in GBs.
-
#size_in_mbs ⇒ Integer
[Required] The aggregate size of the volume group in MBs.
- #source_details ⇒ OCI::Core::Models::VolumeGroupSourceDetails
-
#time_created ⇒ DateTime
[Required] The date and time the volume group was created.
-
#volume_group_replicas ⇒ Array<OCI::Core::Models::VolumeGroupReplicaInfo>
The list of volume group replicas of this volume group.
-
#volume_ids ⇒ Array<String>
[Required] OCIDs for the volumes in this volume group.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VolumeGroup
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ VolumeGroup
Initializes the object
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/oci/core/models/volume_group.rb', line 156 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain'] raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain') self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.id = attributes[:'id'] if attributes[:'id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.size_in_mbs = attributes[:'sizeInMBs'] if attributes[:'sizeInMBs'] raise 'You cannot provide both :sizeInMBs and :size_in_mbs' if attributes.key?(:'sizeInMBs') && attributes.key?(:'size_in_mbs') self.size_in_mbs = attributes[:'size_in_mbs'] if attributes[:'size_in_mbs'] self.size_in_gbs = attributes[:'sizeInGBs'] if attributes[:'sizeInGBs'] raise 'You cannot provide both :sizeInGBs and :size_in_gbs' if attributes.key?(:'sizeInGBs') && attributes.key?(:'size_in_gbs') self.size_in_gbs = attributes[:'size_in_gbs'] if attributes[:'size_in_gbs'] self.source_details = attributes[:'sourceDetails'] if attributes[:'sourceDetails'] raise 'You cannot provide both :sourceDetails and :source_details' if attributes.key?(:'sourceDetails') && attributes.key?(:'source_details') self.source_details = attributes[:'source_details'] if attributes[:'source_details'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.volume_ids = attributes[:'volumeIds'] if attributes[:'volumeIds'] raise 'You cannot provide both :volumeIds and :volume_ids' if attributes.key?(:'volumeIds') && attributes.key?(:'volume_ids') self.volume_ids = attributes[:'volume_ids'] if attributes[:'volume_ids'] self.is_hydrated = attributes[:'isHydrated'] unless attributes[:'isHydrated'].nil? raise 'You cannot provide both :isHydrated and :is_hydrated' if attributes.key?(:'isHydrated') && attributes.key?(:'is_hydrated') self.is_hydrated = attributes[:'is_hydrated'] unless attributes[:'is_hydrated'].nil? self.volume_group_replicas = attributes[:'volumeGroupReplicas'] if attributes[:'volumeGroupReplicas'] raise 'You cannot provide both :volumeGroupReplicas and :volume_group_replicas' if attributes.key?(:'volumeGroupReplicas') && attributes.key?(:'volume_group_replicas') self.volume_group_replicas = attributes[:'volume_group_replicas'] if attributes[:'volume_group_replicas'] end |
Instance Attribute Details
#availability_domain ⇒ String
[Required] The availability domain of the volume group.
27 28 29 |
# File 'lib/oci/core/models/volume_group.rb', line 27 def availability_domain @availability_domain end |
#compartment_id ⇒ String
[Required] The OCID of the compartment that contains the volume group.
31 32 33 |
# File 'lib/oci/core/models/volume_group.rb', line 31 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
39 40 41 |
# File 'lib/oci/core/models/volume_group.rb', line 39 def @defined_tags end |
#display_name ⇒ String
[Required] A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
45 46 47 |
# File 'lib/oci/core/models/volume_group.rb', line 45 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
53 54 55 |
# File 'lib/oci/core/models/volume_group.rb', line 53 def @freeform_tags end |
#id ⇒ String
[Required] The OCID for the volume group.
57 58 59 |
# File 'lib/oci/core/models/volume_group.rb', line 57 def id @id end |
#is_hydrated ⇒ BOOLEAN
Specifies whether the newly created cloned volume group’s data has finished copying from the source volume group or backup.
86 87 88 |
# File 'lib/oci/core/models/volume_group.rb', line 86 def is_hydrated @is_hydrated end |
#lifecycle_state ⇒ String
[Required] The current state of a volume group.
61 62 63 |
# File 'lib/oci/core/models/volume_group.rb', line 61 def lifecycle_state @lifecycle_state end |
#size_in_gbs ⇒ Integer
The aggregate size of the volume group in GBs.
69 70 71 |
# File 'lib/oci/core/models/volume_group.rb', line 69 def size_in_gbs @size_in_gbs end |
#size_in_mbs ⇒ Integer
[Required] The aggregate size of the volume group in MBs.
65 66 67 |
# File 'lib/oci/core/models/volume_group.rb', line 65 def size_in_mbs @size_in_mbs end |
#source_details ⇒ OCI::Core::Models::VolumeGroupSourceDetails
72 73 74 |
# File 'lib/oci/core/models/volume_group.rb', line 72 def source_details @source_details end |
#time_created ⇒ DateTime
[Required] The date and time the volume group was created. Format defined by [RFC3339](tools.ietf.org/html/rfc3339).
76 77 78 |
# File 'lib/oci/core/models/volume_group.rb', line 76 def time_created @time_created end |
#volume_group_replicas ⇒ Array<OCI::Core::Models::VolumeGroupReplicaInfo>
The list of volume group replicas of this volume group.
90 91 92 |
# File 'lib/oci/core/models/volume_group.rb', line 90 def volume_group_replicas @volume_group_replicas end |
#volume_ids ⇒ Array<String>
[Required] OCIDs for the volumes in this volume group.
80 81 82 |
# File 'lib/oci/core/models/volume_group.rb', line 80 def volume_ids @volume_ids end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/oci/core/models/volume_group.rb', line 93 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'availability_domain': :'availabilityDomain', 'compartment_id': :'compartmentId', 'defined_tags': :'definedTags', 'display_name': :'displayName', 'freeform_tags': :'freeformTags', 'id': :'id', 'lifecycle_state': :'lifecycleState', 'size_in_mbs': :'sizeInMBs', 'size_in_gbs': :'sizeInGBs', 'source_details': :'sourceDetails', 'time_created': :'timeCreated', 'volume_ids': :'volumeIds', 'is_hydrated': :'isHydrated', 'volume_group_replicas': :'volumeGroupReplicas' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/oci/core/models/volume_group.rb', line 115 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'availability_domain': :'String', 'compartment_id': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'freeform_tags': :'Hash<String, String>', 'id': :'String', 'lifecycle_state': :'String', 'size_in_mbs': :'Integer', 'size_in_gbs': :'Integer', 'source_details': :'OCI::Core::Models::VolumeGroupSourceDetails', 'time_created': :'DateTime', 'volume_ids': :'Array<String>', 'is_hydrated': :'BOOLEAN', 'volume_group_replicas': :'Array<OCI::Core::Models::VolumeGroupReplicaInfo>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/oci/core/models/volume_group.rb', line 263 def ==(other) return true if equal?(other) self.class == other.class && availability_domain == other.availability_domain && compartment_id == other.compartment_id && == other. && display_name == other.display_name && == other. && id == other.id && lifecycle_state == other.lifecycle_state && size_in_mbs == other.size_in_mbs && size_in_gbs == other.size_in_gbs && source_details == other.source_details && time_created == other.time_created && volume_ids == other.volume_ids && is_hydrated == other.is_hydrated && volume_group_replicas == other.volume_group_replicas end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 |
# File 'lib/oci/core/models/volume_group.rb', line 306 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
286 287 288 |
# File 'lib/oci/core/models/volume_group.rb', line 286 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
295 296 297 |
# File 'lib/oci/core/models/volume_group.rb', line 295 def hash [availability_domain, compartment_id, , display_name, , id, lifecycle_state, size_in_mbs, size_in_gbs, source_details, time_created, volume_ids, is_hydrated, volume_group_replicas].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
339 340 341 342 343 344 345 346 347 348 |
# File 'lib/oci/core/models/volume_group.rb', line 339 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
333 334 335 |
# File 'lib/oci/core/models/volume_group.rb', line 333 def to_s to_hash.to_s end |