Class: OCI::Core::Models::VolumeGroupBackup
- Inherits:
-
Object
- Object
- OCI::Core::Models::VolumeGroupBackup
- Defined in:
- lib/oci/core/models/volume_group_backup.rb
Overview
A point-in-time copy of a volume group that can then be used to create a new volume group or restore a volume group. For more information, see [Volume Groups](docs.cloud.oracle.com/iaas/Content/Block/Concepts/volumegroups.htm).
To use any of the API operations, you must be authorized in an IAM policy. If you’re not authorized, talk to an administrator. If you’re an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/iaas/Content/Identity/Concepts/policygetstarted.htm).
Warning: Oracle recommends that you avoid using any confidential information when you supply string values using the API.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_COMMITTED = 'COMMITTED'.freeze, LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze, LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze, LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze, LIFECYCLE_STATE_FAULTY = 'FAULTY'.freeze, LIFECYCLE_STATE_REQUEST_RECEIVED = 'REQUEST_RECEIVED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- SOURCE_TYPE_ENUM =
[ SOURCE_TYPE_MANUAL = 'MANUAL'.freeze, SOURCE_TYPE_SCHEDULED = 'SCHEDULED'.freeze, SOURCE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- TYPE_ENUM =
[ TYPE_FULL = 'FULL'.freeze, TYPE_INCREMENTAL = 'INCREMENTAL'.freeze, TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The OCID of the compartment that contains the volume group backup.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
[Required] A user-friendly name for the volume group backup.
-
#expiration_time ⇒ DateTime
The date and time the volume group backup will expire and be automatically deleted.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] The OCID of the volume group backup.
-
#lifecycle_state ⇒ String
[Required] The current state of a volume group backup.
-
#size_in_gbs ⇒ Integer
The aggregate size of the volume group backup, in GBs.
-
#size_in_mbs ⇒ Integer
The aggregate size of the volume group backup, in MBs.
-
#source_type ⇒ String
Specifies whether the volume group backup was created manually, or via scheduled backup policy.
-
#source_volume_group_backup_id ⇒ String
The OCID of the source volume group backup.
-
#time_created ⇒ DateTime
[Required] The date and time the volume group backup was created.
-
#time_request_received ⇒ DateTime
The date and time the request to create the volume group backup was received.
-
#type ⇒ String
[Required] The type of backup.
-
#unique_size_in_gbs ⇒ Integer
The aggregate size used by the volume group backup, in GBs.
-
#unique_size_in_mbs ⇒ Integer
The aggregate size used by the volume group backup, in MBs.
-
#volume_backup_ids ⇒ Array<String>
[Required] OCIDs for the volume backups in this volume group backup.
-
#volume_group_id ⇒ String
The OCID of the source volume group.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VolumeGroupBackup
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ VolumeGroupBackup
Initializes the object
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 |
# File 'lib/oci/core/models/volume_group_backup.rb', line 221 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.expiration_time = attributes[:'expirationTime'] if attributes[:'expirationTime'] raise 'You cannot provide both :expirationTime and :expiration_time' if attributes.key?(:'expirationTime') && attributes.key?(:'expiration_time') self.expiration_time = attributes[:'expiration_time'] if attributes[:'expiration_time'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.id = attributes[:'id'] if attributes[:'id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.size_in_mbs = attributes[:'sizeInMBs'] if attributes[:'sizeInMBs'] raise 'You cannot provide both :sizeInMBs and :size_in_mbs' if attributes.key?(:'sizeInMBs') && attributes.key?(:'size_in_mbs') self.size_in_mbs = attributes[:'size_in_mbs'] if attributes[:'size_in_mbs'] self.size_in_gbs = attributes[:'sizeInGBs'] if attributes[:'sizeInGBs'] raise 'You cannot provide both :sizeInGBs and :size_in_gbs' if attributes.key?(:'sizeInGBs') && attributes.key?(:'size_in_gbs') self.size_in_gbs = attributes[:'size_in_gbs'] if attributes[:'size_in_gbs'] self.source_type = attributes[:'sourceType'] if attributes[:'sourceType'] raise 'You cannot provide both :sourceType and :source_type' if attributes.key?(:'sourceType') && attributes.key?(:'source_type') self.source_type = attributes[:'source_type'] if attributes[:'source_type'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_request_received = attributes[:'timeRequestReceived'] if attributes[:'timeRequestReceived'] raise 'You cannot provide both :timeRequestReceived and :time_request_received' if attributes.key?(:'timeRequestReceived') && attributes.key?(:'time_request_received') self.time_request_received = attributes[:'time_request_received'] if attributes[:'time_request_received'] self.type = attributes[:'type'] if attributes[:'type'] self.unique_size_in_mbs = attributes[:'uniqueSizeInMbs'] if attributes[:'uniqueSizeInMbs'] raise 'You cannot provide both :uniqueSizeInMbs and :unique_size_in_mbs' if attributes.key?(:'uniqueSizeInMbs') && attributes.key?(:'unique_size_in_mbs') self.unique_size_in_mbs = attributes[:'unique_size_in_mbs'] if attributes[:'unique_size_in_mbs'] self.unique_size_in_gbs = attributes[:'uniqueSizeInGbs'] if attributes[:'uniqueSizeInGbs'] raise 'You cannot provide both :uniqueSizeInGbs and :unique_size_in_gbs' if attributes.key?(:'uniqueSizeInGbs') && attributes.key?(:'unique_size_in_gbs') self.unique_size_in_gbs = attributes[:'unique_size_in_gbs'] if attributes[:'unique_size_in_gbs'] self.volume_backup_ids = attributes[:'volumeBackupIds'] if attributes[:'volumeBackupIds'] raise 'You cannot provide both :volumeBackupIds and :volume_backup_ids' if attributes.key?(:'volumeBackupIds') && attributes.key?(:'volume_backup_ids') self.volume_backup_ids = attributes[:'volume_backup_ids'] if attributes[:'volume_backup_ids'] self.volume_group_id = attributes[:'volumeGroupId'] if attributes[:'volumeGroupId'] raise 'You cannot provide both :volumeGroupId and :volume_group_id' if attributes.key?(:'volumeGroupId') && attributes.key?(:'volume_group_id') self.volume_group_id = attributes[:'volume_group_id'] if attributes[:'volume_group_id'] self.source_volume_group_backup_id = attributes[:'sourceVolumeGroupBackupId'] if attributes[:'sourceVolumeGroupBackupId'] raise 'You cannot provide both :sourceVolumeGroupBackupId and :source_volume_group_backup_id' if attributes.key?(:'sourceVolumeGroupBackupId') && attributes.key?(:'source_volume_group_backup_id') self.source_volume_group_backup_id = attributes[:'source_volume_group_backup_id'] if attributes[:'source_volume_group_backup_id'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The OCID of the compartment that contains the volume group backup.
45 46 47 |
# File 'lib/oci/core/models/volume_group_backup.rb', line 45 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
53 54 55 |
# File 'lib/oci/core/models/volume_group_backup.rb', line 53 def end |
#display_name ⇒ String
[Required] A user-friendly name for the volume group backup. Does not have to be unique and it’s changeable. Avoid entering confidential information.
59 60 61 |
# File 'lib/oci/core/models/volume_group_backup.rb', line 59 def display_name @display_name end |
#expiration_time ⇒ DateTime
The date and time the volume group backup will expire and be automatically deleted. Format defined by [RFC3339](tools.ietf.org/html/rfc3339). This parameter will always be present for volume group backups that were created automatically by a scheduled-backup policy. For manually created volume group backups, it will be absent, signifying that there is no expiration time and the backup will last forever until manually deleted.
68 69 70 |
# File 'lib/oci/core/models/volume_group_backup.rb', line 68 def expiration_time @expiration_time end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
76 77 78 |
# File 'lib/oci/core/models/volume_group_backup.rb', line 76 def end |
#id ⇒ String
[Required] The OCID of the volume group backup.
80 81 82 |
# File 'lib/oci/core/models/volume_group_backup.rb', line 80 def id @id end |
#lifecycle_state ⇒ String
[Required] The current state of a volume group backup.
84 85 86 |
# File 'lib/oci/core/models/volume_group_backup.rb', line 84 def lifecycle_state @lifecycle_state end |
#size_in_gbs ⇒ Integer
The aggregate size of the volume group backup, in GBs.
94 95 96 |
# File 'lib/oci/core/models/volume_group_backup.rb', line 94 def size_in_gbs @size_in_gbs end |
#size_in_mbs ⇒ Integer
The aggregate size of the volume group backup, in MBs.
89 90 91 |
# File 'lib/oci/core/models/volume_group_backup.rb', line 89 def size_in_mbs @size_in_mbs end |
#source_type ⇒ String
Specifies whether the volume group backup was created manually, or via scheduled backup policy.
100 101 102 |
# File 'lib/oci/core/models/volume_group_backup.rb', line 100 def source_type @source_type end |
#source_volume_group_backup_id ⇒ String
The OCID of the source volume group backup.
143 144 145 |
# File 'lib/oci/core/models/volume_group_backup.rb', line 143 def source_volume_group_backup_id @source_volume_group_backup_id end |
#time_created ⇒ DateTime
[Required] The date and time the volume group backup was created. This is the time the actual point-in-time image of the volume group data was taken. Format defined by [RFC3339](tools.ietf.org/html/rfc3339).
106 107 108 |
# File 'lib/oci/core/models/volume_group_backup.rb', line 106 def time_created @time_created end |
#time_request_received ⇒ DateTime
The date and time the request to create the volume group backup was received. Format defined by [RFC3339](tools.ietf.org/html/rfc3339).
111 112 113 |
# File 'lib/oci/core/models/volume_group_backup.rb', line 111 def time_request_received @time_request_received end |
#type ⇒ String
[Required] The type of backup.
115 116 117 |
# File 'lib/oci/core/models/volume_group_backup.rb', line 115 def type @type end |
#unique_size_in_gbs ⇒ Integer
The aggregate size used by the volume group backup, in GBs.
It is typically smaller than sizeInGBs, depending on the spaceconsumed on the volume group and whether the volume backup is full or incremental.
131 132 133 |
# File 'lib/oci/core/models/volume_group_backup.rb', line 131 def unique_size_in_gbs @unique_size_in_gbs end |
#unique_size_in_mbs ⇒ Integer
The aggregate size used by the volume group backup, in MBs.
It is typically smaller than sizeInMBs, depending on the spaceconsumed on the volume group and whether the volume backup is full or incremental.
123 124 125 |
# File 'lib/oci/core/models/volume_group_backup.rb', line 123 def unique_size_in_mbs @unique_size_in_mbs end |
#volume_backup_ids ⇒ Array<String>
[Required] OCIDs for the volume backups in this volume group backup.
135 136 137 |
# File 'lib/oci/core/models/volume_group_backup.rb', line 135 def volume_backup_ids @volume_backup_ids end |
#volume_group_id ⇒ String
The OCID of the source volume group.
139 140 141 |
# File 'lib/oci/core/models/volume_group_backup.rb', line 139 def volume_group_id @volume_group_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/oci/core/models/volume_group_backup.rb', line 146 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'defined_tags': :'definedTags', 'display_name': :'displayName', 'expiration_time': :'expirationTime', 'freeform_tags': :'freeformTags', 'id': :'id', 'lifecycle_state': :'lifecycleState', 'size_in_mbs': :'sizeInMBs', 'size_in_gbs': :'sizeInGBs', 'source_type': :'sourceType', 'time_created': :'timeCreated', 'time_request_received': :'timeRequestReceived', 'type': :'type', 'unique_size_in_mbs': :'uniqueSizeInMbs', 'unique_size_in_gbs': :'uniqueSizeInGbs', 'volume_backup_ids': :'volumeBackupIds', 'volume_group_id': :'volumeGroupId', 'source_volume_group_backup_id': :'sourceVolumeGroupBackupId' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/oci/core/models/volume_group_backup.rb', line 172 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'expiration_time': :'DateTime', 'freeform_tags': :'Hash<String, String>', 'id': :'String', 'lifecycle_state': :'String', 'size_in_mbs': :'Integer', 'size_in_gbs': :'Integer', 'source_type': :'String', 'time_created': :'DateTime', 'time_request_received': :'DateTime', 'type': :'String', 'unique_size_in_mbs': :'Integer', 'unique_size_in_gbs': :'Integer', 'volume_backup_ids': :'Array<String>', 'volume_group_id': :'String', 'source_volume_group_backup_id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 |
# File 'lib/oci/core/models/volume_group_backup.rb', line 374 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && == other. && display_name == other.display_name && expiration_time == other.expiration_time && == other. && id == other.id && lifecycle_state == other.lifecycle_state && size_in_mbs == other.size_in_mbs && size_in_gbs == other.size_in_gbs && source_type == other.source_type && time_created == other.time_created && time_request_received == other.time_request_received && type == other.type && unique_size_in_mbs == other.unique_size_in_mbs && unique_size_in_gbs == other.unique_size_in_gbs && volume_backup_ids == other.volume_backup_ids && volume_group_id == other.volume_group_id && source_volume_group_backup_id == other.source_volume_group_backup_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 |
# File 'lib/oci/core/models/volume_group_backup.rb', line 421 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
401 402 403 |
# File 'lib/oci/core/models/volume_group_backup.rb', line 401 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
410 411 412 |
# File 'lib/oci/core/models/volume_group_backup.rb', line 410 def hash [compartment_id, , display_name, expiration_time, , id, lifecycle_state, size_in_mbs, size_in_gbs, source_type, time_created, time_request_received, type, unique_size_in_mbs, unique_size_in_gbs, volume_backup_ids, volume_group_id, source_volume_group_backup_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
454 455 456 457 458 459 460 461 462 463 |
# File 'lib/oci/core/models/volume_group_backup.rb', line 454 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
448 449 450 |
# File 'lib/oci/core/models/volume_group_backup.rb', line 448 def to_s to_hash.to_s end |