Class: OCI::Core::Models::VolumeGroupReplica
- Inherits:
-
Object
- Object
- OCI::Core::Models::VolumeGroupReplica
- Defined in:
- lib/oci/core/models/volume_group_replica.rb
Overview
An asynchronous replica of a volume group that can then be used to create a new volume group or recover a volume group. For more information, see [Volume Group Replication](docs.cloud.oracle.com/iaas/Content/Block/Concepts/volumegroupreplication.htm).
To use any of the API operations, you must be authorized in an IAM policy. If you’re not authorized, talk to an administrator. If you’re an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/iaas/Content/Identity/Concepts/policygetstarted.htm).
Warning: Oracle recommends that you avoid using any confidential information when you supply string values using the API.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze, LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze, LIFECYCLE_STATE_ACTIVATING = 'ACTIVATING'.freeze, LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze, LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze, LIFECYCLE_STATE_FAULTY = 'FAULTY'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#availability_domain ⇒ String
[Required] The availability domain of the volume group replica.
-
#compartment_id ⇒ String
[Required] The OCID of the compartment that contains the volume group replica.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
[Required] A user-friendly name.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] The OCID for the volume group replica.
-
#lifecycle_state ⇒ String
[Required] The current state of a volume group.
-
#member_replicas ⇒ Array<OCI::Core::Models::MemberReplica>
[Required] Volume replicas within this volume group replica.
-
#size_in_gbs ⇒ Integer
[Required] The aggregate size of the volume group replica in GBs.
-
#time_created ⇒ DateTime
[Required] The date and time the volume group replica was created.
-
#time_last_synced ⇒ DateTime
[Required] The date and time the volume group replica was last synced from the source volume group.
-
#volume_group_id ⇒ String
[Required] The OCID of the source volume group.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VolumeGroupReplica
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ VolumeGroupReplica
Initializes the object
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 |
# File 'lib/oci/core/models/volume_group_replica.rb', line 148 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain'] raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain') self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.id = attributes[:'id'] if attributes[:'id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.size_in_gbs = attributes[:'sizeInGBs'] if attributes[:'sizeInGBs'] raise 'You cannot provide both :sizeInGBs and :size_in_gbs' if attributes.key?(:'sizeInGBs') && attributes.key?(:'size_in_gbs') self.size_in_gbs = attributes[:'size_in_gbs'] if attributes[:'size_in_gbs'] self.volume_group_id = attributes[:'volumeGroupId'] if attributes[:'volumeGroupId'] raise 'You cannot provide both :volumeGroupId and :volume_group_id' if attributes.key?(:'volumeGroupId') && attributes.key?(:'volume_group_id') self.volume_group_id = attributes[:'volume_group_id'] if attributes[:'volume_group_id'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.member_replicas = attributes[:'memberReplicas'] if attributes[:'memberReplicas'] raise 'You cannot provide both :memberReplicas and :member_replicas' if attributes.key?(:'memberReplicas') && attributes.key?(:'member_replicas') self.member_replicas = attributes[:'member_replicas'] if attributes[:'member_replicas'] self.time_last_synced = attributes[:'timeLastSynced'] if attributes[:'timeLastSynced'] raise 'You cannot provide both :timeLastSynced and :time_last_synced' if attributes.key?(:'timeLastSynced') && attributes.key?(:'time_last_synced') self.time_last_synced = attributes[:'time_last_synced'] if attributes[:'time_last_synced'] end |
Instance Attribute Details
#availability_domain ⇒ String
[Required] The availability domain of the volume group replica.
32 33 34 |
# File 'lib/oci/core/models/volume_group_replica.rb', line 32 def availability_domain @availability_domain end |
#compartment_id ⇒ String
[Required] The OCID of the compartment that contains the volume group replica.
36 37 38 |
# File 'lib/oci/core/models/volume_group_replica.rb', line 36 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
44 45 46 |
# File 'lib/oci/core/models/volume_group_replica.rb', line 44 def end |
#display_name ⇒ String
[Required] A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
50 51 52 |
# File 'lib/oci/core/models/volume_group_replica.rb', line 50 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
58 59 60 |
# File 'lib/oci/core/models/volume_group_replica.rb', line 58 def end |
#id ⇒ String
[Required] The OCID for the volume group replica.
62 63 64 |
# File 'lib/oci/core/models/volume_group_replica.rb', line 62 def id @id end |
#lifecycle_state ⇒ String
[Required] The current state of a volume group.
66 67 68 |
# File 'lib/oci/core/models/volume_group_replica.rb', line 66 def lifecycle_state @lifecycle_state end |
#member_replicas ⇒ Array<OCI::Core::Models::MemberReplica>
[Required] Volume replicas within this volume group replica.
82 83 84 |
# File 'lib/oci/core/models/volume_group_replica.rb', line 82 def member_replicas @member_replicas end |
#size_in_gbs ⇒ Integer
[Required] The aggregate size of the volume group replica in GBs.
70 71 72 |
# File 'lib/oci/core/models/volume_group_replica.rb', line 70 def size_in_gbs @size_in_gbs end |
#time_created ⇒ DateTime
[Required] The date and time the volume group replica was created. Format defined by [RFC3339](tools.ietf.org/html/rfc3339).
78 79 80 |
# File 'lib/oci/core/models/volume_group_replica.rb', line 78 def time_created @time_created end |
#time_last_synced ⇒ DateTime
[Required] The date and time the volume group replica was last synced from the source volume group. Format defined by [RFC3339](tools.ietf.org/html/rfc3339).
88 89 90 |
# File 'lib/oci/core/models/volume_group_replica.rb', line 88 def time_last_synced @time_last_synced end |
#volume_group_id ⇒ String
[Required] The OCID of the source volume group.
74 75 76 |
# File 'lib/oci/core/models/volume_group_replica.rb', line 74 def volume_group_id @volume_group_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/oci/core/models/volume_group_replica.rb', line 91 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'availability_domain': :'availabilityDomain', 'compartment_id': :'compartmentId', 'defined_tags': :'definedTags', 'display_name': :'displayName', 'freeform_tags': :'freeformTags', 'id': :'id', 'lifecycle_state': :'lifecycleState', 'size_in_gbs': :'sizeInGBs', 'volume_group_id': :'volumeGroupId', 'time_created': :'timeCreated', 'member_replicas': :'memberReplicas', 'time_last_synced': :'timeLastSynced' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/oci/core/models/volume_group_replica.rb', line 111 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'availability_domain': :'String', 'compartment_id': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'freeform_tags': :'Hash<String, String>', 'id': :'String', 'lifecycle_state': :'String', 'size_in_gbs': :'Integer', 'volume_group_id': :'String', 'time_created': :'DateTime', 'member_replicas': :'Array<OCI::Core::Models::MemberReplica>', 'time_last_synced': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/oci/core/models/volume_group_replica.rb', line 243 def ==(other) return true if equal?(other) self.class == other.class && availability_domain == other.availability_domain && compartment_id == other.compartment_id && == other. && display_name == other.display_name && == other. && id == other.id && lifecycle_state == other.lifecycle_state && size_in_gbs == other.size_in_gbs && volume_group_id == other.volume_group_id && time_created == other.time_created && member_replicas == other.member_replicas && time_last_synced == other.time_last_synced end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 |
# File 'lib/oci/core/models/volume_group_replica.rb', line 284 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
264 265 266 |
# File 'lib/oci/core/models/volume_group_replica.rb', line 264 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
273 274 275 |
# File 'lib/oci/core/models/volume_group_replica.rb', line 273 def hash [availability_domain, compartment_id, , display_name, , id, lifecycle_state, size_in_gbs, volume_group_id, time_created, member_replicas, time_last_synced].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
317 318 319 320 321 322 323 324 325 326 |
# File 'lib/oci/core/models/volume_group_replica.rb', line 317 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
311 312 313 |
# File 'lib/oci/core/models/volume_group_replica.rb', line 311 def to_s to_hash.to_s end |