Class: OCI::Core::Models::VolumeSourceFromBlockVolumeReplicaDetails

Inherits:
VolumeSourceDetails show all
Defined in:
lib/oci/core/models/volume_source_from_block_volume_replica_details.rb

Overview

Specifies the source block volume replica which the block volume will be created from. The block volume replica shoulbe be in the same availability domain as the block volume. Only one volume can be created from a replica at the same time.

Instance Attribute Summary collapse

Attributes inherited from VolumeSourceDetails

#type

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from VolumeSourceDetails

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ VolumeSourceFromBlockVolumeReplicaDetails

Initializes the object

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property



45
46
47
48
49
50
51
52
53
54
55
56
# File 'lib/oci/core/models/volume_source_from_block_volume_replica_details.rb', line 45

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['type'] = 'blockVolumeReplica'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']
end

Instance Attribute Details

#idString

[Required] The OCID of the block volume replica.



16
17
18
# File 'lib/oci/core/models/volume_source_from_block_volume_replica_details.rb', line 16

def id
  @id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



19
20
21
22
23
24
25
26
# File 'lib/oci/core/models/volume_source_from_block_volume_replica_details.rb', line 19

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'type': :'type',
    'id': :'id'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



29
30
31
32
33
34
35
36
# File 'lib/oci/core/models/volume_source_from_block_volume_replica_details.rb', line 29

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'type': :'String',
    'id': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.



65
66
67
68
69
70
71
# File 'lib/oci/core/models/volume_source_from_block_volume_replica_details.rb', line 65

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    type == other.type &&
    id == other.id
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/oci/core/models/volume_source_from_block_volume_replica_details.rb', line 96

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method


76
77
78
# File 'lib/oci/core/models/volume_source_from_block_volume_replica_details.rb', line 76

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.



85
86
87
# File 'lib/oci/core/models/volume_source_from_block_volume_replica_details.rb', line 85

def hash
  [type, id].hash
end

#to_hashHash

Returns the object in the form of hash



129
130
131
132
133
134
135
136
137
138
# File 'lib/oci/core/models/volume_source_from_block_volume_replica_details.rb', line 129

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



123
124
125
# File 'lib/oci/core/models/volume_source_from_block_volume_replica_details.rb', line 123

def to_s
  to_hash.to_s
end