Class: OCI::DashboardService::DashboardGroupClient
- Inherits:
-
Object
- Object
- OCI::DashboardService::DashboardGroupClient
- Defined in:
- lib/oci/dashboard_service/dashboard_group_client.rb
Overview
Use the Oracle Cloud Infrastructure Dashboards service API to manage dashboards in the Console. Dashboards provide an organized and customizable view of resources and their metrics in the Console. For more information, see [Dashboards](/Content/Dashboards/home.htm).
*Important:* Resources for the Dashboards service are created in the tenacy's home region. Although it is possible to create dashboard and dashboard group resources in regions other than the home region, you won't be able to view those resources in the Console. Therefore, creating resources outside of the home region is not recommended.
Instance Attribute Summary collapse
-
#api_client ⇒ OCI::ApiClient
readonly
Client used to make HTTP requests.
-
#endpoint ⇒ String
readonly
Fully qualified endpoint URL.
-
#region ⇒ String
The region, which will usually correspond to a value in Regions::REGION_ENUM.
-
#retry_config ⇒ OCI::Retry::RetryConfig
readonly
The default retry configuration to apply to all operations in this service client.
Instance Method Summary collapse
-
#create_dashboard_group(create_dashboard_group_details, opts = {}) ⇒ Response
Creates a new dashboard group using the details provided in request body.
-
#delete_dashboard_group(dashboard_group_id, opts = {}) ⇒ Response
Deletes the specified dashboard group.
-
#get_dashboard_group(dashboard_group_id, opts = {}) ⇒ Response
Gets the specified dashboard group's information.
-
#initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) ⇒ DashboardGroupClient
constructor
Creates a new DashboardGroupClient.
-
#list_dashboard_groups(compartment_id, opts = {}) ⇒ Response
Returns a list of dashboard groups with a specific compartment ID.
-
#logger ⇒ Logger
The logger for this client.
-
#update_dashboard_group(dashboard_group_id, update_dashboard_group_details, opts = {}) ⇒ Response
Updates the specified dashboard group.
Constructor Details
#initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) ⇒ DashboardGroupClient
Creates a new DashboardGroupClient. Notes:
If a config is not specified, then the global OCI.config will be used.
This client is not thread-safe
Either a region or an endpoint must be specified. If an endpoint is specified, it will be used instead of the
region. A region may be specified in the config or via or the region parameter. If specified in both, then the
region parameter will be used.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/oci/dashboard_service/dashboard_group_client.rb', line 60 def initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) # If the signer is an InstancePrincipalsSecurityTokenSigner or SecurityTokenSigner and no config was supplied (they are self-sufficient signers) # then create a dummy config to pass to the ApiClient constructor. If customers wish to create a client which uses instance principals # and has config (either populated programmatically or loaded from a file), they must construct that config themselves and then # pass it to this constructor. # # If there is no signer (or the signer is not an instance principals signer) and no config was supplied, this is not valid # so try and load the config from the default file. config = OCI::Config.validate_and_build_config_with_signer(config, signer) signer = OCI::Signer.config_file_auth_builder(config) if signer.nil? @api_client = OCI::ApiClient.new(config, signer, proxy_settings: proxy_settings) @retry_config = retry_config if endpoint @endpoint = endpoint + '/20210731' else region ||= config.region region ||= signer.region if signer.respond_to?(:region) self.region = region end logger.info "DashboardGroupClient endpoint set to '#{@endpoint}'." if logger end |
Instance Attribute Details
#api_client ⇒ OCI::ApiClient (readonly)
Client used to make HTTP requests.
20 21 22 |
# File 'lib/oci/dashboard_service/dashboard_group_client.rb', line 20 def api_client @api_client end |
#endpoint ⇒ String (readonly)
Fully qualified endpoint URL
24 25 26 |
# File 'lib/oci/dashboard_service/dashboard_group_client.rb', line 24 def endpoint @endpoint end |
#region ⇒ String
The region, which will usually correspond to a value in Regions::REGION_ENUM.
34 35 36 |
# File 'lib/oci/dashboard_service/dashboard_group_client.rb', line 34 def region @region end |
#retry_config ⇒ OCI::Retry::RetryConfig (readonly)
The default retry configuration to apply to all operations in this service client. This can be overridden on a per-operation basis. The default retry configuration value is `nil`, which means that an operation will not perform any retries
30 31 32 |
# File 'lib/oci/dashboard_service/dashboard_group_client.rb', line 30 def retry_config @retry_config end |
Instance Method Details
#create_dashboard_group(create_dashboard_group_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/dashboardservice/create_dashboard_group.rb.html) to see an example of how to use create_dashboard_group API.
Creates a new dashboard group using the details provided in request body.
*Caution:* Resources for the Dashboard service are created in the tenacy's home region. Although it is possible to create dashboard group resource in regions other than the home region, you won't be able to view those resources in the Console. Therefore, creating resources outside of the home region is not recommended.
134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/oci/dashboard_service/dashboard_group_client.rb', line 134 def create_dashboard_group(create_dashboard_group_details, opts = {}) logger.debug 'Calling operation DashboardGroupClient#create_dashboard_group.' if logger raise "Missing the required parameter 'create_dashboard_group_details' when calling create_dashboard_group." if create_dashboard_group_details.nil? path = '/dashboardGroups' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'opc-cross-region'] = opts[:opc_cross_region] if opts[:opc_cross_region] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = @api_client.object_to_http_body(create_dashboard_group_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DashboardGroupClient#create_dashboard_group') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::DashboardService::Models::DashboardGroup' ) end # rubocop:enable Metrics/BlockLength end |
#delete_dashboard_group(dashboard_group_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/dashboardservice/delete_dashboard_group.rb.html) to see an example of how to use delete_dashboard_group API.
Deletes the specified dashboard group. Uses the dashboard group's OCID to determine which dashboard group to delete.
202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/oci/dashboard_service/dashboard_group_client.rb', line 202 def delete_dashboard_group(dashboard_group_id, opts = {}) logger.debug 'Calling operation DashboardGroupClient#delete_dashboard_group.' if logger raise "Missing the required parameter 'dashboard_group_id' when calling delete_dashboard_group." if dashboard_group_id.nil? raise "Parameter value for 'dashboard_group_id' must not be blank" if OCI::Internal::Util.blank_string?(dashboard_group_id) path = '/dashboardGroups/{dashboardGroupId}'.sub('{dashboardGroupId}', dashboard_group_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'opc-cross-region'] = opts[:opc_cross_region] if opts[:opc_cross_region] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DashboardGroupClient#delete_dashboard_group') do @api_client.call_api( :DELETE, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#get_dashboard_group(dashboard_group_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/dashboardservice/get_dashboard_group.rb.html) to see an example of how to use get_dashboard_group API.
Gets the specified dashboard group's information. Uses the dashboard group's OCID to determine which dashboard to retrieve.
263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/oci/dashboard_service/dashboard_group_client.rb', line 263 def get_dashboard_group(dashboard_group_id, opts = {}) logger.debug 'Calling operation DashboardGroupClient#get_dashboard_group.' if logger raise "Missing the required parameter 'dashboard_group_id' when calling get_dashboard_group." if dashboard_group_id.nil? raise "Parameter value for 'dashboard_group_id' must not be blank" if OCI::Internal::Util.blank_string?(dashboard_group_id) path = '/dashboardGroups/{dashboardGroupId}'.sub('{dashboardGroupId}', dashboard_group_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'opc-cross-region'] = opts[:opc_cross_region] if opts[:opc_cross_region] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DashboardGroupClient#get_dashboard_group') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::DashboardService::Models::DashboardGroup' ) end # rubocop:enable Metrics/BlockLength end |
#list_dashboard_groups(compartment_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/dashboardservice/list_dashboard_groups.rb.html) to see an example of how to use list_dashboard_groups API.
Returns a list of dashboard groups with a specific compartment ID.
337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 |
# File 'lib/oci/dashboard_service/dashboard_group_client.rb', line 337 def list_dashboard_groups(compartment_id, opts = {}) logger.debug 'Calling operation DashboardGroupClient#list_dashboard_groups.' if logger raise "Missing the required parameter 'compartment_id' when calling list_dashboard_groups." if compartment_id.nil? if opts[:lifecycle_state] && !OCI::DashboardService::Models::DashboardGroup::LIFECYCLE_STATE_ENUM.include?(opts[:lifecycle_state]) raise 'Invalid value for "lifecycle_state", must be one of the values in OCI::DashboardService::Models::DashboardGroup::LIFECYCLE_STATE_ENUM.' end if opts[:sort_order] && !OCI::DashboardService::Models::SORT_ORDER_ENUM.include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of the values in OCI::DashboardService::Models::SORT_ORDER_ENUM.' end if opts[:sort_by] && !%w[timeCreated displayName].include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of timeCreated, displayName.' end path = '/dashboardGroups' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:compartmentId] = compartment_id query_params[:lifecycleState] = opts[:lifecycle_state] if opts[:lifecycle_state] query_params[:displayName] = opts[:display_name] if opts[:display_name] query_params[:id] = opts[:id] if opts[:id] query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'opc-cross-region'] = opts[:opc_cross_region] if opts[:opc_cross_region] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DashboardGroupClient#list_dashboard_groups') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::DashboardService::Models::DashboardGroupCollection' ) end # rubocop:enable Metrics/BlockLength end |
#logger ⇒ Logger
Returns The logger for this client. May be nil.
99 100 101 |
# File 'lib/oci/dashboard_service/dashboard_group_client.rb', line 99 def logger @api_client.config.logger end |
#update_dashboard_group(dashboard_group_id, update_dashboard_group_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/dashboardservice/update_dashboard_group.rb.html) to see an example of how to use update_dashboard_group API.
Updates the specified dashboard group. Uses the dashboard group's OCID to determine which dashboard group to update.
424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/oci/dashboard_service/dashboard_group_client.rb', line 424 def update_dashboard_group(dashboard_group_id, update_dashboard_group_details, opts = {}) logger.debug 'Calling operation DashboardGroupClient#update_dashboard_group.' if logger raise "Missing the required parameter 'dashboard_group_id' when calling update_dashboard_group." if dashboard_group_id.nil? raise "Missing the required parameter 'update_dashboard_group_details' when calling update_dashboard_group." if update_dashboard_group_details.nil? raise "Parameter value for 'dashboard_group_id' must not be blank" if OCI::Internal::Util.blank_string?(dashboard_group_id) path = '/dashboardGroups/{dashboardGroupId}'.sub('{dashboardGroupId}', dashboard_group_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'opc-cross-region'] = opts[:opc_cross_region] if opts[:opc_cross_region] # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(update_dashboard_group_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DashboardGroupClient#update_dashboard_group') do @api_client.call_api( :PUT, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::DashboardService::Models::DashboardGroup' ) end # rubocop:enable Metrics/BlockLength end |