Class: OCI::DashboardService::Models::CreateV1DashboardDetails

Inherits:
CreateDashboardDetails show all
Defined in:
lib/oci/dashboard_service/models/create_v1_dashboard_details.rb

Overview

Details for creating a version 1 dashboard. The interpretation of the `config` and `widgets` fields depends on the runtime behavior of the Oracle Cloud Infrastructure Console. The sum of the `config` and `widget` fields JSON text representation cannot exceed 200 KB.

Instance Attribute Summary collapse

Attributes inherited from CreateDashboardDetails

#dashboard_group_id, #defined_tags, #description, #display_name, #freeform_tags, #schema_version

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from CreateDashboardDetails

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ CreateV1DashboardDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :dashboard_group_id (String)

    The value to assign to the #dashboard_group_id proprety

  • :display_name (String)

    The value to assign to the #display_name proprety

  • :description (String)

    The value to assign to the #description proprety

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags proprety

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags proprety

  • :config (Object)

    The value to assign to the #config property

  • :widgets (Array<Object>)

    The value to assign to the #widgets property



67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/oci/dashboard_service/models/create_v1_dashboard_details.rb', line 67

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['schemaVersion'] = 'V1'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.config = attributes[:'config'] if attributes[:'config']

  self.widgets = attributes[:'widgets'] if attributes[:'widgets']
end

Instance Attribute Details

#configObject

The layout and widget placement for the dashboard.

Returns:

  • (Object)


16
17
18
# File 'lib/oci/dashboard_service/models/create_v1_dashboard_details.rb', line 16

def config
  @config
end

#widgetsArray<Object>

**[Required]** The basic visualization building blocks of a dashboard.

Returns:

  • (Array<Object>)


20
21
22
# File 'lib/oci/dashboard_service/models/create_v1_dashboard_details.rb', line 20

def widgets
  @widgets
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



23
24
25
26
27
28
29
30
31
32
33
34
35
36
# File 'lib/oci/dashboard_service/models/create_v1_dashboard_details.rb', line 23

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'dashboard_group_id': :'dashboardGroupId',
    'display_name': :'displayName',
    'description': :'description',
    'schema_version': :'schemaVersion',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'config': :'config',
    'widgets': :'widgets'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



39
40
41
42
43
44
45
46
47
48
49
50
51
52
# File 'lib/oci/dashboard_service/models/create_v1_dashboard_details.rb', line 39

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'dashboard_group_id': :'String',
    'display_name': :'String',
    'description': :'String',
    'schema_version': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'config': :'Object',
    'widgets': :'Array<Object>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/oci/dashboard_service/models/create_v1_dashboard_details.rb', line 89

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    dashboard_group_id == other.dashboard_group_id &&
    display_name == other.display_name &&
    description == other.description &&
    schema_version == other.schema_version &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    config == other.config &&
    widgets == other.widgets
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'lib/oci/dashboard_service/models/create_v1_dashboard_details.rb', line 126

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


106
107
108
# File 'lib/oci/dashboard_service/models/create_v1_dashboard_details.rb', line 106

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



115
116
117
# File 'lib/oci/dashboard_service/models/create_v1_dashboard_details.rb', line 115

def hash
  [dashboard_group_id, display_name, description, schema_version, freeform_tags, defined_tags, config, widgets].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



159
160
161
162
163
164
165
166
167
168
# File 'lib/oci/dashboard_service/models/create_v1_dashboard_details.rb', line 159

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



153
154
155
# File 'lib/oci/dashboard_service/models/create_v1_dashboard_details.rb', line 153

def to_s
  to_hash.to_s
end