Class: DashboardService::Models::Dashboard
- Inherits:
-
Object
- Object
- DashboardService::Models::Dashboard
- Defined in:
- lib/oci/dashboard_service/models/dashboard.rb
Overview
The base schema for a dashboard. Derived schemas have configurations and widgets specific to the `schemaVersion`.
This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
Constant Summary collapse
- SCHEMA_VERSION_ENUM =
[ SCHEMA_VERSION_V1 = 'V1'.freeze, SCHEMA_VERSION_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the dashboard.
-
#dashboard_group_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the dashboard group that the dashboard belongs to.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
**[Required]** Defined tags for this resource.
-
#description ⇒ String
**[Required]** A short description of the dashboard.
-
#display_name ⇒ String
**[Required]** A user-friendly name for the dashboard.
-
#freeform_tags ⇒ Hash<String, String>
**[Required]** Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the dashboard resource.
-
#lifecycle_state ⇒ String
**[Required]** The current state of the dashboard.
-
#schema_version ⇒ String
**[Required]** The schema describing how to interpret the dashboard configuration and widgets.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys.
-
#time_created ⇒ DateTime
**[Required]** The date and time the dashboard was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#time_updated ⇒ DateTime
**[Required]** The date and time the dashboard was updated, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Dashboard
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Dashboard
Initializes the object
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/oci/dashboard_service/models/dashboard.rb', line 167 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.dashboard_group_id = attributes[:'dashboardGroupId'] if attributes[:'dashboardGroupId'] raise 'You cannot provide both :dashboardGroupId and :dashboard_group_id' if attributes.key?(:'dashboardGroupId') && attributes.key?(:'dashboard_group_id') self.dashboard_group_id = attributes[:'dashboard_group_id'] if attributes[:'dashboard_group_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.schema_version = attributes[:'schemaVersion'] if attributes[:'schemaVersion'] raise 'You cannot provide both :schemaVersion and :schema_version' if attributes.key?(:'schemaVersion') && attributes.key?(:'schema_version') self.schema_version = attributes[:'schema_version'] if attributes[:'schema_version'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the dashboard. A dashboard is always in the same compartment as its dashboard group.
51 52 53 |
# File 'lib/oci/dashboard_service/models/dashboard.rb', line 51 def compartment_id @compartment_id end |
#dashboard_group_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the dashboard group that the dashboard belongs to.
35 36 37 |
# File 'lib/oci/dashboard_service/models/dashboard.rb', line 35 def dashboard_group_id @dashboard_group_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
**[Required]** Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
86 87 88 |
# File 'lib/oci/dashboard_service/models/dashboard.rb', line 86 def @defined_tags end |
#description ⇒ String
**[Required]** A short description of the dashboard. It can be changed. Avoid entering confidential information. The following special characters are not allowed: <>()=/'"&\
47 48 49 |
# File 'lib/oci/dashboard_service/models/dashboard.rb', line 47 def description @description end |
#display_name ⇒ String
**[Required]** A user-friendly name for the dashboard. Does not have to be unique, and it can be changed. Avoid entering confidential information. Leading and trailing spaces and the following special characters are not allowed: <>()=/'"&\
41 42 43 |
# File 'lib/oci/dashboard_service/models/dashboard.rb', line 41 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
**[Required]** Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
80 81 82 |
# File 'lib/oci/dashboard_service/models/dashboard.rb', line 80 def @freeform_tags end |
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the dashboard resource.
31 32 33 |
# File 'lib/oci/dashboard_service/models/dashboard.rb', line 31 def id @id end |
#lifecycle_state ⇒ String
**[Required]** The current state of the dashboard.
74 75 76 |
# File 'lib/oci/dashboard_service/models/dashboard.rb', line 74 def lifecycle_state @lifecycle_state end |
#schema_version ⇒ String
**[Required]** The schema describing how to interpret the dashboard configuration and widgets.
56 57 58 |
# File 'lib/oci/dashboard_service/models/dashboard.rb', line 56 def schema_version @schema_version end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"free-tier-retained": "true"}`
92 93 94 |
# File 'lib/oci/dashboard_service/models/dashboard.rb', line 92 def @system_tags end |
#time_created ⇒ DateTime
**[Required]** The date and time the dashboard was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Example: `2016-08-25T21:10:29.600Z`
63 64 65 |
# File 'lib/oci/dashboard_service/models/dashboard.rb', line 63 def time_created @time_created end |
#time_updated ⇒ DateTime
**[Required]** The date and time the dashboard was updated, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Example: `2016-08-25T21:10:29.600Z`
70 71 72 |
# File 'lib/oci/dashboard_service/models/dashboard.rb', line 70 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/oci/dashboard_service/models/dashboard.rb', line 95 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'dashboard_group_id': :'dashboardGroupId', 'display_name': :'displayName', 'description': :'description', 'compartment_id': :'compartmentId', 'schema_version': :'schemaVersion', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
139 140 141 142 143 144 145 146 |
# File 'lib/oci/dashboard_service/models/dashboard.rb', line 139 def self.get_subtype(object_hash) type = object_hash[:'schemaVersion'] # rubocop:disable Style/SymbolLiteral return 'OCI::DashboardService::Models::V1Dashboard' if type == 'V1' # TODO: Log a warning when the subtype is not found. 'OCI::DashboardService::Models::Dashboard' end |
.swagger_types ⇒ Object
Attribute type mapping.
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/oci/dashboard_service/models/dashboard.rb', line 115 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'dashboard_group_id': :'String', 'display_name': :'String', 'description': :'String', 'compartment_id': :'String', 'schema_version': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 |
# File 'lib/oci/dashboard_service/models/dashboard.rb', line 271 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && dashboard_group_id == other.dashboard_group_id && display_name == other.display_name && description == other.description && compartment_id == other.compartment_id && schema_version == other.schema_version && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'lib/oci/dashboard_service/models/dashboard.rb', line 312 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
292 293 294 |
# File 'lib/oci/dashboard_service/models/dashboard.rb', line 292 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
301 302 303 |
# File 'lib/oci/dashboard_service/models/dashboard.rb', line 301 def hash [id, dashboard_group_id, display_name, description, compartment_id, schema_version, time_created, time_updated, lifecycle_state, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
345 346 347 348 349 350 351 352 353 354 |
# File 'lib/oci/dashboard_service/models/dashboard.rb', line 345 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
339 340 341 |
# File 'lib/oci/dashboard_service/models/dashboard.rb', line 339 def to_s to_hash.to_s end |