Class: OCI::DashboardService::Models::UpdateDashboardDetails
- Inherits:
-
Object
- Object
- OCI::DashboardService::Models::UpdateDashboardDetails
- Defined in:
- lib/oci/dashboard_service/models/update_dashboard_details.rb
Overview
The base schema for updating a dashboard. Derived schemas have configurations and widgets specific to the `schemaVersion`.
This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
Instance Attribute Summary collapse
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
A short description of the dashboard.
-
#display_name ⇒ String
A user-friendly name for the dashboard.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#schema_version ⇒ String
**[Required]** The schema describing how to interpret the dashboard configuration and widgets.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateDashboardDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateDashboardDetails
Initializes the object
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/oci/dashboard_service/models/update_dashboard_details.rb', line 94 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.schema_version = attributes[:'schemaVersion'] if attributes[:'schemaVersion'] raise 'You cannot provide both :schemaVersion and :schema_version' if attributes.key?(:'schemaVersion') && attributes.key?(:'schema_version') self.schema_version = attributes[:'schema_version'] if attributes[:'schema_version'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
40 41 42 |
# File 'lib/oci/dashboard_service/models/update_dashboard_details.rb', line 40 def @defined_tags end |
#description ⇒ String
A short description of the dashboard. It can be changed. Avoid entering confidential information. The following special characters are not allowed: <>()=/'"&\
23 24 25 |
# File 'lib/oci/dashboard_service/models/update_dashboard_details.rb', line 23 def description @description end |
#display_name ⇒ String
A user-friendly name for the dashboard. Does not have to be unique, and it can be changed. Avoid entering confidential information. Leading and trailing spaces and the following special characters are not allowed: <>()=/'"&\
17 18 19 |
# File 'lib/oci/dashboard_service/models/update_dashboard_details.rb', line 17 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
34 35 36 |
# File 'lib/oci/dashboard_service/models/update_dashboard_details.rb', line 34 def @freeform_tags end |
#schema_version ⇒ String
**[Required]** The schema describing how to interpret the dashboard configuration and widgets.
28 29 30 |
# File 'lib/oci/dashboard_service/models/update_dashboard_details.rb', line 28 def schema_version @schema_version end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/oci/dashboard_service/models/update_dashboard_details.rb', line 43 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'description': :'description', 'schema_version': :'schemaVersion', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
73 74 75 76 77 78 79 80 |
# File 'lib/oci/dashboard_service/models/update_dashboard_details.rb', line 73 def self.get_subtype(object_hash) type = object_hash[:'schemaVersion'] # rubocop:disable Style/SymbolLiteral return 'OCI::DashboardService::Models::UpdateV1DashboardDetails' if type == 'V1' # TODO: Log a warning when the subtype is not found. 'OCI::DashboardService::Models::UpdateDashboardDetails' end |
.swagger_types ⇒ Object
Attribute type mapping.
56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/oci/dashboard_service/models/update_dashboard_details.rb', line 56 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'description': :'String', 'schema_version': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
134 135 136 137 138 139 140 141 142 143 |
# File 'lib/oci/dashboard_service/models/update_dashboard_details.rb', line 134 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && description == other.description && schema_version == other.schema_version && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/oci/dashboard_service/models/update_dashboard_details.rb', line 168 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
148 149 150 |
# File 'lib/oci/dashboard_service/models/update_dashboard_details.rb', line 148 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
157 158 159 |
# File 'lib/oci/dashboard_service/models/update_dashboard_details.rb', line 157 def hash [display_name, description, schema_version, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
201 202 203 204 205 206 207 208 209 210 |
# File 'lib/oci/dashboard_service/models/update_dashboard_details.rb', line 201 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
195 196 197 |
# File 'lib/oci/dashboard_service/models/update_dashboard_details.rb', line 195 def to_s to_hash.to_s end |