Class: OCI::DataCatalog::Models::Catalog
- Inherits:
-
Object
- Object
- OCI::DataCatalog::Models::Catalog
- Defined in:
- lib/oci/data_catalog/models/catalog.rb
Overview
A data catalog enables you to collect, organize, find, access, understand, enrich, and activate technical, business, and operational metadata.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_MOVING = 'MOVING'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#attached_catalog_private_endpoints ⇒ Array<String>
The list of private reverse connection endpoints attached to the catalog.
-
#compartment_id ⇒ String
**[Required]** Compartment identifier.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Usage of predefined tag keys.
-
#display_name ⇒ String
Data catalog identifier, which can be renamed.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type, or scope.
-
#id ⇒ String
**[Required]** OCID of the data catalog instance.
-
#lifecycle_details ⇒ String
An message describing the current state in more detail.
-
#lifecycle_state ⇒ String
The current state of the data catalog resource.
-
#number_of_objects ⇒ Integer
The number of data objects added to the data catalog.
-
#service_api_url ⇒ String
The REST front endpoint URL to the data catalog instance.
-
#service_console_url ⇒ String
The console front endpoint URL to the data catalog instance.
-
#time_created ⇒ DateTime
The time the data catalog was created.
-
#time_updated ⇒ DateTime
The time the data catalog was updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Catalog
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Catalog
Initializes the object
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/oci/data_catalog/models/catalog.rb', line 144 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.service_api_url = attributes[:'serviceApiUrl'] if attributes[:'serviceApiUrl'] raise 'You cannot provide both :serviceApiUrl and :service_api_url' if attributes.key?(:'serviceApiUrl') && attributes.key?(:'service_api_url') self.service_api_url = attributes[:'service_api_url'] if attributes[:'service_api_url'] self.service_console_url = attributes[:'serviceConsoleUrl'] if attributes[:'serviceConsoleUrl'] raise 'You cannot provide both :serviceConsoleUrl and :service_console_url' if attributes.key?(:'serviceConsoleUrl') && attributes.key?(:'service_console_url') self.service_console_url = attributes[:'service_console_url'] if attributes[:'service_console_url'] self.number_of_objects = attributes[:'numberOfObjects'] if attributes[:'numberOfObjects'] raise 'You cannot provide both :numberOfObjects and :number_of_objects' if attributes.key?(:'numberOfObjects') && attributes.key?(:'number_of_objects') self.number_of_objects = attributes[:'number_of_objects'] if attributes[:'number_of_objects'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.attached_catalog_private_endpoints = attributes[:'attachedCatalogPrivateEndpoints'] if attributes[:'attachedCatalogPrivateEndpoints'] raise 'You cannot provide both :attachedCatalogPrivateEndpoints and :attached_catalog_private_endpoints' if attributes.key?(:'attachedCatalogPrivateEndpoints') && attributes.key?(:'attached_catalog_private_endpoints') self.attached_catalog_private_endpoints = attributes[:'attached_catalog_private_endpoints'] if attributes[:'attached_catalog_private_endpoints'] end |
Instance Attribute Details
#attached_catalog_private_endpoints ⇒ Array<String>
The list of private reverse connection endpoints attached to the catalog
81 82 83 |
# File 'lib/oci/data_catalog/models/catalog.rb', line 81 def attached_catalog_private_endpoints @attached_catalog_private_endpoints end |
#compartment_id ⇒ String
**[Required]** Compartment identifier.
33 34 35 |
# File 'lib/oci/data_catalog/models/catalog.rb', line 33 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Usage of predefined tag keys. These predefined keys are scoped to namespaces. Example: `{"bar-key": "value"}`
77 78 79 |
# File 'lib/oci/data_catalog/models/catalog.rb', line 77 def @defined_tags end |
#display_name ⇒ String
Data catalog identifier, which can be renamed.
29 30 31 |
# File 'lib/oci/data_catalog/models/catalog.rb', line 29 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type, or scope. Exists for cross-compatibility only. Example: `"value"`
71 72 73 |
# File 'lib/oci/data_catalog/models/catalog.rb', line 71 def @freeform_tags end |
#id ⇒ String
**[Required]** OCID of the data catalog instance.
25 26 27 |
# File 'lib/oci/data_catalog/models/catalog.rb', line 25 def id @id end |
#lifecycle_details ⇒ String
An message describing the current state in more detail. For example, it can be used to provide actionable information for a resource in 'Failed' state.
65 66 67 |
# File 'lib/oci/data_catalog/models/catalog.rb', line 65 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
The current state of the data catalog resource.
59 60 61 |
# File 'lib/oci/data_catalog/models/catalog.rb', line 59 def lifecycle_state @lifecycle_state end |
#number_of_objects ⇒ Integer
The number of data objects added to the data catalog. Please see the data catalog documentation for further information on how this is calculated.
55 56 57 |
# File 'lib/oci/data_catalog/models/catalog.rb', line 55 def number_of_objects @number_of_objects end |
#service_api_url ⇒ String
The REST front endpoint URL to the data catalog instance.
45 46 47 |
# File 'lib/oci/data_catalog/models/catalog.rb', line 45 def service_api_url @service_api_url end |
#service_console_url ⇒ String
The console front endpoint URL to the data catalog instance.
49 50 51 |
# File 'lib/oci/data_catalog/models/catalog.rb', line 49 def service_console_url @service_console_url end |
#time_created ⇒ DateTime
The time the data catalog was created. An [RFC3339](tools.ietf.org/html/rfc3339) formatted datetime string.
37 38 39 |
# File 'lib/oci/data_catalog/models/catalog.rb', line 37 def time_created @time_created end |
#time_updated ⇒ DateTime
The time the data catalog was updated. An [RFC3339](tools.ietf.org/html/rfc3339) formatted datetime string.
41 42 43 |
# File 'lib/oci/data_catalog/models/catalog.rb', line 41 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/oci/data_catalog/models/catalog.rb', line 84 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'service_api_url': :'serviceApiUrl', 'service_console_url': :'serviceConsoleUrl', 'number_of_objects': :'numberOfObjects', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'attached_catalog_private_endpoints': :'attachedCatalogPrivateEndpoints' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/oci/data_catalog/models/catalog.rb', line 105 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'compartment_id': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'service_api_url': :'String', 'service_console_url': :'String', 'number_of_objects': :'Integer', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'attached_catalog_private_endpoints': :'Array<String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 |
# File 'lib/oci/data_catalog/models/catalog.rb', line 245 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && compartment_id == other.compartment_id && time_created == other.time_created && time_updated == other.time_updated && service_api_url == other.service_api_url && service_console_url == other.service_console_url && number_of_objects == other.number_of_objects && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && == other. && == other. && attached_catalog_private_endpoints == other.attached_catalog_private_endpoints end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 |
# File 'lib/oci/data_catalog/models/catalog.rb', line 287 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
267 268 269 |
# File 'lib/oci/data_catalog/models/catalog.rb', line 267 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
276 277 278 |
# File 'lib/oci/data_catalog/models/catalog.rb', line 276 def hash [id, display_name, compartment_id, time_created, time_updated, service_api_url, service_console_url, number_of_objects, lifecycle_state, lifecycle_details, , , attached_catalog_private_endpoints].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
320 321 322 323 324 325 326 327 328 329 |
# File 'lib/oci/data_catalog/models/catalog.rb', line 320 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
314 315 316 |
# File 'lib/oci/data_catalog/models/catalog.rb', line 314 def to_s to_hash.to_s end |