Class: OCI::DataCatalog::Models::ConnectionSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_catalog/models/connection_summary.rb

Overview

Summary representation of a connection to a data asset.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_MOVING = 'MOVING'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ConnectionSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :key (String)

    The value to assign to the #key property

  • :description (String)

    The value to assign to the #description property

  • :display_name (String)

    The value to assign to the #display_name property

  • :data_asset_key (String)

    The value to assign to the #data_asset_key property

  • :type_key (String)

    The value to assign to the #type_key property

  • :uri (String)

    The value to assign to the #uri property

  • :external_key (String)

    The value to assign to the #external_key property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :is_default (BOOLEAN)

    The value to assign to the #is_default property

  • :time_created (DateTime)

    The value to assign to the #time_created property



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/oci/data_catalog/models/connection_summary.rb', line 119

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.key = attributes[:'key'] if attributes[:'key']

  self.description = attributes[:'description'] if attributes[:'description']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.data_asset_key = attributes[:'dataAssetKey'] if attributes[:'dataAssetKey']

  raise 'You cannot provide both :dataAssetKey and :data_asset_key' if attributes.key?(:'dataAssetKey') && attributes.key?(:'data_asset_key')

  self.data_asset_key = attributes[:'data_asset_key'] if attributes[:'data_asset_key']

  self.type_key = attributes[:'typeKey'] if attributes[:'typeKey']

  raise 'You cannot provide both :typeKey and :type_key' if attributes.key?(:'typeKey') && attributes.key?(:'type_key')

  self.type_key = attributes[:'type_key'] if attributes[:'type_key']

  self.uri = attributes[:'uri'] if attributes[:'uri']

  self.external_key = attributes[:'externalKey'] if attributes[:'externalKey']

  raise 'You cannot provide both :externalKey and :external_key' if attributes.key?(:'externalKey') && attributes.key?(:'external_key')

  self.external_key = attributes[:'external_key'] if attributes[:'external_key']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.is_default = attributes[:'isDefault'] unless attributes[:'isDefault'].nil?

  raise 'You cannot provide both :isDefault and :is_default' if attributes.key?(:'isDefault') && attributes.key?(:'is_default')

  self.is_default = attributes[:'is_default'] unless attributes[:'is_default'].nil?

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']
end

Instance Attribute Details

#data_asset_keyString

The unique key of the parent data asset.

Returns:

  • (String)


39
40
41
# File 'lib/oci/data_catalog/models/connection_summary.rb', line 39

def data_asset_key
  @data_asset_key
end

#descriptionString

A description of the connection.

Returns:

  • (String)


29
30
31
# File 'lib/oci/data_catalog/models/connection_summary.rb', line 29

def description
  @description
end

#display_nameString

A user-friendly display name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.

Returns:

  • (String)


35
36
37
# File 'lib/oci/data_catalog/models/connection_summary.rb', line 35

def display_name
  @display_name
end

#external_keyString

Unique external key for this object as defined in the source systems.

Returns:

  • (String)


51
52
53
# File 'lib/oci/data_catalog/models/connection_summary.rb', line 51

def external_key
  @external_key
end

#is_defaultBOOLEAN

Indicates whether this connection is the default connection.

Returns:

  • (BOOLEAN)


59
60
61
# File 'lib/oci/data_catalog/models/connection_summary.rb', line 59

def is_default
  @is_default
end

#keyString

[Required] Unique connection key that is immutable.

Returns:

  • (String)


25
26
27
# File 'lib/oci/data_catalog/models/connection_summary.rb', line 25

def key
  @key
end

#lifecycle_stateString

The current state of the connection.

Returns:

  • (String)


55
56
57
# File 'lib/oci/data_catalog/models/connection_summary.rb', line 55

def lifecycle_state
  @lifecycle_state
end

#time_createdDateTime

The date and time the connection was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339). Example: 2019-03-25T21:10:29.600Z

Returns:

  • (DateTime)


65
66
67
# File 'lib/oci/data_catalog/models/connection_summary.rb', line 65

def time_created
  @time_created
end

#type_keyString

The key of the object type. Type key’s can be found via the ‘/types’ endpoint.

Returns:

  • (String)


43
44
45
# File 'lib/oci/data_catalog/models/connection_summary.rb', line 43

def type_key
  @type_key
end

#uriString

URI to the connection instance in the API.

Returns:

  • (String)


47
48
49
# File 'lib/oci/data_catalog/models/connection_summary.rb', line 47

def uri
  @uri
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/oci/data_catalog/models/connection_summary.rb', line 68

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'key',
    'description': :'description',
    'display_name': :'displayName',
    'data_asset_key': :'dataAssetKey',
    'type_key': :'typeKey',
    'uri': :'uri',
    'external_key': :'externalKey',
    'lifecycle_state': :'lifecycleState',
    'is_default': :'isDefault',
    'time_created': :'timeCreated'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/oci/data_catalog/models/connection_summary.rb', line 86

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'String',
    'description': :'String',
    'display_name': :'String',
    'data_asset_key': :'String',
    'type_key': :'String',
    'uri': :'String',
    'external_key': :'String',
    'lifecycle_state': :'String',
    'is_default': :'BOOLEAN',
    'time_created': :'DateTime'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/oci/data_catalog/models/connection_summary.rb', line 194

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    key == other.key &&
    description == other.description &&
    display_name == other.display_name &&
    data_asset_key == other.data_asset_key &&
    type_key == other.type_key &&
    uri == other.uri &&
    external_key == other.external_key &&
    lifecycle_state == other.lifecycle_state &&
    is_default == other.is_default &&
    time_created == other.time_created
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/oci/data_catalog/models/connection_summary.rb', line 233

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


213
214
215
# File 'lib/oci/data_catalog/models/connection_summary.rb', line 213

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



222
223
224
# File 'lib/oci/data_catalog/models/connection_summary.rb', line 222

def hash
  [key, description, display_name, data_asset_key, type_key, uri, external_key, lifecycle_state, is_default, time_created].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



266
267
268
269
270
271
272
273
274
275
# File 'lib/oci/data_catalog/models/connection_summary.rb', line 266

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



260
261
262
# File 'lib/oci/data_catalog/models/connection_summary.rb', line 260

def to_s
  to_hash.to_s
end