Class: OCI::DataCatalog::Models::CreateAttributeDetails
- Inherits:
-
Object
- Object
- OCI::DataCatalog::Models::CreateAttributeDetails
- Defined in:
- lib/oci/data_catalog/models/create_attribute_details.rb
Overview
Properties used in attribute create operations.
Instance Attribute Summary collapse
-
#business_name ⇒ String
Optional user friendly business name of the attribute.
-
#custom_property_members ⇒ Array<OCI::DataCatalog::Models::CustomPropertySetUsage>
The list of customized properties along with the values for this object.
-
#description ⇒ String
Detailed description of the attribute.
-
#display_name ⇒ String
[Required] A user-friendly display name.
-
#external_data_type ⇒ String
[Required] Data type of the attribute as defined in the external system.
-
#external_datatype_entity_key ⇒ String
External entity key that represents the datatype of this attribute , applicable if this attribute is a complex type.
-
#external_parent_attribute_key ⇒ String
External attribute key that represents the parent attribute of this attribute , applicable if the parent attribute is of complex type.
-
#is_incremental_data ⇒ BOOLEAN
Property that identifies if this attribute can be used as a watermark to extract incremental data.
-
#is_nullable ⇒ BOOLEAN
Property that identifies if this attribute can be assigned null values.
-
#length ⇒ Integer
Max allowed length of the attribute value.
-
#max_collection_count ⇒ Integer
The maximum count for the number of instances of a given type stored in this collection type attribute,applicable if this attribute is a complex type.
-
#min_collection_count ⇒ Integer
The minimum count for the number of instances of a given type stored in this collection type attribute,applicable if this attribute is a complex type.
-
#position ⇒ Integer
Position of the attribute in the record definition.
-
#precision ⇒ Integer
Precision of the attribute value usually applies to float data type.
-
#properties ⇒ Hash<String, Hash<String, String>>
A map of maps that contains the properties which are specific to the attribute type.
-
#scale ⇒ Integer
Scale of the attribute value usually applies to float data type.
-
#time_external ⇒ DateTime
[Required] Last modified timestamp of this object in the external system.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateAttributeDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateAttributeDetails
Initializes the object
164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/oci/data_catalog/models/create_attribute_details.rb', line 164 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.business_name = attributes[:'businessName'] if attributes[:'businessName'] raise 'You cannot provide both :businessName and :business_name' if attributes.key?(:'businessName') && attributes.key?(:'business_name') self.business_name = attributes[:'business_name'] if attributes[:'business_name'] self.description = attributes[:'description'] if attributes[:'description'] self.external_data_type = attributes[:'externalDataType'] if attributes[:'externalDataType'] raise 'You cannot provide both :externalDataType and :external_data_type' if attributes.key?(:'externalDataType') && attributes.key?(:'external_data_type') self.external_data_type = attributes[:'external_data_type'] if attributes[:'external_data_type'] self.is_incremental_data = attributes[:'isIncrementalData'] unless attributes[:'isIncrementalData'].nil? self.is_incremental_data = false if is_incremental_data.nil? && !attributes.key?(:'isIncrementalData') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isIncrementalData and :is_incremental_data' if attributes.key?(:'isIncrementalData') && attributes.key?(:'is_incremental_data') self.is_incremental_data = attributes[:'is_incremental_data'] unless attributes[:'is_incremental_data'].nil? self.is_incremental_data = false if is_incremental_data.nil? && !attributes.key?(:'isIncrementalData') && !attributes.key?(:'is_incremental_data') # rubocop:disable Style/StringLiterals self.is_nullable = attributes[:'isNullable'] unless attributes[:'isNullable'].nil? self.is_nullable = false if is_nullable.nil? && !attributes.key?(:'isNullable') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isNullable and :is_nullable' if attributes.key?(:'isNullable') && attributes.key?(:'is_nullable') self.is_nullable = attributes[:'is_nullable'] unless attributes[:'is_nullable'].nil? self.is_nullable = false if is_nullable.nil? && !attributes.key?(:'isNullable') && !attributes.key?(:'is_nullable') # rubocop:disable Style/StringLiterals self.length = attributes[:'length'] if attributes[:'length'] self.position = attributes[:'position'] if attributes[:'position'] self.precision = attributes[:'precision'] if attributes[:'precision'] self.scale = attributes[:'scale'] if attributes[:'scale'] self.time_external = attributes[:'timeExternal'] if attributes[:'timeExternal'] raise 'You cannot provide both :timeExternal and :time_external' if attributes.key?(:'timeExternal') && attributes.key?(:'time_external') self.time_external = attributes[:'time_external'] if attributes[:'time_external'] self.min_collection_count = attributes[:'minCollectionCount'] if attributes[:'minCollectionCount'] raise 'You cannot provide both :minCollectionCount and :min_collection_count' if attributes.key?(:'minCollectionCount') && attributes.key?(:'min_collection_count') self.min_collection_count = attributes[:'min_collection_count'] if attributes[:'min_collection_count'] self.max_collection_count = attributes[:'maxCollectionCount'] if attributes[:'maxCollectionCount'] raise 'You cannot provide both :maxCollectionCount and :max_collection_count' if attributes.key?(:'maxCollectionCount') && attributes.key?(:'max_collection_count') self.max_collection_count = attributes[:'max_collection_count'] if attributes[:'max_collection_count'] self.external_datatype_entity_key = attributes[:'externalDatatypeEntityKey'] if attributes[:'externalDatatypeEntityKey'] raise 'You cannot provide both :externalDatatypeEntityKey and :external_datatype_entity_key' if attributes.key?(:'externalDatatypeEntityKey') && attributes.key?(:'external_datatype_entity_key') self.external_datatype_entity_key = attributes[:'external_datatype_entity_key'] if attributes[:'external_datatype_entity_key'] self.external_parent_attribute_key = attributes[:'externalParentAttributeKey'] if attributes[:'externalParentAttributeKey'] raise 'You cannot provide both :externalParentAttributeKey and :external_parent_attribute_key' if attributes.key?(:'externalParentAttributeKey') && attributes.key?(:'external_parent_attribute_key') self.external_parent_attribute_key = attributes[:'external_parent_attribute_key'] if attributes[:'external_parent_attribute_key'] self.custom_property_members = attributes[:'customPropertyMembers'] if attributes[:'customPropertyMembers'] raise 'You cannot provide both :customPropertyMembers and :custom_property_members' if attributes.key?(:'customPropertyMembers') && attributes.key?(:'custom_property_members') self.custom_property_members = attributes[:'custom_property_members'] if attributes[:'custom_property_members'] self.properties = attributes[:'properties'] if attributes[:'properties'] end |
Instance Attribute Details
#business_name ⇒ String
Optional user friendly business name of the attribute. If set, this supplements the harvested display name of the object.
18 19 20 |
# File 'lib/oci/data_catalog/models/create_attribute_details.rb', line 18 def business_name @business_name end |
#custom_property_members ⇒ Array<OCI::DataCatalog::Models::CustomPropertySetUsage>
The list of customized properties along with the values for this object
77 78 79 |
# File 'lib/oci/data_catalog/models/create_attribute_details.rb', line 77 def custom_property_members @custom_property_members end |
#description ⇒ String
Detailed description of the attribute.
22 23 24 |
# File 'lib/oci/data_catalog/models/create_attribute_details.rb', line 22 def description @description end |
#display_name ⇒ String
[Required] A user-friendly display name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
14 15 16 |
# File 'lib/oci/data_catalog/models/create_attribute_details.rb', line 14 def display_name @display_name end |
#external_data_type ⇒ String
[Required] Data type of the attribute as defined in the external system.
26 27 28 |
# File 'lib/oci/data_catalog/models/create_attribute_details.rb', line 26 def external_data_type @external_data_type end |
#external_datatype_entity_key ⇒ String
External entity key that represents the datatype of this attribute , applicable if this attribute is a complex type.
69 70 71 |
# File 'lib/oci/data_catalog/models/create_attribute_details.rb', line 69 def external_datatype_entity_key @external_datatype_entity_key end |
#external_parent_attribute_key ⇒ String
External attribute key that represents the parent attribute of this attribute , applicable if the parent attribute is of complex type.
73 74 75 |
# File 'lib/oci/data_catalog/models/create_attribute_details.rb', line 73 def external_parent_attribute_key @external_parent_attribute_key end |
#is_incremental_data ⇒ BOOLEAN
Property that identifies if this attribute can be used as a watermark to extract incremental data.
30 31 32 |
# File 'lib/oci/data_catalog/models/create_attribute_details.rb', line 30 def is_incremental_data @is_incremental_data end |
#is_nullable ⇒ BOOLEAN
Property that identifies if this attribute can be assigned null values.
34 35 36 |
# File 'lib/oci/data_catalog/models/create_attribute_details.rb', line 34 def is_nullable @is_nullable end |
#length ⇒ Integer
Max allowed length of the attribute value.
38 39 40 |
# File 'lib/oci/data_catalog/models/create_attribute_details.rb', line 38 def length @length end |
#max_collection_count ⇒ Integer
The maximum count for the number of instances of a given type stored in this collection type attribute,applicable if this attribute is a complex type. For type specifications in systems that specify only "capacity" without upper or lower bound , this property can also be used to just mean "capacity". Some examples are Varray size in Oracle , Occurs Clause in Cobol , capacity in XmlSchemaObjectCollection , maxOccurs in Xml , maxItems in Json
65 66 67 |
# File 'lib/oci/data_catalog/models/create_attribute_details.rb', line 65 def max_collection_count @max_collection_count end |
#min_collection_count ⇒ Integer
The minimum count for the number of instances of a given type stored in this collection type attribute,applicable if this attribute is a complex type.
58 59 60 |
# File 'lib/oci/data_catalog/models/create_attribute_details.rb', line 58 def min_collection_count @min_collection_count end |
#position ⇒ Integer
Position of the attribute in the record definition.
42 43 44 |
# File 'lib/oci/data_catalog/models/create_attribute_details.rb', line 42 def position @position end |
#precision ⇒ Integer
Precision of the attribute value usually applies to float data type.
46 47 48 |
# File 'lib/oci/data_catalog/models/create_attribute_details.rb', line 46 def precision @precision end |
#properties ⇒ Hash<String, Hash<String, String>>
A map of maps that contains the properties which are specific to the attribute type. Each attribute type definition defines it’s set of required and optional properties. The map keys are category names and the values are maps of property name to property value. Every property is contained inside of a category. Most attributes have required properties within the "default" category. To determine the set of required and optional properties for an attribute type, a query can be done on ‘/types?type=attribute’ that returns a collection of all attribute types. The appropriate attribute type, which will include definitions of all of it’s properties, can be identified from this collection. Example: ‘{ "default": { "key1": "value1"}}`
89 90 91 |
# File 'lib/oci/data_catalog/models/create_attribute_details.rb', line 89 def properties @properties end |
#scale ⇒ Integer
Scale of the attribute value usually applies to float data type.
50 51 52 |
# File 'lib/oci/data_catalog/models/create_attribute_details.rb', line 50 def scale @scale end |
#time_external ⇒ DateTime
[Required] Last modified timestamp of this object in the external system.
54 55 56 |
# File 'lib/oci/data_catalog/models/create_attribute_details.rb', line 54 def time_external @time_external end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/oci/data_catalog/models/create_attribute_details.rb', line 92 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'business_name': :'businessName', 'description': :'description', 'external_data_type': :'externalDataType', 'is_incremental_data': :'isIncrementalData', 'is_nullable': :'isNullable', 'length': :'length', 'position': :'position', 'precision': :'precision', 'scale': :'scale', 'time_external': :'timeExternal', 'min_collection_count': :'minCollectionCount', 'max_collection_count': :'maxCollectionCount', 'external_datatype_entity_key': :'externalDatatypeEntityKey', 'external_parent_attribute_key': :'externalParentAttributeKey', 'custom_property_members': :'customPropertyMembers', 'properties': :'properties' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/oci/data_catalog/models/create_attribute_details.rb', line 117 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'business_name': :'String', 'description': :'String', 'external_data_type': :'String', 'is_incremental_data': :'BOOLEAN', 'is_nullable': :'BOOLEAN', 'length': :'Integer', 'position': :'Integer', 'precision': :'Integer', 'scale': :'Integer', 'time_external': :'DateTime', 'min_collection_count': :'Integer', 'max_collection_count': :'Integer', 'external_datatype_entity_key': :'String', 'external_parent_attribute_key': :'String', 'custom_property_members': :'Array<OCI::DataCatalog::Models::CustomPropertySetUsage>', 'properties': :'Hash<String, Hash<String, String>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/oci/data_catalog/models/create_attribute_details.rb', line 260 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && business_name == other.business_name && description == other.description && external_data_type == other.external_data_type && is_incremental_data == other.is_incremental_data && is_nullable == other.is_nullable && length == other.length && position == other.position && precision == other.precision && scale == other.scale && time_external == other.time_external && min_collection_count == other.min_collection_count && max_collection_count == other.max_collection_count && external_datatype_entity_key == other.external_datatype_entity_key && external_parent_attribute_key == other.external_parent_attribute_key && custom_property_members == other.custom_property_members && properties == other.properties end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 |
# File 'lib/oci/data_catalog/models/create_attribute_details.rb', line 306 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
286 287 288 |
# File 'lib/oci/data_catalog/models/create_attribute_details.rb', line 286 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
295 296 297 |
# File 'lib/oci/data_catalog/models/create_attribute_details.rb', line 295 def hash [display_name, business_name, description, external_data_type, is_incremental_data, is_nullable, length, position, precision, scale, time_external, min_collection_count, max_collection_count, external_datatype_entity_key, external_parent_attribute_key, custom_property_members, properties].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
339 340 341 342 343 344 345 346 347 348 |
# File 'lib/oci/data_catalog/models/create_attribute_details.rb', line 339 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
333 334 335 |
# File 'lib/oci/data_catalog/models/create_attribute_details.rb', line 333 def to_s to_hash.to_s end |