Class: OCI::DataCatalog::Models::CreateConnectionDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_catalog/models/create_connection_details.rb

Overview

Properties used in connection create operations.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateConnectionDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
# File 'lib/oci/data_catalog/models/create_connection_details.rb', line 103

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.description = attributes[:'description'] if attributes[:'description']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.type_key = attributes[:'typeKey'] if attributes[:'typeKey']

  raise 'You cannot provide both :typeKey and :type_key' if attributes.key?(:'typeKey') && attributes.key?(:'type_key')

  self.type_key = attributes[:'type_key'] if attributes[:'type_key']

  self.custom_property_members = attributes[:'customPropertyMembers'] if attributes[:'customPropertyMembers']

  raise 'You cannot provide both :customPropertyMembers and :custom_property_members' if attributes.key?(:'customPropertyMembers') && attributes.key?(:'custom_property_members')

  self.custom_property_members = attributes[:'custom_property_members'] if attributes[:'custom_property_members']

  self.properties = attributes[:'properties'] if attributes[:'properties']

  self.enc_properties = attributes[:'encProperties'] if attributes[:'encProperties']

  raise 'You cannot provide both :encProperties and :enc_properties' if attributes.key?(:'encProperties') && attributes.key?(:'enc_properties')

  self.enc_properties = attributes[:'enc_properties'] if attributes[:'enc_properties']

  self.is_default = attributes[:'isDefault'] unless attributes[:'isDefault'].nil?

  raise 'You cannot provide both :isDefault and :is_default' if attributes.key?(:'isDefault') && attributes.key?(:'is_default')

  self.is_default = attributes[:'is_default'] unless attributes[:'is_default'].nil?
end

Instance Attribute Details

#custom_property_membersArray<OCI::DataCatalog::Models::CustomPropertySetUsage>

The list of customized properties along with the values for this object



26
27
28
# File 'lib/oci/data_catalog/models/create_connection_details.rb', line 26

def custom_property_members
  @custom_property_members
end

#descriptionString

A description of the connection.

Returns:

  • (String)


12
13
14
# File 'lib/oci/data_catalog/models/create_connection_details.rb', line 12

def description
  @description
end

#display_nameString

[Required] A user-friendly display name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.

Returns:

  • (String)


18
19
20
# File 'lib/oci/data_catalog/models/create_connection_details.rb', line 18

def display_name
  @display_name
end

#enc_propertiesHash<String, Hash<String, String>>

A map of maps that contains the encrypted values for sensitive properties which are specific to the connection type. Each connection type definition defines it’s set of required and optional properties. The map keys are category names and the values are maps of property name to property value. Every property is contained inside of a category. Most connections have required properties within the "default" category. To determine the set of optional and required properties for a connection type, a query can be done on ‘/types?type=connection’ that returns a collection of all connection types. The appropriate connection type, which will include definitions of all of it’s properties, can be identified from this collection. Example: ‘{ "default": { "password": "example-password"}}`

Returns:

  • (Hash<String, Hash<String, String>>)


50
51
52
# File 'lib/oci/data_catalog/models/create_connection_details.rb', line 50

def enc_properties
  @enc_properties
end

#is_defaultBOOLEAN

Indicates whether this connection is the default connection. The first connection of a data asset defaults to being the default, subsequent connections default to not being the default. If a default connection already exists, then trying to create a connection as the default will fail. In this case the default connection would need to be updated not to be the default and then the new connection can then be created as the default.

Returns:

  • (BOOLEAN)


58
59
60
# File 'lib/oci/data_catalog/models/create_connection_details.rb', line 58

def is_default
  @is_default
end

#propertiesHash<String, Hash<String, String>>

[Required] A map of maps that contains the properties which are specific to the connection type. Each connection type definition defines it’s set of required and optional properties. The map keys are category names and the values are maps of property name to property value. Every property is contained inside of a category. Most connections have required properties within the "default" category. To determine the set of optional and required properties for a connection type, a query can be done on ‘/types?type=connection’ that returns a collection of all connection types. The appropriate connection type, which will include definitions of all of it’s properties, can be identified from this collection. Example: ‘{ "default": { "username": "user1"}}`

Returns:

  • (Hash<String, Hash<String, String>>)


38
39
40
# File 'lib/oci/data_catalog/models/create_connection_details.rb', line 38

def properties
  @properties
end

#type_keyString

[Required] The key of the object type. Type key’s can be found via the ‘/types’ endpoint.

Returns:

  • (String)


22
23
24
# File 'lib/oci/data_catalog/models/create_connection_details.rb', line 22

def type_key
  @type_key
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/oci/data_catalog/models/create_connection_details.rb', line 61

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'description': :'description',
    'display_name': :'displayName',
    'type_key': :'typeKey',
    'custom_property_members': :'customPropertyMembers',
    'properties': :'properties',
    'enc_properties': :'encProperties',
    'is_default': :'isDefault'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/oci/data_catalog/models/create_connection_details.rb', line 76

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'description': :'String',
    'display_name': :'String',
    'type_key': :'String',
    'custom_property_members': :'Array<OCI::DataCatalog::Models::CustomPropertySetUsage>',
    'properties': :'Hash<String, Hash<String, String>>',
    'enc_properties': :'Hash<String, Hash<String, String>>',
    'is_default': :'BOOLEAN'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/oci/data_catalog/models/create_connection_details.rb', line 151

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    description == other.description &&
    display_name == other.display_name &&
    type_key == other.type_key &&
    custom_property_members == other.custom_property_members &&
    properties == other.properties &&
    enc_properties == other.enc_properties &&
    is_default == other.is_default
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/oci/data_catalog/models/create_connection_details.rb', line 187

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


167
168
169
# File 'lib/oci/data_catalog/models/create_connection_details.rb', line 167

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



176
177
178
# File 'lib/oci/data_catalog/models/create_connection_details.rb', line 176

def hash
  [description, display_name, type_key, custom_property_members, properties, enc_properties, is_default].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



220
221
222
223
224
225
226
227
228
229
# File 'lib/oci/data_catalog/models/create_connection_details.rb', line 220

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



214
215
216
# File 'lib/oci/data_catalog/models/create_connection_details.rb', line 214

def to_s
  to_hash.to_s
end