Class: OCI::DataCatalog::Models::CreateGlossaryDetails
- Inherits:
-
Object
- Object
- OCI::DataCatalog::Models::CreateGlossaryDetails
- Defined in:
- lib/oci/data_catalog/models/create_glossary_details.rb
Overview
Properties used in glossary create operations.
Constant Summary collapse
- WORKFLOW_STATUS_ENUM =
[ WORKFLOW_STATUS_NEW = 'NEW'.freeze, WORKFLOW_STATUS_APPROVED = 'APPROVED'.freeze, WORKFLOW_STATUS_UNDER_REVIEW = 'UNDER_REVIEW'.freeze, WORKFLOW_STATUS_ESCALATED = 'ESCALATED'.freeze ].freeze
Instance Attribute Summary collapse
-
#custom_property_members ⇒ Array<OCI::DataCatalog::Models::CustomPropertySetUsage>
The list of customized properties along with the values for this object.
-
#description ⇒ String
Detailed description of the glossary.
-
#display_name ⇒ String
**[Required]** A user-friendly display name.
-
#owner ⇒ String
OCID of the user who is the owner of the glossary.
-
#workflow_status ⇒ String
Status of the approval process workflow for this business glossary.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateGlossaryDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateGlossaryDetails
Initializes the object
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/oci/data_catalog/models/create_glossary_details.rb', line 76 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.workflow_status = attributes[:'workflowStatus'] if attributes[:'workflowStatus'] raise 'You cannot provide both :workflowStatus and :workflow_status' if attributes.key?(:'workflowStatus') && attributes.key?(:'workflow_status') self.workflow_status = attributes[:'workflow_status'] if attributes[:'workflow_status'] self.owner = attributes[:'owner'] if attributes[:'owner'] self.custom_property_members = attributes[:'customPropertyMembers'] if attributes[:'customPropertyMembers'] raise 'You cannot provide both :customPropertyMembers and :custom_property_members' if attributes.key?(:'customPropertyMembers') && attributes.key?(:'custom_property_members') self.custom_property_members = attributes[:'custom_property_members'] if attributes[:'custom_property_members'] end |
Instance Attribute Details
#custom_property_members ⇒ Array<OCI::DataCatalog::Models::CustomPropertySetUsage>
The list of customized properties along with the values for this object
37 38 39 |
# File 'lib/oci/data_catalog/models/create_glossary_details.rb', line 37 def custom_property_members @custom_property_members end |
#description ⇒ String
Detailed description of the glossary.
25 26 27 |
# File 'lib/oci/data_catalog/models/create_glossary_details.rb', line 25 def description @description end |
#display_name ⇒ String
**[Required]** A user-friendly display name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
21 22 23 |
# File 'lib/oci/data_catalog/models/create_glossary_details.rb', line 21 def display_name @display_name end |
#owner ⇒ String
OCID of the user who is the owner of the glossary.
33 34 35 |
# File 'lib/oci/data_catalog/models/create_glossary_details.rb', line 33 def owner @owner end |
#workflow_status ⇒ String
Status of the approval process workflow for this business glossary.
29 30 31 |
# File 'lib/oci/data_catalog/models/create_glossary_details.rb', line 29 def workflow_status @workflow_status end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/oci/data_catalog/models/create_glossary_details.rb', line 40 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'description': :'description', 'workflow_status': :'workflowStatus', 'owner': :'owner', 'custom_property_members': :'customPropertyMembers' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/oci/data_catalog/models/create_glossary_details.rb', line 53 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'description': :'String', 'workflow_status': :'String', 'owner': :'String', 'custom_property_members': :'Array<OCI::DataCatalog::Models::CustomPropertySetUsage>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
120 121 122 123 124 125 126 127 128 129 |
# File 'lib/oci/data_catalog/models/create_glossary_details.rb', line 120 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && description == other.description && workflow_status == other.workflow_status && owner == other.owner && custom_property_members == other.custom_property_members end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/oci/data_catalog/models/create_glossary_details.rb', line 154 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
134 135 136 |
# File 'lib/oci/data_catalog/models/create_glossary_details.rb', line 134 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
143 144 145 |
# File 'lib/oci/data_catalog/models/create_glossary_details.rb', line 143 def hash [display_name, description, workflow_status, owner, custom_property_members].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
187 188 189 190 191 192 193 194 195 196 |
# File 'lib/oci/data_catalog/models/create_glossary_details.rb', line 187 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
181 182 183 |
# File 'lib/oci/data_catalog/models/create_glossary_details.rb', line 181 def to_s to_hash.to_s end |