Class: OCI::DataCatalog::Models::CreateJobDefinitionDetails
- Inherits:
-
Object
- Object
- OCI::DataCatalog::Models::CreateJobDefinitionDetails
- Defined in:
- lib/oci/data_catalog/models/create_job_definition_details.rb
Overview
Representation of a job definition Resource. Job definitions define the harvest scope and includes the list of objects to be harvested along with a schedule. The list of objects is usually specified through a combination of object type, regular expressions, or specific names of objects and a sample size for the data harvested.
Constant Summary collapse
- JOB_TYPE_ENUM =
[ JOB_TYPE_HARVEST = 'HARVEST'.freeze, JOB_TYPE_PROFILING = 'PROFILING'.freeze, JOB_TYPE_SAMPLING = 'SAMPLING'.freeze, JOB_TYPE_PREVIEW = 'PREVIEW'.freeze, JOB_TYPE_IMPORT = 'IMPORT'.freeze, JOB_TYPE_EXPORT = 'EXPORT'.freeze, JOB_TYPE_IMPORT_GLOSSARY = 'IMPORT_GLOSSARY'.freeze, JOB_TYPE_EXPORT_GLOSSARY = 'EXPORT_GLOSSARY'.freeze, JOB_TYPE_INTERNAL = 'INTERNAL'.freeze, JOB_TYPE_PURGE = 'PURGE'.freeze, JOB_TYPE_IMMEDIATE = 'IMMEDIATE'.freeze, JOB_TYPE_SCHEDULED = 'SCHEDULED'.freeze, JOB_TYPE_IMMEDIATE_EXECUTION = 'IMMEDIATE_EXECUTION'.freeze, JOB_TYPE_SCHEDULED_EXECUTION = 'SCHEDULED_EXECUTION'.freeze, JOB_TYPE_SCHEDULED_EXECUTION_INSTANCE = 'SCHEDULED_EXECUTION_INSTANCE'.freeze, JOB_TYPE_ASYNC_DELETE = 'ASYNC_DELETE'.freeze, JOB_TYPE_IMPORT_DATA_ASSET = 'IMPORT_DATA_ASSET'.freeze ].freeze
Instance Attribute Summary collapse
-
#connection_key ⇒ String
The key of the connection resource to be used for the job.
-
#data_asset_key ⇒ String
The key of the data asset for which the job is defined.
-
#description ⇒ String
Detailed description of the job definition.
-
#display_name ⇒ String
[Required] A user-friendly display name.
-
#is_incremental ⇒ BOOLEAN
Specifies if the job definition is incremental or full.
-
#is_sample_data_extracted ⇒ BOOLEAN
Specify if sample data to be extracted as part of this harvest.
-
#job_type ⇒ String
[Required] Type of the job definition.
-
#properties ⇒ Hash<String, Hash<String, String>>
A map of maps that contains the properties which are specific to the job type.
-
#sample_data_size_in_mbs ⇒ Integer
Specify the sample data size in MB, specified as number of rows, for this metadata harvest.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateJobDefinitionDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateJobDefinitionDetails
Initializes the object
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/oci/data_catalog/models/create_job_definition_details.rb', line 125 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.job_type = attributes[:'jobType'] if attributes[:'jobType'] raise 'You cannot provide both :jobType and :job_type' if attributes.key?(:'jobType') && attributes.key?(:'job_type') self.job_type = attributes[:'job_type'] if attributes[:'job_type'] self.is_incremental = attributes[:'isIncremental'] unless attributes[:'isIncremental'].nil? self.is_incremental = false if is_incremental.nil? && !attributes.key?(:'isIncremental') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isIncremental and :is_incremental' if attributes.key?(:'isIncremental') && attributes.key?(:'is_incremental') self.is_incremental = attributes[:'is_incremental'] unless attributes[:'is_incremental'].nil? self.is_incremental = false if is_incremental.nil? && !attributes.key?(:'isIncremental') && !attributes.key?(:'is_incremental') # rubocop:disable Style/StringLiterals self.data_asset_key = attributes[:'dataAssetKey'] if attributes[:'dataAssetKey'] raise 'You cannot provide both :dataAssetKey and :data_asset_key' if attributes.key?(:'dataAssetKey') && attributes.key?(:'data_asset_key') self.data_asset_key = attributes[:'data_asset_key'] if attributes[:'data_asset_key'] self.connection_key = attributes[:'connectionKey'] if attributes[:'connectionKey'] raise 'You cannot provide both :connectionKey and :connection_key' if attributes.key?(:'connectionKey') && attributes.key?(:'connection_key') self.connection_key = attributes[:'connection_key'] if attributes[:'connection_key'] self.is_sample_data_extracted = attributes[:'isSampleDataExtracted'] unless attributes[:'isSampleDataExtracted'].nil? self.is_sample_data_extracted = true if is_sample_data_extracted.nil? && !attributes.key?(:'isSampleDataExtracted') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isSampleDataExtracted and :is_sample_data_extracted' if attributes.key?(:'isSampleDataExtracted') && attributes.key?(:'is_sample_data_extracted') self.is_sample_data_extracted = attributes[:'is_sample_data_extracted'] unless attributes[:'is_sample_data_extracted'].nil? self.is_sample_data_extracted = true if is_sample_data_extracted.nil? && !attributes.key?(:'isSampleDataExtracted') && !attributes.key?(:'is_sample_data_extracted') # rubocop:disable Style/StringLiterals self.sample_data_size_in_mbs = attributes[:'sampleDataSizeInMBs'] if attributes[:'sampleDataSizeInMBs'] raise 'You cannot provide both :sampleDataSizeInMBs and :sample_data_size_in_mbs' if attributes.key?(:'sampleDataSizeInMBs') && attributes.key?(:'sample_data_size_in_mbs') self.sample_data_size_in_mbs = attributes[:'sample_data_size_in_mbs'] if attributes[:'sample_data_size_in_mbs'] self.properties = attributes[:'properties'] if attributes[:'properties'] end |
Instance Attribute Details
#connection_key ⇒ String
The key of the connection resource to be used for the job.
57 58 59 |
# File 'lib/oci/data_catalog/models/create_job_definition_details.rb', line 57 def connection_key @connection_key end |
#data_asset_key ⇒ String
The key of the data asset for which the job is defined.
53 54 55 |
# File 'lib/oci/data_catalog/models/create_job_definition_details.rb', line 53 def data_asset_key @data_asset_key end |
#description ⇒ String
Detailed description of the job definition.
41 42 43 |
# File 'lib/oci/data_catalog/models/create_job_definition_details.rb', line 41 def description @description end |
#display_name ⇒ String
[Required] A user-friendly display name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
37 38 39 |
# File 'lib/oci/data_catalog/models/create_job_definition_details.rb', line 37 def display_name @display_name end |
#is_incremental ⇒ BOOLEAN
Specifies if the job definition is incremental or full.
49 50 51 |
# File 'lib/oci/data_catalog/models/create_job_definition_details.rb', line 49 def is_incremental @is_incremental end |
#is_sample_data_extracted ⇒ BOOLEAN
Specify if sample data to be extracted as part of this harvest.
61 62 63 |
# File 'lib/oci/data_catalog/models/create_job_definition_details.rb', line 61 def is_sample_data_extracted @is_sample_data_extracted end |
#job_type ⇒ String
[Required] Type of the job definition.
45 46 47 |
# File 'lib/oci/data_catalog/models/create_job_definition_details.rb', line 45 def job_type @job_type end |
#properties ⇒ Hash<String, Hash<String, String>>
A map of maps that contains the properties which are specific to the job type. Each job type definition may define it’s set of required and optional properties. The map keys are category names and the values are maps of property name to property value. Every property is contained inside of a category. Most job definitions have required properties within the "default" category. Example: ‘{ "default": { "host": "host1", "port": "1521", "database": "orcl"}}`
74 75 76 |
# File 'lib/oci/data_catalog/models/create_job_definition_details.rb', line 74 def properties @properties end |
#sample_data_size_in_mbs ⇒ Integer
Specify the sample data size in MB, specified as number of rows, for this metadata harvest.
65 66 67 |
# File 'lib/oci/data_catalog/models/create_job_definition_details.rb', line 65 def sample_data_size_in_mbs @sample_data_size_in_mbs end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/oci/data_catalog/models/create_job_definition_details.rb', line 77 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'description': :'description', 'job_type': :'jobType', 'is_incremental': :'isIncremental', 'data_asset_key': :'dataAssetKey', 'connection_key': :'connectionKey', 'is_sample_data_extracted': :'isSampleDataExtracted', 'sample_data_size_in_mbs': :'sampleDataSizeInMBs', 'properties': :'properties' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/oci/data_catalog/models/create_job_definition_details.rb', line 94 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'description': :'String', 'job_type': :'String', 'is_incremental': :'BOOLEAN', 'data_asset_key': :'String', 'connection_key': :'String', 'is_sample_data_extracted': :'BOOLEAN', 'sample_data_size_in_mbs': :'Integer', 'properties': :'Hash<String, Hash<String, String>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/oci/data_catalog/models/create_job_definition_details.rb', line 197 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && description == other.description && job_type == other.job_type && is_incremental == other.is_incremental && data_asset_key == other.data_asset_key && connection_key == other.connection_key && is_sample_data_extracted == other.is_sample_data_extracted && sample_data_size_in_mbs == other.sample_data_size_in_mbs && properties == other.properties end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/oci/data_catalog/models/create_job_definition_details.rb', line 235 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
215 216 217 |
# File 'lib/oci/data_catalog/models/create_job_definition_details.rb', line 215 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
224 225 226 |
# File 'lib/oci/data_catalog/models/create_job_definition_details.rb', line 224 def hash [display_name, description, job_type, is_incremental, data_asset_key, connection_key, is_sample_data_extracted, sample_data_size_in_mbs, properties].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
268 269 270 271 272 273 274 275 276 277 |
# File 'lib/oci/data_catalog/models/create_job_definition_details.rb', line 268 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
262 263 264 |
# File 'lib/oci/data_catalog/models/create_job_definition_details.rb', line 262 def to_s to_hash.to_s end |