Class: OCI::DataCatalog::Models::CreateMetastoreDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_catalog/models/create_metastore_details.rb

Overview

Information about a new metastore.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateMetastoreDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/oci/data_catalog/models/create_metastore_details.rb', line 82

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.default_managed_table_location = attributes[:'defaultManagedTableLocation'] if attributes[:'defaultManagedTableLocation']

  raise 'You cannot provide both :defaultManagedTableLocation and :default_managed_table_location' if attributes.key?(:'defaultManagedTableLocation') && attributes.key?(:'default_managed_table_location')

  self.default_managed_table_location = attributes[:'default_managed_table_location'] if attributes[:'default_managed_table_location']

  self.default_external_table_location = attributes[:'defaultExternalTableLocation'] if attributes[:'defaultExternalTableLocation']

  raise 'You cannot provide both :defaultExternalTableLocation and :default_external_table_location' if attributes.key?(:'defaultExternalTableLocation') && attributes.key?(:'default_external_table_location')

  self.default_external_table_location = attributes[:'default_external_table_location'] if attributes[:'default_external_table_location']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#compartment_idString

**[Required]** OCID of the compartment which holds the metastore.

Returns:

  • (String)


16
17
18
# File 'lib/oci/data_catalog/models/create_metastore_details.rb', line 16

def compartment_id
  @compartment_id
end

#default_external_table_locationString

**[Required]** Location under which external tables will be created by default. This references Object Storage using an HDFS URI format. Example: oci://bucket@namespace/sub-dir/

Returns:

  • (String)


28
29
30
# File 'lib/oci/data_catalog/models/create_metastore_details.rb', line 28

def default_external_table_location
  @default_external_table_location
end

#default_managed_table_locationString

**[Required]** Location under which managed tables will be created by default. This references Object Storage using an HDFS URI format. Example: oci://bucket@namespace/sub-dir/

Returns:

  • (String)


22
23
24
# File 'lib/oci/data_catalog/models/create_metastore_details.rb', line 22

def default_managed_table_location
  @default_managed_table_location
end

#defined_tagsHash<String, Hash<String, Object>>

Usage of predefined tag keys. These predefined keys are scoped to namespaces. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


40
41
42
# File 'lib/oci/data_catalog/models/create_metastore_details.rb', line 40

def defined_tags
  @defined_tags
end

#display_nameString

Mutable name of the metastore.

Returns:

  • (String)


12
13
14
# File 'lib/oci/data_catalog/models/create_metastore_details.rb', line 12

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`

Returns:

  • (Hash<String, String>)


34
35
36
# File 'lib/oci/data_catalog/models/create_metastore_details.rb', line 34

def freeform_tags
  @freeform_tags
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/oci/data_catalog/models/create_metastore_details.rb', line 43

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'displayName',
    'compartment_id': :'compartmentId',
    'default_managed_table_location': :'defaultManagedTableLocation',
    'default_external_table_location': :'defaultExternalTableLocation',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/oci/data_catalog/models/create_metastore_details.rb', line 57

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'String',
    'compartment_id': :'String',
    'default_managed_table_location': :'String',
    'default_external_table_location': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



132
133
134
135
136
137
138
139
140
141
142
# File 'lib/oci/data_catalog/models/create_metastore_details.rb', line 132

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    display_name == other.display_name &&
    compartment_id == other.compartment_id &&
    default_managed_table_location == other.default_managed_table_location &&
    default_external_table_location == other.default_external_table_location &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/oci/data_catalog/models/create_metastore_details.rb', line 167

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


147
148
149
# File 'lib/oci/data_catalog/models/create_metastore_details.rb', line 147

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



156
157
158
# File 'lib/oci/data_catalog/models/create_metastore_details.rb', line 156

def hash
  [display_name, compartment_id, default_managed_table_location, default_external_table_location, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



200
201
202
203
204
205
206
207
208
209
# File 'lib/oci/data_catalog/models/create_metastore_details.rb', line 200

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



194
195
196
# File 'lib/oci/data_catalog/models/create_metastore_details.rb', line 194

def to_s
  to_hash.to_s
end