Class: OCI::DataCatalog::Models::CreateTermDetails
- Inherits:
-
Object
- Object
- OCI::DataCatalog::Models::CreateTermDetails
- Defined in:
- lib/oci/data_catalog/models/create_term_details.rb
Overview
Properties used in term create operations.
Constant Summary collapse
- WORKFLOW_STATUS_ENUM =
[ WORKFLOW_STATUS_NEW = 'NEW'.freeze, WORKFLOW_STATUS_APPROVED = 'APPROVED'.freeze, WORKFLOW_STATUS_UNDER_REVIEW = 'UNDER_REVIEW'.freeze, WORKFLOW_STATUS_ESCALATED = 'ESCALATED'.freeze ].freeze
Instance Attribute Summary collapse
-
#custom_property_members ⇒ Array<OCI::DataCatalog::Models::CustomPropertySetUsage>
The list of customized properties along with the values for this object.
-
#description ⇒ String
Detailed description of the term.
-
#display_name ⇒ String
[Required] A user-friendly display name.
-
#is_allowed_to_have_child_terms ⇒ BOOLEAN
Indicates whether a term may contain child terms.
-
#owner ⇒ String
OCID of the user who is the owner of this business terminology.
-
#parent_term_key ⇒ String
The parent key of the term.
-
#workflow_status ⇒ String
Status of the approval process workflow for this business term in the glossary.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateTermDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateTermDetails
Initializes the object
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/oci/data_catalog/models/create_term_details.rb', line 90 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.is_allowed_to_have_child_terms = attributes[:'isAllowedToHaveChildTerms'] unless attributes[:'isAllowedToHaveChildTerms'].nil? self.is_allowed_to_have_child_terms = true if is_allowed_to_have_child_terms.nil? && !attributes.key?(:'isAllowedToHaveChildTerms') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isAllowedToHaveChildTerms and :is_allowed_to_have_child_terms' if attributes.key?(:'isAllowedToHaveChildTerms') && attributes.key?(:'is_allowed_to_have_child_terms') self.is_allowed_to_have_child_terms = attributes[:'is_allowed_to_have_child_terms'] unless attributes[:'is_allowed_to_have_child_terms'].nil? self.is_allowed_to_have_child_terms = true if is_allowed_to_have_child_terms.nil? && !attributes.key?(:'isAllowedToHaveChildTerms') && !attributes.key?(:'is_allowed_to_have_child_terms') # rubocop:disable Style/StringLiterals self.parent_term_key = attributes[:'parentTermKey'] if attributes[:'parentTermKey'] raise 'You cannot provide both :parentTermKey and :parent_term_key' if attributes.key?(:'parentTermKey') && attributes.key?(:'parent_term_key') self.parent_term_key = attributes[:'parent_term_key'] if attributes[:'parent_term_key'] self.owner = attributes[:'owner'] if attributes[:'owner'] self.workflow_status = attributes[:'workflowStatus'] if attributes[:'workflowStatus'] raise 'You cannot provide both :workflowStatus and :workflow_status' if attributes.key?(:'workflowStatus') && attributes.key?(:'workflow_status') self.workflow_status = attributes[:'workflow_status'] if attributes[:'workflow_status'] self.custom_property_members = attributes[:'customPropertyMembers'] if attributes[:'customPropertyMembers'] raise 'You cannot provide both :customPropertyMembers and :custom_property_members' if attributes.key?(:'customPropertyMembers') && attributes.key?(:'custom_property_members') self.custom_property_members = attributes[:'custom_property_members'] if attributes[:'custom_property_members'] end |
Instance Attribute Details
#custom_property_members ⇒ Array<OCI::DataCatalog::Models::CustomPropertySetUsage>
The list of customized properties along with the values for this object
45 46 47 |
# File 'lib/oci/data_catalog/models/create_term_details.rb', line 45 def custom_property_members @custom_property_members end |
#description ⇒ String
Detailed description of the term.
25 26 27 |
# File 'lib/oci/data_catalog/models/create_term_details.rb', line 25 def description @description end |
#display_name ⇒ String
[Required] A user-friendly display name. Is changeable. The combination of ‘displayName’ and ‘parentTermKey’ must be unique. Avoid entering confidential information.
21 22 23 |
# File 'lib/oci/data_catalog/models/create_term_details.rb', line 21 def display_name @display_name end |
#is_allowed_to_have_child_terms ⇒ BOOLEAN
Indicates whether a term may contain child terms.
29 30 31 |
# File 'lib/oci/data_catalog/models/create_term_details.rb', line 29 def is_allowed_to_have_child_terms @is_allowed_to_have_child_terms end |
#owner ⇒ String
OCID of the user who is the owner of this business terminology.
37 38 39 |
# File 'lib/oci/data_catalog/models/create_term_details.rb', line 37 def owner @owner end |
#parent_term_key ⇒ String
The parent key of the term. In the case of a root-level category only, the term would have no parent and this should be left unset.
33 34 35 |
# File 'lib/oci/data_catalog/models/create_term_details.rb', line 33 def parent_term_key @parent_term_key end |
#workflow_status ⇒ String
Status of the approval process workflow for this business term in the glossary.
41 42 43 |
# File 'lib/oci/data_catalog/models/create_term_details.rb', line 41 def workflow_status @workflow_status end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/oci/data_catalog/models/create_term_details.rb', line 48 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'description': :'description', 'is_allowed_to_have_child_terms': :'isAllowedToHaveChildTerms', 'parent_term_key': :'parentTermKey', 'owner': :'owner', 'workflow_status': :'workflowStatus', 'custom_property_members': :'customPropertyMembers' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/oci/data_catalog/models/create_term_details.rb', line 63 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'description': :'String', 'is_allowed_to_have_child_terms': :'BOOLEAN', 'parent_term_key': :'String', 'owner': :'String', 'workflow_status': :'String', 'custom_property_members': :'Array<OCI::DataCatalog::Models::CustomPropertySetUsage>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/oci/data_catalog/models/create_term_details.rb', line 148 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && description == other.description && is_allowed_to_have_child_terms == other.is_allowed_to_have_child_terms && parent_term_key == other.parent_term_key && owner == other.owner && workflow_status == other.workflow_status && custom_property_members == other.custom_property_members end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/oci/data_catalog/models/create_term_details.rb', line 184 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
164 165 166 |
# File 'lib/oci/data_catalog/models/create_term_details.rb', line 164 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
173 174 175 |
# File 'lib/oci/data_catalog/models/create_term_details.rb', line 173 def hash [display_name, description, is_allowed_to_have_child_terms, parent_term_key, owner, workflow_status, custom_property_members].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
217 218 219 220 221 222 223 224 225 226 |
# File 'lib/oci/data_catalog/models/create_term_details.rb', line 217 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
211 212 213 |
# File 'lib/oci/data_catalog/models/create_term_details.rb', line 211 def to_s to_hash.to_s end |