Class: OCI::DataCatalog::Models::CustomProperty

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_catalog/models/custom_property.rb

Overview

Custom Property Definition

Constant Summary collapse

DATA_TYPE_ENUM =
[
  DATA_TYPE_TEXT = 'TEXT'.freeze,
  DATA_TYPE_RICH_TEXT = 'RICH_TEXT'.freeze,
  DATA_TYPE_BOOLEAN = 'BOOLEAN'.freeze,
  DATA_TYPE_NUMBER = 'NUMBER'.freeze,
  DATA_TYPE_DATE = 'DATE'.freeze,
  DATA_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_MOVING = 'MOVING'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CustomProperty

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :key (String)

    The value to assign to the #key property

  • :display_name (String)

    The value to assign to the #display_name property

  • :data_type (String)

    The value to assign to the #data_type property

  • :description (String)

    The value to assign to the #description property

  • :namespace_name (String)

    The value to assign to the #namespace_name property

  • :is_list_type (BOOLEAN)

    The value to assign to the #is_list_type property

  • :is_sortable (BOOLEAN)

    The value to assign to the #is_sortable property

  • :is_filterable (BOOLEAN)

    The value to assign to the #is_filterable property

  • :is_multi_valued (BOOLEAN)

    The value to assign to the #is_multi_valued property

  • :is_hidden (BOOLEAN)

    The value to assign to the #is_hidden property

  • :is_editable (BOOLEAN)

    The value to assign to the #is_editable property

  • :is_shown_in_list (BOOLEAN)

    The value to assign to the #is_shown_in_list property

  • :is_service_defined (BOOLEAN)

    The value to assign to the #is_service_defined property

  • :is_hidden_in_search (BOOLEAN)

    The value to assign to the #is_hidden_in_search property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :time_updated (DateTime)

    The value to assign to the #time_updated property

  • :created_by_id (String)

    The value to assign to the #created_by_id property

  • :updated_by_id (String)

    The value to assign to the #updated_by_id property

  • :usage_count (Integer)

    The value to assign to the #usage_count property

  • :is_event_enabled (BOOLEAN)

    The value to assign to the #is_event_enabled property

  • :scope (Array<OCI::DataCatalog::Models::CustomPropertyTypeUsage>)

    The value to assign to the #scope property

  • :allowed_values (Array<String>)

    The value to assign to the #allowed_values property

  • :events (Array<OCI::DataCatalog::Models::EventConfig>)

    The value to assign to the #events property

  • :properties (Hash<String, Hash<String, String>>)

    The value to assign to the #properties property



238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
# File 'lib/oci/data_catalog/models/custom_property.rb', line 238

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.key = attributes[:'key'] if attributes[:'key']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.data_type = attributes[:'dataType'] if attributes[:'dataType']

  raise 'You cannot provide both :dataType and :data_type' if attributes.key?(:'dataType') && attributes.key?(:'data_type')

  self.data_type = attributes[:'data_type'] if attributes[:'data_type']

  self.description = attributes[:'description'] if attributes[:'description']

  self.namespace_name = attributes[:'namespaceName'] if attributes[:'namespaceName']

  raise 'You cannot provide both :namespaceName and :namespace_name' if attributes.key?(:'namespaceName') && attributes.key?(:'namespace_name')

  self.namespace_name = attributes[:'namespace_name'] if attributes[:'namespace_name']

  self.is_list_type = attributes[:'isListType'] unless attributes[:'isListType'].nil?
  self.is_list_type = false if is_list_type.nil? && !attributes.key?(:'isListType') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isListType and :is_list_type' if attributes.key?(:'isListType') && attributes.key?(:'is_list_type')

  self.is_list_type = attributes[:'is_list_type'] unless attributes[:'is_list_type'].nil?
  self.is_list_type = false if is_list_type.nil? && !attributes.key?(:'isListType') && !attributes.key?(:'is_list_type') # rubocop:disable Style/StringLiterals

  self.is_sortable = attributes[:'isSortable'] unless attributes[:'isSortable'].nil?
  self.is_sortable = false if is_sortable.nil? && !attributes.key?(:'isSortable') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isSortable and :is_sortable' if attributes.key?(:'isSortable') && attributes.key?(:'is_sortable')

  self.is_sortable = attributes[:'is_sortable'] unless attributes[:'is_sortable'].nil?
  self.is_sortable = false if is_sortable.nil? && !attributes.key?(:'isSortable') && !attributes.key?(:'is_sortable') # rubocop:disable Style/StringLiterals

  self.is_filterable = attributes[:'isFilterable'] unless attributes[:'isFilterable'].nil?
  self.is_filterable = false if is_filterable.nil? && !attributes.key?(:'isFilterable') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isFilterable and :is_filterable' if attributes.key?(:'isFilterable') && attributes.key?(:'is_filterable')

  self.is_filterable = attributes[:'is_filterable'] unless attributes[:'is_filterable'].nil?
  self.is_filterable = false if is_filterable.nil? && !attributes.key?(:'isFilterable') && !attributes.key?(:'is_filterable') # rubocop:disable Style/StringLiterals

  self.is_multi_valued = attributes[:'isMultiValued'] unless attributes[:'isMultiValued'].nil?
  self.is_multi_valued = false if is_multi_valued.nil? && !attributes.key?(:'isMultiValued') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isMultiValued and :is_multi_valued' if attributes.key?(:'isMultiValued') && attributes.key?(:'is_multi_valued')

  self.is_multi_valued = attributes[:'is_multi_valued'] unless attributes[:'is_multi_valued'].nil?
  self.is_multi_valued = false if is_multi_valued.nil? && !attributes.key?(:'isMultiValued') && !attributes.key?(:'is_multi_valued') # rubocop:disable Style/StringLiterals

  self.is_hidden = attributes[:'isHidden'] unless attributes[:'isHidden'].nil?
  self.is_hidden = true if is_hidden.nil? && !attributes.key?(:'isHidden') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isHidden and :is_hidden' if attributes.key?(:'isHidden') && attributes.key?(:'is_hidden')

  self.is_hidden = attributes[:'is_hidden'] unless attributes[:'is_hidden'].nil?
  self.is_hidden = true if is_hidden.nil? && !attributes.key?(:'isHidden') && !attributes.key?(:'is_hidden') # rubocop:disable Style/StringLiterals

  self.is_editable = attributes[:'isEditable'] unless attributes[:'isEditable'].nil?
  self.is_editable = true if is_editable.nil? && !attributes.key?(:'isEditable') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isEditable and :is_editable' if attributes.key?(:'isEditable') && attributes.key?(:'is_editable')

  self.is_editable = attributes[:'is_editable'] unless attributes[:'is_editable'].nil?
  self.is_editable = true if is_editable.nil? && !attributes.key?(:'isEditable') && !attributes.key?(:'is_editable') # rubocop:disable Style/StringLiterals

  self.is_shown_in_list = attributes[:'isShownInList'] unless attributes[:'isShownInList'].nil?
  self.is_shown_in_list = false if is_shown_in_list.nil? && !attributes.key?(:'isShownInList') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isShownInList and :is_shown_in_list' if attributes.key?(:'isShownInList') && attributes.key?(:'is_shown_in_list')

  self.is_shown_in_list = attributes[:'is_shown_in_list'] unless attributes[:'is_shown_in_list'].nil?
  self.is_shown_in_list = false if is_shown_in_list.nil? && !attributes.key?(:'isShownInList') && !attributes.key?(:'is_shown_in_list') # rubocop:disable Style/StringLiterals

  self.is_service_defined = attributes[:'isServiceDefined'] unless attributes[:'isServiceDefined'].nil?
  self.is_service_defined = false if is_service_defined.nil? && !attributes.key?(:'isServiceDefined') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isServiceDefined and :is_service_defined' if attributes.key?(:'isServiceDefined') && attributes.key?(:'is_service_defined')

  self.is_service_defined = attributes[:'is_service_defined'] unless attributes[:'is_service_defined'].nil?
  self.is_service_defined = false if is_service_defined.nil? && !attributes.key?(:'isServiceDefined') && !attributes.key?(:'is_service_defined') # rubocop:disable Style/StringLiterals

  self.is_hidden_in_search = attributes[:'isHiddenInSearch'] unless attributes[:'isHiddenInSearch'].nil?
  self.is_hidden_in_search = false if is_hidden_in_search.nil? && !attributes.key?(:'isHiddenInSearch') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isHiddenInSearch and :is_hidden_in_search' if attributes.key?(:'isHiddenInSearch') && attributes.key?(:'is_hidden_in_search')

  self.is_hidden_in_search = attributes[:'is_hidden_in_search'] unless attributes[:'is_hidden_in_search'].nil?
  self.is_hidden_in_search = false if is_hidden_in_search.nil? && !attributes.key?(:'isHiddenInSearch') && !attributes.key?(:'is_hidden_in_search') # rubocop:disable Style/StringLiterals

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.created_by_id = attributes[:'createdById'] if attributes[:'createdById']

  raise 'You cannot provide both :createdById and :created_by_id' if attributes.key?(:'createdById') && attributes.key?(:'created_by_id')

  self.created_by_id = attributes[:'created_by_id'] if attributes[:'created_by_id']

  self.updated_by_id = attributes[:'updatedById'] if attributes[:'updatedById']

  raise 'You cannot provide both :updatedById and :updated_by_id' if attributes.key?(:'updatedById') && attributes.key?(:'updated_by_id')

  self.updated_by_id = attributes[:'updated_by_id'] if attributes[:'updated_by_id']

  self.usage_count = attributes[:'usageCount'] if attributes[:'usageCount']

  raise 'You cannot provide both :usageCount and :usage_count' if attributes.key?(:'usageCount') && attributes.key?(:'usage_count')

  self.usage_count = attributes[:'usage_count'] if attributes[:'usage_count']

  self.is_event_enabled = attributes[:'isEventEnabled'] unless attributes[:'isEventEnabled'].nil?
  self.is_event_enabled = false if is_event_enabled.nil? && !attributes.key?(:'isEventEnabled') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isEventEnabled and :is_event_enabled' if attributes.key?(:'isEventEnabled') && attributes.key?(:'is_event_enabled')

  self.is_event_enabled = attributes[:'is_event_enabled'] unless attributes[:'is_event_enabled'].nil?
  self.is_event_enabled = false if is_event_enabled.nil? && !attributes.key?(:'isEventEnabled') && !attributes.key?(:'is_event_enabled') # rubocop:disable Style/StringLiterals

  self.scope = attributes[:'scope'] if attributes[:'scope']

  self.allowed_values = attributes[:'allowedValues'] if attributes[:'allowedValues']

  raise 'You cannot provide both :allowedValues and :allowed_values' if attributes.key?(:'allowedValues') && attributes.key?(:'allowed_values')

  self.allowed_values = attributes[:'allowed_values'] if attributes[:'allowed_values']

  self.events = attributes[:'events'] if attributes[:'events']

  self.properties = attributes[:'properties'] if attributes[:'properties']
end

Instance Attribute Details

#allowed_valuesArray<String>

Allowed values for the custom property if any

Returns:

  • (Array<String>)


126
127
128
# File 'lib/oci/data_catalog/models/custom_property.rb', line 126

def allowed_values
  @allowed_values
end

#created_by_idString

OCID of the user who created the custom property.

Returns:

  • (String)


106
107
108
# File 'lib/oci/data_catalog/models/custom_property.rb', line 106

def created_by_id
  @created_by_id
end

#data_typeString

Data type of the custom property

Returns:

  • (String)


43
44
45
# File 'lib/oci/data_catalog/models/custom_property.rb', line 43

def data_type
  @data_type
end

#descriptionString

Description for the custom property

Returns:

  • (String)


47
48
49
# File 'lib/oci/data_catalog/models/custom_property.rb', line 47

def description
  @description
end

#display_nameString

Display name of the custom property

Returns:

  • (String)


39
40
41
# File 'lib/oci/data_catalog/models/custom_property.rb', line 39

def display_name
  @display_name
end

#eventsArray<OCI::DataCatalog::Models::EventConfig>

Event configuration for this custom property, against the desired subset of object types to which the property applies.



130
131
132
# File 'lib/oci/data_catalog/models/custom_property.rb', line 130

def events
  @events
end

#is_editableBOOLEAN

If this field is a editable field

Returns:

  • (BOOLEAN)


75
76
77
# File 'lib/oci/data_catalog/models/custom_property.rb', line 75

def is_editable
  @is_editable
end

#is_event_enabledBOOLEAN

If an OCI Event will be emitted when the custom property is modified.

Returns:

  • (BOOLEAN)


118
119
120
# File 'lib/oci/data_catalog/models/custom_property.rb', line 118

def is_event_enabled
  @is_event_enabled
end

#is_filterableBOOLEAN

If this field allows to filter or create facets from UI

Returns:

  • (BOOLEAN)


63
64
65
# File 'lib/oci/data_catalog/models/custom_property.rb', line 63

def is_filterable
  @is_filterable
end

#is_hiddenBOOLEAN

If this field is a hidden field

Returns:

  • (BOOLEAN)


71
72
73
# File 'lib/oci/data_catalog/models/custom_property.rb', line 71

def is_hidden
  @is_hidden
end

#is_hidden_in_searchBOOLEAN

If this field is allowed to pop in search results

Returns:

  • (BOOLEAN)


87
88
89
# File 'lib/oci/data_catalog/models/custom_property.rb', line 87

def is_hidden_in_search
  @is_hidden_in_search
end

#is_list_typeBOOLEAN

Is this property allowed to have list of values

Returns:

  • (BOOLEAN)


55
56
57
# File 'lib/oci/data_catalog/models/custom_property.rb', line 55

def is_list_type
  @is_list_type
end

#is_multi_valuedBOOLEAN

If this field allows multiple values to be set

Returns:

  • (BOOLEAN)


67
68
69
# File 'lib/oci/data_catalog/models/custom_property.rb', line 67

def is_multi_valued
  @is_multi_valued
end

#is_service_definedBOOLEAN

If this field is defined by service or by a user

Returns:

  • (BOOLEAN)


83
84
85
# File 'lib/oci/data_catalog/models/custom_property.rb', line 83

def is_service_defined
  @is_service_defined
end

#is_shown_in_listBOOLEAN

If this field is displayed in a list view of applicable objects.

Returns:

  • (BOOLEAN)


79
80
81
# File 'lib/oci/data_catalog/models/custom_property.rb', line 79

def is_shown_in_list
  @is_shown_in_list
end

#is_sortableBOOLEAN

If this field allows to sort from UI

Returns:

  • (BOOLEAN)


59
60
61
# File 'lib/oci/data_catalog/models/custom_property.rb', line 59

def is_sortable
  @is_sortable
end

#keyString

[Required] Unique data asset key that is immutable.

Returns:

  • (String)


35
36
37
# File 'lib/oci/data_catalog/models/custom_property.rb', line 35

def key
  @key
end

#lifecycle_stateString

The current state of the custom property.

Returns:

  • (String)


91
92
93
# File 'lib/oci/data_catalog/models/custom_property.rb', line 91

def lifecycle_state
  @lifecycle_state
end

#namespace_nameString

Namespace name of the custom property

Returns:

  • (String)


51
52
53
# File 'lib/oci/data_catalog/models/custom_property.rb', line 51

def namespace_name
  @namespace_name
end

#propertiesHash<String, Hash<String, String>>

A map of maps that contains the properties which are specific to the asset type. Each data asset type definition defines it’s set of required and optional properties. The map keys are category names and the values are maps of property name to property value. Every property is contained inside of a category. Most data assets have required properties within the "default" category. Example: ‘{ "default": { "host": "host1", "port": "1521", "database": "orcl"}}`

Returns:

  • (Hash<String, Hash<String, String>>)


139
140
141
# File 'lib/oci/data_catalog/models/custom_property.rb', line 139

def properties
  @properties
end

#scopeArray<OCI::DataCatalog::Models::CustomPropertyTypeUsage>

The set of object types to which the custom property applies.



122
123
124
# File 'lib/oci/data_catalog/models/custom_property.rb', line 122

def scope
  @scope
end

#time_createdDateTime

The date and time the custom property was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339). Example: 2019-03-25T21:10:29.600Z

Returns:

  • (DateTime)


97
98
99
# File 'lib/oci/data_catalog/models/custom_property.rb', line 97

def time_created
  @time_created
end

#time_updatedDateTime

The last time that any change was made to the custom property. An [RFC3339](tools.ietf.org/html/rfc3339) formatted datetime string.

Returns:

  • (DateTime)


102
103
104
# File 'lib/oci/data_catalog/models/custom_property.rb', line 102

def time_updated
  @time_updated
end

#updated_by_idString

OCID of the user who last modified the custom property.

Returns:

  • (String)


110
111
112
# File 'lib/oci/data_catalog/models/custom_property.rb', line 110

def updated_by_id
  @updated_by_id
end

#usage_countInteger

Total number of first class objects using this custom property

Returns:

  • (Integer)


114
115
116
# File 'lib/oci/data_catalog/models/custom_property.rb', line 114

def usage_count
  @usage_count
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/oci/data_catalog/models/custom_property.rb', line 142

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'key',
    'display_name': :'displayName',
    'data_type': :'dataType',
    'description': :'description',
    'namespace_name': :'namespaceName',
    'is_list_type': :'isListType',
    'is_sortable': :'isSortable',
    'is_filterable': :'isFilterable',
    'is_multi_valued': :'isMultiValued',
    'is_hidden': :'isHidden',
    'is_editable': :'isEditable',
    'is_shown_in_list': :'isShownInList',
    'is_service_defined': :'isServiceDefined',
    'is_hidden_in_search': :'isHiddenInSearch',
    'lifecycle_state': :'lifecycleState',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'created_by_id': :'createdById',
    'updated_by_id': :'updatedById',
    'usage_count': :'usageCount',
    'is_event_enabled': :'isEventEnabled',
    'scope': :'scope',
    'allowed_values': :'allowedValues',
    'events': :'events',
    'properties': :'properties'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/oci/data_catalog/models/custom_property.rb', line 175

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'String',
    'display_name': :'String',
    'data_type': :'String',
    'description': :'String',
    'namespace_name': :'String',
    'is_list_type': :'BOOLEAN',
    'is_sortable': :'BOOLEAN',
    'is_filterable': :'BOOLEAN',
    'is_multi_valued': :'BOOLEAN',
    'is_hidden': :'BOOLEAN',
    'is_editable': :'BOOLEAN',
    'is_shown_in_list': :'BOOLEAN',
    'is_service_defined': :'BOOLEAN',
    'is_hidden_in_search': :'BOOLEAN',
    'lifecycle_state': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'created_by_id': :'String',
    'updated_by_id': :'String',
    'usage_count': :'Integer',
    'is_event_enabled': :'BOOLEAN',
    'scope': :'Array<OCI::DataCatalog::Models::CustomPropertyTypeUsage>',
    'allowed_values': :'Array<String>',
    'events': :'Array<OCI::DataCatalog::Models::EventConfig>',
    'properties': :'Hash<String, Hash<String, String>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
# File 'lib/oci/data_catalog/models/custom_property.rb', line 428

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    key == other.key &&
    display_name == other.display_name &&
    data_type == other.data_type &&
    description == other.description &&
    namespace_name == other.namespace_name &&
    is_list_type == other.is_list_type &&
    is_sortable == other.is_sortable &&
    is_filterable == other.is_filterable &&
    is_multi_valued == other.is_multi_valued &&
    is_hidden == other.is_hidden &&
    is_editable == other.is_editable &&
    is_shown_in_list == other.is_shown_in_list &&
    is_service_defined == other.is_service_defined &&
    is_hidden_in_search == other.is_hidden_in_search &&
    lifecycle_state == other.lifecycle_state &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    created_by_id == other.created_by_id &&
    updated_by_id == other.updated_by_id &&
    usage_count == other.usage_count &&
    is_event_enabled == other.is_event_enabled &&
    scope == other.scope &&
    allowed_values == other.allowed_values &&
    events == other.events &&
    properties == other.properties
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
# File 'lib/oci/data_catalog/models/custom_property.rb', line 482

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


462
463
464
# File 'lib/oci/data_catalog/models/custom_property.rb', line 462

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



471
472
473
# File 'lib/oci/data_catalog/models/custom_property.rb', line 471

def hash
  [key, display_name, data_type, description, namespace_name, is_list_type, is_sortable, is_filterable, is_multi_valued, is_hidden, is_editable, is_shown_in_list, is_service_defined, is_hidden_in_search, lifecycle_state, time_created, time_updated, created_by_id, updated_by_id, usage_count, is_event_enabled, scope, allowed_values, events, properties].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



515
516
517
518
519
520
521
522
523
524
# File 'lib/oci/data_catalog/models/custom_property.rb', line 515

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



509
510
511
# File 'lib/oci/data_catalog/models/custom_property.rb', line 509

def to_s
  to_hash.to_s
end