Class: OCI::DataCatalog::Models::CustomPropertySummary
- Inherits:
-
Object
- Object
- OCI::DataCatalog::Models::CustomPropertySummary
- Defined in:
- lib/oci/data_catalog/models/custom_property_summary.rb
Overview
Summary of a custom property
Constant Summary collapse
- DATA_TYPE_ENUM =
[ DATA_TYPE_TEXT = 'TEXT'.freeze, DATA_TYPE_RICH_TEXT = 'RICH_TEXT'.freeze, DATA_TYPE_BOOLEAN = 'BOOLEAN'.freeze, DATA_TYPE_NUMBER = 'NUMBER'.freeze, DATA_TYPE_DATE = 'DATE'.freeze, DATA_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_MOVING = 'MOVING'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#allowed_values ⇒ Array<String>
Allowed values for the custom property if any.
-
#data_type ⇒ String
Data type of the custom property.
-
#description ⇒ String
Description of the custom property.
-
#display_name ⇒ String
Display name of the custom property.
-
#is_editable ⇒ BOOLEAN
If this field is a editable field.
-
#is_filterable ⇒ BOOLEAN
If this field allows to filter or create facets from UI.
-
#is_hidden ⇒ BOOLEAN
If this field is a hidden field.
-
#is_hidden_in_search ⇒ BOOLEAN
If this field is allowed to pop in search results.
-
#is_multi_valued ⇒ BOOLEAN
If this field allows multiple values to be set.
-
#is_service_defined ⇒ BOOLEAN
If this field is defined by service or by a user.
-
#is_shown_in_list ⇒ BOOLEAN
If this field is displayed in a list view of applicable objects.
-
#is_sortable ⇒ BOOLEAN
If this field allows to sort from UI.
-
#key ⇒ String
[Required] Unique custom property key that is immutable.
-
#lifecycle_state ⇒ String
The current state of the custom property.
-
#namespace_name ⇒ String
Namespace name of the custom property.
-
#scope ⇒ Array<OCI::DataCatalog::Models::CustomPropertyTypeUsage>
Type or scope of the custom property belongs to.
-
#time_created ⇒ DateTime
The date and time the custom property was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#usage_count ⇒ Integer
Total number of first class objects using this custom property.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CustomPropertySummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CustomPropertySummary
Initializes the object
184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 |
# File 'lib/oci/data_catalog/models/custom_property_summary.rb', line 184 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.key = attributes[:'key'] if attributes[:'key'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.data_type = attributes[:'dataType'] if attributes[:'dataType'] raise 'You cannot provide both :dataType and :data_type' if attributes.key?(:'dataType') && attributes.key?(:'data_type') self.data_type = attributes[:'data_type'] if attributes[:'data_type'] self.namespace_name = attributes[:'namespaceName'] if attributes[:'namespaceName'] raise 'You cannot provide both :namespaceName and :namespace_name' if attributes.key?(:'namespaceName') && attributes.key?(:'namespace_name') self.namespace_name = attributes[:'namespace_name'] if attributes[:'namespace_name'] self.is_sortable = attributes[:'isSortable'] unless attributes[:'isSortable'].nil? self.is_sortable = false if is_sortable.nil? && !attributes.key?(:'isSortable') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isSortable and :is_sortable' if attributes.key?(:'isSortable') && attributes.key?(:'is_sortable') self.is_sortable = attributes[:'is_sortable'] unless attributes[:'is_sortable'].nil? self.is_sortable = false if is_sortable.nil? && !attributes.key?(:'isSortable') && !attributes.key?(:'is_sortable') # rubocop:disable Style/StringLiterals self.is_filterable = attributes[:'isFilterable'] unless attributes[:'isFilterable'].nil? self.is_filterable = false if is_filterable.nil? && !attributes.key?(:'isFilterable') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isFilterable and :is_filterable' if attributes.key?(:'isFilterable') && attributes.key?(:'is_filterable') self.is_filterable = attributes[:'is_filterable'] unless attributes[:'is_filterable'].nil? self.is_filterable = false if is_filterable.nil? && !attributes.key?(:'isFilterable') && !attributes.key?(:'is_filterable') # rubocop:disable Style/StringLiterals self.is_multi_valued = attributes[:'isMultiValued'] unless attributes[:'isMultiValued'].nil? self.is_multi_valued = false if is_multi_valued.nil? && !attributes.key?(:'isMultiValued') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isMultiValued and :is_multi_valued' if attributes.key?(:'isMultiValued') && attributes.key?(:'is_multi_valued') self.is_multi_valued = attributes[:'is_multi_valued'] unless attributes[:'is_multi_valued'].nil? self.is_multi_valued = false if is_multi_valued.nil? && !attributes.key?(:'isMultiValued') && !attributes.key?(:'is_multi_valued') # rubocop:disable Style/StringLiterals self.is_hidden = attributes[:'isHidden'] unless attributes[:'isHidden'].nil? self.is_hidden = true if is_hidden.nil? && !attributes.key?(:'isHidden') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isHidden and :is_hidden' if attributes.key?(:'isHidden') && attributes.key?(:'is_hidden') self.is_hidden = attributes[:'is_hidden'] unless attributes[:'is_hidden'].nil? self.is_hidden = true if is_hidden.nil? && !attributes.key?(:'isHidden') && !attributes.key?(:'is_hidden') # rubocop:disable Style/StringLiterals self.is_editable = attributes[:'isEditable'] unless attributes[:'isEditable'].nil? self.is_editable = true if is_editable.nil? && !attributes.key?(:'isEditable') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isEditable and :is_editable' if attributes.key?(:'isEditable') && attributes.key?(:'is_editable') self.is_editable = attributes[:'is_editable'] unless attributes[:'is_editable'].nil? self.is_editable = true if is_editable.nil? && !attributes.key?(:'isEditable') && !attributes.key?(:'is_editable') # rubocop:disable Style/StringLiterals self.is_shown_in_list = attributes[:'isShownInList'] unless attributes[:'isShownInList'].nil? self.is_shown_in_list = false if is_shown_in_list.nil? && !attributes.key?(:'isShownInList') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isShownInList and :is_shown_in_list' if attributes.key?(:'isShownInList') && attributes.key?(:'is_shown_in_list') self.is_shown_in_list = attributes[:'is_shown_in_list'] unless attributes[:'is_shown_in_list'].nil? self.is_shown_in_list = false if is_shown_in_list.nil? && !attributes.key?(:'isShownInList') && !attributes.key?(:'is_shown_in_list') # rubocop:disable Style/StringLiterals self.is_service_defined = attributes[:'isServiceDefined'] unless attributes[:'isServiceDefined'].nil? self.is_service_defined = false if is_service_defined.nil? && !attributes.key?(:'isServiceDefined') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isServiceDefined and :is_service_defined' if attributes.key?(:'isServiceDefined') && attributes.key?(:'is_service_defined') self.is_service_defined = attributes[:'is_service_defined'] unless attributes[:'is_service_defined'].nil? self.is_service_defined = false if is_service_defined.nil? && !attributes.key?(:'isServiceDefined') && !attributes.key?(:'is_service_defined') # rubocop:disable Style/StringLiterals self.is_hidden_in_search = attributes[:'isHiddenInSearch'] unless attributes[:'isHiddenInSearch'].nil? self.is_hidden_in_search = false if is_hidden_in_search.nil? && !attributes.key?(:'isHiddenInSearch') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isHiddenInSearch and :is_hidden_in_search' if attributes.key?(:'isHiddenInSearch') && attributes.key?(:'is_hidden_in_search') self.is_hidden_in_search = attributes[:'is_hidden_in_search'] unless attributes[:'is_hidden_in_search'].nil? self.is_hidden_in_search = false if is_hidden_in_search.nil? && !attributes.key?(:'isHiddenInSearch') && !attributes.key?(:'is_hidden_in_search') # rubocop:disable Style/StringLiterals self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.usage_count = attributes[:'usageCount'] if attributes[:'usageCount'] raise 'You cannot provide both :usageCount and :usage_count' if attributes.key?(:'usageCount') && attributes.key?(:'usage_count') self.usage_count = attributes[:'usage_count'] if attributes[:'usage_count'] self.scope = attributes[:'scope'] if attributes[:'scope'] self.allowed_values = attributes[:'allowedValues'] if attributes[:'allowedValues'] raise 'You cannot provide both :allowedValues and :allowed_values' if attributes.key?(:'allowedValues') && attributes.key?(:'allowed_values') self.allowed_values = attributes[:'allowed_values'] if attributes[:'allowed_values'] end |
Instance Attribute Details
#allowed_values ⇒ Array<String>
Allowed values for the custom property if any
106 107 108 |
# File 'lib/oci/data_catalog/models/custom_property_summary.rb', line 106 def allowed_values @allowed_values end |
#data_type ⇒ String
Data type of the custom property
47 48 49 |
# File 'lib/oci/data_catalog/models/custom_property_summary.rb', line 47 def data_type @data_type end |
#description ⇒ String
Description of the custom property
43 44 45 |
# File 'lib/oci/data_catalog/models/custom_property_summary.rb', line 43 def description @description end |
#display_name ⇒ String
Display name of the custom property
39 40 41 |
# File 'lib/oci/data_catalog/models/custom_property_summary.rb', line 39 def display_name @display_name end |
#is_editable ⇒ BOOLEAN
If this field is a editable field
71 72 73 |
# File 'lib/oci/data_catalog/models/custom_property_summary.rb', line 71 def is_editable @is_editable end |
#is_filterable ⇒ BOOLEAN
If this field allows to filter or create facets from UI
59 60 61 |
# File 'lib/oci/data_catalog/models/custom_property_summary.rb', line 59 def is_filterable @is_filterable end |
#is_hidden ⇒ BOOLEAN
If this field is a hidden field
67 68 69 |
# File 'lib/oci/data_catalog/models/custom_property_summary.rb', line 67 def is_hidden @is_hidden end |
#is_hidden_in_search ⇒ BOOLEAN
If this field is allowed to pop in search results
83 84 85 |
# File 'lib/oci/data_catalog/models/custom_property_summary.rb', line 83 def is_hidden_in_search @is_hidden_in_search end |
#is_multi_valued ⇒ BOOLEAN
If this field allows multiple values to be set
63 64 65 |
# File 'lib/oci/data_catalog/models/custom_property_summary.rb', line 63 def is_multi_valued @is_multi_valued end |
#is_service_defined ⇒ BOOLEAN
If this field is defined by service or by a user
79 80 81 |
# File 'lib/oci/data_catalog/models/custom_property_summary.rb', line 79 def is_service_defined @is_service_defined end |
#is_shown_in_list ⇒ BOOLEAN
If this field is displayed in a list view of applicable objects.
75 76 77 |
# File 'lib/oci/data_catalog/models/custom_property_summary.rb', line 75 def is_shown_in_list @is_shown_in_list end |
#is_sortable ⇒ BOOLEAN
If this field allows to sort from UI
55 56 57 |
# File 'lib/oci/data_catalog/models/custom_property_summary.rb', line 55 def is_sortable @is_sortable end |
#key ⇒ String
[Required] Unique custom property key that is immutable.
35 36 37 |
# File 'lib/oci/data_catalog/models/custom_property_summary.rb', line 35 def key @key end |
#lifecycle_state ⇒ String
The current state of the custom property.
93 94 95 |
# File 'lib/oci/data_catalog/models/custom_property_summary.rb', line 93 def lifecycle_state @lifecycle_state end |
#namespace_name ⇒ String
Namespace name of the custom property
51 52 53 |
# File 'lib/oci/data_catalog/models/custom_property_summary.rb', line 51 def namespace_name @namespace_name end |
#scope ⇒ Array<OCI::DataCatalog::Models::CustomPropertyTypeUsage>
Type or scope of the custom property belongs to. This will be an array of type id it will be belongs to
102 103 104 |
# File 'lib/oci/data_catalog/models/custom_property_summary.rb', line 102 def scope @scope end |
#time_created ⇒ DateTime
The date and time the custom property was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339). Example: 2019-03-25T21:10:29.600Z
89 90 91 |
# File 'lib/oci/data_catalog/models/custom_property_summary.rb', line 89 def time_created @time_created end |
#usage_count ⇒ Integer
Total number of first class objects using this custom property
97 98 99 |
# File 'lib/oci/data_catalog/models/custom_property_summary.rb', line 97 def usage_count @usage_count end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/oci/data_catalog/models/custom_property_summary.rb', line 109 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'key': :'key', 'display_name': :'displayName', 'description': :'description', 'data_type': :'dataType', 'namespace_name': :'namespaceName', 'is_sortable': :'isSortable', 'is_filterable': :'isFilterable', 'is_multi_valued': :'isMultiValued', 'is_hidden': :'isHidden', 'is_editable': :'isEditable', 'is_shown_in_list': :'isShownInList', 'is_service_defined': :'isServiceDefined', 'is_hidden_in_search': :'isHiddenInSearch', 'time_created': :'timeCreated', 'lifecycle_state': :'lifecycleState', 'usage_count': :'usageCount', 'scope': :'scope', 'allowed_values': :'allowedValues' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/oci/data_catalog/models/custom_property_summary.rb', line 135 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'key': :'String', 'display_name': :'String', 'description': :'String', 'data_type': :'String', 'namespace_name': :'String', 'is_sortable': :'BOOLEAN', 'is_filterable': :'BOOLEAN', 'is_multi_valued': :'BOOLEAN', 'is_hidden': :'BOOLEAN', 'is_editable': :'BOOLEAN', 'is_shown_in_list': :'BOOLEAN', 'is_service_defined': :'BOOLEAN', 'is_hidden_in_search': :'BOOLEAN', 'time_created': :'DateTime', 'lifecycle_state': :'String', 'usage_count': :'Integer', 'scope': :'Array<OCI::DataCatalog::Models::CustomPropertyTypeUsage>', 'allowed_values': :'Array<String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 |
# File 'lib/oci/data_catalog/models/custom_property_summary.rb', line 336 def ==(other) return true if equal?(other) self.class == other.class && key == other.key && display_name == other.display_name && description == other.description && data_type == other.data_type && namespace_name == other.namespace_name && is_sortable == other.is_sortable && is_filterable == other.is_filterable && is_multi_valued == other.is_multi_valued && is_hidden == other.is_hidden && is_editable == other.is_editable && is_shown_in_list == other.is_shown_in_list && is_service_defined == other.is_service_defined && is_hidden_in_search == other.is_hidden_in_search && time_created == other.time_created && lifecycle_state == other.lifecycle_state && usage_count == other.usage_count && scope == other.scope && allowed_values == other.allowed_values end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 |
# File 'lib/oci/data_catalog/models/custom_property_summary.rb', line 383 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
363 364 365 |
# File 'lib/oci/data_catalog/models/custom_property_summary.rb', line 363 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
372 373 374 |
# File 'lib/oci/data_catalog/models/custom_property_summary.rb', line 372 def hash [key, display_name, description, data_type, namespace_name, is_sortable, is_filterable, is_multi_valued, is_hidden, is_editable, is_shown_in_list, is_service_defined, is_hidden_in_search, time_created, lifecycle_state, usage_count, scope, allowed_values].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
416 417 418 419 420 421 422 423 424 425 |
# File 'lib/oci/data_catalog/models/custom_property_summary.rb', line 416 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
410 411 412 |
# File 'lib/oci/data_catalog/models/custom_property_summary.rb', line 410 def to_s to_hash.to_s end |