Class: OCI::DataCatalog::Models::DataAsset
- Inherits:
-
Object
- Object
- OCI::DataCatalog::Models::DataAsset
- Defined in:
- lib/oci/data_catalog/models/data_asset.rb
Overview
Data asset representation. A physical store, or stream, of data known to the data catalog and containing one or many data entities, possibly in an organized structure of folders. A data asset is often synonymous with a ‘System’, such as a database, or may be a file container or a message stream.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_MOVING = 'MOVING'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The data catalog’s OCID.
-
#created_by_id ⇒ String
OCID of the user who created the data asset.
-
#custom_property_members ⇒ Array<OCI::DataCatalog::Models::CustomPropertyGetUsage>
The list of customized properties along with the values for this object.
-
#data_selector_patterns ⇒ Array<OCI::DataCatalog::Models::PatternSummary>
The list of data selector patterns used in the harvest for this data asset to derive logical entities.
-
#description ⇒ String
Detailed description of the data asset.
-
#display_name ⇒ String
A user-friendly display name.
-
#external_key ⇒ String
External URI that can be used to reference the object.
-
#key ⇒ String
[Required] Unique data asset key that is immutable.
-
#lifecycle_state ⇒ String
The current state of the data asset.
-
#properties ⇒ Hash<String, Hash<String, String>>
A map of maps that contains the properties which are specific to the asset type.
-
#time_created ⇒ DateTime
The date and time the data asset was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#time_harvested ⇒ DateTime
The last time that a harvest was performed on the data asset.
-
#time_updated ⇒ DateTime
The last time that any change was made to the data asset.
-
#type_key ⇒ String
The key of the object type.
-
#updated_by_id ⇒ String
OCID of the user who last modified the data asset.
-
#uri ⇒ String
URI to the data asset instance in the API.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DataAsset
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DataAsset
Initializes the object
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/oci/data_catalog/models/data_asset.rb', line 172 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.key = attributes[:'key'] if attributes[:'key'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.catalog_id = attributes[:'catalogId'] if attributes[:'catalogId'] raise 'You cannot provide both :catalogId and :catalog_id' if attributes.key?(:'catalogId') && attributes.key?(:'catalog_id') self.catalog_id = attributes[:'catalog_id'] if attributes[:'catalog_id'] self.external_key = attributes[:'externalKey'] if attributes[:'externalKey'] raise 'You cannot provide both :externalKey and :external_key' if attributes.key?(:'externalKey') && attributes.key?(:'external_key') self.external_key = attributes[:'external_key'] if attributes[:'external_key'] self.type_key = attributes[:'typeKey'] if attributes[:'typeKey'] raise 'You cannot provide both :typeKey and :type_key' if attributes.key?(:'typeKey') && attributes.key?(:'type_key') self.type_key = attributes[:'type_key'] if attributes[:'type_key'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.time_harvested = attributes[:'timeHarvested'] if attributes[:'timeHarvested'] raise 'You cannot provide both :timeHarvested and :time_harvested' if attributes.key?(:'timeHarvested') && attributes.key?(:'time_harvested') self.time_harvested = attributes[:'time_harvested'] if attributes[:'time_harvested'] self.created_by_id = attributes[:'createdById'] if attributes[:'createdById'] raise 'You cannot provide both :createdById and :created_by_id' if attributes.key?(:'createdById') && attributes.key?(:'created_by_id') self.created_by_id = attributes[:'created_by_id'] if attributes[:'created_by_id'] self.updated_by_id = attributes[:'updatedById'] if attributes[:'updatedById'] raise 'You cannot provide both :updatedById and :updated_by_id' if attributes.key?(:'updatedById') && attributes.key?(:'updated_by_id') self.updated_by_id = attributes[:'updated_by_id'] if attributes[:'updated_by_id'] self.uri = attributes[:'uri'] if attributes[:'uri'] self.custom_property_members = attributes[:'customPropertyMembers'] if attributes[:'customPropertyMembers'] raise 'You cannot provide both :customPropertyMembers and :custom_property_members' if attributes.key?(:'customPropertyMembers') && attributes.key?(:'custom_property_members') self.custom_property_members = attributes[:'custom_property_members'] if attributes[:'custom_property_members'] self.data_selector_patterns = attributes[:'dataSelectorPatterns'] if attributes[:'dataSelectorPatterns'] raise 'You cannot provide both :dataSelectorPatterns and :data_selector_patterns' if attributes.key?(:'dataSelectorPatterns') && attributes.key?(:'data_selector_patterns') self.data_selector_patterns = attributes[:'data_selector_patterns'] if attributes[:'data_selector_patterns'] self.properties = attributes[:'properties'] if attributes[:'properties'] end |
Instance Attribute Details
#catalog_id ⇒ String
The data catalog’s OCID.
42 43 44 |
# File 'lib/oci/data_catalog/models/data_asset.rb', line 42 def catalog_id @catalog_id end |
#created_by_id ⇒ String
OCID of the user who created the data asset.
75 76 77 |
# File 'lib/oci/data_catalog/models/data_asset.rb', line 75 def created_by_id @created_by_id end |
#custom_property_members ⇒ Array<OCI::DataCatalog::Models::CustomPropertyGetUsage>
The list of customized properties along with the values for this object
87 88 89 |
# File 'lib/oci/data_catalog/models/data_asset.rb', line 87 def custom_property_members @custom_property_members end |
#data_selector_patterns ⇒ Array<OCI::DataCatalog::Models::PatternSummary>
The list of data selector patterns used in the harvest for this data asset to derive logical entities.
91 92 93 |
# File 'lib/oci/data_catalog/models/data_asset.rb', line 91 def data_selector_patterns @data_selector_patterns end |
#description ⇒ String
Detailed description of the data asset.
38 39 40 |
# File 'lib/oci/data_catalog/models/data_asset.rb', line 38 def description @description end |
#display_name ⇒ String
A user-friendly display name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
34 35 36 |
# File 'lib/oci/data_catalog/models/data_asset.rb', line 34 def display_name @display_name end |
#external_key ⇒ String
External URI that can be used to reference the object. Format will differ based on the type of object.
47 48 49 |
# File 'lib/oci/data_catalog/models/data_asset.rb', line 47 def external_key @external_key end |
#key ⇒ String
[Required] Unique data asset key that is immutable.
28 29 30 |
# File 'lib/oci/data_catalog/models/data_asset.rb', line 28 def key @key end |
#lifecycle_state ⇒ String
The current state of the data asset.
55 56 57 |
# File 'lib/oci/data_catalog/models/data_asset.rb', line 55 def lifecycle_state @lifecycle_state end |
#properties ⇒ Hash<String, Hash<String, String>>
A map of maps that contains the properties which are specific to the asset type. Each data asset type definition defines it’s set of required and optional properties. The map keys are category names and the values are maps of property name to property value. Every property is contained inside of a category. Most data assets have required properties within the "default" category. Example: ‘{ "default": { "host": "host1", "port": "1521", "database": "orcl"}}`
100 101 102 |
# File 'lib/oci/data_catalog/models/data_asset.rb', line 100 def properties @properties end |
#time_created ⇒ DateTime
The date and time the data asset was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339). Example: 2019-03-25T21:10:29.600Z
61 62 63 |
# File 'lib/oci/data_catalog/models/data_asset.rb', line 61 def time_created @time_created end |
#time_harvested ⇒ DateTime
The last time that a harvest was performed on the data asset. An [RFC3339](tools.ietf.org/html/rfc3339) formatted datetime string.
71 72 73 |
# File 'lib/oci/data_catalog/models/data_asset.rb', line 71 def time_harvested @time_harvested end |
#time_updated ⇒ DateTime
The last time that any change was made to the data asset. An [RFC3339](tools.ietf.org/html/rfc3339) formatted datetime string.
66 67 68 |
# File 'lib/oci/data_catalog/models/data_asset.rb', line 66 def time_updated @time_updated end |
#type_key ⇒ String
The key of the object type. Type key’s can be found via the ‘/types’ endpoint.
51 52 53 |
# File 'lib/oci/data_catalog/models/data_asset.rb', line 51 def type_key @type_key end |
#updated_by_id ⇒ String
OCID of the user who last modified the data asset.
79 80 81 |
# File 'lib/oci/data_catalog/models/data_asset.rb', line 79 def updated_by_id @updated_by_id end |
#uri ⇒ String
URI to the data asset instance in the API.
83 84 85 |
# File 'lib/oci/data_catalog/models/data_asset.rb', line 83 def uri @uri end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/oci/data_catalog/models/data_asset.rb', line 103 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'key': :'key', 'display_name': :'displayName', 'description': :'description', 'catalog_id': :'catalogId', 'external_key': :'externalKey', 'type_key': :'typeKey', 'lifecycle_state': :'lifecycleState', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'time_harvested': :'timeHarvested', 'created_by_id': :'createdById', 'updated_by_id': :'updatedById', 'uri': :'uri', 'custom_property_members': :'customPropertyMembers', 'data_selector_patterns': :'dataSelectorPatterns', 'properties': :'properties' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/oci/data_catalog/models/data_asset.rb', line 127 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'key': :'String', 'display_name': :'String', 'description': :'String', 'catalog_id': :'String', 'external_key': :'String', 'type_key': :'String', 'lifecycle_state': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'time_harvested': :'DateTime', 'created_by_id': :'String', 'updated_by_id': :'String', 'uri': :'String', 'custom_property_members': :'Array<OCI::DataCatalog::Models::CustomPropertyGetUsage>', 'data_selector_patterns': :'Array<OCI::DataCatalog::Models::PatternSummary>', 'properties': :'Hash<String, Hash<String, String>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/oci/data_catalog/models/data_asset.rb', line 279 def ==(other) return true if equal?(other) self.class == other.class && key == other.key && display_name == other.display_name && description == other.description && catalog_id == other.catalog_id && external_key == other.external_key && type_key == other.type_key && lifecycle_state == other.lifecycle_state && time_created == other.time_created && time_updated == other.time_updated && time_harvested == other.time_harvested && created_by_id == other.created_by_id && updated_by_id == other.updated_by_id && uri == other.uri && custom_property_members == other.custom_property_members && data_selector_patterns == other.data_selector_patterns && properties == other.properties end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 |
# File 'lib/oci/data_catalog/models/data_asset.rb', line 324 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
304 305 306 |
# File 'lib/oci/data_catalog/models/data_asset.rb', line 304 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
313 314 315 |
# File 'lib/oci/data_catalog/models/data_asset.rb', line 313 def hash [key, display_name, description, catalog_id, external_key, type_key, lifecycle_state, time_created, time_updated, time_harvested, created_by_id, updated_by_id, uri, custom_property_members, data_selector_patterns, properties].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
357 358 359 360 361 362 363 364 365 366 |
# File 'lib/oci/data_catalog/models/data_asset.rb', line 357 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
351 352 353 |
# File 'lib/oci/data_catalog/models/data_asset.rb', line 351 def to_s to_hash.to_s end |