Class: OCI::DataCatalog::Models::DataAssetSummary
- Inherits:
-
Object
- Object
- OCI::DataCatalog::Models::DataAssetSummary
- Defined in:
- lib/oci/data_catalog/models/data_asset_summary.rb
Overview
Summary of a data asset. A physical store, or stream, of data known to the data catalog and containing one or many data entities, possibly in an organized structure of folders. A data asset is often synonymous with a ‘System’, such as a database, or may be a file container or a message stream.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_MOVING = 'MOVING'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The data catalog’s OCID.
-
#description ⇒ String
Detailed description of the data asset.
-
#display_name ⇒ String
A user-friendly display name.
-
#external_key ⇒ String
External URI that can be used to reference the object.
-
#key ⇒ String
[Required] Unique data asset key that is immutable.
-
#lifecycle_state ⇒ String
State of the data asset.
-
#time_created ⇒ DateTime
The date and time the data asset was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#type_key ⇒ String
The key of the object type.
-
#uri ⇒ String
URI to the data asset instance in the API.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DataAssetSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DataAssetSummary
Initializes the object
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/oci/data_catalog/models/data_asset_summary.rb', line 116 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.key = attributes[:'key'] if attributes[:'key'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.catalog_id = attributes[:'catalogId'] if attributes[:'catalogId'] raise 'You cannot provide both :catalogId and :catalog_id' if attributes.key?(:'catalogId') && attributes.key?(:'catalog_id') self.catalog_id = attributes[:'catalog_id'] if attributes[:'catalog_id'] self.external_key = attributes[:'externalKey'] if attributes[:'externalKey'] raise 'You cannot provide both :externalKey and :external_key' if attributes.key?(:'externalKey') && attributes.key?(:'external_key') self.external_key = attributes[:'external_key'] if attributes[:'external_key'] self.uri = attributes[:'uri'] if attributes[:'uri'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.type_key = attributes[:'typeKey'] if attributes[:'typeKey'] raise 'You cannot provide both :typeKey and :type_key' if attributes.key?(:'typeKey') && attributes.key?(:'type_key') self.type_key = attributes[:'type_key'] if attributes[:'type_key'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] end |
Instance Attribute Details
#catalog_id ⇒ String
The data catalog’s OCID.
42 43 44 |
# File 'lib/oci/data_catalog/models/data_asset_summary.rb', line 42 def catalog_id @catalog_id end |
#description ⇒ String
Detailed description of the data asset.
38 39 40 |
# File 'lib/oci/data_catalog/models/data_asset_summary.rb', line 38 def description @description end |
#display_name ⇒ String
A user-friendly display name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
34 35 36 |
# File 'lib/oci/data_catalog/models/data_asset_summary.rb', line 34 def display_name @display_name end |
#external_key ⇒ String
External URI that can be used to reference the object. Format will differ based on the type of object.
47 48 49 |
# File 'lib/oci/data_catalog/models/data_asset_summary.rb', line 47 def external_key @external_key end |
#key ⇒ String
[Required] Unique data asset key that is immutable.
28 29 30 |
# File 'lib/oci/data_catalog/models/data_asset_summary.rb', line 28 def key @key end |
#lifecycle_state ⇒ String
State of the data asset.
65 66 67 |
# File 'lib/oci/data_catalog/models/data_asset_summary.rb', line 65 def lifecycle_state @lifecycle_state end |
#time_created ⇒ DateTime
The date and time the data asset was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339). Example: 2019-03-25T21:10:29.600Z
57 58 59 |
# File 'lib/oci/data_catalog/models/data_asset_summary.rb', line 57 def time_created @time_created end |
#type_key ⇒ String
The key of the object type. Type keys’s can be found via the ‘/types’ endpoint.
61 62 63 |
# File 'lib/oci/data_catalog/models/data_asset_summary.rb', line 61 def type_key @type_key end |
#uri ⇒ String
URI to the data asset instance in the API.
51 52 53 |
# File 'lib/oci/data_catalog/models/data_asset_summary.rb', line 51 def uri @uri end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/oci/data_catalog/models/data_asset_summary.rb', line 68 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'key': :'key', 'display_name': :'displayName', 'description': :'description', 'catalog_id': :'catalogId', 'external_key': :'externalKey', 'uri': :'uri', 'time_created': :'timeCreated', 'type_key': :'typeKey', 'lifecycle_state': :'lifecycleState' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/oci/data_catalog/models/data_asset_summary.rb', line 85 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'key': :'String', 'display_name': :'String', 'description': :'String', 'catalog_id': :'String', 'external_key': :'String', 'uri': :'String', 'time_created': :'DateTime', 'type_key': :'String', 'lifecycle_state': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/oci/data_catalog/models/data_asset_summary.rb', line 185 def ==(other) return true if equal?(other) self.class == other.class && key == other.key && display_name == other.display_name && description == other.description && catalog_id == other.catalog_id && external_key == other.external_key && uri == other.uri && time_created == other.time_created && type_key == other.type_key && lifecycle_state == other.lifecycle_state end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/oci/data_catalog/models/data_asset_summary.rb', line 223 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
203 204 205 |
# File 'lib/oci/data_catalog/models/data_asset_summary.rb', line 203 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
212 213 214 |
# File 'lib/oci/data_catalog/models/data_asset_summary.rb', line 212 def hash [key, display_name, description, catalog_id, external_key, uri, time_created, type_key, lifecycle_state].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
256 257 258 259 260 261 262 263 264 265 |
# File 'lib/oci/data_catalog/models/data_asset_summary.rb', line 256 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
250 251 252 |
# File 'lib/oci/data_catalog/models/data_asset_summary.rb', line 250 def to_s to_hash.to_s end |