Class: OCI::DataCatalog::Models::Folder

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_catalog/models/folder.rb

Overview

A generic term used in the data catalog for an external organization concept used for a collection of data entities or processes within a data asset. This term is an internal term which models multiple external types of folder, such as file directories, database schemas, and so on. Some data assets, such as Object Store containers, may contain many levels of folders.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_MOVING = 'MOVING'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
HARVEST_STATUS_ENUM =
[
  HARVEST_STATUS_COMPLETE = 'COMPLETE'.freeze,
  HARVEST_STATUS_ERROR = 'ERROR'.freeze,
  HARVEST_STATUS_IN_PROGRESS = 'IN_PROGRESS'.freeze,
  HARVEST_STATUS_DEFERRED = 'DEFERRED'.freeze,
  HARVEST_STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Folder

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
# File 'lib/oci/data_catalog/models/folder.rb', line 222

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.key = attributes[:'key'] if attributes[:'key']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.business_name = attributes[:'businessName'] if attributes[:'businessName']

  raise 'You cannot provide both :businessName and :business_name' if attributes.key?(:'businessName') && attributes.key?(:'business_name')

  self.business_name = attributes[:'business_name'] if attributes[:'business_name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.parent_folder_key = attributes[:'parentFolderKey'] if attributes[:'parentFolderKey']

  raise 'You cannot provide both :parentFolderKey and :parent_folder_key' if attributes.key?(:'parentFolderKey') && attributes.key?(:'parent_folder_key')

  self.parent_folder_key = attributes[:'parent_folder_key'] if attributes[:'parent_folder_key']

  self.type_key = attributes[:'typeKey'] if attributes[:'typeKey']

  raise 'You cannot provide both :typeKey and :type_key' if attributes.key?(:'typeKey') && attributes.key?(:'type_key')

  self.type_key = attributes[:'type_key'] if attributes[:'type_key']

  self.time_harvested = attributes[:'timeHarvested'] if attributes[:'timeHarvested']

  raise 'You cannot provide both :timeHarvested and :time_harvested' if attributes.key?(:'timeHarvested') && attributes.key?(:'time_harvested')

  self.time_harvested = attributes[:'time_harvested'] if attributes[:'time_harvested']

  self.object_relationships = attributes[:'objectRelationships'] if attributes[:'objectRelationships']

  raise 'You cannot provide both :objectRelationships and :object_relationships' if attributes.key?(:'objectRelationships') && attributes.key?(:'object_relationships')

  self.object_relationships = attributes[:'object_relationships'] if attributes[:'object_relationships']

  self.path = attributes[:'path'] if attributes[:'path']

  self.data_asset_key = attributes[:'dataAssetKey'] if attributes[:'dataAssetKey']

  raise 'You cannot provide both :dataAssetKey and :data_asset_key' if attributes.key?(:'dataAssetKey') && attributes.key?(:'data_asset_key')

  self.data_asset_key = attributes[:'data_asset_key'] if attributes[:'data_asset_key']

  self.custom_property_members = attributes[:'customPropertyMembers'] if attributes[:'customPropertyMembers']

  raise 'You cannot provide both :customPropertyMembers and :custom_property_members' if attributes.key?(:'customPropertyMembers') && attributes.key?(:'custom_property_members')

  self.custom_property_members = attributes[:'custom_property_members'] if attributes[:'custom_property_members']

  self.properties = attributes[:'properties'] if attributes[:'properties']

  self.external_key = attributes[:'externalKey'] if attributes[:'externalKey']

  raise 'You cannot provide both :externalKey and :external_key' if attributes.key?(:'externalKey') && attributes.key?(:'external_key')

  self.external_key = attributes[:'external_key'] if attributes[:'external_key']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.created_by_id = attributes[:'createdById'] if attributes[:'createdById']

  raise 'You cannot provide both :createdById and :created_by_id' if attributes.key?(:'createdById') && attributes.key?(:'created_by_id')

  self.created_by_id = attributes[:'created_by_id'] if attributes[:'created_by_id']

  self.updated_by_id = attributes[:'updatedById'] if attributes[:'updatedById']

  raise 'You cannot provide both :updatedById and :updated_by_id' if attributes.key?(:'updatedById') && attributes.key?(:'updated_by_id')

  self.updated_by_id = attributes[:'updated_by_id'] if attributes[:'updated_by_id']

  self.time_external = attributes[:'timeExternal'] if attributes[:'timeExternal']

  raise 'You cannot provide both :timeExternal and :time_external' if attributes.key?(:'timeExternal') && attributes.key?(:'time_external')

  self.time_external = attributes[:'time_external'] if attributes[:'time_external']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.harvest_status = attributes[:'harvestStatus'] if attributes[:'harvestStatus']

  raise 'You cannot provide both :harvestStatus and :harvest_status' if attributes.key?(:'harvestStatus') && attributes.key?(:'harvest_status')

  self.harvest_status = attributes[:'harvest_status'] if attributes[:'harvest_status']

  self.last_job_key = attributes[:'lastJobKey'] if attributes[:'lastJobKey']

  raise 'You cannot provide both :lastJobKey and :last_job_key' if attributes.key?(:'lastJobKey') && attributes.key?(:'last_job_key')

  self.last_job_key = attributes[:'last_job_key'] if attributes[:'last_job_key']

  self.uri = attributes[:'uri'] if attributes[:'uri']
end

Instance Attribute Details

#business_nameString

Optional user friendly business name of the folder. If set, this supplements the harvested display name of the object.

Returns:

  • (String)


47
48
49
# File 'lib/oci/data_catalog/models/folder.rb', line 47

def business_name
  @business_name
end

#created_by_idString

OCID of the user who created the folder.

Returns:

  • (String)


108
109
110
# File 'lib/oci/data_catalog/models/folder.rb', line 108

def created_by_id
  @created_by_id
end

#custom_property_membersArray<OCI::DataCatalog::Models::CustomPropertyGetUsage>

The list of customized properties along with the values for this object



80
81
82
# File 'lib/oci/data_catalog/models/folder.rb', line 80

def custom_property_members
  @custom_property_members
end

#data_asset_keyString

The key of the associated data asset.

Returns:

  • (String)


76
77
78
# File 'lib/oci/data_catalog/models/folder.rb', line 76

def data_asset_key
  @data_asset_key
end

#descriptionString

Detailed description of a folder.

Returns:

  • (String)


51
52
53
# File 'lib/oci/data_catalog/models/folder.rb', line 51

def description
  @description
end

#display_nameString

A user-friendly display name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.

Returns:

  • (String)


43
44
45
# File 'lib/oci/data_catalog/models/folder.rb', line 43

def display_name
  @display_name
end

#external_keyString

Unique external key of this object in the source system.

Returns:

  • (String)


93
94
95
# File 'lib/oci/data_catalog/models/folder.rb', line 93

def external_key
  @external_key
end

#harvest_statusString

Status of the object as updated by the harvest process.

Returns:

  • (String)


124
125
126
# File 'lib/oci/data_catalog/models/folder.rb', line 124

def harvest_status
  @harvest_status
end

#keyString

[Required] Unique folder key that is immutable.

Returns:

  • (String)


37
38
39
# File 'lib/oci/data_catalog/models/folder.rb', line 37

def key
  @key
end

#last_job_keyString

The key of the last harvest process to update the metadata of this object.

Returns:

  • (String)


128
129
130
# File 'lib/oci/data_catalog/models/folder.rb', line 128

def last_job_key
  @last_job_key
end

#lifecycle_stateString

The current state of the folder.

Returns:

  • (String)


120
121
122
# File 'lib/oci/data_catalog/models/folder.rb', line 120

def lifecycle_state
  @lifecycle_state
end

#object_relationshipsArray<OCI::DataCatalog::Models::ObjectRelationship>

List of objects and their relationships to this folder.



68
69
70
# File 'lib/oci/data_catalog/models/folder.rb', line 68

def object_relationships
  @object_relationships
end

#parent_folder_keyString

The unique key of the containing folder or null if there is no parent folder.

Returns:

  • (String)


55
56
57
# File 'lib/oci/data_catalog/models/folder.rb', line 55

def parent_folder_key
  @parent_folder_key
end

#pathString

Full path of the folder.

Returns:

  • (String)


72
73
74
# File 'lib/oci/data_catalog/models/folder.rb', line 72

def path
  @path
end

#propertiesHash<String, Hash<String, String>>

A map of maps that contains the properties which are specific to the folder type. Each folder type definition defines it’s set of required and optional properties. The map keys are category names and the values are maps of property name to property value. Every property is contained inside of a category. Most folders have required properties within the "default" category. Example: ‘{ "default": { "key1": "value1"}}`

Returns:

  • (Hash<String, Hash<String, String>>)


89
90
91
# File 'lib/oci/data_catalog/models/folder.rb', line 89

def properties
  @properties
end

#time_createdDateTime

The date and time the folder was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339). Example: 2019-03-25T21:10:29.600Z

Returns:

  • (DateTime)


99
100
101
# File 'lib/oci/data_catalog/models/folder.rb', line 99

def time_created
  @time_created
end

#time_externalDateTime

Last modified timestamp of this object in the external system.

Returns:

  • (DateTime)


116
117
118
# File 'lib/oci/data_catalog/models/folder.rb', line 116

def time_external
  @time_external
end

#time_harvestedDateTime

The date and time the folder was harvested, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).

Returns:

  • (DateTime)


64
65
66
# File 'lib/oci/data_catalog/models/folder.rb', line 64

def time_harvested
  @time_harvested
end

#time_updatedDateTime

The last time that any change was made to the folder. An [RFC3339](tools.ietf.org/html/rfc3339) formatted datetime string.

Returns:

  • (DateTime)


104
105
106
# File 'lib/oci/data_catalog/models/folder.rb', line 104

def time_updated
  @time_updated
end

#type_keyString

The type of folder object. Type keys can be found via the ‘/types’ endpoint.

Returns:

  • (String)


59
60
61
# File 'lib/oci/data_catalog/models/folder.rb', line 59

def type_key
  @type_key
end

#updated_by_idString

OCID of the user who modified the folder.

Returns:

  • (String)


112
113
114
# File 'lib/oci/data_catalog/models/folder.rb', line 112

def updated_by_id
  @updated_by_id
end

#uriString

URI to the folder instance in the API.

Returns:

  • (String)


132
133
134
# File 'lib/oci/data_catalog/models/folder.rb', line 132

def uri
  @uri
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/oci/data_catalog/models/folder.rb', line 135

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'key',
    'display_name': :'displayName',
    'business_name': :'businessName',
    'description': :'description',
    'parent_folder_key': :'parentFolderKey',
    'type_key': :'typeKey',
    'time_harvested': :'timeHarvested',
    'object_relationships': :'objectRelationships',
    'path': :'path',
    'data_asset_key': :'dataAssetKey',
    'custom_property_members': :'customPropertyMembers',
    'properties': :'properties',
    'external_key': :'externalKey',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'created_by_id': :'createdById',
    'updated_by_id': :'updatedById',
    'time_external': :'timeExternal',
    'lifecycle_state': :'lifecycleState',
    'harvest_status': :'harvestStatus',
    'last_job_key': :'lastJobKey',
    'uri': :'uri'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/oci/data_catalog/models/folder.rb', line 165

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'String',
    'display_name': :'String',
    'business_name': :'String',
    'description': :'String',
    'parent_folder_key': :'String',
    'type_key': :'String',
    'time_harvested': :'DateTime',
    'object_relationships': :'Array<OCI::DataCatalog::Models::ObjectRelationship>',
    'path': :'String',
    'data_asset_key': :'String',
    'custom_property_members': :'Array<OCI::DataCatalog::Models::CustomPropertyGetUsage>',
    'properties': :'Hash<String, Hash<String, String>>',
    'external_key': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'created_by_id': :'String',
    'updated_by_id': :'String',
    'time_external': :'DateTime',
    'lifecycle_state': :'String',
    'harvest_status': :'String',
    'last_job_key': :'String',
    'uri': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
# File 'lib/oci/data_catalog/models/folder.rb', line 374

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    key == other.key &&
    display_name == other.display_name &&
    business_name == other.business_name &&
    description == other.description &&
    parent_folder_key == other.parent_folder_key &&
    type_key == other.type_key &&
    time_harvested == other.time_harvested &&
    object_relationships == other.object_relationships &&
    path == other.path &&
    data_asset_key == other.data_asset_key &&
    custom_property_members == other.custom_property_members &&
    properties == other.properties &&
    external_key == other.external_key &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    created_by_id == other.created_by_id &&
    updated_by_id == other.updated_by_id &&
    time_external == other.time_external &&
    lifecycle_state == other.lifecycle_state &&
    harvest_status == other.harvest_status &&
    last_job_key == other.last_job_key &&
    uri == other.uri
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
# File 'lib/oci/data_catalog/models/folder.rb', line 425

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


405
406
407
# File 'lib/oci/data_catalog/models/folder.rb', line 405

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



414
415
416
# File 'lib/oci/data_catalog/models/folder.rb', line 414

def hash
  [key, display_name, business_name, description, parent_folder_key, type_key, time_harvested, object_relationships, path, data_asset_key, custom_property_members, properties, external_key, time_created, time_updated, created_by_id, updated_by_id, time_external, lifecycle_state, harvest_status, last_job_key, uri].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



458
459
460
461
462
463
464
465
466
467
# File 'lib/oci/data_catalog/models/folder.rb', line 458

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



452
453
454
# File 'lib/oci/data_catalog/models/folder.rb', line 452

def to_s
  to_hash.to_s
end