Class: DataCatalog::Models::Job
- Inherits:
-
Object
- Object
- DataCatalog::Models::Job
- Defined in:
- lib/oci/data_catalog/models/job.rb
Overview
Details of a job. Jobs are scheduled instances of a job definition.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_EXPIRED = 'EXPIRED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- JOB_TYPE_ENUM =
[ JOB_TYPE_HARVEST = 'HARVEST'.freeze, JOB_TYPE_PROFILING = 'PROFILING'.freeze, JOB_TYPE_SAMPLING = 'SAMPLING'.freeze, JOB_TYPE_PREVIEW = 'PREVIEW'.freeze, JOB_TYPE_IMPORT = 'IMPORT'.freeze, JOB_TYPE_EXPORT = 'EXPORT'.freeze, JOB_TYPE_IMPORT_GLOSSARY = 'IMPORT_GLOSSARY'.freeze, JOB_TYPE_EXPORT_GLOSSARY = 'EXPORT_GLOSSARY'.freeze, JOB_TYPE_INTERNAL = 'INTERNAL'.freeze, JOB_TYPE_PURGE = 'PURGE'.freeze, JOB_TYPE_IMMEDIATE = 'IMMEDIATE'.freeze, JOB_TYPE_SCHEDULED = 'SCHEDULED'.freeze, JOB_TYPE_IMMEDIATE_EXECUTION = 'IMMEDIATE_EXECUTION'.freeze, JOB_TYPE_SCHEDULED_EXECUTION = 'SCHEDULED_EXECUTION'.freeze, JOB_TYPE_SCHEDULED_EXECUTION_INSTANCE = 'SCHEDULED_EXECUTION_INSTANCE'.freeze, JOB_TYPE_ASYNC_DELETE = 'ASYNC_DELETE'.freeze, JOB_TYPE_IMPORT_DATA_ASSET = 'IMPORT_DATA_ASSET'.freeze, JOB_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- SCHEDULE_TYPE_ENUM =
[ SCHEDULE_TYPE_SCHEDULED = 'SCHEDULED'.freeze, SCHEDULE_TYPE_IMMEDIATE = 'IMMEDIATE'.freeze, SCHEDULE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The data catalog's OCID.
-
#connection_key ⇒ String
The key of the connection used by the job.
-
#created_by_id ⇒ String
OCID of the user who created this job.
-
#data_asset_key ⇒ String
Unique key of the data asset to which this job applies, if the job involves a data asset.
-
#description ⇒ String
Detailed description of the job.
-
#display_name ⇒ String
A user-friendly display name.
-
#error_code ⇒ String
Error code returned from the latest job execution for this job.
-
#error_message ⇒ String
Error message returned from the latest job execution for this job.
-
#execution_count ⇒ Integer
The total number of executions for this job schedule.
-
#internal_version ⇒ String
Internal version of the job resource.
-
#job_definition_key ⇒ String
The unique key of the job definition resource that defined the scope of this job.
-
#job_definition_name ⇒ String
The display name of the job definition resource that defined the scope of this job.
-
#job_type ⇒ String
Type of the job.
-
#key ⇒ String
**[Required]** Unique key of the job resource.
-
#lifecycle_state ⇒ String
Lifecycle state for job.
-
#schedule_cron_expression ⇒ String
Interval on which the job will be run.
-
#schedule_type ⇒ String
Type of job schedule that is inferred from the scheduling properties.
-
#time_created ⇒ DateTime
The date and time the job was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#time_of_latest_execution ⇒ DateTime
The date and time of the most recent execution for this Job, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#time_schedule_begin ⇒ DateTime
Date that the schedule should be operational.
-
#time_schedule_end ⇒ DateTime
Date that the schedule should end from being operational.
-
#time_updated ⇒ DateTime
Time that this job was last updated.
-
#updated_by_id ⇒ String
OCID of the user who updated this job.
-
#uri ⇒ String
URI to the job instance in the API.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Job
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Job
Initializes the object
248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 |
# File 'lib/oci/data_catalog/models/job.rb', line 248 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.key = attributes[:'key'] if attributes[:'key'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.catalog_id = attributes[:'catalogId'] if attributes[:'catalogId'] raise 'You cannot provide both :catalogId and :catalog_id' if attributes.key?(:'catalogId') && attributes.key?(:'catalog_id') self.catalog_id = attributes[:'catalog_id'] if attributes[:'catalog_id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.job_type = attributes[:'jobType'] if attributes[:'jobType'] raise 'You cannot provide both :jobType and :job_type' if attributes.key?(:'jobType') && attributes.key?(:'job_type') self.job_type = attributes[:'job_type'] if attributes[:'job_type'] self.schedule_cron_expression = attributes[:'scheduleCronExpression'] if attributes[:'scheduleCronExpression'] raise 'You cannot provide both :scheduleCronExpression and :schedule_cron_expression' if attributes.key?(:'scheduleCronExpression') && attributes.key?(:'schedule_cron_expression') self.schedule_cron_expression = attributes[:'schedule_cron_expression'] if attributes[:'schedule_cron_expression'] self.time_schedule_begin = attributes[:'timeScheduleBegin'] if attributes[:'timeScheduleBegin'] raise 'You cannot provide both :timeScheduleBegin and :time_schedule_begin' if attributes.key?(:'timeScheduleBegin') && attributes.key?(:'time_schedule_begin') self.time_schedule_begin = attributes[:'time_schedule_begin'] if attributes[:'time_schedule_begin'] self.time_schedule_end = attributes[:'timeScheduleEnd'] if attributes[:'timeScheduleEnd'] raise 'You cannot provide both :timeScheduleEnd and :time_schedule_end' if attributes.key?(:'timeScheduleEnd') && attributes.key?(:'time_schedule_end') self.time_schedule_end = attributes[:'time_schedule_end'] if attributes[:'time_schedule_end'] self.schedule_type = attributes[:'scheduleType'] if attributes[:'scheduleType'] raise 'You cannot provide both :scheduleType and :schedule_type' if attributes.key?(:'scheduleType') && attributes.key?(:'schedule_type') self.schedule_type = attributes[:'schedule_type'] if attributes[:'schedule_type'] self.connection_key = attributes[:'connectionKey'] if attributes[:'connectionKey'] raise 'You cannot provide both :connectionKey and :connection_key' if attributes.key?(:'connectionKey') && attributes.key?(:'connection_key') self.connection_key = attributes[:'connection_key'] if attributes[:'connection_key'] self.job_definition_key = attributes[:'jobDefinitionKey'] if attributes[:'jobDefinitionKey'] raise 'You cannot provide both :jobDefinitionKey and :job_definition_key' if attributes.key?(:'jobDefinitionKey') && attributes.key?(:'job_definition_key') self.job_definition_key = attributes[:'job_definition_key'] if attributes[:'job_definition_key'] self.internal_version = attributes[:'internalVersion'] if attributes[:'internalVersion'] raise 'You cannot provide both :internalVersion and :internal_version' if attributes.key?(:'internalVersion') && attributes.key?(:'internal_version') self.internal_version = attributes[:'internal_version'] if attributes[:'internal_version'] self.execution_count = attributes[:'executionCount'] if attributes[:'executionCount'] raise 'You cannot provide both :executionCount and :execution_count' if attributes.key?(:'executionCount') && attributes.key?(:'execution_count') self.execution_count = attributes[:'execution_count'] if attributes[:'execution_count'] self.time_of_latest_execution = attributes[:'timeOfLatestExecution'] if attributes[:'timeOfLatestExecution'] raise 'You cannot provide both :timeOfLatestExecution and :time_of_latest_execution' if attributes.key?(:'timeOfLatestExecution') && attributes.key?(:'time_of_latest_execution') self.time_of_latest_execution = attributes[:'time_of_latest_execution'] if attributes[:'time_of_latest_execution'] self.created_by_id = attributes[:'createdById'] if attributes[:'createdById'] raise 'You cannot provide both :createdById and :created_by_id' if attributes.key?(:'createdById') && attributes.key?(:'created_by_id') self.created_by_id = attributes[:'created_by_id'] if attributes[:'created_by_id'] self.updated_by_id = attributes[:'updatedById'] if attributes[:'updatedById'] raise 'You cannot provide both :updatedById and :updated_by_id' if attributes.key?(:'updatedById') && attributes.key?(:'updated_by_id') self.updated_by_id = attributes[:'updated_by_id'] if attributes[:'updated_by_id'] self.job_definition_name = attributes[:'jobDefinitionName'] if attributes[:'jobDefinitionName'] raise 'You cannot provide both :jobDefinitionName and :job_definition_name' if attributes.key?(:'jobDefinitionName') && attributes.key?(:'job_definition_name') self.job_definition_name = attributes[:'job_definition_name'] if attributes[:'job_definition_name'] self.data_asset_key = attributes[:'dataAssetKey'] if attributes[:'dataAssetKey'] raise 'You cannot provide both :dataAssetKey and :data_asset_key' if attributes.key?(:'dataAssetKey') && attributes.key?(:'data_asset_key') self.data_asset_key = attributes[:'data_asset_key'] if attributes[:'data_asset_key'] self.error_code = attributes[:'errorCode'] if attributes[:'errorCode'] raise 'You cannot provide both :errorCode and :error_code' if attributes.key?(:'errorCode') && attributes.key?(:'error_code') self.error_code = attributes[:'error_code'] if attributes[:'error_code'] self. = attributes[:'errorMessage'] if attributes[:'errorMessage'] raise 'You cannot provide both :errorMessage and :error_message' if attributes.key?(:'errorMessage') && attributes.key?(:'error_message') self. = attributes[:'error_message'] if attributes[:'error_message'] self.uri = attributes[:'uri'] if attributes[:'uri'] end |
Instance Attribute Details
#catalog_id ⇒ String
The data catalog's OCID.
61 62 63 |
# File 'lib/oci/data_catalog/models/job.rb', line 61 def catalog_id @catalog_id end |
#connection_key ⇒ String
The key of the connection used by the job. This connection will override the default connection specified in the associated job definition. All executions will use this connection.
103 104 105 |
# File 'lib/oci/data_catalog/models/job.rb', line 103 def connection_key @connection_key end |
#created_by_id ⇒ String
OCID of the user who created this job.
126 127 128 |
# File 'lib/oci/data_catalog/models/job.rb', line 126 def created_by_id @created_by_id end |
#data_asset_key ⇒ String
Unique key of the data asset to which this job applies, if the job involves a data asset.
138 139 140 |
# File 'lib/oci/data_catalog/models/job.rb', line 138 def data_asset_key @data_asset_key end |
#description ⇒ String
Detailed description of the job.
57 58 59 |
# File 'lib/oci/data_catalog/models/job.rb', line 57 def description @description end |
#display_name ⇒ String
A user-friendly display name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
53 54 55 |
# File 'lib/oci/data_catalog/models/job.rb', line 53 def display_name @display_name end |
#error_code ⇒ String
Error code returned from the latest job execution for this job. Useful when the latest Job execution is in FAILED state.
143 144 145 |
# File 'lib/oci/data_catalog/models/job.rb', line 143 def error_code @error_code end |
#error_message ⇒ String
Error message returned from the latest job execution for this job. Useful when the latest Job Execution is in a FAILED state.
148 149 150 |
# File 'lib/oci/data_catalog/models/job.rb', line 148 def @error_message end |
#execution_count ⇒ Integer
The total number of executions for this job schedule.
116 117 118 |
# File 'lib/oci/data_catalog/models/job.rb', line 116 def execution_count @execution_count end |
#internal_version ⇒ String
Internal version of the job resource.
111 112 113 |
# File 'lib/oci/data_catalog/models/job.rb', line 111 def internal_version @internal_version end |
#job_definition_key ⇒ String
The unique key of the job definition resource that defined the scope of this job.
107 108 109 |
# File 'lib/oci/data_catalog/models/job.rb', line 107 def job_definition_key @job_definition_key end |
#job_definition_name ⇒ String
The display name of the job definition resource that defined the scope of this job.
134 135 136 |
# File 'lib/oci/data_catalog/models/job.rb', line 134 def job_definition_name @job_definition_name end |
#job_type ⇒ String
Type of the job.
79 80 81 |
# File 'lib/oci/data_catalog/models/job.rb', line 79 def job_type @job_type end |
#key ⇒ String
**[Required]** Unique key of the job resource.
47 48 49 |
# File 'lib/oci/data_catalog/models/job.rb', line 47 def key @key end |
#lifecycle_state ⇒ String
Lifecycle state for job.
65 66 67 |
# File 'lib/oci/data_catalog/models/job.rb', line 65 def lifecycle_state @lifecycle_state end |
#schedule_cron_expression ⇒ String
Interval on which the job will be run. Value is specified as a cron-supported time specification "nickname". The following subset of those is supported: @monthly, @weekly, @daily, @hourly.
85 86 87 |
# File 'lib/oci/data_catalog/models/job.rb', line 85 def schedule_cron_expression @schedule_cron_expression end |
#schedule_type ⇒ String
Type of job schedule that is inferred from the scheduling properties.
97 98 99 |
# File 'lib/oci/data_catalog/models/job.rb', line 97 def schedule_type @schedule_type end |
#time_created ⇒ DateTime
The date and time the job was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339). Example: `2019-03-25T21:10:29.600Z`
71 72 73 |
# File 'lib/oci/data_catalog/models/job.rb', line 71 def time_created @time_created end |
#time_of_latest_execution ⇒ DateTime
The date and time of the most recent execution for this Job, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339). Example: `2019-03-25T21:10:29.600Z`
122 123 124 |
# File 'lib/oci/data_catalog/models/job.rb', line 122 def time_of_latest_execution @time_of_latest_execution end |
#time_schedule_begin ⇒ DateTime
Date that the schedule should be operational. An [RFC3339](tools.ietf.org/html/rfc3339) formatted datetime string.
89 90 91 |
# File 'lib/oci/data_catalog/models/job.rb', line 89 def time_schedule_begin @time_schedule_begin end |
#time_schedule_end ⇒ DateTime
Date that the schedule should end from being operational. An [RFC3339](tools.ietf.org/html/rfc3339) formatted datetime string.
93 94 95 |
# File 'lib/oci/data_catalog/models/job.rb', line 93 def time_schedule_end @time_schedule_end end |
#time_updated ⇒ DateTime
Time that this job was last updated. An [RFC3339](tools.ietf.org/html/rfc3339) formatted datetime string.
75 76 77 |
# File 'lib/oci/data_catalog/models/job.rb', line 75 def time_updated @time_updated end |
#updated_by_id ⇒ String
OCID of the user who updated this job.
130 131 132 |
# File 'lib/oci/data_catalog/models/job.rb', line 130 def updated_by_id @updated_by_id end |
#uri ⇒ String
URI to the job instance in the API.
152 153 154 |
# File 'lib/oci/data_catalog/models/job.rb', line 152 def uri @uri end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/oci/data_catalog/models/job.rb', line 155 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'key': :'key', 'display_name': :'displayName', 'description': :'description', 'catalog_id': :'catalogId', 'lifecycle_state': :'lifecycleState', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'job_type': :'jobType', 'schedule_cron_expression': :'scheduleCronExpression', 'time_schedule_begin': :'timeScheduleBegin', 'time_schedule_end': :'timeScheduleEnd', 'schedule_type': :'scheduleType', 'connection_key': :'connectionKey', 'job_definition_key': :'jobDefinitionKey', 'internal_version': :'internalVersion', 'execution_count': :'executionCount', 'time_of_latest_execution': :'timeOfLatestExecution', 'created_by_id': :'createdById', 'updated_by_id': :'updatedById', 'job_definition_name': :'jobDefinitionName', 'data_asset_key': :'dataAssetKey', 'error_code': :'errorCode', 'error_message': :'errorMessage', 'uri': :'uri' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/oci/data_catalog/models/job.rb', line 187 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'key': :'String', 'display_name': :'String', 'description': :'String', 'catalog_id': :'String', 'lifecycle_state': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'job_type': :'String', 'schedule_cron_expression': :'String', 'time_schedule_begin': :'DateTime', 'time_schedule_end': :'DateTime', 'schedule_type': :'String', 'connection_key': :'String', 'job_definition_key': :'String', 'internal_version': :'String', 'execution_count': :'Integer', 'time_of_latest_execution': :'DateTime', 'created_by_id': :'String', 'updated_by_id': :'String', 'job_definition_name': :'String', 'data_asset_key': :'String', 'error_code': :'String', 'error_message': :'String', 'uri': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 |
# File 'lib/oci/data_catalog/models/job.rb', line 433 def ==(other) return true if equal?(other) self.class == other.class && key == other.key && display_name == other.display_name && description == other.description && catalog_id == other.catalog_id && lifecycle_state == other.lifecycle_state && time_created == other.time_created && time_updated == other.time_updated && job_type == other.job_type && schedule_cron_expression == other.schedule_cron_expression && time_schedule_begin == other.time_schedule_begin && time_schedule_end == other.time_schedule_end && schedule_type == other.schedule_type && connection_key == other.connection_key && job_definition_key == other.job_definition_key && internal_version == other.internal_version && execution_count == other.execution_count && time_of_latest_execution == other.time_of_latest_execution && created_by_id == other.created_by_id && updated_by_id == other.updated_by_id && job_definition_name == other.job_definition_name && data_asset_key == other.data_asset_key && error_code == other.error_code && == other. && uri == other.uri end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 |
# File 'lib/oci/data_catalog/models/job.rb', line 486 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
466 467 468 |
# File 'lib/oci/data_catalog/models/job.rb', line 466 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
475 476 477 |
# File 'lib/oci/data_catalog/models/job.rb', line 475 def hash [key, display_name, description, catalog_id, lifecycle_state, time_created, time_updated, job_type, schedule_cron_expression, time_schedule_begin, time_schedule_end, schedule_type, connection_key, job_definition_key, internal_version, execution_count, time_of_latest_execution, created_by_id, updated_by_id, job_definition_name, data_asset_key, error_code, , uri].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
519 520 521 522 523 524 525 526 527 528 |
# File 'lib/oci/data_catalog/models/job.rb', line 519 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
513 514 515 |
# File 'lib/oci/data_catalog/models/job.rb', line 513 def to_s to_hash.to_s end |