Class: OCI::DataCatalog::Models::JobExecution
- Inherits:
-
Object
- Object
- OCI::DataCatalog::Models::JobExecution
- Defined in:
- lib/oci/data_catalog/models/job_execution.rb
Overview
A job execution is a unit of work being executed on behalf of a job.
Constant Summary collapse
- JOB_TYPE_ENUM =
[ JOB_TYPE_HARVEST = 'HARVEST'.freeze, JOB_TYPE_PROFILING = 'PROFILING'.freeze, JOB_TYPE_SAMPLING = 'SAMPLING'.freeze, JOB_TYPE_PREVIEW = 'PREVIEW'.freeze, JOB_TYPE_IMPORT = 'IMPORT'.freeze, JOB_TYPE_EXPORT = 'EXPORT'.freeze, JOB_TYPE_IMPORT_GLOSSARY = 'IMPORT_GLOSSARY'.freeze, JOB_TYPE_EXPORT_GLOSSARY = 'EXPORT_GLOSSARY'.freeze, JOB_TYPE_INTERNAL = 'INTERNAL'.freeze, JOB_TYPE_PURGE = 'PURGE'.freeze, JOB_TYPE_IMMEDIATE = 'IMMEDIATE'.freeze, JOB_TYPE_SCHEDULED = 'SCHEDULED'.freeze, JOB_TYPE_IMMEDIATE_EXECUTION = 'IMMEDIATE_EXECUTION'.freeze, JOB_TYPE_SCHEDULED_EXECUTION = 'SCHEDULED_EXECUTION'.freeze, JOB_TYPE_SCHEDULED_EXECUTION_INSTANCE = 'SCHEDULED_EXECUTION_INSTANCE'.freeze, JOB_TYPE_ASYNC_DELETE = 'ASYNC_DELETE'.freeze, JOB_TYPE_IMPORT_DATA_ASSET = 'IMPORT_DATA_ASSET'.freeze, JOB_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATED = 'CREATED'.freeze, LIFECYCLE_STATE_IN_PROGRESS = 'IN_PROGRESS'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_SUCCEEDED = 'SUCCEEDED'.freeze, LIFECYCLE_STATE_CANCELED = 'CANCELED'.freeze, LIFECYCLE_STATE_SUCCEEDED_WITH_WARNINGS = 'SUCCEEDED_WITH_WARNINGS'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#created_by_id ⇒ String
OCID of the user who created the job execution.
-
#data_entity_key ⇒ String
The key of the associated data entity resource.
-
#error_code ⇒ String
Error code returned from the job execution or null if job is still running or didn’t return an error.
-
#error_message ⇒ String
Error message returned from the job execution or null if job is still running or didn’t return an error.
-
#event_key ⇒ String
An identifier used for log message correlation.
-
#external_url ⇒ String
If the job is an external process, then a URL of the job for accessing this resource and its status.
-
#job_key ⇒ String
The unique key of the parent job.
-
#job_type ⇒ String
Type of the job execution.
-
#key ⇒ String
[Required] Unique key of the job execution resource.
-
#lifecycle_state ⇒ String
Status of the job execution, such as running, paused, or completed.
-
#parent_key ⇒ String
The unique key of the parent execution or null if this job execution has no parent.
-
#process_key ⇒ String
Process identifier related to the job execution if the job is an external job.
-
#properties ⇒ Hash<String, Hash<String, String>>
A map of maps that contains the execution context properties which are specific to a job execution.
-
#schedule_instance_key ⇒ String
The unique key of the triggering external scheduler resource or null if this job execution is not externally triggered.
-
#sub_type ⇒ String
Sub-type of this job execution.
-
#time_created ⇒ DateTime
The date and time the job execution was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#time_ended ⇒ DateTime
Time that the job execution ended or null if it hasn’t yet completed.
-
#time_started ⇒ DateTime
Time that job execution started.
-
#updated_by ⇒ String
OCID of the user who updated the job execution.
-
#uri ⇒ String
URI to the job execution instance in the API.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ JobExecution
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ JobExecution
Initializes the object
218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 |
# File 'lib/oci/data_catalog/models/job_execution.rb', line 218 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.key = attributes[:'key'] if attributes[:'key'] self.job_key = attributes[:'jobKey'] if attributes[:'jobKey'] raise 'You cannot provide both :jobKey and :job_key' if attributes.key?(:'jobKey') && attributes.key?(:'job_key') self.job_key = attributes[:'job_key'] if attributes[:'job_key'] self.job_type = attributes[:'jobType'] if attributes[:'jobType'] raise 'You cannot provide both :jobType and :job_type' if attributes.key?(:'jobType') && attributes.key?(:'job_type') self.job_type = attributes[:'job_type'] if attributes[:'job_type'] self.sub_type = attributes[:'subType'] if attributes[:'subType'] raise 'You cannot provide both :subType and :sub_type' if attributes.key?(:'subType') && attributes.key?(:'sub_type') self.sub_type = attributes[:'sub_type'] if attributes[:'sub_type'] self.parent_key = attributes[:'parentKey'] if attributes[:'parentKey'] raise 'You cannot provide both :parentKey and :parent_key' if attributes.key?(:'parentKey') && attributes.key?(:'parent_key') self.parent_key = attributes[:'parent_key'] if attributes[:'parent_key'] self.schedule_instance_key = attributes[:'scheduleInstanceKey'] if attributes[:'scheduleInstanceKey'] raise 'You cannot provide both :scheduleInstanceKey and :schedule_instance_key' if attributes.key?(:'scheduleInstanceKey') && attributes.key?(:'schedule_instance_key') self.schedule_instance_key = attributes[:'schedule_instance_key'] if attributes[:'schedule_instance_key'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_started = attributes[:'timeStarted'] if attributes[:'timeStarted'] raise 'You cannot provide both :timeStarted and :time_started' if attributes.key?(:'timeStarted') && attributes.key?(:'time_started') self.time_started = attributes[:'time_started'] if attributes[:'time_started'] self.time_ended = attributes[:'timeEnded'] if attributes[:'timeEnded'] raise 'You cannot provide both :timeEnded and :time_ended' if attributes.key?(:'timeEnded') && attributes.key?(:'time_ended') self.time_ended = attributes[:'time_ended'] if attributes[:'time_ended'] self.error_code = attributes[:'errorCode'] if attributes[:'errorCode'] raise 'You cannot provide both :errorCode and :error_code' if attributes.key?(:'errorCode') && attributes.key?(:'error_code') self.error_code = attributes[:'error_code'] if attributes[:'error_code'] self. = attributes[:'errorMessage'] if attributes[:'errorMessage'] raise 'You cannot provide both :errorMessage and :error_message' if attributes.key?(:'errorMessage') && attributes.key?(:'error_message') self. = attributes[:'error_message'] if attributes[:'error_message'] self.process_key = attributes[:'processKey'] if attributes[:'processKey'] raise 'You cannot provide both :processKey and :process_key' if attributes.key?(:'processKey') && attributes.key?(:'process_key') self.process_key = attributes[:'process_key'] if attributes[:'process_key'] self.external_url = attributes[:'externalUrl'] if attributes[:'externalUrl'] raise 'You cannot provide both :externalUrl and :external_url' if attributes.key?(:'externalUrl') && attributes.key?(:'external_url') self.external_url = attributes[:'external_url'] if attributes[:'external_url'] self.event_key = attributes[:'eventKey'] if attributes[:'eventKey'] raise 'You cannot provide both :eventKey and :event_key' if attributes.key?(:'eventKey') && attributes.key?(:'event_key') self.event_key = attributes[:'event_key'] if attributes[:'event_key'] self.data_entity_key = attributes[:'dataEntityKey'] if attributes[:'dataEntityKey'] raise 'You cannot provide both :dataEntityKey and :data_entity_key' if attributes.key?(:'dataEntityKey') && attributes.key?(:'data_entity_key') self.data_entity_key = attributes[:'data_entity_key'] if attributes[:'data_entity_key'] self.created_by_id = attributes[:'createdById'] if attributes[:'createdById'] raise 'You cannot provide both :createdById and :created_by_id' if attributes.key?(:'createdById') && attributes.key?(:'created_by_id') self.created_by_id = attributes[:'created_by_id'] if attributes[:'created_by_id'] self.updated_by = attributes[:'updatedBy'] if attributes[:'updatedBy'] raise 'You cannot provide both :updatedBy and :updated_by' if attributes.key?(:'updatedBy') && attributes.key?(:'updated_by') self.updated_by = attributes[:'updated_by'] if attributes[:'updated_by'] self.uri = attributes[:'uri'] if attributes[:'uri'] self.properties = attributes[:'properties'] if attributes[:'properties'] end |
Instance Attribute Details
#created_by_id ⇒ String
OCID of the user who created the job execution.
117 118 119 |
# File 'lib/oci/data_catalog/models/job_execution.rb', line 117 def created_by_id @created_by_id end |
#data_entity_key ⇒ String
The key of the associated data entity resource.
113 114 115 |
# File 'lib/oci/data_catalog/models/job_execution.rb', line 113 def data_entity_key @data_entity_key end |
#error_code ⇒ String
Error code returned from the job execution or null if job is still running or didn’t return an error.
90 91 92 |
# File 'lib/oci/data_catalog/models/job_execution.rb', line 90 def error_code @error_code end |
#error_message ⇒ String
Error message returned from the job execution or null if job is still running or didn’t return an error.
95 96 97 |
# File 'lib/oci/data_catalog/models/job_execution.rb', line 95 def @error_message end |
#event_key ⇒ String
An identifier used for log message correlation.
109 110 111 |
# File 'lib/oci/data_catalog/models/job_execution.rb', line 109 def event_key @event_key end |
#external_url ⇒ String
If the job is an external process, then a URL of the job for accessing this resource and its status.
104 105 106 |
# File 'lib/oci/data_catalog/models/job_execution.rb', line 104 def external_url @external_url end |
#job_key ⇒ String
The unique key of the parent job.
49 50 51 |
# File 'lib/oci/data_catalog/models/job_execution.rb', line 49 def job_key @job_key end |
#job_type ⇒ String
Type of the job execution.
53 54 55 |
# File 'lib/oci/data_catalog/models/job_execution.rb', line 53 def job_type @job_type end |
#key ⇒ String
[Required] Unique key of the job execution resource.
45 46 47 |
# File 'lib/oci/data_catalog/models/job_execution.rb', line 45 def key @key end |
#lifecycle_state ⇒ String
Status of the job execution, such as running, paused, or completed.
69 70 71 |
# File 'lib/oci/data_catalog/models/job_execution.rb', line 69 def lifecycle_state @lifecycle_state end |
#parent_key ⇒ String
The unique key of the parent execution or null if this job execution has no parent.
61 62 63 |
# File 'lib/oci/data_catalog/models/job_execution.rb', line 61 def parent_key @parent_key end |
#process_key ⇒ String
Process identifier related to the job execution if the job is an external job.
99 100 101 |
# File 'lib/oci/data_catalog/models/job_execution.rb', line 99 def process_key @process_key end |
#properties ⇒ Hash<String, Hash<String, String>>
A map of maps that contains the execution context properties which are specific to a job execution. Each job execution may define it’s set of required and optional properties. The map keys are category names and the values are maps of property name to property value. Every property is contained inside of a category. Most job executions have required properties within the "default" category. Example: ‘{ "default": { "host": "host1", "port": "1521", "database": "orcl"}}`
134 135 136 |
# File 'lib/oci/data_catalog/models/job_execution.rb', line 134 def properties @properties end |
#schedule_instance_key ⇒ String
The unique key of the triggering external scheduler resource or null if this job execution is not externally triggered.
65 66 67 |
# File 'lib/oci/data_catalog/models/job_execution.rb', line 65 def schedule_instance_key @schedule_instance_key end |
#sub_type ⇒ String
Sub-type of this job execution.
57 58 59 |
# File 'lib/oci/data_catalog/models/job_execution.rb', line 57 def sub_type @sub_type end |
#time_created ⇒ DateTime
The date and time the job execution was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339). Example: 2019-03-25T21:10:29.600Z
75 76 77 |
# File 'lib/oci/data_catalog/models/job_execution.rb', line 75 def time_created @time_created end |
#time_ended ⇒ DateTime
Time that the job execution ended or null if it hasn’t yet completed. An [RFC3339](tools.ietf.org/html/rfc3339) formatted datetime string.
85 86 87 |
# File 'lib/oci/data_catalog/models/job_execution.rb', line 85 def time_ended @time_ended end |
#time_started ⇒ DateTime
Time that job execution started. An [RFC3339](tools.ietf.org/html/rfc3339) formatted datetime string.
79 80 81 |
# File 'lib/oci/data_catalog/models/job_execution.rb', line 79 def time_started @time_started end |
#updated_by ⇒ String
OCID of the user who updated the job execution.
121 122 123 |
# File 'lib/oci/data_catalog/models/job_execution.rb', line 121 def updated_by @updated_by end |
#uri ⇒ String
URI to the job execution instance in the API.
125 126 127 |
# File 'lib/oci/data_catalog/models/job_execution.rb', line 125 def uri @uri end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/oci/data_catalog/models/job_execution.rb', line 137 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'key': :'key', 'job_key': :'jobKey', 'job_type': :'jobType', 'sub_type': :'subType', 'parent_key': :'parentKey', 'schedule_instance_key': :'scheduleInstanceKey', 'lifecycle_state': :'lifecycleState', 'time_created': :'timeCreated', 'time_started': :'timeStarted', 'time_ended': :'timeEnded', 'error_code': :'errorCode', 'error_message': :'errorMessage', 'process_key': :'processKey', 'external_url': :'externalUrl', 'event_key': :'eventKey', 'data_entity_key': :'dataEntityKey', 'created_by_id': :'createdById', 'updated_by': :'updatedBy', 'uri': :'uri', 'properties': :'properties' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/oci/data_catalog/models/job_execution.rb', line 165 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'key': :'String', 'job_key': :'String', 'job_type': :'String', 'sub_type': :'String', 'parent_key': :'String', 'schedule_instance_key': :'String', 'lifecycle_state': :'String', 'time_created': :'DateTime', 'time_started': :'DateTime', 'time_ended': :'DateTime', 'error_code': :'String', 'error_message': :'String', 'process_key': :'String', 'external_url': :'String', 'event_key': :'String', 'data_entity_key': :'String', 'created_by_id': :'String', 'updated_by': :'String', 'uri': :'String', 'properties': :'Hash<String, Hash<String, String>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 |
# File 'lib/oci/data_catalog/models/job_execution.rb', line 366 def ==(other) return true if equal?(other) self.class == other.class && key == other.key && job_key == other.job_key && job_type == other.job_type && sub_type == other.sub_type && parent_key == other.parent_key && schedule_instance_key == other.schedule_instance_key && lifecycle_state == other.lifecycle_state && time_created == other.time_created && time_started == other.time_started && time_ended == other.time_ended && error_code == other.error_code && == other. && process_key == other.process_key && external_url == other.external_url && event_key == other.event_key && data_entity_key == other.data_entity_key && created_by_id == other.created_by_id && updated_by == other.updated_by && uri == other.uri && properties == other.properties end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 |
# File 'lib/oci/data_catalog/models/job_execution.rb', line 415 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
395 396 397 |
# File 'lib/oci/data_catalog/models/job_execution.rb', line 395 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
404 405 406 |
# File 'lib/oci/data_catalog/models/job_execution.rb', line 404 def hash [key, job_key, job_type, sub_type, parent_key, schedule_instance_key, lifecycle_state, time_created, time_started, time_ended, error_code, , process_key, external_url, event_key, data_entity_key, created_by_id, updated_by, uri, properties].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
448 449 450 451 452 453 454 455 456 457 |
# File 'lib/oci/data_catalog/models/job_execution.rb', line 448 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
442 443 444 |
# File 'lib/oci/data_catalog/models/job_execution.rb', line 442 def to_s to_hash.to_s end |