Class: OCI::DataCatalog::Models::JobExecutionSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_catalog/models/job_execution_summary.rb

Overview

A list of job executions. A job execution is a unit of work being executed on behalf of a job.

Constant Summary collapse

JOB_TYPE_ENUM =
[
  JOB_TYPE_HARVEST = 'HARVEST'.freeze,
  JOB_TYPE_PROFILING = 'PROFILING'.freeze,
  JOB_TYPE_SAMPLING = 'SAMPLING'.freeze,
  JOB_TYPE_PREVIEW = 'PREVIEW'.freeze,
  JOB_TYPE_IMPORT = 'IMPORT'.freeze,
  JOB_TYPE_EXPORT = 'EXPORT'.freeze,
  JOB_TYPE_IMPORT_GLOSSARY = 'IMPORT_GLOSSARY'.freeze,
  JOB_TYPE_EXPORT_GLOSSARY = 'EXPORT_GLOSSARY'.freeze,
  JOB_TYPE_INTERNAL = 'INTERNAL'.freeze,
  JOB_TYPE_PURGE = 'PURGE'.freeze,
  JOB_TYPE_IMMEDIATE = 'IMMEDIATE'.freeze,
  JOB_TYPE_SCHEDULED = 'SCHEDULED'.freeze,
  JOB_TYPE_IMMEDIATE_EXECUTION = 'IMMEDIATE_EXECUTION'.freeze,
  JOB_TYPE_SCHEDULED_EXECUTION = 'SCHEDULED_EXECUTION'.freeze,
  JOB_TYPE_SCHEDULED_EXECUTION_INSTANCE = 'SCHEDULED_EXECUTION_INSTANCE'.freeze,
  JOB_TYPE_ASYNC_DELETE = 'ASYNC_DELETE'.freeze,
  JOB_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATED = 'CREATED'.freeze,
  LIFECYCLE_STATE_IN_PROGRESS = 'IN_PROGRESS'.freeze,
  LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_SUCCEEDED = 'SUCCEEDED'.freeze,
  LIFECYCLE_STATE_CANCELED = 'CANCELED'.freeze,
  LIFECYCLE_STATE_SUCCEEDED_WITH_WARNINGS = 'SUCCEEDED_WITH_WARNINGS'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ JobExecutionSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :key (String)

    The value to assign to the #key property

  • :job_key (String)

    The value to assign to the #job_key property

  • :job_type (String)

    The value to assign to the #job_type property

  • :parent_key (String)

    The value to assign to the #parent_key property

  • :schedule_instance_key (String)

    The value to assign to the #schedule_instance_key property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :time_started (DateTime)

    The value to assign to the #time_started property

  • :time_ended (DateTime)

    The value to assign to the #time_ended property

  • :uri (String)

    The value to assign to the #uri property



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/oci/data_catalog/models/job_execution_summary.rb', line 138

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.key = attributes[:'key'] if attributes[:'key']

  self.job_key = attributes[:'jobKey'] if attributes[:'jobKey']

  raise 'You cannot provide both :jobKey and :job_key' if attributes.key?(:'jobKey') && attributes.key?(:'job_key')

  self.job_key = attributes[:'job_key'] if attributes[:'job_key']

  self.job_type = attributes[:'jobType'] if attributes[:'jobType']

  raise 'You cannot provide both :jobType and :job_type' if attributes.key?(:'jobType') && attributes.key?(:'job_type')

  self.job_type = attributes[:'job_type'] if attributes[:'job_type']

  self.parent_key = attributes[:'parentKey'] if attributes[:'parentKey']

  raise 'You cannot provide both :parentKey and :parent_key' if attributes.key?(:'parentKey') && attributes.key?(:'parent_key')

  self.parent_key = attributes[:'parent_key'] if attributes[:'parent_key']

  self.schedule_instance_key = attributes[:'scheduleInstanceKey'] if attributes[:'scheduleInstanceKey']

  raise 'You cannot provide both :scheduleInstanceKey and :schedule_instance_key' if attributes.key?(:'scheduleInstanceKey') && attributes.key?(:'schedule_instance_key')

  self.schedule_instance_key = attributes[:'schedule_instance_key'] if attributes[:'schedule_instance_key']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_started = attributes[:'timeStarted'] if attributes[:'timeStarted']

  raise 'You cannot provide both :timeStarted and :time_started' if attributes.key?(:'timeStarted') && attributes.key?(:'time_started')

  self.time_started = attributes[:'time_started'] if attributes[:'time_started']

  self.time_ended = attributes[:'timeEnded'] if attributes[:'timeEnded']

  raise 'You cannot provide both :timeEnded and :time_ended' if attributes.key?(:'timeEnded') && attributes.key?(:'time_ended')

  self.time_ended = attributes[:'time_ended'] if attributes[:'time_ended']

  self.uri = attributes[:'uri'] if attributes[:'uri']
end

Instance Attribute Details

#job_keyString

The unique key of the parent job.

Returns:

  • (String)


48
49
50
# File 'lib/oci/data_catalog/models/job_execution_summary.rb', line 48

def job_key
  @job_key
end

#job_typeString

Type of the job execution.

Returns:

  • (String)


52
53
54
# File 'lib/oci/data_catalog/models/job_execution_summary.rb', line 52

def job_type
  @job_type
end

#keyString

[Required] Unique key of the job execution resource.

Returns:

  • (String)


44
45
46
# File 'lib/oci/data_catalog/models/job_execution_summary.rb', line 44

def key
  @key
end

#lifecycle_stateString

Status of the job execution, such as running, paused, or completed.

Returns:

  • (String)


64
65
66
# File 'lib/oci/data_catalog/models/job_execution_summary.rb', line 64

def lifecycle_state
  @lifecycle_state
end

#parent_keyString

The unique key of the parent execution or null if this job execution has no parent.

Returns:

  • (String)


56
57
58
# File 'lib/oci/data_catalog/models/job_execution_summary.rb', line 56

def parent_key
  @parent_key
end

#schedule_instance_keyString

The unique key of the triggering external scheduler resource or null if this job execution is not externally triggered.

Returns:

  • (String)


60
61
62
# File 'lib/oci/data_catalog/models/job_execution_summary.rb', line 60

def schedule_instance_key
  @schedule_instance_key
end

#time_createdDateTime

The date and time the job execution was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339). Example: 2019-03-25T21:10:29.600Z

Returns:

  • (DateTime)


70
71
72
# File 'lib/oci/data_catalog/models/job_execution_summary.rb', line 70

def time_created
  @time_created
end

#time_endedDateTime

Time that the job execution ended or null if it hasn’t yet completed. An [RFC3339](tools.ietf.org/html/rfc3339) formatted datetime string.

Returns:

  • (DateTime)


80
81
82
# File 'lib/oci/data_catalog/models/job_execution_summary.rb', line 80

def time_ended
  @time_ended
end

#time_startedDateTime

Time that job execution started. An [RFC3339](tools.ietf.org/html/rfc3339) formatted datetime string.

Returns:

  • (DateTime)


74
75
76
# File 'lib/oci/data_catalog/models/job_execution_summary.rb', line 74

def time_started
  @time_started
end

#uriString

URI to the job execution instance in the API.

Returns:

  • (String)


84
85
86
# File 'lib/oci/data_catalog/models/job_execution_summary.rb', line 84

def uri
  @uri
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/oci/data_catalog/models/job_execution_summary.rb', line 87

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'key',
    'job_key': :'jobKey',
    'job_type': :'jobType',
    'parent_key': :'parentKey',
    'schedule_instance_key': :'scheduleInstanceKey',
    'lifecycle_state': :'lifecycleState',
    'time_created': :'timeCreated',
    'time_started': :'timeStarted',
    'time_ended': :'timeEnded',
    'uri': :'uri'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/oci/data_catalog/models/job_execution_summary.rb', line 105

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'String',
    'job_key': :'String',
    'job_type': :'String',
    'parent_key': :'String',
    'schedule_instance_key': :'String',
    'lifecycle_state': :'String',
    'time_created': :'DateTime',
    'time_started': :'DateTime',
    'time_ended': :'DateTime',
    'uri': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
# File 'lib/oci/data_catalog/models/job_execution_summary.rb', line 230

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    key == other.key &&
    job_key == other.job_key &&
    job_type == other.job_type &&
    parent_key == other.parent_key &&
    schedule_instance_key == other.schedule_instance_key &&
    lifecycle_state == other.lifecycle_state &&
    time_created == other.time_created &&
    time_started == other.time_started &&
    time_ended == other.time_ended &&
    uri == other.uri
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
# File 'lib/oci/data_catalog/models/job_execution_summary.rb', line 269

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


249
250
251
# File 'lib/oci/data_catalog/models/job_execution_summary.rb', line 249

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



258
259
260
# File 'lib/oci/data_catalog/models/job_execution_summary.rb', line 258

def hash
  [key, job_key, job_type, parent_key, schedule_instance_key, lifecycle_state, time_created, time_started, time_ended, uri].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



302
303
304
305
306
307
308
309
310
311
# File 'lib/oci/data_catalog/models/job_execution_summary.rb', line 302

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



296
297
298
# File 'lib/oci/data_catalog/models/job_execution_summary.rb', line 296

def to_s
  to_hash.to_s
end