Class: OCI::DataCatalog::Models::Pattern
- Inherits:
-
Object
- Object
- OCI::DataCatalog::Models::Pattern
- Defined in:
- lib/oci/data_catalog/models/pattern.rb
Overview
Pattern representation. A Pattern is defined using an expression and can be used as data selectors or filters to provide a singular view of an entity across multiple physical data artifacts.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_MOVING = 'MOVING'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The data catalog’s OCID.
-
#check_failure_limit ⇒ Integer
The maximum number of UNMATCHED files, in checkFilePathList, above which the check fails.
-
#check_file_path_list ⇒ Array<String>
List of file paths against which the expression can be tried, as a check.
-
#created_by_id ⇒ String
OCID of the user who created the pattern.
-
#description ⇒ String
Detailed description of the pattern.
-
#display_name ⇒ String
A user-friendly display name.
-
#expression ⇒ String
The expression used in the pattern that may include qualifiers.
-
#is_enable_check_failure_limit ⇒ BOOLEAN
Indicates whether the expression check, against the checkFilePathList, will fail the request if the count of UNMATCHED files is above the checkFailureLimit.
-
#key ⇒ String
[Required] Unique pattern key that is immutable.
-
#lifecycle_state ⇒ String
The current state of the data asset.
-
#properties ⇒ Hash<String, Hash<String, String>>
A map of maps that contains the properties which are specific to the pattern type.
-
#time_created ⇒ DateTime
The date and time the pattern was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#time_updated ⇒ DateTime
The last time that any change was made to the pattern.
-
#updated_by_id ⇒ String
OCID of the user who last modified the pattern.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Pattern
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Pattern
Initializes the object
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/oci/data_catalog/models/pattern.rb', line 163 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.key = attributes[:'key'] if attributes[:'key'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.catalog_id = attributes[:'catalogId'] if attributes[:'catalogId'] raise 'You cannot provide both :catalogId and :catalog_id' if attributes.key?(:'catalogId') && attributes.key?(:'catalog_id') self.catalog_id = attributes[:'catalog_id'] if attributes[:'catalog_id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.created_by_id = attributes[:'createdById'] if attributes[:'createdById'] raise 'You cannot provide both :createdById and :created_by_id' if attributes.key?(:'createdById') && attributes.key?(:'created_by_id') self.created_by_id = attributes[:'created_by_id'] if attributes[:'created_by_id'] self.updated_by_id = attributes[:'updatedById'] if attributes[:'updatedById'] raise 'You cannot provide both :updatedById and :updated_by_id' if attributes.key?(:'updatedById') && attributes.key?(:'updated_by_id') self.updated_by_id = attributes[:'updated_by_id'] if attributes[:'updated_by_id'] self.expression = attributes[:'expression'] if attributes[:'expression'] self.check_file_path_list = attributes[:'checkFilePathList'] if attributes[:'checkFilePathList'] raise 'You cannot provide both :checkFilePathList and :check_file_path_list' if attributes.key?(:'checkFilePathList') && attributes.key?(:'check_file_path_list') self.check_file_path_list = attributes[:'check_file_path_list'] if attributes[:'check_file_path_list'] self.is_enable_check_failure_limit = attributes[:'isEnableCheckFailureLimit'] unless attributes[:'isEnableCheckFailureLimit'].nil? self.is_enable_check_failure_limit = false if is_enable_check_failure_limit.nil? && !attributes.key?(:'isEnableCheckFailureLimit') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isEnableCheckFailureLimit and :is_enable_check_failure_limit' if attributes.key?(:'isEnableCheckFailureLimit') && attributes.key?(:'is_enable_check_failure_limit') self.is_enable_check_failure_limit = attributes[:'is_enable_check_failure_limit'] unless attributes[:'is_enable_check_failure_limit'].nil? self.is_enable_check_failure_limit = false if is_enable_check_failure_limit.nil? && !attributes.key?(:'isEnableCheckFailureLimit') && !attributes.key?(:'is_enable_check_failure_limit') # rubocop:disable Style/StringLiterals self.check_failure_limit = attributes[:'checkFailureLimit'] if attributes[:'checkFailureLimit'] raise 'You cannot provide both :checkFailureLimit and :check_failure_limit' if attributes.key?(:'checkFailureLimit') && attributes.key?(:'check_failure_limit') self.check_failure_limit = attributes[:'check_failure_limit'] if attributes[:'check_failure_limit'] self.properties = attributes[:'properties'] if attributes[:'properties'] end |
Instance Attribute Details
#catalog_id ⇒ String
The data catalog’s OCID.
41 42 43 |
# File 'lib/oci/data_catalog/models/pattern.rb', line 41 def catalog_id @catalog_id end |
#check_failure_limit ⇒ Integer
The maximum number of UNMATCHED files, in checkFilePathList, above which the check fails. Optional, if checkFilePathList is provided - but if isEnableCheckFailureLimit is set to true it is required.
90 91 92 |
# File 'lib/oci/data_catalog/models/pattern.rb', line 90 def check_failure_limit @check_failure_limit end |
#check_file_path_list ⇒ Array<String>
List of file paths against which the expression can be tried, as a check. This documents, for reference purposes, some example objects a pattern is meant to work with. If isEnableCheckFailureLimit is set to true, this will be run as a validation during the request, such that if the check fails the request fails. If isEnableCheckFailureLimit instead is set to (the default) false, a pattern will still be created or updated even if the check fails, with a lifecycleState of FAILED.
78 79 80 |
# File 'lib/oci/data_catalog/models/pattern.rb', line 78 def check_file_path_list @check_file_path_list end |
#created_by_id ⇒ String
OCID of the user who created the pattern.
60 61 62 |
# File 'lib/oci/data_catalog/models/pattern.rb', line 60 def created_by_id @created_by_id end |
#description ⇒ String
Detailed description of the pattern.
37 38 39 |
# File 'lib/oci/data_catalog/models/pattern.rb', line 37 def description @description end |
#display_name ⇒ String
A user-friendly display name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
33 34 35 |
# File 'lib/oci/data_catalog/models/pattern.rb', line 33 def display_name @display_name end |
#expression ⇒ String
The expression used in the pattern that may include qualifiers. Refer to the user documentation for details of the format and examples.
69 70 71 |
# File 'lib/oci/data_catalog/models/pattern.rb', line 69 def expression @expression end |
#is_enable_check_failure_limit ⇒ BOOLEAN
Indicates whether the expression check, against the checkFilePathList, will fail the request if the count of UNMATCHED files is above the checkFailureLimit.
84 85 86 |
# File 'lib/oci/data_catalog/models/pattern.rb', line 84 def is_enable_check_failure_limit @is_enable_check_failure_limit end |
#key ⇒ String
[Required] Unique pattern key that is immutable.
27 28 29 |
# File 'lib/oci/data_catalog/models/pattern.rb', line 27 def key @key end |
#lifecycle_state ⇒ String
The current state of the data asset.
45 46 47 |
# File 'lib/oci/data_catalog/models/pattern.rb', line 45 def lifecycle_state @lifecycle_state end |
#properties ⇒ Hash<String, Hash<String, String>>
A map of maps that contains the properties which are specific to the pattern type. Each pattern type definition defines it’s set of required and optional properties. Example: ‘{ "default": { "tbd"}}`
97 98 99 |
# File 'lib/oci/data_catalog/models/pattern.rb', line 97 def properties @properties end |
#time_created ⇒ DateTime
The date and time the pattern was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339). Example: 2019-03-25T21:10:29.600Z
51 52 53 |
# File 'lib/oci/data_catalog/models/pattern.rb', line 51 def time_created @time_created end |
#time_updated ⇒ DateTime
The last time that any change was made to the pattern. An [RFC3339](tools.ietf.org/html/rfc3339) formatted datetime string.
56 57 58 |
# File 'lib/oci/data_catalog/models/pattern.rb', line 56 def time_updated @time_updated end |
#updated_by_id ⇒ String
OCID of the user who last modified the pattern.
64 65 66 |
# File 'lib/oci/data_catalog/models/pattern.rb', line 64 def updated_by_id @updated_by_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/oci/data_catalog/models/pattern.rb', line 100 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'key': :'key', 'display_name': :'displayName', 'description': :'description', 'catalog_id': :'catalogId', 'lifecycle_state': :'lifecycleState', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'created_by_id': :'createdById', 'updated_by_id': :'updatedById', 'expression': :'expression', 'check_file_path_list': :'checkFilePathList', 'is_enable_check_failure_limit': :'isEnableCheckFailureLimit', 'check_failure_limit': :'checkFailureLimit', 'properties': :'properties' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/oci/data_catalog/models/pattern.rb', line 122 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'key': :'String', 'display_name': :'String', 'description': :'String', 'catalog_id': :'String', 'lifecycle_state': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'created_by_id': :'String', 'updated_by_id': :'String', 'expression': :'String', 'check_file_path_list': :'Array<String>', 'is_enable_check_failure_limit': :'BOOLEAN', 'check_failure_limit': :'Integer', 'properties': :'Hash<String, Hash<String, String>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 |
# File 'lib/oci/data_catalog/models/pattern.rb', line 260 def ==(other) return true if equal?(other) self.class == other.class && key == other.key && display_name == other.display_name && description == other.description && catalog_id == other.catalog_id && lifecycle_state == other.lifecycle_state && time_created == other.time_created && time_updated == other.time_updated && created_by_id == other.created_by_id && updated_by_id == other.updated_by_id && expression == other.expression && check_file_path_list == other.check_file_path_list && is_enable_check_failure_limit == other.is_enable_check_failure_limit && check_failure_limit == other.check_failure_limit && properties == other.properties end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 |
# File 'lib/oci/data_catalog/models/pattern.rb', line 303 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
283 284 285 |
# File 'lib/oci/data_catalog/models/pattern.rb', line 283 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
292 293 294 |
# File 'lib/oci/data_catalog/models/pattern.rb', line 292 def hash [key, display_name, description, catalog_id, lifecycle_state, time_created, time_updated, created_by_id, updated_by_id, expression, check_file_path_list, is_enable_check_failure_limit, check_failure_limit, properties].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
336 337 338 339 340 341 342 343 344 345 |
# File 'lib/oci/data_catalog/models/pattern.rb', line 336 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
330 331 332 |
# File 'lib/oci/data_catalog/models/pattern.rb', line 330 def to_s to_hash.to_s end |