Class: OCI::DataCatalog::Models::PatternSummary
- Inherits:
-
Object
- Object
- OCI::DataCatalog::Models::PatternSummary
- Defined in:
- lib/oci/data_catalog/models/pattern_summary.rb
Overview
Summary of a pattern. A pattern is a data selector or filter which can provide a singular, logical entity view aggregating multiple physical data artifacts for ease of use.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_MOVING = 'MOVING'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The data catalog’s OCID.
-
#description ⇒ String
Detailed description of the pattern.
-
#display_name ⇒ String
A user-friendly display name.
-
#expression ⇒ String
Input string which drives the selection process, allowing for fine-grained control using qualifiers.
-
#file_path_prefix ⇒ String
Input string which drives the selection process.
-
#key ⇒ String
[Required] Unique pattern key that is immutable.
-
#lifecycle_state ⇒ String
State of the pattern.
-
#time_created ⇒ DateTime
The date and time the pattern was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PatternSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ PatternSummary
Initializes the object
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/oci/data_catalog/models/pattern_summary.rb', line 113 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.key = attributes[:'key'] if attributes[:'key'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.catalog_id = attributes[:'catalogId'] if attributes[:'catalogId'] raise 'You cannot provide both :catalogId and :catalog_id' if attributes.key?(:'catalogId') && attributes.key?(:'catalog_id') self.catalog_id = attributes[:'catalog_id'] if attributes[:'catalog_id'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.expression = attributes[:'expression'] if attributes[:'expression'] self.file_path_prefix = attributes[:'filePathPrefix'] if attributes[:'filePathPrefix'] raise 'You cannot provide both :filePathPrefix and :file_path_prefix' if attributes.key?(:'filePathPrefix') && attributes.key?(:'file_path_prefix') self.file_path_prefix = attributes[:'file_path_prefix'] if attributes[:'file_path_prefix'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] end |
Instance Attribute Details
#catalog_id ⇒ String
The data catalog’s OCID.
41 42 43 |
# File 'lib/oci/data_catalog/models/pattern_summary.rb', line 41 def catalog_id @catalog_id end |
#description ⇒ String
Detailed description of the pattern.
37 38 39 |
# File 'lib/oci/data_catalog/models/pattern_summary.rb', line 37 def description @description end |
#display_name ⇒ String
A user-friendly display name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
33 34 35 |
# File 'lib/oci/data_catalog/models/pattern_summary.rb', line 33 def display_name @display_name end |
#expression ⇒ String
Input string which drives the selection process, allowing for fine-grained control using qualifiers. Refer to the user documentation for details of the format and examples. A pattern cannot include both a prefix and an expression.
54 55 56 |
# File 'lib/oci/data_catalog/models/pattern_summary.rb', line 54 def expression @expression end |
#file_path_prefix ⇒ String
Input string which drives the selection process. Refer to the user documentation for details of the format and examples. A pattern cannot include both a prefix and an expression.
61 62 63 |
# File 'lib/oci/data_catalog/models/pattern_summary.rb', line 61 def file_path_prefix @file_path_prefix end |
#key ⇒ String
[Required] Unique pattern key that is immutable.
27 28 29 |
# File 'lib/oci/data_catalog/models/pattern_summary.rb', line 27 def key @key end |
#lifecycle_state ⇒ String
State of the pattern.
65 66 67 |
# File 'lib/oci/data_catalog/models/pattern_summary.rb', line 65 def lifecycle_state @lifecycle_state end |
#time_created ⇒ DateTime
The date and time the pattern was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339). Example: 2019-03-25T21:10:29.600Z
47 48 49 |
# File 'lib/oci/data_catalog/models/pattern_summary.rb', line 47 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/oci/data_catalog/models/pattern_summary.rb', line 68 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'key': :'key', 'display_name': :'displayName', 'description': :'description', 'catalog_id': :'catalogId', 'time_created': :'timeCreated', 'expression': :'expression', 'file_path_prefix': :'filePathPrefix', 'lifecycle_state': :'lifecycleState' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/oci/data_catalog/models/pattern_summary.rb', line 84 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'key': :'String', 'display_name': :'String', 'description': :'String', 'catalog_id': :'String', 'time_created': :'DateTime', 'expression': :'String', 'file_path_prefix': :'String', 'lifecycle_state': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/oci/data_catalog/models/pattern_summary.rb', line 176 def ==(other) return true if equal?(other) self.class == other.class && key == other.key && display_name == other.display_name && description == other.description && catalog_id == other.catalog_id && time_created == other.time_created && expression == other.expression && file_path_prefix == other.file_path_prefix && lifecycle_state == other.lifecycle_state end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 |
# File 'lib/oci/data_catalog/models/pattern_summary.rb', line 213 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
193 194 195 |
# File 'lib/oci/data_catalog/models/pattern_summary.rb', line 193 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
202 203 204 |
# File 'lib/oci/data_catalog/models/pattern_summary.rb', line 202 def hash [key, display_name, description, catalog_id, time_created, expression, file_path_prefix, lifecycle_state].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
246 247 248 249 250 251 252 253 254 255 |
# File 'lib/oci/data_catalog/models/pattern_summary.rb', line 246 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
240 241 242 |
# File 'lib/oci/data_catalog/models/pattern_summary.rb', line 240 def to_s to_hash.to_s end |