Class: OCI::DataCatalog::Models::SearchCriteria

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_catalog/models/search_criteria.rb

Overview

Search Query object that allows complex search predicates that cannot be expressed through simple query params.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ SearchCriteria

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/oci/data_catalog/models/search_criteria.rb', line 67

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.query = attributes[:'query'] if attributes[:'query']

  self.faceted_query = attributes[:'facetedQuery'] if attributes[:'facetedQuery']

  raise 'You cannot provide both :facetedQuery and :faceted_query' if attributes.key?(:'facetedQuery') && attributes.key?(:'faceted_query')

  self.faceted_query = attributes[:'faceted_query'] if attributes[:'faceted_query']

  self.dimensions = attributes[:'dimensions'] if attributes[:'dimensions']

  self.sort = attributes[:'sort'] if attributes[:'sort']

  self.filters = attributes[:'filters'] if attributes[:'filters']
end

Instance Attribute Details

#dimensionsArray<String>

List of properties of dataObjects that needs to aggregated on for facets.

Returns:

  • (Array<String>)


21
22
23
# File 'lib/oci/data_catalog/models/search_criteria.rb', line 21

def dimensions
  @dimensions
end

#faceted_queryString

Query string that a dataObject is to be searched with. Used in the faceted query request

Returns:

  • (String)


17
18
19
# File 'lib/oci/data_catalog/models/search_criteria.rb', line 17

def faceted_query
  @faceted_query
end

#filtersOCI::DataCatalog::Models::FacetedSearchFilterRequest



28
29
30
# File 'lib/oci/data_catalog/models/search_criteria.rb', line 28

def filters
  @filters
end

#queryString

Search query dsl that defines the query components including fields and predicates.

Returns:

  • (String)


13
14
15
# File 'lib/oci/data_catalog/models/search_criteria.rb', line 13

def query
  @query
end

#sortArray<OCI::DataCatalog::Models::FacetedSearchSortRequest>

Array of objects having details about sort field and order.



25
26
27
# File 'lib/oci/data_catalog/models/search_criteria.rb', line 25

def sort
  @sort
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
40
41
# File 'lib/oci/data_catalog/models/search_criteria.rb', line 31

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'query': :'query',
    'faceted_query': :'facetedQuery',
    'dimensions': :'dimensions',
    'sort': :'sort',
    'filters': :'filters'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



44
45
46
47
48
49
50
51
52
53
54
# File 'lib/oci/data_catalog/models/search_criteria.rb', line 44

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'query': :'String',
    'faceted_query': :'String',
    'dimensions': :'Array<String>',
    'sort': :'Array<OCI::DataCatalog::Models::FacetedSearchSortRequest>',
    'filters': :'OCI::DataCatalog::Models::FacetedSearchFilterRequest'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



95
96
97
98
99
100
101
102
103
104
# File 'lib/oci/data_catalog/models/search_criteria.rb', line 95

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    query == other.query &&
    faceted_query == other.faceted_query &&
    dimensions == other.dimensions &&
    sort == other.sort &&
    filters == other.filters
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/oci/data_catalog/models/search_criteria.rb', line 129

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


109
110
111
# File 'lib/oci/data_catalog/models/search_criteria.rb', line 109

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



118
119
120
# File 'lib/oci/data_catalog/models/search_criteria.rb', line 118

def hash
  [query, faceted_query, dimensions, sort, filters].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



162
163
164
165
166
167
168
169
170
171
# File 'lib/oci/data_catalog/models/search_criteria.rb', line 162

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



156
157
158
# File 'lib/oci/data_catalog/models/search_criteria.rb', line 156

def to_s
  to_hash.to_s
end