Class: OCI::DataCatalog::Models::SearchResult

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_catalog/models/search_result.rb

Overview

The search result object is the definition of an element that is returned as part of search. It contains basic information about the object such as key, name and description. The search result also contains the list of tags for each object along with other contextual information like the data asset root, folder, or entity parents.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_MOVING = 'MOVING'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ SearchResult

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
# File 'lib/oci/data_catalog/models/search_result.rb', line 280

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.key = attributes[:'key'] if attributes[:'key']

  self.name = attributes[:'name'] if attributes[:'name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.tag_summary = attributes[:'tagSummary'] if attributes[:'tagSummary']

  raise 'You cannot provide both :tagSummary and :tag_summary' if attributes.key?(:'tagSummary') && attributes.key?(:'tag_summary')

  self.tag_summary = attributes[:'tag_summary'] if attributes[:'tag_summary']

  self.term_summary = attributes[:'termSummary'] if attributes[:'termSummary']

  raise 'You cannot provide both :termSummary and :term_summary' if attributes.key?(:'termSummary') && attributes.key?(:'term_summary')

  self.term_summary = attributes[:'term_summary'] if attributes[:'term_summary']

  self.type_name = attributes[:'typeName'] if attributes[:'typeName']

  raise 'You cannot provide both :typeName and :type_name' if attributes.key?(:'typeName') && attributes.key?(:'type_name')

  self.type_name = attributes[:'type_name'] if attributes[:'type_name']

  self.external_type_name = attributes[:'externalTypeName'] if attributes[:'externalTypeName']

  raise 'You cannot provide both :externalTypeName and :external_type_name' if attributes.key?(:'externalTypeName') && attributes.key?(:'external_type_name')

  self.external_type_name = attributes[:'external_type_name'] if attributes[:'external_type_name']

  self.external_data_type = attributes[:'externalDataType'] if attributes[:'externalDataType']

  raise 'You cannot provide both :externalDataType and :external_data_type' if attributes.key?(:'externalDataType') && attributes.key?(:'external_data_type')

  self.external_data_type = attributes[:'external_data_type'] if attributes[:'external_data_type']

  self.data_asset_key = attributes[:'dataAssetKey'] if attributes[:'dataAssetKey']

  raise 'You cannot provide both :dataAssetKey and :data_asset_key' if attributes.key?(:'dataAssetKey') && attributes.key?(:'data_asset_key')

  self.data_asset_key = attributes[:'data_asset_key'] if attributes[:'data_asset_key']

  self.data_asset_type = attributes[:'dataAssetType'] if attributes[:'dataAssetType']

  raise 'You cannot provide both :dataAssetType and :data_asset_type' if attributes.key?(:'dataAssetType') && attributes.key?(:'data_asset_type')

  self.data_asset_type = attributes[:'data_asset_type'] if attributes[:'data_asset_type']

  self.data_asset_name = attributes[:'dataAssetName'] if attributes[:'dataAssetName']

  raise 'You cannot provide both :dataAssetName and :data_asset_name' if attributes.key?(:'dataAssetName') && attributes.key?(:'data_asset_name')

  self.data_asset_name = attributes[:'data_asset_name'] if attributes[:'data_asset_name']

  self.folder_key = attributes[:'folderKey'] if attributes[:'folderKey']

  raise 'You cannot provide both :folderKey and :folder_key' if attributes.key?(:'folderKey') && attributes.key?(:'folder_key')

  self.folder_key = attributes[:'folder_key'] if attributes[:'folder_key']

  self.folder_type = attributes[:'folderType'] if attributes[:'folderType']

  raise 'You cannot provide both :folderType and :folder_type' if attributes.key?(:'folderType') && attributes.key?(:'folder_type')

  self.folder_type = attributes[:'folder_type'] if attributes[:'folder_type']

  self.folder_name = attributes[:'folderName'] if attributes[:'folderName']

  raise 'You cannot provide both :folderName and :folder_name' if attributes.key?(:'folderName') && attributes.key?(:'folder_name')

  self.folder_name = attributes[:'folder_name'] if attributes[:'folder_name']

  self.entitykey = attributes[:'entitykey'] if attributes[:'entitykey']

  self.entity_type = attributes[:'entityType'] if attributes[:'entityType']

  raise 'You cannot provide both :entityType and :entity_type' if attributes.key?(:'entityType') && attributes.key?(:'entity_type')

  self.entity_type = attributes[:'entity_type'] if attributes[:'entity_type']

  self.entity_name = attributes[:'entityName'] if attributes[:'entityName']

  raise 'You cannot provide both :entityName and :entity_name' if attributes.key?(:'entityName') && attributes.key?(:'entity_name')

  self.entity_name = attributes[:'entity_name'] if attributes[:'entity_name']

  self.glossary_key = attributes[:'glossaryKey'] if attributes[:'glossaryKey']

  raise 'You cannot provide both :glossaryKey and :glossary_key' if attributes.key?(:'glossaryKey') && attributes.key?(:'glossary_key')

  self.glossary_key = attributes[:'glossary_key'] if attributes[:'glossary_key']

  self.glossary_name = attributes[:'glossaryName'] if attributes[:'glossaryName']

  raise 'You cannot provide both :glossaryName and :glossary_name' if attributes.key?(:'glossaryName') && attributes.key?(:'glossary_name')

  self.glossary_name = attributes[:'glossary_name'] if attributes[:'glossary_name']

  self.parent_term_key = attributes[:'parentTermKey'] if attributes[:'parentTermKey']

  raise 'You cannot provide both :parentTermKey and :parent_term_key' if attributes.key?(:'parentTermKey') && attributes.key?(:'parent_term_key')

  self.parent_term_key = attributes[:'parent_term_key'] if attributes[:'parent_term_key']

  self.parent_term_name = attributes[:'parentTermName'] if attributes[:'parentTermName']

  raise 'You cannot provide both :parentTermName and :parent_term_name' if attributes.key?(:'parentTermName') && attributes.key?(:'parent_term_name')

  self.parent_term_name = attributes[:'parent_term_name'] if attributes[:'parent_term_name']

  self.created_by_id = attributes[:'createdById'] if attributes[:'createdById']

  raise 'You cannot provide both :createdById and :created_by_id' if attributes.key?(:'createdById') && attributes.key?(:'created_by_id')

  self.created_by_id = attributes[:'created_by_id'] if attributes[:'created_by_id']

  self.updated_by_id = attributes[:'updatedById'] if attributes[:'updatedById']

  raise 'You cannot provide both :updatedById and :updated_by_id' if attributes.key?(:'updatedById') && attributes.key?(:'updated_by_id')

  self.updated_by_id = attributes[:'updated_by_id'] if attributes[:'updated_by_id']

  self.path = attributes[:'path'] if attributes[:'path']

  self.business_name = attributes[:'businessName'] if attributes[:'businessName']

  raise 'You cannot provide both :businessName and :business_name' if attributes.key?(:'businessName') && attributes.key?(:'business_name')

  self.business_name = attributes[:'business_name'] if attributes[:'business_name']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.attribute_type = attributes[:'attributeType'] if attributes[:'attributeType']

  raise 'You cannot provide both :attributeType and :attribute_type' if attributes.key?(:'attributeType') && attributes.key?(:'attribute_type')

  self.attribute_type = attributes[:'attribute_type'] if attributes[:'attribute_type']

  self.expression = attributes[:'expression'] if attributes[:'expression']

  self.custom_properties = attributes[:'customProperties'] if attributes[:'customProperties']

  raise 'You cannot provide both :customProperties and :custom_properties' if attributes.key?(:'customProperties') && attributes.key?(:'custom_properties')

  self.custom_properties = attributes[:'custom_properties'] if attributes[:'custom_properties']

  self.properties = attributes[:'properties'] if attributes[:'properties']
end

Instance Attribute Details

#attribute_typeString

Type name of the attribute. For example - complex, primitive, or array.

Returns:

  • (String)


144
145
146
# File 'lib/oci/data_catalog/models/search_result.rb', line 144

def attribute_type
  @attribute_type
end

#business_nameString

Optional user friendly business name of the data object. If set, this supplements the harvested display name of the object.

Returns:

  • (String)


136
137
138
# File 'lib/oci/data_catalog/models/search_result.rb', line 136

def business_name
  @business_name
end

#created_by_idString

OCID of the user who created the resource.

Returns:

  • (String)


124
125
126
# File 'lib/oci/data_catalog/models/search_result.rb', line 124

def created_by_id
  @created_by_id
end

#custom_propertiesArray<OCI::DataCatalog::Models::FacetedSearchCustomProperty>

Custom properties defined by users.



152
153
154
# File 'lib/oci/data_catalog/models/search_result.rb', line 152

def custom_properties
  @custom_properties
end

#data_asset_keyString

Unique key of the data asset that is the root parent of this object.

Returns:

  • (String)


72
73
74
# File 'lib/oci/data_catalog/models/search_result.rb', line 72

def data_asset_key
  @data_asset_key
end

#data_asset_nameString

Name of the data asset that is the root parent of this object.

Returns:

  • (String)


80
81
82
# File 'lib/oci/data_catalog/models/search_result.rb', line 80

def data_asset_name
  @data_asset_name
end

#data_asset_typeString

Type name of the data asset. For example, Oracle, MySQL or Oracle Object Storage.

Returns:

  • (String)


76
77
78
# File 'lib/oci/data_catalog/models/search_result.rb', line 76

def data_asset_type
  @data_asset_type
end

#descriptionString

Detailed description of the object.

Returns:

  • (String)


36
37
38
# File 'lib/oci/data_catalog/models/search_result.rb', line 36

def description
  @description
end

#entity_nameString

Name of the parent entity object if this object is an attribute.

Returns:

  • (String)


104
105
106
# File 'lib/oci/data_catalog/models/search_result.rb', line 104

def entity_name
  @entity_name
end

#entity_typeString

Type name of the entity. For example, table, view, external table, file, or object.

Returns:

  • (String)


100
101
102
# File 'lib/oci/data_catalog/models/search_result.rb', line 100

def entity_type
  @entity_type
end

#entitykeyString

Unique key of the entity object if this object is an attribute.

Returns:

  • (String)


96
97
98
# File 'lib/oci/data_catalog/models/search_result.rb', line 96

def entitykey
  @entitykey
end

#expressionString

Expression for logical entities against which names of dataObjects will be matched.

Returns:

  • (String)


148
149
150
# File 'lib/oci/data_catalog/models/search_result.rb', line 148

def expression
  @expression
end

#external_data_typeString

Data type of the object if the object is an attribute. Null otherwise.

Returns:

  • (String)


68
69
70
# File 'lib/oci/data_catalog/models/search_result.rb', line 68

def external_data_type
  @external_data_type
end

#external_type_nameString

Name of the external object type in the host data asset. For example, column, field, table, view, or file.

Returns:

  • (String)


64
65
66
# File 'lib/oci/data_catalog/models/search_result.rb', line 64

def external_type_name
  @external_type_name
end

#folder_keyString

Unique key of the folder object if this object is a sub folder, entity, or attribute.

Returns:

  • (String)


84
85
86
# File 'lib/oci/data_catalog/models/search_result.rb', line 84

def folder_key
  @folder_key
end

#folder_nameString

Name of the parent folder object if this object is a sub folder, entity, or attribute.

Returns:

  • (String)


92
93
94
# File 'lib/oci/data_catalog/models/search_result.rb', line 92

def folder_name
  @folder_name
end

#folder_typeString

Type name of the folder. For example, schema, directory, or topic.

Returns:

  • (String)


88
89
90
# File 'lib/oci/data_catalog/models/search_result.rb', line 88

def folder_type
  @folder_type
end

#glossary_keyString

Unique id of the parent glossary.

Returns:

  • (String)


108
109
110
# File 'lib/oci/data_catalog/models/search_result.rb', line 108

def glossary_key
  @glossary_key
end

#glossary_nameString

Name of the parent glossary if this object is a term.

Returns:

  • (String)


112
113
114
# File 'lib/oci/data_catalog/models/search_result.rb', line 112

def glossary_name
  @glossary_name
end

#keyString

Unique key of the object returned as part of the search result.

Returns:

  • (String)


28
29
30
# File 'lib/oci/data_catalog/models/search_result.rb', line 28

def key
  @key
end

#lifecycle_stateString

The current state of the data object.

Returns:

  • (String)


140
141
142
# File 'lib/oci/data_catalog/models/search_result.rb', line 140

def lifecycle_state
  @lifecycle_state
end

#nameString

Name of the object.

Returns:

  • (String)


32
33
34
# File 'lib/oci/data_catalog/models/search_result.rb', line 32

def name
  @name
end

#parent_term_keyString

This terms parent term key. Will be null if the term has no parent term.

Returns:

  • (String)


116
117
118
# File 'lib/oci/data_catalog/models/search_result.rb', line 116

def parent_term_key
  @parent_term_key
end

#parent_term_nameString

Name of the parent term. Will be null if the term has no parent term.

Returns:

  • (String)


120
121
122
# File 'lib/oci/data_catalog/models/search_result.rb', line 120

def parent_term_name
  @parent_term_name
end

#pathString

Absolute path of this resource, which could be a term, folder, entity etc, usually resolvable to this resource through a namespace hierarchy.

Returns:

  • (String)


132
133
134
# File 'lib/oci/data_catalog/models/search_result.rb', line 132

def path
  @path
end

#propertiesHash<String, Hash<String, String>>

A map of maps that contains the properties which are specific to the element type in the search result. The map keys are category names and the values are maps of property name to property value. Every property is contained inside of a category. Most element types have required properties within the "default" category. Example: `{ "default": { "key1": "value1"}}`

Returns:

  • (Hash<String, Hash<String, String>>)


160
161
162
# File 'lib/oci/data_catalog/models/search_result.rb', line 160

def properties
  @properties
end

#tag_summaryArray<OCI::DataCatalog::Models::SearchTagSummary>

Array of the tags associated with this object.



52
53
54
# File 'lib/oci/data_catalog/models/search_result.rb', line 52

def tag_summary
  @tag_summary
end

#term_summaryArray<OCI::DataCatalog::Models::SearchTermSummary>

Array of the terms associated with this object.



56
57
58
# File 'lib/oci/data_catalog/models/search_result.rb', line 56

def term_summary
  @term_summary
end

#time_createdDateTime

The date and time the result object was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339). Example: `2019-03-25T21:10:29.600Z`

Returns:

  • (DateTime)


42
43
44
# File 'lib/oci/data_catalog/models/search_result.rb', line 42

def time_created
  @time_created
end

#time_updatedDateTime

The date and time the result object was updated, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339). Example: `2019-03-25T21:10:29.600Z`

Returns:

  • (DateTime)


48
49
50
# File 'lib/oci/data_catalog/models/search_result.rb', line 48

def time_updated
  @time_updated
end

#type_nameString

Name of the object type.

Returns:

  • (String)


60
61
62
# File 'lib/oci/data_catalog/models/search_result.rb', line 60

def type_name
  @type_name
end

#updated_by_idString

OCID of the user who updated the resource.

Returns:

  • (String)


128
129
130
# File 'lib/oci/data_catalog/models/search_result.rb', line 128

def updated_by_id
  @updated_by_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/oci/data_catalog/models/search_result.rb', line 163

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'key',
    'name': :'name',
    'description': :'description',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'tag_summary': :'tagSummary',
    'term_summary': :'termSummary',
    'type_name': :'typeName',
    'external_type_name': :'externalTypeName',
    'external_data_type': :'externalDataType',
    'data_asset_key': :'dataAssetKey',
    'data_asset_type': :'dataAssetType',
    'data_asset_name': :'dataAssetName',
    'folder_key': :'folderKey',
    'folder_type': :'folderType',
    'folder_name': :'folderName',
    'entitykey': :'entitykey',
    'entity_type': :'entityType',
    'entity_name': :'entityName',
    'glossary_key': :'glossaryKey',
    'glossary_name': :'glossaryName',
    'parent_term_key': :'parentTermKey',
    'parent_term_name': :'parentTermName',
    'created_by_id': :'createdById',
    'updated_by_id': :'updatedById',
    'path': :'path',
    'business_name': :'businessName',
    'lifecycle_state': :'lifecycleState',
    'attribute_type': :'attributeType',
    'expression': :'expression',
    'custom_properties': :'customProperties',
    'properties': :'properties'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/oci/data_catalog/models/search_result.rb', line 203

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'String',
    'name': :'String',
    'description': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'tag_summary': :'Array<OCI::DataCatalog::Models::SearchTagSummary>',
    'term_summary': :'Array<OCI::DataCatalog::Models::SearchTermSummary>',
    'type_name': :'String',
    'external_type_name': :'String',
    'external_data_type': :'String',
    'data_asset_key': :'String',
    'data_asset_type': :'String',
    'data_asset_name': :'String',
    'folder_key': :'String',
    'folder_type': :'String',
    'folder_name': :'String',
    'entitykey': :'String',
    'entity_type': :'String',
    'entity_name': :'String',
    'glossary_key': :'String',
    'glossary_name': :'String',
    'parent_term_key': :'String',
    'parent_term_name': :'String',
    'created_by_id': :'String',
    'updated_by_id': :'String',
    'path': :'String',
    'business_name': :'String',
    'lifecycle_state': :'String',
    'attribute_type': :'String',
    'expression': :'String',
    'custom_properties': :'Array<OCI::DataCatalog::Models::FacetedSearchCustomProperty>',
    'properties': :'Hash<String, Hash<String, String>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
# File 'lib/oci/data_catalog/models/search_result.rb', line 471

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    key == other.key &&
    name == other.name &&
    description == other.description &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    tag_summary == other.tag_summary &&
    term_summary == other.term_summary &&
    type_name == other.type_name &&
    external_type_name == other.external_type_name &&
    external_data_type == other.external_data_type &&
    data_asset_key == other.data_asset_key &&
    data_asset_type == other.data_asset_type &&
    data_asset_name == other.data_asset_name &&
    folder_key == other.folder_key &&
    folder_type == other.folder_type &&
    folder_name == other.folder_name &&
    entitykey == other.entitykey &&
    entity_type == other.entity_type &&
    entity_name == other.entity_name &&
    glossary_key == other.glossary_key &&
    glossary_name == other.glossary_name &&
    parent_term_key == other.parent_term_key &&
    parent_term_name == other.parent_term_name &&
    created_by_id == other.created_by_id &&
    updated_by_id == other.updated_by_id &&
    path == other.path &&
    business_name == other.business_name &&
    lifecycle_state == other.lifecycle_state &&
    attribute_type == other.attribute_type &&
    expression == other.expression &&
    custom_properties == other.custom_properties &&
    properties == other.properties
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
# File 'lib/oci/data_catalog/models/search_result.rb', line 532

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


512
513
514
# File 'lib/oci/data_catalog/models/search_result.rb', line 512

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



521
522
523
# File 'lib/oci/data_catalog/models/search_result.rb', line 521

def hash
  [key, name, description, time_created, time_updated, tag_summary, term_summary, type_name, external_type_name, external_data_type, data_asset_key, data_asset_type, data_asset_name, folder_key, folder_type, folder_name, entitykey, entity_type, entity_name, glossary_key, glossary_name, parent_term_key, parent_term_name, created_by_id, updated_by_id, path, business_name, lifecycle_state, attribute_type, expression, custom_properties, properties].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



565
566
567
568
569
570
571
572
573
574
# File 'lib/oci/data_catalog/models/search_result.rb', line 565

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



559
560
561
# File 'lib/oci/data_catalog/models/search_result.rb', line 559

def to_s
  to_hash.to_s
end