Class: OCI::DataCatalog::Models::SearchResultCollection

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_catalog/models/search_result_collection.rb

Overview

The list of search result items matching the criteria returned from the search operation. Search errors and messages, if any , will be part of the standard error response.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ SearchResultCollection

Initializes the object

Options Hash (attributes):

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/oci/data_catalog/models/search_result_collection.rb', line 69

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.count = attributes[:'count'] if attributes[:'count']

  self.items = attributes[:'items'] if attributes[:'items']

  self.query = attributes[:'query'] if attributes[:'query']

  self.faceted_search_aggregation = attributes[:'facetedSearchAggregation'] if attributes[:'facetedSearchAggregation']

  raise 'You cannot provide both :facetedSearchAggregation and :faceted_search_aggregation' if attributes.key?(:'facetedSearchAggregation') && attributes.key?(:'faceted_search_aggregation')

  self.faceted_search_aggregation = attributes[:'faceted_search_aggregation'] if attributes[:'faceted_search_aggregation']

  self.sortable_fields = attributes[:'sortableFields'] if attributes[:'sortableFields']

  raise 'You cannot provide both :sortableFields and :sortable_fields' if attributes.key?(:'sortableFields') && attributes.key?(:'sortable_fields')

  self.sortable_fields = attributes[:'sortable_fields'] if attributes[:'sortable_fields']
end

Instance Attribute Details

#countInteger

Total number of items returned.

Returns:



14
15
16
# File 'lib/oci/data_catalog/models/search_result_collection.rb', line 14

def count
  @count
end

#faceted_search_aggregationArray<OCI::DataCatalog::Models::FacetedSearchAggregation>

Aggregations/facets on properties of data objects.

Returns:



26
27
28
# File 'lib/oci/data_catalog/models/search_result_collection.rb', line 26

def faceted_search_aggregation
  @faceted_search_aggregation
end

#itemsArray<OCI::DataCatalog::Models::SearchResult>

Search result set.

Returns:



18
19
20
# File 'lib/oci/data_catalog/models/search_result_collection.rb', line 18

def items
  @items
end

#queryString

String that data objects are to be searched with.

Returns:



22
23
24
# File 'lib/oci/data_catalog/models/search_result_collection.rb', line 22

def query
  @query
end

#sortable_fieldsArray<String>

A list of fields or properties used in the sorting of a search result.

Returns:



30
31
32
# File 'lib/oci/data_catalog/models/search_result_collection.rb', line 30

def sortable_fields
  @sortable_fields
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



33
34
35
36
37
38
39
40
41
42
43
# File 'lib/oci/data_catalog/models/search_result_collection.rb', line 33

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'count': :'count',
    'items': :'items',
    'query': :'query',
    'faceted_search_aggregation': :'facetedSearchAggregation',
    'sortable_fields': :'sortableFields'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



46
47
48
49
50
51
52
53
54
55
56
# File 'lib/oci/data_catalog/models/search_result_collection.rb', line 46

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'count': :'Integer',
    'items': :'Array<OCI::DataCatalog::Models::SearchResult>',
    'query': :'String',
    'faceted_search_aggregation': :'Array<OCI::DataCatalog::Models::FacetedSearchAggregation>',
    'sortable_fields': :'Array<String>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • the other object to be compared



101
102
103
104
105
106
107
108
109
110
# File 'lib/oci/data_catalog/models/search_result_collection.rb', line 101

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    count == other.count &&
    items == other.items &&
    query == other.query &&
    faceted_search_aggregation == other.faceted_search_aggregation &&
    sortable_fields == other.sortable_fields
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/oci/data_catalog/models/search_result_collection.rb', line 135

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method

Parameters:

  • the other object to be compared

Returns:



115
116
117
# File 'lib/oci/data_catalog/models/search_result_collection.rb', line 115

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • Hash code



124
125
126
# File 'lib/oci/data_catalog/models/search_result_collection.rb', line 124

def hash
  [count, items, query, faceted_search_aggregation, sortable_fields].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



168
169
170
171
172
173
174
175
176
177
# File 'lib/oci/data_catalog/models/search_result_collection.rb', line 168

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



162
163
164
# File 'lib/oci/data_catalog/models/search_result_collection.rb', line 162

def to_s
  to_hash.to_s
end