Class: OCI::DataCatalog::Models::TermSummary
- Inherits:
-
Object
- Object
- OCI::DataCatalog::Models::TermSummary
- Defined in:
- lib/oci/data_catalog/models/term_summary.rb
Overview
Summary of a term. A defined business term in a business glossary. As well as a term definition, simple format rules for attributes mapping to the term (for example, the expected data type and length restrictions) may be stated at the term level.
Constant Summary collapse
- WORKFLOW_STATUS_ENUM =
[ WORKFLOW_STATUS_NEW = 'NEW'.freeze, WORKFLOW_STATUS_APPROVED = 'APPROVED'.freeze, WORKFLOW_STATUS_UNDER_REVIEW = 'UNDER_REVIEW'.freeze, WORKFLOW_STATUS_ESCALATED = 'ESCALATED'.freeze, WORKFLOW_STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_MOVING = 'MOVING'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#associated_object_count ⇒ Integer
The number of objects tagged with this term.
-
#description ⇒ String
Detailed description of the term.
-
#display_name ⇒ String
A user-friendly display name.
-
#glossary_key ⇒ String
Unique id of the parent glossary.
-
#is_allowed_to_have_child_terms ⇒ BOOLEAN
Indicates whether a term may contain child terms.
-
#key ⇒ String
**[Required]** Unique term key that is immutable.
-
#lifecycle_state ⇒ String
State of the term.
-
#parent_term_key ⇒ String
This terms parent term key.
-
#path ⇒ String
Absolute path of the term.
-
#time_created ⇒ DateTime
The date and time the term was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#uri ⇒ String
URI to the term instance in the API.
-
#workflow_status ⇒ String
Status of the approval process workflow for this business term in the glossary.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TermSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ TermSummary
Initializes the object
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/oci/data_catalog/models/term_summary.rb', line 144 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.key = attributes[:'key'] if attributes[:'key'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.glossary_key = attributes[:'glossaryKey'] if attributes[:'glossaryKey'] raise 'You cannot provide both :glossaryKey and :glossary_key' if attributes.key?(:'glossaryKey') && attributes.key?(:'glossary_key') self.glossary_key = attributes[:'glossary_key'] if attributes[:'glossary_key'] self.uri = attributes[:'uri'] if attributes[:'uri'] self.parent_term_key = attributes[:'parentTermKey'] if attributes[:'parentTermKey'] raise 'You cannot provide both :parentTermKey and :parent_term_key' if attributes.key?(:'parentTermKey') && attributes.key?(:'parent_term_key') self.parent_term_key = attributes[:'parent_term_key'] if attributes[:'parent_term_key'] self.is_allowed_to_have_child_terms = attributes[:'isAllowedToHaveChildTerms'] unless attributes[:'isAllowedToHaveChildTerms'].nil? self.is_allowed_to_have_child_terms = true if is_allowed_to_have_child_terms.nil? && !attributes.key?(:'isAllowedToHaveChildTerms') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isAllowedToHaveChildTerms and :is_allowed_to_have_child_terms' if attributes.key?(:'isAllowedToHaveChildTerms') && attributes.key?(:'is_allowed_to_have_child_terms') self.is_allowed_to_have_child_terms = attributes[:'is_allowed_to_have_child_terms'] unless attributes[:'is_allowed_to_have_child_terms'].nil? self.is_allowed_to_have_child_terms = true if is_allowed_to_have_child_terms.nil? && !attributes.key?(:'isAllowedToHaveChildTerms') && !attributes.key?(:'is_allowed_to_have_child_terms') # rubocop:disable Style/StringLiterals self.path = attributes[:'path'] if attributes[:'path'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.workflow_status = attributes[:'workflowStatus'] if attributes[:'workflowStatus'] raise 'You cannot provide both :workflowStatus and :workflow_status' if attributes.key?(:'workflowStatus') && attributes.key?(:'workflow_status') self.workflow_status = attributes[:'workflow_status'] if attributes[:'workflow_status'] self.associated_object_count = attributes[:'associatedObjectCount'] if attributes[:'associatedObjectCount'] raise 'You cannot provide both :associatedObjectCount and :associated_object_count' if attributes.key?(:'associatedObjectCount') && attributes.key?(:'associated_object_count') self.associated_object_count = attributes[:'associated_object_count'] if attributes[:'associated_object_count'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] end |
Instance Attribute Details
#associated_object_count ⇒ Integer
The number of objects tagged with this term.
80 81 82 |
# File 'lib/oci/data_catalog/models/term_summary.rb', line 80 def associated_object_count @associated_object_count end |
#description ⇒ String
Detailed description of the term.
46 47 48 |
# File 'lib/oci/data_catalog/models/term_summary.rb', line 46 def description @description end |
#display_name ⇒ String
A user-friendly display name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
42 43 44 |
# File 'lib/oci/data_catalog/models/term_summary.rb', line 42 def display_name @display_name end |
#glossary_key ⇒ String
Unique id of the parent glossary.
50 51 52 |
# File 'lib/oci/data_catalog/models/term_summary.rb', line 50 def glossary_key @glossary_key end |
#is_allowed_to_have_child_terms ⇒ BOOLEAN
Indicates whether a term may contain child terms.
62 63 64 |
# File 'lib/oci/data_catalog/models/term_summary.rb', line 62 def is_allowed_to_have_child_terms @is_allowed_to_have_child_terms end |
#key ⇒ String
**[Required]** Unique term key that is immutable.
36 37 38 |
# File 'lib/oci/data_catalog/models/term_summary.rb', line 36 def key @key end |
#lifecycle_state ⇒ String
State of the term.
84 85 86 |
# File 'lib/oci/data_catalog/models/term_summary.rb', line 84 def lifecycle_state @lifecycle_state end |
#parent_term_key ⇒ String
This terms parent term key. Will be null if the term has no parent term.
58 59 60 |
# File 'lib/oci/data_catalog/models/term_summary.rb', line 58 def parent_term_key @parent_term_key end |
#path ⇒ String
Absolute path of the term.
66 67 68 |
# File 'lib/oci/data_catalog/models/term_summary.rb', line 66 def path @path end |
#time_created ⇒ DateTime
The date and time the term was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339). Example: `2019-03-25T21:10:29.600Z`
72 73 74 |
# File 'lib/oci/data_catalog/models/term_summary.rb', line 72 def time_created @time_created end |
#uri ⇒ String
URI to the term instance in the API.
54 55 56 |
# File 'lib/oci/data_catalog/models/term_summary.rb', line 54 def uri @uri end |
#workflow_status ⇒ String
Status of the approval process workflow for this business term in the glossary.
76 77 78 |
# File 'lib/oci/data_catalog/models/term_summary.rb', line 76 def workflow_status @workflow_status end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/oci/data_catalog/models/term_summary.rb', line 87 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'key': :'key', 'display_name': :'displayName', 'description': :'description', 'glossary_key': :'glossaryKey', 'uri': :'uri', 'parent_term_key': :'parentTermKey', 'is_allowed_to_have_child_terms': :'isAllowedToHaveChildTerms', 'path': :'path', 'time_created': :'timeCreated', 'workflow_status': :'workflowStatus', 'associated_object_count': :'associatedObjectCount', 'lifecycle_state': :'lifecycleState' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/oci/data_catalog/models/term_summary.rb', line 107 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'key': :'String', 'display_name': :'String', 'description': :'String', 'glossary_key': :'String', 'uri': :'String', 'parent_term_key': :'String', 'is_allowed_to_have_child_terms': :'BOOLEAN', 'path': :'String', 'time_created': :'DateTime', 'workflow_status': :'String', 'associated_object_count': :'Integer', 'lifecycle_state': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/oci/data_catalog/models/term_summary.rb', line 242 def ==(other) return true if equal?(other) self.class == other.class && key == other.key && display_name == other.display_name && description == other.description && glossary_key == other.glossary_key && uri == other.uri && parent_term_key == other.parent_term_key && is_allowed_to_have_child_terms == other.is_allowed_to_have_child_terms && path == other.path && time_created == other.time_created && workflow_status == other.workflow_status && associated_object_count == other.associated_object_count && lifecycle_state == other.lifecycle_state end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'lib/oci/data_catalog/models/term_summary.rb', line 283 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
263 264 265 |
# File 'lib/oci/data_catalog/models/term_summary.rb', line 263 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
272 273 274 |
# File 'lib/oci/data_catalog/models/term_summary.rb', line 272 def hash [key, display_name, description, glossary_key, uri, parent_term_key, is_allowed_to_have_child_terms, path, time_created, workflow_status, associated_object_count, lifecycle_state].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
316 317 318 319 320 321 322 323 324 325 |
# File 'lib/oci/data_catalog/models/term_summary.rb', line 316 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
310 311 312 |
# File 'lib/oci/data_catalog/models/term_summary.rb', line 310 def to_s to_hash.to_s end |