Class: OCI::DataCatalog::Models::UpdateConnectionDetails
- Inherits:
-
Object
- Object
- OCI::DataCatalog::Models::UpdateConnectionDetails
- Defined in:
- lib/oci/data_catalog/models/update_connection_details.rb
Overview
Properties used in connection update operations.
Instance Attribute Summary collapse
-
#custom_property_members ⇒ Array<OCI::DataCatalog::Models::CustomPropertySetUsage>
The list of customized properties along with the values for this object.
-
#description ⇒ String
A description of the connection.
-
#display_name ⇒ String
A user-friendly display name.
-
#enc_properties ⇒ Hash<String, Hash<String, String>>
A map of maps that contains the encrypted values for sensitive properties which are specific to the connection type.
-
#is_default ⇒ BOOLEAN
Indicates whether this connection is the default connection.
-
#properties ⇒ Hash<String, Hash<String, String>>
A map of maps that contains the properties which are specific to the connection type.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateConnectionDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateConnectionDetails
Initializes the object
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/oci/data_catalog/models/update_connection_details.rb', line 92 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.description = attributes[:'description'] if attributes[:'description'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.custom_property_members = attributes[:'customPropertyMembers'] if attributes[:'customPropertyMembers'] raise 'You cannot provide both :customPropertyMembers and :custom_property_members' if attributes.key?(:'customPropertyMembers') && attributes.key?(:'custom_property_members') self.custom_property_members = attributes[:'custom_property_members'] if attributes[:'custom_property_members'] self.properties = attributes[:'properties'] if attributes[:'properties'] self.enc_properties = attributes[:'encProperties'] if attributes[:'encProperties'] raise 'You cannot provide both :encProperties and :enc_properties' if attributes.key?(:'encProperties') && attributes.key?(:'enc_properties') self.enc_properties = attributes[:'enc_properties'] if attributes[:'enc_properties'] self.is_default = attributes[:'isDefault'] unless attributes[:'isDefault'].nil? raise 'You cannot provide both :isDefault and :is_default' if attributes.key?(:'isDefault') && attributes.key?(:'is_default') self.is_default = attributes[:'is_default'] unless attributes[:'is_default'].nil? end |
Instance Attribute Details
#custom_property_members ⇒ Array<OCI::DataCatalog::Models::CustomPropertySetUsage>
The list of customized properties along with the values for this object
22 23 24 |
# File 'lib/oci/data_catalog/models/update_connection_details.rb', line 22 def custom_property_members @custom_property_members end |
#description ⇒ String
A description of the connection.
12 13 14 |
# File 'lib/oci/data_catalog/models/update_connection_details.rb', line 12 def description @description end |
#display_name ⇒ String
A user-friendly display name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
18 19 20 |
# File 'lib/oci/data_catalog/models/update_connection_details.rb', line 18 def display_name @display_name end |
#enc_properties ⇒ Hash<String, Hash<String, String>>
A map of maps that contains the encrypted values for sensitive properties which are specific to the connection type. Each connection type definition defines it’s set of required and optional properties. The map keys are category names and the values are maps of property name to property value. Every property is contained inside of a category. Most connections have required properties within the "default" category. To determine the set of optional and required properties for a connection type, a query can be done on ‘/types?type=connection’ that returns a collection of all connection types. The appropriate connection type, which will include definitions of all of it’s properties, can be identified from this collection. Example: ‘{ "default": { "password": "example-password"}}`
46 47 48 |
# File 'lib/oci/data_catalog/models/update_connection_details.rb', line 46 def enc_properties @enc_properties end |
#is_default ⇒ BOOLEAN
Indicates whether this connection is the default connection.
50 51 52 |
# File 'lib/oci/data_catalog/models/update_connection_details.rb', line 50 def is_default @is_default end |
#properties ⇒ Hash<String, Hash<String, String>>
A map of maps that contains the properties which are specific to the connection type. Each connection type definition defines it’s set of required and optional properties. The map keys are category names and the values are maps of property name to property value. Every property is contained inside of a category. Most connections have required properties within the "default" category. To determine the set of optional and required properties for a connection type, a query can be done on ‘/types?type=connection’ that returns a collection of all connection types. The appropriate connection type, which will include definitions of all of it’s properties, can be identified from this collection. Example: ‘{ "default": { "username": "user1"}}`
34 35 36 |
# File 'lib/oci/data_catalog/models/update_connection_details.rb', line 34 def properties @properties end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/oci/data_catalog/models/update_connection_details.rb', line 53 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'description': :'description', 'display_name': :'displayName', 'custom_property_members': :'customPropertyMembers', 'properties': :'properties', 'enc_properties': :'encProperties', 'is_default': :'isDefault' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/oci/data_catalog/models/update_connection_details.rb', line 67 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'description': :'String', 'display_name': :'String', 'custom_property_members': :'Array<OCI::DataCatalog::Models::CustomPropertySetUsage>', 'properties': :'Hash<String, Hash<String, String>>', 'enc_properties': :'Hash<String, Hash<String, String>>', 'is_default': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/oci/data_catalog/models/update_connection_details.rb', line 134 def ==(other) return true if equal?(other) self.class == other.class && description == other.description && display_name == other.display_name && custom_property_members == other.custom_property_members && properties == other.properties && enc_properties == other.enc_properties && is_default == other.is_default end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/oci/data_catalog/models/update_connection_details.rb', line 169 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
149 150 151 |
# File 'lib/oci/data_catalog/models/update_connection_details.rb', line 149 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
158 159 160 |
# File 'lib/oci/data_catalog/models/update_connection_details.rb', line 158 def hash [description, display_name, custom_property_members, properties, enc_properties, is_default].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
202 203 204 205 206 207 208 209 210 211 |
# File 'lib/oci/data_catalog/models/update_connection_details.rb', line 202 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
196 197 198 |
# File 'lib/oci/data_catalog/models/update_connection_details.rb', line 196 def to_s to_hash.to_s end |