Class: OCI::DataCatalog::Models::UpdateCustomPropertyDetails
- Inherits:
-
Object
- Object
- OCI::DataCatalog::Models::UpdateCustomPropertyDetails
- Defined in:
- lib/oci/data_catalog/models/update_custom_property_details.rb
Overview
Properties used in custom atrribute update operations.
Instance Attribute Summary collapse
-
#allowed_values ⇒ Array<String>
Allowed values for the custom property if any.
-
#description ⇒ String
Detailed description of the data asset.
-
#display_name ⇒ String
A user-friendly display name.
-
#is_editable ⇒ BOOLEAN
If this field is a editable field.
-
#is_filterable ⇒ BOOLEAN
If this field allows to filter or create facets from UI.
-
#is_hidden ⇒ BOOLEAN
If this field is a hidden field.
-
#is_hidden_in_search ⇒ BOOLEAN
If this field is allowed to pop in search results.
-
#is_multi_valued ⇒ BOOLEAN
If this field allows multiple values to be set.
-
#is_shown_in_list ⇒ BOOLEAN
If this field is displayed in a list view of applicable objects.
-
#is_sortable ⇒ BOOLEAN
If this field allows to sort from UI.
-
#properties ⇒ Hash<String, Hash<String, String>>
A map of maps that contains the properties which are specific to the asset type.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateCustomPropertyDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateCustomPropertyDetails
Initializes the object
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/oci/data_catalog/models/update_custom_property_details.rb', line 116 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.is_sortable = attributes[:'isSortable'] unless attributes[:'isSortable'].nil? self.is_sortable = false if is_sortable.nil? && !attributes.key?(:'isSortable') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isSortable and :is_sortable' if attributes.key?(:'isSortable') && attributes.key?(:'is_sortable') self.is_sortable = attributes[:'is_sortable'] unless attributes[:'is_sortable'].nil? self.is_sortable = false if is_sortable.nil? && !attributes.key?(:'isSortable') && !attributes.key?(:'is_sortable') # rubocop:disable Style/StringLiterals self.is_filterable = attributes[:'isFilterable'] unless attributes[:'isFilterable'].nil? self.is_filterable = false if is_filterable.nil? && !attributes.key?(:'isFilterable') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isFilterable and :is_filterable' if attributes.key?(:'isFilterable') && attributes.key?(:'is_filterable') self.is_filterable = attributes[:'is_filterable'] unless attributes[:'is_filterable'].nil? self.is_filterable = false if is_filterable.nil? && !attributes.key?(:'isFilterable') && !attributes.key?(:'is_filterable') # rubocop:disable Style/StringLiterals self.is_multi_valued = attributes[:'isMultiValued'] unless attributes[:'isMultiValued'].nil? self.is_multi_valued = false if is_multi_valued.nil? && !attributes.key?(:'isMultiValued') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isMultiValued and :is_multi_valued' if attributes.key?(:'isMultiValued') && attributes.key?(:'is_multi_valued') self.is_multi_valued = attributes[:'is_multi_valued'] unless attributes[:'is_multi_valued'].nil? self.is_multi_valued = false if is_multi_valued.nil? && !attributes.key?(:'isMultiValued') && !attributes.key?(:'is_multi_valued') # rubocop:disable Style/StringLiterals self.is_hidden = attributes[:'isHidden'] unless attributes[:'isHidden'].nil? self.is_hidden = true if is_hidden.nil? && !attributes.key?(:'isHidden') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isHidden and :is_hidden' if attributes.key?(:'isHidden') && attributes.key?(:'is_hidden') self.is_hidden = attributes[:'is_hidden'] unless attributes[:'is_hidden'].nil? self.is_hidden = true if is_hidden.nil? && !attributes.key?(:'isHidden') && !attributes.key?(:'is_hidden') # rubocop:disable Style/StringLiterals self.is_editable = attributes[:'isEditable'] unless attributes[:'isEditable'].nil? self.is_editable = true if is_editable.nil? && !attributes.key?(:'isEditable') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isEditable and :is_editable' if attributes.key?(:'isEditable') && attributes.key?(:'is_editable') self.is_editable = attributes[:'is_editable'] unless attributes[:'is_editable'].nil? self.is_editable = true if is_editable.nil? && !attributes.key?(:'isEditable') && !attributes.key?(:'is_editable') # rubocop:disable Style/StringLiterals self.is_shown_in_list = attributes[:'isShownInList'] unless attributes[:'isShownInList'].nil? self.is_shown_in_list = false if is_shown_in_list.nil? && !attributes.key?(:'isShownInList') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isShownInList and :is_shown_in_list' if attributes.key?(:'isShownInList') && attributes.key?(:'is_shown_in_list') self.is_shown_in_list = attributes[:'is_shown_in_list'] unless attributes[:'is_shown_in_list'].nil? self.is_shown_in_list = false if is_shown_in_list.nil? && !attributes.key?(:'isShownInList') && !attributes.key?(:'is_shown_in_list') # rubocop:disable Style/StringLiterals self.is_hidden_in_search = attributes[:'isHiddenInSearch'] unless attributes[:'isHiddenInSearch'].nil? self.is_hidden_in_search = false if is_hidden_in_search.nil? && !attributes.key?(:'isHiddenInSearch') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isHiddenInSearch and :is_hidden_in_search' if attributes.key?(:'isHiddenInSearch') && attributes.key?(:'is_hidden_in_search') self.is_hidden_in_search = attributes[:'is_hidden_in_search'] unless attributes[:'is_hidden_in_search'].nil? self.is_hidden_in_search = false if is_hidden_in_search.nil? && !attributes.key?(:'isHiddenInSearch') && !attributes.key?(:'is_hidden_in_search') # rubocop:disable Style/StringLiterals self.allowed_values = attributes[:'allowedValues'] if attributes[:'allowedValues'] raise 'You cannot provide both :allowedValues and :allowed_values' if attributes.key?(:'allowedValues') && attributes.key?(:'allowed_values') self.allowed_values = attributes[:'allowed_values'] if attributes[:'allowed_values'] self.properties = attributes[:'properties'] if attributes[:'properties'] end |
Instance Attribute Details
#allowed_values ⇒ Array<String>
Allowed values for the custom property if any
50 51 52 |
# File 'lib/oci/data_catalog/models/update_custom_property_details.rb', line 50 def allowed_values @allowed_values end |
#description ⇒ String
Detailed description of the data asset.
18 19 20 |
# File 'lib/oci/data_catalog/models/update_custom_property_details.rb', line 18 def description @description end |
#display_name ⇒ String
A user-friendly display name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
14 15 16 |
# File 'lib/oci/data_catalog/models/update_custom_property_details.rb', line 14 def display_name @display_name end |
#is_editable ⇒ BOOLEAN
If this field is a editable field
38 39 40 |
# File 'lib/oci/data_catalog/models/update_custom_property_details.rb', line 38 def is_editable @is_editable end |
#is_filterable ⇒ BOOLEAN
If this field allows to filter or create facets from UI
26 27 28 |
# File 'lib/oci/data_catalog/models/update_custom_property_details.rb', line 26 def is_filterable @is_filterable end |
#is_hidden ⇒ BOOLEAN
If this field is a hidden field
34 35 36 |
# File 'lib/oci/data_catalog/models/update_custom_property_details.rb', line 34 def is_hidden @is_hidden end |
#is_hidden_in_search ⇒ BOOLEAN
If this field is allowed to pop in search results
46 47 48 |
# File 'lib/oci/data_catalog/models/update_custom_property_details.rb', line 46 def is_hidden_in_search @is_hidden_in_search end |
#is_multi_valued ⇒ BOOLEAN
If this field allows multiple values to be set
30 31 32 |
# File 'lib/oci/data_catalog/models/update_custom_property_details.rb', line 30 def is_multi_valued @is_multi_valued end |
#is_shown_in_list ⇒ BOOLEAN
If this field is displayed in a list view of applicable objects.
42 43 44 |
# File 'lib/oci/data_catalog/models/update_custom_property_details.rb', line 42 def is_shown_in_list @is_shown_in_list end |
#is_sortable ⇒ BOOLEAN
If this field allows to sort from UI
22 23 24 |
# File 'lib/oci/data_catalog/models/update_custom_property_details.rb', line 22 def is_sortable @is_sortable end |
#properties ⇒ Hash<String, Hash<String, String>>
A map of maps that contains the properties which are specific to the asset type. Each data asset type definition defines it’s set of required and optional properties. The map keys are category names and the values are maps of property name to property value. Every property is contained inside of a category. Most data assets have required properties within the "default" category. Example: ‘{ "default": { "host": "host1", "port": "1521", "database": "orcl"}}`
59 60 61 |
# File 'lib/oci/data_catalog/models/update_custom_property_details.rb', line 59 def properties @properties end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/oci/data_catalog/models/update_custom_property_details.rb', line 62 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'description': :'description', 'is_sortable': :'isSortable', 'is_filterable': :'isFilterable', 'is_multi_valued': :'isMultiValued', 'is_hidden': :'isHidden', 'is_editable': :'isEditable', 'is_shown_in_list': :'isShownInList', 'is_hidden_in_search': :'isHiddenInSearch', 'allowed_values': :'allowedValues', 'properties': :'properties' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/oci/data_catalog/models/update_custom_property_details.rb', line 81 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'description': :'String', 'is_sortable': :'BOOLEAN', 'is_filterable': :'BOOLEAN', 'is_multi_valued': :'BOOLEAN', 'is_hidden': :'BOOLEAN', 'is_editable': :'BOOLEAN', 'is_shown_in_list': :'BOOLEAN', 'is_hidden_in_search': :'BOOLEAN', 'allowed_values': :'Array<String>', 'properties': :'Hash<String, Hash<String, String>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/oci/data_catalog/models/update_custom_property_details.rb', line 202 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && description == other.description && is_sortable == other.is_sortable && is_filterable == other.is_filterable && is_multi_valued == other.is_multi_valued && is_hidden == other.is_hidden && is_editable == other.is_editable && is_shown_in_list == other.is_shown_in_list && is_hidden_in_search == other.is_hidden_in_search && allowed_values == other.allowed_values && properties == other.properties end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/oci/data_catalog/models/update_custom_property_details.rb', line 242 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
222 223 224 |
# File 'lib/oci/data_catalog/models/update_custom_property_details.rb', line 222 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
231 232 233 |
# File 'lib/oci/data_catalog/models/update_custom_property_details.rb', line 231 def hash [display_name, description, is_sortable, is_filterable, is_multi_valued, is_hidden, is_editable, is_shown_in_list, is_hidden_in_search, allowed_values, properties].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
275 276 277 278 279 280 281 282 283 284 |
# File 'lib/oci/data_catalog/models/update_custom_property_details.rb', line 275 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
269 270 271 |
# File 'lib/oci/data_catalog/models/update_custom_property_details.rb', line 269 def to_s to_hash.to_s end |