Class: OCI::DataCatalog::Models::UpdateJobDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_catalog/models/update_job_details.rb

Overview

Job properties that can be updated.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateJobDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :display_name (String)

    The value to assign to the #display_name property

  • :description (String)

    The value to assign to the #description property

  • :schedule_cron_expression (String)

    The value to assign to the #schedule_cron_expression property

  • :time_schedule_begin (DateTime)

    The value to assign to the #time_schedule_begin property

  • :time_schedule_end (DateTime)

    The value to assign to the #time_schedule_end property

  • :connection_key (String)

    The value to assign to the #connection_key property



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/oci/data_catalog/models/update_job_details.rb', line 78

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.schedule_cron_expression = attributes[:'scheduleCronExpression'] if attributes[:'scheduleCronExpression']

  raise 'You cannot provide both :scheduleCronExpression and :schedule_cron_expression' if attributes.key?(:'scheduleCronExpression') && attributes.key?(:'schedule_cron_expression')

  self.schedule_cron_expression = attributes[:'schedule_cron_expression'] if attributes[:'schedule_cron_expression']

  self.time_schedule_begin = attributes[:'timeScheduleBegin'] if attributes[:'timeScheduleBegin']

  raise 'You cannot provide both :timeScheduleBegin and :time_schedule_begin' if attributes.key?(:'timeScheduleBegin') && attributes.key?(:'time_schedule_begin')

  self.time_schedule_begin = attributes[:'time_schedule_begin'] if attributes[:'time_schedule_begin']

  self.time_schedule_end = attributes[:'timeScheduleEnd'] if attributes[:'timeScheduleEnd']

  raise 'You cannot provide both :timeScheduleEnd and :time_schedule_end' if attributes.key?(:'timeScheduleEnd') && attributes.key?(:'time_schedule_end')

  self.time_schedule_end = attributes[:'time_schedule_end'] if attributes[:'time_schedule_end']

  self.connection_key = attributes[:'connectionKey'] if attributes[:'connectionKey']

  raise 'You cannot provide both :connectionKey and :connection_key' if attributes.key?(:'connectionKey') && attributes.key?(:'connection_key')

  self.connection_key = attributes[:'connection_key'] if attributes[:'connection_key']
end

Instance Attribute Details

#connection_keyString

The key of the connection resource that is used for the harvest by this job.

Returns:

  • (String)


36
37
38
# File 'lib/oci/data_catalog/models/update_job_details.rb', line 36

def connection_key
  @connection_key
end

#descriptionString

Detailed description of the job.

Returns:

  • (String)


18
19
20
# File 'lib/oci/data_catalog/models/update_job_details.rb', line 18

def description
  @description
end

#display_nameString

A user-friendly display name. Does not have to be unique, and it's changeable. Avoid entering confidential information.

Returns:

  • (String)


14
15
16
# File 'lib/oci/data_catalog/models/update_job_details.rb', line 14

def display_name
  @display_name
end

#schedule_cron_expressionString

Interval on which the job will be run. Value is specified as a cron-supported time specification "nickname". The following subset of those is supported: @monthly, @weekly, @daily, @hourly.

Returns:

  • (String)


24
25
26
# File 'lib/oci/data_catalog/models/update_job_details.rb', line 24

def schedule_cron_expression
  @schedule_cron_expression
end

#time_schedule_beginDateTime

Date that the schedule should be operational. An [RFC3339](tools.ietf.org/html/rfc3339) formatted datetime string.

Returns:

  • (DateTime)


28
29
30
# File 'lib/oci/data_catalog/models/update_job_details.rb', line 28

def time_schedule_begin
  @time_schedule_begin
end

#time_schedule_endDateTime

Date that the schedule should end from being operational. An [RFC3339](tools.ietf.org/html/rfc3339) formatted datetime string.

Returns:

  • (DateTime)


32
33
34
# File 'lib/oci/data_catalog/models/update_job_details.rb', line 32

def time_schedule_end
  @time_schedule_end
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



39
40
41
42
43
44
45
46
47
48
49
50
# File 'lib/oci/data_catalog/models/update_job_details.rb', line 39

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'displayName',
    'description': :'description',
    'schedule_cron_expression': :'scheduleCronExpression',
    'time_schedule_begin': :'timeScheduleBegin',
    'time_schedule_end': :'timeScheduleEnd',
    'connection_key': :'connectionKey'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/oci/data_catalog/models/update_job_details.rb', line 53

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'String',
    'description': :'String',
    'schedule_cron_expression': :'String',
    'time_schedule_begin': :'DateTime',
    'time_schedule_end': :'DateTime',
    'connection_key': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



124
125
126
127
128
129
130
131
132
133
134
# File 'lib/oci/data_catalog/models/update_job_details.rb', line 124

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    display_name == other.display_name &&
    description == other.description &&
    schedule_cron_expression == other.schedule_cron_expression &&
    time_schedule_begin == other.time_schedule_begin &&
    time_schedule_end == other.time_schedule_end &&
    connection_key == other.connection_key
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/oci/data_catalog/models/update_job_details.rb', line 159

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


139
140
141
# File 'lib/oci/data_catalog/models/update_job_details.rb', line 139

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



148
149
150
# File 'lib/oci/data_catalog/models/update_job_details.rb', line 148

def hash
  [display_name, description, schedule_cron_expression, time_schedule_begin, time_schedule_end, connection_key].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



192
193
194
195
196
197
198
199
200
201
# File 'lib/oci/data_catalog/models/update_job_details.rb', line 192

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



186
187
188
# File 'lib/oci/data_catalog/models/update_job_details.rb', line 186

def to_s
  to_hash.to_s
end