Class: OCI::DataCatalog::Models::UpdateNamespaceDetails
- Inherits:
-
Object
- Object
- OCI::DataCatalog::Models::UpdateNamespaceDetails
- Defined in:
- lib/oci/data_catalog/models/update_namespace_details.rb
Overview
Properties used in namespace update operations.
Instance Attribute Summary collapse
-
#description ⇒ String
Detailed description of the namespace.
-
#display_name ⇒ String
A user-friendly display name.
-
#is_service_defined ⇒ BOOLEAN
If this field is defined by service or by a user.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateNamespaceDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateNamespaceDetails
Initializes the object
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/oci/data_catalog/models/update_namespace_details.rb', line 55 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.is_service_defined = attributes[:'isServiceDefined'] unless attributes[:'isServiceDefined'].nil? self.is_service_defined = false if is_service_defined.nil? && !attributes.key?(:'isServiceDefined') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isServiceDefined and :is_service_defined' if attributes.key?(:'isServiceDefined') && attributes.key?(:'is_service_defined') self.is_service_defined = attributes[:'is_service_defined'] unless attributes[:'is_service_defined'].nil? self.is_service_defined = false if is_service_defined.nil? && !attributes.key?(:'isServiceDefined') && !attributes.key?(:'is_service_defined') # rubocop:disable Style/StringLiterals end |
Instance Attribute Details
#description ⇒ String
Detailed description of the namespace.
18 19 20 |
# File 'lib/oci/data_catalog/models/update_namespace_details.rb', line 18 def description @description end |
#display_name ⇒ String
A user-friendly display name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
14 15 16 |
# File 'lib/oci/data_catalog/models/update_namespace_details.rb', line 14 def display_name @display_name end |
#is_service_defined ⇒ BOOLEAN
If this field is defined by service or by a user
22 23 24 |
# File 'lib/oci/data_catalog/models/update_namespace_details.rb', line 22 def is_service_defined @is_service_defined end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
25 26 27 28 29 30 31 32 33 |
# File 'lib/oci/data_catalog/models/update_namespace_details.rb', line 25 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'description': :'description', 'is_service_defined': :'isServiceDefined' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
36 37 38 39 40 41 42 43 44 |
# File 'lib/oci/data_catalog/models/update_namespace_details.rb', line 36 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'description': :'String', 'is_service_defined': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
85 86 87 88 89 90 91 92 |
# File 'lib/oci/data_catalog/models/update_namespace_details.rb', line 85 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && description == other.description && is_service_defined == other.is_service_defined end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/oci/data_catalog/models/update_namespace_details.rb', line 117 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
97 98 99 |
# File 'lib/oci/data_catalog/models/update_namespace_details.rb', line 97 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
106 107 108 |
# File 'lib/oci/data_catalog/models/update_namespace_details.rb', line 106 def hash [display_name, description, is_service_defined].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
150 151 152 153 154 155 156 157 158 159 |
# File 'lib/oci/data_catalog/models/update_namespace_details.rb', line 150 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
144 145 146 |
# File 'lib/oci/data_catalog/models/update_namespace_details.rb', line 144 def to_s to_hash.to_s end |