Class: OCI::DataCatalog::Models::UpdatePatternDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_catalog/models/update_pattern_details.rb

Overview

Properties used in pattern update operations.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdatePatternDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :display_name (String)

    The value to assign to the #display_name property

  • :description (String)

    The value to assign to the #description property

  • :expression (String)

    The value to assign to the #expression property

  • :file_path_prefix (String)

    The value to assign to the #file_path_prefix property

  • :check_file_path_list (Array<String>)

    The value to assign to the #check_file_path_list property

  • :is_enable_check_failure_limit (BOOLEAN)

    The value to assign to the #is_enable_check_failure_limit property

  • :check_failure_limit (Integer)

    The value to assign to the #check_failure_limit property

  • :properties (Hash<String, Hash<String, String>>)

    The value to assign to the #properties property



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/oci/data_catalog/models/update_pattern_details.rb', line 108

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.expression = attributes[:'expression'] if attributes[:'expression']

  self.file_path_prefix = attributes[:'filePathPrefix'] if attributes[:'filePathPrefix']

  raise 'You cannot provide both :filePathPrefix and :file_path_prefix' if attributes.key?(:'filePathPrefix') && attributes.key?(:'file_path_prefix')

  self.file_path_prefix = attributes[:'file_path_prefix'] if attributes[:'file_path_prefix']

  self.check_file_path_list = attributes[:'checkFilePathList'] if attributes[:'checkFilePathList']

  raise 'You cannot provide both :checkFilePathList and :check_file_path_list' if attributes.key?(:'checkFilePathList') && attributes.key?(:'check_file_path_list')

  self.check_file_path_list = attributes[:'check_file_path_list'] if attributes[:'check_file_path_list']

  self.is_enable_check_failure_limit = attributes[:'isEnableCheckFailureLimit'] unless attributes[:'isEnableCheckFailureLimit'].nil?
  self.is_enable_check_failure_limit = false if is_enable_check_failure_limit.nil? && !attributes.key?(:'isEnableCheckFailureLimit') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isEnableCheckFailureLimit and :is_enable_check_failure_limit' if attributes.key?(:'isEnableCheckFailureLimit') && attributes.key?(:'is_enable_check_failure_limit')

  self.is_enable_check_failure_limit = attributes[:'is_enable_check_failure_limit'] unless attributes[:'is_enable_check_failure_limit'].nil?
  self.is_enable_check_failure_limit = false if is_enable_check_failure_limit.nil? && !attributes.key?(:'isEnableCheckFailureLimit') && !attributes.key?(:'is_enable_check_failure_limit') # rubocop:disable Style/StringLiterals

  self.check_failure_limit = attributes[:'checkFailureLimit'] if attributes[:'checkFailureLimit']

  raise 'You cannot provide both :checkFailureLimit and :check_failure_limit' if attributes.key?(:'checkFailureLimit') && attributes.key?(:'check_failure_limit')

  self.check_failure_limit = attributes[:'check_failure_limit'] if attributes[:'check_failure_limit']

  self.properties = attributes[:'properties'] if attributes[:'properties']
end

Instance Attribute Details

#check_failure_limitInteger

The maximum number of UNMATCHED files, in checkFilePathList, above which the check fails. Optional, if checkFilePathList is provided - but if isEnableCheckFailureLimit is set to true it is required.

Returns:

  • (Integer)


53
54
55
# File 'lib/oci/data_catalog/models/update_pattern_details.rb', line 53

def check_failure_limit
  @check_failure_limit
end

#check_file_path_listArray<String>

List of file paths against which the pattern can be tried, as a check. This documents, for reference purposes, some example objects a pattern is meant to work with. If isEnableCheckFailureLimit is set to true, this will be run as a validation during the request, such that if the check fails the request fails. If isEnableCheckFailureLimit instead is set to (the default) false, a pattern will still be created or updated even if the check fails, with a lifecycleState of FAILED.

Returns:

  • (Array<String>)


41
42
43
# File 'lib/oci/data_catalog/models/update_pattern_details.rb', line 41

def check_file_path_list
  @check_file_path_list
end

#descriptionString

Detailed description of the Pattern.

Returns:

  • (String)


18
19
20
# File 'lib/oci/data_catalog/models/update_pattern_details.rb', line 18

def description
  @description
end

#display_nameString

A user-friendly display name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.

Returns:

  • (String)


14
15
16
# File 'lib/oci/data_catalog/models/update_pattern_details.rb', line 14

def display_name
  @display_name
end

#expressionString

Input string which drives the selection process, allowing for fine-grained control using qualifiers. Refer to the user documentation for details of the format and examples. A pattern cannot include both a prefix and an expression.

Returns:

  • (String)


25
26
27
# File 'lib/oci/data_catalog/models/update_pattern_details.rb', line 25

def expression
  @expression
end

#file_path_prefixString

Input string which drives the selection process. Refer to the user documentation for details of the format and examples. A pattern cannot include both a prefix and an expression.

Returns:

  • (String)


32
33
34
# File 'lib/oci/data_catalog/models/update_pattern_details.rb', line 32

def file_path_prefix
  @file_path_prefix
end

#is_enable_check_failure_limitBOOLEAN

Indicates whether the pattern check, against the checkFilePathList, will fail the request if the count of UNMATCHED files is above the checkFailureLimit.

Returns:

  • (BOOLEAN)


47
48
49
# File 'lib/oci/data_catalog/models/update_pattern_details.rb', line 47

def is_enable_check_failure_limit
  @is_enable_check_failure_limit
end

#propertiesHash<String, Hash<String, String>>

A map of maps that contains the properties which are specific to the pattern type. Each pattern type definition defines it’s set of required and optional properties. Example: ‘{ "default": { "tbd"}}`

Returns:

  • (Hash<String, Hash<String, String>>)


60
61
62
# File 'lib/oci/data_catalog/models/update_pattern_details.rb', line 60

def properties
  @properties
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/oci/data_catalog/models/update_pattern_details.rb', line 63

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'displayName',
    'description': :'description',
    'expression': :'expression',
    'file_path_prefix': :'filePathPrefix',
    'check_file_path_list': :'checkFilePathList',
    'is_enable_check_failure_limit': :'isEnableCheckFailureLimit',
    'check_failure_limit': :'checkFailureLimit',
    'properties': :'properties'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/oci/data_catalog/models/update_pattern_details.rb', line 79

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'String',
    'description': :'String',
    'expression': :'String',
    'file_path_prefix': :'String',
    'check_file_path_list': :'Array<String>',
    'is_enable_check_failure_limit': :'BOOLEAN',
    'check_failure_limit': :'Integer',
    'properties': :'Hash<String, Hash<String, String>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/oci/data_catalog/models/update_pattern_details.rb', line 160

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    display_name == other.display_name &&
    description == other.description &&
    expression == other.expression &&
    file_path_prefix == other.file_path_prefix &&
    check_file_path_list == other.check_file_path_list &&
    is_enable_check_failure_limit == other.is_enable_check_failure_limit &&
    check_failure_limit == other.check_failure_limit &&
    properties == other.properties
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/oci/data_catalog/models/update_pattern_details.rb', line 197

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


177
178
179
# File 'lib/oci/data_catalog/models/update_pattern_details.rb', line 177

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



186
187
188
# File 'lib/oci/data_catalog/models/update_pattern_details.rb', line 186

def hash
  [display_name, description, expression, file_path_prefix, check_file_path_list, is_enable_check_failure_limit, check_failure_limit, properties].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



230
231
232
233
234
235
236
237
238
239
# File 'lib/oci/data_catalog/models/update_pattern_details.rb', line 230

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



224
225
226
# File 'lib/oci/data_catalog/models/update_pattern_details.rb', line 224

def to_s
  to_hash.to_s
end