Class: OCI::DataCatalog::Models::ValidatePatternDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_catalog/models/validate_pattern_details.rb

Overview

Validate pattern using the expression and file list.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ValidatePatternDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :expression (String)

    The value to assign to the #expression property

  • :file_path_prefix (String)

    The value to assign to the #file_path_prefix property

  • :check_file_path_list (Array<String>)

    The value to assign to the #check_file_path_list property

  • :check_failure_limit (Integer)

    The value to assign to the #check_failure_limit property



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/oci/data_catalog/models/validate_pattern_details.rb', line 74

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.expression = attributes[:'expression'] if attributes[:'expression']

  self.file_path_prefix = attributes[:'filePathPrefix'] if attributes[:'filePathPrefix']

  raise 'You cannot provide both :filePathPrefix and :file_path_prefix' if attributes.key?(:'filePathPrefix') && attributes.key?(:'file_path_prefix')

  self.file_path_prefix = attributes[:'file_path_prefix'] if attributes[:'file_path_prefix']

  self.check_file_path_list = attributes[:'checkFilePathList'] if attributes[:'checkFilePathList']

  raise 'You cannot provide both :checkFilePathList and :check_file_path_list' if attributes.key?(:'checkFilePathList') && attributes.key?(:'check_file_path_list')

  self.check_file_path_list = attributes[:'check_file_path_list'] if attributes[:'check_file_path_list']

  self.check_failure_limit = attributes[:'checkFailureLimit'] if attributes[:'checkFailureLimit']

  raise 'You cannot provide both :checkFailureLimit and :check_failure_limit' if attributes.key?(:'checkFailureLimit') && attributes.key?(:'check_failure_limit')

  self.check_failure_limit = attributes[:'check_failure_limit'] if attributes[:'check_failure_limit']
end

Instance Attribute Details

#check_failure_limitInteger

The maximum number of UNMATCHED files, in checkFilePathList, above which the check fails. Optional, if checkFilePathList is provided.

If provided with the request, this overrides the value which already exists as part of the pattern, if any.

Returns:

  • (Integer)


38
39
40
# File 'lib/oci/data_catalog/models/validate_pattern_details.rb', line 38

def check_failure_limit
  @check_failure_limit
end

#check_file_path_listArray<String>

List of file paths against which the pattern can be tried, as a check. This documents, for reference purposes, some example objects a pattern is meant to work with.

If provided with the request,this overrides the list which already exists as part of the pattern, if any.

Returns:

  • (Array<String>)


30
31
32
# File 'lib/oci/data_catalog/models/validate_pattern_details.rb', line 30

def check_file_path_list
  @check_file_path_list
end

#expressionString

Input string which drives the selection process, allowing for fine-grained control using qualifiers. Refer to the user documentation for details of the format and examples. A pattern cannot include both a prefix and an expression.

Returns:

  • (String)


15
16
17
# File 'lib/oci/data_catalog/models/validate_pattern_details.rb', line 15

def expression
  @expression
end

#file_path_prefixString

Input string which drives the selection process. Refer to the user documentation for details of the format and examples. A pattern cannot include both a prefix and an expression.

Returns:

  • (String)


22
23
24
# File 'lib/oci/data_catalog/models/validate_pattern_details.rb', line 22

def file_path_prefix
  @file_path_prefix
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



41
42
43
44
45
46
47
48
49
50
# File 'lib/oci/data_catalog/models/validate_pattern_details.rb', line 41

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'expression': :'expression',
    'file_path_prefix': :'filePathPrefix',
    'check_file_path_list': :'checkFilePathList',
    'check_failure_limit': :'checkFailureLimit'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



53
54
55
56
57
58
59
60
61
62
# File 'lib/oci/data_catalog/models/validate_pattern_details.rb', line 53

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'expression': :'String',
    'file_path_prefix': :'String',
    'check_file_path_list': :'Array<String>',
    'check_failure_limit': :'Integer'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



108
109
110
111
112
113
114
115
116
# File 'lib/oci/data_catalog/models/validate_pattern_details.rb', line 108

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    expression == other.expression &&
    file_path_prefix == other.file_path_prefix &&
    check_file_path_list == other.check_file_path_list &&
    check_failure_limit == other.check_failure_limit
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/oci/data_catalog/models/validate_pattern_details.rb', line 141

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


121
122
123
# File 'lib/oci/data_catalog/models/validate_pattern_details.rb', line 121

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



130
131
132
# File 'lib/oci/data_catalog/models/validate_pattern_details.rb', line 130

def hash
  [expression, file_path_prefix, check_file_path_list, check_failure_limit].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



174
175
176
177
178
179
180
181
182
183
# File 'lib/oci/data_catalog/models/validate_pattern_details.rb', line 174

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



168
169
170
# File 'lib/oci/data_catalog/models/validate_pattern_details.rb', line 168

def to_s
  to_hash.to_s
end