Class: OCI::DataCatalog::Models::ValidatePatternResult

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_catalog/models/validate_pattern_result.rb

Overview

Details regarding the validation of a pattern resource.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ValidatePatternResult

Initializes the object

Options Hash (attributes):



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/oci/data_catalog/models/validate_pattern_result.rb', line 60

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.message = attributes[:'message'] if attributes[:'message']

  self.status = attributes[:'status'] if attributes[:'status']

  self.expression = attributes[:'expression'] if attributes[:'expression']

  self.derived_logical_entities = attributes[:'derivedLogicalEntities'] if attributes[:'derivedLogicalEntities']

  raise 'You cannot provide both :derivedLogicalEntities and :derived_logical_entities' if attributes.key?(:'derivedLogicalEntities') && attributes.key?(:'derived_logical_entities')

  self.derived_logical_entities = attributes[:'derived_logical_entities'] if attributes[:'derived_logical_entities']
end

Instance Attribute Details

#derived_logical_entitiesArray<OCI::DataCatalog::Models::DerivedLogicalEntities>

Collection of logical entities derived from the expression applied to a list of file paths.



24
25
26
# File 'lib/oci/data_catalog/models/validate_pattern_result.rb', line 24

def derived_logical_entities
  @derived_logical_entities
end

#expressionString

The expression used in the pattern validation.



20
21
22
# File 'lib/oci/data_catalog/models/validate_pattern_result.rb', line 20

def expression
  @expression
end

#messageString

The message from the pattern validation.



12
13
14
# File 'lib/oci/data_catalog/models/validate_pattern_result.rb', line 12

def message
  @message
end

#statusString

[Required] The status returned from the pattern validation.



16
17
18
# File 'lib/oci/data_catalog/models/validate_pattern_result.rb', line 16

def status
  @status
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



27
28
29
30
31
32
33
34
35
36
# File 'lib/oci/data_catalog/models/validate_pattern_result.rb', line 27

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'message': :'message',
    'status': :'status',
    'expression': :'expression',
    'derived_logical_entities': :'derivedLogicalEntities'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



39
40
41
42
43
44
45
46
47
48
# File 'lib/oci/data_catalog/models/validate_pattern_result.rb', line 39

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'message': :'String',
    'status': :'String',
    'expression': :'String',
    'derived_logical_entities': :'Array<OCI::DataCatalog::Models::DerivedLogicalEntities>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.



86
87
88
89
90
91
92
93
94
# File 'lib/oci/data_catalog/models/validate_pattern_result.rb', line 86

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    message == other.message &&
    status == other.status &&
    expression == other.expression &&
    derived_logical_entities == other.derived_logical_entities
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/oci/data_catalog/models/validate_pattern_result.rb', line 119

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method


99
100
101
# File 'lib/oci/data_catalog/models/validate_pattern_result.rb', line 99

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.



108
109
110
# File 'lib/oci/data_catalog/models/validate_pattern_result.rb', line 108

def hash
  [message, status, expression, derived_logical_entities].hash
end

#to_hashHash

Returns the object in the form of hash



152
153
154
155
156
157
158
159
160
161
# File 'lib/oci/data_catalog/models/validate_pattern_result.rb', line 152

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



146
147
148
# File 'lib/oci/data_catalog/models/validate_pattern_result.rb', line 146

def to_s
  to_hash.to_s
end