Class: DataConnectivity::Models::BaseType

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_connectivity/models/base_type.rb

Overview

Base type for the type system. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class

Constant Summary collapse

MODEL_TYPE_ENUM =
[
  MODEL_TYPE_STRUCTURED_TYPE = 'STRUCTURED_TYPE'.freeze,
  MODEL_TYPE_DATA_TYPE = 'DATA_TYPE'.freeze,
  MODEL_TYPE_CONFIGURED_TYPE = 'CONFIGURED_TYPE'.freeze,
  MODEL_TYPE_COMPOSITE_TYPE = 'COMPOSITE_TYPE'.freeze,
  MODEL_TYPE_DERIVED_TYPE = 'DERIVED_TYPE'.freeze,
  MODEL_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ BaseType

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'lib/oci/data_connectivity/models/base_type.rb', line 110

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.model_type = attributes[:'modelType'] if attributes[:'modelType']

  raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type')

  self.model_type = attributes[:'model_type'] if attributes[:'model_type']

  self.key = attributes[:'key'] if attributes[:'key']

  self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion']

  raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version')

  self.model_version = attributes[:'model_version'] if attributes[:'model_version']

  self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef']

  raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref')

  self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref']

  self.name = attributes[:'name'] if attributes[:'name']

  self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus']

  raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status')

  self.object_status = attributes[:'object_status'] if attributes[:'object_status']

  self.description = attributes[:'description'] if attributes[:'description']
end

Instance Attribute Details

#descriptionString

A user defined description for the object.

Returns:

  • (String)


46
47
48
# File 'lib/oci/data_connectivity/models/base_type.rb', line 46

def description
  @description
end

#keyString

The key of the object.

Returns:

  • (String)


27
28
29
# File 'lib/oci/data_connectivity/models/base_type.rb', line 27

def key
  @key
end

#model_typeString

**[Required]** The property which disciminates the subtypes.

Returns:

  • (String)


23
24
25
# File 'lib/oci/data_connectivity/models/base_type.rb', line 23

def model_type
  @model_type
end

#model_versionString

The model version of an object.

Returns:

  • (String)


31
32
33
# File 'lib/oci/data_connectivity/models/base_type.rb', line 31

def model_version
  @model_version
end

#nameString

Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.

Returns:

  • (String)


38
39
40
# File 'lib/oci/data_connectivity/models/base_type.rb', line 38

def name
  @name
end

#object_statusInteger

The status of an object that can be set to value 1 for shallow references across objects, other values reserved.

Returns:

  • (Integer)


42
43
44
# File 'lib/oci/data_connectivity/models/base_type.rb', line 42

def object_status
  @object_status
end

#parent_refOCI::DataConnectivity::Models::ParentReference



34
35
36
# File 'lib/oci/data_connectivity/models/base_type.rb', line 34

def parent_ref
  @parent_ref
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/oci/data_connectivity/models/base_type.rb', line 49

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'modelType',
    'key': :'key',
    'model_version': :'modelVersion',
    'parent_ref': :'parentRef',
    'name': :'name',
    'object_status': :'objectStatus',
    'description': :'description'
    # rubocop:enable Style/SymbolLiteral
  }
end

.get_subtype(object_hash) ⇒ Object

Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.



83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/oci/data_connectivity/models/base_type.rb', line 83

def self.get_subtype(object_hash)
  type = object_hash[:'modelType'] # rubocop:disable Style/SymbolLiteral

  return 'OCI::DataConnectivity::Models::ConfiguredType' if type == 'CONFIGURED_TYPE'
  return 'OCI::DataConnectivity::Models::DerivedType' if type == 'DERIVED_TYPE'
  return 'OCI::DataConnectivity::Models::DataType' if type == 'DATA_TYPE'
  return 'OCI::DataConnectivity::Models::StructuredType' if type == 'STRUCTURED_TYPE'
  return 'OCI::DataConnectivity::Models::CompositeType' if type == 'COMPOSITE_TYPE'

  # TODO: Log a warning when the subtype is not found.
  'OCI::DataConnectivity::Models::BaseType'
end

.swagger_typesObject

Attribute type mapping.



64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/oci/data_connectivity/models/base_type.rb', line 64

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'String',
    'key': :'String',
    'model_version': :'String',
    'parent_ref': :'OCI::DataConnectivity::Models::ParentReference',
    'name': :'String',
    'object_status': :'Integer',
    'description': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/oci/data_connectivity/models/base_type.rb', line 167

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    model_type == other.model_type &&
    key == other.key &&
    model_version == other.model_version &&
    parent_ref == other.parent_ref &&
    name == other.name &&
    object_status == other.object_status &&
    description == other.description
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/oci/data_connectivity/models/base_type.rb', line 203

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


183
184
185
# File 'lib/oci/data_connectivity/models/base_type.rb', line 183

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



192
193
194
# File 'lib/oci/data_connectivity/models/base_type.rb', line 192

def hash
  [model_type, key, model_version, parent_ref, name, object_status, description].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



236
237
238
239
240
241
242
243
244
245
# File 'lib/oci/data_connectivity/models/base_type.rb', line 236

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



230
231
232
# File 'lib/oci/data_connectivity/models/base_type.rb', line 230

def to_s
  to_hash.to_s
end