Class: OCI::DataConnectivity::Models::ConnectionValidationSummary
- Inherits:
-
Object
- Object
- OCI::DataConnectivity::Models::ConnectionValidationSummary
- Defined in:
- lib/oci/data_connectivity/models/connection_validation_summary.rb
Overview
The information about connection validation.
Instance Attribute Summary collapse
- #connection ⇒ OCI::DataConnectivity::Models::CreateConnectionDetails
- #data_asset ⇒ OCI::DataConnectivity::Models::CreateDataAssetDetails
-
#description ⇒ String
Detailed description for the object.
-
#identifier ⇒ String
Value can only contain upper case letters, underscore and numbers.
-
#key ⇒ String
Objects will use a 36 character key as unique ID.
- #metadata ⇒ OCI::DataConnectivity::Models::ObjectMetadata
-
#model_type ⇒ String
**[Required]** The type of the object.
-
#model_version ⇒ String
The model version of an object.
-
#name ⇒ String
Free form text without any restriction on permitted characters.
-
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
-
#object_version ⇒ Integer
The version of the object that is used to track changes in the object instance.
- #parent_ref ⇒ OCI::DataConnectivity::Models::ParentReference
- #registry_metadata ⇒ OCI::DataConnectivity::Models::RegistryMetadata
- #validation_message ⇒ OCI::DataConnectivity::Models::Message
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ConnectionValidationSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ConnectionValidationSummary
Initializes the object
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/oci/data_connectivity/models/connection_validation_summary.rb', line 124 def initialize(attributes = {}) return unless attributes.is_a?(Hash) self. = attributes[:'validationMessage'] if attributes[:'validationMessage'] raise 'You cannot provide both :validationMessage and :validation_message' if attributes.key?(:'validationMessage') && attributes.key?(:'validation_message') self. = attributes[:'validation_message'] if attributes[:'validation_message'] self.key = attributes[:'key'] if attributes[:'key'] self.model_type = attributes[:'modelType'] if attributes[:'modelType'] raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type') self.model_type = attributes[:'model_type'] if attributes[:'model_type'] self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion'] raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version') self.model_version = attributes[:'model_version'] if attributes[:'model_version'] self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef'] raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref') self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref'] self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.object_version = attributes[:'objectVersion'] if attributes[:'objectVersion'] raise 'You cannot provide both :objectVersion and :object_version' if attributes.key?(:'objectVersion') && attributes.key?(:'object_version') self.object_version = attributes[:'object_version'] if attributes[:'object_version'] self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus'] raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status') self.object_status = attributes[:'object_status'] if attributes[:'object_status'] self. = attributes[:'registryMetadata'] if attributes[:'registryMetadata'] raise 'You cannot provide both :registryMetadata and :registry_metadata' if attributes.key?(:'registryMetadata') && attributes.key?(:'registry_metadata') self. = attributes[:'registry_metadata'] if attributes[:'registry_metadata'] self.connection = attributes[:'connection'] if attributes[:'connection'] self.data_asset = attributes[:'dataAsset'] if attributes[:'dataAsset'] raise 'You cannot provide both :dataAsset and :data_asset' if attributes.key?(:'dataAsset') && attributes.key?(:'data_asset') self.data_asset = attributes[:'data_asset'] if attributes[:'data_asset'] self.identifier = attributes[:'identifier'] if attributes[:'identifier'] self. = attributes[:'metadata'] if attributes[:'metadata'] end |
Instance Attribute Details
#connection ⇒ OCI::DataConnectivity::Models::CreateConnectionDetails
48 49 50 |
# File 'lib/oci/data_connectivity/models/connection_validation_summary.rb', line 48 def connection @connection end |
#data_asset ⇒ OCI::DataConnectivity::Models::CreateDataAssetDetails
51 52 53 |
# File 'lib/oci/data_connectivity/models/connection_validation_summary.rb', line 51 def data_asset @data_asset end |
#description ⇒ String
Detailed description for the object.
34 35 36 |
# File 'lib/oci/data_connectivity/models/connection_validation_summary.rb', line 34 def description @description end |
#identifier ⇒ String
Value can only contain upper case letters, underscore and numbers. It should begin with upper case letter or underscore. The value can be modified.
55 56 57 |
# File 'lib/oci/data_connectivity/models/connection_validation_summary.rb', line 55 def identifier @identifier end |
#key ⇒ String
Objects will use a 36 character key as unique ID. It is system generated and cannot be modified.
15 16 17 |
# File 'lib/oci/data_connectivity/models/connection_validation_summary.rb', line 15 def key @key end |
#metadata ⇒ OCI::DataConnectivity::Models::ObjectMetadata
58 59 60 |
# File 'lib/oci/data_connectivity/models/connection_validation_summary.rb', line 58 def @metadata end |
#model_type ⇒ String
**[Required]** The type of the object.
19 20 21 |
# File 'lib/oci/data_connectivity/models/connection_validation_summary.rb', line 19 def model_type @model_type end |
#model_version ⇒ String
The model version of an object.
23 24 25 |
# File 'lib/oci/data_connectivity/models/connection_validation_summary.rb', line 23 def model_version @model_version end |
#name ⇒ String
Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.
30 31 32 |
# File 'lib/oci/data_connectivity/models/connection_validation_summary.rb', line 30 def name @name end |
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
42 43 44 |
# File 'lib/oci/data_connectivity/models/connection_validation_summary.rb', line 42 def object_status @object_status end |
#object_version ⇒ Integer
The version of the object that is used to track changes in the object instance.
38 39 40 |
# File 'lib/oci/data_connectivity/models/connection_validation_summary.rb', line 38 def object_version @object_version end |
#parent_ref ⇒ OCI::DataConnectivity::Models::ParentReference
26 27 28 |
# File 'lib/oci/data_connectivity/models/connection_validation_summary.rb', line 26 def parent_ref @parent_ref end |
#registry_metadata ⇒ OCI::DataConnectivity::Models::RegistryMetadata
45 46 47 |
# File 'lib/oci/data_connectivity/models/connection_validation_summary.rb', line 45 def @registry_metadata end |
#validation_message ⇒ OCI::DataConnectivity::Models::Message
11 12 13 |
# File 'lib/oci/data_connectivity/models/connection_validation_summary.rb', line 11 def @validation_message end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/oci/data_connectivity/models/connection_validation_summary.rb', line 61 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'validation_message': :'validationMessage', 'key': :'key', 'model_type': :'modelType', 'model_version': :'modelVersion', 'parent_ref': :'parentRef', 'name': :'name', 'description': :'description', 'object_version': :'objectVersion', 'object_status': :'objectStatus', 'registry_metadata': :'registryMetadata', 'connection': :'connection', 'data_asset': :'dataAsset', 'identifier': :'identifier', 'metadata': :'metadata' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/oci/data_connectivity/models/connection_validation_summary.rb', line 83 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'validation_message': :'OCI::DataConnectivity::Models::Message', 'key': :'String', 'model_type': :'String', 'model_version': :'String', 'parent_ref': :'OCI::DataConnectivity::Models::ParentReference', 'name': :'String', 'description': :'String', 'object_version': :'Integer', 'object_status': :'Integer', 'registry_metadata': :'OCI::DataConnectivity::Models::RegistryMetadata', 'connection': :'OCI::DataConnectivity::Models::CreateConnectionDetails', 'data_asset': :'OCI::DataConnectivity::Models::CreateDataAssetDetails', 'identifier': :'String', 'metadata': :'OCI::DataConnectivity::Models::ObjectMetadata' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/oci/data_connectivity/models/connection_validation_summary.rb', line 195 def ==(other) return true if equal?(other) self.class == other.class && == other. && key == other.key && model_type == other.model_type && model_version == other.model_version && parent_ref == other.parent_ref && name == other.name && description == other.description && object_version == other.object_version && object_status == other.object_status && == other. && connection == other.connection && data_asset == other.data_asset && identifier == other.identifier && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 |
# File 'lib/oci/data_connectivity/models/connection_validation_summary.rb', line 238 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
218 219 220 |
# File 'lib/oci/data_connectivity/models/connection_validation_summary.rb', line 218 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
227 228 229 |
# File 'lib/oci/data_connectivity/models/connection_validation_summary.rb', line 227 def hash [, key, model_type, model_version, parent_ref, name, description, object_version, object_status, , connection, data_asset, identifier, ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
271 272 273 274 275 276 277 278 279 280 |
# File 'lib/oci/data_connectivity/models/connection_validation_summary.rb', line 271 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
265 266 267 |
# File 'lib/oci/data_connectivity/models/connection_validation_summary.rb', line 265 def to_s to_hash.to_s end |