Class: OCI::DataConnectivity::Models::CreateConnectivityValidationDetails
- Inherits:
-
Object
- Object
- OCI::DataConnectivity::Models::CreateConnectivityValidationDetails
- Defined in:
- lib/oci/data_connectivity/models/create_connectivity_validation_details.rb
Overview
Input to perform connector validation. If defines some data integration semantics in a data flow. It may be reading/writing data or transforming the data. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
DataConnectivity::Models::Source, DataConnectivity::Models::Target
Constant Summary collapse
- MODEL_TYPE_ENUM =
[ MODEL_TYPE_SOURCE_OPERATOR = 'SOURCE_OPERATOR'.freeze, MODEL_TYPE_TARGET_OPERATOR = 'TARGET_OPERATOR'.freeze ].freeze
Instance Attribute Summary collapse
-
#description ⇒ String
Details about the operator.
-
#identifier ⇒ String
Value can only contain upper case letters, underscore, and numbers.
-
#input_ports ⇒ Array<OCI::DataConnectivity::Models::InputPort>
An array of input ports.
-
#key ⇒ String
The key of the object.
-
#model_type ⇒ String
**[Required]** The model type of the operator.
-
#model_version ⇒ String
The model version of an object.
-
#name ⇒ String
Free form text without any restriction on permitted characters.
-
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
-
#object_version ⇒ Integer
The version of the object that is used to track changes in the object instance.
- #op_config_values ⇒ OCI::DataConnectivity::Models::ConfigValues
-
#output_ports ⇒ Array<OCI::DataConnectivity::Models::OutputPort>
An array of output ports.
-
#parameters ⇒ Array<OCI::DataConnectivity::Models::Parameter>
An array of parameters used in the data flow.
- #parent_ref ⇒ OCI::DataConnectivity::Models::ParentReference
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateConnectivityValidationDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateConnectivityValidationDetails
Initializes the object
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/oci/data_connectivity/models/create_connectivity_validation_details.rb', line 143 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.model_type = attributes[:'modelType'] if attributes[:'modelType'] raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type') self.model_type = attributes[:'model_type'] if attributes[:'model_type'] self.key = attributes[:'key'] if attributes[:'key'] self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion'] raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version') self.model_version = attributes[:'model_version'] if attributes[:'model_version'] self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef'] raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref') self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref'] self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.object_version = attributes[:'objectVersion'] if attributes[:'objectVersion'] raise 'You cannot provide both :objectVersion and :object_version' if attributes.key?(:'objectVersion') && attributes.key?(:'object_version') self.object_version = attributes[:'object_version'] if attributes[:'object_version'] self.input_ports = attributes[:'inputPorts'] if attributes[:'inputPorts'] raise 'You cannot provide both :inputPorts and :input_ports' if attributes.key?(:'inputPorts') && attributes.key?(:'input_ports') self.input_ports = attributes[:'input_ports'] if attributes[:'input_ports'] self.output_ports = attributes[:'outputPorts'] if attributes[:'outputPorts'] raise 'You cannot provide both :outputPorts and :output_ports' if attributes.key?(:'outputPorts') && attributes.key?(:'output_ports') self.output_ports = attributes[:'output_ports'] if attributes[:'output_ports'] self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus'] raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status') self.object_status = attributes[:'object_status'] if attributes[:'object_status'] self.identifier = attributes[:'identifier'] if attributes[:'identifier'] self.parameters = attributes[:'parameters'] if attributes[:'parameters'] self.op_config_values = attributes[:'opConfigValues'] if attributes[:'opConfigValues'] raise 'You cannot provide both :opConfigValues and :op_config_values' if attributes.key?(:'opConfigValues') && attributes.key?(:'op_config_values') self.op_config_values = attributes[:'op_config_values'] if attributes[:'op_config_values'] end |
Instance Attribute Details
#description ⇒ String
Details about the operator.
37 38 39 |
# File 'lib/oci/data_connectivity/models/create_connectivity_validation_details.rb', line 37 def description @description end |
#identifier ⇒ String
Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.
57 58 59 |
# File 'lib/oci/data_connectivity/models/create_connectivity_validation_details.rb', line 57 def identifier @identifier end |
#input_ports ⇒ Array<OCI::DataConnectivity::Models::InputPort>
An array of input ports.
45 46 47 |
# File 'lib/oci/data_connectivity/models/create_connectivity_validation_details.rb', line 45 def input_ports @input_ports end |
#key ⇒ String
The key of the object.
22 23 24 |
# File 'lib/oci/data_connectivity/models/create_connectivity_validation_details.rb', line 22 def key @key end |
#model_type ⇒ String
**[Required]** The model type of the operator.
18 19 20 |
# File 'lib/oci/data_connectivity/models/create_connectivity_validation_details.rb', line 18 def model_type @model_type end |
#model_version ⇒ String
The model version of an object.
26 27 28 |
# File 'lib/oci/data_connectivity/models/create_connectivity_validation_details.rb', line 26 def model_version @model_version end |
#name ⇒ String
Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.
33 34 35 |
# File 'lib/oci/data_connectivity/models/create_connectivity_validation_details.rb', line 33 def name @name end |
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
53 54 55 |
# File 'lib/oci/data_connectivity/models/create_connectivity_validation_details.rb', line 53 def object_status @object_status end |
#object_version ⇒ Integer
The version of the object that is used to track changes in the object instance.
41 42 43 |
# File 'lib/oci/data_connectivity/models/create_connectivity_validation_details.rb', line 41 def object_version @object_version end |
#op_config_values ⇒ OCI::DataConnectivity::Models::ConfigValues
64 65 66 |
# File 'lib/oci/data_connectivity/models/create_connectivity_validation_details.rb', line 64 def op_config_values @op_config_values end |
#output_ports ⇒ Array<OCI::DataConnectivity::Models::OutputPort>
An array of output ports.
49 50 51 |
# File 'lib/oci/data_connectivity/models/create_connectivity_validation_details.rb', line 49 def output_ports @output_ports end |
#parameters ⇒ Array<OCI::DataConnectivity::Models::Parameter>
An array of parameters used in the data flow.
61 62 63 |
# File 'lib/oci/data_connectivity/models/create_connectivity_validation_details.rb', line 61 def parameters @parameters end |
#parent_ref ⇒ OCI::DataConnectivity::Models::ParentReference
29 30 31 |
# File 'lib/oci/data_connectivity/models/create_connectivity_validation_details.rb', line 29 def parent_ref @parent_ref end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/oci/data_connectivity/models/create_connectivity_validation_details.rb', line 67 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'key': :'key', 'model_version': :'modelVersion', 'parent_ref': :'parentRef', 'name': :'name', 'description': :'description', 'object_version': :'objectVersion', 'input_ports': :'inputPorts', 'output_ports': :'outputPorts', 'object_status': :'objectStatus', 'identifier': :'identifier', 'parameters': :'parameters', 'op_config_values': :'opConfigValues' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
113 114 115 116 117 118 119 120 121 |
# File 'lib/oci/data_connectivity/models/create_connectivity_validation_details.rb', line 113 def self.get_subtype(object_hash) type = object_hash[:'modelType'] # rubocop:disable Style/SymbolLiteral return 'OCI::DataConnectivity::Models::Target' if type == 'TARGET_OPERATOR' return 'OCI::DataConnectivity::Models::Source' if type == 'SOURCE_OPERATOR' # TODO: Log a warning when the subtype is not found. 'OCI::DataConnectivity::Models::CreateConnectivityValidationDetails' end |
.swagger_types ⇒ Object
Attribute type mapping.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/oci/data_connectivity/models/create_connectivity_validation_details.rb', line 88 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'key': :'String', 'model_version': :'String', 'parent_ref': :'OCI::DataConnectivity::Models::ParentReference', 'name': :'String', 'description': :'String', 'object_version': :'Integer', 'input_ports': :'Array<OCI::DataConnectivity::Models::InputPort>', 'output_ports': :'Array<OCI::DataConnectivity::Models::OutputPort>', 'object_status': :'Integer', 'identifier': :'String', 'parameters': :'Array<OCI::DataConnectivity::Models::Parameter>', 'op_config_values': :'OCI::DataConnectivity::Models::ConfigValues' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/oci/data_connectivity/models/create_connectivity_validation_details.rb', line 223 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && key == other.key && model_version == other.model_version && parent_ref == other.parent_ref && name == other.name && description == other.description && object_version == other.object_version && input_ports == other.input_ports && output_ports == other.output_ports && object_status == other.object_status && identifier == other.identifier && parameters == other.parameters && op_config_values == other.op_config_values end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 |
# File 'lib/oci/data_connectivity/models/create_connectivity_validation_details.rb', line 265 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
245 246 247 |
# File 'lib/oci/data_connectivity/models/create_connectivity_validation_details.rb', line 245 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
254 255 256 |
# File 'lib/oci/data_connectivity/models/create_connectivity_validation_details.rb', line 254 def hash [model_type, key, model_version, parent_ref, name, description, object_version, input_ports, output_ports, object_status, identifier, parameters, op_config_values].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
298 299 300 301 302 303 304 305 306 307 |
# File 'lib/oci/data_connectivity/models/create_connectivity_validation_details.rb', line 298 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
292 293 294 |
# File 'lib/oci/data_connectivity/models/create_connectivity_validation_details.rb', line 292 def to_s to_hash.to_s end |