Class: OCI::DataConnectivity::Models::CreateDataProfileDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_connectivity/models/create_data_profile_details.rb

Overview

The data profile payload.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateDataProfileDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/oci/data_connectivity/models/create_data_profile_details.rb', line 68

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.read_operation_config = attributes[:'readOperationConfig'] if attributes[:'readOperationConfig']

  raise 'You cannot provide both :readOperationConfig and :read_operation_config' if attributes.key?(:'readOperationConfig') && attributes.key?(:'read_operation_config')

  self.read_operation_config = attributes[:'read_operation_config'] if attributes[:'read_operation_config']

  self.data_asset = attributes[:'dataAsset'] if attributes[:'dataAsset']

  raise 'You cannot provide both :dataAsset and :data_asset' if attributes.key?(:'dataAsset') && attributes.key?(:'data_asset')

  self.data_asset = attributes[:'data_asset'] if attributes[:'data_asset']

  self.connection = attributes[:'connection'] if attributes[:'connection']

  self.schema = attributes[:'schema'] if attributes[:'schema']

  self.data_entity = attributes[:'dataEntity'] if attributes[:'dataEntity']

  raise 'You cannot provide both :dataEntity and :data_entity' if attributes.key?(:'dataEntity') && attributes.key?(:'data_entity')

  self.data_entity = attributes[:'data_entity'] if attributes[:'data_entity']

  self.profile_config = attributes[:'profileConfig'] if attributes[:'profileConfig']

  raise 'You cannot provide both :profileConfig and :profile_config' if attributes.key?(:'profileConfig') && attributes.key?(:'profile_config')

  self.profile_config = attributes[:'profile_config'] if attributes[:'profile_config']
end

Instance Attribute Details

#connectionOCI::DataConnectivity::Models::Connection



17
18
19
# File 'lib/oci/data_connectivity/models/create_data_profile_details.rb', line 17

def connection
  @connection
end

#data_assetOCI::DataConnectivity::Models::DataAsset



14
15
16
# File 'lib/oci/data_connectivity/models/create_data_profile_details.rb', line 14

def data_asset
  @data_asset
end

#data_entityOCI::DataConnectivity::Models::DataEntity



23
24
25
# File 'lib/oci/data_connectivity/models/create_data_profile_details.rb', line 23

def data_entity
  @data_entity
end

#profile_configOCI::DataConnectivity::Models::ProfileConfig



26
27
28
# File 'lib/oci/data_connectivity/models/create_data_profile_details.rb', line 26

def profile_config
  @profile_config
end

#read_operation_configOCI::DataConnectivity::Models::ReadOperationConfig



11
12
13
# File 'lib/oci/data_connectivity/models/create_data_profile_details.rb', line 11

def read_operation_config
  @read_operation_config
end

#schemaOCI::DataConnectivity::Models::Schema

Returns:

  • (OCI::DataConnectivity::Models::Schema)


20
21
22
# File 'lib/oci/data_connectivity/models/create_data_profile_details.rb', line 20

def schema
  @schema
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



29
30
31
32
33
34
35
36
37
38
39
40
# File 'lib/oci/data_connectivity/models/create_data_profile_details.rb', line 29

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'read_operation_config': :'readOperationConfig',
    'data_asset': :'dataAsset',
    'connection': :'connection',
    'schema': :'schema',
    'data_entity': :'dataEntity',
    'profile_config': :'profileConfig'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/oci/data_connectivity/models/create_data_profile_details.rb', line 43

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'read_operation_config': :'OCI::DataConnectivity::Models::ReadOperationConfig',
    'data_asset': :'OCI::DataConnectivity::Models::DataAsset',
    'connection': :'OCI::DataConnectivity::Models::Connection',
    'schema': :'OCI::DataConnectivity::Models::Schema',
    'data_entity': :'OCI::DataConnectivity::Models::DataEntity',
    'profile_config': :'OCI::DataConnectivity::Models::ProfileConfig'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



110
111
112
113
114
115
116
117
118
119
120
# File 'lib/oci/data_connectivity/models/create_data_profile_details.rb', line 110

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    read_operation_config == other.read_operation_config &&
    data_asset == other.data_asset &&
    connection == other.connection &&
    schema == other.schema &&
    data_entity == other.data_entity &&
    profile_config == other.profile_config
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/oci/data_connectivity/models/create_data_profile_details.rb', line 145

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


125
126
127
# File 'lib/oci/data_connectivity/models/create_data_profile_details.rb', line 125

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



134
135
136
# File 'lib/oci/data_connectivity/models/create_data_profile_details.rb', line 134

def hash
  [read_operation_config, data_asset, connection, schema, data_entity, profile_config].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



178
179
180
181
182
183
184
185
186
187
# File 'lib/oci/data_connectivity/models/create_data_profile_details.rb', line 178

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



172
173
174
# File 'lib/oci/data_connectivity/models/create_data_profile_details.rb', line 172

def to_s
  to_hash.to_s
end