Class: OCI::DataConnectivity::Models::CreateDpEndpointFromPrivate
- Inherits:
-
CreateDpEndpointDetails
- Object
- CreateDpEndpointDetails
- OCI::DataConnectivity::Models::CreateDpEndpointFromPrivate
- Defined in:
- lib/oci/data_connectivity/models/create_dp_endpoint_from_private.rb
Overview
The details to create a private endpoint.
Constant Summary collapse
- STATE_ENUM =
[ STATE_ACTIVE = 'ACTIVE'.freeze, STATE_INACTIVE = 'INACTIVE'.freeze ].freeze
Constants inherited from CreateDpEndpointDetails
OCI::DataConnectivity::Models::CreateDpEndpointDetails::MODEL_TYPE_ENUM
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
The compartmentId of private endpoint resource.
-
#dcms_endpoint_id ⇒ String
**[Required]** The endpoint ID provided by control plane.
-
#dns_proxy_ip ⇒ String
The IP address of dns proxy.
-
#dns_zones ⇒ Array<String>
Array of dns zones to be use during private endpoint resolution.
-
#pe_id ⇒ String
The ocid of private endpoint resource.
-
#private_endpoint_ip ⇒ String
The ocid of private endpoint resource.
-
#state ⇒ String
Specifies the private endpoint state.
Attributes inherited from CreateDpEndpointDetails
#data_assets, #description, #identifier, #key, #model_type, #model_version, #name, #object_status, #object_version, #parent_ref
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateDpEndpointFromPrivate
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from CreateDpEndpointDetails
Constructor Details
#initialize(attributes = {}) ⇒ CreateDpEndpointFromPrivate
Initializes the object
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/oci/data_connectivity/models/create_dp_endpoint_from_private.rb', line 116 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['modelType'] = 'PRIVATE_END_POINT' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.dcms_endpoint_id = attributes[:'dcmsEndpointId'] if attributes[:'dcmsEndpointId'] raise 'You cannot provide both :dcmsEndpointId and :dcms_endpoint_id' if attributes.key?(:'dcmsEndpointId') && attributes.key?(:'dcms_endpoint_id') self.dcms_endpoint_id = attributes[:'dcms_endpoint_id'] if attributes[:'dcms_endpoint_id'] self.pe_id = attributes[:'peId'] if attributes[:'peId'] raise 'You cannot provide both :peId and :pe_id' if attributes.key?(:'peId') && attributes.key?(:'pe_id') self.pe_id = attributes[:'pe_id'] if attributes[:'pe_id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.dns_proxy_ip = attributes[:'dnsProxyIp'] if attributes[:'dnsProxyIp'] raise 'You cannot provide both :dnsProxyIp and :dns_proxy_ip' if attributes.key?(:'dnsProxyIp') && attributes.key?(:'dns_proxy_ip') self.dns_proxy_ip = attributes[:'dns_proxy_ip'] if attributes[:'dns_proxy_ip'] self.private_endpoint_ip = attributes[:'privateEndpointIp'] if attributes[:'privateEndpointIp'] raise 'You cannot provide both :privateEndpointIp and :private_endpoint_ip' if attributes.key?(:'privateEndpointIp') && attributes.key?(:'private_endpoint_ip') self.private_endpoint_ip = attributes[:'private_endpoint_ip'] if attributes[:'private_endpoint_ip'] self.dns_zones = attributes[:'dnsZones'] if attributes[:'dnsZones'] raise 'You cannot provide both :dnsZones and :dns_zones' if attributes.key?(:'dnsZones') && attributes.key?(:'dns_zones') self.dns_zones = attributes[:'dns_zones'] if attributes[:'dns_zones'] self.state = attributes[:'state'] if attributes[:'state'] end |
Instance Attribute Details
#compartment_id ⇒ String
The compartmentId of private endpoint resource.
26 27 28 |
# File 'lib/oci/data_connectivity/models/create_dp_endpoint_from_private.rb', line 26 def compartment_id @compartment_id end |
#dcms_endpoint_id ⇒ String
**[Required]** The endpoint ID provided by control plane.
18 19 20 |
# File 'lib/oci/data_connectivity/models/create_dp_endpoint_from_private.rb', line 18 def dcms_endpoint_id @dcms_endpoint_id end |
#dns_proxy_ip ⇒ String
The IP address of dns proxy.
30 31 32 |
# File 'lib/oci/data_connectivity/models/create_dp_endpoint_from_private.rb', line 30 def dns_proxy_ip @dns_proxy_ip end |
#dns_zones ⇒ Array<String>
Array of dns zones to be use during private endpoint resolution.
38 39 40 |
# File 'lib/oci/data_connectivity/models/create_dp_endpoint_from_private.rb', line 38 def dns_zones @dns_zones end |
#pe_id ⇒ String
The ocid of private endpoint resource.
22 23 24 |
# File 'lib/oci/data_connectivity/models/create_dp_endpoint_from_private.rb', line 22 def pe_id @pe_id end |
#private_endpoint_ip ⇒ String
The ocid of private endpoint resource.
34 35 36 |
# File 'lib/oci/data_connectivity/models/create_dp_endpoint_from_private.rb', line 34 def private_endpoint_ip @private_endpoint_ip end |
#state ⇒ String
Specifies the private endpoint state.
42 43 44 |
# File 'lib/oci/data_connectivity/models/create_dp_endpoint_from_private.rb', line 42 def state @state end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/oci/data_connectivity/models/create_dp_endpoint_from_private.rb', line 45 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'key': :'key', 'model_version': :'modelVersion', 'parent_ref': :'parentRef', 'name': :'name', 'description': :'description', 'object_status': :'objectStatus', 'object_version': :'objectVersion', 'identifier': :'identifier', 'data_assets': :'dataAssets', 'dcms_endpoint_id': :'dcmsEndpointId', 'pe_id': :'peId', 'compartment_id': :'compartmentId', 'dns_proxy_ip': :'dnsProxyIp', 'private_endpoint_ip': :'privateEndpointIp', 'dns_zones': :'dnsZones', 'state': :'state' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/oci/data_connectivity/models/create_dp_endpoint_from_private.rb', line 70 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'key': :'String', 'model_version': :'String', 'parent_ref': :'OCI::DataConnectivity::Models::ParentReference', 'name': :'String', 'description': :'String', 'object_status': :'Integer', 'object_version': :'Integer', 'identifier': :'String', 'data_assets': :'Array<OCI::DataConnectivity::Models::DataAsset>', 'dcms_endpoint_id': :'String', 'pe_id': :'String', 'compartment_id': :'String', 'dns_proxy_ip': :'String', 'private_endpoint_ip': :'String', 'dns_zones': :'Array<String>', 'state': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/oci/data_connectivity/models/create_dp_endpoint_from_private.rb', line 180 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && key == other.key && model_version == other.model_version && parent_ref == other.parent_ref && name == other.name && description == other.description && object_status == other.object_status && object_version == other.object_version && identifier == other.identifier && data_assets == other.data_assets && dcms_endpoint_id == other.dcms_endpoint_id && pe_id == other.pe_id && compartment_id == other.compartment_id && dns_proxy_ip == other.dns_proxy_ip && private_endpoint_ip == other.private_endpoint_ip && dns_zones == other.dns_zones && state == other.state end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/oci/data_connectivity/models/create_dp_endpoint_from_private.rb', line 226 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
206 207 208 |
# File 'lib/oci/data_connectivity/models/create_dp_endpoint_from_private.rb', line 206 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
215 216 217 |
# File 'lib/oci/data_connectivity/models/create_dp_endpoint_from_private.rb', line 215 def hash [model_type, key, model_version, parent_ref, name, description, object_status, object_version, identifier, data_assets, dcms_endpoint_id, pe_id, compartment_id, dns_proxy_ip, private_endpoint_ip, dns_zones, state].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
259 260 261 262 263 264 265 266 267 268 |
# File 'lib/oci/data_connectivity/models/create_dp_endpoint_from_private.rb', line 259 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
253 254 255 |
# File 'lib/oci/data_connectivity/models/create_dp_endpoint_from_private.rb', line 253 def to_s to_hash.to_s end |