Class: OCI::DataConnectivity::Models::CreateEndpointDetails
- Inherits:
-
Object
- Object
- OCI::DataConnectivity::Models::CreateEndpointDetails
- Defined in:
- lib/oci/data_connectivity/models/create_endpoint_details.rb
Overview
The information about new Endpoint.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
Compartment Identifier.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Usage of predefined tag keys.
-
#description ⇒ String
Data Connectivity Management Registry description.
-
#display_name ⇒ String
**[Required]** Data Connectivity Management Registry display name, registries can be renamed.
-
#dns_zones ⇒ Array<String>
List of DNS zones to be used by the data assets to be harvested.
-
#endpoint_size ⇒ Integer
Endpoint size for reverse connection capacity.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#nsg_ids ⇒ Array<String>
List of NSGs to which the Private Endpoint VNIC must be added.
-
#subnet_id ⇒ String
Subnet Identifier for customer connected databases.
-
#vcn_id ⇒ String
VCN Identifier where the subnet resides.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateEndpointDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateEndpointDetails
Initializes the object
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/oci/data_connectivity/models/create_endpoint_details.rb', line 108 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.vcn_id = attributes[:'vcnId'] if attributes[:'vcnId'] raise 'You cannot provide both :vcnId and :vcn_id' if attributes.key?(:'vcnId') && attributes.key?(:'vcn_id') self.vcn_id = attributes[:'vcn_id'] if attributes[:'vcn_id'] self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId'] raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id') self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id'] self.dns_zones = attributes[:'dnsZones'] if attributes[:'dnsZones'] raise 'You cannot provide both :dnsZones and :dns_zones' if attributes.key?(:'dnsZones') && attributes.key?(:'dns_zones') self.dns_zones = attributes[:'dns_zones'] if attributes[:'dns_zones'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.description = attributes[:'description'] if attributes[:'description'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.endpoint_size = attributes[:'endpointSize'] if attributes[:'endpointSize'] raise 'You cannot provide both :endpointSize and :endpoint_size' if attributes.key?(:'endpointSize') && attributes.key?(:'endpoint_size') self.endpoint_size = attributes[:'endpoint_size'] if attributes[:'endpoint_size'] self.nsg_ids = attributes[:'nsgIds'] if attributes[:'nsgIds'] raise 'You cannot provide both :nsgIds and :nsg_ids' if attributes.key?(:'nsgIds') && attributes.key?(:'nsg_ids') self.nsg_ids = attributes[:'nsg_ids'] if attributes[:'nsg_ids'] end |
Instance Attribute Details
#compartment_id ⇒ String
Compartment Identifier
46 47 48 |
# File 'lib/oci/data_connectivity/models/create_endpoint_details.rb', line 46 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Usage of predefined tag keys. These predefined keys are scoped to namespaces. Example: `{"bar-key": "value"}`
34 35 36 |
# File 'lib/oci/data_connectivity/models/create_endpoint_details.rb', line 34 def @defined_tags end |
#description ⇒ String
Data Connectivity Management Registry description
38 39 40 |
# File 'lib/oci/data_connectivity/models/create_endpoint_details.rb', line 38 def description @description end |
#display_name ⇒ String
**[Required]** Data Connectivity Management Registry display name, registries can be renamed
42 43 44 |
# File 'lib/oci/data_connectivity/models/create_endpoint_details.rb', line 42 def display_name @display_name end |
#dns_zones ⇒ Array<String>
List of DNS zones to be used by the data assets to be harvested. Example: custpvtsubnet.oraclevcn.com for data asset: db.custpvtsubnet.oraclevcn.com
22 23 24 |
# File 'lib/oci/data_connectivity/models/create_endpoint_details.rb', line 22 def dns_zones @dns_zones end |
#endpoint_size ⇒ Integer
Endpoint size for reverse connection capacity.
50 51 52 |
# File 'lib/oci/data_connectivity/models/create_endpoint_details.rb', line 50 def endpoint_size @endpoint_size end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
28 29 30 |
# File 'lib/oci/data_connectivity/models/create_endpoint_details.rb', line 28 def @freeform_tags end |
#nsg_ids ⇒ Array<String>
List of NSGs to which the Private Endpoint VNIC must be added.
54 55 56 |
# File 'lib/oci/data_connectivity/models/create_endpoint_details.rb', line 54 def nsg_ids @nsg_ids end |
#subnet_id ⇒ String
Subnet Identifier for customer connected databases
16 17 18 |
# File 'lib/oci/data_connectivity/models/create_endpoint_details.rb', line 16 def subnet_id @subnet_id end |
#vcn_id ⇒ String
VCN Identifier where the subnet resides.
12 13 14 |
# File 'lib/oci/data_connectivity/models/create_endpoint_details.rb', line 12 def vcn_id @vcn_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/oci/data_connectivity/models/create_endpoint_details.rb', line 57 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'vcn_id': :'vcnId', 'subnet_id': :'subnetId', 'dns_zones': :'dnsZones', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'description': :'description', 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'endpoint_size': :'endpointSize', 'nsg_ids': :'nsgIds' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/oci/data_connectivity/models/create_endpoint_details.rb', line 75 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'vcn_id': :'String', 'subnet_id': :'String', 'dns_zones': :'Array<String>', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'description': :'String', 'display_name': :'String', 'compartment_id': :'String', 'endpoint_size': :'Integer', 'nsg_ids': :'Array<String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/oci/data_connectivity/models/create_endpoint_details.rb', line 178 def ==(other) return true if equal?(other) self.class == other.class && vcn_id == other.vcn_id && subnet_id == other.subnet_id && dns_zones == other.dns_zones && == other. && == other. && description == other.description && display_name == other.display_name && compartment_id == other.compartment_id && endpoint_size == other.endpoint_size && nsg_ids == other.nsg_ids end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/oci/data_connectivity/models/create_endpoint_details.rb', line 217 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
197 198 199 |
# File 'lib/oci/data_connectivity/models/create_endpoint_details.rb', line 197 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
206 207 208 |
# File 'lib/oci/data_connectivity/models/create_endpoint_details.rb', line 206 def hash [vcn_id, subnet_id, dns_zones, , , description, display_name, compartment_id, endpoint_size, nsg_ids].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
250 251 252 253 254 255 256 257 258 259 |
# File 'lib/oci/data_connectivity/models/create_endpoint_details.rb', line 250 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
244 245 246 |
# File 'lib/oci/data_connectivity/models/create_endpoint_details.rb', line 244 def to_s to_hash.to_s end |