Class: OCI::DataConnectivity::Models::CreateEntityShapeDetails
- Inherits:
-
Object
- Object
- OCI::DataConnectivity::Models::CreateEntityShapeDetails
- Defined in:
- lib/oci/data_connectivity/models/create_entity_shape_details.rb
Overview
The data entity shape object. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
CreateEntityShapeFromDataStore, CreateEntityShapeFromFile, CreateEntityShapeFromSQL, CreateEntityShapeFromTable, CreateEntityShapeFromView
Constant Summary collapse
- MODEL_TYPE_ENUM =
[ MODEL_TYPE_VIEW_ENTITY = 'VIEW_ENTITY'.freeze, MODEL_TYPE_TABLE_ENTITY = 'TABLE_ENTITY'.freeze, MODEL_TYPE_FILE_ENTITY = 'FILE_ENTITY'.freeze, MODEL_TYPE_DATA_STORE_ENTITY = 'DATA_STORE_ENTITY'.freeze, MODEL_TYPE_SQL_ENTITY = 'SQL_ENTITY'.freeze ].freeze
- ENTITY_TYPE_ENUM =
[ ENTITY_TYPE_TABLE = 'TABLE'.freeze, ENTITY_TYPE_VIEW = 'VIEW'.freeze, ENTITY_TYPE_FILE = 'FILE'.freeze, ENTITY_TYPE_SQL = 'SQL'.freeze ].freeze
Instance Attribute Summary collapse
-
#entity_properties ⇒ Hash<String, String>
Map<String, String> for entity properties.
-
#entity_type ⇒ String
The entity type.
-
#external_key ⇒ String
The external key for the object.
-
#foreign_keys ⇒ Array<OCI::DataConnectivity::Models::ForeignKey>
An array of foreign keys.
-
#identifier ⇒ String
Value can only contain upper case letters, underscore, and numbers.
-
#key ⇒ String
The object key.
-
#model_type ⇒ String
**[Required]** The data entity type.
-
#model_version ⇒ String
The object's model version.
-
#name ⇒ String
**[Required]** Free form text without any restriction on permitted characters.
-
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
-
#object_version ⇒ Integer
The version of the object that is used to track changes in the object instance.
-
#other_type_label ⇒ String
Specifies other type label.
- #parent_ref ⇒ OCI::DataConnectivity::Models::ParentReference
-
#resource_name ⇒ String
The resource name.
- #shape ⇒ OCI::DataConnectivity::Models::Shape
-
#shape_id ⇒ String
The shape ID.
- #types ⇒ OCI::DataConnectivity::Models::TypeLibrary
-
#unique_keys ⇒ Array<OCI::DataConnectivity::Models::UniqueKey>
An array of unique keys.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateEntityShapeDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateEntityShapeDetails
Initializes the object
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 |
# File 'lib/oci/data_connectivity/models/create_entity_shape_details.rb', line 190 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.model_type = attributes[:'modelType'] if attributes[:'modelType'] raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type') self.model_type = attributes[:'model_type'] if attributes[:'model_type'] self.key = attributes[:'key'] if attributes[:'key'] self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion'] raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version') self.model_version = attributes[:'model_version'] if attributes[:'model_version'] self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef'] raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref') self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref'] self.name = attributes[:'name'] if attributes[:'name'] self.object_version = attributes[:'objectVersion'] if attributes[:'objectVersion'] raise 'You cannot provide both :objectVersion and :object_version' if attributes.key?(:'objectVersion') && attributes.key?(:'object_version') self.object_version = attributes[:'object_version'] if attributes[:'object_version'] self.external_key = attributes[:'externalKey'] if attributes[:'externalKey'] raise 'You cannot provide both :externalKey and :external_key' if attributes.key?(:'externalKey') && attributes.key?(:'external_key') self.external_key = attributes[:'external_key'] if attributes[:'external_key'] self.shape = attributes[:'shape'] if attributes[:'shape'] self.shape_id = attributes[:'shapeId'] if attributes[:'shapeId'] raise 'You cannot provide both :shapeId and :shape_id' if attributes.key?(:'shapeId') && attributes.key?(:'shape_id') self.shape_id = attributes[:'shape_id'] if attributes[:'shape_id'] self.entity_type = attributes[:'entityType'] if attributes[:'entityType'] raise 'You cannot provide both :entityType and :entity_type' if attributes.key?(:'entityType') && attributes.key?(:'entity_type') self.entity_type = attributes[:'entity_type'] if attributes[:'entity_type'] self.other_type_label = attributes[:'otherTypeLabel'] if attributes[:'otherTypeLabel'] raise 'You cannot provide both :otherTypeLabel and :other_type_label' if attributes.key?(:'otherTypeLabel') && attributes.key?(:'other_type_label') self.other_type_label = attributes[:'other_type_label'] if attributes[:'other_type_label'] self.unique_keys = attributes[:'uniqueKeys'] if attributes[:'uniqueKeys'] raise 'You cannot provide both :uniqueKeys and :unique_keys' if attributes.key?(:'uniqueKeys') && attributes.key?(:'unique_keys') self.unique_keys = attributes[:'unique_keys'] if attributes[:'unique_keys'] self.foreign_keys = attributes[:'foreignKeys'] if attributes[:'foreignKeys'] raise 'You cannot provide both :foreignKeys and :foreign_keys' if attributes.key?(:'foreignKeys') && attributes.key?(:'foreign_keys') self.foreign_keys = attributes[:'foreign_keys'] if attributes[:'foreign_keys'] self.resource_name = attributes[:'resourceName'] if attributes[:'resourceName'] raise 'You cannot provide both :resourceName and :resource_name' if attributes.key?(:'resourceName') && attributes.key?(:'resource_name') self.resource_name = attributes[:'resource_name'] if attributes[:'resource_name'] self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus'] raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status') self.object_status = attributes[:'object_status'] if attributes[:'object_status'] self.identifier = attributes[:'identifier'] if attributes[:'identifier'] self.types = attributes[:'types'] if attributes[:'types'] self.entity_properties = attributes[:'entityProperties'] if attributes[:'entityProperties'] raise 'You cannot provide both :entityProperties and :entity_properties' if attributes.key?(:'entityProperties') && attributes.key?(:'entity_properties') self.entity_properties = attributes[:'entity_properties'] if attributes[:'entity_properties'] end |
Instance Attribute Details
#entity_properties ⇒ Hash<String, String>
Map<String, String> for entity properties
93 94 95 |
# File 'lib/oci/data_connectivity/models/create_entity_shape_details.rb', line 93 def entity_properties @entity_properties end |
#entity_type ⇒ String
The entity type.
62 63 64 |
# File 'lib/oci/data_connectivity/models/create_entity_shape_details.rb', line 62 def entity_type @entity_type end |
#external_key ⇒ String
The external key for the object.
51 52 53 |
# File 'lib/oci/data_connectivity/models/create_entity_shape_details.rb', line 51 def external_key @external_key end |
#foreign_keys ⇒ Array<OCI::DataConnectivity::Models::ForeignKey>
An array of foreign keys.
74 75 76 |
# File 'lib/oci/data_connectivity/models/create_entity_shape_details.rb', line 74 def foreign_keys @foreign_keys end |
#identifier ⇒ String
Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.
86 87 88 |
# File 'lib/oci/data_connectivity/models/create_entity_shape_details.rb', line 86 def identifier @identifier end |
#key ⇒ String
The object key.
32 33 34 |
# File 'lib/oci/data_connectivity/models/create_entity_shape_details.rb', line 32 def key @key end |
#model_type ⇒ String
**[Required]** The data entity type.
28 29 30 |
# File 'lib/oci/data_connectivity/models/create_entity_shape_details.rb', line 28 def model_type @model_type end |
#model_version ⇒ String
The object's model version.
36 37 38 |
# File 'lib/oci/data_connectivity/models/create_entity_shape_details.rb', line 36 def model_version @model_version end |
#name ⇒ String
**[Required]** Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.
43 44 45 |
# File 'lib/oci/data_connectivity/models/create_entity_shape_details.rb', line 43 def name @name end |
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
82 83 84 |
# File 'lib/oci/data_connectivity/models/create_entity_shape_details.rb', line 82 def object_status @object_status end |
#object_version ⇒ Integer
The version of the object that is used to track changes in the object instance.
47 48 49 |
# File 'lib/oci/data_connectivity/models/create_entity_shape_details.rb', line 47 def object_version @object_version end |
#other_type_label ⇒ String
Specifies other type label.
66 67 68 |
# File 'lib/oci/data_connectivity/models/create_entity_shape_details.rb', line 66 def other_type_label @other_type_label end |
#parent_ref ⇒ OCI::DataConnectivity::Models::ParentReference
39 40 41 |
# File 'lib/oci/data_connectivity/models/create_entity_shape_details.rb', line 39 def parent_ref @parent_ref end |
#resource_name ⇒ String
The resource name.
78 79 80 |
# File 'lib/oci/data_connectivity/models/create_entity_shape_details.rb', line 78 def resource_name @resource_name end |
#shape ⇒ OCI::DataConnectivity::Models::Shape
54 55 56 |
# File 'lib/oci/data_connectivity/models/create_entity_shape_details.rb', line 54 def shape @shape end |
#shape_id ⇒ String
The shape ID.
58 59 60 |
# File 'lib/oci/data_connectivity/models/create_entity_shape_details.rb', line 58 def shape_id @shape_id end |
#types ⇒ OCI::DataConnectivity::Models::TypeLibrary
89 90 91 |
# File 'lib/oci/data_connectivity/models/create_entity_shape_details.rb', line 89 def types @types end |
#unique_keys ⇒ Array<OCI::DataConnectivity::Models::UniqueKey>
An array of unique keys.
70 71 72 |
# File 'lib/oci/data_connectivity/models/create_entity_shape_details.rb', line 70 def unique_keys @unique_keys end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/oci/data_connectivity/models/create_entity_shape_details.rb', line 96 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'key': :'key', 'model_version': :'modelVersion', 'parent_ref': :'parentRef', 'name': :'name', 'object_version': :'objectVersion', 'external_key': :'externalKey', 'shape': :'shape', 'shape_id': :'shapeId', 'entity_type': :'entityType', 'other_type_label': :'otherTypeLabel', 'unique_keys': :'uniqueKeys', 'foreign_keys': :'foreignKeys', 'resource_name': :'resourceName', 'object_status': :'objectStatus', 'identifier': :'identifier', 'types': :'types', 'entity_properties': :'entityProperties' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/oci/data_connectivity/models/create_entity_shape_details.rb', line 152 def self.get_subtype(object_hash) type = object_hash[:'modelType'] # rubocop:disable Style/SymbolLiteral return 'OCI::DataConnectivity::Models::CreateEntityShapeFromDataStore' if type == 'DATA_STORE_ENTITY' return 'OCI::DataConnectivity::Models::CreateEntityShapeFromTable' if type == 'TABLE_ENTITY' return 'OCI::DataConnectivity::Models::CreateEntityShapeFromSQL' if type == 'SQL_ENTITY' return 'OCI::DataConnectivity::Models::CreateEntityShapeFromFile' if type == 'FILE_ENTITY' return 'OCI::DataConnectivity::Models::CreateEntityShapeFromView' if type == 'VIEW_ENTITY' # TODO: Log a warning when the subtype is not found. 'OCI::DataConnectivity::Models::CreateEntityShapeDetails' end |
.swagger_types ⇒ Object
Attribute type mapping.
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/oci/data_connectivity/models/create_entity_shape_details.rb', line 122 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'key': :'String', 'model_version': :'String', 'parent_ref': :'OCI::DataConnectivity::Models::ParentReference', 'name': :'String', 'object_version': :'Integer', 'external_key': :'String', 'shape': :'OCI::DataConnectivity::Models::Shape', 'shape_id': :'String', 'entity_type': :'String', 'other_type_label': :'String', 'unique_keys': :'Array<OCI::DataConnectivity::Models::UniqueKey>', 'foreign_keys': :'Array<OCI::DataConnectivity::Models::ForeignKey>', 'resource_name': :'String', 'object_status': :'Integer', 'identifier': :'String', 'types': :'OCI::DataConnectivity::Models::TypeLibrary', 'entity_properties': :'Hash<String, String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 |
# File 'lib/oci/data_connectivity/models/create_entity_shape_details.rb', line 308 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && key == other.key && model_version == other.model_version && parent_ref == other.parent_ref && name == other.name && object_version == other.object_version && external_key == other.external_key && shape == other.shape && shape_id == other.shape_id && entity_type == other.entity_type && other_type_label == other.other_type_label && unique_keys == other.unique_keys && foreign_keys == other.foreign_keys && resource_name == other.resource_name && object_status == other.object_status && identifier == other.identifier && types == other.types && entity_properties == other.entity_properties end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 |
# File 'lib/oci/data_connectivity/models/create_entity_shape_details.rb', line 355 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
335 336 337 |
# File 'lib/oci/data_connectivity/models/create_entity_shape_details.rb', line 335 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
344 345 346 |
# File 'lib/oci/data_connectivity/models/create_entity_shape_details.rb', line 344 def hash [model_type, key, model_version, parent_ref, name, object_version, external_key, shape, shape_id, entity_type, other_type_label, unique_keys, foreign_keys, resource_name, object_status, identifier, types, entity_properties].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
388 389 390 391 392 393 394 395 396 397 |
# File 'lib/oci/data_connectivity/models/create_entity_shape_details.rb', line 388 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
382 383 384 |
# File 'lib/oci/data_connectivity/models/create_entity_shape_details.rb', line 382 def to_s to_hash.to_s end |