Class: OCI::DataConnectivity::Models::CreateEntityShapeFromTable
- Inherits:
-
CreateEntityShapeDetails
- Object
- CreateEntityShapeDetails
- OCI::DataConnectivity::Models::CreateEntityShapeFromTable
- Defined in:
- lib/oci/data_connectivity/models/create_entity_shape_from_table.rb
Overview
The table data entity details.
Constant Summary
Constants inherited from CreateEntityShapeDetails
OCI::DataConnectivity::Models::CreateEntityShapeDetails::ENTITY_TYPE_ENUM, OCI::DataConnectivity::Models::CreateEntityShapeDetails::MODEL_TYPE_ENUM
Instance Attribute Summary
Attributes inherited from CreateEntityShapeDetails
#entity_properties, #entity_type, #external_key, #foreign_keys, #identifier, #key, #model_type, #model_version, #name, #object_status, #object_version, #other_type_label, #parent_ref, #resource_name, #shape, #shape_id, #types, #unique_keys
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateEntityShapeFromTable
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from CreateEntityShapeDetails
Constructor Details
#initialize(attributes = {}) ⇒ CreateEntityShapeFromTable
Initializes the object
86 87 88 89 90 91 92 |
# File 'lib/oci/data_connectivity/models/create_entity_shape_from_table.rb', line 86 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['modelType'] = 'TABLE_ENTITY' super(attributes) end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 |
# File 'lib/oci/data_connectivity/models/create_entity_shape_from_table.rb', line 12 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'key': :'key', 'model_version': :'modelVersion', 'parent_ref': :'parentRef', 'name': :'name', 'object_version': :'objectVersion', 'external_key': :'externalKey', 'shape': :'shape', 'shape_id': :'shapeId', 'entity_type': :'entityType', 'other_type_label': :'otherTypeLabel', 'unique_keys': :'uniqueKeys', 'foreign_keys': :'foreignKeys', 'resource_name': :'resourceName', 'object_status': :'objectStatus', 'identifier': :'identifier', 'types': :'types', 'entity_properties': :'entityProperties' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/oci/data_connectivity/models/create_entity_shape_from_table.rb', line 38 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'key': :'String', 'model_version': :'String', 'parent_ref': :'OCI::DataConnectivity::Models::ParentReference', 'name': :'String', 'object_version': :'Integer', 'external_key': :'String', 'shape': :'OCI::DataConnectivity::Models::Shape', 'shape_id': :'String', 'entity_type': :'String', 'other_type_label': :'String', 'unique_keys': :'Array<OCI::DataConnectivity::Models::UniqueKey>', 'foreign_keys': :'Array<OCI::DataConnectivity::Models::ForeignKey>', 'resource_name': :'String', 'object_status': :'Integer', 'identifier': :'String', 'types': :'OCI::DataConnectivity::Models::TypeLibrary', 'entity_properties': :'Hash<String, String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/oci/data_connectivity/models/create_entity_shape_from_table.rb', line 101 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && key == other.key && model_version == other.model_version && parent_ref == other.parent_ref && name == other.name && object_version == other.object_version && external_key == other.external_key && shape == other.shape && shape_id == other.shape_id && entity_type == other.entity_type && other_type_label == other.other_type_label && unique_keys == other.unique_keys && foreign_keys == other.foreign_keys && resource_name == other.resource_name && object_status == other.object_status && identifier == other.identifier && types == other.types && entity_properties == other.entity_properties end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/oci/data_connectivity/models/create_entity_shape_from_table.rb', line 148 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
128 129 130 |
# File 'lib/oci/data_connectivity/models/create_entity_shape_from_table.rb', line 128 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
137 138 139 |
# File 'lib/oci/data_connectivity/models/create_entity_shape_from_table.rb', line 137 def hash [model_type, key, model_version, parent_ref, name, object_version, external_key, shape, shape_id, entity_type, other_type_label, unique_keys, foreign_keys, resource_name, object_status, identifier, types, entity_properties].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
181 182 183 184 185 186 187 188 189 190 |
# File 'lib/oci/data_connectivity/models/create_entity_shape_from_table.rb', line 181 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
175 176 177 |
# File 'lib/oci/data_connectivity/models/create_entity_shape_from_table.rb', line 175 def to_s to_hash.to_s end |