Class: OCI::DataConnectivity::Models::CreateExecuteOperationJobDetails
- Inherits:
-
Object
- Object
- OCI::DataConnectivity::Models::CreateExecuteOperationJobDetails
- Defined in:
- lib/oci/data_connectivity/models/create_execute_operation_job_details.rb
Overview
Input details to execute operation.
Instance Attribute Summary collapse
- #call_operation_config ⇒ OCI::DataConnectivity::Models::CallOperationConfig
-
#input_records ⇒ Array<OCI::DataConnectivity::Models::OperationInputRecord>
Collection of input parameters supplied.
- #operation ⇒ OCI::DataConnectivity::Models::Operation
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateExecuteOperationJobDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateExecuteOperationJobDetails
Initializes the object
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/oci/data_connectivity/models/create_execute_operation_job_details.rb', line 51 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.operation = attributes[:'operation'] if attributes[:'operation'] self.call_operation_config = attributes[:'callOperationConfig'] if attributes[:'callOperationConfig'] raise 'You cannot provide both :callOperationConfig and :call_operation_config' if attributes.key?(:'callOperationConfig') && attributes.key?(:'call_operation_config') self.call_operation_config = attributes[:'call_operation_config'] if attributes[:'call_operation_config'] self.input_records = attributes[:'inputRecords'] if attributes[:'inputRecords'] raise 'You cannot provide both :inputRecords and :input_records' if attributes.key?(:'inputRecords') && attributes.key?(:'input_records') self.input_records = attributes[:'input_records'] if attributes[:'input_records'] end |
Instance Attribute Details
#call_operation_config ⇒ OCI::DataConnectivity::Models::CallOperationConfig
14 15 16 |
# File 'lib/oci/data_connectivity/models/create_execute_operation_job_details.rb', line 14 def call_operation_config @call_operation_config end |
#input_records ⇒ Array<OCI::DataConnectivity::Models::OperationInputRecord>
Collection of input parameters supplied.
18 19 20 |
# File 'lib/oci/data_connectivity/models/create_execute_operation_job_details.rb', line 18 def input_records @input_records end |
#operation ⇒ OCI::DataConnectivity::Models::Operation
11 12 13 |
# File 'lib/oci/data_connectivity/models/create_execute_operation_job_details.rb', line 11 def operation @operation end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
21 22 23 24 25 26 27 28 29 |
# File 'lib/oci/data_connectivity/models/create_execute_operation_job_details.rb', line 21 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'operation': :'operation', 'call_operation_config': :'callOperationConfig', 'input_records': :'inputRecords' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
32 33 34 35 36 37 38 39 40 |
# File 'lib/oci/data_connectivity/models/create_execute_operation_job_details.rb', line 32 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'operation': :'OCI::DataConnectivity::Models::Operation', 'call_operation_config': :'OCI::DataConnectivity::Models::CallOperationConfig', 'input_records': :'Array<OCI::DataConnectivity::Models::OperationInputRecord>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
79 80 81 82 83 84 85 86 |
# File 'lib/oci/data_connectivity/models/create_execute_operation_job_details.rb', line 79 def ==(other) return true if equal?(other) self.class == other.class && operation == other.operation && call_operation_config == other.call_operation_config && input_records == other.input_records end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/oci/data_connectivity/models/create_execute_operation_job_details.rb', line 111 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
91 92 93 |
# File 'lib/oci/data_connectivity/models/create_execute_operation_job_details.rb', line 91 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
100 101 102 |
# File 'lib/oci/data_connectivity/models/create_execute_operation_job_details.rb', line 100 def hash [operation, call_operation_config, input_records].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
144 145 146 147 148 149 150 151 152 153 |
# File 'lib/oci/data_connectivity/models/create_execute_operation_job_details.rb', line 144 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
138 139 140 |
# File 'lib/oci/data_connectivity/models/create_execute_operation_job_details.rb', line 138 def to_s to_hash.to_s end |