Class: OCI::DataConnectivity::Models::CreateRegistryDetails
- Inherits:
-
Object
- Object
- OCI::DataConnectivity::Models::CreateRegistryDetails
- Defined in:
- lib/oci/data_connectivity/models/create_registry_details.rb
Overview
The information about new Registry.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
Compartment Identifier.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Usage of predefined tag keys.
-
#description ⇒ String
Data Connectivity Management Registry description.
-
#display_name ⇒ String
**[Required]** Data Connectivity Management Registry display name, registries can be renamed.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateRegistryDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateRegistryDetails
Initializes the object
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/oci/data_connectivity/models/create_registry_details.rb', line 71 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.description = attributes[:'description'] if attributes[:'description'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] end |
Instance Attribute Details
#compartment_id ⇒ String
Compartment Identifier
32 33 34 |
# File 'lib/oci/data_connectivity/models/create_registry_details.rb', line 32 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Usage of predefined tag keys. These predefined keys are scoped to namespaces. Example: `{"bar-key": "value"}`
20 21 22 |
# File 'lib/oci/data_connectivity/models/create_registry_details.rb', line 20 def @defined_tags end |
#description ⇒ String
Data Connectivity Management Registry description
24 25 26 |
# File 'lib/oci/data_connectivity/models/create_registry_details.rb', line 24 def description @description end |
#display_name ⇒ String
**[Required]** Data Connectivity Management Registry display name, registries can be renamed
28 29 30 |
# File 'lib/oci/data_connectivity/models/create_registry_details.rb', line 28 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
14 15 16 |
# File 'lib/oci/data_connectivity/models/create_registry_details.rb', line 14 def @freeform_tags end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 45 |
# File 'lib/oci/data_connectivity/models/create_registry_details.rb', line 35 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'description': :'description', 'display_name': :'displayName', 'compartment_id': :'compartmentId' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/oci/data_connectivity/models/create_registry_details.rb', line 48 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'description': :'String', 'display_name': :'String', 'compartment_id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
111 112 113 114 115 116 117 118 119 120 |
# File 'lib/oci/data_connectivity/models/create_registry_details.rb', line 111 def ==(other) return true if equal?(other) self.class == other.class && == other. && == other. && description == other.description && display_name == other.display_name && compartment_id == other.compartment_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/oci/data_connectivity/models/create_registry_details.rb', line 145 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
125 126 127 |
# File 'lib/oci/data_connectivity/models/create_registry_details.rb', line 125 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
134 135 136 |
# File 'lib/oci/data_connectivity/models/create_registry_details.rb', line 134 def hash [, , description, display_name, compartment_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
178 179 180 181 182 183 184 185 186 187 |
# File 'lib/oci/data_connectivity/models/create_registry_details.rb', line 178 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
172 173 174 |
# File 'lib/oci/data_connectivity/models/create_registry_details.rb', line 172 def to_s to_hash.to_s end |