Class: OCI::DataConnectivity::Models::DataEntityFromTableEntityDetails

Inherits:
DataEntityDetails
  • Object
show all
Defined in:
lib/oci/data_connectivity/models/data_entity_from_table_entity_details.rb

Overview

The table entity data entity.

Constant Summary collapse

ENTITY_TYPE_ENUM =
[
  ENTITY_TYPE_TABLE = 'TABLE'.freeze,
  ENTITY_TYPE_VIEW = 'VIEW'.freeze,
  ENTITY_TYPE_FILE = 'FILE'.freeze,
  ENTITY_TYPE_SQL = 'SQL'.freeze,
  ENTITY_TYPE_DATA_STORE = 'DATA_STORE'.freeze
].freeze

Constants inherited from DataEntityDetails

OCI::DataConnectivity::Models::DataEntityDetails::MODEL_TYPE_ENUM

Instance Attribute Summary collapse

Attributes inherited from DataEntityDetails

#model_type

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from DataEntityDetails

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ DataEntityFromTableEntityDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/oci/data_connectivity/models/data_entity_from_table_entity_details.rb', line 153

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['modelType'] = 'TABLE_ENTITY'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.key = attributes[:'key'] if attributes[:'key']

  self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion']

  raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version')

  self.model_version = attributes[:'model_version'] if attributes[:'model_version']

  self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef']

  raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref')

  self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref']

  self.name = attributes[:'name'] if attributes[:'name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.object_version = attributes[:'objectVersion'] if attributes[:'objectVersion']

  raise 'You cannot provide both :objectVersion and :object_version' if attributes.key?(:'objectVersion') && attributes.key?(:'object_version')

  self.object_version = attributes[:'object_version'] if attributes[:'object_version']

  self.external_key = attributes[:'externalKey'] if attributes[:'externalKey']

  raise 'You cannot provide both :externalKey and :external_key' if attributes.key?(:'externalKey') && attributes.key?(:'external_key')

  self.external_key = attributes[:'external_key'] if attributes[:'external_key']

  self.shape = attributes[:'shape'] if attributes[:'shape']

  self.shape_id = attributes[:'shapeId'] if attributes[:'shapeId']

  raise 'You cannot provide both :shapeId and :shape_id' if attributes.key?(:'shapeId') && attributes.key?(:'shape_id')

  self.shape_id = attributes[:'shape_id'] if attributes[:'shape_id']

  self.entity_type = attributes[:'entityType'] if attributes[:'entityType']

  raise 'You cannot provide both :entityType and :entity_type' if attributes.key?(:'entityType') && attributes.key?(:'entity_type')

  self.entity_type = attributes[:'entity_type'] if attributes[:'entity_type']

  self.other_type_label = attributes[:'otherTypeLabel'] if attributes[:'otherTypeLabel']

  raise 'You cannot provide both :otherTypeLabel and :other_type_label' if attributes.key?(:'otherTypeLabel') && attributes.key?(:'other_type_label')

  self.other_type_label = attributes[:'other_type_label'] if attributes[:'other_type_label']

  self.unique_keys = attributes[:'uniqueKeys'] if attributes[:'uniqueKeys']

  raise 'You cannot provide both :uniqueKeys and :unique_keys' if attributes.key?(:'uniqueKeys') && attributes.key?(:'unique_keys')

  self.unique_keys = attributes[:'unique_keys'] if attributes[:'unique_keys']

  self.foreign_keys = attributes[:'foreignKeys'] if attributes[:'foreignKeys']

  raise 'You cannot provide both :foreignKeys and :foreign_keys' if attributes.key?(:'foreignKeys') && attributes.key?(:'foreign_keys')

  self.foreign_keys = attributes[:'foreign_keys'] if attributes[:'foreign_keys']

  self.resource_name = attributes[:'resourceName'] if attributes[:'resourceName']

  raise 'You cannot provide both :resourceName and :resource_name' if attributes.key?(:'resourceName') && attributes.key?(:'resource_name')

  self.resource_name = attributes[:'resource_name'] if attributes[:'resource_name']

  self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus']

  raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status')

  self.object_status = attributes[:'object_status'] if attributes[:'object_status']

  self.identifier = attributes[:'identifier'] if attributes[:'identifier']
end

Instance Attribute Details

#descriptionString

Detailed description for the object.

Returns:

  • (String)


36
37
38
# File 'lib/oci/data_connectivity/models/data_entity_from_table_entity_details.rb', line 36

def description
  @description
end

#entity_typeString

The entity type.

Returns:

  • (String)


55
56
57
# File 'lib/oci/data_connectivity/models/data_entity_from_table_entity_details.rb', line 55

def entity_type
  @entity_type
end

#external_keyString

The external key for the object.

Returns:

  • (String)


44
45
46
# File 'lib/oci/data_connectivity/models/data_entity_from_table_entity_details.rb', line 44

def external_key
  @external_key
end

#foreign_keysArray<OCI::DataConnectivity::Models::ForeignKey>

An array of foreign keys.



67
68
69
# File 'lib/oci/data_connectivity/models/data_entity_from_table_entity_details.rb', line 67

def foreign_keys
  @foreign_keys
end

#identifierString

Value can only contain upper case letters, underscore and numbers. It should begin with upper case letter or underscore. The value can be modified.

Returns:

  • (String)


79
80
81
# File 'lib/oci/data_connectivity/models/data_entity_from_table_entity_details.rb', line 79

def identifier
  @identifier
end

#keyString

The object key.

Returns:

  • (String)


21
22
23
# File 'lib/oci/data_connectivity/models/data_entity_from_table_entity_details.rb', line 21

def key
  @key
end

#model_versionString

The object's model version.

Returns:

  • (String)


25
26
27
# File 'lib/oci/data_connectivity/models/data_entity_from_table_entity_details.rb', line 25

def model_version
  @model_version
end

#nameString

Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.

Returns:

  • (String)


32
33
34
# File 'lib/oci/data_connectivity/models/data_entity_from_table_entity_details.rb', line 32

def name
  @name
end

#object_statusInteger

The status of an object that can be set to value 1 for shallow references across objects, other values reserved.

Returns:

  • (Integer)


75
76
77
# File 'lib/oci/data_connectivity/models/data_entity_from_table_entity_details.rb', line 75

def object_status
  @object_status
end

#object_versionInteger

The version of the object that is used to track changes in the object instance.

Returns:

  • (Integer)


40
41
42
# File 'lib/oci/data_connectivity/models/data_entity_from_table_entity_details.rb', line 40

def object_version
  @object_version
end

#other_type_labelString

Specifies other type label.

Returns:

  • (String)


59
60
61
# File 'lib/oci/data_connectivity/models/data_entity_from_table_entity_details.rb', line 59

def other_type_label
  @other_type_label
end

#parent_refOCI::DataConnectivity::Models::ParentReference



28
29
30
# File 'lib/oci/data_connectivity/models/data_entity_from_table_entity_details.rb', line 28

def parent_ref
  @parent_ref
end

#resource_nameString

The resource name.

Returns:

  • (String)


71
72
73
# File 'lib/oci/data_connectivity/models/data_entity_from_table_entity_details.rb', line 71

def resource_name
  @resource_name
end

#shapeOCI::DataConnectivity::Models::Shape

Returns:

  • (OCI::DataConnectivity::Models::Shape)


47
48
49
# File 'lib/oci/data_connectivity/models/data_entity_from_table_entity_details.rb', line 47

def shape
  @shape
end

#shape_idString

The shape ID.

Returns:

  • (String)


51
52
53
# File 'lib/oci/data_connectivity/models/data_entity_from_table_entity_details.rb', line 51

def shape_id
  @shape_id
end

#unique_keysArray<OCI::DataConnectivity::Models::UniqueKey>

An array of unique keys.



63
64
65
# File 'lib/oci/data_connectivity/models/data_entity_from_table_entity_details.rb', line 63

def unique_keys
  @unique_keys
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/oci/data_connectivity/models/data_entity_from_table_entity_details.rb', line 82

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'modelType',
    'key': :'key',
    'model_version': :'modelVersion',
    'parent_ref': :'parentRef',
    'name': :'name',
    'description': :'description',
    'object_version': :'objectVersion',
    'external_key': :'externalKey',
    'shape': :'shape',
    'shape_id': :'shapeId',
    'entity_type': :'entityType',
    'other_type_label': :'otherTypeLabel',
    'unique_keys': :'uniqueKeys',
    'foreign_keys': :'foreignKeys',
    'resource_name': :'resourceName',
    'object_status': :'objectStatus',
    'identifier': :'identifier'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/oci/data_connectivity/models/data_entity_from_table_entity_details.rb', line 107

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'String',
    'key': :'String',
    'model_version': :'String',
    'parent_ref': :'OCI::DataConnectivity::Models::ParentReference',
    'name': :'String',
    'description': :'String',
    'object_version': :'Integer',
    'external_key': :'String',
    'shape': :'OCI::DataConnectivity::Models::Shape',
    'shape_id': :'String',
    'entity_type': :'String',
    'other_type_label': :'String',
    'unique_keys': :'Array<OCI::DataConnectivity::Models::UniqueKey>',
    'foreign_keys': :'Array<OCI::DataConnectivity::Models::ForeignKey>',
    'resource_name': :'String',
    'object_status': :'Integer',
    'identifier': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/oci/data_connectivity/models/data_entity_from_table_entity_details.rb', line 255

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    model_type == other.model_type &&
    key == other.key &&
    model_version == other.model_version &&
    parent_ref == other.parent_ref &&
    name == other.name &&
    description == other.description &&
    object_version == other.object_version &&
    external_key == other.external_key &&
    shape == other.shape &&
    shape_id == other.shape_id &&
    entity_type == other.entity_type &&
    other_type_label == other.other_type_label &&
    unique_keys == other.unique_keys &&
    foreign_keys == other.foreign_keys &&
    resource_name == other.resource_name &&
    object_status == other.object_status &&
    identifier == other.identifier
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
# File 'lib/oci/data_connectivity/models/data_entity_from_table_entity_details.rb', line 301

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


281
282
283
# File 'lib/oci/data_connectivity/models/data_entity_from_table_entity_details.rb', line 281

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



290
291
292
# File 'lib/oci/data_connectivity/models/data_entity_from_table_entity_details.rb', line 290

def hash
  [model_type, key, model_version, parent_ref, name, description, object_version, external_key, shape, shape_id, entity_type, other_type_label, unique_keys, foreign_keys, resource_name, object_status, identifier].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



334
335
336
337
338
339
340
341
342
343
# File 'lib/oci/data_connectivity/models/data_entity_from_table_entity_details.rb', line 334

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



328
329
330
# File 'lib/oci/data_connectivity/models/data_entity_from_table_entity_details.rb', line 328

def to_s
  to_hash.to_s
end