Class: OCI::DataConnectivity::Models::DataPreview
- Inherits:
-
Object
- Object
- OCI::DataConnectivity::Models::DataPreview
- Defined in:
- lib/oci/data_connectivity/models/data_preview.rb
Overview
The data preview response.
Instance Attribute Summary collapse
-
#columns ⇒ Array<OCI::DataConnectivity::Models::Column>
Array of column definition for the preview result.
-
#entity_name ⇒ String
**[Required]** Name of the entity for which data preview was requested.
-
#rows ⇒ Array<OCI::DataConnectivity::Models::Row>
Array of rows values for the preview result.
-
#sample_rows_count ⇒ Integer
Total number of rows taken for sampling.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DataPreview
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DataPreview
Initializes the object
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/oci/data_connectivity/models/data_preview.rb', line 60 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.entity_name = attributes[:'entityName'] if attributes[:'entityName'] raise 'You cannot provide both :entityName and :entity_name' if attributes.key?(:'entityName') && attributes.key?(:'entity_name') self.entity_name = attributes[:'entity_name'] if attributes[:'entity_name'] self.sample_rows_count = attributes[:'sampleRowsCount'] if attributes[:'sampleRowsCount'] raise 'You cannot provide both :sampleRowsCount and :sample_rows_count' if attributes.key?(:'sampleRowsCount') && attributes.key?(:'sample_rows_count') self.sample_rows_count = attributes[:'sample_rows_count'] if attributes[:'sample_rows_count'] self.columns = attributes[:'columns'] if attributes[:'columns'] self.rows = attributes[:'rows'] if attributes[:'rows'] end |
Instance Attribute Details
#columns ⇒ Array<OCI::DataConnectivity::Models::Column>
Array of column definition for the preview result
20 21 22 |
# File 'lib/oci/data_connectivity/models/data_preview.rb', line 20 def columns @columns end |
#entity_name ⇒ String
**[Required]** Name of the entity for which data preview was requested
12 13 14 |
# File 'lib/oci/data_connectivity/models/data_preview.rb', line 12 def entity_name @entity_name end |
#rows ⇒ Array<OCI::DataConnectivity::Models::Row>
Array of rows values for the preview result
24 25 26 |
# File 'lib/oci/data_connectivity/models/data_preview.rb', line 24 def rows @rows end |
#sample_rows_count ⇒ Integer
Total number of rows taken for sampling
16 17 18 |
# File 'lib/oci/data_connectivity/models/data_preview.rb', line 16 def sample_rows_count @sample_rows_count end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
27 28 29 30 31 32 33 34 35 36 |
# File 'lib/oci/data_connectivity/models/data_preview.rb', line 27 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'entity_name': :'entityName', 'sample_rows_count': :'sampleRowsCount', 'columns': :'columns', 'rows': :'rows' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
39 40 41 42 43 44 45 46 47 48 |
# File 'lib/oci/data_connectivity/models/data_preview.rb', line 39 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'entity_name': :'String', 'sample_rows_count': :'Integer', 'columns': :'Array<OCI::DataConnectivity::Models::Column>', 'rows': :'Array<OCI::DataConnectivity::Models::Row>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
90 91 92 93 94 95 96 97 98 |
# File 'lib/oci/data_connectivity/models/data_preview.rb', line 90 def ==(other) return true if equal?(other) self.class == other.class && entity_name == other.entity_name && sample_rows_count == other.sample_rows_count && columns == other.columns && rows == other.rows end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/oci/data_connectivity/models/data_preview.rb', line 123 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
103 104 105 |
# File 'lib/oci/data_connectivity/models/data_preview.rb', line 103 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
112 113 114 |
# File 'lib/oci/data_connectivity/models/data_preview.rb', line 112 def hash [entity_name, sample_rows_count, columns, rows].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
156 157 158 159 160 161 162 163 164 165 |
# File 'lib/oci/data_connectivity/models/data_preview.rb', line 156 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
150 151 152 |
# File 'lib/oci/data_connectivity/models/data_preview.rb', line 150 def to_s to_hash.to_s end |