Class: OCI::DataConnectivity::Models::DataProfile
- Inherits:
-
Object
- Object
- OCI::DataConnectivity::Models::DataProfile
- Defined in:
- lib/oci/data_connectivity/models/data_profile.rb
Overview
The data profile response.
Instance Attribute Summary collapse
-
#attribute_profile_results ⇒ Array<OCI::DataConnectivity::Models::AttributeProfileResult>
Array of profiling results.
-
#entity_name ⇒ String
**[Required]** Entity name for which prodilig is requested.
- #entity_profile_result ⇒ OCI::DataConnectivity::Models::EntityProfileResult
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DataProfile
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DataProfile
Initializes the object
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/oci/data_connectivity/models/data_profile.rb', line 52 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.entity_name = attributes[:'entityName'] if attributes[:'entityName'] raise 'You cannot provide both :entityName and :entity_name' if attributes.key?(:'entityName') && attributes.key?(:'entity_name') self.entity_name = attributes[:'entity_name'] if attributes[:'entity_name'] self.entity_profile_result = attributes[:'entityProfileResult'] if attributes[:'entityProfileResult'] raise 'You cannot provide both :entityProfileResult and :entity_profile_result' if attributes.key?(:'entityProfileResult') && attributes.key?(:'entity_profile_result') self.entity_profile_result = attributes[:'entity_profile_result'] if attributes[:'entity_profile_result'] self.attribute_profile_results = attributes[:'attributeProfileResults'] if attributes[:'attributeProfileResults'] raise 'You cannot provide both :attributeProfileResults and :attribute_profile_results' if attributes.key?(:'attributeProfileResults') && attributes.key?(:'attribute_profile_results') self.attribute_profile_results = attributes[:'attribute_profile_results'] if attributes[:'attribute_profile_results'] end |
Instance Attribute Details
#attribute_profile_results ⇒ Array<OCI::DataConnectivity::Models::AttributeProfileResult>
Array of profiling results
19 20 21 |
# File 'lib/oci/data_connectivity/models/data_profile.rb', line 19 def attribute_profile_results @attribute_profile_results end |
#entity_name ⇒ String
**[Required]** Entity name for which prodilig is requested.
12 13 14 |
# File 'lib/oci/data_connectivity/models/data_profile.rb', line 12 def entity_name @entity_name end |
#entity_profile_result ⇒ OCI::DataConnectivity::Models::EntityProfileResult
15 16 17 |
# File 'lib/oci/data_connectivity/models/data_profile.rb', line 15 def entity_profile_result @entity_profile_result end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
22 23 24 25 26 27 28 29 30 |
# File 'lib/oci/data_connectivity/models/data_profile.rb', line 22 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'entity_name': :'entityName', 'entity_profile_result': :'entityProfileResult', 'attribute_profile_results': :'attributeProfileResults' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
33 34 35 36 37 38 39 40 41 |
# File 'lib/oci/data_connectivity/models/data_profile.rb', line 33 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'entity_name': :'String', 'entity_profile_result': :'OCI::DataConnectivity::Models::EntityProfileResult', 'attribute_profile_results': :'Array<OCI::DataConnectivity::Models::AttributeProfileResult>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
84 85 86 87 88 89 90 91 |
# File 'lib/oci/data_connectivity/models/data_profile.rb', line 84 def ==(other) return true if equal?(other) self.class == other.class && entity_name == other.entity_name && entity_profile_result == other.entity_profile_result && attribute_profile_results == other.attribute_profile_results end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/oci/data_connectivity/models/data_profile.rb', line 116 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
96 97 98 |
# File 'lib/oci/data_connectivity/models/data_profile.rb', line 96 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
105 106 107 |
# File 'lib/oci/data_connectivity/models/data_profile.rb', line 105 def hash [entity_name, entity_profile_result, attribute_profile_results].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
149 150 151 152 153 154 155 156 157 158 |
# File 'lib/oci/data_connectivity/models/data_profile.rb', line 149 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
143 144 145 |
# File 'lib/oci/data_connectivity/models/data_profile.rb', line 143 def to_s to_hash.to_s end |