Class: OCI::DataConnectivity::Models::DataTypeStat

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_connectivity/models/data_type_stat.rb

Overview

Statistical data in profiling results

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DataTypeStat

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :value (String)

    The value to assign to the #value property

  • :confidence (Integer)

    The value to assign to the #confidence property

  • :freq (Integer)

    The value to assign to the #freq property

  • :freq_percentage (Float)

    The value to assign to the #freq_percentage property



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/oci/data_connectivity/models/data_type_stat.rb', line 60

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  self.value = attributes[:'value'] if attributes[:'value']

  self.confidence = attributes[:'confidence'] if attributes[:'confidence']

  self.freq = attributes[:'freq'] if attributes[:'freq']

  self.freq_percentage = attributes[:'freqPercentage'] if attributes[:'freqPercentage']

  raise 'You cannot provide both :freqPercentage and :freq_percentage' if attributes.key?(:'freqPercentage') && attributes.key?(:'freq_percentage')

  self.freq_percentage = attributes[:'freq_percentage'] if attributes[:'freq_percentage']
end

Instance Attribute Details

#confidenceInteger

Placeholder for now, in future we will return the confidence of the profile result (because we are using sampled data and not whole data)

Returns:

  • (Integer)


16
17
18
# File 'lib/oci/data_connectivity/models/data_type_stat.rb', line 16

def confidence
  @confidence
end

#freqInteger

How many times that value occurred.

Returns:

  • (Integer)


20
21
22
# File 'lib/oci/data_connectivity/models/data_type_stat.rb', line 20

def freq
  @freq
end

#freq_percentageFloat

Frequency percentage across the sampled row counts (excluding nulls).

Returns:

  • (Float)


24
25
26
# File 'lib/oci/data_connectivity/models/data_type_stat.rb', line 24

def freq_percentage
  @freq_percentage
end

#valueString

Value of the confidence of the profile result

Returns:

  • (String)


12
13
14
# File 'lib/oci/data_connectivity/models/data_type_stat.rb', line 12

def value
  @value
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



27
28
29
30
31
32
33
34
35
36
# File 'lib/oci/data_connectivity/models/data_type_stat.rb', line 27

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'value': :'value',
    'confidence': :'confidence',
    'freq': :'freq',
    'freq_percentage': :'freqPercentage'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



39
40
41
42
43
44
45
46
47
48
# File 'lib/oci/data_connectivity/models/data_type_stat.rb', line 39

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'value': :'String',
    'confidence': :'Integer',
    'freq': :'Integer',
    'freq_percentage': :'Float'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



83
84
85
86
87
88
89
90
91
# File 'lib/oci/data_connectivity/models/data_type_stat.rb', line 83

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    value == other.value &&
    confidence == other.confidence &&
    freq == other.freq &&
    freq_percentage == other.freq_percentage
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/oci/data_connectivity/models/data_type_stat.rb', line 116

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


96
97
98
# File 'lib/oci/data_connectivity/models/data_type_stat.rb', line 96

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



105
106
107
# File 'lib/oci/data_connectivity/models/data_type_stat.rb', line 105

def hash
  [value, confidence, freq, freq_percentage].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



149
150
151
152
153
154
155
156
157
158
# File 'lib/oci/data_connectivity/models/data_type_stat.rb', line 149

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



143
144
145
# File 'lib/oci/data_connectivity/models/data_type_stat.rb', line 143

def to_s
  to_hash.to_s
end