Class: OCI::DataConnectivity::Models::DpEndpoint
- Inherits:
-
Object
- Object
- OCI::DataConnectivity::Models::DpEndpoint
- Defined in:
- lib/oci/data_connectivity/models/dp_endpoint.rb
Overview
The endpoint for a data asset. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
Constant Summary collapse
- MODEL_TYPE_ENUM =
[ MODEL_TYPE_PRIVATE_END_POINT = 'PRIVATE_END_POINT'.freeze, MODEL_TYPE_PUBLIC_END_POINT = 'PUBLIC_END_POINT'.freeze, MODEL_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#data_assets ⇒ Array<OCI::DataConnectivity::Models::DataAsset>
List of data assets which belongs to this endpoint.
-
#description ⇒ String
User-defined description for the endpoint.
-
#identifier ⇒ String
Value can only contain upper case letters, underscore, and numbers.
-
#key ⇒ String
Generated key that can be used in API calls to identify endpoint.
-
#model_type ⇒ String
**[Required]** The type of the endpoint.
-
#model_version ⇒ String
The model version of an object.
-
#name ⇒ String
Free form text without any restriction on permitted characters.
-
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
-
#object_version ⇒ Integer
The version of the object that is used to track changes in the object instance.
- #parent_ref ⇒ OCI::DataConnectivity::Models::ParentReference
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DpEndpoint
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DpEndpoint
Initializes the object
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/oci/data_connectivity/models/dp_endpoint.rb', line 125 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.model_type = attributes[:'modelType'] if attributes[:'modelType'] raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type') self.model_type = attributes[:'model_type'] if attributes[:'model_type'] self.key = attributes[:'key'] if attributes[:'key'] self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion'] raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version') self.model_version = attributes[:'model_version'] if attributes[:'model_version'] self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef'] raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref') self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref'] self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.object_version = attributes[:'objectVersion'] if attributes[:'objectVersion'] raise 'You cannot provide both :objectVersion and :object_version' if attributes.key?(:'objectVersion') && attributes.key?(:'object_version') self.object_version = attributes[:'object_version'] if attributes[:'object_version'] self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus'] raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status') self.object_status = attributes[:'object_status'] if attributes[:'object_status'] self.identifier = attributes[:'identifier'] if attributes[:'identifier'] self.data_assets = attributes[:'dataAssets'] if attributes[:'dataAssets'] raise 'You cannot provide both :dataAssets and :data_assets' if attributes.key?(:'dataAssets') && attributes.key?(:'data_assets') self.data_assets = attributes[:'data_assets'] if attributes[:'data_assets'] end |
Instance Attribute Details
#data_assets ⇒ Array<OCI::DataConnectivity::Models::DataAsset>
List of data assets which belongs to this endpoint
55 56 57 |
# File 'lib/oci/data_connectivity/models/dp_endpoint.rb', line 55 def data_assets @data_assets end |
#description ⇒ String
User-defined description for the endpoint.
39 40 41 |
# File 'lib/oci/data_connectivity/models/dp_endpoint.rb', line 39 def description @description end |
#identifier ⇒ String
Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.
51 52 53 |
# File 'lib/oci/data_connectivity/models/dp_endpoint.rb', line 51 def identifier @identifier end |
#key ⇒ String
Generated key that can be used in API calls to identify endpoint. On scenarios where reference to the endpoint is needed, a value can be passed in create.
24 25 26 |
# File 'lib/oci/data_connectivity/models/dp_endpoint.rb', line 24 def key @key end |
#model_type ⇒ String
**[Required]** The type of the endpoint.
20 21 22 |
# File 'lib/oci/data_connectivity/models/dp_endpoint.rb', line 20 def model_type @model_type end |
#model_version ⇒ String
The model version of an object.
28 29 30 |
# File 'lib/oci/data_connectivity/models/dp_endpoint.rb', line 28 def model_version @model_version end |
#name ⇒ String
Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.
35 36 37 |
# File 'lib/oci/data_connectivity/models/dp_endpoint.rb', line 35 def name @name end |
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
47 48 49 |
# File 'lib/oci/data_connectivity/models/dp_endpoint.rb', line 47 def object_status @object_status end |
#object_version ⇒ Integer
The version of the object that is used to track changes in the object instance.
43 44 45 |
# File 'lib/oci/data_connectivity/models/dp_endpoint.rb', line 43 def object_version @object_version end |
#parent_ref ⇒ OCI::DataConnectivity::Models::ParentReference
31 32 33 |
# File 'lib/oci/data_connectivity/models/dp_endpoint.rb', line 31 def parent_ref @parent_ref end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/oci/data_connectivity/models/dp_endpoint.rb', line 58 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'key': :'key', 'model_version': :'modelVersion', 'parent_ref': :'parentRef', 'name': :'name', 'description': :'description', 'object_version': :'objectVersion', 'object_status': :'objectStatus', 'identifier': :'identifier', 'data_assets': :'dataAssets' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
98 99 100 101 102 103 104 105 106 |
# File 'lib/oci/data_connectivity/models/dp_endpoint.rb', line 98 def self.get_subtype(object_hash) type = object_hash[:'modelType'] # rubocop:disable Style/SymbolLiteral return 'OCI::DataConnectivity::Models::DpEndpointFromPrivate' if type == 'PRIVATE_END_POINT' return 'OCI::DataConnectivity::Models::DpEndpointFromPublic' if type == 'PUBLIC_END_POINT' # TODO: Log a warning when the subtype is not found. 'OCI::DataConnectivity::Models::DpEndpoint' end |
.swagger_types ⇒ Object
Attribute type mapping.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/oci/data_connectivity/models/dp_endpoint.rb', line 76 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'key': :'String', 'model_version': :'String', 'parent_ref': :'OCI::DataConnectivity::Models::ParentReference', 'name': :'String', 'description': :'String', 'object_version': :'Integer', 'object_status': :'Integer', 'identifier': :'String', 'data_assets': :'Array<OCI::DataConnectivity::Models::DataAsset>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/oci/data_connectivity/models/dp_endpoint.rb', line 196 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && key == other.key && model_version == other.model_version && parent_ref == other.parent_ref && name == other.name && description == other.description && object_version == other.object_version && object_status == other.object_status && identifier == other.identifier && data_assets == other.data_assets end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/oci/data_connectivity/models/dp_endpoint.rb', line 235 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
215 216 217 |
# File 'lib/oci/data_connectivity/models/dp_endpoint.rb', line 215 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
224 225 226 |
# File 'lib/oci/data_connectivity/models/dp_endpoint.rb', line 224 def hash [model_type, key, model_version, parent_ref, name, description, object_version, object_status, identifier, data_assets].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
268 269 270 271 272 273 274 275 276 277 |
# File 'lib/oci/data_connectivity/models/dp_endpoint.rb', line 268 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
262 263 264 |
# File 'lib/oci/data_connectivity/models/dp_endpoint.rb', line 262 def to_s to_hash.to_s end |