Class: OCI::DataConnectivity::Models::DpEndpointFromPublicDetails
- Inherits:
-
DpEndpointDetails
- Object
- DpEndpointDetails
- OCI::DataConnectivity::Models::DpEndpointFromPublicDetails
- Defined in:
- lib/oci/data_connectivity/models/dp_endpoint_from_public_details.rb
Overview
The endpoint details for a public endpoint.
Constant Summary
Constants inherited from DpEndpointDetails
OCI::DataConnectivity::Models::DpEndpointDetails::MODEL_TYPE_ENUM
Instance Attribute Summary
Attributes inherited from DpEndpointDetails
#data_assets, #description, #identifier, #key, #model_type, #model_version, #name, #object_status, #object_version, #parent_ref
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DpEndpointFromPublicDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from DpEndpointDetails
Constructor Details
#initialize(attributes = {}) ⇒ DpEndpointFromPublicDetails
Initializes the object
62 63 64 65 66 67 68 |
# File 'lib/oci/data_connectivity/models/dp_endpoint_from_public_details.rb', line 62 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['modelType'] = 'PUBLIC_END_POINT' super(attributes) end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 |
# File 'lib/oci/data_connectivity/models/dp_endpoint_from_public_details.rb', line 12 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'key': :'key', 'model_version': :'modelVersion', 'parent_ref': :'parentRef', 'name': :'name', 'description': :'description', 'object_version': :'objectVersion', 'object_status': :'objectStatus', 'identifier': :'identifier', 'data_assets': :'dataAssets' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 |
# File 'lib/oci/data_connectivity/models/dp_endpoint_from_public_details.rb', line 30 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'key': :'String', 'model_version': :'String', 'parent_ref': :'OCI::DataConnectivity::Models::ParentReference', 'name': :'String', 'description': :'String', 'object_version': :'Integer', 'object_status': :'Integer', 'identifier': :'String', 'data_assets': :'Array<OCI::DataConnectivity::Models::DataAsset>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/oci/data_connectivity/models/dp_endpoint_from_public_details.rb', line 77 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && key == other.key && model_version == other.model_version && parent_ref == other.parent_ref && name == other.name && description == other.description && object_version == other.object_version && object_status == other.object_status && identifier == other.identifier && data_assets == other.data_assets end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/oci/data_connectivity/models/dp_endpoint_from_public_details.rb', line 116 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
96 97 98 |
# File 'lib/oci/data_connectivity/models/dp_endpoint_from_public_details.rb', line 96 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
105 106 107 |
# File 'lib/oci/data_connectivity/models/dp_endpoint_from_public_details.rb', line 105 def hash [model_type, key, model_version, parent_ref, name, description, object_version, object_status, identifier, data_assets].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
149 150 151 152 153 154 155 156 157 158 |
# File 'lib/oci/data_connectivity/models/dp_endpoint_from_public_details.rb', line 149 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
143 144 145 |
# File 'lib/oci/data_connectivity/models/dp_endpoint_from_public_details.rb', line 143 def to_s to_hash.to_s end |