Class: OCI::DataConnectivity::Models::EntityProfileResult

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_connectivity/models/entity_profile_result.rb

Overview

A metadata details of a profiling entity result.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ EntityProfileResult

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/oci/data_connectivity/models/entity_profile_result.rb', line 53

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.attribute_count = attributes[:'attributeCount'] if attributes[:'attributeCount']

  raise 'You cannot provide both :attributeCount and :attribute_count' if attributes.key?(:'attributeCount') && attributes.key?(:'attribute_count')

  self.attribute_count = attributes[:'attribute_count'] if attributes[:'attribute_count']

  self.sampled_row_count = attributes[:'sampledRowCount'] if attributes[:'sampledRowCount']

  raise 'You cannot provide both :sampledRowCount and :sampled_row_count' if attributes.key?(:'sampledRowCount') && attributes.key?(:'sampled_row_count')

  self.sampled_row_count = attributes[:'sampled_row_count'] if attributes[:'sampled_row_count']

  self.estimated_row_count = attributes[:'estimatedRowCount'] if attributes[:'estimatedRowCount']

  raise 'You cannot provide both :estimatedRowCount and :estimated_row_count' if attributes.key?(:'estimatedRowCount') && attributes.key?(:'estimated_row_count')

  self.estimated_row_count = attributes[:'estimated_row_count'] if attributes[:'estimated_row_count']
end

Instance Attribute Details

#attribute_countInteger

Number of columns in the DataFrame (arrow buffer) sent from Java layer. This value is not impacted by the List of attributes to profile as being passed via configuration.

Returns:

  • (Integer)


12
13
14
# File 'lib/oci/data_connectivity/models/entity_profile_result.rb', line 12

def attribute_count
  @attribute_count
end

#estimated_row_countInteger

The estimated row count in the source.

Returns:

  • (Integer)


20
21
22
# File 'lib/oci/data_connectivity/models/entity_profile_result.rb', line 20

def estimated_row_count
  @estimated_row_count
end

#sampled_row_countInteger

Number of rows were that were sampled

Returns:

  • (Integer)


16
17
18
# File 'lib/oci/data_connectivity/models/entity_profile_result.rb', line 16

def sampled_row_count
  @sampled_row_count
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



23
24
25
26
27
28
29
30
31
# File 'lib/oci/data_connectivity/models/entity_profile_result.rb', line 23

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'attribute_count': :'attributeCount',
    'sampled_row_count': :'sampledRowCount',
    'estimated_row_count': :'estimatedRowCount'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



34
35
36
37
38
39
40
41
42
# File 'lib/oci/data_connectivity/models/entity_profile_result.rb', line 34

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'attribute_count': :'Integer',
    'sampled_row_count': :'Integer',
    'estimated_row_count': :'Integer'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



85
86
87
88
89
90
91
92
# File 'lib/oci/data_connectivity/models/entity_profile_result.rb', line 85

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    attribute_count == other.attribute_count &&
    sampled_row_count == other.sampled_row_count &&
    estimated_row_count == other.estimated_row_count
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/oci/data_connectivity/models/entity_profile_result.rb', line 117

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


97
98
99
# File 'lib/oci/data_connectivity/models/entity_profile_result.rb', line 97

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



106
107
108
# File 'lib/oci/data_connectivity/models/entity_profile_result.rb', line 106

def hash
  [attribute_count, sampled_row_count, estimated_row_count].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



150
151
152
153
154
155
156
157
158
159
# File 'lib/oci/data_connectivity/models/entity_profile_result.rb', line 150

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



144
145
146
# File 'lib/oci/data_connectivity/models/entity_profile_result.rb', line 144

def to_s
  to_hash.to_s
end