Class: OCI::DataConnectivity::Models::FullPushDownTaskResponse
- Inherits:
-
Object
- Object
- OCI::DataConnectivity::Models::FullPushDownTaskResponse
- Defined in:
- lib/oci/data_connectivity/models/full_push_down_task_response.rb
Overview
The full pushdown task
Instance Attribute Summary collapse
-
#error_message ⇒ String
The error message in response object.
-
#model_type ⇒ String
**[Required]** The type of of FullPushDownTask Response.
-
#status ⇒ String
The status of FullPushDownTask.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ FullPushDownTaskResponse
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ FullPushDownTaskResponse
Initializes the object
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/oci/data_connectivity/models/full_push_down_task_response.rb', line 53 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.model_type = attributes[:'modelType'] if attributes[:'modelType'] raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type') self.model_type = attributes[:'model_type'] if attributes[:'model_type'] self. = attributes[:'errorMessage'] if attributes[:'errorMessage'] raise 'You cannot provide both :errorMessage and :error_message' if attributes.key?(:'errorMessage') && attributes.key?(:'error_message') self. = attributes[:'error_message'] if attributes[:'error_message'] self.status = attributes[:'status'] if attributes[:'status'] end |
Instance Attribute Details
#error_message ⇒ String
The error message in response object.
16 17 18 |
# File 'lib/oci/data_connectivity/models/full_push_down_task_response.rb', line 16 def @error_message end |
#model_type ⇒ String
**[Required]** The type of of FullPushDownTask Response.
12 13 14 |
# File 'lib/oci/data_connectivity/models/full_push_down_task_response.rb', line 12 def model_type @model_type end |
#status ⇒ String
The status of FullPushDownTask.
20 21 22 |
# File 'lib/oci/data_connectivity/models/full_push_down_task_response.rb', line 20 def status @status end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
23 24 25 26 27 28 29 30 31 |
# File 'lib/oci/data_connectivity/models/full_push_down_task_response.rb', line 23 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'error_message': :'errorMessage', 'status': :'status' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
34 35 36 37 38 39 40 41 42 |
# File 'lib/oci/data_connectivity/models/full_push_down_task_response.rb', line 34 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'error_message': :'String', 'status': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
81 82 83 84 85 86 87 88 |
# File 'lib/oci/data_connectivity/models/full_push_down_task_response.rb', line 81 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && == other. && status == other.status end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/oci/data_connectivity/models/full_push_down_task_response.rb', line 113 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
93 94 95 |
# File 'lib/oci/data_connectivity/models/full_push_down_task_response.rb', line 93 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
102 103 104 |
# File 'lib/oci/data_connectivity/models/full_push_down_task_response.rb', line 102 def hash [model_type, , status].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
146 147 148 149 150 151 152 153 154 155 |
# File 'lib/oci/data_connectivity/models/full_push_down_task_response.rb', line 146 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
140 141 142 |
# File 'lib/oci/data_connectivity/models/full_push_down_task_response.rb', line 140 def to_s to_hash.to_s end |