Class: DataConnectivity::Models::Join

Inherits:
OCI::DataConnectivity::Models::PushDownOperation show all
Defined in:
lib/oci/data_connectivity/models/join.rb

Overview

The information about the join operator. The join operator links data from multiple inbound sources.

Constant Summary collapse

POLICY_ENUM =
[
  POLICY_INNER_JOIN = 'INNER_JOIN'.freeze,
  POLICY_LEFT_JOIN = 'LEFT_JOIN'.freeze,
  POLICY_RIGHT_JOIN = 'RIGHT_JOIN'.freeze,
  POLICY_FULL_JOIN = 'FULL_JOIN'.freeze,
  POLICY_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Constants inherited from OCI::DataConnectivity::Models::PushDownOperation

OCI::DataConnectivity::Models::PushDownOperation::MODEL_TYPE_ENUM

Instance Attribute Summary collapse

Attributes inherited from OCI::DataConnectivity::Models::PushDownOperation

#model_type

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from OCI::DataConnectivity::Models::PushDownOperation

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ Join

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :condition (String)

    The value to assign to the #condition property

  • :policy (String)

    The value to assign to the #policy property



58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/oci/data_connectivity/models/join.rb', line 58

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['modelType'] = 'JOIN'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.condition = attributes[:'condition'] if attributes[:'condition']

  self.policy = attributes[:'policy'] if attributes[:'policy']
end

Instance Attribute Details

#conditionString

**[Required]** The join condition.

Returns:

  • (String)


22
23
24
# File 'lib/oci/data_connectivity/models/join.rb', line 22

def condition
  @condition
end

#policyString

**[Required]** The type of join.

Returns:

  • (String)


26
27
28
# File 'lib/oci/data_connectivity/models/join.rb', line 26

def policy
  @policy
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



29
30
31
32
33
34
35
36
37
# File 'lib/oci/data_connectivity/models/join.rb', line 29

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'modelType',
    'condition': :'condition',
    'policy': :'policy'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



40
41
42
43
44
45
46
47
48
# File 'lib/oci/data_connectivity/models/join.rb', line 40

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'String',
    'condition': :'String',
    'policy': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



93
94
95
96
97
98
99
100
# File 'lib/oci/data_connectivity/models/join.rb', line 93

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    model_type == other.model_type &&
    condition == other.condition &&
    policy == other.policy
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/oci/data_connectivity/models/join.rb', line 125

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


105
106
107
# File 'lib/oci/data_connectivity/models/join.rb', line 105

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



114
115
116
# File 'lib/oci/data_connectivity/models/join.rb', line 114

def hash
  [model_type, condition, policy].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



158
159
160
161
162
163
164
165
166
167
# File 'lib/oci/data_connectivity/models/join.rb', line 158

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



152
153
154
# File 'lib/oci/data_connectivity/models/join.rb', line 152

def to_s
  to_hash.to_s
end