Class: OCI::DataConnectivity::Models::NativeShapeField
- Inherits:
-
TypedObject
- Object
- TypedObject
- OCI::DataConnectivity::Models::NativeShapeField
- Defined in:
- lib/oci/data_connectivity/models/native_shape_field.rb
Overview
The native shape field object.
Constant Summary
Constants inherited from TypedObject
Instance Attribute Summary collapse
-
#default_value_string ⇒ String
The default value.
-
#is_mandatory ⇒ BOOLEAN
Specifies whether the field is mandatory.
-
#position ⇒ Integer
The position of the attribute.
-
#type ⇒ Object
**[Required]** The type reference.
Attributes inherited from TypedObject
#config_values, #description, #key, #model_type, #model_version, #name, #object_status, #parent_ref
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NativeShapeField
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from TypedObject
Constructor Details
#initialize(attributes = {}) ⇒ NativeShapeField
Initializes the object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/oci/data_connectivity/models/native_shape_field.rb', line 84 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['modelType'] = 'NATIVE_SHAPE_FIELD' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.type = attributes[:'type'] if attributes[:'type'] self.position = attributes[:'position'] if attributes[:'position'] self.default_value_string = attributes[:'defaultValueString'] if attributes[:'defaultValueString'] raise 'You cannot provide both :defaultValueString and :default_value_string' if attributes.key?(:'defaultValueString') && attributes.key?(:'default_value_string') self.default_value_string = attributes[:'default_value_string'] if attributes[:'default_value_string'] self.is_mandatory = attributes[:'isMandatory'] unless attributes[:'isMandatory'].nil? raise 'You cannot provide both :isMandatory and :is_mandatory' if attributes.key?(:'isMandatory') && attributes.key?(:'is_mandatory') self.is_mandatory = attributes[:'is_mandatory'] unless attributes[:'is_mandatory'].nil? end |
Instance Attribute Details
#default_value_string ⇒ String
The default value.
21 22 23 |
# File 'lib/oci/data_connectivity/models/native_shape_field.rb', line 21 def default_value_string @default_value_string end |
#is_mandatory ⇒ BOOLEAN
Specifies whether the field is mandatory.
25 26 27 |
# File 'lib/oci/data_connectivity/models/native_shape_field.rb', line 25 def is_mandatory @is_mandatory end |
#position ⇒ Integer
The position of the attribute.
17 18 19 |
# File 'lib/oci/data_connectivity/models/native_shape_field.rb', line 17 def position @position end |
#type ⇒ Object
**[Required]** The type reference.
13 14 15 |
# File 'lib/oci/data_connectivity/models/native_shape_field.rb', line 13 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 |
# File 'lib/oci/data_connectivity/models/native_shape_field.rb', line 28 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'key': :'key', 'model_version': :'modelVersion', 'parent_ref': :'parentRef', 'config_values': :'configValues', 'object_status': :'objectStatus', 'name': :'name', 'description': :'description', 'type': :'type', 'position': :'position', 'default_value_string': :'defaultValueString', 'is_mandatory': :'isMandatory' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/oci/data_connectivity/models/native_shape_field.rb', line 48 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'key': :'String', 'model_version': :'String', 'parent_ref': :'OCI::DataConnectivity::Models::ParentReference', 'config_values': :'OCI::DataConnectivity::Models::ConfigValues', 'object_status': :'Integer', 'name': :'String', 'description': :'String', 'type': :'Object', 'position': :'Integer', 'default_value_string': :'String', 'is_mandatory': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/oci/data_connectivity/models/native_shape_field.rb', line 118 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && key == other.key && model_version == other.model_version && parent_ref == other.parent_ref && config_values == other.config_values && object_status == other.object_status && name == other.name && description == other.description && type == other.type && position == other.position && default_value_string == other.default_value_string && is_mandatory == other.is_mandatory end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/oci/data_connectivity/models/native_shape_field.rb', line 159 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
139 140 141 |
# File 'lib/oci/data_connectivity/models/native_shape_field.rb', line 139 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
148 149 150 |
# File 'lib/oci/data_connectivity/models/native_shape_field.rb', line 148 def hash [model_type, key, model_version, parent_ref, config_values, object_status, name, description, type, position, default_value_string, is_mandatory].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
192 193 194 195 196 197 198 199 200 201 |
# File 'lib/oci/data_connectivity/models/native_shape_field.rb', line 192 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
186 187 188 |
# File 'lib/oci/data_connectivity/models/native_shape_field.rb', line 186 def to_s to_hash.to_s end |