Class: OCI::DataConnectivity::Models::OperationFromProcedure

Inherits:
DataConnectivity::Models::Operation
  • Object
show all
Defined in:
lib/oci/data_connectivity/models/operation_from_procedure.rb

Overview

The operation object.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ OperationFromProcedure

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/oci/data_connectivity/models/operation_from_procedure.rb', line 99

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['modelType'] = 'PROCEDURE'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.key = attributes[:'key'] if attributes[:'key']

  self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion']

  raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version')

  self.model_version = attributes[:'model_version'] if attributes[:'model_version']

  self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef']

  raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref')

  self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref']

  self.shape = attributes[:'shape'] if attributes[:'shape']

  self.name = attributes[:'name'] if attributes[:'name']

  self.object_version = attributes[:'objectVersion'] if attributes[:'objectVersion']

  raise 'You cannot provide both :objectVersion and :object_version' if attributes.key?(:'objectVersion') && attributes.key?(:'object_version')

  self.object_version = attributes[:'object_version'] if attributes[:'object_version']

  self.external_key = attributes[:'externalKey'] if attributes[:'externalKey']

  raise 'You cannot provide both :externalKey and :external_key' if attributes.key?(:'externalKey') && attributes.key?(:'external_key')

  self.external_key = attributes[:'external_key'] if attributes[:'external_key']

  self.resource_name = attributes[:'resourceName'] if attributes[:'resourceName']

  raise 'You cannot provide both :resourceName and :resource_name' if attributes.key?(:'resourceName') && attributes.key?(:'resource_name')

  self.resource_name = attributes[:'resource_name'] if attributes[:'resource_name']

  self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus']

  raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status')

  self.object_status = attributes[:'object_status'] if attributes[:'object_status']
end

Instance Attribute Details

#external_keyString

The external key for the object.

Returns:

  • (String)


35
36
37
# File 'lib/oci/data_connectivity/models/operation_from_procedure.rb', line 35

def external_key
  @external_key
end

#keyString

The object key.

Returns:

  • (String)


13
14
15
# File 'lib/oci/data_connectivity/models/operation_from_procedure.rb', line 13

def key
  @key
end

#model_versionString

The model version of the object.

Returns:

  • (String)


17
18
19
# File 'lib/oci/data_connectivity/models/operation_from_procedure.rb', line 17

def model_version
  @model_version
end

#nameString

The operation name.

Returns:

  • (String)


27
28
29
# File 'lib/oci/data_connectivity/models/operation_from_procedure.rb', line 27

def name
  @name
end

#object_statusInteger

The status of an object that can be set to value 1 for shallow reference across objects, other values reserved.

Returns:

  • (Integer)


43
44
45
# File 'lib/oci/data_connectivity/models/operation_from_procedure.rb', line 43

def object_status
  @object_status
end

#object_versionInteger

The version of the object that is used to track changes in the object instance.

Returns:

  • (Integer)


31
32
33
# File 'lib/oci/data_connectivity/models/operation_from_procedure.rb', line 31

def object_version
  @object_version
end

#parent_refOCI::DataConnectivity::Models::ParentReference



20
21
22
# File 'lib/oci/data_connectivity/models/operation_from_procedure.rb', line 20

def parent_ref
  @parent_ref
end

#resource_nameString

The resource name.

Returns:

  • (String)


39
40
41
# File 'lib/oci/data_connectivity/models/operation_from_procedure.rb', line 39

def resource_name
  @resource_name
end

#shapeOCI::DataConnectivity::Models::Shape

Returns:

  • (OCI::DataConnectivity::Models::Shape)


23
24
25
# File 'lib/oci/data_connectivity/models/operation_from_procedure.rb', line 23

def shape
  @shape
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/oci/data_connectivity/models/operation_from_procedure.rb', line 46

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'modelType',
    'metadata': :'metadata',
    'key': :'key',
    'model_version': :'modelVersion',
    'parent_ref': :'parentRef',
    'shape': :'shape',
    'name': :'name',
    'object_version': :'objectVersion',
    'external_key': :'externalKey',
    'resource_name': :'resourceName',
    'object_status': :'objectStatus'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/oci/data_connectivity/models/operation_from_procedure.rb', line 65

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'String',
    'metadata': :'OCI::DataConnectivity::Models::ObjectMetadata',
    'key': :'String',
    'model_version': :'String',
    'parent_ref': :'OCI::DataConnectivity::Models::ParentReference',
    'shape': :'OCI::DataConnectivity::Models::Shape',
    'name': :'String',
    'object_version': :'Integer',
    'external_key': :'String',
    'resource_name': :'String',
    'object_status': :'Integer'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/oci/data_connectivity/models/operation_from_procedure.rb', line 159

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    model_type == other.model_type &&
     == other. &&
    key == other.key &&
    model_version == other.model_version &&
    parent_ref == other.parent_ref &&
    shape == other.shape &&
    name == other.name &&
    object_version == other.object_version &&
    external_key == other.external_key &&
    resource_name == other.resource_name &&
    object_status == other.object_status
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/oci/data_connectivity/models/operation_from_procedure.rb', line 199

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


179
180
181
# File 'lib/oci/data_connectivity/models/operation_from_procedure.rb', line 179

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



188
189
190
# File 'lib/oci/data_connectivity/models/operation_from_procedure.rb', line 188

def hash
  [model_type, , key, model_version, parent_ref, shape, name, object_version, external_key, resource_name, object_status].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



232
233
234
235
236
237
238
239
240
241
# File 'lib/oci/data_connectivity/models/operation_from_procedure.rb', line 232

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



226
227
228
# File 'lib/oci/data_connectivity/models/operation_from_procedure.rb', line 226

def to_s
  to_hash.to_s
end