Class: OCI::DataConnectivity::Models::OperationSummaryFromProcedure
- Inherits:
-
OperationSummary
- Object
- OperationSummary
- OCI::DataConnectivity::Models::OperationSummaryFromProcedure
- Defined in:
- lib/oci/data_connectivity/models/operation_summary_from_procedure.rb
Overview
The operation object.
Constant Summary
Constants inherited from OperationSummary
OCI::DataConnectivity::Models::OperationSummary::MODEL_TYPE_ENUM
Instance Attribute Summary collapse
-
#external_key ⇒ String
The external key for the object.
-
#key ⇒ String
The object key.
-
#model_version ⇒ String
The model version of the object.
-
#name ⇒ String
The operation name.
-
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow reference across objects, other values reserved.
-
#object_version ⇒ Integer
The version of the object that is used to track changes in the object instance.
- #parent_ref ⇒ OCI::DataConnectivity::Models::ParentReference
-
#resource_name ⇒ String
The resource name.
Attributes inherited from OperationSummary
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OperationSummaryFromProcedure
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from OperationSummary
Constructor Details
#initialize(attributes = {}) ⇒ OperationSummaryFromProcedure
Initializes the object
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/oci/data_connectivity/models/operation_summary_from_procedure.rb', line 93 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['modelType'] = 'PROCEDURE' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.key = attributes[:'key'] if attributes[:'key'] self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion'] raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version') self.model_version = attributes[:'model_version'] if attributes[:'model_version'] self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef'] raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref') self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref'] self.name = attributes[:'name'] if attributes[:'name'] self.object_version = attributes[:'objectVersion'] if attributes[:'objectVersion'] raise 'You cannot provide both :objectVersion and :object_version' if attributes.key?(:'objectVersion') && attributes.key?(:'object_version') self.object_version = attributes[:'object_version'] if attributes[:'object_version'] self.external_key = attributes[:'externalKey'] if attributes[:'externalKey'] raise 'You cannot provide both :externalKey and :external_key' if attributes.key?(:'externalKey') && attributes.key?(:'external_key') self.external_key = attributes[:'external_key'] if attributes[:'external_key'] self.resource_name = attributes[:'resourceName'] if attributes[:'resourceName'] raise 'You cannot provide both :resourceName and :resource_name' if attributes.key?(:'resourceName') && attributes.key?(:'resource_name') self.resource_name = attributes[:'resource_name'] if attributes[:'resource_name'] self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus'] raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status') self.object_status = attributes[:'object_status'] if attributes[:'object_status'] end |
Instance Attribute Details
#external_key ⇒ String
The external key for the object.
32 33 34 |
# File 'lib/oci/data_connectivity/models/operation_summary_from_procedure.rb', line 32 def external_key @external_key end |
#key ⇒ String
The object key.
13 14 15 |
# File 'lib/oci/data_connectivity/models/operation_summary_from_procedure.rb', line 13 def key @key end |
#model_version ⇒ String
The model version of the object.
17 18 19 |
# File 'lib/oci/data_connectivity/models/operation_summary_from_procedure.rb', line 17 def model_version @model_version end |
#name ⇒ String
The operation name.
24 25 26 |
# File 'lib/oci/data_connectivity/models/operation_summary_from_procedure.rb', line 24 def name @name end |
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow reference across objects, other values reserved.
40 41 42 |
# File 'lib/oci/data_connectivity/models/operation_summary_from_procedure.rb', line 40 def object_status @object_status end |
#object_version ⇒ Integer
The version of the object that is used to track changes in the object instance.
28 29 30 |
# File 'lib/oci/data_connectivity/models/operation_summary_from_procedure.rb', line 28 def object_version @object_version end |
#parent_ref ⇒ OCI::DataConnectivity::Models::ParentReference
20 21 22 |
# File 'lib/oci/data_connectivity/models/operation_summary_from_procedure.rb', line 20 def parent_ref @parent_ref end |
#resource_name ⇒ String
The resource name.
36 37 38 |
# File 'lib/oci/data_connectivity/models/operation_summary_from_procedure.rb', line 36 def resource_name @resource_name end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/oci/data_connectivity/models/operation_summary_from_procedure.rb', line 43 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'metadata': :'metadata', 'key': :'key', 'model_version': :'modelVersion', 'parent_ref': :'parentRef', 'name': :'name', 'object_version': :'objectVersion', 'external_key': :'externalKey', 'resource_name': :'resourceName', 'object_status': :'objectStatus' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/oci/data_connectivity/models/operation_summary_from_procedure.rb', line 61 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'metadata': :'OCI::DataConnectivity::Models::ObjectMetadata', 'key': :'String', 'model_version': :'String', 'parent_ref': :'OCI::DataConnectivity::Models::ParentReference', 'name': :'String', 'object_version': :'Integer', 'external_key': :'String', 'resource_name': :'String', 'object_status': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/oci/data_connectivity/models/operation_summary_from_procedure.rb', line 151 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && == other. && key == other.key && model_version == other.model_version && parent_ref == other.parent_ref && name == other.name && object_version == other.object_version && external_key == other.external_key && resource_name == other.resource_name && object_status == other.object_status end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/oci/data_connectivity/models/operation_summary_from_procedure.rb', line 190 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
170 171 172 |
# File 'lib/oci/data_connectivity/models/operation_summary_from_procedure.rb', line 170 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
179 180 181 |
# File 'lib/oci/data_connectivity/models/operation_summary_from_procedure.rb', line 179 def hash [model_type, , key, model_version, parent_ref, name, object_version, external_key, resource_name, object_status].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
223 224 225 226 227 228 229 230 231 232 |
# File 'lib/oci/data_connectivity/models/operation_summary_from_procedure.rb', line 223 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
217 218 219 |
# File 'lib/oci/data_connectivity/models/operation_summary_from_procedure.rb', line 217 def to_s to_hash.to_s end |