Class: DataConnectivity::Models::Outlier

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_connectivity/models/outlier.rb

Overview

To capture all the Outlier details related to profiling

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Outlier

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :low (String)

    The value to assign to the #low property

  • :high (String)

    The value to assign to the #high property

  • :low_count (String)

    The value to assign to the #low_count property

  • :high_count (String)

    The value to assign to the #high_count property



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/oci/data_connectivity/models/outlier.rb', line 60

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.low = attributes[:'low'] if attributes[:'low']

  self.high = attributes[:'high'] if attributes[:'high']

  self.low_count = attributes[:'lowCount'] if attributes[:'lowCount']

  raise 'You cannot provide both :lowCount and :low_count' if attributes.key?(:'lowCount') && attributes.key?(:'low_count')

  self.low_count = attributes[:'low_count'] if attributes[:'low_count']

  self.high_count = attributes[:'highCount'] if attributes[:'highCount']

  raise 'You cannot provide both :highCount and :high_count' if attributes.key?(:'highCount') && attributes.key?(:'high_count')

  self.high_count = attributes[:'high_count'] if attributes[:'high_count']
end

Instance Attribute Details

#highString

high value of outlier

Returns:

  • (String)


16
17
18
# File 'lib/oci/data_connectivity/models/outlier.rb', line 16

def high
  @high
end

#high_countString

highCount value of outlier

Returns:

  • (String)


24
25
26
# File 'lib/oci/data_connectivity/models/outlier.rb', line 24

def high_count
  @high_count
end

#lowString

low value of outlier

Returns:

  • (String)


12
13
14
# File 'lib/oci/data_connectivity/models/outlier.rb', line 12

def low
  @low
end

#low_countString

lowCount value of outlier

Returns:

  • (String)


20
21
22
# File 'lib/oci/data_connectivity/models/outlier.rb', line 20

def low_count
  @low_count
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



27
28
29
30
31
32
33
34
35
36
# File 'lib/oci/data_connectivity/models/outlier.rb', line 27

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'low': :'low',
    'high': :'high',
    'low_count': :'lowCount',
    'high_count': :'highCount'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



39
40
41
42
43
44
45
46
47
48
# File 'lib/oci/data_connectivity/models/outlier.rb', line 39

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'low': :'String',
    'high': :'String',
    'low_count': :'String',
    'high_count': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



90
91
92
93
94
95
96
97
98
# File 'lib/oci/data_connectivity/models/outlier.rb', line 90

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    low == other.low &&
    high == other.high &&
    low_count == other.low_count &&
    high_count == other.high_count
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'lib/oci/data_connectivity/models/outlier.rb', line 123

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


103
104
105
# File 'lib/oci/data_connectivity/models/outlier.rb', line 103

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



112
113
114
# File 'lib/oci/data_connectivity/models/outlier.rb', line 112

def hash
  [low, high, low_count, high_count].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



156
157
158
159
160
161
162
163
164
165
# File 'lib/oci/data_connectivity/models/outlier.rb', line 156

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



150
151
152
# File 'lib/oci/data_connectivity/models/outlier.rb', line 150

def to_s
  to_hash.to_s
end