Class: OCI::DataConnectivity::Models::ReferenceArtifactSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_connectivity/models/reference_artifact_summary.rb

Overview

Represents Reference details of a data asset.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ReferenceArtifactSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/oci/data_connectivity/models/reference_artifact_summary.rb', line 121

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.model_type = attributes[:'modelType'] if attributes[:'modelType']

  raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type')

  self.model_type = attributes[:'model_type'] if attributes[:'model_type']

  self.key = attributes[:'key'] if attributes[:'key']

  self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion']

  raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version')

  self.model_version = attributes[:'model_version'] if attributes[:'model_version']

  self.name = attributes[:'name'] if attributes[:'name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus']

  raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status')

  self.object_status = attributes[:'object_status'] if attributes[:'object_status']

  self.object_version = attributes[:'objectVersion'] if attributes[:'objectVersion']

  raise 'You cannot provide both :objectVersion and :object_version' if attributes.key?(:'objectVersion') && attributes.key?(:'object_version')

  self.object_version = attributes[:'object_version'] if attributes[:'object_version']

  self.identifier = attributes[:'identifier'] if attributes[:'identifier']

  self.dcms_artifact_id = attributes[:'dcmsArtifactId'] if attributes[:'dcmsArtifactId']

  raise 'You cannot provide both :dcmsArtifactId and :dcms_artifact_id' if attributes.key?(:'dcmsArtifactId') && attributes.key?(:'dcms_artifact_id')

  self.dcms_artifact_id = attributes[:'dcms_artifact_id'] if attributes[:'dcms_artifact_id']

  self.service_artifact_id = attributes[:'serviceArtifactId'] if attributes[:'serviceArtifactId']

  raise 'You cannot provide both :serviceArtifactId and :service_artifact_id' if attributes.key?(:'serviceArtifactId') && attributes.key?(:'service_artifact_id')

  self.service_artifact_id = attributes[:'service_artifact_id'] if attributes[:'service_artifact_id']

  self.reference_count = attributes[:'referenceCount'] if attributes[:'referenceCount']

  raise 'You cannot provide both :referenceCount and :reference_count' if attributes.key?(:'referenceCount') && attributes.key?(:'reference_count')

  self.reference_count = attributes[:'reference_count'] if attributes[:'reference_count']

  self. = attributes[:'registryMetadata'] if attributes[:'registryMetadata']

  raise 'You cannot provide both :registryMetadata and :registry_metadata' if attributes.key?(:'registryMetadata') && attributes.key?(:'registry_metadata')

  self. = attributes[:'registry_metadata'] if attributes[:'registry_metadata']

  self. = attributes[:'metadata'] if attributes[:'metadata']
end

Instance Attribute Details

#dcms_artifact_idString

unique id of dcms artifact that is getting registered.

Returns:

  • (String)


44
45
46
# File 'lib/oci/data_connectivity/models/reference_artifact_summary.rb', line 44

def dcms_artifact_id
  @dcms_artifact_id
end

#descriptionString

User-defined description of the referenceInfo.

Returns:

  • (String)


28
29
30
# File 'lib/oci/data_connectivity/models/reference_artifact_summary.rb', line 28

def description
  @description
end

#identifierString

Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.

Returns:

  • (String)


40
41
42
# File 'lib/oci/data_connectivity/models/reference_artifact_summary.rb', line 40

def identifier
  @identifier
end

#keyString

Generated key that can be used in API calls to identify referenceinfo.

Returns:

  • (String)


16
17
18
# File 'lib/oci/data_connectivity/models/reference_artifact_summary.rb', line 16

def key
  @key
end

#metadataOCI::DataConnectivity::Models::ObjectMetadata



58
59
60
# File 'lib/oci/data_connectivity/models/reference_artifact_summary.rb', line 58

def 
  @metadata
end

#model_typeString

**[Required]** The type of the ReferenceInfo.

Returns:

  • (String)


12
13
14
# File 'lib/oci/data_connectivity/models/reference_artifact_summary.rb', line 12

def model_type
  @model_type
end

#model_versionString

The model version of an object.

Returns:

  • (String)


20
21
22
# File 'lib/oci/data_connectivity/models/reference_artifact_summary.rb', line 20

def model_version
  @model_version
end

#nameString

Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.

Returns:

  • (String)


24
25
26
# File 'lib/oci/data_connectivity/models/reference_artifact_summary.rb', line 24

def name
  @name
end

#object_statusInteger

The status of an object that can be set to value 1 for shallow references across objects, other values reserved.

Returns:

  • (Integer)


32
33
34
# File 'lib/oci/data_connectivity/models/reference_artifact_summary.rb', line 32

def object_status
  @object_status
end

#object_versionInteger

The version of the object that is used to track changes in the object instance.

Returns:

  • (Integer)


36
37
38
# File 'lib/oci/data_connectivity/models/reference_artifact_summary.rb', line 36

def object_version
  @object_version
end

#reference_countInteger

count of how many times a dcms artifact has been registered by a service.

Returns:

  • (Integer)


52
53
54
# File 'lib/oci/data_connectivity/models/reference_artifact_summary.rb', line 52

def reference_count
  @reference_count
end

#registry_metadataOCI::DataConnectivity::Models::RegistryMetadata



55
56
57
# File 'lib/oci/data_connectivity/models/reference_artifact_summary.rb', line 55

def 
  @registry_metadata
end

#service_artifact_idString

**[Required]** unique id of service which is referencing dcms artifact.

Returns:

  • (String)


48
49
50
# File 'lib/oci/data_connectivity/models/reference_artifact_summary.rb', line 48

def service_artifact_id
  @service_artifact_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/oci/data_connectivity/models/reference_artifact_summary.rb', line 61

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'modelType',
    'key': :'key',
    'model_version': :'modelVersion',
    'name': :'name',
    'description': :'description',
    'object_status': :'objectStatus',
    'object_version': :'objectVersion',
    'identifier': :'identifier',
    'dcms_artifact_id': :'dcmsArtifactId',
    'service_artifact_id': :'serviceArtifactId',
    'reference_count': :'referenceCount',
    'registry_metadata': :'registryMetadata',
    'metadata': :'metadata'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/oci/data_connectivity/models/reference_artifact_summary.rb', line 82

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'String',
    'key': :'String',
    'model_version': :'String',
    'name': :'String',
    'description': :'String',
    'object_status': :'Integer',
    'object_version': :'Integer',
    'identifier': :'String',
    'dcms_artifact_id': :'String',
    'service_artifact_id': :'String',
    'reference_count': :'Integer',
    'registry_metadata': :'OCI::DataConnectivity::Models::RegistryMetadata',
    'metadata': :'OCI::DataConnectivity::Models::ObjectMetadata'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/oci/data_connectivity/models/reference_artifact_summary.rb', line 193

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    model_type == other.model_type &&
    key == other.key &&
    model_version == other.model_version &&
    name == other.name &&
    description == other.description &&
    object_status == other.object_status &&
    object_version == other.object_version &&
    identifier == other.identifier &&
    dcms_artifact_id == other.dcms_artifact_id &&
    service_artifact_id == other.service_artifact_id &&
    reference_count == other.reference_count &&
     == other. &&
     == other.
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/oci/data_connectivity/models/reference_artifact_summary.rb', line 235

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


215
216
217
# File 'lib/oci/data_connectivity/models/reference_artifact_summary.rb', line 215

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



224
225
226
# File 'lib/oci/data_connectivity/models/reference_artifact_summary.rb', line 224

def hash
  [model_type, key, model_version, name, description, object_status, object_version, identifier, dcms_artifact_id, service_artifact_id, reference_count, , ].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



268
269
270
271
272
273
274
275
276
277
# File 'lib/oci/data_connectivity/models/reference_artifact_summary.rb', line 268

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



262
263
264
# File 'lib/oci/data_connectivity/models/reference_artifact_summary.rb', line 262

def to_s
  to_hash.to_s
end