Class: DataConnectivity::Models::Schema

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_connectivity/models/schema.rb

Overview

The schema object.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Schema

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/oci/data_connectivity/models/schema.rb', line 128

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.key = attributes[:'key'] if attributes[:'key']

  self.model_type = attributes[:'modelType'] if attributes[:'modelType']

  raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type')

  self.model_type = attributes[:'model_type'] if attributes[:'model_type']

  self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion']

  raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version')

  self.model_version = attributes[:'model_version'] if attributes[:'model_version']

  self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef']

  raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref')

  self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref']

  self.name = attributes[:'name'] if attributes[:'name']

  self.resource_name = attributes[:'resourceName'] if attributes[:'resourceName']

  raise 'You cannot provide both :resourceName and :resource_name' if attributes.key?(:'resourceName') && attributes.key?(:'resource_name')

  self.resource_name = attributes[:'resource_name'] if attributes[:'resource_name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.object_version = attributes[:'objectVersion'] if attributes[:'objectVersion']

  raise 'You cannot provide both :objectVersion and :object_version' if attributes.key?(:'objectVersion') && attributes.key?(:'object_version')

  self.object_version = attributes[:'object_version'] if attributes[:'object_version']

  self.external_key = attributes[:'externalKey'] if attributes[:'externalKey']

  raise 'You cannot provide both :externalKey and :external_key' if attributes.key?(:'externalKey') && attributes.key?(:'external_key')

  self.external_key = attributes[:'external_key'] if attributes[:'external_key']

  self.is_has_containers = attributes[:'isHasContainers'] unless attributes[:'isHasContainers'].nil?

  raise 'You cannot provide both :isHasContainers and :is_has_containers' if attributes.key?(:'isHasContainers') && attributes.key?(:'is_has_containers')

  self.is_has_containers = attributes[:'is_has_containers'] unless attributes[:'is_has_containers'].nil?

  self.default_connection = attributes[:'defaultConnection'] if attributes[:'defaultConnection']

  raise 'You cannot provide both :defaultConnection and :default_connection' if attributes.key?(:'defaultConnection') && attributes.key?(:'default_connection')

  self.default_connection = attributes[:'default_connection'] if attributes[:'default_connection']

  self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus']

  raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status')

  self.object_status = attributes[:'object_status'] if attributes[:'object_status']

  self.identifier = attributes[:'identifier'] if attributes[:'identifier']

  self. = attributes[:'metadata'] if attributes[:'metadata']
end

Instance Attribute Details

#default_connectionString

The default connection key.

Returns:

  • (String)


51
52
53
# File 'lib/oci/data_connectivity/models/schema.rb', line 51

def default_connection
  @default_connection
end

#descriptionString

User-defined description for the schema.

Returns:

  • (String)


35
36
37
# File 'lib/oci/data_connectivity/models/schema.rb', line 35

def description
  @description
end

#external_keyString

The external key for the object.

Returns:

  • (String)


43
44
45
# File 'lib/oci/data_connectivity/models/schema.rb', line 43

def external_key
  @external_key
end

#identifierString

**[Required]** Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.

Returns:

  • (String)


59
60
61
# File 'lib/oci/data_connectivity/models/schema.rb', line 59

def identifier
  @identifier
end

#is_has_containersBOOLEAN

Specifies whether the schema has containers.

Returns:

  • (BOOLEAN)


47
48
49
# File 'lib/oci/data_connectivity/models/schema.rb', line 47

def is_has_containers
  @is_has_containers
end

#keyString

**[Required]** The object key.

Returns:

  • (String)


12
13
14
# File 'lib/oci/data_connectivity/models/schema.rb', line 12

def key
  @key
end

#metadataOCI::DataConnectivity::Models::ObjectMetadata



62
63
64
# File 'lib/oci/data_connectivity/models/schema.rb', line 62

def 
  @metadata
end

#model_typeString

**[Required]** The object's type.

Returns:

  • (String)


16
17
18
# File 'lib/oci/data_connectivity/models/schema.rb', line 16

def model_type
  @model_type
end

#model_versionString

The object's model version.

Returns:

  • (String)


20
21
22
# File 'lib/oci/data_connectivity/models/schema.rb', line 20

def model_version
  @model_version
end

#nameString

**[Required]** Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.

Returns:

  • (String)


27
28
29
# File 'lib/oci/data_connectivity/models/schema.rb', line 27

def name
  @name
end

#object_statusInteger

The status of an object that can be set to value 1 for shallow references across objects, other values reserved.

Returns:

  • (Integer)


55
56
57
# File 'lib/oci/data_connectivity/models/schema.rb', line 55

def object_status
  @object_status
end

#object_versionInteger

The version of the object that is used to track changes in the object instance.

Returns:

  • (Integer)


39
40
41
# File 'lib/oci/data_connectivity/models/schema.rb', line 39

def object_version
  @object_version
end

#parent_refOCI::DataConnectivity::Models::ParentReference



23
24
25
# File 'lib/oci/data_connectivity/models/schema.rb', line 23

def parent_ref
  @parent_ref
end

#resource_nameString

A resource name can have letters, numbers, and special characters. The value is editable and is restricted to 4000 characters.

Returns:

  • (String)


31
32
33
# File 'lib/oci/data_connectivity/models/schema.rb', line 31

def resource_name
  @resource_name
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/oci/data_connectivity/models/schema.rb', line 65

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'key',
    'model_type': :'modelType',
    'model_version': :'modelVersion',
    'parent_ref': :'parentRef',
    'name': :'name',
    'resource_name': :'resourceName',
    'description': :'description',
    'object_version': :'objectVersion',
    'external_key': :'externalKey',
    'is_has_containers': :'isHasContainers',
    'default_connection': :'defaultConnection',
    'object_status': :'objectStatus',
    'identifier': :'identifier',
    'metadata': :'metadata'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/oci/data_connectivity/models/schema.rb', line 87

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'String',
    'model_type': :'String',
    'model_version': :'String',
    'parent_ref': :'OCI::DataConnectivity::Models::ParentReference',
    'name': :'String',
    'resource_name': :'String',
    'description': :'String',
    'object_version': :'Integer',
    'external_key': :'String',
    'is_has_containers': :'BOOLEAN',
    'default_connection': :'String',
    'object_status': :'Integer',
    'identifier': :'String',
    'metadata': :'OCI::DataConnectivity::Models::ObjectMetadata'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/oci/data_connectivity/models/schema.rb', line 206

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    key == other.key &&
    model_type == other.model_type &&
    model_version == other.model_version &&
    parent_ref == other.parent_ref &&
    name == other.name &&
    resource_name == other.resource_name &&
    description == other.description &&
    object_version == other.object_version &&
    external_key == other.external_key &&
    is_has_containers == other.is_has_containers &&
    default_connection == other.default_connection &&
    object_status == other.object_status &&
    identifier == other.identifier &&
     == other.
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/oci/data_connectivity/models/schema.rb', line 249

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


229
230
231
# File 'lib/oci/data_connectivity/models/schema.rb', line 229

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



238
239
240
# File 'lib/oci/data_connectivity/models/schema.rb', line 238

def hash
  [key, model_type, model_version, parent_ref, name, resource_name, description, object_version, external_key, is_has_containers, default_connection, object_status, identifier, ].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



282
283
284
285
286
287
288
289
290
291
# File 'lib/oci/data_connectivity/models/schema.rb', line 282

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



276
277
278
# File 'lib/oci/data_connectivity/models/schema.rb', line 276

def to_s
  to_hash.to_s
end