Class: OCI::DataConnectivity::Models::StringAttribute

Inherits:
AttributeProfileResult show all
Defined in:
lib/oci/data_connectivity/models/string_attribute.rb

Overview

A summary of profiling results of a specefic attribute.

Instance Attribute Summary collapse

Attributes inherited from AttributeProfileResult

#distinct_count, #duplicate_count, #max, #min, #name, #null_count, #type, #unique_count, #value_frequencies

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from AttributeProfileResult

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ StringAttribute

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/oci/data_connectivity/models/string_attribute.rb', line 91

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['type'] = 'STRING'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.min_length = attributes[:'minLength'] if attributes[:'minLength']

  raise 'You cannot provide both :minLength and :min_length' if attributes.key?(:'minLength') && attributes.key?(:'min_length')

  self.min_length = attributes[:'min_length'] if attributes[:'min_length']

  self.max_length = attributes[:'maxLength'] if attributes[:'maxLength']

  raise 'You cannot provide both :maxLength and :max_length' if attributes.key?(:'maxLength') && attributes.key?(:'max_length')

  self.max_length = attributes[:'max_length'] if attributes[:'max_length']

  self.mean_length = attributes[:'meanLength'] if attributes[:'meanLength']

  raise 'You cannot provide both :meanLength and :mean_length' if attributes.key?(:'meanLength') && attributes.key?(:'mean_length')

  self.mean_length = attributes[:'mean_length'] if attributes[:'mean_length']

  self.pattern_frequencies = attributes[:'patternFrequencies'] if attributes[:'patternFrequencies']

  raise 'You cannot provide both :patternFrequencies and :pattern_frequencies' if attributes.key?(:'patternFrequencies') && attributes.key?(:'pattern_frequencies')

  self.pattern_frequencies = attributes[:'pattern_frequencies'] if attributes[:'pattern_frequencies']

  self.inferred_data_types = attributes[:'inferredDataTypes'] if attributes[:'inferredDataTypes']

  raise 'You cannot provide both :inferredDataTypes and :inferred_data_types' if attributes.key?(:'inferredDataTypes') && attributes.key?(:'inferred_data_types')

  self.inferred_data_types = attributes[:'inferred_data_types'] if attributes[:'inferred_data_types']
end

Instance Attribute Details

#inferred_data_typesArray<OCI::DataConnectivity::Models::DataTypeStat>

Inferred DataType for the column.



26
27
28
# File 'lib/oci/data_connectivity/models/string_attribute.rb', line 26

def inferred_data_types
  @inferred_data_types
end

#max_lengthOCI::DataConnectivity::Models::ProfileStat



15
16
17
# File 'lib/oci/data_connectivity/models/string_attribute.rb', line 15

def max_length
  @max_length
end

#mean_lengthOCI::DataConnectivity::Models::ProfileStat



18
19
20
# File 'lib/oci/data_connectivity/models/string_attribute.rb', line 18

def mean_length
  @mean_length
end

#min_lengthOCI::DataConnectivity::Models::ProfileStat



12
13
14
# File 'lib/oci/data_connectivity/models/string_attribute.rb', line 12

def min_length
  @min_length
end

#pattern_frequenciesArray<OCI::DataConnectivity::Models::ObjectFreqStat>

Pattern frequencies for the column as described already in profile config.



22
23
24
# File 'lib/oci/data_connectivity/models/string_attribute.rb', line 22

def pattern_frequencies
  @pattern_frequencies
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
# File 'lib/oci/data_connectivity/models/string_attribute.rb', line 29

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'type': :'type',
    'name': :'name',
    'min': :'min',
    'max': :'max',
    'null_count': :'nullCount',
    'distinct_count': :'distinctCount',
    'unique_count': :'uniqueCount',
    'duplicate_count': :'duplicateCount',
    'value_frequencies': :'valueFrequencies',
    'min_length': :'minLength',
    'max_length': :'maxLength',
    'mean_length': :'meanLength',
    'pattern_frequencies': :'patternFrequencies',
    'inferred_data_types': :'inferredDataTypes'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/oci/data_connectivity/models/string_attribute.rb', line 51

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'type': :'Object',
    'name': :'String',
    'min': :'OCI::DataConnectivity::Models::ProfileStat',
    'max': :'OCI::DataConnectivity::Models::ProfileStat',
    'null_count': :'OCI::DataConnectivity::Models::ProfileStat',
    'distinct_count': :'OCI::DataConnectivity::Models::ProfileStat',
    'unique_count': :'OCI::DataConnectivity::Models::ProfileStat',
    'duplicate_count': :'OCI::DataConnectivity::Models::ProfileStat',
    'value_frequencies': :'Array<OCI::DataConnectivity::Models::ObjectFreqStat>',
    'min_length': :'OCI::DataConnectivity::Models::ProfileStat',
    'max_length': :'OCI::DataConnectivity::Models::ProfileStat',
    'mean_length': :'OCI::DataConnectivity::Models::ProfileStat',
    'pattern_frequencies': :'Array<OCI::DataConnectivity::Models::ObjectFreqStat>',
    'inferred_data_types': :'Array<OCI::DataConnectivity::Models::DataTypeStat>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/oci/data_connectivity/models/string_attribute.rb', line 139

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    type == other.type &&
    name == other.name &&
    min == other.min &&
    max == other.max &&
    null_count == other.null_count &&
    distinct_count == other.distinct_count &&
    unique_count == other.unique_count &&
    duplicate_count == other.duplicate_count &&
    value_frequencies == other.value_frequencies &&
    min_length == other.min_length &&
    max_length == other.max_length &&
    mean_length == other.mean_length &&
    pattern_frequencies == other.pattern_frequencies &&
    inferred_data_types == other.inferred_data_types
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/oci/data_connectivity/models/string_attribute.rb', line 182

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


162
163
164
# File 'lib/oci/data_connectivity/models/string_attribute.rb', line 162

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



171
172
173
# File 'lib/oci/data_connectivity/models/string_attribute.rb', line 171

def hash
  [type, name, min, max, null_count, distinct_count, unique_count, duplicate_count, value_frequencies, min_length, max_length, mean_length, pattern_frequencies, inferred_data_types].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



215
216
217
218
219
220
221
222
223
224
# File 'lib/oci/data_connectivity/models/string_attribute.rb', line 215

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



209
210
211
# File 'lib/oci/data_connectivity/models/string_attribute.rb', line 209

def to_s
  to_hash.to_s
end