Class: OCI::DataConnectivity::Models::TestNetworkConnectivity
- Inherits:
-
Object
- Object
- OCI::DataConnectivity::Models::TestNetworkConnectivity
- Defined in:
- lib/oci/data_connectivity/models/test_network_connectivity.rb
Overview
The network validation response.
Instance Attribute Summary collapse
-
#exception_message ⇒ String
Exception or error message encountered while testing network reachability for the data asset.
-
#is_reachable ⇒ BOOLEAN
**[Required]** True if the data asset is has a valid network path.
-
#network_validation_output ⇒ String
Last line from network validation command execution output.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TestNetworkConnectivity
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ TestNetworkConnectivity
Initializes the object
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/oci/data_connectivity/models/test_network_connectivity.rb', line 53 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.network_validation_output = attributes[:'networkValidationOutput'] if attributes[:'networkValidationOutput'] raise 'You cannot provide both :networkValidationOutput and :network_validation_output' if attributes.key?(:'networkValidationOutput') && attributes.key?(:'network_validation_output') self.network_validation_output = attributes[:'network_validation_output'] if attributes[:'network_validation_output'] self.is_reachable = attributes[:'isReachable'] unless attributes[:'isReachable'].nil? raise 'You cannot provide both :isReachable and :is_reachable' if attributes.key?(:'isReachable') && attributes.key?(:'is_reachable') self.is_reachable = attributes[:'is_reachable'] unless attributes[:'is_reachable'].nil? self. = attributes[:'exceptionMessage'] if attributes[:'exceptionMessage'] raise 'You cannot provide both :exceptionMessage and :exception_message' if attributes.key?(:'exceptionMessage') && attributes.key?(:'exception_message') self. = attributes[:'exception_message'] if attributes[:'exception_message'] end |
Instance Attribute Details
#exception_message ⇒ String
Exception or error message encountered while testing network reachability for the data asset.
20 21 22 |
# File 'lib/oci/data_connectivity/models/test_network_connectivity.rb', line 20 def @exception_message end |
#is_reachable ⇒ BOOLEAN
**[Required]** True if the data asset is has a valid network path.
16 17 18 |
# File 'lib/oci/data_connectivity/models/test_network_connectivity.rb', line 16 def is_reachable @is_reachable end |
#network_validation_output ⇒ String
Last line from network validation command execution output.
12 13 14 |
# File 'lib/oci/data_connectivity/models/test_network_connectivity.rb', line 12 def network_validation_output @network_validation_output end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
23 24 25 26 27 28 29 30 31 |
# File 'lib/oci/data_connectivity/models/test_network_connectivity.rb', line 23 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'network_validation_output': :'networkValidationOutput', 'is_reachable': :'isReachable', 'exception_message': :'exceptionMessage' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
34 35 36 37 38 39 40 41 42 |
# File 'lib/oci/data_connectivity/models/test_network_connectivity.rb', line 34 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'network_validation_output': :'String', 'is_reachable': :'BOOLEAN', 'exception_message': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
85 86 87 88 89 90 91 92 |
# File 'lib/oci/data_connectivity/models/test_network_connectivity.rb', line 85 def ==(other) return true if equal?(other) self.class == other.class && network_validation_output == other.network_validation_output && is_reachable == other.is_reachable && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/oci/data_connectivity/models/test_network_connectivity.rb', line 117 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
97 98 99 |
# File 'lib/oci/data_connectivity/models/test_network_connectivity.rb', line 97 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
106 107 108 |
# File 'lib/oci/data_connectivity/models/test_network_connectivity.rb', line 106 def hash [network_validation_output, is_reachable, ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
150 151 152 153 154 155 156 157 158 159 |
# File 'lib/oci/data_connectivity/models/test_network_connectivity.rb', line 150 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
144 145 146 |
# File 'lib/oci/data_connectivity/models/test_network_connectivity.rb', line 144 def to_s to_hash.to_s end |