Class: OCI::DataConnectivity::Models::TypedObject

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_connectivity/models/typed_object.rb

Overview

The `TypedObject` class is a base class for any model object that has a type. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class

Constant Summary collapse

MODEL_TYPE_ENUM =
[
  MODEL_TYPE_SHAPE = 'SHAPE'.freeze,
  MODEL_TYPE_SHAPE_FIELD = 'SHAPE_FIELD'.freeze,
  MODEL_TYPE_NATIVE_SHAPE_FIELD = 'NATIVE_SHAPE_FIELD'.freeze,
  MODEL_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ TypedObject

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/oci/data_connectivity/models/typed_object.rb', line 115

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.model_type = attributes[:'modelType'] if attributes[:'modelType']

  raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type')

  self.model_type = attributes[:'model_type'] if attributes[:'model_type']

  self.key = attributes[:'key'] if attributes[:'key']

  self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion']

  raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version')

  self.model_version = attributes[:'model_version'] if attributes[:'model_version']

  self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef']

  raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref')

  self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref']

  self.config_values = attributes[:'configValues'] if attributes[:'configValues']

  raise 'You cannot provide both :configValues and :config_values' if attributes.key?(:'configValues') && attributes.key?(:'config_values')

  self.config_values = attributes[:'config_values'] if attributes[:'config_values']

  self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus']

  raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status')

  self.object_status = attributes[:'object_status'] if attributes[:'object_status']

  self.name = attributes[:'name'] if attributes[:'name']

  self.description = attributes[:'description'] if attributes[:'description']
end

Instance Attribute Details

#config_valuesOCI::DataConnectivity::Models::ConfigValues



35
36
37
# File 'lib/oci/data_connectivity/models/typed_object.rb', line 35

def config_values
  @config_values
end

#descriptionString

Detailed description for the object.

Returns:

  • (String)


47
48
49
# File 'lib/oci/data_connectivity/models/typed_object.rb', line 47

def description
  @description
end

#keyString

The key of the object.

Returns:

  • (String)


25
26
27
# File 'lib/oci/data_connectivity/models/typed_object.rb', line 25

def key
  @key
end

#model_typeString

**[Required]** The type of the types object.

Returns:

  • (String)


21
22
23
# File 'lib/oci/data_connectivity/models/typed_object.rb', line 21

def model_type
  @model_type
end

#model_versionString

The model version of an object.

Returns:

  • (String)


29
30
31
# File 'lib/oci/data_connectivity/models/typed_object.rb', line 29

def model_version
  @model_version
end

#nameString

Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.

Returns:

  • (String)


43
44
45
# File 'lib/oci/data_connectivity/models/typed_object.rb', line 43

def name
  @name
end

#object_statusInteger

The status of an object that can be set to value 1 for shallow references across objects, other values reserved.

Returns:

  • (Integer)


39
40
41
# File 'lib/oci/data_connectivity/models/typed_object.rb', line 39

def object_status
  @object_status
end

#parent_refOCI::DataConnectivity::Models::ParentReference



32
33
34
# File 'lib/oci/data_connectivity/models/typed_object.rb', line 32

def parent_ref
  @parent_ref
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/oci/data_connectivity/models/typed_object.rb', line 50

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'modelType',
    'key': :'key',
    'model_version': :'modelVersion',
    'parent_ref': :'parentRef',
    'config_values': :'configValues',
    'object_status': :'objectStatus',
    'name': :'name',
    'description': :'description'
    # rubocop:enable Style/SymbolLiteral
  }
end

.get_subtype(object_hash) ⇒ Object

Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.



86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/oci/data_connectivity/models/typed_object.rb', line 86

def self.get_subtype(object_hash)
  type = object_hash[:'modelType'] # rubocop:disable Style/SymbolLiteral

  return 'OCI::DataConnectivity::Models::OutputPort' if type == 'OUTPUT_PORT'
  return 'OCI::DataConnectivity::Models::Shape' if type == 'SHAPE'
  return 'OCI::DataConnectivity::Models::ShapeField' if type == 'SHAPE_FIELD'
  return 'OCI::DataConnectivity::Models::InputPort' if type == 'INPUT_PORT'
  return 'OCI::DataConnectivity::Models::Parameter' if type == 'PARAMETER'
  return 'OCI::DataConnectivity::Models::NativeShapeField' if type == 'NATIVE_SHAPE_FIELD'

  # TODO: Log a warning when the subtype is not found.
  'OCI::DataConnectivity::Models::TypedObject'
end

.swagger_typesObject

Attribute type mapping.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/oci/data_connectivity/models/typed_object.rb', line 66

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'String',
    'key': :'String',
    'model_version': :'String',
    'parent_ref': :'OCI::DataConnectivity::Models::ParentReference',
    'config_values': :'OCI::DataConnectivity::Models::ConfigValues',
    'object_status': :'Integer',
    'name': :'String',
    'description': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/oci/data_connectivity/models/typed_object.rb', line 178

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    model_type == other.model_type &&
    key == other.key &&
    model_version == other.model_version &&
    parent_ref == other.parent_ref &&
    config_values == other.config_values &&
    object_status == other.object_status &&
    name == other.name &&
    description == other.description
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/oci/data_connectivity/models/typed_object.rb', line 215

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


195
196
197
# File 'lib/oci/data_connectivity/models/typed_object.rb', line 195

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



204
205
206
# File 'lib/oci/data_connectivity/models/typed_object.rb', line 204

def hash
  [model_type, key, model_version, parent_ref, config_values, object_status, name, description].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



248
249
250
251
252
253
254
255
256
257
# File 'lib/oci/data_connectivity/models/typed_object.rb', line 248

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



242
243
244
# File 'lib/oci/data_connectivity/models/typed_object.rb', line 242

def to_s
  to_hash.to_s
end