Class: OCI::DataConnectivity::Models::UpdateConnectionDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_connectivity/models/update_connection_details.rb

Overview

Properties used in connection update operations.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateConnectionDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/oci/data_connectivity/models/update_connection_details.rb', line 127

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion']

  raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version')

  self.model_version = attributes[:'model_version'] if attributes[:'model_version']

  self.model_type = attributes[:'modelType'] if attributes[:'modelType']

  raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type')

  self.model_type = attributes[:'model_type'] if attributes[:'model_type']

  self.name = attributes[:'name'] if attributes[:'name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.object_version = attributes[:'objectVersion'] if attributes[:'objectVersion']

  raise 'You cannot provide both :objectVersion and :object_version' if attributes.key?(:'objectVersion') && attributes.key?(:'object_version')

  self.object_version = attributes[:'object_version'] if attributes[:'object_version']

  self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus']

  raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status')

  self.object_status = attributes[:'object_status'] if attributes[:'object_status']

  self.identifier = attributes[:'identifier'] if attributes[:'identifier']

  self.primary_schema = attributes[:'primarySchema'] if attributes[:'primarySchema']

  raise 'You cannot provide both :primarySchema and :primary_schema' if attributes.key?(:'primarySchema') && attributes.key?(:'primary_schema')

  self.primary_schema = attributes[:'primary_schema'] if attributes[:'primary_schema']

  self.connection_properties = attributes[:'connectionProperties'] if attributes[:'connectionProperties']

  raise 'You cannot provide both :connectionProperties and :connection_properties' if attributes.key?(:'connectionProperties') && attributes.key?(:'connection_properties')

  self.connection_properties = attributes[:'connection_properties'] if attributes[:'connection_properties']

  self.properties = attributes[:'properties'] if attributes[:'properties']

  self.type = attributes[:'type'] if attributes[:'type']

  self.is_default = attributes[:'isDefault'] unless attributes[:'isDefault'].nil?
  self.is_default = false if is_default.nil? && !attributes.key?(:'isDefault') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isDefault and :is_default' if attributes.key?(:'isDefault') && attributes.key?(:'is_default')

  self.is_default = attributes[:'is_default'] unless attributes[:'is_default'].nil?
  self.is_default = false if is_default.nil? && !attributes.key?(:'isDefault') && !attributes.key?(:'is_default') # rubocop:disable Style/StringLiterals

  self. = attributes[:'metadata'] if attributes[:'metadata']

  self. = attributes[:'registryMetadata'] if attributes[:'registryMetadata']

  raise 'You cannot provide both :registryMetadata and :registry_metadata' if attributes.key?(:'registryMetadata') && attributes.key?(:'registry_metadata')

  self. = attributes[:'registry_metadata'] if attributes[:'registry_metadata']
end

Instance Attribute Details

#connection_propertiesArray<OCI::DataConnectivity::Models::ConnectionProperty>

The properties for the connection.



43
44
45
# File 'lib/oci/data_connectivity/models/update_connection_details.rb', line 43

def connection_properties
  @connection_properties
end

#descriptionString

User-defined description for the connection.

Returns:

  • (String)


24
25
26
# File 'lib/oci/data_connectivity/models/update_connection_details.rb', line 24

def description
  @description
end

#identifierString

Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.

Returns:

  • (String)


36
37
38
# File 'lib/oci/data_connectivity/models/update_connection_details.rb', line 36

def identifier
  @identifier
end

#is_defaultBOOLEAN

The default property for the connection.

Returns:

  • (BOOLEAN)


55
56
57
# File 'lib/oci/data_connectivity/models/update_connection_details.rb', line 55

def is_default
  @is_default
end

#metadataOCI::DataConnectivity::Models::ObjectMetadata



58
59
60
# File 'lib/oci/data_connectivity/models/update_connection_details.rb', line 58

def 
  @metadata
end

#model_typeString

The type of the object.

Returns:

  • (String)


16
17
18
# File 'lib/oci/data_connectivity/models/update_connection_details.rb', line 16

def model_type
  @model_type
end

#model_versionString

The model version of an object.

Returns:

  • (String)


12
13
14
# File 'lib/oci/data_connectivity/models/update_connection_details.rb', line 12

def model_version
  @model_version
end

#nameString

Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.

Returns:

  • (String)


20
21
22
# File 'lib/oci/data_connectivity/models/update_connection_details.rb', line 20

def name
  @name
end

#object_statusInteger

The status of an object that can be set to value 1 for shallow references across objects, other values reserved.

Returns:

  • (Integer)


32
33
34
# File 'lib/oci/data_connectivity/models/update_connection_details.rb', line 32

def object_status
  @object_status
end

#object_versionInteger

The version of the object that is used to track changes in the object instance.

Returns:

  • (Integer)


28
29
30
# File 'lib/oci/data_connectivity/models/update_connection_details.rb', line 28

def object_version
  @object_version
end

#primary_schemaOCI::DataConnectivity::Models::Schema

Returns:

  • (OCI::DataConnectivity::Models::Schema)


39
40
41
# File 'lib/oci/data_connectivity/models/update_connection_details.rb', line 39

def primary_schema
  @primary_schema
end

#propertiesHash<String, Object>

**[Required]** All the properties for the connection in a key-value map format.

Returns:

  • (Hash<String, Object>)


47
48
49
# File 'lib/oci/data_connectivity/models/update_connection_details.rb', line 47

def properties
  @properties
end

#registry_metadataOCI::DataConnectivity::Models::RegistryMetadata



61
62
63
# File 'lib/oci/data_connectivity/models/update_connection_details.rb', line 61

def 
  @registry_metadata
end

#typeString

**[Required]** Specific Connection Type

Returns:

  • (String)


51
52
53
# File 'lib/oci/data_connectivity/models/update_connection_details.rb', line 51

def type
  @type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/oci/data_connectivity/models/update_connection_details.rb', line 64

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'model_version': :'modelVersion',
    'model_type': :'modelType',
    'name': :'name',
    'description': :'description',
    'object_version': :'objectVersion',
    'object_status': :'objectStatus',
    'identifier': :'identifier',
    'primary_schema': :'primarySchema',
    'connection_properties': :'connectionProperties',
    'properties': :'properties',
    'type': :'type',
    'is_default': :'isDefault',
    'metadata': :'metadata',
    'registry_metadata': :'registryMetadata'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/oci/data_connectivity/models/update_connection_details.rb', line 86

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'model_version': :'String',
    'model_type': :'String',
    'name': :'String',
    'description': :'String',
    'object_version': :'Integer',
    'object_status': :'Integer',
    'identifier': :'String',
    'primary_schema': :'OCI::DataConnectivity::Models::Schema',
    'connection_properties': :'Array<OCI::DataConnectivity::Models::ConnectionProperty>',
    'properties': :'Hash<String, Object>',
    'type': :'String',
    'is_default': :'BOOLEAN',
    'metadata': :'OCI::DataConnectivity::Models::ObjectMetadata',
    'registry_metadata': :'OCI::DataConnectivity::Models::RegistryMetadata'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/oci/data_connectivity/models/update_connection_details.rb', line 203

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    model_version == other.model_version &&
    model_type == other.model_type &&
    name == other.name &&
    description == other.description &&
    object_version == other.object_version &&
    object_status == other.object_status &&
    identifier == other.identifier &&
    primary_schema == other.primary_schema &&
    connection_properties == other.connection_properties &&
    properties == other.properties &&
    type == other.type &&
    is_default == other.is_default &&
     == other. &&
     == other.
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'lib/oci/data_connectivity/models/update_connection_details.rb', line 246

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


226
227
228
# File 'lib/oci/data_connectivity/models/update_connection_details.rb', line 226

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



235
236
237
# File 'lib/oci/data_connectivity/models/update_connection_details.rb', line 235

def hash
  [model_version, model_type, name, description, object_version, object_status, identifier, primary_schema, connection_properties, properties, type, is_default, , ].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



279
280
281
282
283
284
285
286
287
288
# File 'lib/oci/data_connectivity/models/update_connection_details.rb', line 279

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



273
274
275
# File 'lib/oci/data_connectivity/models/update_connection_details.rb', line 273

def to_s
  to_hash.to_s
end