Class: OCI::DataConnectivity::Models::UpdateDataAssetDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_connectivity/models/update_data_asset_details.rb

Overview

Properties used in data asset update operations.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateDataAssetDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/oci/data_connectivity/models/update_data_asset_details.rb', line 140

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion']

  raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version')

  self.model_version = attributes[:'model_version'] if attributes[:'model_version']

  self.model_type = attributes[:'modelType'] if attributes[:'modelType']

  raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type')

  self.model_type = attributes[:'model_type'] if attributes[:'model_type']

  self.name = attributes[:'name'] if attributes[:'name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus']

  raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status')

  self.object_status = attributes[:'object_status'] if attributes[:'object_status']

  self.object_version = attributes[:'objectVersion'] if attributes[:'objectVersion']

  raise 'You cannot provide both :objectVersion and :object_version' if attributes.key?(:'objectVersion') && attributes.key?(:'object_version')

  self.object_version = attributes[:'object_version'] if attributes[:'object_version']

  self.identifier = attributes[:'identifier'] if attributes[:'identifier']

  self.external_key = attributes[:'externalKey'] if attributes[:'externalKey']

  raise 'You cannot provide both :externalKey and :external_key' if attributes.key?(:'externalKey') && attributes.key?(:'external_key')

  self.external_key = attributes[:'external_key'] if attributes[:'external_key']

  self.asset_properties = attributes[:'assetProperties'] if attributes[:'assetProperties']

  raise 'You cannot provide both :assetProperties and :asset_properties' if attributes.key?(:'assetProperties') && attributes.key?(:'asset_properties')

  self.asset_properties = attributes[:'asset_properties'] if attributes[:'asset_properties']

  self.properties = attributes[:'properties'] if attributes[:'properties']

  self.type = attributes[:'type'] if attributes[:'type']

  self.native_type_system = attributes[:'nativeTypeSystem'] if attributes[:'nativeTypeSystem']

  raise 'You cannot provide both :nativeTypeSystem and :native_type_system' if attributes.key?(:'nativeTypeSystem') && attributes.key?(:'native_type_system')

  self.native_type_system = attributes[:'native_type_system'] if attributes[:'native_type_system']

  self. = attributes[:'registryMetadata'] if attributes[:'registryMetadata']

  raise 'You cannot provide both :registryMetadata and :registry_metadata' if attributes.key?(:'registryMetadata') && attributes.key?(:'registry_metadata')

  self. = attributes[:'registry_metadata'] if attributes[:'registry_metadata']

  self. = attributes[:'metadata'] if attributes[:'metadata']

  self.default_connection = attributes[:'defaultConnection'] if attributes[:'defaultConnection']

  raise 'You cannot provide both :defaultConnection and :default_connection' if attributes.key?(:'defaultConnection') && attributes.key?(:'default_connection')

  self.default_connection = attributes[:'default_connection'] if attributes[:'default_connection']

  self.end_points = attributes[:'endPoints'] if attributes[:'endPoints']

  raise 'You cannot provide both :endPoints and :end_points' if attributes.key?(:'endPoints') && attributes.key?(:'end_points')

  self.end_points = attributes[:'end_points'] if attributes[:'end_points']
end

Instance Attribute Details

#asset_propertiesHash<String, String>

Additional properties for the data asset.

Returns:

  • (Hash<String, String>)


44
45
46
# File 'lib/oci/data_connectivity/models/update_data_asset_details.rb', line 44

def asset_properties
  @asset_properties
end

#default_connectionOCI::DataConnectivity::Models::Connection



64
65
66
# File 'lib/oci/data_connectivity/models/update_data_asset_details.rb', line 64

def default_connection
  @default_connection
end

#descriptionString

User-defined description of the data asset.

Returns:

  • (String)


24
25
26
# File 'lib/oci/data_connectivity/models/update_data_asset_details.rb', line 24

def description
  @description
end

#end_pointsArray<OCI::DataConnectivity::Models::DpEndpoint>

The list of endpoints with which this data asset is associated.



68
69
70
# File 'lib/oci/data_connectivity/models/update_data_asset_details.rb', line 68

def end_points
  @end_points
end

#external_keyString

The external key for the object.

Returns:

  • (String)


40
41
42
# File 'lib/oci/data_connectivity/models/update_data_asset_details.rb', line 40

def external_key
  @external_key
end

#identifierString

Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.

Returns:

  • (String)


36
37
38
# File 'lib/oci/data_connectivity/models/update_data_asset_details.rb', line 36

def identifier
  @identifier
end

#metadataOCI::DataConnectivity::Models::ObjectMetadata



61
62
63
# File 'lib/oci/data_connectivity/models/update_data_asset_details.rb', line 61

def 
  @metadata
end

#model_typeString

The type of the object.

Returns:

  • (String)


16
17
18
# File 'lib/oci/data_connectivity/models/update_data_asset_details.rb', line 16

def model_type
  @model_type
end

#model_versionString

The model version of an object.

Returns:

  • (String)


12
13
14
# File 'lib/oci/data_connectivity/models/update_data_asset_details.rb', line 12

def model_version
  @model_version
end

#nameString

Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.

Returns:

  • (String)


20
21
22
# File 'lib/oci/data_connectivity/models/update_data_asset_details.rb', line 20

def name
  @name
end

#native_type_systemOCI::DataConnectivity::Models::TypeSystem



55
56
57
# File 'lib/oci/data_connectivity/models/update_data_asset_details.rb', line 55

def native_type_system
  @native_type_system
end

#object_statusInteger

The status of an object that can be set to value 1 for shallow references across objects, other values reserved.

Returns:

  • (Integer)


28
29
30
# File 'lib/oci/data_connectivity/models/update_data_asset_details.rb', line 28

def object_status
  @object_status
end

#object_versionInteger

The version of the object that is used to track changes in the object instance.

Returns:

  • (Integer)


32
33
34
# File 'lib/oci/data_connectivity/models/update_data_asset_details.rb', line 32

def object_version
  @object_version
end

#propertiesHash<String, Object>

**[Required]** All the properties for the data asset in a key-value map format.

Returns:

  • (Hash<String, Object>)


48
49
50
# File 'lib/oci/data_connectivity/models/update_data_asset_details.rb', line 48

def properties
  @properties
end

#registry_metadataOCI::DataConnectivity::Models::RegistryMetadata



58
59
60
# File 'lib/oci/data_connectivity/models/update_data_asset_details.rb', line 58

def 
  @registry_metadata
end

#typeString

**[Required]** Specific DataAsset Type

Returns:

  • (String)


52
53
54
# File 'lib/oci/data_connectivity/models/update_data_asset_details.rb', line 52

def type
  @type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/oci/data_connectivity/models/update_data_asset_details.rb', line 71

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'model_version': :'modelVersion',
    'model_type': :'modelType',
    'name': :'name',
    'description': :'description',
    'object_status': :'objectStatus',
    'object_version': :'objectVersion',
    'identifier': :'identifier',
    'external_key': :'externalKey',
    'asset_properties': :'assetProperties',
    'properties': :'properties',
    'type': :'type',
    'native_type_system': :'nativeTypeSystem',
    'registry_metadata': :'registryMetadata',
    'metadata': :'metadata',
    'default_connection': :'defaultConnection',
    'end_points': :'endPoints'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/oci/data_connectivity/models/update_data_asset_details.rb', line 95

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'model_version': :'String',
    'model_type': :'String',
    'name': :'String',
    'description': :'String',
    'object_status': :'Integer',
    'object_version': :'Integer',
    'identifier': :'String',
    'external_key': :'String',
    'asset_properties': :'Hash<String, String>',
    'properties': :'Hash<String, Object>',
    'type': :'String',
    'native_type_system': :'OCI::DataConnectivity::Models::TypeSystem',
    'registry_metadata': :'OCI::DataConnectivity::Models::RegistryMetadata',
    'metadata': :'OCI::DataConnectivity::Models::ObjectMetadata',
    'default_connection': :'OCI::DataConnectivity::Models::Connection',
    'end_points': :'Array<OCI::DataConnectivity::Models::DpEndpoint>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
# File 'lib/oci/data_connectivity/models/update_data_asset_details.rb', line 226

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    model_version == other.model_version &&
    model_type == other.model_type &&
    name == other.name &&
    description == other.description &&
    object_status == other.object_status &&
    object_version == other.object_version &&
    identifier == other.identifier &&
    external_key == other.external_key &&
    asset_properties == other.asset_properties &&
    properties == other.properties &&
    type == other.type &&
    native_type_system == other.native_type_system &&
     == other. &&
     == other. &&
    default_connection == other.default_connection &&
    end_points == other.end_points
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'lib/oci/data_connectivity/models/update_data_asset_details.rb', line 271

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


251
252
253
# File 'lib/oci/data_connectivity/models/update_data_asset_details.rb', line 251

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



260
261
262
# File 'lib/oci/data_connectivity/models/update_data_asset_details.rb', line 260

def hash
  [model_version, model_type, name, description, object_status, object_version, identifier, external_key, asset_properties, properties, type, native_type_system, , , default_connection, end_points].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



304
305
306
307
308
309
310
311
312
313
# File 'lib/oci/data_connectivity/models/update_data_asset_details.rb', line 304

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



298
299
300
# File 'lib/oci/data_connectivity/models/update_data_asset_details.rb', line 298

def to_s
  to_hash.to_s
end