Class: OCI::DataConnectivity::Models::UpdateDpEndpointDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_connectivity/models/update_dp_endpoint_details.rb

Overview

Properties used in endpoint update operations. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class

Constant Summary collapse

MODEL_TYPE_ENUM =
[
  MODEL_TYPE_PRIVATE_END_POINT = 'PRIVATE_END_POINT'.freeze,
  MODEL_TYPE_PUBLIC_END_POINT = 'PUBLIC_END_POINT'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateDpEndpointDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/oci/data_connectivity/models/update_dp_endpoint_details.rb', line 123

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.model_type = attributes[:'modelType'] if attributes[:'modelType']

  raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type')

  self.model_type = attributes[:'model_type'] if attributes[:'model_type']

  self.key = attributes[:'key'] if attributes[:'key']

  self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion']

  raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version')

  self.model_version = attributes[:'model_version'] if attributes[:'model_version']

  self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef']

  raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref')

  self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref']

  self.name = attributes[:'name'] if attributes[:'name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus']

  raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status')

  self.object_status = attributes[:'object_status'] if attributes[:'object_status']

  self.object_version = attributes[:'objectVersion'] if attributes[:'objectVersion']

  raise 'You cannot provide both :objectVersion and :object_version' if attributes.key?(:'objectVersion') && attributes.key?(:'object_version')

  self.object_version = attributes[:'object_version'] if attributes[:'object_version']

  self.identifier = attributes[:'identifier'] if attributes[:'identifier']

  self.data_assets = attributes[:'dataAssets'] if attributes[:'dataAssets']

  raise 'You cannot provide both :dataAssets and :data_assets' if attributes.key?(:'dataAssets') && attributes.key?(:'data_assets')

  self.data_assets = attributes[:'data_assets'] if attributes[:'data_assets']
end

Instance Attribute Details

#data_assetsArray<OCI::DataConnectivity::Models::DataAsset>

List of data assets which belongs to this endpoint



53
54
55
# File 'lib/oci/data_connectivity/models/update_dp_endpoint_details.rb', line 53

def data_assets
  @data_assets
end

#descriptionString

User-defined description for the endpoint.

Returns:

  • (String)


37
38
39
# File 'lib/oci/data_connectivity/models/update_dp_endpoint_details.rb', line 37

def description
  @description
end

#identifierString

Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.

Returns:

  • (String)


49
50
51
# File 'lib/oci/data_connectivity/models/update_dp_endpoint_details.rb', line 49

def identifier
  @identifier
end

#keyString

**[Required]** Generated key that can be used in API calls to identify endpoint. On scenarios where reference to the endpoint is needed, a value can be passed in create.

Returns:

  • (String)


22
23
24
# File 'lib/oci/data_connectivity/models/update_dp_endpoint_details.rb', line 22

def key
  @key
end

#model_typeString

**[Required]** The type of the endpoint.

Returns:

  • (String)


18
19
20
# File 'lib/oci/data_connectivity/models/update_dp_endpoint_details.rb', line 18

def model_type
  @model_type
end

#model_versionString

The model version of an object.

Returns:

  • (String)


26
27
28
# File 'lib/oci/data_connectivity/models/update_dp_endpoint_details.rb', line 26

def model_version
  @model_version
end

#nameString

Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.

Returns:

  • (String)


33
34
35
# File 'lib/oci/data_connectivity/models/update_dp_endpoint_details.rb', line 33

def name
  @name
end

#object_statusInteger

The status of an object that can be set to value 1 for shallow references across objects, other values reserved.

Returns:

  • (Integer)


41
42
43
# File 'lib/oci/data_connectivity/models/update_dp_endpoint_details.rb', line 41

def object_status
  @object_status
end

#object_versionInteger

**[Required]** The version of the object that is used to track changes in the object instance.

Returns:

  • (Integer)


45
46
47
# File 'lib/oci/data_connectivity/models/update_dp_endpoint_details.rb', line 45

def object_version
  @object_version
end

#parent_refOCI::DataConnectivity::Models::ParentReference



29
30
31
# File 'lib/oci/data_connectivity/models/update_dp_endpoint_details.rb', line 29

def parent_ref
  @parent_ref
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/oci/data_connectivity/models/update_dp_endpoint_details.rb', line 56

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'modelType',
    'key': :'key',
    'model_version': :'modelVersion',
    'parent_ref': :'parentRef',
    'name': :'name',
    'description': :'description',
    'object_status': :'objectStatus',
    'object_version': :'objectVersion',
    'identifier': :'identifier',
    'data_assets': :'dataAssets'
    # rubocop:enable Style/SymbolLiteral
  }
end

.get_subtype(object_hash) ⇒ Object

Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.



96
97
98
99
100
101
102
103
104
# File 'lib/oci/data_connectivity/models/update_dp_endpoint_details.rb', line 96

def self.get_subtype(object_hash)
  type = object_hash[:'modelType'] # rubocop:disable Style/SymbolLiteral

  return 'OCI::DataConnectivity::Models::UpdateDpEndpointFromPublic' if type == 'PUBLIC_END_POINT'
  return 'OCI::DataConnectivity::Models::UpdateDpEndpointFromPrivate' if type == 'PRIVATE_END_POINT'

  # TODO: Log a warning when the subtype is not found.
  'OCI::DataConnectivity::Models::UpdateDpEndpointDetails'
end

.swagger_typesObject

Attribute type mapping.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/oci/data_connectivity/models/update_dp_endpoint_details.rb', line 74

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'String',
    'key': :'String',
    'model_version': :'String',
    'parent_ref': :'OCI::DataConnectivity::Models::ParentReference',
    'name': :'String',
    'description': :'String',
    'object_status': :'Integer',
    'object_version': :'Integer',
    'identifier': :'String',
    'data_assets': :'Array<OCI::DataConnectivity::Models::DataAsset>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/oci/data_connectivity/models/update_dp_endpoint_details.rb', line 189

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    model_type == other.model_type &&
    key == other.key &&
    model_version == other.model_version &&
    parent_ref == other.parent_ref &&
    name == other.name &&
    description == other.description &&
    object_status == other.object_status &&
    object_version == other.object_version &&
    identifier == other.identifier &&
    data_assets == other.data_assets
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
# File 'lib/oci/data_connectivity/models/update_dp_endpoint_details.rb', line 228

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


208
209
210
# File 'lib/oci/data_connectivity/models/update_dp_endpoint_details.rb', line 208

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



217
218
219
# File 'lib/oci/data_connectivity/models/update_dp_endpoint_details.rb', line 217

def hash
  [model_type, key, model_version, parent_ref, name, description, object_status, object_version, identifier, data_assets].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



261
262
263
264
265
266
267
268
269
270
# File 'lib/oci/data_connectivity/models/update_dp_endpoint_details.rb', line 261

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



255
256
257
# File 'lib/oci/data_connectivity/models/update_dp_endpoint_details.rb', line 255

def to_s
  to_hash.to_s
end