Class: OCI::DataConnectivity::Models::UpdateEndpointDetails
- Inherits:
-
Object
- Object
- OCI::DataConnectivity::Models::UpdateEndpointDetails
- Defined in:
- lib/oci/data_connectivity/models/update_endpoint_details.rb
Overview
The information to be updated.
Instance Attribute Summary collapse
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Usage of predefined tag keys.
-
#description ⇒ String
Data Connectivity Management Registry description.
-
#display_name ⇒ String
Data Connectivity Management Registry display name, registries can be renamed.
-
#endpoint_size ⇒ Integer
Update Endpoint size for reverse connection capacity.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#nsg_ids ⇒ Array<String>
List of NSGs to which the Private Endpoint VNIC must be added.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateEndpointDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateEndpointDetails
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/oci/data_connectivity/models/update_endpoint_details.rb', line 78 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.description = attributes[:'description'] if attributes[:'description'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.endpoint_size = attributes[:'endpointSize'] if attributes[:'endpointSize'] raise 'You cannot provide both :endpointSize and :endpoint_size' if attributes.key?(:'endpointSize') && attributes.key?(:'endpoint_size') self.endpoint_size = attributes[:'endpoint_size'] if attributes[:'endpoint_size'] self.nsg_ids = attributes[:'nsgIds'] if attributes[:'nsgIds'] raise 'You cannot provide both :nsgIds and :nsg_ids' if attributes.key?(:'nsgIds') && attributes.key?(:'nsg_ids') self.nsg_ids = attributes[:'nsg_ids'] if attributes[:'nsg_ids'] end |
Instance Attribute Details
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Usage of predefined tag keys. These predefined keys are scoped to namespaces. Example: `{"bar-key": "value"}`
20 21 22 |
# File 'lib/oci/data_connectivity/models/update_endpoint_details.rb', line 20 def @defined_tags end |
#description ⇒ String
Data Connectivity Management Registry description
24 25 26 |
# File 'lib/oci/data_connectivity/models/update_endpoint_details.rb', line 24 def description @description end |
#display_name ⇒ String
Data Connectivity Management Registry display name, registries can be renamed
28 29 30 |
# File 'lib/oci/data_connectivity/models/update_endpoint_details.rb', line 28 def display_name @display_name end |
#endpoint_size ⇒ Integer
Update Endpoint size for reverse connection capacity.
32 33 34 |
# File 'lib/oci/data_connectivity/models/update_endpoint_details.rb', line 32 def endpoint_size @endpoint_size end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
14 15 16 |
# File 'lib/oci/data_connectivity/models/update_endpoint_details.rb', line 14 def @freeform_tags end |
#nsg_ids ⇒ Array<String>
List of NSGs to which the Private Endpoint VNIC must be added.
36 37 38 |
# File 'lib/oci/data_connectivity/models/update_endpoint_details.rb', line 36 def nsg_ids @nsg_ids end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/oci/data_connectivity/models/update_endpoint_details.rb', line 39 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'description': :'description', 'display_name': :'displayName', 'endpoint_size': :'endpointSize', 'nsg_ids': :'nsgIds' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/oci/data_connectivity/models/update_endpoint_details.rb', line 53 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'description': :'String', 'display_name': :'String', 'endpoint_size': :'Integer', 'nsg_ids': :'Array<String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/oci/data_connectivity/models/update_endpoint_details.rb', line 124 def ==(other) return true if equal?(other) self.class == other.class && == other. && == other. && description == other.description && display_name == other.display_name && endpoint_size == other.endpoint_size && nsg_ids == other.nsg_ids end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/oci/data_connectivity/models/update_endpoint_details.rb', line 159 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
139 140 141 |
# File 'lib/oci/data_connectivity/models/update_endpoint_details.rb', line 139 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
148 149 150 |
# File 'lib/oci/data_connectivity/models/update_endpoint_details.rb', line 148 def hash [, , description, display_name, endpoint_size, nsg_ids].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
192 193 194 195 196 197 198 199 200 201 |
# File 'lib/oci/data_connectivity/models/update_endpoint_details.rb', line 192 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
186 187 188 |
# File 'lib/oci/data_connectivity/models/update_endpoint_details.rb', line 186 def to_s to_hash.to_s end |