Class: OCI::DataConnectivity::Models::WriteOperationConfig
- Inherits:
-
AbstractDataOperationConfig
- Object
- AbstractDataOperationConfig
- OCI::DataConnectivity::Models::WriteOperationConfig
- Defined in:
- lib/oci/data_connectivity/models/write_operation_config.rb
Overview
The information about the write operation.
Constant Summary collapse
- WRITE_MODE_ENUM =
[ WRITE_MODE_OVERWRITE = 'OVERWRITE'.freeze, WRITE_MODE_APPEND = 'APPEND'.freeze, WRITE_MODE_MERGE = 'MERGE'.freeze, WRITE_MODE_IGNORE = 'IGNORE'.freeze, WRITE_MODE_CREATE = 'CREATE'.freeze, WRITE_MODE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Constants inherited from AbstractDataOperationConfig
AbstractDataOperationConfig::MODEL_TYPE_ENUM
Instance Attribute Summary collapse
- #data_format ⇒ OCI::DataConnectivity::Models::DataFormat
-
#key ⇒ String
The object key.
- #merge_key ⇒ OCI::DataConnectivity::Models::UniqueKey
-
#model_version ⇒ String
The object's model version.
-
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
-
#operations ⇒ Array<OCI::DataConnectivity::Models::PushDownOperation>
An array of operations.
- #parent_ref ⇒ OCI::DataConnectivity::Models::ParentReference
- #partition_config ⇒ OCI::DataConnectivity::Models::PartitionConfig
-
#reject_limit ⇒ Integer
The number of rows are rejected based on which operation will error out.
- #write_attribute ⇒ OCI::DataConnectivity::Models::AbstractWriteAttribute
-
#write_mode ⇒ String
The mode for the write operation.
Attributes inherited from AbstractDataOperationConfig
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WriteOperationConfig
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from AbstractDataOperationConfig
Constructor Details
#initialize(attributes = {}) ⇒ WriteOperationConfig
Initializes the object
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/oci/data_connectivity/models/write_operation_config.rb', line 117 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['modelType'] = 'WRITE_OPERATION_CONFIG' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.key = attributes[:'key'] if attributes[:'key'] self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion'] raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version') self.model_version = attributes[:'model_version'] if attributes[:'model_version'] self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef'] raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref') self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref'] self.operations = attributes[:'operations'] if attributes[:'operations'] self.data_format = attributes[:'dataFormat'] if attributes[:'dataFormat'] raise 'You cannot provide both :dataFormat and :data_format' if attributes.key?(:'dataFormat') && attributes.key?(:'data_format') self.data_format = attributes[:'data_format'] if attributes[:'data_format'] self.partition_config = attributes[:'partitionConfig'] if attributes[:'partitionConfig'] raise 'You cannot provide both :partitionConfig and :partition_config' if attributes.key?(:'partitionConfig') && attributes.key?(:'partition_config') self.partition_config = attributes[:'partition_config'] if attributes[:'partition_config'] self.write_attribute = attributes[:'writeAttribute'] if attributes[:'writeAttribute'] raise 'You cannot provide both :writeAttribute and :write_attribute' if attributes.key?(:'writeAttribute') && attributes.key?(:'write_attribute') self.write_attribute = attributes[:'write_attribute'] if attributes[:'write_attribute'] self.write_mode = attributes[:'writeMode'] if attributes[:'writeMode'] raise 'You cannot provide both :writeMode and :write_mode' if attributes.key?(:'writeMode') && attributes.key?(:'write_mode') self.write_mode = attributes[:'write_mode'] if attributes[:'write_mode'] self.merge_key = attributes[:'mergeKey'] if attributes[:'mergeKey'] raise 'You cannot provide both :mergeKey and :merge_key' if attributes.key?(:'mergeKey') && attributes.key?(:'merge_key') self.merge_key = attributes[:'merge_key'] if attributes[:'merge_key'] self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus'] raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status') self.object_status = attributes[:'object_status'] if attributes[:'object_status'] self.reject_limit = attributes[:'rejectLimit'] if attributes[:'rejectLimit'] raise 'You cannot provide both :rejectLimit and :reject_limit' if attributes.key?(:'rejectLimit') && attributes.key?(:'reject_limit') self.reject_limit = attributes[:'reject_limit'] if attributes[:'reject_limit'] end |
Instance Attribute Details
#data_format ⇒ OCI::DataConnectivity::Models::DataFormat
37 38 39 |
# File 'lib/oci/data_connectivity/models/write_operation_config.rb', line 37 def data_format @data_format end |
#key ⇒ String
The object key.
23 24 25 |
# File 'lib/oci/data_connectivity/models/write_operation_config.rb', line 23 def key @key end |
#merge_key ⇒ OCI::DataConnectivity::Models::UniqueKey
50 51 52 |
# File 'lib/oci/data_connectivity/models/write_operation_config.rb', line 50 def merge_key @merge_key end |
#model_version ⇒ String
The object's model version.
27 28 29 |
# File 'lib/oci/data_connectivity/models/write_operation_config.rb', line 27 def model_version @model_version end |
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
54 55 56 |
# File 'lib/oci/data_connectivity/models/write_operation_config.rb', line 54 def object_status @object_status end |
#operations ⇒ Array<OCI::DataConnectivity::Models::PushDownOperation>
An array of operations.
34 35 36 |
# File 'lib/oci/data_connectivity/models/write_operation_config.rb', line 34 def operations @operations end |
#parent_ref ⇒ OCI::DataConnectivity::Models::ParentReference
30 31 32 |
# File 'lib/oci/data_connectivity/models/write_operation_config.rb', line 30 def parent_ref @parent_ref end |
#partition_config ⇒ OCI::DataConnectivity::Models::PartitionConfig
40 41 42 |
# File 'lib/oci/data_connectivity/models/write_operation_config.rb', line 40 def partition_config @partition_config end |
#reject_limit ⇒ Integer
The number of rows are rejected based on which operation will error out.
58 59 60 |
# File 'lib/oci/data_connectivity/models/write_operation_config.rb', line 58 def reject_limit @reject_limit end |
#write_attribute ⇒ OCI::DataConnectivity::Models::AbstractWriteAttribute
43 44 45 |
# File 'lib/oci/data_connectivity/models/write_operation_config.rb', line 43 def write_attribute @write_attribute end |
#write_mode ⇒ String
The mode for the write operation.
47 48 49 |
# File 'lib/oci/data_connectivity/models/write_operation_config.rb', line 47 def write_mode @write_mode end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/oci/data_connectivity/models/write_operation_config.rb', line 61 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'key': :'key', 'model_version': :'modelVersion', 'parent_ref': :'parentRef', 'operations': :'operations', 'data_format': :'dataFormat', 'partition_config': :'partitionConfig', 'write_attribute': :'writeAttribute', 'write_mode': :'writeMode', 'merge_key': :'mergeKey', 'object_status': :'objectStatus', 'reject_limit': :'rejectLimit' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/oci/data_connectivity/models/write_operation_config.rb', line 81 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'key': :'String', 'model_version': :'String', 'parent_ref': :'OCI::DataConnectivity::Models::ParentReference', 'operations': :'Array<OCI::DataConnectivity::Models::PushDownOperation>', 'data_format': :'OCI::DataConnectivity::Models::DataFormat', 'partition_config': :'OCI::DataConnectivity::Models::PartitionConfig', 'write_attribute': :'OCI::DataConnectivity::Models::AbstractWriteAttribute', 'write_mode': :'String', 'merge_key': :'OCI::DataConnectivity::Models::UniqueKey', 'object_status': :'Integer', 'reject_limit': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/oci/data_connectivity/models/write_operation_config.rb', line 206 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && key == other.key && model_version == other.model_version && parent_ref == other.parent_ref && operations == other.operations && data_format == other.data_format && partition_config == other.partition_config && write_attribute == other.write_attribute && write_mode == other.write_mode && merge_key == other.merge_key && object_status == other.object_status && reject_limit == other.reject_limit end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/oci/data_connectivity/models/write_operation_config.rb', line 247 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
227 228 229 |
# File 'lib/oci/data_connectivity/models/write_operation_config.rb', line 227 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
236 237 238 |
# File 'lib/oci/data_connectivity/models/write_operation_config.rb', line 236 def hash [model_type, key, model_version, parent_ref, operations, data_format, partition_config, write_attribute, write_mode, merge_key, object_status, reject_limit].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
280 281 282 283 284 285 286 287 288 289 |
# File 'lib/oci/data_connectivity/models/write_operation_config.rb', line 280 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
274 275 276 |
# File 'lib/oci/data_connectivity/models/write_operation_config.rb', line 274 def to_s to_hash.to_s end |