Class: OCI::DataFlow::DataFlowClient
- Inherits:
-
Object
- Object
- OCI::DataFlow::DataFlowClient
- Defined in:
- lib/oci/data_flow/data_flow_client.rb
Overview
Use the Data Flow APIs to run any Apache Spark application at any scale without deploying or managing any infrastructure.
Instance Attribute Summary collapse
-
#api_client ⇒ OCI::ApiClient
readonly
Client used to make HTTP requests.
-
#endpoint ⇒ String
readonly
Fully qualified endpoint URL.
-
#region ⇒ String
The region, which will usually correspond to a value in Regions::REGION_ENUM.
-
#retry_config ⇒ OCI::Retry::RetryConfig
readonly
The default retry configuration to apply to all operations in this service client.
Instance Method Summary collapse
-
#change_application_compartment(application_id, change_application_compartment_details, opts = {}) ⇒ Response
Moves an application into a different compartment.
-
#change_private_endpoint_compartment(private_endpoint_id, change_private_endpoint_compartment_details, opts = {}) ⇒ Response
Moves a private endpoint into a different compartment.
-
#change_run_compartment(run_id, change_run_compartment_details, opts = {}) ⇒ Response
Moves a run into a different compartment.
-
#create_application(create_application_details, opts = {}) ⇒ Response
Creates an application.
-
#create_private_endpoint(create_private_endpoint_details, opts = {}) ⇒ Response
Creates a private endpoint to be used by applications.
-
#create_run(create_run_details, opts = {}) ⇒ Response
Creates a run for an application.
-
#delete_application(application_id, opts = {}) ⇒ Response
Deletes an application using an
applicationId. -
#delete_private_endpoint(private_endpoint_id, opts = {}) ⇒ Response
Deletes a private endpoint using a
privateEndpointId. -
#delete_run(run_id, opts = {}) ⇒ Response
Cancels the specified run if it has not already completed or was previously cancelled.
-
#get_application(application_id, opts = {}) ⇒ Response
Retrieves an application using an
applicationId. -
#get_private_endpoint(private_endpoint_id, opts = {}) ⇒ Response
Retrieves an private endpoint using a
privateEndpointId. -
#get_run(run_id, opts = {}) ⇒ Response
Retrieves the run for the specified
runId. -
#get_run_log(run_id, name, opts = {}, &block) ⇒ Response
Retrieves the content of an run log.
-
#get_work_request(work_request_id, opts = {}) ⇒ Response
Gets the status of the work request with the given OCID.
-
#initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) ⇒ DataFlowClient
constructor
Creates a new DataFlowClient.
-
#list_applications(compartment_id, opts = {}) ⇒ Response
Lists all applications in the specified compartment.
-
#list_private_endpoints(compartment_id, opts = {}) ⇒ Response
Lists all private endpoints in the specified compartment.
-
#list_run_logs(run_id, opts = {}) ⇒ Response
Retrieves summaries of the run’s logs.
-
#list_runs(compartment_id, opts = {}) ⇒ Response
Lists all runs of an application in the specified compartment.
-
#list_work_request_errors(work_request_id, opts = {}) ⇒ Response
Return a (paginated) list of errors for a given work request.
-
#list_work_request_logs(work_request_id, opts = {}) ⇒ Response
Return a paginated list of logs for a given work request.
-
#list_work_requests(compartment_id, opts = {}) ⇒ Response
Lists the work requests in a compartment.
-
#logger ⇒ Logger
The logger for this client.
-
#update_application(update_application_details, application_id, opts = {}) ⇒ Response
Updates an application using an
applicationId. -
#update_private_endpoint(update_private_endpoint_details, private_endpoint_id, opts = {}) ⇒ Response
Updates a private endpoint using a
privateEndpointId. -
#update_run(update_run_details, run_id, opts = {}) ⇒ Response
Updates a run using a
runId.
Constructor Details
#initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) ⇒ DataFlowClient
Creates a new DataFlowClient. Notes:
If a config is not specified, then the global OCI.config will be used.
This client is not thread-safe
Either a region or an endpoint must be specified. If an endpoint is specified, it will be used instead of the
region. A region may be specified in the config or via or the region parameter. If specified in both, then the
region parameter will be used.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/oci/data_flow/data_flow_client.rb', line 53 def initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) # If the signer is an InstancePrincipalsSecurityTokenSigner or SecurityTokenSigner and no config was supplied (they are self-sufficient signers) # then create a dummy config to pass to the ApiClient constructor. If customers wish to create a client which uses instance principals # and has config (either populated programmatically or loaded from a file), they must construct that config themselves and then # pass it to this constructor. # # If there is no signer (or the signer is not an instance principals signer) and no config was supplied, this is not valid # so try and load the config from the default file. config = OCI::Config.validate_and_build_config_with_signer(config, signer) signer = OCI::Signer.config_file_auth_builder(config) if signer.nil? @api_client = OCI::ApiClient.new(config, signer, proxy_settings: proxy_settings) @retry_config = retry_config if endpoint @endpoint = endpoint + '/20200129' else region ||= config.region region ||= signer.region if signer.respond_to?(:region) self.region = region end logger.info "DataFlowClient endpoint set to '#{@endpoint}'." if logger end |
Instance Attribute Details
#api_client ⇒ OCI::ApiClient (readonly)
Client used to make HTTP requests.
13 14 15 |
# File 'lib/oci/data_flow/data_flow_client.rb', line 13 def api_client @api_client end |
#endpoint ⇒ String (readonly)
Fully qualified endpoint URL
17 18 19 |
# File 'lib/oci/data_flow/data_flow_client.rb', line 17 def endpoint @endpoint end |
#region ⇒ String
The region, which will usually correspond to a value in Regions::REGION_ENUM.
27 28 29 |
# File 'lib/oci/data_flow/data_flow_client.rb', line 27 def region @region end |
#retry_config ⇒ OCI::Retry::RetryConfig (readonly)
The default retry configuration to apply to all operations in this service client. This can be overridden on a per-operation basis. The default retry configuration value is nil, which means that an operation will not perform any retries
23 24 25 |
# File 'lib/oci/data_flow/data_flow_client.rb', line 23 def retry_config @retry_config end |
Instance Method Details
#change_application_compartment(application_id, change_application_compartment_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/dataflow/change_application_compartment.rb.html) to see an example of how to use change_application_compartment API.
Moves an application into a different compartment. When provided, If-Match is checked against ETag values of the resource. Associated resources, like runs, will not be automatically moved.
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/oci/data_flow/data_flow_client.rb', line 125 def change_application_compartment(application_id, change_application_compartment_details, opts = {}) logger.debug 'Calling operation DataFlowClient#change_application_compartment.' if logger raise "Missing the required parameter 'application_id' when calling change_application_compartment." if application_id.nil? raise "Missing the required parameter 'change_application_compartment_details' when calling change_application_compartment." if change_application_compartment_details.nil? raise "Parameter value for 'application_id' must not be blank" if OCI::Internal::Util.blank_string?(application_id) path = '/applications/{applicationId}/actions/changeCompartment'.sub('{applicationId}', application_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = @api_client.object_to_http_body(change_application_compartment_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DataFlowClient#change_application_compartment') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#change_private_endpoint_compartment(private_endpoint_id, change_private_endpoint_compartment_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/dataflow/change_private_endpoint_compartment.rb.html) to see an example of how to use change_private_endpoint_compartment API.
Moves a private endpoint into a different compartment. When provided, If-Match is checked against ETag values of the resource.
192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/oci/data_flow/data_flow_client.rb', line 192 def change_private_endpoint_compartment(private_endpoint_id, change_private_endpoint_compartment_details, opts = {}) logger.debug 'Calling operation DataFlowClient#change_private_endpoint_compartment.' if logger raise "Missing the required parameter 'private_endpoint_id' when calling change_private_endpoint_compartment." if private_endpoint_id.nil? raise "Missing the required parameter 'change_private_endpoint_compartment_details' when calling change_private_endpoint_compartment." if change_private_endpoint_compartment_details.nil? raise "Parameter value for 'private_endpoint_id' must not be blank" if OCI::Internal::Util.blank_string?(private_endpoint_id) path = '/privateEndpoints/{privateEndpointId}/actions/changeCompartment'.sub('{privateEndpointId}', private_endpoint_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'if-match'] = opts[:if_match] if opts[:if_match] # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(change_private_endpoint_compartment_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DataFlowClient#change_private_endpoint_compartment') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#change_run_compartment(run_id, change_run_compartment_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/dataflow/change_run_compartment.rb.html) to see an example of how to use change_run_compartment API.
Moves a run into a different compartment. When provided, If-Match is checked against ETag values of the resource. Associated resources, like historical metrics, will not be automatically moved. The run must be in a terminal state (CANCELED, FAILED, SUCCEEDED) in order for it to be moved to a different compartment
265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 |
# File 'lib/oci/data_flow/data_flow_client.rb', line 265 def change_run_compartment(run_id, change_run_compartment_details, opts = {}) logger.debug 'Calling operation DataFlowClient#change_run_compartment.' if logger raise "Missing the required parameter 'run_id' when calling change_run_compartment." if run_id.nil? raise "Missing the required parameter 'change_run_compartment_details' when calling change_run_compartment." if change_run_compartment_details.nil? raise "Parameter value for 'run_id' must not be blank" if OCI::Internal::Util.blank_string?(run_id) path = '/runs/{runId}/actions/changeCompartment'.sub('{runId}', run_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = @api_client.object_to_http_body(change_run_compartment_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DataFlowClient#change_run_compartment') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#create_application(create_application_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/dataflow/create_application.rb.html) to see an example of how to use create_application API.
Creates an application.
331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 |
# File 'lib/oci/data_flow/data_flow_client.rb', line 331 def create_application(create_application_details, opts = {}) logger.debug 'Calling operation DataFlowClient#create_application.' if logger raise "Missing the required parameter 'create_application_details' when calling create_application." if create_application_details.nil? path = '/applications' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = @api_client.object_to_http_body(create_application_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DataFlowClient#create_application') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::DataFlow::Models::Application' ) end # rubocop:enable Metrics/BlockLength end |
#create_private_endpoint(create_private_endpoint_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/dataflow/create_private_endpoint.rb.html) to see an example of how to use create_private_endpoint API.
Creates a private endpoint to be used by applications.
395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 |
# File 'lib/oci/data_flow/data_flow_client.rb', line 395 def create_private_endpoint(create_private_endpoint_details, opts = {}) logger.debug 'Calling operation DataFlowClient#create_private_endpoint.' if logger raise "Missing the required parameter 'create_private_endpoint_details' when calling create_private_endpoint." if create_private_endpoint_details.nil? path = '/privateEndpoints' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = @api_client.object_to_http_body(create_private_endpoint_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DataFlowClient#create_private_endpoint') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::DataFlow::Models::PrivateEndpoint' ) end # rubocop:enable Metrics/BlockLength end |
#create_run(create_run_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/dataflow/create_run.rb.html) to see an example of how to use create_run API.
Creates a run for an application.
459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 |
# File 'lib/oci/data_flow/data_flow_client.rb', line 459 def create_run(create_run_details, opts = {}) logger.debug 'Calling operation DataFlowClient#create_run.' if logger raise "Missing the required parameter 'create_run_details' when calling create_run." if create_run_details.nil? path = '/runs' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = @api_client.object_to_http_body(create_run_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DataFlowClient#create_run') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::DataFlow::Models::Run' ) end # rubocop:enable Metrics/BlockLength end |
#delete_application(application_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/dataflow/delete_application.rb.html) to see an example of how to use delete_application API.
Deletes an application using an applicationId.
522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 |
# File 'lib/oci/data_flow/data_flow_client.rb', line 522 def delete_application(application_id, opts = {}) logger.debug 'Calling operation DataFlowClient#delete_application.' if logger raise "Missing the required parameter 'application_id' when calling delete_application." if application_id.nil? raise "Parameter value for 'application_id' must not be blank" if OCI::Internal::Util.blank_string?(application_id) path = '/applications/{applicationId}'.sub('{applicationId}', application_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'if-match'] = opts[:if_match] if opts[:if_match] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DataFlowClient#delete_application') do @api_client.call_api( :DELETE, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#delete_private_endpoint(private_endpoint_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/dataflow/delete_private_endpoint.rb.html) to see an example of how to use delete_private_endpoint API.
Deletes a private endpoint using a privateEndpointId.
584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 |
# File 'lib/oci/data_flow/data_flow_client.rb', line 584 def delete_private_endpoint(private_endpoint_id, opts = {}) logger.debug 'Calling operation DataFlowClient#delete_private_endpoint.' if logger raise "Missing the required parameter 'private_endpoint_id' when calling delete_private_endpoint." if private_endpoint_id.nil? raise "Parameter value for 'private_endpoint_id' must not be blank" if OCI::Internal::Util.blank_string?(private_endpoint_id) path = '/privateEndpoints/{privateEndpointId}'.sub('{privateEndpointId}', private_endpoint_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'if-match'] = opts[:if_match] if opts[:if_match] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DataFlowClient#delete_private_endpoint') do @api_client.call_api( :DELETE, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#delete_run(run_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/dataflow/delete_run.rb.html) to see an example of how to use delete_run API.
Cancels the specified run if it has not already completed or was previously cancelled. If a run is in progress, the executing job will be killed.
647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 |
# File 'lib/oci/data_flow/data_flow_client.rb', line 647 def delete_run(run_id, opts = {}) logger.debug 'Calling operation DataFlowClient#delete_run.' if logger raise "Missing the required parameter 'run_id' when calling delete_run." if run_id.nil? raise "Parameter value for 'run_id' must not be blank" if OCI::Internal::Util.blank_string?(run_id) path = '/runs/{runId}'.sub('{runId}', run_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'if-match'] = opts[:if_match] if opts[:if_match] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DataFlowClient#delete_run') do @api_client.call_api( :DELETE, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#get_application(application_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/dataflow/get_application.rb.html) to see an example of how to use get_application API.
Retrieves an application using an applicationId.
705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 |
# File 'lib/oci/data_flow/data_flow_client.rb', line 705 def get_application(application_id, opts = {}) logger.debug 'Calling operation DataFlowClient#get_application.' if logger raise "Missing the required parameter 'application_id' when calling get_application." if application_id.nil? raise "Parameter value for 'application_id' must not be blank" if OCI::Internal::Util.blank_string?(application_id) path = '/applications/{applicationId}'.sub('{applicationId}', application_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DataFlowClient#get_application') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::DataFlow::Models::Application' ) end # rubocop:enable Metrics/BlockLength end |
#get_private_endpoint(private_endpoint_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/dataflow/get_private_endpoint.rb.html) to see an example of how to use get_private_endpoint API.
Retrieves an private endpoint using a privateEndpointId.
763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 |
# File 'lib/oci/data_flow/data_flow_client.rb', line 763 def get_private_endpoint(private_endpoint_id, opts = {}) logger.debug 'Calling operation DataFlowClient#get_private_endpoint.' if logger raise "Missing the required parameter 'private_endpoint_id' when calling get_private_endpoint." if private_endpoint_id.nil? raise "Parameter value for 'private_endpoint_id' must not be blank" if OCI::Internal::Util.blank_string?(private_endpoint_id) path = '/privateEndpoints/{privateEndpointId}'.sub('{privateEndpointId}', private_endpoint_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DataFlowClient#get_private_endpoint') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::DataFlow::Models::PrivateEndpoint' ) end # rubocop:enable Metrics/BlockLength end |
#get_run(run_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/dataflow/get_run.rb.html) to see an example of how to use get_run API.
Retrieves the run for the specified runId.
821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 |
# File 'lib/oci/data_flow/data_flow_client.rb', line 821 def get_run(run_id, opts = {}) logger.debug 'Calling operation DataFlowClient#get_run.' if logger raise "Missing the required parameter 'run_id' when calling get_run." if run_id.nil? raise "Parameter value for 'run_id' must not be blank" if OCI::Internal::Util.blank_string?(run_id) path = '/runs/{runId}'.sub('{runId}', run_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DataFlowClient#get_run') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::DataFlow::Models::Run' ) end # rubocop:enable Metrics/BlockLength end |
#get_run_log(run_id, name, opts = {}, &block) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/dataflow/get_run_log.rb.html) to see an example of how to use get_run_log API.
Retrieves the content of an run log.
883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 |
# File 'lib/oci/data_flow/data_flow_client.rb', line 883 def get_run_log(run_id, name, opts = {}, &block) logger.debug 'Calling operation DataFlowClient#get_run_log.' if logger raise "Missing the required parameter 'run_id' when calling get_run_log." if run_id.nil? raise "Missing the required parameter 'name' when calling get_run_log." if name.nil? raise "Parameter value for 'run_id' must not be blank" if OCI::Internal::Util.blank_string?(run_id) raise "Parameter value for 'name' must not be blank" if OCI::Internal::Util.blank_string?(name) path = '/runs/{runId}/logs/{name}'.sub('{runId}', run_id.to_s).sub('{name}', name.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = opts[:accept] if opts[:accept] header_params[:accept] ||= 'application/octet-stream' header_params[:'accept-encoding'] = opts[:accept_encoding] if opts[:accept_encoding] header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DataFlowClient#get_run_log') do if !block.nil? @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'Stream', &block ) elsif opts[:response_target] if opts[:response_target].respond_to? :write @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'Stream', &proc { |chunk, _response| opts[:response_target].write(chunk) } ) elsif opts[:response_target].is_a?(String) File.open(opts[:response_target], 'wb') do |output| return @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'Stream', &proc { |chunk, _response| output.write(chunk) } ) end end else @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'String' ) end end # rubocop:enable Metrics/BlockLength end |
#get_work_request(work_request_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/dataflow/get_work_request.rb.html) to see an example of how to use get_work_request API.
Gets the status of the work request with the given OCID.
987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 |
# File 'lib/oci/data_flow/data_flow_client.rb', line 987 def get_work_request(work_request_id, opts = {}) logger.debug 'Calling operation DataFlowClient#get_work_request.' if logger raise "Missing the required parameter 'work_request_id' when calling get_work_request." if work_request_id.nil? raise "Parameter value for 'work_request_id' must not be blank" if OCI::Internal::Util.blank_string?(work_request_id) path = '/workRequests/{workRequestId}'.sub('{workRequestId}', work_request_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DataFlowClient#get_work_request') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::DataFlow::Models::WorkRequest' ) end # rubocop:enable Metrics/BlockLength end |
#list_applications(compartment_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/dataflow/list_applications.rb.html) to see an example of how to use list_applications API.
Lists all applications in the specified compartment. Only one parameter other than compartmentId may also be included in a query. The query must include compartmentId. If the query does not include compartmentId, or includes compartmentId but two or more other parameters an error is returned.
Allowed values are: timeCreated, displayName, language
1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 |
# File 'lib/oci/data_flow/data_flow_client.rb', line 1064 def list_applications(compartment_id, opts = {}) logger.debug 'Calling operation DataFlowClient#list_applications.' if logger raise "Missing the required parameter 'compartment_id' when calling list_applications." if compartment_id.nil? if opts[:sort_by] && !%w[timeCreated displayName language].include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of timeCreated, displayName, language.' end if opts[:sort_order] && !%w[ASC DESC].include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of ASC, DESC.' end path = '/applications' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:compartmentId] = compartment_id query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] query_params[:displayName] = opts[:display_name] if opts[:display_name] query_params[:ownerPrincipalId] = opts[:owner_principal_id] if opts[:owner_principal_id] query_params[:displayNameStartsWith] = opts[:display_name_starts_with] if opts[:display_name_starts_with] query_params[:sparkVersion] = opts[:spark_version] if opts[:spark_version] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DataFlowClient#list_applications') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'Array<OCI::DataFlow::Models::ApplicationSummary>' ) end # rubocop:enable Metrics/BlockLength end |
#list_private_endpoints(compartment_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/dataflow/list_private_endpoints.rb.html) to see an example of how to use list_private_endpoints API.
Lists all private endpoints in the specified compartment.
Allowed values are: timeCreated
1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 |
# File 'lib/oci/data_flow/data_flow_client.rb', line 1157 def list_private_endpoints(compartment_id, opts = {}) logger.debug 'Calling operation DataFlowClient#list_private_endpoints.' if logger raise "Missing the required parameter 'compartment_id' when calling list_private_endpoints." if compartment_id.nil? if opts[:lifecycle_state] && !OCI::DataFlow::Models::PRIVATE_ENDPOINT_LIFECYCLE_STATE_ENUM.include?(opts[:lifecycle_state]) raise 'Invalid value for "lifecycle_state", must be one of the values in OCI::DataFlow::Models::PRIVATE_ENDPOINT_LIFECYCLE_STATE_ENUM.' end if opts[:sort_by] && !%w[timeCreated].include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of timeCreated.' end if opts[:sort_order] && !%w[ASC DESC].include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of ASC, DESC.' end path = '/privateEndpoints' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:compartmentId] = compartment_id query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] query_params[:lifecycleState] = opts[:lifecycle_state] if opts[:lifecycle_state] query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] query_params[:displayName] = opts[:display_name] if opts[:display_name] query_params[:ownerPrincipalId] = opts[:owner_principal_id] if opts[:owner_principal_id] query_params[:displayNameStartsWith] = opts[:display_name_starts_with] if opts[:display_name_starts_with] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DataFlowClient#list_private_endpoints') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::DataFlow::Models::PrivateEndpointCollection' ) end # rubocop:enable Metrics/BlockLength end |
#list_run_logs(run_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/dataflow/list_run_logs.rb.html) to see an example of how to use list_run_logs API.
Retrieves summaries of the run’s logs.
1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 1267 1268 1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 |
# File 'lib/oci/data_flow/data_flow_client.rb', line 1240 def list_run_logs(run_id, opts = {}) logger.debug 'Calling operation DataFlowClient#list_run_logs.' if logger raise "Missing the required parameter 'run_id' when calling list_run_logs." if run_id.nil? raise "Parameter value for 'run_id' must not be blank" if OCI::Internal::Util.blank_string?(run_id) path = '/runs/{runId}/logs'.sub('{runId}', run_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DataFlowClient#list_run_logs') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'Array<OCI::DataFlow::Models::RunLogSummary>' ) end # rubocop:enable Metrics/BlockLength end |
#list_runs(compartment_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/dataflow/list_runs.rb.html) to see an example of how to use list_runs API.
Lists all runs of an application in the specified compartment. Only one parameter other than compartmentId may also be included in a query. The query must include compartmentId. If the query does not include compartmentId, or includes compartmentId but two or more other parameters an error is returned.
Allowed values are: timeCreated, displayName, language, runDurationInMilliseconds, lifecycleState, totalOCpu, dataReadInBytes, dataWrittenInBytes
1323 1324 1325 1326 1327 1328 1329 1330 1331 1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 |
# File 'lib/oci/data_flow/data_flow_client.rb', line 1323 def list_runs(compartment_id, opts = {}) logger.debug 'Calling operation DataFlowClient#list_runs.' if logger raise "Missing the required parameter 'compartment_id' when calling list_runs." if compartment_id.nil? if opts[:lifecycle_state] && !OCI::DataFlow::Models::RUN_LIFECYCLE_STATE_ENUM.include?(opts[:lifecycle_state]) raise 'Invalid value for "lifecycle_state", must be one of the values in OCI::DataFlow::Models::RUN_LIFECYCLE_STATE_ENUM.' end if opts[:sort_by] && !%w[timeCreated displayName language runDurationInMilliseconds lifecycleState totalOCpu dataReadInBytes dataWrittenInBytes].include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of timeCreated, displayName, language, runDurationInMilliseconds, lifecycleState, totalOCpu, dataReadInBytes, dataWrittenInBytes.' end if opts[:sort_order] && !%w[ASC DESC].include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of ASC, DESC.' end path = '/runs' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:compartmentId] = compartment_id query_params[:applicationId] = opts[:application_id] if opts[:application_id] query_params[:ownerPrincipalId] = opts[:owner_principal_id] if opts[:owner_principal_id] query_params[:displayNameStartsWith] = opts[:display_name_starts_with] if opts[:display_name_starts_with] query_params[:lifecycleState] = opts[:lifecycle_state] if opts[:lifecycle_state] query_params[:timeCreatedGreaterThan] = opts[:time_created_greater_than] if opts[:time_created_greater_than] query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] query_params[:displayName] = opts[:display_name] if opts[:display_name] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DataFlowClient#list_runs') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'Array<OCI::DataFlow::Models::RunSummary>' ) end # rubocop:enable Metrics/BlockLength end |
#list_work_request_errors(work_request_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/dataflow/list_work_request_errors.rb.html) to see an example of how to use list_work_request_errors API.
Return a (paginated) list of errors for a given work request.
1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 |
# File 'lib/oci/data_flow/data_flow_client.rb', line 1408 def list_work_request_errors(work_request_id, opts = {}) logger.debug 'Calling operation DataFlowClient#list_work_request_errors.' if logger raise "Missing the required parameter 'work_request_id' when calling list_work_request_errors." if work_request_id.nil? raise "Parameter value for 'work_request_id' must not be blank" if OCI::Internal::Util.blank_string?(work_request_id) path = '/workRequests/{workRequestId}/errors'.sub('{workRequestId}', work_request_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DataFlowClient#list_work_request_errors') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::DataFlow::Models::WorkRequestErrorCollection' ) end # rubocop:enable Metrics/BlockLength end |
#list_work_request_logs(work_request_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/dataflow/list_work_request_logs.rb.html) to see an example of how to use list_work_request_logs API.
Return a paginated list of logs for a given work request.
1473 1474 1475 1476 1477 1478 1479 1480 1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 |
# File 'lib/oci/data_flow/data_flow_client.rb', line 1473 def list_work_request_logs(work_request_id, opts = {}) logger.debug 'Calling operation DataFlowClient#list_work_request_logs.' if logger raise "Missing the required parameter 'work_request_id' when calling list_work_request_logs." if work_request_id.nil? raise "Parameter value for 'work_request_id' must not be blank" if OCI::Internal::Util.blank_string?(work_request_id) path = '/workRequests/{workRequestId}/logs'.sub('{workRequestId}', work_request_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DataFlowClient#list_work_request_logs') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::DataFlow::Models::WorkRequestLogCollection' ) end # rubocop:enable Metrics/BlockLength end |
#list_work_requests(compartment_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/dataflow/list_work_requests.rb.html) to see an example of how to use list_work_requests API.
Lists the work requests in a compartment.
1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 |
# File 'lib/oci/data_flow/data_flow_client.rb', line 1538 def list_work_requests(compartment_id, opts = {}) logger.debug 'Calling operation DataFlowClient#list_work_requests.' if logger raise "Missing the required parameter 'compartment_id' when calling list_work_requests." if compartment_id.nil? path = '/workRequests' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:compartmentId] = compartment_id query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DataFlowClient#list_work_requests') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::DataFlow::Models::WorkRequestCollection' ) end # rubocop:enable Metrics/BlockLength end |
#logger ⇒ Logger
Returns The logger for this client. May be nil.
92 93 94 |
# File 'lib/oci/data_flow/data_flow_client.rb', line 92 def logger @api_client.config.logger end |
#update_application(update_application_details, application_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/dataflow/update_application.rb.html) to see an example of how to use update_application API.
Updates an application using an applicationId.
1604 1605 1606 1607 1608 1609 1610 1611 1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 |
# File 'lib/oci/data_flow/data_flow_client.rb', line 1604 def update_application(update_application_details, application_id, opts = {}) logger.debug 'Calling operation DataFlowClient#update_application.' if logger raise "Missing the required parameter 'update_application_details' when calling update_application." if update_application_details.nil? raise "Missing the required parameter 'application_id' when calling update_application." if application_id.nil? raise "Parameter value for 'application_id' must not be blank" if OCI::Internal::Util.blank_string?(application_id) path = '/applications/{applicationId}'.sub('{applicationId}', application_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'if-match'] = opts[:if_match] if opts[:if_match] # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(update_application_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DataFlowClient#update_application') do @api_client.call_api( :PUT, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::DataFlow::Models::Application' ) end # rubocop:enable Metrics/BlockLength end |
#update_private_endpoint(update_private_endpoint_details, private_endpoint_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/dataflow/update_private_endpoint.rb.html) to see an example of how to use update_private_endpoint API.
Updates a private endpoint using a privateEndpointId. If changes to a private endpoint match a previously defined private endpoint, then a 409 status code will be returned. This indicates that a conflict has been detected.
1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 1692 1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 |
# File 'lib/oci/data_flow/data_flow_client.rb', line 1672 def update_private_endpoint(update_private_endpoint_details, private_endpoint_id, opts = {}) logger.debug 'Calling operation DataFlowClient#update_private_endpoint.' if logger raise "Missing the required parameter 'update_private_endpoint_details' when calling update_private_endpoint." if update_private_endpoint_details.nil? raise "Missing the required parameter 'private_endpoint_id' when calling update_private_endpoint." if private_endpoint_id.nil? raise "Parameter value for 'private_endpoint_id' must not be blank" if OCI::Internal::Util.blank_string?(private_endpoint_id) path = '/privateEndpoints/{privateEndpointId}'.sub('{privateEndpointId}', private_endpoint_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'if-match'] = opts[:if_match] if opts[:if_match] # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(update_private_endpoint_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DataFlowClient#update_private_endpoint') do @api_client.call_api( :PUT, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#update_run(update_run_details, run_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/dataflow/update_run.rb.html) to see an example of how to use update_run API.
Updates a run using a runId.
1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 1770 1771 1772 1773 1774 1775 |
# File 'lib/oci/data_flow/data_flow_client.rb', line 1737 def update_run(update_run_details, run_id, opts = {}) logger.debug 'Calling operation DataFlowClient#update_run.' if logger raise "Missing the required parameter 'update_run_details' when calling update_run." if update_run_details.nil? raise "Missing the required parameter 'run_id' when calling update_run." if run_id.nil? raise "Parameter value for 'run_id' must not be blank" if OCI::Internal::Util.blank_string?(run_id) path = '/runs/{runId}'.sub('{runId}', run_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'if-match'] = opts[:if_match] if opts[:if_match] # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(update_run_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DataFlowClient#update_run') do @api_client.call_api( :PUT, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::DataFlow::Models::Run' ) end # rubocop:enable Metrics/BlockLength end |