Class: OCI::DataFlow::Models::PrivateEndpoint
- Inherits:
-
Object
- Object
- OCI::DataFlow::Models::PrivateEndpoint
- Defined in:
- lib/oci/data_flow/models/private_endpoint.rb
Overview
A Data Flow private endpoint object.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The OCID of a compartment.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
[Required] Defined tags for this resource.
-
#description ⇒ String
A user-friendly description.
-
#display_name ⇒ String
[Required] A user-friendly name.
-
#dns_zones ⇒ Array<String>
[Required] An array of DNS zone names.
-
#freeform_tags ⇒ Hash<String, String>
[Required] Free-form tags for this resource.
-
#id ⇒ String
[Required] The OCID of a private endpoint.
-
#lifecycle_details ⇒ String
The detailed messages about the lifecycle state.
-
#lifecycle_state ⇒ String
[Required] The current state of this private endpoint.
-
#max_host_count ⇒ Integer
The maximum number of hosts to be accessed through the private endpoint.
-
#nsg_ids ⇒ Array<String>
An array of network security group OCIDs.
-
#owner_principal_id ⇒ String
[Required] The OCID of the user who created the resource.
-
#owner_user_name ⇒ String
The username of the user who created the resource.
-
#subnet_id ⇒ String
[Required] The OCID of a subnet.
-
#time_created ⇒ DateTime
[Required] The date and time a application was created, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.
-
#time_updated ⇒ DateTime
[Required] The date and time a application was updated, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PrivateEndpoint
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ PrivateEndpoint
Initializes the object
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/oci/data_flow/models/private_endpoint.rb', line 183 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.description = attributes[:'description'] if attributes[:'description'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.dns_zones = attributes[:'dnsZones'] if attributes[:'dnsZones'] raise 'You cannot provide both :dnsZones and :dns_zones' if attributes.key?(:'dnsZones') && attributes.key?(:'dns_zones') self.dns_zones = attributes[:'dns_zones'] if attributes[:'dns_zones'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.id = attributes[:'id'] if attributes[:'id'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.max_host_count = attributes[:'maxHostCount'] if attributes[:'maxHostCount'] raise 'You cannot provide both :maxHostCount and :max_host_count' if attributes.key?(:'maxHostCount') && attributes.key?(:'max_host_count') self.max_host_count = attributes[:'max_host_count'] if attributes[:'max_host_count'] self.nsg_ids = attributes[:'nsgIds'] if attributes[:'nsgIds'] raise 'You cannot provide both :nsgIds and :nsg_ids' if attributes.key?(:'nsgIds') && attributes.key?(:'nsg_ids') self.nsg_ids = attributes[:'nsg_ids'] if attributes[:'nsg_ids'] self.owner_principal_id = attributes[:'ownerPrincipalId'] if attributes[:'ownerPrincipalId'] raise 'You cannot provide both :ownerPrincipalId and :owner_principal_id' if attributes.key?(:'ownerPrincipalId') && attributes.key?(:'owner_principal_id') self.owner_principal_id = attributes[:'owner_principal_id'] if attributes[:'owner_principal_id'] self.owner_user_name = attributes[:'ownerUserName'] if attributes[:'ownerUserName'] raise 'You cannot provide both :ownerUserName and :owner_user_name' if attributes.key?(:'ownerUserName') && attributes.key?(:'owner_user_name') self.owner_user_name = attributes[:'owner_user_name'] if attributes[:'owner_user_name'] self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId'] raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id') self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The OCID of a compartment.
26 27 28 |
# File 'lib/oci/data_flow/models/private_endpoint.rb', line 26 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
[Required] Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: ‘{"CostCenter": "42"}`
32 33 34 |
# File 'lib/oci/data_flow/models/private_endpoint.rb', line 32 def end |
#description ⇒ String
A user-friendly description. Avoid entering confidential information.
37 38 39 |
# File 'lib/oci/data_flow/models/private_endpoint.rb', line 37 def description @description end |
#display_name ⇒ String
[Required] A user-friendly name. It does not have to be unique. Avoid entering confidential information.
42 43 44 |
# File 'lib/oci/data_flow/models/private_endpoint.rb', line 42 def display_name @display_name end |
#dns_zones ⇒ Array<String>
[Required] An array of DNS zone names. Example: ‘[ "app.examplecorp.com", "app.examplecorp2.com" ]`
48 49 50 |
# File 'lib/oci/data_flow/models/private_endpoint.rb', line 48 def dns_zones @dns_zones end |
#freeform_tags ⇒ Hash<String, String>
[Required] Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: ‘"Finance"`
55 56 57 |
# File 'lib/oci/data_flow/models/private_endpoint.rb', line 55 def end |
#id ⇒ String
[Required] The OCID of a private endpoint.
60 61 62 |
# File 'lib/oci/data_flow/models/private_endpoint.rb', line 60 def id @id end |
#lifecycle_details ⇒ String
The detailed messages about the lifecycle state.
65 66 67 |
# File 'lib/oci/data_flow/models/private_endpoint.rb', line 65 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
[Required] The current state of this private endpoint.
70 71 72 |
# File 'lib/oci/data_flow/models/private_endpoint.rb', line 70 def lifecycle_state @lifecycle_state end |
#max_host_count ⇒ Integer
The maximum number of hosts to be accessed through the private endpoint. This value is used to calculate the relevant CIDR block and should be a multiple of 256. If the value is not a multiple of 256, it is rounded up to the next multiple of 256. For example, 300 is rounded up to 512.
78 79 80 |
# File 'lib/oci/data_flow/models/private_endpoint.rb', line 78 def max_host_count @max_host_count end |
#nsg_ids ⇒ Array<String>
An array of network security group OCIDs.
83 84 85 |
# File 'lib/oci/data_flow/models/private_endpoint.rb', line 83 def nsg_ids @nsg_ids end |
#owner_principal_id ⇒ String
[Required] The OCID of the user who created the resource.
88 89 90 |
# File 'lib/oci/data_flow/models/private_endpoint.rb', line 88 def owner_principal_id @owner_principal_id end |
#owner_user_name ⇒ String
The username of the user who created the resource. If the username of the owner does not exist, null will be returned and the caller should refer to the ownerPrincipalId value instead.
94 95 96 |
# File 'lib/oci/data_flow/models/private_endpoint.rb', line 94 def owner_user_name @owner_user_name end |
#subnet_id ⇒ String
[Required] The OCID of a subnet.
99 100 101 |
# File 'lib/oci/data_flow/models/private_endpoint.rb', line 99 def subnet_id @subnet_id end |
#time_created ⇒ DateTime
[Required] The date and time a application was created, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format. Example: 2018-04-03T21:10:29.600Z
105 106 107 |
# File 'lib/oci/data_flow/models/private_endpoint.rb', line 105 def time_created @time_created end |
#time_updated ⇒ DateTime
[Required] The date and time a application was updated, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format. Example: 2018-04-03T21:10:29.600Z
111 112 113 |
# File 'lib/oci/data_flow/models/private_endpoint.rb', line 111 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/oci/data_flow/models/private_endpoint.rb', line 114 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'defined_tags': :'definedTags', 'description': :'description', 'display_name': :'displayName', 'dns_zones': :'dnsZones', 'freeform_tags': :'freeformTags', 'id': :'id', 'lifecycle_details': :'lifecycleDetails', 'lifecycle_state': :'lifecycleState', 'max_host_count': :'maxHostCount', 'nsg_ids': :'nsgIds', 'owner_principal_id': :'ownerPrincipalId', 'owner_user_name': :'ownerUserName', 'subnet_id': :'subnetId', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/oci/data_flow/models/private_endpoint.rb', line 138 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'description': :'String', 'display_name': :'String', 'dns_zones': :'Array<String>', 'freeform_tags': :'Hash<String, String>', 'id': :'String', 'lifecycle_details': :'String', 'lifecycle_state': :'String', 'max_host_count': :'Integer', 'nsg_ids': :'Array<String>', 'owner_principal_id': :'String', 'owner_user_name': :'String', 'subnet_id': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 |
# File 'lib/oci/data_flow/models/private_endpoint.rb', line 298 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && == other. && description == other.description && display_name == other.display_name && dns_zones == other.dns_zones && == other. && id == other.id && lifecycle_details == other.lifecycle_details && lifecycle_state == other.lifecycle_state && max_host_count == other.max_host_count && nsg_ids == other.nsg_ids && owner_principal_id == other.owner_principal_id && owner_user_name == other.owner_user_name && subnet_id == other.subnet_id && time_created == other.time_created && time_updated == other.time_updated end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 |
# File 'lib/oci/data_flow/models/private_endpoint.rb', line 343 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
323 324 325 |
# File 'lib/oci/data_flow/models/private_endpoint.rb', line 323 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
332 333 334 |
# File 'lib/oci/data_flow/models/private_endpoint.rb', line 332 def hash [compartment_id, , description, display_name, dns_zones, , id, lifecycle_details, lifecycle_state, max_host_count, nsg_ids, owner_principal_id, owner_user_name, subnet_id, time_created, time_updated].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
376 377 378 379 380 381 382 383 384 385 |
# File 'lib/oci/data_flow/models/private_endpoint.rb', line 376 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
370 371 372 |
# File 'lib/oci/data_flow/models/private_endpoint.rb', line 370 def to_s to_hash.to_s end |