Class: OCI::DataFlow::Models::PrivateEndpointSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_flow/models/private_endpoint_summary.rb

Overview

A Data Flow private endpoint object used in bulk listings.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PrivateEndpointSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property

  • :display_name (String)

    The value to assign to the #display_name property

  • :dns_zones (Array<String>)

    The value to assign to the #dns_zones property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :id (String)

    The value to assign to the #id property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :max_host_count (Integer)

    The value to assign to the #max_host_count property

  • :nsg_ids (Array<String>)

    The value to assign to the #nsg_ids property

  • :owner_principal_id (String)

    The value to assign to the #owner_principal_id property

  • :owner_user_name (String)

    The value to assign to the #owner_user_name property

  • :subnet_id (String)

    The value to assign to the #subnet_id property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :time_updated (DateTime)

    The value to assign to the #time_updated property



167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
# File 'lib/oci/data_flow/models/private_endpoint_summary.rb', line 167

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.dns_zones = attributes[:'dnsZones'] if attributes[:'dnsZones']

  raise 'You cannot provide both :dnsZones and :dns_zones' if attributes.key?(:'dnsZones') && attributes.key?(:'dns_zones')

  self.dns_zones = attributes[:'dns_zones'] if attributes[:'dns_zones']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.id = attributes[:'id'] if attributes[:'id']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.max_host_count = attributes[:'maxHostCount'] if attributes[:'maxHostCount']

  raise 'You cannot provide both :maxHostCount and :max_host_count' if attributes.key?(:'maxHostCount') && attributes.key?(:'max_host_count')

  self.max_host_count = attributes[:'max_host_count'] if attributes[:'max_host_count']

  self.nsg_ids = attributes[:'nsgIds'] if attributes[:'nsgIds']

  raise 'You cannot provide both :nsgIds and :nsg_ids' if attributes.key?(:'nsgIds') && attributes.key?(:'nsg_ids')

  self.nsg_ids = attributes[:'nsg_ids'] if attributes[:'nsg_ids']

  self.owner_principal_id = attributes[:'ownerPrincipalId'] if attributes[:'ownerPrincipalId']

  raise 'You cannot provide both :ownerPrincipalId and :owner_principal_id' if attributes.key?(:'ownerPrincipalId') && attributes.key?(:'owner_principal_id')

  self.owner_principal_id = attributes[:'owner_principal_id'] if attributes[:'owner_principal_id']

  self.owner_user_name = attributes[:'ownerUserName'] if attributes[:'ownerUserName']

  raise 'You cannot provide both :ownerUserName and :owner_user_name' if attributes.key?(:'ownerUserName') && attributes.key?(:'owner_user_name')

  self.owner_user_name = attributes[:'owner_user_name'] if attributes[:'owner_user_name']

  self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId']

  raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id')

  self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']
end

Instance Attribute Details

#compartment_idString

[Required] The OCID of a compartment.

Returns:

  • (String)


26
27
28
# File 'lib/oci/data_flow/models/private_endpoint_summary.rb', line 26

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

[Required] Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: ‘{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


32
33
34
# File 'lib/oci/data_flow/models/private_endpoint_summary.rb', line 32

def defined_tags
  @defined_tags
end

#display_nameString

[Required] A user-friendly name. It does not have to be unique. Avoid entering confidential information.

Returns:

  • (String)


37
38
39
# File 'lib/oci/data_flow/models/private_endpoint_summary.rb', line 37

def display_name
  @display_name
end

#dns_zonesArray<String>

[Required] An array of DNS zone names. Example: ‘[ "app.examplecorp.com", "app.examplecorp2.com" ]`

Returns:

  • (Array<String>)


43
44
45
# File 'lib/oci/data_flow/models/private_endpoint_summary.rb', line 43

def dns_zones
  @dns_zones
end

#freeform_tagsHash<String, String>

[Required] Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: ‘"Finance"`

Returns:

  • (Hash<String, String>)


50
51
52
# File 'lib/oci/data_flow/models/private_endpoint_summary.rb', line 50

def freeform_tags
  @freeform_tags
end

#idString

[Required] The OCID of a private endpoint.

Returns:

  • (String)


55
56
57
# File 'lib/oci/data_flow/models/private_endpoint_summary.rb', line 55

def id
  @id
end

#lifecycle_stateString

[Required] The current state of this private endpoint.

Returns:

  • (String)


60
61
62
# File 'lib/oci/data_flow/models/private_endpoint_summary.rb', line 60

def lifecycle_state
  @lifecycle_state
end

#max_host_countInteger

The maximum number of hosts to be accessed through the private endpoint. This value is used to calculate the relevant CIDR block and should be a multiple of 256. If the value is not a multiple of 256, it is rounded up to the next multiple of 256. For example, 300 is rounded up to 512.

Returns:

  • (Integer)


68
69
70
# File 'lib/oci/data_flow/models/private_endpoint_summary.rb', line 68

def max_host_count
  @max_host_count
end

#nsg_idsArray<String>

An array of network security group OCIDs.

Returns:

  • (Array<String>)


73
74
75
# File 'lib/oci/data_flow/models/private_endpoint_summary.rb', line 73

def nsg_ids
  @nsg_ids
end

#owner_principal_idString

[Required] The OCID of the user who created the resource.

Returns:

  • (String)


78
79
80
# File 'lib/oci/data_flow/models/private_endpoint_summary.rb', line 78

def owner_principal_id
  @owner_principal_id
end

#owner_user_nameString

The username of the user who created the resource. If the username of the owner does not exist, null will be returned and the caller should refer to the ownerPrincipalId value instead.

Returns:

  • (String)


84
85
86
# File 'lib/oci/data_flow/models/private_endpoint_summary.rb', line 84

def owner_user_name
  @owner_user_name
end

#subnet_idString

[Required] The OCID of a subnet.

Returns:

  • (String)


89
90
91
# File 'lib/oci/data_flow/models/private_endpoint_summary.rb', line 89

def subnet_id
  @subnet_id
end

#time_createdDateTime

[Required] The date and time a application was created, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format. Example: 2018-04-03T21:10:29.600Z

Returns:

  • (DateTime)


95
96
97
# File 'lib/oci/data_flow/models/private_endpoint_summary.rb', line 95

def time_created
  @time_created
end

#time_updatedDateTime

[Required] The date and time a application was updated, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format. Example: 2018-04-03T21:10:29.600Z

Returns:

  • (DateTime)


101
102
103
# File 'lib/oci/data_flow/models/private_endpoint_summary.rb', line 101

def time_updated
  @time_updated
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/oci/data_flow/models/private_endpoint_summary.rb', line 104

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'compartmentId',
    'defined_tags': :'definedTags',
    'display_name': :'displayName',
    'dns_zones': :'dnsZones',
    'freeform_tags': :'freeformTags',
    'id': :'id',
    'lifecycle_state': :'lifecycleState',
    'max_host_count': :'maxHostCount',
    'nsg_ids': :'nsgIds',
    'owner_principal_id': :'ownerPrincipalId',
    'owner_user_name': :'ownerUserName',
    'subnet_id': :'subnetId',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'lib/oci/data_flow/models/private_endpoint_summary.rb', line 126

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'String',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'display_name': :'String',
    'dns_zones': :'Array<String>',
    'freeform_tags': :'Hash<String, String>',
    'id': :'String',
    'lifecycle_state': :'String',
    'max_host_count': :'Integer',
    'nsg_ids': :'Array<String>',
    'owner_principal_id': :'String',
    'owner_user_name': :'String',
    'subnet_id': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/oci/data_flow/models/private_endpoint_summary.rb', line 274

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    compartment_id == other.compartment_id &&
    defined_tags == other.defined_tags &&
    display_name == other.display_name &&
    dns_zones == other.dns_zones &&
    freeform_tags == other.freeform_tags &&
    id == other.id &&
    lifecycle_state == other.lifecycle_state &&
    max_host_count == other.max_host_count &&
    nsg_ids == other.nsg_ids &&
    owner_principal_id == other.owner_principal_id &&
    owner_user_name == other.owner_user_name &&
    subnet_id == other.subnet_id &&
    time_created == other.time_created &&
    time_updated == other.time_updated
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
# File 'lib/oci/data_flow/models/private_endpoint_summary.rb', line 317

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


297
298
299
# File 'lib/oci/data_flow/models/private_endpoint_summary.rb', line 297

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



306
307
308
# File 'lib/oci/data_flow/models/private_endpoint_summary.rb', line 306

def hash
  [compartment_id, defined_tags, display_name, dns_zones, freeform_tags, id, lifecycle_state, max_host_count, nsg_ids, owner_principal_id, owner_user_name, subnet_id, time_created, time_updated].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



350
351
352
353
354
355
356
357
358
359
# File 'lib/oci/data_flow/models/private_endpoint_summary.rb', line 350

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



344
345
346
# File 'lib/oci/data_flow/models/private_endpoint_summary.rb', line 344

def to_s
  to_hash.to_s
end