Class: OCI::DataFlow::Models::WorkRequestResource
- Inherits:
-
Object
- Object
- OCI::DataFlow::Models::WorkRequestResource
- Defined in:
- lib/oci/data_flow/models/work_request_resource.rb
Overview
A resource related to a Data Flow work request.
Constant Summary collapse
- ACTION_TYPE_ENUM =
[ ACTION_TYPE_CREATED = 'CREATED'.freeze, ACTION_TYPE_UPDATED = 'UPDATED'.freeze, ACTION_TYPE_DELETED = 'DELETED'.freeze, ACTION_TYPE_INPROGRESS = 'INPROGRESS'.freeze, ACTION_TYPE_RELATED = 'RELATED'.freeze, ACTION_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#action_type ⇒ String
[Required] The way in which this resource is affected by the work tracked in the work request.
-
#id ⇒ Integer
The id of a work request resource object.
-
#resource_id ⇒ String
[Required] The id of the releated resource.
-
#resource_type ⇒ String
[Required] The type of resource.
-
#resource_uri ⇒ String
The URI path that the user can use to get access to the resource metadata.
-
#work_requestid ⇒ String
The OCID of a work request.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WorkRequestResource
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ WorkRequestResource
Initializes the object
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/oci/data_flow/models/work_request_resource.rb', line 91 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.action_type = attributes[:'actionType'] if attributes[:'actionType'] raise 'You cannot provide both :actionType and :action_type' if attributes.key?(:'actionType') && attributes.key?(:'action_type') self.action_type = attributes[:'action_type'] if attributes[:'action_type'] self.id = attributes[:'id'] if attributes[:'id'] self.resource_id = attributes[:'resourceId'] if attributes[:'resourceId'] raise 'You cannot provide both :resourceId and :resource_id' if attributes.key?(:'resourceId') && attributes.key?(:'resource_id') self.resource_id = attributes[:'resource_id'] if attributes[:'resource_id'] self.resource_type = attributes[:'resourceType'] if attributes[:'resourceType'] raise 'You cannot provide both :resourceType and :resource_type' if attributes.key?(:'resourceType') && attributes.key?(:'resource_type') self.resource_type = attributes[:'resource_type'] if attributes[:'resource_type'] self.resource_uri = attributes[:'resourceUri'] if attributes[:'resourceUri'] raise 'You cannot provide both :resourceUri and :resource_uri' if attributes.key?(:'resourceUri') && attributes.key?(:'resource_uri') self.resource_uri = attributes[:'resource_uri'] if attributes[:'resource_uri'] self.work_requestid = attributes[:'workRequestid'] if attributes[:'workRequestid'] raise 'You cannot provide both :workRequestid and :work_requestid' if attributes.key?(:'workRequestid') && attributes.key?(:'work_requestid') self.work_requestid = attributes[:'work_requestid'] if attributes[:'work_requestid'] end |
Instance Attribute Details
#action_type ⇒ String
[Required] The way in which this resource is affected by the work tracked in the work request.
24 25 26 |
# File 'lib/oci/data_flow/models/work_request_resource.rb', line 24 def action_type @action_type end |
#id ⇒ Integer
The id of a work request resource object.
29 30 31 |
# File 'lib/oci/data_flow/models/work_request_resource.rb', line 29 def id @id end |
#resource_id ⇒ String
[Required] The id of the releated resource. See resourceType to identity the specific type of resource.
34 35 36 |
# File 'lib/oci/data_flow/models/work_request_resource.rb', line 34 def resource_id @resource_id end |
#resource_type ⇒ String
[Required] The type of resource. See resourceId for the id of the specific resource.
39 40 41 |
# File 'lib/oci/data_flow/models/work_request_resource.rb', line 39 def resource_type @resource_type end |
#resource_uri ⇒ String
The URI path that the user can use to get access to the resource metadata
44 45 46 |
# File 'lib/oci/data_flow/models/work_request_resource.rb', line 44 def resource_uri @resource_uri end |
#work_requestid ⇒ String
The OCID of a work request.
49 50 51 |
# File 'lib/oci/data_flow/models/work_request_resource.rb', line 49 def work_requestid @work_requestid end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/oci/data_flow/models/work_request_resource.rb', line 52 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'action_type': :'actionType', 'id': :'id', 'resource_id': :'resourceId', 'resource_type': :'resourceType', 'resource_uri': :'resourceUri', 'work_requestid': :'workRequestid' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/oci/data_flow/models/work_request_resource.rb', line 66 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'action_type': :'String', 'id': :'Integer', 'resource_id': :'String', 'resource_type': :'String', 'resource_uri': :'String', 'work_requestid': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/oci/data_flow/models/work_request_resource.rb', line 150 def ==(other) return true if equal?(other) self.class == other.class && action_type == other.action_type && id == other.id && resource_id == other.resource_id && resource_type == other.resource_type && resource_uri == other.resource_uri && work_requestid == other.work_requestid end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/oci/data_flow/models/work_request_resource.rb', line 185 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
165 166 167 |
# File 'lib/oci/data_flow/models/work_request_resource.rb', line 165 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
174 175 176 |
# File 'lib/oci/data_flow/models/work_request_resource.rb', line 174 def hash [action_type, id, resource_id, resource_type, resource_uri, work_requestid].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
218 219 220 221 222 223 224 225 226 227 |
# File 'lib/oci/data_flow/models/work_request_resource.rb', line 218 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
212 213 214 |
# File 'lib/oci/data_flow/models/work_request_resource.rb', line 212 def to_s to_hash.to_s end |