Class: OCI::DataIntegration::Models::AbstractDataOperationConfig
- Inherits:
-
Object
- Object
- OCI::DataIntegration::Models::AbstractDataOperationConfig
- Defined in:
- lib/oci/data_integration/models/abstract_data_operation_config.rb
Overview
The information about the data operation. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
Constant Summary collapse
- MODEL_TYPE_ENUM =
[ MODEL_TYPE_READ_OPERATION_CONFIG = 'READ_OPERATION_CONFIG'.freeze, MODEL_TYPE_WRITE_OPERATION_CONFIG = 'WRITE_OPERATION_CONFIG'.freeze ].freeze
Instance Attribute Summary collapse
- #call_attribute ⇒ OCI::DataIntegration::Models::BipCallAttribute
-
#derived_attributes ⇒ Hash<String, String>
this map is used for passing BIP report parameter values.
-
#metadata_config_properties ⇒ Hash<String, String>
This map is used for passing extra metatdata configuration that is required by read / write operation.
-
#model_type ⇒ String
**[Required]** The type of data operation.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AbstractDataOperationConfig
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ AbstractDataOperationConfig
Initializes the object
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/oci/data_integration/models/abstract_data_operation_config.rb', line 81 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.model_type = attributes[:'modelType'] if attributes[:'modelType'] raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type') self.model_type = attributes[:'model_type'] if attributes[:'model_type'] self. = attributes[:'metadataConfigProperties'] if attributes[:'metadataConfigProperties'] raise 'You cannot provide both :metadataConfigProperties and :metadata_config_properties' if attributes.key?(:'metadataConfigProperties') && attributes.key?(:'metadata_config_properties') self. = attributes[:'metadata_config_properties'] if attributes[:'metadata_config_properties'] self.derived_attributes = attributes[:'derivedAttributes'] if attributes[:'derivedAttributes'] raise 'You cannot provide both :derivedAttributes and :derived_attributes' if attributes.key?(:'derivedAttributes') && attributes.key?(:'derived_attributes') self.derived_attributes = attributes[:'derived_attributes'] if attributes[:'derived_attributes'] self.call_attribute = attributes[:'callAttribute'] if attributes[:'callAttribute'] raise 'You cannot provide both :callAttribute and :call_attribute' if attributes.key?(:'callAttribute') && attributes.key?(:'call_attribute') self.call_attribute = attributes[:'call_attribute'] if attributes[:'call_attribute'] end |
Instance Attribute Details
#call_attribute ⇒ OCI::DataIntegration::Models::BipCallAttribute
29 30 31 |
# File 'lib/oci/data_integration/models/abstract_data_operation_config.rb', line 29 def call_attribute @call_attribute end |
#derived_attributes ⇒ Hash<String, String>
this map is used for passing BIP report parameter values.
26 27 28 |
# File 'lib/oci/data_integration/models/abstract_data_operation_config.rb', line 26 def derived_attributes @derived_attributes end |
#metadata_config_properties ⇒ Hash<String, String>
This map is used for passing extra metatdata configuration that is required by read / write operation.
22 23 24 |
# File 'lib/oci/data_integration/models/abstract_data_operation_config.rb', line 22 def @metadata_config_properties end |
#model_type ⇒ String
**[Required]** The type of data operation.
18 19 20 |
# File 'lib/oci/data_integration/models/abstract_data_operation_config.rb', line 18 def model_type @model_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 40 41 |
# File 'lib/oci/data_integration/models/abstract_data_operation_config.rb', line 32 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'metadata_config_properties': :'metadataConfigProperties', 'derived_attributes': :'derivedAttributes', 'call_attribute': :'callAttribute' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
60 61 62 63 64 65 66 67 68 |
# File 'lib/oci/data_integration/models/abstract_data_operation_config.rb', line 60 def self.get_subtype(object_hash) type = object_hash[:'modelType'] # rubocop:disable Style/SymbolLiteral return 'OCI::DataIntegration::Models::WriteOperationConfig' if type == 'WRITE_OPERATION_CONFIG' return 'OCI::DataIntegration::Models::ReadOperationConfig' if type == 'READ_OPERATION_CONFIG' # TODO: Log a warning when the subtype is not found. 'OCI::DataIntegration::Models::AbstractDataOperationConfig' end |
.swagger_types ⇒ Object
Attribute type mapping.
44 45 46 47 48 49 50 51 52 53 |
# File 'lib/oci/data_integration/models/abstract_data_operation_config.rb', line 44 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'metadata_config_properties': :'Hash<String, String>', 'derived_attributes': :'Hash<String, String>', 'call_attribute': :'OCI::DataIntegration::Models::BipCallAttribute' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
127 128 129 130 131 132 133 134 135 |
# File 'lib/oci/data_integration/models/abstract_data_operation_config.rb', line 127 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && == other. && derived_attributes == other.derived_attributes && call_attribute == other.call_attribute end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/oci/data_integration/models/abstract_data_operation_config.rb', line 160 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
140 141 142 |
# File 'lib/oci/data_integration/models/abstract_data_operation_config.rb', line 140 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
149 150 151 |
# File 'lib/oci/data_integration/models/abstract_data_operation_config.rb', line 149 def hash [model_type, , derived_attributes, call_attribute].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
193 194 195 196 197 198 199 200 201 202 |
# File 'lib/oci/data_integration/models/abstract_data_operation_config.rb', line 193 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
187 188 189 |
# File 'lib/oci/data_integration/models/abstract_data_operation_config.rb', line 187 def to_s to_hash.to_s end |