Class: OCI::DataIntegration::Models::AbstractWriteAttribute
- Inherits:
-
Object
- Object
- OCI::DataIntegration::Models::AbstractWriteAttribute
- Defined in:
- lib/oci/data_integration/models/abstract_write_attribute.rb
Overview
The abstract write attribute. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
OracleAdwcWriteAttribute, OracleAtpWriteAttribute, OracleWriteAttribute
Constant Summary collapse
- MODEL_TYPE_ENUM =
[ MODEL_TYPE_ORACLEWRITEATTRIBUTE = 'ORACLEWRITEATTRIBUTE'.freeze, MODEL_TYPE_ORACLEATPWRITEATTRIBUTE = 'ORACLEATPWRITEATTRIBUTE'.freeze, MODEL_TYPE_ORACLEADWCWRITEATTRIBUTE = 'ORACLEADWCWRITEATTRIBUTE'.freeze, MODEL_TYPE_ORACLE_WRITE_ATTRIBUTE = 'ORACLE_WRITE_ATTRIBUTE'.freeze, MODEL_TYPE_ORACLE_ATP_WRITE_ATTRIBUTE = 'ORACLE_ATP_WRITE_ATTRIBUTE'.freeze, MODEL_TYPE_ORACLE_ADWC_WRITE_ATTRIBUTE = 'ORACLE_ADWC_WRITE_ATTRIBUTE'.freeze, MODEL_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#model_type ⇒ String
[Required] The type of the abstract write attribute.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AbstractWriteAttribute
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ AbstractWriteAttribute
Initializes the object
68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/oci/data_integration/models/abstract_write_attribute.rb', line 68 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.model_type = attributes[:'modelType'] if attributes[:'modelType'] raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type') self.model_type = attributes[:'model_type'] if attributes[:'model_type'] end |
Instance Attribute Details
#model_type ⇒ String
[Required] The type of the abstract write attribute.
24 25 26 |
# File 'lib/oci/data_integration/models/abstract_write_attribute.rb', line 24 def model_type @model_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
27 28 29 30 31 32 33 |
# File 'lib/oci/data_integration/models/abstract_write_attribute.rb', line 27 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
49 50 51 52 53 54 55 56 57 58 |
# File 'lib/oci/data_integration/models/abstract_write_attribute.rb', line 49 def self.get_subtype(object_hash) type = object_hash[:'modelType'] # rubocop:disable Style/SymbolLiteral return 'OCI::DataIntegration::Models::OracleAdwcWriteAttribute' if type == 'ORACLEADWCWRITEATTRIBUTE' return 'OCI::DataIntegration::Models::OracleWriteAttribute' if type == 'ORACLEWRITEATTRIBUTE' return 'OCI::DataIntegration::Models::OracleAtpWriteAttribute' if type == 'ORACLEATPWRITEATTRIBUTE' # TODO: Log a warning when the subtype is not found. 'OCI::DataIntegration::Models::AbstractWriteAttribute' end |
.swagger_types ⇒ Object
Attribute type mapping.
36 37 38 39 40 41 42 |
# File 'lib/oci/data_integration/models/abstract_write_attribute.rb', line 36 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
101 102 103 104 105 106 |
# File 'lib/oci/data_integration/models/abstract_write_attribute.rb', line 101 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/oci/data_integration/models/abstract_write_attribute.rb', line 131 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
111 112 113 |
# File 'lib/oci/data_integration/models/abstract_write_attribute.rb', line 111 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
120 121 122 |
# File 'lib/oci/data_integration/models/abstract_write_attribute.rb', line 120 def hash [model_type].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
164 165 166 167 168 169 170 171 172 173 |
# File 'lib/oci/data_integration/models/abstract_write_attribute.rb', line 164 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
158 159 160 |
# File 'lib/oci/data_integration/models/abstract_write_attribute.rb', line 158 def to_s to_hash.to_s end |