Class: OCI::DataIntegration::Models::Aggregator
- Inherits:
-
DataIntegration::Models::Operator
- Object
- DataIntegration::Models::Operator
- OCI::DataIntegration::Models::Aggregator
- Defined in:
- lib/oci/data_integration/models/aggregator.rb
Overview
The information about the aggregator operator. The aggregate operator performs calculations, like sum or count, on all rows or a group of rows to create new, derivative attributes.
Instance Attribute Summary collapse
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Aggregator
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Aggregator
Initializes the object
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/oci/data_integration/models/aggregator.rb', line 77 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['modelType'] = 'AGGREGATOR_OPERATOR' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.group_by_columns = attributes[:'groupByColumns'] if attributes[:'groupByColumns'] raise 'You cannot provide both :groupByColumns and :group_by_columns' if attributes.key?(:'groupByColumns') && attributes.key?(:'group_by_columns') self.group_by_columns = attributes[:'group_by_columns'] if attributes[:'group_by_columns'] end |
Instance Attribute Details
#group_by_columns ⇒ OCI::DataIntegration::Models::DynamicProxyField
12 13 14 |
# File 'lib/oci/data_integration/models/aggregator.rb', line 12 def group_by_columns @group_by_columns end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 |
# File 'lib/oci/data_integration/models/aggregator.rb', line 15 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'key': :'key', 'model_version': :'modelVersion', 'parent_ref': :'parentRef', 'name': :'name', 'description': :'description', 'object_version': :'objectVersion', 'input_ports': :'inputPorts', 'output_ports': :'outputPorts', 'object_status': :'objectStatus', 'identifier': :'identifier', 'parameters': :'parameters', 'op_config_values': :'opConfigValues', 'group_by_columns': :'groupByColumns' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/oci/data_integration/models/aggregator.rb', line 37 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'key': :'String', 'model_version': :'String', 'parent_ref': :'OCI::DataIntegration::Models::ParentReference', 'name': :'String', 'description': :'String', 'object_version': :'Integer', 'input_ports': :'Array<OCI::DataIntegration::Models::InputPort>', 'output_ports': :'Array<OCI::DataIntegration::Models::OutputPort>', 'object_status': :'Integer', 'identifier': :'String', 'parameters': :'Array<OCI::DataIntegration::Models::Parameter>', 'op_config_values': :'OCI::DataIntegration::Models::ConfigValues', 'group_by_columns': :'OCI::DataIntegration::Models::DynamicProxyField' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/oci/data_integration/models/aggregator.rb', line 101 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && key == other.key && model_version == other.model_version && parent_ref == other.parent_ref && name == other.name && description == other.description && object_version == other.object_version && input_ports == other.input_ports && output_ports == other.output_ports && object_status == other.object_status && identifier == other.identifier && parameters == other.parameters && op_config_values == other.op_config_values && group_by_columns == other.group_by_columns end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/oci/data_integration/models/aggregator.rb', line 144 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
124 125 126 |
# File 'lib/oci/data_integration/models/aggregator.rb', line 124 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
133 134 135 |
# File 'lib/oci/data_integration/models/aggregator.rb', line 133 def hash [model_type, key, model_version, parent_ref, name, description, object_version, input_ports, output_ports, object_status, identifier, parameters, op_config_values, group_by_columns].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
177 178 179 180 181 182 183 184 185 186 |
# File 'lib/oci/data_integration/models/aggregator.rb', line 177 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
171 172 173 |
# File 'lib/oci/data_integration/models/aggregator.rb', line 171 def to_s to_hash.to_s end |