Class: OCI::DataIntegration::Models::BiccReadAttributes
- Inherits:
-
AbstractReadAttribute
- Object
- AbstractReadAttribute
- OCI::DataIntegration::Models::BiccReadAttributes
- Defined in:
- lib/oci/data_integration/models/bicc_read_attributes.rb
Overview
Properties to configure reading from BICC.
Constant Summary collapse
- EXTRACT_STRATEGY_ENUM =
[ EXTRACT_STRATEGY_FULL = 'FULL'.freeze, EXTRACT_STRATEGY_INCREMENTAL = 'INCREMENTAL'.freeze, EXTRACT_STRATEGY_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Constants inherited from AbstractReadAttribute
AbstractReadAttribute::MODEL_TYPE_ENUM
Instance Attribute Summary collapse
- #external_storage ⇒ OCI::DataIntegration::Models::ExternalStorage
-
#extract_strategy ⇒ String
Extraction Strategy - FULL|INCREMENTAL.
-
#fetch_size ⇒ Integer
The fetch size for reading.
-
#initial_extract_date ⇒ DateTime
Date from where extract should start.
-
#last_extract_date ⇒ DateTime
Date last extracted.
Attributes inherited from AbstractReadAttribute
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BiccReadAttributes
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from AbstractReadAttribute
Constructor Details
#initialize(attributes = {}) ⇒ BiccReadAttributes
Initializes the object
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/oci/data_integration/models/bicc_read_attributes.rb', line 76 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['modelType'] = 'BICC_READ_ATTRIBUTE' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.fetch_size = attributes[:'fetchSize'] if attributes[:'fetchSize'] raise 'You cannot provide both :fetchSize and :fetch_size' if attributes.key?(:'fetchSize') && attributes.key?(:'fetch_size') self.fetch_size = attributes[:'fetch_size'] if attributes[:'fetch_size'] self.extract_strategy = attributes[:'extractStrategy'] if attributes[:'extractStrategy'] raise 'You cannot provide both :extractStrategy and :extract_strategy' if attributes.key?(:'extractStrategy') && attributes.key?(:'extract_strategy') self.extract_strategy = attributes[:'extract_strategy'] if attributes[:'extract_strategy'] self.external_storage = attributes[:'externalStorage'] if attributes[:'externalStorage'] raise 'You cannot provide both :externalStorage and :external_storage' if attributes.key?(:'externalStorage') && attributes.key?(:'external_storage') self.external_storage = attributes[:'external_storage'] if attributes[:'external_storage'] self.initial_extract_date = attributes[:'initialExtractDate'] if attributes[:'initialExtractDate'] raise 'You cannot provide both :initialExtractDate and :initial_extract_date' if attributes.key?(:'initialExtractDate') && attributes.key?(:'initial_extract_date') self.initial_extract_date = attributes[:'initial_extract_date'] if attributes[:'initial_extract_date'] self.last_extract_date = attributes[:'lastExtractDate'] if attributes[:'lastExtractDate'] raise 'You cannot provide both :lastExtractDate and :last_extract_date' if attributes.key?(:'lastExtractDate') && attributes.key?(:'last_extract_date') self.last_extract_date = attributes[:'last_extract_date'] if attributes[:'last_extract_date'] end |
Instance Attribute Details
#external_storage ⇒ OCI::DataIntegration::Models::ExternalStorage
27 28 29 |
# File 'lib/oci/data_integration/models/bicc_read_attributes.rb', line 27 def external_storage @external_storage end |
#extract_strategy ⇒ String
Extraction Strategy - FULL|INCREMENTAL
24 25 26 |
# File 'lib/oci/data_integration/models/bicc_read_attributes.rb', line 24 def extract_strategy @extract_strategy end |
#fetch_size ⇒ Integer
The fetch size for reading.
20 21 22 |
# File 'lib/oci/data_integration/models/bicc_read_attributes.rb', line 20 def fetch_size @fetch_size end |
#initial_extract_date ⇒ DateTime
Date from where extract should start
31 32 33 |
# File 'lib/oci/data_integration/models/bicc_read_attributes.rb', line 31 def initial_extract_date @initial_extract_date end |
#last_extract_date ⇒ DateTime
Date last extracted
35 36 37 |
# File 'lib/oci/data_integration/models/bicc_read_attributes.rb', line 35 def last_extract_date @last_extract_date end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
38 39 40 41 42 43 44 45 46 47 48 49 |
# File 'lib/oci/data_integration/models/bicc_read_attributes.rb', line 38 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'fetch_size': :'fetchSize', 'extract_strategy': :'extractStrategy', 'external_storage': :'externalStorage', 'initial_extract_date': :'initialExtractDate', 'last_extract_date': :'lastExtractDate' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/oci/data_integration/models/bicc_read_attributes.rb', line 52 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'fetch_size': :'Integer', 'extract_strategy': :'String', 'external_storage': :'OCI::DataIntegration::Models::ExternalStorage', 'initial_extract_date': :'DateTime', 'last_extract_date': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/oci/data_integration/models/bicc_read_attributes.rb', line 137 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && fetch_size == other.fetch_size && extract_strategy == other.extract_strategy && external_storage == other.external_storage && initial_extract_date == other.initial_extract_date && last_extract_date == other.last_extract_date end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/oci/data_integration/models/bicc_read_attributes.rb', line 172 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
152 153 154 |
# File 'lib/oci/data_integration/models/bicc_read_attributes.rb', line 152 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
161 162 163 |
# File 'lib/oci/data_integration/models/bicc_read_attributes.rb', line 161 def hash [model_type, fetch_size, extract_strategy, external_storage, initial_extract_date, last_extract_date].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
205 206 207 208 209 210 211 212 213 214 |
# File 'lib/oci/data_integration/models/bicc_read_attributes.rb', line 205 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
199 200 201 |
# File 'lib/oci/data_integration/models/bicc_read_attributes.rb', line 199 def to_s to_hash.to_s end |