Class: OCI::DataIntegration::Models::ChildReference

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_integration/models/child_reference.rb

Overview

Child reference contains application configuration information.

Constant Summary collapse

TYPE_ENUM =
[
  TYPE_ORACLEDB_CONNECTION = 'ORACLEDB_CONNECTION'.freeze,
  TYPE_ORACLE_OBJECT_STORAGE_CONNECTION = 'ORACLE_OBJECT_STORAGE_CONNECTION'.freeze,
  TYPE_ORACLE_ATP_CONNECTION = 'ORACLE_ATP_CONNECTION'.freeze,
  TYPE_ORACLE_ADWC_CONNECTION = 'ORACLE_ADWC_CONNECTION'.freeze,
  TYPE_MYSQL_CONNECTION = 'MYSQL_CONNECTION'.freeze,
  TYPE_GENERIC_JDBC_CONNECTION = 'GENERIC_JDBC_CONNECTION'.freeze,
  TYPE_BIP_CONNECTION = 'BIP_CONNECTION'.freeze,
  TYPE_BICC_CONNECTION = 'BICC_CONNECTION'.freeze,
  TYPE_AMAZON_S3_CONNECTION = 'AMAZON_S3_CONNECTION'.freeze,
  TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ChildReference

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :key (String)

    The value to assign to the #key property

  • :name (String)

    The value to assign to the #name property

  • :identifier (String)

    The value to assign to the #identifier property

  • :identifier_path (String)

    The value to assign to the #identifier_path property

  • :description (String)

    The value to assign to the #description property

  • :type (String)

    The value to assign to the #type property

  • :target_object (Object)

    The value to assign to the #target_object property

  • :aggregator_key (String)

    The value to assign to the #aggregator_key property

  • :used_by (Array<OCI::DataIntegration::Models::ReferenceUsedBy>)

    The value to assign to the #used_by property



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'lib/oci/data_integration/models/child_reference.rb', line 109

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.key = attributes[:'key'] if attributes[:'key']

  self.name = attributes[:'name'] if attributes[:'name']

  self.identifier = attributes[:'identifier'] if attributes[:'identifier']

  self.identifier_path = attributes[:'identifierPath'] if attributes[:'identifierPath']

  raise 'You cannot provide both :identifierPath and :identifier_path' if attributes.key?(:'identifierPath') && attributes.key?(:'identifier_path')

  self.identifier_path = attributes[:'identifier_path'] if attributes[:'identifier_path']

  self.description = attributes[:'description'] if attributes[:'description']

  self.type = attributes[:'type'] if attributes[:'type']

  self.target_object = attributes[:'targetObject'] if attributes[:'targetObject']

  raise 'You cannot provide both :targetObject and :target_object' if attributes.key?(:'targetObject') && attributes.key?(:'target_object')

  self.target_object = attributes[:'target_object'] if attributes[:'target_object']

  self.aggregator_key = attributes[:'aggregatorKey'] if attributes[:'aggregatorKey']

  raise 'You cannot provide both :aggregatorKey and :aggregator_key' if attributes.key?(:'aggregatorKey') && attributes.key?(:'aggregator_key')

  self.aggregator_key = attributes[:'aggregator_key'] if attributes[:'aggregator_key']

  self.used_by = attributes[:'usedBy'] if attributes[:'usedBy']

  raise 'You cannot provide both :usedBy and :used_by' if attributes.key?(:'usedBy') && attributes.key?(:'used_by')

  self.used_by = attributes[:'used_by'] if attributes[:'used_by']
end

Instance Attribute Details

#aggregator_keyString

The aggregator key of the child reference object. For example, this can be a data asset key.

Returns:

  • (String)


54
55
56
# File 'lib/oci/data_integration/models/child_reference.rb', line 54

def aggregator_key
  @aggregator_key
end

#descriptionString

The description of reference object.

Returns:

  • (String)


42
43
44
# File 'lib/oci/data_integration/models/child_reference.rb', line 42

def description
  @description
end

#identifierString

The identifier of reference object.

Returns:

  • (String)


34
35
36
# File 'lib/oci/data_integration/models/child_reference.rb', line 34

def identifier
  @identifier
end

#identifier_pathString

The identifier path of reference object.

Returns:

  • (String)


38
39
40
# File 'lib/oci/data_integration/models/child_reference.rb', line 38

def identifier_path
  @identifier_path
end

#keyString

The reference's key, key of the object that is being used by a published object or its dependents.

Returns:

  • (String)


26
27
28
# File 'lib/oci/data_integration/models/child_reference.rb', line 26

def key
  @key
end

#nameString

The name of reference object.

Returns:

  • (String)


30
31
32
# File 'lib/oci/data_integration/models/child_reference.rb', line 30

def name
  @name
end

#target_objectObject

The new reference object to use instead of the original reference. For example, this can be a data asset reference.

Returns:

  • (Object)


50
51
52
# File 'lib/oci/data_integration/models/child_reference.rb', line 50

def target_object
  @target_object
end

#typeString

The type of the reference object.

Returns:

  • (String)


46
47
48
# File 'lib/oci/data_integration/models/child_reference.rb', line 46

def type
  @type
end

#used_byArray<OCI::DataIntegration::Models::ReferenceUsedBy>

List of published objects where this is used.



58
59
60
# File 'lib/oci/data_integration/models/child_reference.rb', line 58

def used_by
  @used_by
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/oci/data_integration/models/child_reference.rb', line 61

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'key',
    'name': :'name',
    'identifier': :'identifier',
    'identifier_path': :'identifierPath',
    'description': :'description',
    'type': :'type',
    'target_object': :'targetObject',
    'aggregator_key': :'aggregatorKey',
    'used_by': :'usedBy'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/oci/data_integration/models/child_reference.rb', line 78

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'String',
    'name': :'String',
    'identifier': :'String',
    'identifier_path': :'String',
    'description': :'String',
    'type': :'String',
    'target_object': :'Object',
    'aggregator_key': :'String',
    'used_by': :'Array<OCI::DataIntegration::Models::ReferenceUsedBy>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/oci/data_integration/models/child_reference.rb', line 170

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    key == other.key &&
    name == other.name &&
    identifier == other.identifier &&
    identifier_path == other.identifier_path &&
    description == other.description &&
    type == other.type &&
    target_object == other.target_object &&
    aggregator_key == other.aggregator_key &&
    used_by == other.used_by
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/oci/data_integration/models/child_reference.rb', line 208

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


188
189
190
# File 'lib/oci/data_integration/models/child_reference.rb', line 188

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



197
198
199
# File 'lib/oci/data_integration/models/child_reference.rb', line 197

def hash
  [key, name, identifier, identifier_path, description, type, target_object, aggregator_key, used_by].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



241
242
243
244
245
246
247
248
249
250
# File 'lib/oci/data_integration/models/child_reference.rb', line 241

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



235
236
237
# File 'lib/oci/data_integration/models/child_reference.rb', line 235

def to_s
  to_hash.to_s
end