Class: OCI::DataIntegration::Models::CompositeType
- Defined in:
- lib/oci/data_integration/models/composite_type.rb
Overview
A CompositeType represents a type that is composed of a list of sub-types, for example an Address type. The sub-types can be simple DataType or other CompositeType objects. Typically, a CompositeType may represent an arbitrarily deep hierarchy of types.
Constant Summary
Constants inherited from BaseType
Instance Attribute Summary collapse
- #config_definition ⇒ OCI::DataIntegration::Models::ConfigDefinition
-
#elements ⇒ Array<OCI::DataIntegration::Models::TypedObject>
An array of elements.
- #parent_type ⇒ OCI::DataIntegration::Models::CompositeType
Attributes inherited from BaseType
#description, #key, #model_type, #model_version, #name, #object_status, #parent_ref
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CompositeType
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from BaseType
Constructor Details
#initialize(attributes = {}) ⇒ CompositeType
Initializes the object
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/oci/data_integration/models/composite_type.rb', line 72 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['modelType'] = 'COMPOSITE_TYPE' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.parent_type = attributes[:'parentType'] if attributes[:'parentType'] raise 'You cannot provide both :parentType and :parent_type' if attributes.key?(:'parentType') && attributes.key?(:'parent_type') self.parent_type = attributes[:'parent_type'] if attributes[:'parent_type'] self.elements = attributes[:'elements'] if attributes[:'elements'] self.config_definition = attributes[:'configDefinition'] if attributes[:'configDefinition'] raise 'You cannot provide both :configDefinition and :config_definition' if attributes.key?(:'configDefinition') && attributes.key?(:'config_definition') self.config_definition = attributes[:'config_definition'] if attributes[:'config_definition'] end |
Instance Attribute Details
#config_definition ⇒ OCI::DataIntegration::Models::ConfigDefinition
19 20 21 |
# File 'lib/oci/data_integration/models/composite_type.rb', line 19 def config_definition @config_definition end |
#elements ⇒ Array<OCI::DataIntegration::Models::TypedObject>
An array of elements.
16 17 18 |
# File 'lib/oci/data_integration/models/composite_type.rb', line 16 def elements @elements end |
#parent_type ⇒ OCI::DataIntegration::Models::CompositeType
12 13 14 |
# File 'lib/oci/data_integration/models/composite_type.rb', line 12 def parent_type @parent_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 |
# File 'lib/oci/data_integration/models/composite_type.rb', line 22 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'key': :'key', 'model_version': :'modelVersion', 'parent_ref': :'parentRef', 'name': :'name', 'object_status': :'objectStatus', 'description': :'description', 'parent_type': :'parentType', 'elements': :'elements', 'config_definition': :'configDefinition' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/oci/data_integration/models/composite_type.rb', line 40 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'key': :'String', 'model_version': :'String', 'parent_ref': :'OCI::DataIntegration::Models::ParentReference', 'name': :'String', 'object_status': :'Integer', 'description': :'String', 'parent_type': :'OCI::DataIntegration::Models::CompositeType', 'elements': :'Array<OCI::DataIntegration::Models::TypedObject>', 'config_definition': :'OCI::DataIntegration::Models::ConfigDefinition' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/oci/data_integration/models/composite_type.rb', line 104 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && key == other.key && model_version == other.model_version && parent_ref == other.parent_ref && name == other.name && object_status == other.object_status && description == other.description && parent_type == other.parent_type && elements == other.elements && config_definition == other.config_definition end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/oci/data_integration/models/composite_type.rb', line 143 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
123 124 125 |
# File 'lib/oci/data_integration/models/composite_type.rb', line 123 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
132 133 134 |
# File 'lib/oci/data_integration/models/composite_type.rb', line 132 def hash [model_type, key, model_version, parent_ref, name, object_status, description, parent_type, elements, config_definition].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
176 177 178 179 180 181 182 183 184 185 |
# File 'lib/oci/data_integration/models/composite_type.rb', line 176 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
170 171 172 |
# File 'lib/oci/data_integration/models/composite_type.rb', line 170 def to_s to_hash.to_s end |