Class: OCI::DataIntegration::Models::ConditionalCompositeFieldMap
- Inherits:
-
FieldMap
- Object
- FieldMap
- OCI::DataIntegration::Models::ConditionalCompositeFieldMap
- Defined in:
- lib/oci/data_integration/models/conditional_composite_field_map.rb
Overview
A conditional composite field map.
Constant Summary
Constants inherited from FieldMap
Instance Attribute Summary collapse
- #config_values ⇒ OCI::DataIntegration::Models::ConfigValues
-
#field_map_scope ⇒ Array<OCI::DataIntegration::Models::ProjectionRule>
An array of projection rules.
-
#field_maps ⇒ Array<OCI::DataIntegration::Models::FieldMap>
An array of field maps.
-
#key ⇒ String
The object key.
-
#model_version ⇒ String
The object's model version.
-
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
- #parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
Attributes inherited from FieldMap
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ConditionalCompositeFieldMap
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from FieldMap
Constructor Details
#initialize(attributes = {}) ⇒ ConditionalCompositeFieldMap
Initializes the object
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/oci/data_integration/models/conditional_composite_field_map.rb', line 85 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['modelType'] = 'CONDITIONAL_COMPOSITE_FIELD_MAP' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.field_map_scope = attributes[:'fieldMapScope'] if attributes[:'fieldMapScope'] raise 'You cannot provide both :fieldMapScope and :field_map_scope' if attributes.key?(:'fieldMapScope') && attributes.key?(:'field_map_scope') self.field_map_scope = attributes[:'field_map_scope'] if attributes[:'field_map_scope'] self.key = attributes[:'key'] if attributes[:'key'] self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion'] raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version') self.model_version = attributes[:'model_version'] if attributes[:'model_version'] self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef'] raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref') self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref'] self.config_values = attributes[:'configValues'] if attributes[:'configValues'] raise 'You cannot provide both :configValues and :config_values' if attributes.key?(:'configValues') && attributes.key?(:'config_values') self.config_values = attributes[:'config_values'] if attributes[:'config_values'] self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus'] raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status') self.object_status = attributes[:'object_status'] if attributes[:'object_status'] self.field_maps = attributes[:'fieldMaps'] if attributes[:'fieldMaps'] raise 'You cannot provide both :fieldMaps and :field_maps' if attributes.key?(:'fieldMaps') && attributes.key?(:'field_maps') self.field_maps = attributes[:'field_maps'] if attributes[:'field_maps'] end |
Instance Attribute Details
#config_values ⇒ OCI::DataIntegration::Models::ConfigValues
27 28 29 |
# File 'lib/oci/data_integration/models/conditional_composite_field_map.rb', line 27 def config_values @config_values end |
#field_map_scope ⇒ Array<OCI::DataIntegration::Models::ProjectionRule>
An array of projection rules.
13 14 15 |
# File 'lib/oci/data_integration/models/conditional_composite_field_map.rb', line 13 def field_map_scope @field_map_scope end |
#field_maps ⇒ Array<OCI::DataIntegration::Models::FieldMap>
An array of field maps.
35 36 37 |
# File 'lib/oci/data_integration/models/conditional_composite_field_map.rb', line 35 def field_maps @field_maps end |
#key ⇒ String
The object key.
17 18 19 |
# File 'lib/oci/data_integration/models/conditional_composite_field_map.rb', line 17 def key @key end |
#model_version ⇒ String
The object's model version.
21 22 23 |
# File 'lib/oci/data_integration/models/conditional_composite_field_map.rb', line 21 def model_version @model_version end |
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
31 32 33 |
# File 'lib/oci/data_integration/models/conditional_composite_field_map.rb', line 31 def object_status @object_status end |
#parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
24 25 26 |
# File 'lib/oci/data_integration/models/conditional_composite_field_map.rb', line 24 def parent_ref @parent_ref end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/oci/data_integration/models/conditional_composite_field_map.rb', line 38 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'description': :'description', 'field_map_scope': :'fieldMapScope', 'key': :'key', 'model_version': :'modelVersion', 'parent_ref': :'parentRef', 'config_values': :'configValues', 'object_status': :'objectStatus', 'field_maps': :'fieldMaps' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/oci/data_integration/models/conditional_composite_field_map.rb', line 55 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'description': :'String', 'field_map_scope': :'Array<OCI::DataIntegration::Models::ProjectionRule>', 'key': :'String', 'model_version': :'String', 'parent_ref': :'OCI::DataIntegration::Models::ParentReference', 'config_values': :'OCI::DataIntegration::Models::ConfigValues', 'object_status': :'Integer', 'field_maps': :'Array<OCI::DataIntegration::Models::FieldMap>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/oci/data_integration/models/conditional_composite_field_map.rb', line 141 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && description == other.description && field_map_scope == other.field_map_scope && key == other.key && model_version == other.model_version && parent_ref == other.parent_ref && config_values == other.config_values && object_status == other.object_status && field_maps == other.field_maps end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/oci/data_integration/models/conditional_composite_field_map.rb', line 179 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
159 160 161 |
# File 'lib/oci/data_integration/models/conditional_composite_field_map.rb', line 159 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
168 169 170 |
# File 'lib/oci/data_integration/models/conditional_composite_field_map.rb', line 168 def hash [model_type, description, field_map_scope, key, model_version, parent_ref, config_values, object_status, field_maps].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
212 213 214 215 216 217 218 219 220 221 |
# File 'lib/oci/data_integration/models/conditional_composite_field_map.rb', line 212 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
206 207 208 |
# File 'lib/oci/data_integration/models/conditional_composite_field_map.rb', line 206 def to_s to_hash.to_s end |