Class: OCI::DataIntegration::Models::ConfigParameterDefinition
- Inherits:
-
Object
- Object
- OCI::DataIntegration::Models::ConfigParameterDefinition
- Defined in:
- lib/oci/data_integration/models/config_parameter_definition.rb
Overview
The configurable properties of an object type.
Instance Attribute Summary collapse
-
#class_field_name ⇒ String
The parameter class field name.
-
#default_value ⇒ Object
The default value for the parameter.
-
#description ⇒ String
A user defined description for the object.
-
#is_class_field_value ⇒ BOOLEAN
Specifies whether the parameter is a class field or not.
-
#is_static ⇒ BOOLEAN
Specifies whether the parameter is static or not.
-
#parameter_name ⇒ String
This object represents the configurable properties for an object type.
- #parameter_type ⇒ OCI::DataIntegration::Models::BaseType
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ConfigParameterDefinition
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ConfigParameterDefinition
Initializes the object
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/oci/data_integration/models/config_parameter_definition.rb', line 80 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.parameter_type = attributes[:'parameterType'] if attributes[:'parameterType'] raise 'You cannot provide both :parameterType and :parameter_type' if attributes.key?(:'parameterType') && attributes.key?(:'parameter_type') self.parameter_type = attributes[:'parameter_type'] if attributes[:'parameter_type'] self.parameter_name = attributes[:'parameterName'] if attributes[:'parameterName'] raise 'You cannot provide both :parameterName and :parameter_name' if attributes.key?(:'parameterName') && attributes.key?(:'parameter_name') self.parameter_name = attributes[:'parameter_name'] if attributes[:'parameter_name'] self.description = attributes[:'description'] if attributes[:'description'] self.default_value = attributes[:'defaultValue'] if attributes[:'defaultValue'] raise 'You cannot provide both :defaultValue and :default_value' if attributes.key?(:'defaultValue') && attributes.key?(:'default_value') self.default_value = attributes[:'default_value'] if attributes[:'default_value'] self.class_field_name = attributes[:'classFieldName'] if attributes[:'classFieldName'] raise 'You cannot provide both :classFieldName and :class_field_name' if attributes.key?(:'classFieldName') && attributes.key?(:'class_field_name') self.class_field_name = attributes[:'class_field_name'] if attributes[:'class_field_name'] self.is_static = attributes[:'isStatic'] unless attributes[:'isStatic'].nil? raise 'You cannot provide both :isStatic and :is_static' if attributes.key?(:'isStatic') && attributes.key?(:'is_static') self.is_static = attributes[:'is_static'] unless attributes[:'is_static'].nil? self.is_class_field_value = attributes[:'isClassFieldValue'] unless attributes[:'isClassFieldValue'].nil? raise 'You cannot provide both :isClassFieldValue and :is_class_field_value' if attributes.key?(:'isClassFieldValue') && attributes.key?(:'is_class_field_value') self.is_class_field_value = attributes[:'is_class_field_value'] unless attributes[:'is_class_field_value'].nil? end |
Instance Attribute Details
#class_field_name ⇒ String
The parameter class field name.
27 28 29 |
# File 'lib/oci/data_integration/models/config_parameter_definition.rb', line 27 def class_field_name @class_field_name end |
#default_value ⇒ Object
The default value for the parameter.
23 24 25 |
# File 'lib/oci/data_integration/models/config_parameter_definition.rb', line 23 def default_value @default_value end |
#description ⇒ String
A user defined description for the object.
19 20 21 |
# File 'lib/oci/data_integration/models/config_parameter_definition.rb', line 19 def description @description end |
#is_class_field_value ⇒ BOOLEAN
Specifies whether the parameter is a class field or not.
35 36 37 |
# File 'lib/oci/data_integration/models/config_parameter_definition.rb', line 35 def is_class_field_value @is_class_field_value end |
#is_static ⇒ BOOLEAN
Specifies whether the parameter is static or not.
31 32 33 |
# File 'lib/oci/data_integration/models/config_parameter_definition.rb', line 31 def is_static @is_static end |
#parameter_name ⇒ String
This object represents the configurable properties for an object type.
15 16 17 |
# File 'lib/oci/data_integration/models/config_parameter_definition.rb', line 15 def parameter_name @parameter_name end |
#parameter_type ⇒ OCI::DataIntegration::Models::BaseType
11 12 13 |
# File 'lib/oci/data_integration/models/config_parameter_definition.rb', line 11 def parameter_type @parameter_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
38 39 40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/oci/data_integration/models/config_parameter_definition.rb', line 38 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'parameter_type': :'parameterType', 'parameter_name': :'parameterName', 'description': :'description', 'default_value': :'defaultValue', 'class_field_name': :'classFieldName', 'is_static': :'isStatic', 'is_class_field_value': :'isClassFieldValue' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/oci/data_integration/models/config_parameter_definition.rb', line 53 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'parameter_type': :'OCI::DataIntegration::Models::BaseType', 'parameter_name': :'String', 'description': :'String', 'default_value': :'Object', 'class_field_name': :'String', 'is_static': :'BOOLEAN', 'is_class_field_value': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/oci/data_integration/models/config_parameter_definition.rb', line 132 def ==(other) return true if equal?(other) self.class == other.class && parameter_type == other.parameter_type && parameter_name == other.parameter_name && description == other.description && default_value == other.default_value && class_field_name == other.class_field_name && is_static == other.is_static && is_class_field_value == other.is_class_field_value end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/oci/data_integration/models/config_parameter_definition.rb', line 168 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
148 149 150 |
# File 'lib/oci/data_integration/models/config_parameter_definition.rb', line 148 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
157 158 159 |
# File 'lib/oci/data_integration/models/config_parameter_definition.rb', line 157 def hash [parameter_type, parameter_name, description, default_value, class_field_name, is_static, is_class_field_value].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
201 202 203 204 205 206 207 208 209 210 |
# File 'lib/oci/data_integration/models/config_parameter_definition.rb', line 201 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
195 196 197 |
# File 'lib/oci/data_integration/models/config_parameter_definition.rb', line 195 def to_s to_hash.to_s end |