Class: OCI::DataIntegration::Models::ConfigParameterValue
- Inherits:
-
Object
- Object
- OCI::DataIntegration::Models::ConfigParameterValue
- Defined in:
- lib/oci/data_integration/models/config_parameter_value.rb
Overview
Contains the parameter configuration values.
Instance Attribute Summary collapse
-
#int_value ⇒ Integer
An integer value of the parameter.
-
#object_value ⇒ Object
An object value of the parameter.
-
#parameter_value ⇒ String
Reference to the parameter by its key.
-
#ref_value ⇒ Object
The root object reference value.
-
#string_value ⇒ String
A string value of the parameter.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ConfigParameterValue
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ConfigParameterValue
Initializes the object
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/oci/data_integration/models/config_parameter_value.rb', line 67 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.string_value = attributes[:'stringValue'] if attributes[:'stringValue'] raise 'You cannot provide both :stringValue and :string_value' if attributes.key?(:'stringValue') && attributes.key?(:'string_value') self.string_value = attributes[:'string_value'] if attributes[:'string_value'] self.int_value = attributes[:'intValue'] if attributes[:'intValue'] raise 'You cannot provide both :intValue and :int_value' if attributes.key?(:'intValue') && attributes.key?(:'int_value') self.int_value = attributes[:'int_value'] if attributes[:'int_value'] self.object_value = attributes[:'objectValue'] if attributes[:'objectValue'] raise 'You cannot provide both :objectValue and :object_value' if attributes.key?(:'objectValue') && attributes.key?(:'object_value') self.object_value = attributes[:'object_value'] if attributes[:'object_value'] self.ref_value = attributes[:'refValue'] if attributes[:'refValue'] raise 'You cannot provide both :refValue and :ref_value' if attributes.key?(:'refValue') && attributes.key?(:'ref_value') self.ref_value = attributes[:'ref_value'] if attributes[:'ref_value'] self.parameter_value = attributes[:'parameterValue'] if attributes[:'parameterValue'] raise 'You cannot provide both :parameterValue and :parameter_value' if attributes.key?(:'parameterValue') && attributes.key?(:'parameter_value') self.parameter_value = attributes[:'parameter_value'] if attributes[:'parameter_value'] end |
Instance Attribute Details
#int_value ⇒ Integer
An integer value of the parameter.
16 17 18 |
# File 'lib/oci/data_integration/models/config_parameter_value.rb', line 16 def int_value @int_value end |
#object_value ⇒ Object
An object value of the parameter.
20 21 22 |
# File 'lib/oci/data_integration/models/config_parameter_value.rb', line 20 def object_value @object_value end |
#parameter_value ⇒ String
Reference to the parameter by its key.
28 29 30 |
# File 'lib/oci/data_integration/models/config_parameter_value.rb', line 28 def parameter_value @parameter_value end |
#ref_value ⇒ Object
The root object reference value.
24 25 26 |
# File 'lib/oci/data_integration/models/config_parameter_value.rb', line 24 def ref_value @ref_value end |
#string_value ⇒ String
A string value of the parameter.
12 13 14 |
# File 'lib/oci/data_integration/models/config_parameter_value.rb', line 12 def string_value @string_value end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 40 41 |
# File 'lib/oci/data_integration/models/config_parameter_value.rb', line 31 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'string_value': :'stringValue', 'int_value': :'intValue', 'object_value': :'objectValue', 'ref_value': :'refValue', 'parameter_value': :'parameterValue' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/oci/data_integration/models/config_parameter_value.rb', line 44 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'string_value': :'String', 'int_value': :'Integer', 'object_value': :'Object', 'ref_value': :'Object', 'parameter_value': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
111 112 113 114 115 116 117 118 119 120 |
# File 'lib/oci/data_integration/models/config_parameter_value.rb', line 111 def ==(other) return true if equal?(other) self.class == other.class && string_value == other.string_value && int_value == other.int_value && object_value == other.object_value && ref_value == other.ref_value && parameter_value == other.parameter_value end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/oci/data_integration/models/config_parameter_value.rb', line 145 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
125 126 127 |
# File 'lib/oci/data_integration/models/config_parameter_value.rb', line 125 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
134 135 136 |
# File 'lib/oci/data_integration/models/config_parameter_value.rb', line 134 def hash [string_value, int_value, object_value, ref_value, parameter_value].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
178 179 180 181 182 183 184 185 186 187 |
# File 'lib/oci/data_integration/models/config_parameter_value.rb', line 178 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
172 173 174 |
# File 'lib/oci/data_integration/models/config_parameter_value.rb', line 172 def to_s to_hash.to_s end |