Class: OCI::DataIntegration::Models::ConfiguredType
- Defined in:
- lib/oci/data_integration/models/configured_type.rb
Overview
A ConfiguredType represents a type that has built-in configuration to the type itself. An example is a SSN type whose basic type is VARCHAR, but the type itself also has a built-in configuration like length=10.
Constant Summary
Constants inherited from BaseType
Instance Attribute Summary collapse
- #config_definition ⇒ OCI::DataIntegration::Models::ConfigDefinition
- #config_values ⇒ OCI::DataIntegration::Models::ConfigValues
-
#wrapped_type ⇒ Object
A wrapped type, may be a string or a BaseType.
Attributes inherited from BaseType
#description, #key, #model_type, #model_version, #name, #object_status, #parent_ref
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ConfiguredType
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from BaseType
Constructor Details
#initialize(attributes = {}) ⇒ ConfiguredType
Initializes the object
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/oci/data_integration/models/configured_type.rb', line 72 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['modelType'] = 'CONFIGURED_TYPE' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.wrapped_type = attributes[:'wrappedType'] if attributes[:'wrappedType'] raise 'You cannot provide both :wrappedType and :wrapped_type' if attributes.key?(:'wrappedType') && attributes.key?(:'wrapped_type') self.wrapped_type = attributes[:'wrapped_type'] if attributes[:'wrapped_type'] self.config_values = attributes[:'configValues'] if attributes[:'configValues'] raise 'You cannot provide both :configValues and :config_values' if attributes.key?(:'configValues') && attributes.key?(:'config_values') self.config_values = attributes[:'config_values'] if attributes[:'config_values'] self.config_definition = attributes[:'configDefinition'] if attributes[:'configDefinition'] raise 'You cannot provide both :configDefinition and :config_definition' if attributes.key?(:'configDefinition') && attributes.key?(:'config_definition') self.config_definition = attributes[:'config_definition'] if attributes[:'config_definition'] end |
Instance Attribute Details
#config_definition ⇒ OCI::DataIntegration::Models::ConfigDefinition
19 20 21 |
# File 'lib/oci/data_integration/models/configured_type.rb', line 19 def config_definition @config_definition end |
#config_values ⇒ OCI::DataIntegration::Models::ConfigValues
16 17 18 |
# File 'lib/oci/data_integration/models/configured_type.rb', line 16 def config_values @config_values end |
#wrapped_type ⇒ Object
A wrapped type, may be a string or a BaseType.
13 14 15 |
# File 'lib/oci/data_integration/models/configured_type.rb', line 13 def wrapped_type @wrapped_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 |
# File 'lib/oci/data_integration/models/configured_type.rb', line 22 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'key': :'key', 'model_version': :'modelVersion', 'parent_ref': :'parentRef', 'name': :'name', 'object_status': :'objectStatus', 'description': :'description', 'wrapped_type': :'wrappedType', 'config_values': :'configValues', 'config_definition': :'configDefinition' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/oci/data_integration/models/configured_type.rb', line 40 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'key': :'String', 'model_version': :'String', 'parent_ref': :'OCI::DataIntegration::Models::ParentReference', 'name': :'String', 'object_status': :'Integer', 'description': :'String', 'wrapped_type': :'Object', 'config_values': :'OCI::DataIntegration::Models::ConfigValues', 'config_definition': :'OCI::DataIntegration::Models::ConfigDefinition' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/oci/data_integration/models/configured_type.rb', line 108 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && key == other.key && model_version == other.model_version && parent_ref == other.parent_ref && name == other.name && object_status == other.object_status && description == other.description && wrapped_type == other.wrapped_type && config_values == other.config_values && config_definition == other.config_definition end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/oci/data_integration/models/configured_type.rb', line 147 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
127 128 129 |
# File 'lib/oci/data_integration/models/configured_type.rb', line 127 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
136 137 138 |
# File 'lib/oci/data_integration/models/configured_type.rb', line 136 def hash [model_type, key, model_version, parent_ref, name, object_status, description, wrapped_type, config_values, config_definition].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
180 181 182 183 184 185 186 187 188 189 |
# File 'lib/oci/data_integration/models/configured_type.rb', line 180 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
174 175 176 |
# File 'lib/oci/data_integration/models/configured_type.rb', line 174 def to_s to_hash.to_s end |