Class: OCI::DataIntegration::Models::Connection
- Inherits:
-
Object
- Object
- OCI::DataIntegration::Models::Connection
- Defined in:
- lib/oci/data_integration/models/connection.rb
Overview
The connection for a data asset. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
ConnectionFromAdwc, ConnectionFromAtp, ConnectionFromJdbc, ConnectionFromMySQL, ConnectionFromObjectStorage, ConnectionFromOracle
Constant Summary collapse
- MODEL_TYPE_ENUM =
[ MODEL_TYPE_ORACLE_ADWC_CONNECTION = 'ORACLE_ADWC_CONNECTION'.freeze, MODEL_TYPE_ORACLE_ATP_CONNECTION = 'ORACLE_ATP_CONNECTION'.freeze, MODEL_TYPE_ORACLE_OBJECT_STORAGE_CONNECTION = 'ORACLE_OBJECT_STORAGE_CONNECTION'.freeze, MODEL_TYPE_ORACLEDB_CONNECTION = 'ORACLEDB_CONNECTION'.freeze, MODEL_TYPE_MYSQL_CONNECTION = 'MYSQL_CONNECTION'.freeze, MODEL_TYPE_GENERIC_JDBC_CONNECTION = 'GENERIC_JDBC_CONNECTION'.freeze, MODEL_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#connection_properties ⇒ Array<OCI::DataIntegration::Models::ConnectionProperty>
The properties for the connection.
-
#description ⇒ String
User-defined description for the connection.
-
#identifier ⇒ String
Value can only contain upper case letters, underscore, and numbers.
-
#is_default ⇒ BOOLEAN
The default property for the connection.
-
#key ⇒ String
Generated key that can be used in API calls to identify connection.
-
#key_map ⇒ Hash<String, String>
A key map.
- #metadata ⇒ OCI::DataIntegration::Models::ObjectMetadata
-
#model_type ⇒ String
[Required] The type of the connection.
-
#model_version ⇒ String
The model version of an object.
-
#name ⇒ String
Free form text without any restriction on permitted characters.
-
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
-
#object_version ⇒ Integer
The version of the object that is used to track changes in the object instance.
- #parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
- #primary_schema ⇒ OCI::DataIntegration::Models::Schema
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Connection
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Connection
Initializes the object
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/oci/data_integration/models/connection.rb', line 159 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.model_type = attributes[:'modelType'] if attributes[:'modelType'] raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type') self.model_type = attributes[:'model_type'] if attributes[:'model_type'] self.key = attributes[:'key'] if attributes[:'key'] self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion'] raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version') self.model_version = attributes[:'model_version'] if attributes[:'model_version'] self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef'] raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref') self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref'] self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.object_version = attributes[:'objectVersion'] if attributes[:'objectVersion'] raise 'You cannot provide both :objectVersion and :object_version' if attributes.key?(:'objectVersion') && attributes.key?(:'object_version') self.object_version = attributes[:'object_version'] if attributes[:'object_version'] self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus'] raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status') self.object_status = attributes[:'object_status'] if attributes[:'object_status'] self.identifier = attributes[:'identifier'] if attributes[:'identifier'] self.primary_schema = attributes[:'primarySchema'] if attributes[:'primarySchema'] raise 'You cannot provide both :primarySchema and :primary_schema' if attributes.key?(:'primarySchema') && attributes.key?(:'primary_schema') self.primary_schema = attributes[:'primary_schema'] if attributes[:'primary_schema'] self.connection_properties = attributes[:'connectionProperties'] if attributes[:'connectionProperties'] raise 'You cannot provide both :connectionProperties and :connection_properties' if attributes.key?(:'connectionProperties') && attributes.key?(:'connection_properties') self.connection_properties = attributes[:'connection_properties'] if attributes[:'connection_properties'] self.is_default = attributes[:'isDefault'] unless attributes[:'isDefault'].nil? self.is_default = false if is_default.nil? && !attributes.key?(:'isDefault') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isDefault and :is_default' if attributes.key?(:'isDefault') && attributes.key?(:'is_default') self.is_default = attributes[:'is_default'] unless attributes[:'is_default'].nil? self.is_default = false if is_default.nil? && !attributes.key?(:'isDefault') && !attributes.key?(:'is_default') # rubocop:disable Style/StringLiterals self. = attributes[:'metadata'] if attributes[:'metadata'] self.key_map = attributes[:'keyMap'] if attributes[:'keyMap'] raise 'You cannot provide both :keyMap and :key_map' if attributes.key?(:'keyMap') && attributes.key?(:'key_map') self.key_map = attributes[:'key_map'] if attributes[:'key_map'] end |
Instance Attribute Details
#connection_properties ⇒ Array<OCI::DataIntegration::Models::ConnectionProperty>
The properties for the connection.
62 63 64 |
# File 'lib/oci/data_integration/models/connection.rb', line 62 def connection_properties @connection_properties end |
#description ⇒ String
User-defined description for the connection.
43 44 45 |
# File 'lib/oci/data_integration/models/connection.rb', line 43 def description @description end |
#identifier ⇒ String
Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.
55 56 57 |
# File 'lib/oci/data_integration/models/connection.rb', line 55 def identifier @identifier end |
#is_default ⇒ BOOLEAN
The default property for the connection.
66 67 68 |
# File 'lib/oci/data_integration/models/connection.rb', line 66 def is_default @is_default end |
#key ⇒ String
Generated key that can be used in API calls to identify connection. On scenarios where reference to the connection is needed, a value can be passed in create.
28 29 30 |
# File 'lib/oci/data_integration/models/connection.rb', line 28 def key @key end |
#key_map ⇒ Hash<String, String>
A key map. If provided, key is replaced with generated key. This structure provides mapping between user provided key and generated key.
73 74 75 |
# File 'lib/oci/data_integration/models/connection.rb', line 73 def key_map @key_map end |
#metadata ⇒ OCI::DataIntegration::Models::ObjectMetadata
69 70 71 |
# File 'lib/oci/data_integration/models/connection.rb', line 69 def end |
#model_type ⇒ String
[Required] The type of the connection.
24 25 26 |
# File 'lib/oci/data_integration/models/connection.rb', line 24 def model_type @model_type end |
#model_version ⇒ String
The model version of an object.
32 33 34 |
# File 'lib/oci/data_integration/models/connection.rb', line 32 def model_version @model_version end |
#name ⇒ String
Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.
39 40 41 |
# File 'lib/oci/data_integration/models/connection.rb', line 39 def name @name end |
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
51 52 53 |
# File 'lib/oci/data_integration/models/connection.rb', line 51 def object_status @object_status end |
#object_version ⇒ Integer
The version of the object that is used to track changes in the object instance.
47 48 49 |
# File 'lib/oci/data_integration/models/connection.rb', line 47 def object_version @object_version end |
#parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
35 36 37 |
# File 'lib/oci/data_integration/models/connection.rb', line 35 def parent_ref @parent_ref end |
#primary_schema ⇒ OCI::DataIntegration::Models::Schema
58 59 60 |
# File 'lib/oci/data_integration/models/connection.rb', line 58 def primary_schema @primary_schema end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/oci/data_integration/models/connection.rb', line 76 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'key': :'key', 'model_version': :'modelVersion', 'parent_ref': :'parentRef', 'name': :'name', 'description': :'description', 'object_version': :'objectVersion', 'object_status': :'objectStatus', 'identifier': :'identifier', 'primary_schema': :'primarySchema', 'connection_properties': :'connectionProperties', 'is_default': :'isDefault', 'metadata': :'metadata', 'key_map': :'keyMap' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/oci/data_integration/models/connection.rb', line 124 def self.get_subtype(object_hash) type = object_hash[:'modelType'] # rubocop:disable Style/SymbolLiteral return 'OCI::DataIntegration::Models::ConnectionFromObjectStorage' if type == 'ORACLE_OBJECT_STORAGE_CONNECTION' return 'OCI::DataIntegration::Models::ConnectionFromAdwc' if type == 'ORACLE_ADWC_CONNECTION' return 'OCI::DataIntegration::Models::ConnectionFromAtp' if type == 'ORACLE_ATP_CONNECTION' return 'OCI::DataIntegration::Models::ConnectionFromOracle' if type == 'ORACLEDB_CONNECTION' return 'OCI::DataIntegration::Models::ConnectionFromMySQL' if type == 'MYSQL_CONNECTION' return 'OCI::DataIntegration::Models::ConnectionFromJdbc' if type == 'GENERIC_JDBC_CONNECTION' # TODO: Log a warning when the subtype is not found. 'OCI::DataIntegration::Models::Connection' end |
.swagger_types ⇒ Object
Attribute type mapping.
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/oci/data_integration/models/connection.rb', line 98 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'key': :'String', 'model_version': :'String', 'parent_ref': :'OCI::DataIntegration::Models::ParentReference', 'name': :'String', 'description': :'String', 'object_version': :'Integer', 'object_status': :'Integer', 'identifier': :'String', 'primary_schema': :'OCI::DataIntegration::Models::Schema', 'connection_properties': :'Array<OCI::DataIntegration::Models::ConnectionProperty>', 'is_default': :'BOOLEAN', 'metadata': :'OCI::DataIntegration::Models::ObjectMetadata', 'key_map': :'Hash<String, String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/oci/data_integration/models/connection.rb', line 252 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && key == other.key && model_version == other.model_version && parent_ref == other.parent_ref && name == other.name && description == other.description && object_version == other.object_version && object_status == other.object_status && identifier == other.identifier && primary_schema == other.primary_schema && connection_properties == other.connection_properties && is_default == other.is_default && == other. && key_map == other.key_map end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/oci/data_integration/models/connection.rb', line 295 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
275 276 277 |
# File 'lib/oci/data_integration/models/connection.rb', line 275 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
284 285 286 |
# File 'lib/oci/data_integration/models/connection.rb', line 284 def hash [model_type, key, model_version, parent_ref, name, description, object_version, object_status, identifier, primary_schema, connection_properties, is_default, , key_map].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
328 329 330 331 332 333 334 335 336 337 |
# File 'lib/oci/data_integration/models/connection.rb', line 328 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
322 323 324 |
# File 'lib/oci/data_integration/models/connection.rb', line 322 def to_s to_hash.to_s end |