Class: OCI::DataIntegration::Models::ConnectionDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_integration/models/connection_details.rb

Overview

The connection details for a data asset. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class

Constant Summary collapse

MODEL_TYPE_ENUM =
[
  MODEL_TYPE_ORACLE_ADWC_CONNECTION = 'ORACLE_ADWC_CONNECTION'.freeze,
  MODEL_TYPE_ORACLE_ATP_CONNECTION = 'ORACLE_ATP_CONNECTION'.freeze,
  MODEL_TYPE_ORACLE_OBJECT_STORAGE_CONNECTION = 'ORACLE_OBJECT_STORAGE_CONNECTION'.freeze,
  MODEL_TYPE_ORACLEDB_CONNECTION = 'ORACLEDB_CONNECTION'.freeze,
  MODEL_TYPE_MYSQL_CONNECTION = 'MYSQL_CONNECTION'.freeze,
  MODEL_TYPE_GENERIC_JDBC_CONNECTION = 'GENERIC_JDBC_CONNECTION'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ConnectionDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/oci/data_integration/models/connection_details.rb', line 150

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.model_type = attributes[:'modelType'] if attributes[:'modelType']

  raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type')

  self.model_type = attributes[:'model_type'] if attributes[:'model_type']

  self.key = attributes[:'key'] if attributes[:'key']

  self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion']

  raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version')

  self.model_version = attributes[:'model_version'] if attributes[:'model_version']

  self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef']

  raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref')

  self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref']

  self.name = attributes[:'name'] if attributes[:'name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.object_version = attributes[:'objectVersion'] if attributes[:'objectVersion']

  raise 'You cannot provide both :objectVersion and :object_version' if attributes.key?(:'objectVersion') && attributes.key?(:'object_version')

  self.object_version = attributes[:'object_version'] if attributes[:'object_version']

  self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus']

  raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status')

  self.object_status = attributes[:'object_status'] if attributes[:'object_status']

  self.identifier = attributes[:'identifier'] if attributes[:'identifier']

  self.primary_schema = attributes[:'primarySchema'] if attributes[:'primarySchema']

  raise 'You cannot provide both :primarySchema and :primary_schema' if attributes.key?(:'primarySchema') && attributes.key?(:'primary_schema')

  self.primary_schema = attributes[:'primary_schema'] if attributes[:'primary_schema']

  self.connection_properties = attributes[:'connectionProperties'] if attributes[:'connectionProperties']

  raise 'You cannot provide both :connectionProperties and :connection_properties' if attributes.key?(:'connectionProperties') && attributes.key?(:'connection_properties')

  self.connection_properties = attributes[:'connection_properties'] if attributes[:'connection_properties']

  self.is_default = attributes[:'isDefault'] unless attributes[:'isDefault'].nil?
  self.is_default = false if is_default.nil? && !attributes.key?(:'isDefault') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isDefault and :is_default' if attributes.key?(:'isDefault') && attributes.key?(:'is_default')

  self.is_default = attributes[:'is_default'] unless attributes[:'is_default'].nil?
  self.is_default = false if is_default.nil? && !attributes.key?(:'isDefault') && !attributes.key?(:'is_default') # rubocop:disable Style/StringLiterals

  self. = attributes[:'metadata'] if attributes[:'metadata']
end

Instance Attribute Details

#connection_propertiesArray<OCI::DataIntegration::Models::ConnectionProperty>

The properties for the connection.



60
61
62
# File 'lib/oci/data_integration/models/connection_details.rb', line 60

def connection_properties
  @connection_properties
end

#descriptionString

User-defined description for the connection.

Returns:

  • (String)


41
42
43
# File 'lib/oci/data_integration/models/connection_details.rb', line 41

def description
  @description
end

#identifierString

Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.

Returns:

  • (String)


53
54
55
# File 'lib/oci/data_integration/models/connection_details.rb', line 53

def identifier
  @identifier
end

#is_defaultBOOLEAN

The default property for the connection.

Returns:

  • (BOOLEAN)


64
65
66
# File 'lib/oci/data_integration/models/connection_details.rb', line 64

def is_default
  @is_default
end

#keyString

Generated key that can be used in API calls to identify connection. On scenarios where reference to the connection is needed, a value can be passed in create.

Returns:

  • (String)


26
27
28
# File 'lib/oci/data_integration/models/connection_details.rb', line 26

def key
  @key
end

#metadataOCI::DataIntegration::Models::ObjectMetadata



67
68
69
# File 'lib/oci/data_integration/models/connection_details.rb', line 67

def 
  
end

#model_typeString

[Required] The type of the connection.

Returns:

  • (String)


22
23
24
# File 'lib/oci/data_integration/models/connection_details.rb', line 22

def model_type
  @model_type
end

#model_versionString

The model version of an object.

Returns:

  • (String)


30
31
32
# File 'lib/oci/data_integration/models/connection_details.rb', line 30

def model_version
  @model_version
end

#nameString

Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.

Returns:

  • (String)


37
38
39
# File 'lib/oci/data_integration/models/connection_details.rb', line 37

def name
  @name
end

#object_statusInteger

The status of an object that can be set to value 1 for shallow references across objects, other values reserved.

Returns:

  • (Integer)


49
50
51
# File 'lib/oci/data_integration/models/connection_details.rb', line 49

def object_status
  @object_status
end

#object_versionInteger

The version of the object that is used to track changes in the object instance.

Returns:

  • (Integer)


45
46
47
# File 'lib/oci/data_integration/models/connection_details.rb', line 45

def object_version
  @object_version
end

#parent_refOCI::DataIntegration::Models::ParentReference



33
34
35
# File 'lib/oci/data_integration/models/connection_details.rb', line 33

def parent_ref
  @parent_ref
end

#primary_schemaOCI::DataIntegration::Models::Schema

Returns:

  • (OCI::DataIntegration::Models::Schema)


56
57
58
# File 'lib/oci/data_integration/models/connection_details.rb', line 56

def primary_schema
  @primary_schema
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/oci/data_integration/models/connection_details.rb', line 70

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'modelType',
    'key': :'key',
    'model_version': :'modelVersion',
    'parent_ref': :'parentRef',
    'name': :'name',
    'description': :'description',
    'object_version': :'objectVersion',
    'object_status': :'objectStatus',
    'identifier': :'identifier',
    'primary_schema': :'primarySchema',
    'connection_properties': :'connectionProperties',
    'is_default': :'isDefault',
    'metadata': :'metadata'
    # rubocop:enable Style/SymbolLiteral
  }
end

.get_subtype(object_hash) ⇒ Object

Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.



116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/oci/data_integration/models/connection_details.rb', line 116

def self.get_subtype(object_hash)
  type = object_hash[:'modelType'] # rubocop:disable Style/SymbolLiteral

  return 'OCI::DataIntegration::Models::ConnectionFromJdbcDetails' if type == 'GENERIC_JDBC_CONNECTION'
  return 'OCI::DataIntegration::Models::ConnectionFromObjectStorageDetails' if type == 'ORACLE_OBJECT_STORAGE_CONNECTION'
  return 'OCI::DataIntegration::Models::ConnectionFromMySQLDetails' if type == 'MYSQL_CONNECTION'
  return 'OCI::DataIntegration::Models::ConnectionFromAdwcDetails' if type == 'ORACLE_ADWC_CONNECTION'
  return 'OCI::DataIntegration::Models::ConnectionFromAtpDetails' if type == 'ORACLE_ATP_CONNECTION'
  return 'OCI::DataIntegration::Models::ConnectionFromOracleDetails' if type == 'ORACLEDB_CONNECTION'

  # TODO: Log a warning when the subtype is not found.
  'OCI::DataIntegration::Models::ConnectionDetails'
end

.swagger_typesObject

Attribute type mapping.



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/oci/data_integration/models/connection_details.rb', line 91

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'String',
    'key': :'String',
    'model_version': :'String',
    'parent_ref': :'OCI::DataIntegration::Models::ParentReference',
    'name': :'String',
    'description': :'String',
    'object_version': :'Integer',
    'object_status': :'Integer',
    'identifier': :'String',
    'primary_schema': :'OCI::DataIntegration::Models::Schema',
    'connection_properties': :'Array<OCI::DataIntegration::Models::ConnectionProperty>',
    'is_default': :'BOOLEAN',
    'metadata': :'OCI::DataIntegration::Models::ObjectMetadata'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/oci/data_integration/models/connection_details.rb', line 232

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    model_type == other.model_type &&
    key == other.key &&
    model_version == other.model_version &&
    parent_ref == other.parent_ref &&
    name == other.name &&
    description == other.description &&
    object_version == other.object_version &&
    object_status == other.object_status &&
    identifier == other.identifier &&
    primary_schema == other.primary_schema &&
    connection_properties == other.connection_properties &&
    is_default == other.is_default &&
     == other.
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
# File 'lib/oci/data_integration/models/connection_details.rb', line 274

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


254
255
256
# File 'lib/oci/data_integration/models/connection_details.rb', line 254

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



263
264
265
# File 'lib/oci/data_integration/models/connection_details.rb', line 263

def hash
  [model_type, key, model_version, parent_ref, name, description, object_version, object_status, identifier, primary_schema, connection_properties, is_default, ].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



307
308
309
310
311
312
313
314
315
316
# File 'lib/oci/data_integration/models/connection_details.rb', line 307

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



301
302
303
# File 'lib/oci/data_integration/models/connection_details.rb', line 301

def to_s
  to_hash.to_s
end