Class: OCI::DataIntegration::Models::ConnectionFromObjectStorageDetails
- Inherits:
-
ConnectionDetails
- Object
- ConnectionDetails
- OCI::DataIntegration::Models::ConnectionFromObjectStorageDetails
- Defined in:
- lib/oci/data_integration/models/connection_from_object_storage_details.rb
Overview
The connection summary details for an Oracle Object Storage data asset.
Constant Summary
Constants inherited from ConnectionDetails
OCI::DataIntegration::Models::ConnectionDetails::MODEL_TYPE_ENUM
Instance Attribute Summary collapse
-
#credential_file_content ⇒ String
The credential file content from an Oracle Object Storage wallet.
-
#finger_print ⇒ String
The fingerprint for the user.
-
#pass_phrase ⇒ String
The passphrase for the connection.
-
#user_id ⇒ String
The OCI user OCID for the user to connect to.
Attributes inherited from ConnectionDetails
#connection_properties, #description, #identifier, #is_default, #key, #metadata, #model_type, #model_version, #name, #object_status, #object_version, #parent_ref, #primary_schema
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ConnectionFromObjectStorageDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from ConnectionDetails
Constructor Details
#initialize(attributes = {}) ⇒ ConnectionFromObjectStorageDetails
Initializes the object
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/oci/data_integration/models/connection_from_object_storage_details.rb', line 99 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['modelType'] = 'ORACLE_OBJECT_STORAGE_CONNECTION' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.credential_file_content = attributes[:'credentialFileContent'] if attributes[:'credentialFileContent'] raise 'You cannot provide both :credentialFileContent and :credential_file_content' if attributes.key?(:'credentialFileContent') && attributes.key?(:'credential_file_content') self.credential_file_content = attributes[:'credential_file_content'] if attributes[:'credential_file_content'] self.user_id = attributes[:'userId'] if attributes[:'userId'] raise 'You cannot provide both :userId and :user_id' if attributes.key?(:'userId') && attributes.key?(:'user_id') self.user_id = attributes[:'user_id'] if attributes[:'user_id'] self.finger_print = attributes[:'fingerPrint'] if attributes[:'fingerPrint'] raise 'You cannot provide both :fingerPrint and :finger_print' if attributes.key?(:'fingerPrint') && attributes.key?(:'finger_print') self.finger_print = attributes[:'finger_print'] if attributes[:'finger_print'] self.pass_phrase = attributes[:'passPhrase'] if attributes[:'passPhrase'] raise 'You cannot provide both :passPhrase and :pass_phrase' if attributes.key?(:'passPhrase') && attributes.key?(:'pass_phrase') self.pass_phrase = attributes[:'pass_phrase'] if attributes[:'pass_phrase'] end |
Instance Attribute Details
#credential_file_content ⇒ String
The credential file content from an Oracle Object Storage wallet.
13 14 15 |
# File 'lib/oci/data_integration/models/connection_from_object_storage_details.rb', line 13 def credential_file_content @credential_file_content end |
#finger_print ⇒ String
The fingerprint for the user.
21 22 23 |
# File 'lib/oci/data_integration/models/connection_from_object_storage_details.rb', line 21 def finger_print @finger_print end |
#pass_phrase ⇒ String
The passphrase for the connection.
25 26 27 |
# File 'lib/oci/data_integration/models/connection_from_object_storage_details.rb', line 25 def pass_phrase @pass_phrase end |
#user_id ⇒ String
The OCI user OCID for the user to connect to.
17 18 19 |
# File 'lib/oci/data_integration/models/connection_from_object_storage_details.rb', line 17 def user_id @user_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/oci/data_integration/models/connection_from_object_storage_details.rb', line 28 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'key': :'key', 'model_version': :'modelVersion', 'parent_ref': :'parentRef', 'name': :'name', 'description': :'description', 'object_version': :'objectVersion', 'object_status': :'objectStatus', 'identifier': :'identifier', 'primary_schema': :'primarySchema', 'connection_properties': :'connectionProperties', 'is_default': :'isDefault', 'metadata': :'metadata', 'credential_file_content': :'credentialFileContent', 'user_id': :'userId', 'finger_print': :'fingerPrint', 'pass_phrase': :'passPhrase' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/oci/data_integration/models/connection_from_object_storage_details.rb', line 53 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'key': :'String', 'model_version': :'String', 'parent_ref': :'OCI::DataIntegration::Models::ParentReference', 'name': :'String', 'description': :'String', 'object_version': :'Integer', 'object_status': :'Integer', 'identifier': :'String', 'primary_schema': :'OCI::DataIntegration::Models::Schema', 'connection_properties': :'Array<OCI::DataIntegration::Models::ConnectionProperty>', 'is_default': :'BOOLEAN', 'metadata': :'OCI::DataIntegration::Models::ObjectMetadata', 'credential_file_content': :'String', 'user_id': :'String', 'finger_print': :'String', 'pass_phrase': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/oci/data_integration/models/connection_from_object_storage_details.rb', line 141 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && key == other.key && model_version == other.model_version && parent_ref == other.parent_ref && name == other.name && description == other.description && object_version == other.object_version && object_status == other.object_status && identifier == other.identifier && primary_schema == other.primary_schema && connection_properties == other.connection_properties && is_default == other.is_default && == other. && credential_file_content == other.credential_file_content && user_id == other.user_id && finger_print == other.finger_print && pass_phrase == other.pass_phrase end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/oci/data_integration/models/connection_from_object_storage_details.rb', line 187 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
167 168 169 |
# File 'lib/oci/data_integration/models/connection_from_object_storage_details.rb', line 167 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
176 177 178 |
# File 'lib/oci/data_integration/models/connection_from_object_storage_details.rb', line 176 def hash [model_type, key, model_version, parent_ref, name, description, object_version, object_status, identifier, primary_schema, connection_properties, is_default, , credential_file_content, user_id, finger_print, pass_phrase].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
220 221 222 223 224 225 226 227 228 229 |
# File 'lib/oci/data_integration/models/connection_from_object_storage_details.rb', line 220 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
214 215 216 |
# File 'lib/oci/data_integration/models/connection_from_object_storage_details.rb', line 214 def to_s to_hash.to_s end |