Class: OCI::DataIntegration::Models::ConnectionSummaryFromAdwc

Inherits:
ConnectionSummary show all
Defined in:
lib/oci/data_integration/models/connection_summary_from_adwc.rb

Overview

The connection summary details for an Autonomous Data Warehouse data asset.

Constant Summary

Constants inherited from ConnectionSummary

OCI::DataIntegration::Models::ConnectionSummary::MODEL_TYPE_ENUM

Instance Attribute Summary collapse

Attributes inherited from ConnectionSummary

#connection_properties, #description, #identifier, #is_default, #key, #key_map, #metadata, #model_type, #model_version, #name, #object_status, #object_version, #parent_ref, #primary_schema

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ConnectionSummary

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ ConnectionSummaryFromAdwc

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/oci/data_integration/models/connection_summary_from_adwc.rb', line 108

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['modelType'] = 'ORACLE_ADWC_CONNECTION'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.tns_alias = attributes[:'tnsAlias'] if attributes[:'tnsAlias']

  raise 'You cannot provide both :tnsAlias and :tns_alias' if attributes.key?(:'tnsAlias') && attributes.key?(:'tns_alias')

  self.tns_alias = attributes[:'tns_alias'] if attributes[:'tns_alias']

  self.tns_names = attributes[:'tnsNames'] if attributes[:'tnsNames']

  raise 'You cannot provide both :tnsNames and :tns_names' if attributes.key?(:'tnsNames') && attributes.key?(:'tns_names')

  self.tns_names = attributes[:'tns_names'] if attributes[:'tns_names']

  self.username = attributes[:'username'] if attributes[:'username']

  self.password = attributes[:'password'] if attributes[:'password']

  self.password_secret = attributes[:'passwordSecret'] if attributes[:'passwordSecret']

  raise 'You cannot provide both :passwordSecret and :password_secret' if attributes.key?(:'passwordSecret') && attributes.key?(:'password_secret')

  self.password_secret = attributes[:'password_secret'] if attributes[:'password_secret']
end

Instance Attribute Details

#passwordString

The password for the connection.

Returns:

  • (String)


25
26
27
# File 'lib/oci/data_integration/models/connection_summary_from_adwc.rb', line 25

def password
  @password
end

#password_secretOCI::DataIntegration::Models::SensitiveAttribute



28
29
30
# File 'lib/oci/data_integration/models/connection_summary_from_adwc.rb', line 28

def password_secret
  @password_secret
end

#tns_aliasString

The Autonomous Data Warehouse instance service name.

Returns:

  • (String)


13
14
15
# File 'lib/oci/data_integration/models/connection_summary_from_adwc.rb', line 13

def tns_alias
  @tns_alias
end

#tns_namesArray<String>

Array of service names that are available for selection in the tnsAlias property.

Returns:

  • (Array<String>)


17
18
19
# File 'lib/oci/data_integration/models/connection_summary_from_adwc.rb', line 17

def tns_names
  @tns_names
end

#usernameString

The user name for the connection.

Returns:

  • (String)


21
22
23
# File 'lib/oci/data_integration/models/connection_summary_from_adwc.rb', line 21

def username
  @username
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/oci/data_integration/models/connection_summary_from_adwc.rb', line 31

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'modelType',
    'key': :'key',
    'model_version': :'modelVersion',
    'parent_ref': :'parentRef',
    'name': :'name',
    'description': :'description',
    'object_version': :'objectVersion',
    'object_status': :'objectStatus',
    'identifier': :'identifier',
    'primary_schema': :'primarySchema',
    'connection_properties': :'connectionProperties',
    'is_default': :'isDefault',
    'metadata': :'metadata',
    'key_map': :'keyMap',
    'tns_alias': :'tnsAlias',
    'tns_names': :'tnsNames',
    'username': :'username',
    'password': :'password',
    'password_secret': :'passwordSecret'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/oci/data_integration/models/connection_summary_from_adwc.rb', line 58

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'String',
    'key': :'String',
    'model_version': :'String',
    'parent_ref': :'OCI::DataIntegration::Models::ParentReference',
    'name': :'String',
    'description': :'String',
    'object_version': :'Integer',
    'object_status': :'Integer',
    'identifier': :'String',
    'primary_schema': :'OCI::DataIntegration::Models::Schema',
    'connection_properties': :'Array<OCI::DataIntegration::Models::ConnectionProperty>',
    'is_default': :'BOOLEAN',
    'metadata': :'OCI::DataIntegration::Models::ObjectMetadata',
    'key_map': :'Hash<String, String>',
    'tns_alias': :'String',
    'tns_names': :'Array<String>',
    'username': :'String',
    'password': :'String',
    'password_secret': :'OCI::DataIntegration::Models::SensitiveAttribute'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/oci/data_integration/models/connection_summary_from_adwc.rb', line 148

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    model_type == other.model_type &&
    key == other.key &&
    model_version == other.model_version &&
    parent_ref == other.parent_ref &&
    name == other.name &&
    description == other.description &&
    object_version == other.object_version &&
    object_status == other.object_status &&
    identifier == other.identifier &&
    primary_schema == other.primary_schema &&
    connection_properties == other.connection_properties &&
    is_default == other.is_default &&
     == other. &&
    key_map == other.key_map &&
    tns_alias == other.tns_alias &&
    tns_names == other.tns_names &&
    username == other.username &&
    password == other.password &&
    password_secret == other.password_secret
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/oci/data_integration/models/connection_summary_from_adwc.rb', line 196

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


176
177
178
# File 'lib/oci/data_integration/models/connection_summary_from_adwc.rb', line 176

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



185
186
187
# File 'lib/oci/data_integration/models/connection_summary_from_adwc.rb', line 185

def hash
  [model_type, key, model_version, parent_ref, name, description, object_version, object_status, identifier, primary_schema, connection_properties, is_default, , key_map, tns_alias, tns_names, username, password, password_secret].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



229
230
231
232
233
234
235
236
237
238
# File 'lib/oci/data_integration/models/connection_summary_from_adwc.rb', line 229

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



223
224
225
# File 'lib/oci/data_integration/models/connection_summary_from_adwc.rb', line 223

def to_s
  to_hash.to_s
end