Class: OCI::DataIntegration::Models::CreateApplicationDetails
- Inherits:
-
Object
- Object
- OCI::DataIntegration::Models::CreateApplicationDetails
- Defined in:
- lib/oci/data_integration/models/create_application_details.rb
Overview
Properties used in application create operations.
Constant Summary collapse
- MODEL_TYPE_ENUM =
[ MODEL_TYPE_INTEGRATION_APPLICATION = 'INTEGRATION_APPLICATION'.freeze ].freeze
Instance Attribute Summary collapse
-
#description ⇒ String
Detailed description for the object.
-
#identifier ⇒ String
[Required] Value can only contain upper case letters, underscore, and numbers.
-
#key ⇒ String
Currently not used on application creation.
-
#model_type ⇒ String
The type of the application.
-
#model_version ⇒ String
The object’s model version.
-
#name ⇒ String
[Required] Free form text without any restriction on permitted characters.
-
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
- #registry_metadata ⇒ OCI::DataIntegration::Models::RegistryMetadata
- #source_application_info ⇒ OCI::DataIntegration::Models::CreateSourceApplicationInfo
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateApplicationDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateApplicationDetails
Initializes the object
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/oci/data_integration/models/create_application_details.rb', line 97 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.key = attributes[:'key'] if attributes[:'key'] self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion'] raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version') self.model_version = attributes[:'model_version'] if attributes[:'model_version'] self.model_type = attributes[:'modelType'] if attributes[:'modelType'] raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type') self.model_type = attributes[:'model_type'] if attributes[:'model_type'] self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus'] raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status') self.object_status = attributes[:'object_status'] if attributes[:'object_status'] self.identifier = attributes[:'identifier'] if attributes[:'identifier'] self.source_application_info = attributes[:'sourceApplicationInfo'] if attributes[:'sourceApplicationInfo'] raise 'You cannot provide both :sourceApplicationInfo and :source_application_info' if attributes.key?(:'sourceApplicationInfo') && attributes.key?(:'source_application_info') self.source_application_info = attributes[:'source_application_info'] if attributes[:'source_application_info'] self. = attributes[:'registryMetadata'] if attributes[:'registryMetadata'] raise 'You cannot provide both :registryMetadata and :registry_metadata' if attributes.key?(:'registryMetadata') && attributes.key?(:'registry_metadata') self. = attributes[:'registry_metadata'] if attributes[:'registry_metadata'] end |
Instance Attribute Details
#description ⇒ String
Detailed description for the object.
32 33 34 |
# File 'lib/oci/data_integration/models/create_application_details.rb', line 32 def description @description end |
#identifier ⇒ String
[Required] Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.
40 41 42 |
# File 'lib/oci/data_integration/models/create_application_details.rb', line 40 def identifier @identifier end |
#key ⇒ String
Currently not used on application creation. Reserved for future.
16 17 18 |
# File 'lib/oci/data_integration/models/create_application_details.rb', line 16 def key @key end |
#model_type ⇒ String
The type of the application.
24 25 26 |
# File 'lib/oci/data_integration/models/create_application_details.rb', line 24 def model_type @model_type end |
#model_version ⇒ String
The object’s model version.
20 21 22 |
# File 'lib/oci/data_integration/models/create_application_details.rb', line 20 def model_version @model_version end |
#name ⇒ String
[Required] Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.
28 29 30 |
# File 'lib/oci/data_integration/models/create_application_details.rb', line 28 def name @name end |
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
36 37 38 |
# File 'lib/oci/data_integration/models/create_application_details.rb', line 36 def object_status @object_status end |
#registry_metadata ⇒ OCI::DataIntegration::Models::RegistryMetadata
46 47 48 |
# File 'lib/oci/data_integration/models/create_application_details.rb', line 46 def @registry_metadata end |
#source_application_info ⇒ OCI::DataIntegration::Models::CreateSourceApplicationInfo
43 44 45 |
# File 'lib/oci/data_integration/models/create_application_details.rb', line 43 def source_application_info @source_application_info end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/oci/data_integration/models/create_application_details.rb', line 49 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'key': :'key', 'model_version': :'modelVersion', 'model_type': :'modelType', 'name': :'name', 'description': :'description', 'object_status': :'objectStatus', 'identifier': :'identifier', 'source_application_info': :'sourceApplicationInfo', 'registry_metadata': :'registryMetadata' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/oci/data_integration/models/create_application_details.rb', line 66 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'key': :'String', 'model_version': :'String', 'model_type': :'String', 'name': :'String', 'description': :'String', 'object_status': :'Integer', 'identifier': :'String', 'source_application_info': :'OCI::DataIntegration::Models::CreateSourceApplicationInfo', 'registry_metadata': :'OCI::DataIntegration::Models::RegistryMetadata' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/oci/data_integration/models/create_application_details.rb', line 157 def ==(other) return true if equal?(other) self.class == other.class && key == other.key && model_version == other.model_version && model_type == other.model_type && name == other.name && description == other.description && object_status == other.object_status && identifier == other.identifier && source_application_info == other.source_application_info && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/oci/data_integration/models/create_application_details.rb', line 195 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
175 176 177 |
# File 'lib/oci/data_integration/models/create_application_details.rb', line 175 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
184 185 186 |
# File 'lib/oci/data_integration/models/create_application_details.rb', line 184 def hash [key, model_version, model_type, name, description, object_status, identifier, source_application_info, ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
228 229 230 231 232 233 234 235 236 237 |
# File 'lib/oci/data_integration/models/create_application_details.rb', line 228 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
222 223 224 |
# File 'lib/oci/data_integration/models/create_application_details.rb', line 222 def to_s to_hash.to_s end |