Class: OCI::DataIntegration::Models::CreateDataAssetFromAdwc
- Inherits:
-
CreateDataAssetDetails
- Object
- CreateDataAssetDetails
- OCI::DataIntegration::Models::CreateDataAssetFromAdwc
- Defined in:
- lib/oci/data_integration/models/create_data_asset_from_adwc.rb
Overview
Details for the Autonomous Data Warehouse data asset type.
Constant Summary
Constants inherited from CreateDataAssetDetails
OCI::DataIntegration::Models::CreateDataAssetDetails::MODEL_TYPE_ENUM
Instance Attribute Summary collapse
-
#credential_file_content ⇒ String
The credential file content from a Autonomous Data Warehouse wallet.
- #default_connection ⇒ OCI::DataIntegration::Models::CreateConnectionFromAdwc
-
#driver_class ⇒ String
The Autonomous Data Warehouse driver class.
-
#service_name ⇒ String
The Autonomous Data Warehouse instance service name.
- #wallet_password_secret ⇒ OCI::DataIntegration::Models::SensitiveAttribute
- #wallet_secret ⇒ OCI::DataIntegration::Models::SensitiveAttribute
Attributes inherited from CreateDataAssetDetails
#asset_properties, #description, #external_key, #identifier, #key, #model_type, #model_version, #name, #object_status, #registry_metadata
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateDataAssetFromAdwc
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from CreateDataAssetDetails
Constructor Details
#initialize(attributes = {}) ⇒ CreateDataAssetFromAdwc
Initializes the object
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/oci/data_integration/models/create_data_asset_from_adwc.rb', line 101 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['modelType'] = 'ORACLE_ADWC_DATA_ASSET' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.service_name = attributes[:'serviceName'] if attributes[:'serviceName'] raise 'You cannot provide both :serviceName and :service_name' if attributes.key?(:'serviceName') && attributes.key?(:'service_name') self.service_name = attributes[:'service_name'] if attributes[:'service_name'] self.driver_class = attributes[:'driverClass'] if attributes[:'driverClass'] raise 'You cannot provide both :driverClass and :driver_class' if attributes.key?(:'driverClass') && attributes.key?(:'driver_class') self.driver_class = attributes[:'driver_class'] if attributes[:'driver_class'] self.credential_file_content = attributes[:'credentialFileContent'] if attributes[:'credentialFileContent'] raise 'You cannot provide both :credentialFileContent and :credential_file_content' if attributes.key?(:'credentialFileContent') && attributes.key?(:'credential_file_content') self.credential_file_content = attributes[:'credential_file_content'] if attributes[:'credential_file_content'] self.wallet_secret = attributes[:'walletSecret'] if attributes[:'walletSecret'] raise 'You cannot provide both :walletSecret and :wallet_secret' if attributes.key?(:'walletSecret') && attributes.key?(:'wallet_secret') self.wallet_secret = attributes[:'wallet_secret'] if attributes[:'wallet_secret'] self.wallet_password_secret = attributes[:'walletPasswordSecret'] if attributes[:'walletPasswordSecret'] raise 'You cannot provide both :walletPasswordSecret and :wallet_password_secret' if attributes.key?(:'walletPasswordSecret') && attributes.key?(:'wallet_password_secret') self.wallet_password_secret = attributes[:'wallet_password_secret'] if attributes[:'wallet_password_secret'] self.default_connection = attributes[:'defaultConnection'] if attributes[:'defaultConnection'] raise 'You cannot provide both :defaultConnection and :default_connection' if attributes.key?(:'defaultConnection') && attributes.key?(:'default_connection') self.default_connection = attributes[:'default_connection'] if attributes[:'default_connection'] end |
Instance Attribute Details
#credential_file_content ⇒ String
The credential file content from a Autonomous Data Warehouse wallet.
21 22 23 |
# File 'lib/oci/data_integration/models/create_data_asset_from_adwc.rb', line 21 def credential_file_content @credential_file_content end |
#default_connection ⇒ OCI::DataIntegration::Models::CreateConnectionFromAdwc
30 31 32 |
# File 'lib/oci/data_integration/models/create_data_asset_from_adwc.rb', line 30 def default_connection @default_connection end |
#driver_class ⇒ String
The Autonomous Data Warehouse driver class.
17 18 19 |
# File 'lib/oci/data_integration/models/create_data_asset_from_adwc.rb', line 17 def driver_class @driver_class end |
#service_name ⇒ String
The Autonomous Data Warehouse instance service name.
13 14 15 |
# File 'lib/oci/data_integration/models/create_data_asset_from_adwc.rb', line 13 def service_name @service_name end |
#wallet_password_secret ⇒ OCI::DataIntegration::Models::SensitiveAttribute
27 28 29 |
# File 'lib/oci/data_integration/models/create_data_asset_from_adwc.rb', line 27 def wallet_password_secret @wallet_password_secret end |
#wallet_secret ⇒ OCI::DataIntegration::Models::SensitiveAttribute
24 25 26 |
# File 'lib/oci/data_integration/models/create_data_asset_from_adwc.rb', line 24 def wallet_secret @wallet_secret end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/oci/data_integration/models/create_data_asset_from_adwc.rb', line 33 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'key': :'key', 'model_version': :'modelVersion', 'name': :'name', 'description': :'description', 'object_status': :'objectStatus', 'identifier': :'identifier', 'external_key': :'externalKey', 'asset_properties': :'assetProperties', 'registry_metadata': :'registryMetadata', 'service_name': :'serviceName', 'driver_class': :'driverClass', 'credential_file_content': :'credentialFileContent', 'wallet_secret': :'walletSecret', 'wallet_password_secret': :'walletPasswordSecret', 'default_connection': :'defaultConnection' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/oci/data_integration/models/create_data_asset_from_adwc.rb', line 57 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'key': :'String', 'model_version': :'String', 'name': :'String', 'description': :'String', 'object_status': :'Integer', 'identifier': :'String', 'external_key': :'String', 'asset_properties': :'Hash<String, String>', 'registry_metadata': :'OCI::DataIntegration::Models::RegistryMetadata', 'service_name': :'String', 'driver_class': :'String', 'credential_file_content': :'String', 'wallet_secret': :'OCI::DataIntegration::Models::SensitiveAttribute', 'wallet_password_secret': :'OCI::DataIntegration::Models::SensitiveAttribute', 'default_connection': :'OCI::DataIntegration::Models::CreateConnectionFromAdwc' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/oci/data_integration/models/create_data_asset_from_adwc.rb', line 155 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && key == other.key && model_version == other.model_version && name == other.name && description == other.description && object_status == other.object_status && identifier == other.identifier && external_key == other.external_key && asset_properties == other.asset_properties && == other. && service_name == other.service_name && driver_class == other.driver_class && credential_file_content == other.credential_file_content && wallet_secret == other.wallet_secret && wallet_password_secret == other.wallet_password_secret && default_connection == other.default_connection end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/oci/data_integration/models/create_data_asset_from_adwc.rb', line 200 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
180 181 182 |
# File 'lib/oci/data_integration/models/create_data_asset_from_adwc.rb', line 180 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
189 190 191 |
# File 'lib/oci/data_integration/models/create_data_asset_from_adwc.rb', line 189 def hash [model_type, key, model_version, name, description, object_status, identifier, external_key, asset_properties, , service_name, driver_class, credential_file_content, wallet_secret, wallet_password_secret, default_connection].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
233 234 235 236 237 238 239 240 241 242 |
# File 'lib/oci/data_integration/models/create_data_asset_from_adwc.rb', line 233 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
227 228 229 |
# File 'lib/oci/data_integration/models/create_data_asset_from_adwc.rb', line 227 def to_s to_hash.to_s end |