Class: OCI::DataIntegration::Models::CreateDataAssetFromOracle
- Inherits:
-
CreateDataAssetDetails
- Object
- CreateDataAssetDetails
- OCI::DataIntegration::Models::CreateDataAssetFromOracle
- Defined in:
- lib/oci/data_integration/models/create_data_asset_from_oracle.rb
Overview
Details for the Oracle Database data asset type.
Constant Summary
Constants inherited from CreateDataAssetDetails
OCI::DataIntegration::Models::CreateDataAssetDetails::MODEL_TYPE_ENUM
Instance Attribute Summary collapse
-
#credential_file_content ⇒ String
The credential file content from a wallet for the data asset.
- #default_connection ⇒ OCI::DataIntegration::Models::CreateConnectionFromOracle
-
#driver_class ⇒ String
The Oracle Database driver class.
-
#host ⇒ String
The Oracle Database hostname.
-
#port ⇒ String
The Oracle Database port.
-
#service_name ⇒ String
The service name for the data asset.
-
#sid ⇒ String
The Oracle Database SID.
- #wallet_password_secret ⇒ OCI::DataIntegration::Models::SensitiveAttribute
- #wallet_secret ⇒ OCI::DataIntegration::Models::SensitiveAttribute
Attributes inherited from CreateDataAssetDetails
#asset_properties, #description, #external_key, #identifier, #key, #model_type, #model_version, #name, #object_status, #registry_metadata
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateDataAssetFromOracle
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from CreateDataAssetDetails
Constructor Details
#initialize(attributes = {}) ⇒ CreateDataAssetFromOracle
Initializes the object
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/oci/data_integration/models/create_data_asset_from_oracle.rb', line 122 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['modelType'] = 'ORACLE_DATA_ASSET' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.host = attributes[:'host'] if attributes[:'host'] self.port = attributes[:'port'] if attributes[:'port'] self.service_name = attributes[:'serviceName'] if attributes[:'serviceName'] raise 'You cannot provide both :serviceName and :service_name' if attributes.key?(:'serviceName') && attributes.key?(:'service_name') self.service_name = attributes[:'service_name'] if attributes[:'service_name'] self.driver_class = attributes[:'driverClass'] if attributes[:'driverClass'] raise 'You cannot provide both :driverClass and :driver_class' if attributes.key?(:'driverClass') && attributes.key?(:'driver_class') self.driver_class = attributes[:'driver_class'] if attributes[:'driver_class'] self.sid = attributes[:'sid'] if attributes[:'sid'] self.credential_file_content = attributes[:'credentialFileContent'] if attributes[:'credentialFileContent'] raise 'You cannot provide both :credentialFileContent and :credential_file_content' if attributes.key?(:'credentialFileContent') && attributes.key?(:'credential_file_content') self.credential_file_content = attributes[:'credential_file_content'] if attributes[:'credential_file_content'] self.wallet_secret = attributes[:'walletSecret'] if attributes[:'walletSecret'] raise 'You cannot provide both :walletSecret and :wallet_secret' if attributes.key?(:'walletSecret') && attributes.key?(:'wallet_secret') self.wallet_secret = attributes[:'wallet_secret'] if attributes[:'wallet_secret'] self.wallet_password_secret = attributes[:'walletPasswordSecret'] if attributes[:'walletPasswordSecret'] raise 'You cannot provide both :walletPasswordSecret and :wallet_password_secret' if attributes.key?(:'walletPasswordSecret') && attributes.key?(:'wallet_password_secret') self.wallet_password_secret = attributes[:'wallet_password_secret'] if attributes[:'wallet_password_secret'] self.default_connection = attributes[:'defaultConnection'] if attributes[:'defaultConnection'] raise 'You cannot provide both :defaultConnection and :default_connection' if attributes.key?(:'defaultConnection') && attributes.key?(:'default_connection') self.default_connection = attributes[:'default_connection'] if attributes[:'default_connection'] end |
Instance Attribute Details
#credential_file_content ⇒ String
The credential file content from a wallet for the data asset.
33 34 35 |
# File 'lib/oci/data_integration/models/create_data_asset_from_oracle.rb', line 33 def credential_file_content @credential_file_content end |
#default_connection ⇒ OCI::DataIntegration::Models::CreateConnectionFromOracle
42 43 44 |
# File 'lib/oci/data_integration/models/create_data_asset_from_oracle.rb', line 42 def default_connection @default_connection end |
#driver_class ⇒ String
The Oracle Database driver class.
25 26 27 |
# File 'lib/oci/data_integration/models/create_data_asset_from_oracle.rb', line 25 def driver_class @driver_class end |
#host ⇒ String
The Oracle Database hostname.
13 14 15 |
# File 'lib/oci/data_integration/models/create_data_asset_from_oracle.rb', line 13 def host @host end |
#port ⇒ String
The Oracle Database port.
17 18 19 |
# File 'lib/oci/data_integration/models/create_data_asset_from_oracle.rb', line 17 def port @port end |
#service_name ⇒ String
The service name for the data asset.
21 22 23 |
# File 'lib/oci/data_integration/models/create_data_asset_from_oracle.rb', line 21 def service_name @service_name end |
#sid ⇒ String
The Oracle Database SID.
29 30 31 |
# File 'lib/oci/data_integration/models/create_data_asset_from_oracle.rb', line 29 def sid @sid end |
#wallet_password_secret ⇒ OCI::DataIntegration::Models::SensitiveAttribute
39 40 41 |
# File 'lib/oci/data_integration/models/create_data_asset_from_oracle.rb', line 39 def wallet_password_secret @wallet_password_secret end |
#wallet_secret ⇒ OCI::DataIntegration::Models::SensitiveAttribute
36 37 38 |
# File 'lib/oci/data_integration/models/create_data_asset_from_oracle.rb', line 36 def wallet_secret @wallet_secret end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/oci/data_integration/models/create_data_asset_from_oracle.rb', line 45 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'key': :'key', 'model_version': :'modelVersion', 'name': :'name', 'description': :'description', 'object_status': :'objectStatus', 'identifier': :'identifier', 'external_key': :'externalKey', 'asset_properties': :'assetProperties', 'registry_metadata': :'registryMetadata', 'host': :'host', 'port': :'port', 'service_name': :'serviceName', 'driver_class': :'driverClass', 'sid': :'sid', 'credential_file_content': :'credentialFileContent', 'wallet_secret': :'walletSecret', 'wallet_password_secret': :'walletPasswordSecret', 'default_connection': :'defaultConnection' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/oci/data_integration/models/create_data_asset_from_oracle.rb', line 72 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'key': :'String', 'model_version': :'String', 'name': :'String', 'description': :'String', 'object_status': :'Integer', 'identifier': :'String', 'external_key': :'String', 'asset_properties': :'Hash<String, String>', 'registry_metadata': :'OCI::DataIntegration::Models::RegistryMetadata', 'host': :'String', 'port': :'String', 'service_name': :'String', 'driver_class': :'String', 'sid': :'String', 'credential_file_content': :'String', 'wallet_secret': :'OCI::DataIntegration::Models::SensitiveAttribute', 'wallet_password_secret': :'OCI::DataIntegration::Models::SensitiveAttribute', 'default_connection': :'OCI::DataIntegration::Models::CreateConnectionFromOracle' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/oci/data_integration/models/create_data_asset_from_oracle.rb', line 182 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && key == other.key && model_version == other.model_version && name == other.name && description == other.description && object_status == other.object_status && identifier == other.identifier && external_key == other.external_key && asset_properties == other.asset_properties && == other. && host == other.host && port == other.port && service_name == other.service_name && driver_class == other.driver_class && sid == other.sid && credential_file_content == other.credential_file_content && wallet_secret == other.wallet_secret && wallet_password_secret == other.wallet_password_secret && default_connection == other.default_connection end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/oci/data_integration/models/create_data_asset_from_oracle.rb', line 230 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
210 211 212 |
# File 'lib/oci/data_integration/models/create_data_asset_from_oracle.rb', line 210 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
219 220 221 |
# File 'lib/oci/data_integration/models/create_data_asset_from_oracle.rb', line 219 def hash [model_type, key, model_version, name, description, object_status, identifier, external_key, asset_properties, , host, port, service_name, driver_class, sid, credential_file_content, wallet_secret, wallet_password_secret, default_connection].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
263 264 265 266 267 268 269 270 271 272 |
# File 'lib/oci/data_integration/models/create_data_asset_from_oracle.rb', line 263 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
257 258 259 |
# File 'lib/oci/data_integration/models/create_data_asset_from_oracle.rb', line 257 def to_s to_hash.to_s end |