Class: OCI::DataIntegration::Models::CreateDisApplicationDetails
- Inherits:
-
Object
- Object
- OCI::DataIntegration::Models::CreateDisApplicationDetails
- Defined in:
- lib/oci/data_integration/models/create_dis_application_details.rb
Overview
Properties used in application create operations.
Constant Summary collapse
- MODEL_TYPE_ENUM =
[ MODEL_TYPE_INTEGRATION_APPLICATION = 'INTEGRATION_APPLICATION'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze ].freeze
Instance Attribute Summary collapse
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
Detailed description for the object.
-
#display_name ⇒ String
Free form text without any restriction on permitted characters.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#identifier ⇒ String
**[Required]** Value can only contain upper case letters, underscore, and numbers.
-
#key ⇒ String
Currently not used on application creation.
-
#lifecycle_state ⇒ String
The current state of the workspace.
-
#model_type ⇒ String
The type of the application.
-
#model_version ⇒ String
The object's model version.
-
#name ⇒ String
**[Required]** Free form text without any restriction on permitted characters.
-
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
- #registry_metadata ⇒ OCI::DataIntegration::Models::RegistryMetadata
- #source_application_info ⇒ OCI::DataIntegration::Models::CreateSourceApplicationInfo
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateDisApplicationDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateDisApplicationDetails
Initializes the object
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/oci/data_integration/models/create_dis_application_details.rb', line 138 def initialize(attributes = {}) return unless attributes.is_a?(Hash) self.key = attributes[:'key'] if attributes[:'key'] self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion'] raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version') self.model_version = attributes[:'model_version'] if attributes[:'model_version'] self.model_type = attributes[:'modelType'] if attributes[:'modelType'] raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type') self.model_type = attributes[:'model_type'] if attributes[:'model_type'] self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus'] raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status') self.object_status = attributes[:'object_status'] if attributes[:'object_status'] self.identifier = attributes[:'identifier'] if attributes[:'identifier'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.source_application_info = attributes[:'sourceApplicationInfo'] if attributes[:'sourceApplicationInfo'] raise 'You cannot provide both :sourceApplicationInfo and :source_application_info' if attributes.key?(:'sourceApplicationInfo') && attributes.key?(:'source_application_info') self.source_application_info = attributes[:'source_application_info'] if attributes[:'source_application_info'] self. = attributes[:'registryMetadata'] if attributes[:'registryMetadata'] raise 'You cannot provide both :registryMetadata and :registry_metadata' if attributes.key?(:'registryMetadata') && attributes.key?(:'registry_metadata') self. = attributes[:'registry_metadata'] if attributes[:'registry_metadata'] end |
Instance Attribute Details
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `{"CostCenter": "42"}`
65 66 67 |
# File 'lib/oci/data_integration/models/create_dis_application_details.rb', line 65 def @defined_tags end |
#description ⇒ String
Detailed description for the object.
41 42 43 |
# File 'lib/oci/data_integration/models/create_dis_application_details.rb', line 41 def description @description end |
#display_name ⇒ String
Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.
53 54 55 |
# File 'lib/oci/data_integration/models/create_dis_application_details.rb', line 53 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `"Finance"`
59 60 61 |
# File 'lib/oci/data_integration/models/create_dis_application_details.rb', line 59 def @freeform_tags end |
#identifier ⇒ String
**[Required]** Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.
49 50 51 |
# File 'lib/oci/data_integration/models/create_dis_application_details.rb', line 49 def identifier @identifier end |
#key ⇒ String
Currently not used on application creation. Reserved for future.
25 26 27 |
# File 'lib/oci/data_integration/models/create_dis_application_details.rb', line 25 def key @key end |
#lifecycle_state ⇒ String
The current state of the workspace.
69 70 71 |
# File 'lib/oci/data_integration/models/create_dis_application_details.rb', line 69 def lifecycle_state @lifecycle_state end |
#model_type ⇒ String
The type of the application.
33 34 35 |
# File 'lib/oci/data_integration/models/create_dis_application_details.rb', line 33 def model_type @model_type end |
#model_version ⇒ String
The object's model version.
29 30 31 |
# File 'lib/oci/data_integration/models/create_dis_application_details.rb', line 29 def model_version @model_version end |
#name ⇒ String
**[Required]** Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.
37 38 39 |
# File 'lib/oci/data_integration/models/create_dis_application_details.rb', line 37 def name @name end |
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
45 46 47 |
# File 'lib/oci/data_integration/models/create_dis_application_details.rb', line 45 def object_status @object_status end |
#registry_metadata ⇒ OCI::DataIntegration::Models::RegistryMetadata
75 76 77 |
# File 'lib/oci/data_integration/models/create_dis_application_details.rb', line 75 def @registry_metadata end |
#source_application_info ⇒ OCI::DataIntegration::Models::CreateSourceApplicationInfo
72 73 74 |
# File 'lib/oci/data_integration/models/create_dis_application_details.rb', line 72 def source_application_info @source_application_info end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/oci/data_integration/models/create_dis_application_details.rb', line 78 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'key': :'key', 'model_version': :'modelVersion', 'model_type': :'modelType', 'name': :'name', 'description': :'description', 'object_status': :'objectStatus', 'identifier': :'identifier', 'display_name': :'displayName', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'lifecycle_state': :'lifecycleState', 'source_application_info': :'sourceApplicationInfo', 'registry_metadata': :'registryMetadata' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/oci/data_integration/models/create_dis_application_details.rb', line 99 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'key': :'String', 'model_version': :'String', 'model_type': :'String', 'name': :'String', 'description': :'String', 'object_status': :'Integer', 'identifier': :'String', 'display_name': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'lifecycle_state': :'String', 'source_application_info': :'OCI::DataIntegration::Models::CreateSourceApplicationInfo', 'registry_metadata': :'OCI::DataIntegration::Models::RegistryMetadata' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/oci/data_integration/models/create_dis_application_details.rb', line 227 def ==(other) return true if equal?(other) self.class == other.class && key == other.key && model_version == other.model_version && model_type == other.model_type && name == other.name && description == other.description && object_status == other.object_status && identifier == other.identifier && display_name == other.display_name && == other. && == other. && lifecycle_state == other.lifecycle_state && source_application_info == other.source_application_info && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'lib/oci/data_integration/models/create_dis_application_details.rb', line 269 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
249 250 251 |
# File 'lib/oci/data_integration/models/create_dis_application_details.rb', line 249 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
258 259 260 |
# File 'lib/oci/data_integration/models/create_dis_application_details.rb', line 258 def hash [key, model_version, model_type, name, description, object_status, identifier, display_name, , , lifecycle_state, source_application_info, ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
302 303 304 305 306 307 308 309 310 311 |
# File 'lib/oci/data_integration/models/create_dis_application_details.rb', line 302 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
296 297 298 |
# File 'lib/oci/data_integration/models/create_dis_application_details.rb', line 296 def to_s to_hash.to_s end |