Class: OCI::DataIntegration::Models::CreateExternalPublicationDetails
- Inherits:
-
Object
- Object
- OCI::DataIntegration::Models::CreateExternalPublicationDetails
- Defined in:
- lib/oci/data_integration/models/create_external_publication_details.rb
Overview
Properties used to publish an Oracle Cloud Infrastructure Data Flow object.
Instance Attribute Summary collapse
-
#application_compartment_id ⇒ String
[Required] The OCID of the compartment where the application is created in the Oracle Cloud Infrastructure Data Flow Service.
-
#application_id ⇒ String
The unique OCID of the identifier that is returned after creating the Oracle Cloud Infrastructure Data Flow application.
- #configuration_details ⇒ OCI::DataIntegration::Models::ConfigurationDetails
-
#description ⇒ String
The details of the data flow or the application.
-
#display_name ⇒ String
[Required] The name of the application.
- #resource_configuration ⇒ OCI::DataIntegration::Models::ResourceConfiguration
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateExternalPublicationDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateExternalPublicationDetails
Initializes the object
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/oci/data_integration/models/create_external_publication_details.rb', line 72 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.application_id = attributes[:'applicationId'] if attributes[:'applicationId'] raise 'You cannot provide both :applicationId and :application_id' if attributes.key?(:'applicationId') && attributes.key?(:'application_id') self.application_id = attributes[:'application_id'] if attributes[:'application_id'] self.application_compartment_id = attributes[:'applicationCompartmentId'] if attributes[:'applicationCompartmentId'] raise 'You cannot provide both :applicationCompartmentId and :application_compartment_id' if attributes.key?(:'applicationCompartmentId') && attributes.key?(:'application_compartment_id') self.application_compartment_id = attributes[:'application_compartment_id'] if attributes[:'application_compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.resource_configuration = attributes[:'resourceConfiguration'] if attributes[:'resourceConfiguration'] raise 'You cannot provide both :resourceConfiguration and :resource_configuration' if attributes.key?(:'resourceConfiguration') && attributes.key?(:'resource_configuration') self.resource_configuration = attributes[:'resource_configuration'] if attributes[:'resource_configuration'] self.configuration_details = attributes[:'configurationDetails'] if attributes[:'configurationDetails'] raise 'You cannot provide both :configurationDetails and :configuration_details' if attributes.key?(:'configurationDetails') && attributes.key?(:'configuration_details') self.configuration_details = attributes[:'configuration_details'] if attributes[:'configuration_details'] end |
Instance Attribute Details
#application_compartment_id ⇒ String
[Required] The OCID of the compartment where the application is created in the Oracle Cloud Infrastructure Data Flow Service.
16 17 18 |
# File 'lib/oci/data_integration/models/create_external_publication_details.rb', line 16 def application_compartment_id @application_compartment_id end |
#application_id ⇒ String
The unique OCID of the identifier that is returned after creating the Oracle Cloud Infrastructure Data Flow application.
12 13 14 |
# File 'lib/oci/data_integration/models/create_external_publication_details.rb', line 12 def application_id @application_id end |
#configuration_details ⇒ OCI::DataIntegration::Models::ConfigurationDetails
30 31 32 |
# File 'lib/oci/data_integration/models/create_external_publication_details.rb', line 30 def configuration_details @configuration_details end |
#description ⇒ String
The details of the data flow or the application.
24 25 26 |
# File 'lib/oci/data_integration/models/create_external_publication_details.rb', line 24 def description @description end |
#display_name ⇒ String
[Required] The name of the application.
20 21 22 |
# File 'lib/oci/data_integration/models/create_external_publication_details.rb', line 20 def display_name @display_name end |
#resource_configuration ⇒ OCI::DataIntegration::Models::ResourceConfiguration
27 28 29 |
# File 'lib/oci/data_integration/models/create_external_publication_details.rb', line 27 def resource_configuration @resource_configuration end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 41 42 43 44 |
# File 'lib/oci/data_integration/models/create_external_publication_details.rb', line 33 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'application_id': :'applicationId', 'application_compartment_id': :'applicationCompartmentId', 'display_name': :'displayName', 'description': :'description', 'resource_configuration': :'resourceConfiguration', 'configuration_details': :'configurationDetails' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/oci/data_integration/models/create_external_publication_details.rb', line 47 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'application_id': :'String', 'application_compartment_id': :'String', 'display_name': :'String', 'description': :'String', 'resource_configuration': :'OCI::DataIntegration::Models::ResourceConfiguration', 'configuration_details': :'OCI::DataIntegration::Models::ConfigurationDetails' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/oci/data_integration/models/create_external_publication_details.rb', line 118 def ==(other) return true if equal?(other) self.class == other.class && application_id == other.application_id && application_compartment_id == other.application_compartment_id && display_name == other.display_name && description == other.description && resource_configuration == other.resource_configuration && configuration_details == other.configuration_details end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/oci/data_integration/models/create_external_publication_details.rb', line 153 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
133 134 135 |
# File 'lib/oci/data_integration/models/create_external_publication_details.rb', line 133 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
142 143 144 |
# File 'lib/oci/data_integration/models/create_external_publication_details.rb', line 142 def hash [application_id, application_compartment_id, display_name, description, resource_configuration, configuration_details].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
186 187 188 189 190 191 192 193 194 195 |
# File 'lib/oci/data_integration/models/create_external_publication_details.rb', line 186 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
180 181 182 |
# File 'lib/oci/data_integration/models/create_external_publication_details.rb', line 180 def to_s to_hash.to_s end |