Class: OCI::DataIntegration::Models::CreateExternalPublicationValidationDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_integration/models/create_external_publication_validation_details.rb

Overview

The task type contains the audit summary information and the definition of the task that is published externally.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateExternalPublicationValidationDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :key (String)

    The value to assign to the #key property



39
40
41
42
43
44
45
46
# File 'lib/oci/data_integration/models/create_external_publication_validation_details.rb', line 39

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.key = attributes[:'key'] if attributes[:'key']
end

Instance Attribute Details

#keyString

Generated key that can be used in API calls to identify the task. On scenarios where reference to the task is needed, a value can be passed in the create operation.

Returns:

  • (String)


12
13
14
# File 'lib/oci/data_integration/models/create_external_publication_validation_details.rb', line 12

def key
  @key
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



15
16
17
18
19
20
21
# File 'lib/oci/data_integration/models/create_external_publication_validation_details.rb', line 15

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'key'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



24
25
26
27
28
29
30
# File 'lib/oci/data_integration/models/create_external_publication_validation_details.rb', line 24

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



55
56
57
58
59
60
# File 'lib/oci/data_integration/models/create_external_publication_validation_details.rb', line 55

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    key == other.key
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/oci/data_integration/models/create_external_publication_validation_details.rb', line 85

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


65
66
67
# File 'lib/oci/data_integration/models/create_external_publication_validation_details.rb', line 65

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



74
75
76
# File 'lib/oci/data_integration/models/create_external_publication_validation_details.rb', line 74

def hash
  [key].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



118
119
120
121
122
123
124
125
126
127
# File 'lib/oci/data_integration/models/create_external_publication_validation_details.rb', line 118

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



112
113
114
# File 'lib/oci/data_integration/models/create_external_publication_validation_details.rb', line 112

def to_s
  to_hash.to_s
end