Class: OCI::DataIntegration::Models::CreatePatchDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_integration/models/create_patch_details.rb

Overview

Properties used in patch create operations.

Constant Summary collapse

PATCH_TYPE_ENUM =
[
  PATCH_TYPE_PUBLISH = 'PUBLISH'.freeze,
  PATCH_TYPE_REFRESH = 'REFRESH'.freeze,
  PATCH_TYPE_UNPUBLISH = 'UNPUBLISH'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreatePatchDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/oci/data_integration/models/create_patch_details.rb', line 100

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.key = attributes[:'key'] if attributes[:'key']

  self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion']

  raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version')

  self.model_version = attributes[:'model_version'] if attributes[:'model_version']

  self.name = attributes[:'name'] if attributes[:'name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus']

  raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status')

  self.object_status = attributes[:'object_status'] if attributes[:'object_status']

  self.identifier = attributes[:'identifier'] if attributes[:'identifier']

  self.patch_type = attributes[:'patchType'] if attributes[:'patchType']

  raise 'You cannot provide both :patchType and :patch_type' if attributes.key?(:'patchType') && attributes.key?(:'patch_type')

  self.patch_type = attributes[:'patch_type'] if attributes[:'patch_type']

  self.object_keys = attributes[:'objectKeys'] if attributes[:'objectKeys']

  raise 'You cannot provide both :objectKeys and :object_keys' if attributes.key?(:'objectKeys') && attributes.key?(:'object_keys')

  self.object_keys = attributes[:'object_keys'] if attributes[:'object_keys']

  self. = attributes[:'registryMetadata'] if attributes[:'registryMetadata']

  raise 'You cannot provide both :registryMetadata and :registry_metadata' if attributes.key?(:'registryMetadata') && attributes.key?(:'registry_metadata')

  self. = attributes[:'registry_metadata'] if attributes[:'registry_metadata']
end

Instance Attribute Details

#descriptionString

Detailed description for the object.

Returns:

  • (String)


30
31
32
# File 'lib/oci/data_integration/models/create_patch_details.rb', line 30

def description
  @description
end

#identifierString

[Required] Value can only contain upper case letters, underscore and numbers. It should begin with upper case letter or underscore. The value can be modified.

Returns:

  • (String)


38
39
40
# File 'lib/oci/data_integration/models/create_patch_details.rb', line 38

def identifier
  @identifier
end

#keyString

The object’s key.

Returns:

  • (String)


18
19
20
# File 'lib/oci/data_integration/models/create_patch_details.rb', line 18

def key
  @key
end

#model_versionString

The object’s model version.

Returns:

  • (String)


22
23
24
# File 'lib/oci/data_integration/models/create_patch_details.rb', line 22

def model_version
  @model_version
end

#nameString

[Required] Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.

Returns:

  • (String)


26
27
28
# File 'lib/oci/data_integration/models/create_patch_details.rb', line 26

def name
  @name
end

#object_keysArray<String>

[Required] The array of object keys to publish into application.

Returns:

  • (Array<String>)


46
47
48
# File 'lib/oci/data_integration/models/create_patch_details.rb', line 46

def object_keys
  @object_keys
end

#object_statusInteger

The status of an object that can be set to value 1 for shallow references across objects, other values reserved.

Returns:

  • (Integer)


34
35
36
# File 'lib/oci/data_integration/models/create_patch_details.rb', line 34

def object_status
  @object_status
end

#patch_typeString

[Required] The type of the patch applied or being applied on the application.

Returns:

  • (String)


42
43
44
# File 'lib/oci/data_integration/models/create_patch_details.rb', line 42

def patch_type
  @patch_type
end

#registry_metadataOCI::DataIntegration::Models::RegistryMetadata



49
50
51
# File 'lib/oci/data_integration/models/create_patch_details.rb', line 49

def 
  @registry_metadata
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/oci/data_integration/models/create_patch_details.rb', line 52

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'key',
    'model_version': :'modelVersion',
    'name': :'name',
    'description': :'description',
    'object_status': :'objectStatus',
    'identifier': :'identifier',
    'patch_type': :'patchType',
    'object_keys': :'objectKeys',
    'registry_metadata': :'registryMetadata'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/oci/data_integration/models/create_patch_details.rb', line 69

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'String',
    'model_version': :'String',
    'name': :'String',
    'description': :'String',
    'object_status': :'Integer',
    'identifier': :'String',
    'patch_type': :'String',
    'object_keys': :'Array<String>',
    'registry_metadata': :'OCI::DataIntegration::Models::RegistryMetadata'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/oci/data_integration/models/create_patch_details.rb', line 160

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    key == other.key &&
    model_version == other.model_version &&
    name == other.name &&
    description == other.description &&
    object_status == other.object_status &&
    identifier == other.identifier &&
    patch_type == other.patch_type &&
    object_keys == other.object_keys &&
     == other.
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/oci/data_integration/models/create_patch_details.rb', line 198

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


178
179
180
# File 'lib/oci/data_integration/models/create_patch_details.rb', line 178

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



187
188
189
# File 'lib/oci/data_integration/models/create_patch_details.rb', line 187

def hash
  [key, model_version, name, description, object_status, identifier, patch_type, object_keys, ].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



231
232
233
234
235
236
237
238
239
240
# File 'lib/oci/data_integration/models/create_patch_details.rb', line 231

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



225
226
227
# File 'lib/oci/data_integration/models/create_patch_details.rb', line 225

def to_s
  to_hash.to_s
end