Class: OCI::DataIntegration::Models::CreateSourceApplicationInfo
- Inherits:
-
Object
- Object
- OCI::DataIntegration::Models::CreateSourceApplicationInfo
- Defined in:
- lib/oci/data_integration/models/create_source_application_info.rb
Overview
The information about the application.
Instance Attribute Summary collapse
-
#application_key ⇒ String
The source application key to use when creating the application.
-
#workspace_id ⇒ String
The OCID of the workspace containing the application.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateSourceApplicationInfo
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateSourceApplicationInfo
Initializes the object
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/oci/data_integration/models/create_source_application_info.rb', line 46 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.workspace_id = attributes[:'workspaceId'] if attributes[:'workspaceId'] raise 'You cannot provide both :workspaceId and :workspace_id' if attributes.key?(:'workspaceId') && attributes.key?(:'workspace_id') self.workspace_id = attributes[:'workspace_id'] if attributes[:'workspace_id'] self.application_key = attributes[:'applicationKey'] if attributes[:'applicationKey'] raise 'You cannot provide both :applicationKey and :application_key' if attributes.key?(:'applicationKey') && attributes.key?(:'application_key') self.application_key = attributes[:'application_key'] if attributes[:'application_key'] end |
Instance Attribute Details
#application_key ⇒ String
The source application key to use when creating the application.
16 17 18 |
# File 'lib/oci/data_integration/models/create_source_application_info.rb', line 16 def application_key @application_key end |
#workspace_id ⇒ String
The OCID of the workspace containing the application. This allows cross workspace deployment to publish an application from a different workspace into the current workspace specified in this operation.
12 13 14 |
# File 'lib/oci/data_integration/models/create_source_application_info.rb', line 12 def workspace_id @workspace_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
19 20 21 22 23 24 25 26 |
# File 'lib/oci/data_integration/models/create_source_application_info.rb', line 19 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'workspace_id': :'workspaceId', 'application_key': :'applicationKey' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
29 30 31 32 33 34 35 36 |
# File 'lib/oci/data_integration/models/create_source_application_info.rb', line 29 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'workspace_id': :'String', 'application_key': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
72 73 74 75 76 77 78 |
# File 'lib/oci/data_integration/models/create_source_application_info.rb', line 72 def ==(other) return true if equal?(other) self.class == other.class && workspace_id == other.workspace_id && application_key == other.application_key end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/oci/data_integration/models/create_source_application_info.rb', line 103 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
83 84 85 |
# File 'lib/oci/data_integration/models/create_source_application_info.rb', line 83 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
92 93 94 |
# File 'lib/oci/data_integration/models/create_source_application_info.rb', line 92 def hash [workspace_id, application_key].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
136 137 138 139 140 141 142 143 144 145 |
# File 'lib/oci/data_integration/models/create_source_application_info.rb', line 136 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
130 131 132 |
# File 'lib/oci/data_integration/models/create_source_application_info.rb', line 130 def to_s to_hash.to_s end |