Class: OCI::DataIntegration::Models::CreateTaskRunDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_integration/models/create_task_run_details.rb

Overview

The properties used in task run create operations.

Constant Summary collapse

RE_RUN_TYPE_ENUM =
[
  RE_RUN_TYPE_BEGINNING = 'BEGINNING'.freeze,
  RE_RUN_TYPE_FAILED = 'FAILED'.freeze,
  RE_RUN_TYPE_STEP = 'STEP'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateTaskRunDetails

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 120

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.key = attributes[:'key'] if attributes[:'key']

  self.model_type = attributes[:'modelType'] if attributes[:'modelType']

  raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type')

  self.model_type = attributes[:'model_type'] if attributes[:'model_type']

  self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion']

  raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version')

  self.model_version = attributes[:'model_version'] if attributes[:'model_version']

  self.name = attributes[:'name'] if attributes[:'name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.config_provider = attributes[:'configProvider'] if attributes[:'configProvider']

  raise 'You cannot provide both :configProvider and :config_provider' if attributes.key?(:'configProvider') && attributes.key?(:'config_provider')

  self.config_provider = attributes[:'config_provider'] if attributes[:'config_provider']

  self.identifier = attributes[:'identifier'] if attributes[:'identifier']

  self.task_schedule_key = attributes[:'taskScheduleKey'] if attributes[:'taskScheduleKey']

  raise 'You cannot provide both :taskScheduleKey and :task_schedule_key' if attributes.key?(:'taskScheduleKey') && attributes.key?(:'task_schedule_key')

  self.task_schedule_key = attributes[:'task_schedule_key'] if attributes[:'task_schedule_key']

  self.ref_task_run_id = attributes[:'refTaskRunId'] if attributes[:'refTaskRunId']

  raise 'You cannot provide both :refTaskRunId and :ref_task_run_id' if attributes.key?(:'refTaskRunId') && attributes.key?(:'ref_task_run_id')

  self.ref_task_run_id = attributes[:'ref_task_run_id'] if attributes[:'ref_task_run_id']

  self.re_run_type = attributes[:'reRunType'] if attributes[:'reRunType']

  raise 'You cannot provide both :reRunType and :re_run_type' if attributes.key?(:'reRunType') && attributes.key?(:'re_run_type')

  self.re_run_type = attributes[:'re_run_type'] if attributes[:'re_run_type']

  self.step_id = attributes[:'stepId'] if attributes[:'stepId']

  raise 'You cannot provide both :stepId and :step_id' if attributes.key?(:'stepId') && attributes.key?(:'step_id')

  self.step_id = attributes[:'step_id'] if attributes[:'step_id']

  self. = attributes[:'registryMetadata'] if attributes[:'registryMetadata']

  raise 'You cannot provide both :registryMetadata and :registry_metadata' if attributes.key?(:'registryMetadata') && attributes.key?(:'registry_metadata')

  self. = attributes[:'registry_metadata'] if attributes[:'registry_metadata']
end

Instance Attribute Details

#config_providerOCI::DataIntegration::Models::CreateConfigProvider

Returns:



37
38
39
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 37

def config_provider
  @config_provider
end

#descriptionString

Detailed description for the object.

Returns:



34
35
36
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 34

def description
  @description
end

#identifierString

Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.

Returns:



41
42
43
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 41

def identifier
  @identifier
end

#keyString

The key of the object.

Returns:



18
19
20
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 18

def key
  @key
end

#model_typeString

The type of the object.

Returns:



22
23
24
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 22

def model_type
  @model_type
end

#model_versionString

The model version of an object.

Returns:



26
27
28
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 26

def model_version
  @model_version
end

#nameString

Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.

Returns:



30
31
32
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 30

def name
  @name
end

#re_run_typeString

Supported re-run types

Returns:



53
54
55
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 53

def re_run_type
  @re_run_type
end

#ref_task_run_idString

Reference Task Run Id to be used for re-run

Returns:



49
50
51
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 49

def ref_task_run_id
  @ref_task_run_id
end

#registry_metadataOCI::DataIntegration::Models::RegistryMetadata

Returns:



60
61
62
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 60

def 
  
end

#step_idString

Step Id for running from a certain step.

Returns:



57
58
59
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 57

def step_id
  @step_id
end

#task_schedule_keyString

Optional task schedule key reference.

Returns:



45
46
47
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 45

def task_schedule_key
  @task_schedule_key
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 63

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'key',
    'model_type': :'modelType',
    'model_version': :'modelVersion',
    'name': :'name',
    'description': :'description',
    'config_provider': :'configProvider',
    'identifier': :'identifier',
    'task_schedule_key': :'taskScheduleKey',
    'ref_task_run_id': :'refTaskRunId',
    're_run_type': :'reRunType',
    'step_id': :'stepId',
    'registry_metadata': :'registryMetadata'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 83

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'String',
    'model_type': :'String',
    'model_version': :'String',
    'name': :'String',
    'description': :'String',
    'config_provider': :'OCI::DataIntegration::Models::CreateConfigProvider',
    'identifier': :'String',
    'task_schedule_key': :'String',
    'ref_task_run_id': :'String',
    're_run_type': :'String',
    'step_id': :'String',
    'registry_metadata': :'OCI::DataIntegration::Models::RegistryMetadata'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • the other object to be compared



198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 198

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    key == other.key &&
    model_type == other.model_type &&
    model_version == other.model_version &&
    name == other.name &&
    description == other.description &&
    config_provider == other.config_provider &&
    identifier == other.identifier &&
    task_schedule_key == other.task_schedule_key &&
    ref_task_run_id == other.ref_task_run_id &&
    re_run_type == other.re_run_type &&
    step_id == other.step_id &&
     == other.
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 239

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • the other object to be compared

Returns:

See Also:

  • `==` method


219
220
221
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 219

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • Hash code



228
229
230
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 228

def hash
  [key, model_type, model_version, name, description, config_provider, identifier, task_schedule_key, ref_task_run_id, re_run_type, step_id, ].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



272
273
274
275
276
277
278
279
280
281
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 272

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



266
267
268
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 266

def to_s
  to_hash.to_s
end