Class: OCI::DataIntegration::Models::CreateTaskScheduleDetails
- Inherits:
-
Object
- Object
- OCI::DataIntegration::Models::CreateTaskScheduleDetails
- Defined in:
- lib/oci/data_integration/models/create_task_schedule_details.rb
Overview
The create task details.
Constant Summary collapse
- RETRY_DELAY_UNIT_ENUM =
[ RETRY_DELAY_UNIT_SECONDS = 'SECONDS'.freeze, RETRY_DELAY_UNIT_MINUTES = 'MINUTES'.freeze, RETRY_DELAY_UNIT_HOURS = 'HOURS'.freeze, RETRY_DELAY_UNIT_DAYS = 'DAYS'.freeze ].freeze
- AUTH_MODE_ENUM =
[ AUTH_MODE_OBO = 'OBO'.freeze, AUTH_MODE_RESOURCE_PRINCIPAL = 'RESOURCE_PRINCIPAL'.freeze, AUTH_MODE_USER_CERTIFICATE = 'USER_CERTIFICATE'.freeze ].freeze
- EXPECTED_DURATION_UNIT_ENUM =
[ EXPECTED_DURATION_UNIT_SECONDS = 'SECONDS'.freeze, EXPECTED_DURATION_UNIT_MINUTES = 'MINUTES'.freeze, EXPECTED_DURATION_UNIT_HOURS = 'HOURS'.freeze, EXPECTED_DURATION_UNIT_DAYS = 'DAYS'.freeze ].freeze
Instance Attribute Summary collapse
-
#auth_mode ⇒ String
The authorization mode for the task.
- #config_provider_delegate ⇒ OCI::DataIntegration::Models::ConfigProvider
-
#description ⇒ String
Detailed description for the object.
-
#end_time_millis ⇒ Integer
The end time in milliseconds.
-
#expected_duration ⇒ Float
The expected duration of the task execution.
-
#expected_duration_unit ⇒ String
The expected duration unit of the task execution.
-
#identifier ⇒ String
[Required] Value can only contain upper case letters, underscore, and numbers.
-
#is_backfill_enabled ⇒ BOOLEAN
Whether the backfill is enabled.
-
#is_concurrent_allowed ⇒ BOOLEAN
Whether the same task can be executed concurrently.
-
#is_enabled ⇒ BOOLEAN
Whether the task schedule is enabled.
-
#key ⇒ String
Generated key that can be used in API calls to identify taskSchedule.
-
#model_version ⇒ String
This is a version number that is used by the service to upgrade objects if needed through releases of the service.
-
#name ⇒ String
[Required] Free form text without any restriction on permitted characters.
-
#number_of_retries ⇒ Integer
The number of retries.
-
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
-
#object_version ⇒ Integer
This is used by the service for optimistic locking of the object, to prevent multiple users from simultaneously updating the object.
- #parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
- #registry_metadata ⇒ OCI::DataIntegration::Models::RegistryMetadata
-
#retry_delay ⇒ Float
The retry delay, the unit for measurement is in the property retry delay unit.
-
#retry_delay_unit ⇒ String
The unit for the retry delay.
- #schedule_ref ⇒ OCI::DataIntegration::Models::Schedule
-
#start_time_millis ⇒ Integer
The start time in milliseconds.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateTaskScheduleDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateTaskScheduleDetails
Initializes the object
202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'lib/oci/data_integration/models/create_task_schedule_details.rb', line 202 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.key = attributes[:'key'] if attributes[:'key'] self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion'] raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version') self.model_version = attributes[:'model_version'] if attributes[:'model_version'] self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef'] raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref') self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref'] self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.object_version = attributes[:'objectVersion'] if attributes[:'objectVersion'] raise 'You cannot provide both :objectVersion and :object_version' if attributes.key?(:'objectVersion') && attributes.key?(:'object_version') self.object_version = attributes[:'object_version'] if attributes[:'object_version'] self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus'] raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status') self.object_status = attributes[:'object_status'] if attributes[:'object_status'] self.identifier = attributes[:'identifier'] if attributes[:'identifier'] self.schedule_ref = attributes[:'scheduleRef'] if attributes[:'scheduleRef'] raise 'You cannot provide both :scheduleRef and :schedule_ref' if attributes.key?(:'scheduleRef') && attributes.key?(:'schedule_ref') self.schedule_ref = attributes[:'schedule_ref'] if attributes[:'schedule_ref'] self.config_provider_delegate = attributes[:'configProviderDelegate'] if attributes[:'configProviderDelegate'] raise 'You cannot provide both :configProviderDelegate and :config_provider_delegate' if attributes.key?(:'configProviderDelegate') && attributes.key?(:'config_provider_delegate') self.config_provider_delegate = attributes[:'config_provider_delegate'] if attributes[:'config_provider_delegate'] self.is_enabled = attributes[:'isEnabled'] unless attributes[:'isEnabled'].nil? raise 'You cannot provide both :isEnabled and :is_enabled' if attributes.key?(:'isEnabled') && attributes.key?(:'is_enabled') self.is_enabled = attributes[:'is_enabled'] unless attributes[:'is_enabled'].nil? self.number_of_retries = attributes[:'numberOfRetries'] if attributes[:'numberOfRetries'] raise 'You cannot provide both :numberOfRetries and :number_of_retries' if attributes.key?(:'numberOfRetries') && attributes.key?(:'number_of_retries') self.number_of_retries = attributes[:'number_of_retries'] if attributes[:'number_of_retries'] self.retry_delay = attributes[:'retryDelay'] if attributes[:'retryDelay'] raise 'You cannot provide both :retryDelay and :retry_delay' if attributes.key?(:'retryDelay') && attributes.key?(:'retry_delay') self.retry_delay = attributes[:'retry_delay'] if attributes[:'retry_delay'] self.retry_delay_unit = attributes[:'retryDelayUnit'] if attributes[:'retryDelayUnit'] raise 'You cannot provide both :retryDelayUnit and :retry_delay_unit' if attributes.key?(:'retryDelayUnit') && attributes.key?(:'retry_delay_unit') self.retry_delay_unit = attributes[:'retry_delay_unit'] if attributes[:'retry_delay_unit'] self.start_time_millis = attributes[:'startTimeMillis'] if attributes[:'startTimeMillis'] raise 'You cannot provide both :startTimeMillis and :start_time_millis' if attributes.key?(:'startTimeMillis') && attributes.key?(:'start_time_millis') self.start_time_millis = attributes[:'start_time_millis'] if attributes[:'start_time_millis'] self.end_time_millis = attributes[:'endTimeMillis'] if attributes[:'endTimeMillis'] raise 'You cannot provide both :endTimeMillis and :end_time_millis' if attributes.key?(:'endTimeMillis') && attributes.key?(:'end_time_millis') self.end_time_millis = attributes[:'end_time_millis'] if attributes[:'end_time_millis'] self.is_concurrent_allowed = attributes[:'isConcurrentAllowed'] unless attributes[:'isConcurrentAllowed'].nil? self.is_concurrent_allowed = true if is_concurrent_allowed.nil? && !attributes.key?(:'isConcurrentAllowed') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isConcurrentAllowed and :is_concurrent_allowed' if attributes.key?(:'isConcurrentAllowed') && attributes.key?(:'is_concurrent_allowed') self.is_concurrent_allowed = attributes[:'is_concurrent_allowed'] unless attributes[:'is_concurrent_allowed'].nil? self.is_concurrent_allowed = true if is_concurrent_allowed.nil? && !attributes.key?(:'isConcurrentAllowed') && !attributes.key?(:'is_concurrent_allowed') # rubocop:disable Style/StringLiterals self.is_backfill_enabled = attributes[:'isBackfillEnabled'] unless attributes[:'isBackfillEnabled'].nil? self.is_backfill_enabled = false if is_backfill_enabled.nil? && !attributes.key?(:'isBackfillEnabled') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isBackfillEnabled and :is_backfill_enabled' if attributes.key?(:'isBackfillEnabled') && attributes.key?(:'is_backfill_enabled') self.is_backfill_enabled = attributes[:'is_backfill_enabled'] unless attributes[:'is_backfill_enabled'].nil? self.is_backfill_enabled = false if is_backfill_enabled.nil? && !attributes.key?(:'isBackfillEnabled') && !attributes.key?(:'is_backfill_enabled') # rubocop:disable Style/StringLiterals self.auth_mode = attributes[:'authMode'] if attributes[:'authMode'] raise 'You cannot provide both :authMode and :auth_mode' if attributes.key?(:'authMode') && attributes.key?(:'auth_mode') self.auth_mode = attributes[:'auth_mode'] if attributes[:'auth_mode'] self.expected_duration = attributes[:'expectedDuration'] if attributes[:'expectedDuration'] raise 'You cannot provide both :expectedDuration and :expected_duration' if attributes.key?(:'expectedDuration') && attributes.key?(:'expected_duration') self.expected_duration = attributes[:'expected_duration'] if attributes[:'expected_duration'] self.expected_duration_unit = attributes[:'expectedDurationUnit'] if attributes[:'expectedDurationUnit'] raise 'You cannot provide both :expectedDurationUnit and :expected_duration_unit' if attributes.key?(:'expectedDurationUnit') && attributes.key?(:'expected_duration_unit') self.expected_duration_unit = attributes[:'expected_duration_unit'] if attributes[:'expected_duration_unit'] self. = attributes[:'registryMetadata'] if attributes[:'registryMetadata'] raise 'You cannot provide both :registryMetadata and :registry_metadata' if attributes.key?(:'registryMetadata') && attributes.key?(:'registry_metadata') self. = attributes[:'registry_metadata'] if attributes[:'registry_metadata'] end |
Instance Attribute Details
#auth_mode ⇒ String
The authorization mode for the task.
101 102 103 |
# File 'lib/oci/data_integration/models/create_task_schedule_details.rb', line 101 def auth_mode @auth_mode end |
#config_provider_delegate ⇒ OCI::DataIntegration::Models::ConfigProvider
65 66 67 |
# File 'lib/oci/data_integration/models/create_task_schedule_details.rb', line 65 def config_provider_delegate @config_provider_delegate end |
#description ⇒ String
Detailed description for the object.
47 48 49 |
# File 'lib/oci/data_integration/models/create_task_schedule_details.rb', line 47 def description @description end |
#end_time_millis ⇒ Integer
The end time in milliseconds.
89 90 91 |
# File 'lib/oci/data_integration/models/create_task_schedule_details.rb', line 89 def end_time_millis @end_time_millis end |
#expected_duration ⇒ Float
The expected duration of the task execution.
105 106 107 |
# File 'lib/oci/data_integration/models/create_task_schedule_details.rb', line 105 def expected_duration @expected_duration end |
#expected_duration_unit ⇒ String
The expected duration unit of the task execution.
109 110 111 |
# File 'lib/oci/data_integration/models/create_task_schedule_details.rb', line 109 def expected_duration_unit @expected_duration_unit end |
#identifier ⇒ String
[Required] Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.
59 60 61 |
# File 'lib/oci/data_integration/models/create_task_schedule_details.rb', line 59 def identifier @identifier end |
#is_backfill_enabled ⇒ BOOLEAN
Whether the backfill is enabled.
97 98 99 |
# File 'lib/oci/data_integration/models/create_task_schedule_details.rb', line 97 def is_backfill_enabled @is_backfill_enabled end |
#is_concurrent_allowed ⇒ BOOLEAN
Whether the same task can be executed concurrently.
93 94 95 |
# File 'lib/oci/data_integration/models/create_task_schedule_details.rb', line 93 def is_concurrent_allowed @is_concurrent_allowed end |
#is_enabled ⇒ BOOLEAN
Whether the task schedule is enabled.
69 70 71 |
# File 'lib/oci/data_integration/models/create_task_schedule_details.rb', line 69 def is_enabled @is_enabled end |
#key ⇒ String
Generated key that can be used in API calls to identify taskSchedule. On scenarios where reference to the taskSchedule is needed, a value can be passed in create.
32 33 34 |
# File 'lib/oci/data_integration/models/create_task_schedule_details.rb', line 32 def key @key end |
#model_version ⇒ String
This is a version number that is used by the service to upgrade objects if needed through releases of the service.
36 37 38 |
# File 'lib/oci/data_integration/models/create_task_schedule_details.rb', line 36 def model_version @model_version end |
#name ⇒ String
[Required] Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.
43 44 45 |
# File 'lib/oci/data_integration/models/create_task_schedule_details.rb', line 43 def name @name end |
#number_of_retries ⇒ Integer
The number of retries.
73 74 75 |
# File 'lib/oci/data_integration/models/create_task_schedule_details.rb', line 73 def number_of_retries @number_of_retries end |
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
55 56 57 |
# File 'lib/oci/data_integration/models/create_task_schedule_details.rb', line 55 def object_status @object_status end |
#object_version ⇒ Integer
This is used by the service for optimistic locking of the object, to prevent multiple users from simultaneously updating the object.
51 52 53 |
# File 'lib/oci/data_integration/models/create_task_schedule_details.rb', line 51 def object_version @object_version end |
#parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
39 40 41 |
# File 'lib/oci/data_integration/models/create_task_schedule_details.rb', line 39 def parent_ref @parent_ref end |
#registry_metadata ⇒ OCI::DataIntegration::Models::RegistryMetadata
112 113 114 |
# File 'lib/oci/data_integration/models/create_task_schedule_details.rb', line 112 def @registry_metadata end |
#retry_delay ⇒ Float
The retry delay, the unit for measurement is in the property retry delay unit.
77 78 79 |
# File 'lib/oci/data_integration/models/create_task_schedule_details.rb', line 77 def retry_delay @retry_delay end |
#retry_delay_unit ⇒ String
The unit for the retry delay.
81 82 83 |
# File 'lib/oci/data_integration/models/create_task_schedule_details.rb', line 81 def retry_delay_unit @retry_delay_unit end |
#schedule_ref ⇒ OCI::DataIntegration::Models::Schedule
62 63 64 |
# File 'lib/oci/data_integration/models/create_task_schedule_details.rb', line 62 def schedule_ref @schedule_ref end |
#start_time_millis ⇒ Integer
The start time in milliseconds.
85 86 87 |
# File 'lib/oci/data_integration/models/create_task_schedule_details.rb', line 85 def start_time_millis @start_time_millis end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/oci/data_integration/models/create_task_schedule_details.rb', line 115 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'key': :'key', 'model_version': :'modelVersion', 'parent_ref': :'parentRef', 'name': :'name', 'description': :'description', 'object_version': :'objectVersion', 'object_status': :'objectStatus', 'identifier': :'identifier', 'schedule_ref': :'scheduleRef', 'config_provider_delegate': :'configProviderDelegate', 'is_enabled': :'isEnabled', 'number_of_retries': :'numberOfRetries', 'retry_delay': :'retryDelay', 'retry_delay_unit': :'retryDelayUnit', 'start_time_millis': :'startTimeMillis', 'end_time_millis': :'endTimeMillis', 'is_concurrent_allowed': :'isConcurrentAllowed', 'is_backfill_enabled': :'isBackfillEnabled', 'auth_mode': :'authMode', 'expected_duration': :'expectedDuration', 'expected_duration_unit': :'expectedDurationUnit', 'registry_metadata': :'registryMetadata' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/oci/data_integration/models/create_task_schedule_details.rb', line 145 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'key': :'String', 'model_version': :'String', 'parent_ref': :'OCI::DataIntegration::Models::ParentReference', 'name': :'String', 'description': :'String', 'object_version': :'Integer', 'object_status': :'Integer', 'identifier': :'String', 'schedule_ref': :'OCI::DataIntegration::Models::Schedule', 'config_provider_delegate': :'OCI::DataIntegration::Models::ConfigProvider', 'is_enabled': :'BOOLEAN', 'number_of_retries': :'Integer', 'retry_delay': :'Float', 'retry_delay_unit': :'String', 'start_time_millis': :'Integer', 'end_time_millis': :'Integer', 'is_concurrent_allowed': :'BOOLEAN', 'is_backfill_enabled': :'BOOLEAN', 'auth_mode': :'String', 'expected_duration': :'Float', 'expected_duration_unit': :'String', 'registry_metadata': :'OCI::DataIntegration::Models::RegistryMetadata' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 |
# File 'lib/oci/data_integration/models/create_task_schedule_details.rb', line 360 def ==(other) return true if equal?(other) self.class == other.class && key == other.key && model_version == other.model_version && parent_ref == other.parent_ref && name == other.name && description == other.description && object_version == other.object_version && object_status == other.object_status && identifier == other.identifier && schedule_ref == other.schedule_ref && config_provider_delegate == other.config_provider_delegate && is_enabled == other.is_enabled && number_of_retries == other.number_of_retries && retry_delay == other.retry_delay && retry_delay_unit == other.retry_delay_unit && start_time_millis == other.start_time_millis && end_time_millis == other.end_time_millis && is_concurrent_allowed == other.is_concurrent_allowed && is_backfill_enabled == other.is_backfill_enabled && auth_mode == other.auth_mode && expected_duration == other.expected_duration && expected_duration_unit == other.expected_duration_unit && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 |
# File 'lib/oci/data_integration/models/create_task_schedule_details.rb', line 411 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
391 392 393 |
# File 'lib/oci/data_integration/models/create_task_schedule_details.rb', line 391 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
400 401 402 |
# File 'lib/oci/data_integration/models/create_task_schedule_details.rb', line 400 def hash [key, model_version, parent_ref, name, description, object_version, object_status, identifier, schedule_ref, config_provider_delegate, is_enabled, number_of_retries, retry_delay, retry_delay_unit, start_time_millis, end_time_millis, is_concurrent_allowed, is_backfill_enabled, auth_mode, expected_duration, expected_duration_unit, ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
444 445 446 447 448 449 450 451 452 453 |
# File 'lib/oci/data_integration/models/create_task_schedule_details.rb', line 444 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
438 439 440 |
# File 'lib/oci/data_integration/models/create_task_schedule_details.rb', line 438 def to_s to_hash.to_s end |