Class: OCI::DataIntegration::Models::CreateTaskValidationDetails
- Inherits:
-
Object
- Object
- OCI::DataIntegration::Models::CreateTaskValidationDetails
- Defined in:
- lib/oci/data_integration/models/create_task_validation_details.rb
Overview
The task type contains the audit summary information and the definition of the task. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
CreateTaskValidationFromDataLoaderTask, CreateTaskValidationFromIntegrationTask
Constant Summary collapse
- MODEL_TYPE_ENUM =
[ MODEL_TYPE_INTEGRATION_TASK = 'INTEGRATION_TASK'.freeze, MODEL_TYPE_DATA_LOADER_TASK = 'DATA_LOADER_TASK'.freeze ].freeze
Instance Attribute Summary collapse
- #config_provider_delegate ⇒ OCI::DataIntegration::Models::ConfigProvider
-
#description ⇒ String
Detailed description for the object.
-
#identifier ⇒ String
Value can only contain upper case letters, underscore and numbers.
-
#input_ports ⇒ Array<OCI::DataIntegration::Models::InputPort>
An array of input ports.
-
#key ⇒ String
Generated key that can be used in API calls to identify task.
- #metadata ⇒ OCI::DataIntegration::Models::ObjectMetadata
-
#model_type ⇒ String
The type of the task.
-
#model_version ⇒ String
The model version of an object.
-
#name ⇒ String
Free form text without any restriction on permitted characters.
-
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
-
#object_version ⇒ Integer
The version of the object that is used to track changes in the object instance.
- #op_config_values ⇒ OCI::DataIntegration::Models::ConfigValues
-
#output_ports ⇒ Array<OCI::DataIntegration::Models::OutputPort>
An array of output ports.
-
#parameters ⇒ Array<OCI::DataIntegration::Models::Parameter>
An array of parameters.
- #parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateTaskValidationDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateTaskValidationDetails
Initializes the object
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/oci/data_integration/models/create_task_validation_details.rb', line 155 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.model_type = attributes[:'modelType'] if attributes[:'modelType'] raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type') self.model_type = attributes[:'model_type'] if attributes[:'model_type'] self.key = attributes[:'key'] if attributes[:'key'] self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion'] raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version') self.model_version = attributes[:'model_version'] if attributes[:'model_version'] self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef'] raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref') self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref'] self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.object_version = attributes[:'objectVersion'] if attributes[:'objectVersion'] raise 'You cannot provide both :objectVersion and :object_version' if attributes.key?(:'objectVersion') && attributes.key?(:'object_version') self.object_version = attributes[:'object_version'] if attributes[:'object_version'] self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus'] raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status') self.object_status = attributes[:'object_status'] if attributes[:'object_status'] self.identifier = attributes[:'identifier'] if attributes[:'identifier'] self.input_ports = attributes[:'inputPorts'] if attributes[:'inputPorts'] raise 'You cannot provide both :inputPorts and :input_ports' if attributes.key?(:'inputPorts') && attributes.key?(:'input_ports') self.input_ports = attributes[:'input_ports'] if attributes[:'input_ports'] self.output_ports = attributes[:'outputPorts'] if attributes[:'outputPorts'] raise 'You cannot provide both :outputPorts and :output_ports' if attributes.key?(:'outputPorts') && attributes.key?(:'output_ports') self.output_ports = attributes[:'output_ports'] if attributes[:'output_ports'] self.parameters = attributes[:'parameters'] if attributes[:'parameters'] self.op_config_values = attributes[:'opConfigValues'] if attributes[:'opConfigValues'] raise 'You cannot provide both :opConfigValues and :op_config_values' if attributes.key?(:'opConfigValues') && attributes.key?(:'op_config_values') self.op_config_values = attributes[:'op_config_values'] if attributes[:'op_config_values'] self.config_provider_delegate = attributes[:'configProviderDelegate'] if attributes[:'configProviderDelegate'] raise 'You cannot provide both :configProviderDelegate and :config_provider_delegate' if attributes.key?(:'configProviderDelegate') && attributes.key?(:'config_provider_delegate') self.config_provider_delegate = attributes[:'config_provider_delegate'] if attributes[:'config_provider_delegate'] self. = attributes[:'metadata'] if attributes[:'metadata'] end |
Instance Attribute Details
#config_provider_delegate ⇒ OCI::DataIntegration::Models::ConfigProvider
67 68 69 |
# File 'lib/oci/data_integration/models/create_task_validation_details.rb', line 67 def config_provider_delegate @config_provider_delegate end |
#description ⇒ String
Detailed description for the object.
37 38 39 |
# File 'lib/oci/data_integration/models/create_task_validation_details.rb', line 37 def description @description end |
#identifier ⇒ String
Value can only contain upper case letters, underscore and numbers. It should begin with upper case letter or underscore. The value can be modified.
49 50 51 |
# File 'lib/oci/data_integration/models/create_task_validation_details.rb', line 49 def identifier @identifier end |
#input_ports ⇒ Array<OCI::DataIntegration::Models::InputPort>
An array of input ports.
53 54 55 |
# File 'lib/oci/data_integration/models/create_task_validation_details.rb', line 53 def input_ports @input_ports end |
#key ⇒ String
Generated key that can be used in API calls to identify task. On scenarios where reference to the task is needed, a value can be passed in the create operation.
22 23 24 |
# File 'lib/oci/data_integration/models/create_task_validation_details.rb', line 22 def key @key end |
#metadata ⇒ OCI::DataIntegration::Models::ObjectMetadata
70 71 72 |
# File 'lib/oci/data_integration/models/create_task_validation_details.rb', line 70 def @metadata end |
#model_type ⇒ String
The type of the task.
18 19 20 |
# File 'lib/oci/data_integration/models/create_task_validation_details.rb', line 18 def model_type @model_type end |
#model_version ⇒ String
The model version of an object.
26 27 28 |
# File 'lib/oci/data_integration/models/create_task_validation_details.rb', line 26 def model_version @model_version end |
#name ⇒ String
Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.
33 34 35 |
# File 'lib/oci/data_integration/models/create_task_validation_details.rb', line 33 def name @name end |
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
45 46 47 |
# File 'lib/oci/data_integration/models/create_task_validation_details.rb', line 45 def object_status @object_status end |
#object_version ⇒ Integer
The version of the object that is used to track changes in the object instance.
41 42 43 |
# File 'lib/oci/data_integration/models/create_task_validation_details.rb', line 41 def object_version @object_version end |
#op_config_values ⇒ OCI::DataIntegration::Models::ConfigValues
64 65 66 |
# File 'lib/oci/data_integration/models/create_task_validation_details.rb', line 64 def op_config_values @op_config_values end |
#output_ports ⇒ Array<OCI::DataIntegration::Models::OutputPort>
An array of output ports.
57 58 59 |
# File 'lib/oci/data_integration/models/create_task_validation_details.rb', line 57 def output_ports @output_ports end |
#parameters ⇒ Array<OCI::DataIntegration::Models::Parameter>
An array of parameters.
61 62 63 |
# File 'lib/oci/data_integration/models/create_task_validation_details.rb', line 61 def parameters @parameters end |
#parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
29 30 31 |
# File 'lib/oci/data_integration/models/create_task_validation_details.rb', line 29 def parent_ref @parent_ref end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/oci/data_integration/models/create_task_validation_details.rb', line 73 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'key': :'key', 'model_version': :'modelVersion', 'parent_ref': :'parentRef', 'name': :'name', 'description': :'description', 'object_version': :'objectVersion', 'object_status': :'objectStatus', 'identifier': :'identifier', 'input_ports': :'inputPorts', 'output_ports': :'outputPorts', 'parameters': :'parameters', 'op_config_values': :'opConfigValues', 'config_provider_delegate': :'configProviderDelegate', 'metadata': :'metadata' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
123 124 125 126 127 128 129 130 131 |
# File 'lib/oci/data_integration/models/create_task_validation_details.rb', line 123 def self.get_subtype(object_hash) type = object_hash[:'modelType'] # rubocop:disable Style/SymbolLiteral return 'OCI::DataIntegration::Models::CreateTaskValidationFromDataLoaderTask' if type == 'DATA_LOADER_TASK' return 'OCI::DataIntegration::Models::CreateTaskValidationFromIntegrationTask' if type == 'INTEGRATION_TASK' # TODO: Log a warning when the subtype is not found. 'OCI::DataIntegration::Models::CreateTaskValidationDetails' end |
.swagger_types ⇒ Object
Attribute type mapping.
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/oci/data_integration/models/create_task_validation_details.rb', line 96 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'key': :'String', 'model_version': :'String', 'parent_ref': :'OCI::DataIntegration::Models::ParentReference', 'name': :'String', 'description': :'String', 'object_version': :'Integer', 'object_status': :'Integer', 'identifier': :'String', 'input_ports': :'Array<OCI::DataIntegration::Models::InputPort>', 'output_ports': :'Array<OCI::DataIntegration::Models::OutputPort>', 'parameters': :'Array<OCI::DataIntegration::Models::Parameter>', 'op_config_values': :'OCI::DataIntegration::Models::ConfigValues', 'config_provider_delegate': :'OCI::DataIntegration::Models::ConfigProvider', 'metadata': :'OCI::DataIntegration::Models::ObjectMetadata' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 |
# File 'lib/oci/data_integration/models/create_task_validation_details.rb', line 243 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && key == other.key && model_version == other.model_version && parent_ref == other.parent_ref && name == other.name && description == other.description && object_version == other.object_version && object_status == other.object_status && identifier == other.identifier && input_ports == other.input_ports && output_ports == other.output_ports && parameters == other.parameters && op_config_values == other.op_config_values && config_provider_delegate == other.config_provider_delegate && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 |
# File 'lib/oci/data_integration/models/create_task_validation_details.rb', line 287 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
267 268 269 |
# File 'lib/oci/data_integration/models/create_task_validation_details.rb', line 267 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
276 277 278 |
# File 'lib/oci/data_integration/models/create_task_validation_details.rb', line 276 def hash [model_type, key, model_version, parent_ref, name, description, object_version, object_status, identifier, input_ports, output_ports, parameters, op_config_values, config_provider_delegate, ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
320 321 322 323 324 325 326 327 328 329 |
# File 'lib/oci/data_integration/models/create_task_validation_details.rb', line 320 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
314 315 316 |
# File 'lib/oci/data_integration/models/create_task_validation_details.rb', line 314 def to_s to_hash.to_s end |