Class: OCI::DataIntegration::Models::CreateWorkspaceDetails
- Inherits:
-
Object
- Object
- OCI::DataIntegration::Models::CreateWorkspaceDetails
- Defined in:
- lib/oci/data_integration/models/create_workspace_details.rb
Overview
The information needed to create a new workspace.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The OCID of the compartment containing the workspace.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
A user defined description for the workspace.
-
#display_name ⇒ String
[Required] A user-friendly display name for the workspace.
-
#dns_server_ip ⇒ String
The IP of the custom DNS.
-
#dns_server_zone ⇒ String
The DNS zone of the custom DNS to use to resolve names.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#is_private_network_enabled ⇒ BOOLEAN
Specifies whether the private network connection is enabled or disabled.
-
#subnet_id ⇒ String
The OCID of the subnet for customer connected databases.
-
#vcn_id ⇒ String
The OCID of the VCN the subnet is in.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateWorkspaceDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateWorkspaceDetails
Initializes the object
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/oci/data_integration/models/create_workspace_details.rb', line 106 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.vcn_id = attributes[:'vcnId'] if attributes[:'vcnId'] raise 'You cannot provide both :vcnId and :vcn_id' if attributes.key?(:'vcnId') && attributes.key?(:'vcn_id') self.vcn_id = attributes[:'vcn_id'] if attributes[:'vcn_id'] self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId'] raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id') self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id'] self.dns_server_ip = attributes[:'dnsServerIp'] if attributes[:'dnsServerIp'] raise 'You cannot provide both :dnsServerIp and :dns_server_ip' if attributes.key?(:'dnsServerIp') && attributes.key?(:'dns_server_ip') self.dns_server_ip = attributes[:'dns_server_ip'] if attributes[:'dns_server_ip'] self.dns_server_zone = attributes[:'dnsServerZone'] if attributes[:'dnsServerZone'] raise 'You cannot provide both :dnsServerZone and :dns_server_zone' if attributes.key?(:'dnsServerZone') && attributes.key?(:'dns_server_zone') self.dns_server_zone = attributes[:'dns_server_zone'] if attributes[:'dns_server_zone'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.description = attributes[:'description'] if attributes[:'description'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.is_private_network_enabled = attributes[:'isPrivateNetworkEnabled'] unless attributes[:'isPrivateNetworkEnabled'].nil? self.is_private_network_enabled = false if is_private_network_enabled.nil? && !attributes.key?(:'isPrivateNetworkEnabled') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isPrivateNetworkEnabled and :is_private_network_enabled' if attributes.key?(:'isPrivateNetworkEnabled') && attributes.key?(:'is_private_network_enabled') self.is_private_network_enabled = attributes[:'is_private_network_enabled'] unless attributes[:'is_private_network_enabled'].nil? self.is_private_network_enabled = false if is_private_network_enabled.nil? && !attributes.key?(:'isPrivateNetworkEnabled') && !attributes.key?(:'is_private_network_enabled') # rubocop:disable Style/StringLiterals end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The OCID of the compartment containing the workspace.
48 49 50 |
# File 'lib/oci/data_integration/models/create_workspace_details.rb', line 48 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"CostCenter": "42"}`
36 37 38 |
# File 'lib/oci/data_integration/models/create_workspace_details.rb', line 36 def end |
#description ⇒ String
A user defined description for the workspace.
40 41 42 |
# File 'lib/oci/data_integration/models/create_workspace_details.rb', line 40 def description @description end |
#display_name ⇒ String
[Required] A user-friendly display name for the workspace. Does not have to be unique, and can be modified. Avoid entering confidential information.
44 45 46 |
# File 'lib/oci/data_integration/models/create_workspace_details.rb', line 44 def display_name @display_name end |
#dns_server_ip ⇒ String
The IP of the custom DNS.
20 21 22 |
# File 'lib/oci/data_integration/models/create_workspace_details.rb', line 20 def dns_server_ip @dns_server_ip end |
#dns_server_zone ⇒ String
The DNS zone of the custom DNS to use to resolve names.
24 25 26 |
# File 'lib/oci/data_integration/models/create_workspace_details.rb', line 24 def dns_server_zone @dns_server_zone end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"Finance"`
30 31 32 |
# File 'lib/oci/data_integration/models/create_workspace_details.rb', line 30 def end |
#is_private_network_enabled ⇒ BOOLEAN
Specifies whether the private network connection is enabled or disabled.
52 53 54 |
# File 'lib/oci/data_integration/models/create_workspace_details.rb', line 52 def is_private_network_enabled @is_private_network_enabled end |
#subnet_id ⇒ String
The OCID of the subnet for customer connected databases.
16 17 18 |
# File 'lib/oci/data_integration/models/create_workspace_details.rb', line 16 def subnet_id @subnet_id end |
#vcn_id ⇒ String
The OCID of the VCN the subnet is in.
12 13 14 |
# File 'lib/oci/data_integration/models/create_workspace_details.rb', line 12 def vcn_id @vcn_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/oci/data_integration/models/create_workspace_details.rb', line 55 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'vcn_id': :'vcnId', 'subnet_id': :'subnetId', 'dns_server_ip': :'dnsServerIp', 'dns_server_zone': :'dnsServerZone', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'description': :'description', 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'is_private_network_enabled': :'isPrivateNetworkEnabled' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/oci/data_integration/models/create_workspace_details.rb', line 73 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'vcn_id': :'String', 'subnet_id': :'String', 'dns_server_ip': :'String', 'dns_server_zone': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'description': :'String', 'display_name': :'String', 'compartment_id': :'String', 'is_private_network_enabled': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/oci/data_integration/models/create_workspace_details.rb', line 178 def ==(other) return true if equal?(other) self.class == other.class && vcn_id == other.vcn_id && subnet_id == other.subnet_id && dns_server_ip == other.dns_server_ip && dns_server_zone == other.dns_server_zone && == other. && == other. && description == other.description && display_name == other.display_name && compartment_id == other.compartment_id && is_private_network_enabled == other.is_private_network_enabled end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/oci/data_integration/models/create_workspace_details.rb', line 217 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
197 198 199 |
# File 'lib/oci/data_integration/models/create_workspace_details.rb', line 197 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
206 207 208 |
# File 'lib/oci/data_integration/models/create_workspace_details.rb', line 206 def hash [vcn_id, subnet_id, dns_server_ip, dns_server_zone, , , description, display_name, compartment_id, is_private_network_enabled].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
250 251 252 253 254 255 256 257 258 259 |
# File 'lib/oci/data_integration/models/create_workspace_details.rb', line 250 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
244 245 246 |
# File 'lib/oci/data_integration/models/create_workspace_details.rb', line 244 def to_s to_hash.to_s end |