Class: OCI::DataIntegration::Models::DataAssetSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_integration/models/data_asset_summary.rb

Overview

The summary object for data asset. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class

Constant Summary collapse

MODEL_TYPE_ENUM =
[
  MODEL_TYPE_ORACLE_DATA_ASSET = 'ORACLE_DATA_ASSET'.freeze,
  MODEL_TYPE_ORACLE_OBJECT_STORAGE_DATA_ASSET = 'ORACLE_OBJECT_STORAGE_DATA_ASSET'.freeze,
  MODEL_TYPE_ORACLE_ATP_DATA_ASSET = 'ORACLE_ATP_DATA_ASSET'.freeze,
  MODEL_TYPE_ORACLE_ADWC_DATA_ASSET = 'ORACLE_ADWC_DATA_ASSET'.freeze,
  MODEL_TYPE_MYSQL_DATA_ASSET = 'MYSQL_DATA_ASSET'.freeze,
  MODEL_TYPE_GENERIC_JDBC_DATA_ASSET = 'GENERIC_JDBC_DATA_ASSET'.freeze,
  MODEL_TYPE_FUSION_APP_DATA_ASSET = 'FUSION_APP_DATA_ASSET'.freeze,
  MODEL_TYPE_AMAZON_S3_DATA_ASSET = 'AMAZON_S3_DATA_ASSET'.freeze,
  MODEL_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DataAssetSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/oci/data_integration/models/data_asset_summary.rb', line 156

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.model_type = attributes[:'modelType'] if attributes[:'modelType']

  raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type')

  self.model_type = attributes[:'model_type'] if attributes[:'model_type']

  self.key = attributes[:'key'] if attributes[:'key']

  self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion']

  raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version')

  self.model_version = attributes[:'model_version'] if attributes[:'model_version']

  self.name = attributes[:'name'] if attributes[:'name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus']

  raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status')

  self.object_status = attributes[:'object_status'] if attributes[:'object_status']

  self.identifier = attributes[:'identifier'] if attributes[:'identifier']

  self.external_key = attributes[:'externalKey'] if attributes[:'externalKey']

  raise 'You cannot provide both :externalKey and :external_key' if attributes.key?(:'externalKey') && attributes.key?(:'external_key')

  self.external_key = attributes[:'external_key'] if attributes[:'external_key']

  self.asset_properties = attributes[:'assetProperties'] if attributes[:'assetProperties']

  raise 'You cannot provide both :assetProperties and :asset_properties' if attributes.key?(:'assetProperties') && attributes.key?(:'asset_properties')

  self.asset_properties = attributes[:'asset_properties'] if attributes[:'asset_properties']

  self.native_type_system = attributes[:'nativeTypeSystem'] if attributes[:'nativeTypeSystem']

  raise 'You cannot provide both :nativeTypeSystem and :native_type_system' if attributes.key?(:'nativeTypeSystem') && attributes.key?(:'native_type_system')

  self.native_type_system = attributes[:'native_type_system'] if attributes[:'native_type_system']

  self.object_version = attributes[:'objectVersion'] if attributes[:'objectVersion']

  raise 'You cannot provide both :objectVersion and :object_version' if attributes.key?(:'objectVersion') && attributes.key?(:'object_version')

  self.object_version = attributes[:'object_version'] if attributes[:'object_version']

  self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef']

  raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref')

  self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref']

  self. = attributes[:'metadata'] if attributes[:'metadata']
end

Instance Attribute Details

#asset_propertiesHash<String, String>

Additional properties for the data asset.

Returns:

  • (Hash<String, String>)


58
59
60
# File 'lib/oci/data_integration/models/data_asset_summary.rb', line 58

def asset_properties
  @asset_properties
end

#descriptionString

The user-defined description of the data asset.

Returns:

  • (String)


42
43
44
# File 'lib/oci/data_integration/models/data_asset_summary.rb', line 42

def description
  @description
end

#external_keyString

The external key for the object.

Returns:

  • (String)


54
55
56
# File 'lib/oci/data_integration/models/data_asset_summary.rb', line 54

def external_key
  @external_key
end

#identifierString

Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.

Returns:

  • (String)


50
51
52
# File 'lib/oci/data_integration/models/data_asset_summary.rb', line 50

def identifier
  @identifier
end

#keyString

Generated key that can be used in API calls to identify data asset.

Returns:

  • (String)


30
31
32
# File 'lib/oci/data_integration/models/data_asset_summary.rb', line 30

def key
  @key
end

#metadataOCI::DataIntegration::Models::ObjectMetadata



71
72
73
# File 'lib/oci/data_integration/models/data_asset_summary.rb', line 71

def 
  @metadata
end

#model_typeString

The type of the data asset.

Returns:

  • (String)


26
27
28
# File 'lib/oci/data_integration/models/data_asset_summary.rb', line 26

def model_type
  @model_type
end

#model_versionString

The model version of an object.

Returns:

  • (String)


34
35
36
# File 'lib/oci/data_integration/models/data_asset_summary.rb', line 34

def model_version
  @model_version
end

#nameString

Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.

Returns:

  • (String)


38
39
40
# File 'lib/oci/data_integration/models/data_asset_summary.rb', line 38

def name
  @name
end

#native_type_systemOCI::DataIntegration::Models::TypeSystem



61
62
63
# File 'lib/oci/data_integration/models/data_asset_summary.rb', line 61

def native_type_system
  @native_type_system
end

#object_statusInteger

The status of an object that can be set to value 1 for shallow references across objects, other values reserved.

Returns:

  • (Integer)


46
47
48
# File 'lib/oci/data_integration/models/data_asset_summary.rb', line 46

def object_status
  @object_status
end

#object_versionInteger

The version of the object that is used to track changes in the object instance.

Returns:

  • (Integer)


65
66
67
# File 'lib/oci/data_integration/models/data_asset_summary.rb', line 65

def object_version
  @object_version
end

#parent_refOCI::DataIntegration::Models::ParentReference



68
69
70
# File 'lib/oci/data_integration/models/data_asset_summary.rb', line 68

def parent_ref
  @parent_ref
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/oci/data_integration/models/data_asset_summary.rb', line 74

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'modelType',
    'key': :'key',
    'model_version': :'modelVersion',
    'name': :'name',
    'description': :'description',
    'object_status': :'objectStatus',
    'identifier': :'identifier',
    'external_key': :'externalKey',
    'asset_properties': :'assetProperties',
    'native_type_system': :'nativeTypeSystem',
    'object_version': :'objectVersion',
    'parent_ref': :'parentRef',
    'metadata': :'metadata'
    # rubocop:enable Style/SymbolLiteral
  }
end

.get_subtype(object_hash) ⇒ Object

Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/oci/data_integration/models/data_asset_summary.rb', line 120

def self.get_subtype(object_hash)
  type = object_hash[:'modelType'] # rubocop:disable Style/SymbolLiteral

  return 'OCI::DataIntegration::Models::DataAssetSummaryFromMySQL' if type == 'MYSQL_DATA_ASSET'
  return 'OCI::DataIntegration::Models::DataAssetSummaryFromAtp' if type == 'ORACLE_ATP_DATA_ASSET'
  return 'OCI::DataIntegration::Models::DataAssetSummaryFromAdwc' if type == 'ORACLE_ADWC_DATA_ASSET'
  return 'OCI::DataIntegration::Models::DataAssetSummaryFromJdbc' if type == 'GENERIC_JDBC_DATA_ASSET'
  return 'OCI::DataIntegration::Models::DataAssetSummaryFromAmazonS3' if type == 'AMAZON_S3_DATA_ASSET'
  return 'OCI::DataIntegration::Models::DataAssetSummaryFromObjectStorage' if type == 'ORACLE_OBJECT_STORAGE_DATA_ASSET'
  return 'OCI::DataIntegration::Models::DataAssetSummaryFromOracle' if type == 'ORACLE_DATA_ASSET'
  return 'OCI::DataIntegration::Models::DataAssetSummaryFromFusionApp' if type == 'FUSION_APP_DATA_ASSET'

  # TODO: Log a warning when the subtype is not found.
  'OCI::DataIntegration::Models::DataAssetSummary'
end

.swagger_typesObject

Attribute type mapping.



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/oci/data_integration/models/data_asset_summary.rb', line 95

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'String',
    'key': :'String',
    'model_version': :'String',
    'name': :'String',
    'description': :'String',
    'object_status': :'Integer',
    'identifier': :'String',
    'external_key': :'String',
    'asset_properties': :'Hash<String, String>',
    'native_type_system': :'OCI::DataIntegration::Models::TypeSystem',
    'object_version': :'Integer',
    'parent_ref': :'OCI::DataIntegration::Models::ParentReference',
    'metadata': :'OCI::DataIntegration::Models::ObjectMetadata'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/oci/data_integration/models/data_asset_summary.rb', line 241

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    model_type == other.model_type &&
    key == other.key &&
    model_version == other.model_version &&
    name == other.name &&
    description == other.description &&
    object_status == other.object_status &&
    identifier == other.identifier &&
    external_key == other.external_key &&
    asset_properties == other.asset_properties &&
    native_type_system == other.native_type_system &&
    object_version == other.object_version &&
    parent_ref == other.parent_ref &&
     == other.
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
# File 'lib/oci/data_integration/models/data_asset_summary.rb', line 283

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


263
264
265
# File 'lib/oci/data_integration/models/data_asset_summary.rb', line 263

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



272
273
274
# File 'lib/oci/data_integration/models/data_asset_summary.rb', line 272

def hash
  [model_type, key, model_version, name, description, object_status, identifier, external_key, asset_properties, native_type_system, object_version, parent_ref, ].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



316
317
318
319
320
321
322
323
324
325
# File 'lib/oci/data_integration/models/data_asset_summary.rb', line 316

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



310
311
312
# File 'lib/oci/data_integration/models/data_asset_summary.rb', line 310

def to_s
  to_hash.to_s
end