Class: OCI::DataIntegration::Models::DataAssetSummaryFromAtp
- Inherits:
-
DataAssetSummary
- Object
- DataAssetSummary
- OCI::DataIntegration::Models::DataAssetSummaryFromAtp
- Defined in:
- lib/oci/data_integration/models/data_asset_summary_from_atp.rb
Overview
Summary details for the Autonomous Transaction Processing data asset type.
Constant Summary
Constants inherited from DataAssetSummary
OCI::DataIntegration::Models::DataAssetSummary::MODEL_TYPE_ENUM
Instance Attribute Summary collapse
- #default_connection ⇒ OCI::DataIntegration::Models::ConnectionSummaryFromAtp
-
#driver_class ⇒ String
The Autonomous Transaction Processing driver class.
-
#service_name ⇒ String
The Autonomous Transaction Processing instance service name.
-
#service_names ⇒ Array<String>
Array of service names that are available for selection in the serviceName property.
Attributes inherited from DataAssetSummary
#asset_properties, #description, #external_key, #identifier, #key, #metadata, #model_type, #model_version, #name, #native_type_system, #object_status, #object_version, #parent_ref
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DataAssetSummaryFromAtp
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from DataAssetSummary
Constructor Details
#initialize(attributes = {}) ⇒ DataAssetSummaryFromAtp
Initializes the object
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/oci/data_integration/models/data_asset_summary_from_atp.rb', line 98 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['modelType'] = 'ORACLE_ATP_DATA_ASSET' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.service_name = attributes[:'serviceName'] if attributes[:'serviceName'] raise 'You cannot provide both :serviceName and :service_name' if attributes.key?(:'serviceName') && attributes.key?(:'service_name') self.service_name = attributes[:'service_name'] if attributes[:'service_name'] self.service_names = attributes[:'serviceNames'] if attributes[:'serviceNames'] raise 'You cannot provide both :serviceNames and :service_names' if attributes.key?(:'serviceNames') && attributes.key?(:'service_names') self.service_names = attributes[:'service_names'] if attributes[:'service_names'] self.driver_class = attributes[:'driverClass'] if attributes[:'driverClass'] raise 'You cannot provide both :driverClass and :driver_class' if attributes.key?(:'driverClass') && attributes.key?(:'driver_class') self.driver_class = attributes[:'driver_class'] if attributes[:'driver_class'] self.default_connection = attributes[:'defaultConnection'] if attributes[:'defaultConnection'] raise 'You cannot provide both :defaultConnection and :default_connection' if attributes.key?(:'defaultConnection') && attributes.key?(:'default_connection') self.default_connection = attributes[:'default_connection'] if attributes[:'default_connection'] end |
Instance Attribute Details
#default_connection ⇒ OCI::DataIntegration::Models::ConnectionSummaryFromAtp
24 25 26 |
# File 'lib/oci/data_integration/models/data_asset_summary_from_atp.rb', line 24 def default_connection @default_connection end |
#driver_class ⇒ String
The Autonomous Transaction Processing driver class.
21 22 23 |
# File 'lib/oci/data_integration/models/data_asset_summary_from_atp.rb', line 21 def driver_class @driver_class end |
#service_name ⇒ String
The Autonomous Transaction Processing instance service name.
13 14 15 |
# File 'lib/oci/data_integration/models/data_asset_summary_from_atp.rb', line 13 def service_name @service_name end |
#service_names ⇒ Array<String>
Array of service names that are available for selection in the serviceName property.
17 18 19 |
# File 'lib/oci/data_integration/models/data_asset_summary_from_atp.rb', line 17 def service_names @service_names end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 |
# File 'lib/oci/data_integration/models/data_asset_summary_from_atp.rb', line 27 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'key': :'key', 'model_version': :'modelVersion', 'name': :'name', 'description': :'description', 'object_status': :'objectStatus', 'identifier': :'identifier', 'external_key': :'externalKey', 'asset_properties': :'assetProperties', 'native_type_system': :'nativeTypeSystem', 'object_version': :'objectVersion', 'parent_ref': :'parentRef', 'metadata': :'metadata', 'service_name': :'serviceName', 'service_names': :'serviceNames', 'driver_class': :'driverClass', 'default_connection': :'defaultConnection' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/oci/data_integration/models/data_asset_summary_from_atp.rb', line 52 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'key': :'String', 'model_version': :'String', 'name': :'String', 'description': :'String', 'object_status': :'Integer', 'identifier': :'String', 'external_key': :'String', 'asset_properties': :'Hash<String, String>', 'native_type_system': :'OCI::DataIntegration::Models::TypeSystem', 'object_version': :'Integer', 'parent_ref': :'OCI::DataIntegration::Models::ParentReference', 'metadata': :'OCI::DataIntegration::Models::ObjectMetadata', 'service_name': :'String', 'service_names': :'Array<String>', 'driver_class': :'String', 'default_connection': :'OCI::DataIntegration::Models::ConnectionSummaryFromAtp' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/oci/data_integration/models/data_asset_summary_from_atp.rb', line 140 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && key == other.key && model_version == other.model_version && name == other.name && description == other.description && object_status == other.object_status && identifier == other.identifier && external_key == other.external_key && asset_properties == other.asset_properties && native_type_system == other.native_type_system && object_version == other.object_version && parent_ref == other.parent_ref && == other. && service_name == other.service_name && service_names == other.service_names && driver_class == other.driver_class && default_connection == other.default_connection end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/oci/data_integration/models/data_asset_summary_from_atp.rb', line 186 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
166 167 168 |
# File 'lib/oci/data_integration/models/data_asset_summary_from_atp.rb', line 166 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
175 176 177 |
# File 'lib/oci/data_integration/models/data_asset_summary_from_atp.rb', line 175 def hash [model_type, key, model_version, name, description, object_status, identifier, external_key, asset_properties, native_type_system, object_version, parent_ref, , service_name, service_names, driver_class, default_connection].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
219 220 221 222 223 224 225 226 227 228 |
# File 'lib/oci/data_integration/models/data_asset_summary_from_atp.rb', line 219 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
213 214 215 |
# File 'lib/oci/data_integration/models/data_asset_summary_from_atp.rb', line 213 def to_s to_hash.to_s end |