Class: OCI::DataIntegration::Models::DataAssetSummaryFromObjectStorage
- Inherits:
-
DataAssetSummary
- Object
- DataAssetSummary
- OCI::DataIntegration::Models::DataAssetSummaryFromObjectStorage
- Defined in:
- lib/oci/data_integration/models/data_asset_summary_from_object_storage.rb
Overview
Summary details for the Oracle Object storage data asset type.
Constant Summary
Constants inherited from DataAssetSummary
OCI::DataIntegration::Models::DataAssetSummary::MODEL_TYPE_ENUM
Instance Attribute Summary collapse
- #default_connection ⇒ OCI::DataIntegration::Models::ConnectionSummaryFromObjectStorage
-
#namespace ⇒ String
The namespace for the specified Oracle Object storage resource.
-
#oci_region ⇒ String
The Oracle Object storage Region ie.
-
#tenancy_id ⇒ String
The OCI tenancy OCID.
-
#url ⇒ String
The Oracle Object storage URL.
Attributes inherited from DataAssetSummary
#asset_properties, #description, #external_key, #identifier, #key, #metadata, #model_type, #model_version, #name, #native_type_system, #object_status, #object_version, #parent_ref
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DataAssetSummaryFromObjectStorage
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from DataAssetSummary
Constructor Details
#initialize(attributes = {}) ⇒ DataAssetSummaryFromObjectStorage
Initializes the object
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/oci/data_integration/models/data_asset_summary_from_object_storage.rb', line 105 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['modelType'] = 'ORACLE_OBJECT_STORAGE_DATA_ASSET' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.oci_region = attributes[:'ociRegion'] if attributes[:'ociRegion'] raise 'You cannot provide both :ociRegion and :oci_region' if attributes.key?(:'ociRegion') && attributes.key?(:'oci_region') self.oci_region = attributes[:'oci_region'] if attributes[:'oci_region'] self.url = attributes[:'url'] if attributes[:'url'] self.tenancy_id = attributes[:'tenancyId'] if attributes[:'tenancyId'] raise 'You cannot provide both :tenancyId and :tenancy_id' if attributes.key?(:'tenancyId') && attributes.key?(:'tenancy_id') self.tenancy_id = attributes[:'tenancy_id'] if attributes[:'tenancy_id'] self.namespace = attributes[:'namespace'] if attributes[:'namespace'] self.default_connection = attributes[:'defaultConnection'] if attributes[:'defaultConnection'] raise 'You cannot provide both :defaultConnection and :default_connection' if attributes.key?(:'defaultConnection') && attributes.key?(:'default_connection') self.default_connection = attributes[:'default_connection'] if attributes[:'default_connection'] end |
Instance Attribute Details
#default_connection ⇒ OCI::DataIntegration::Models::ConnectionSummaryFromObjectStorage
28 29 30 |
# File 'lib/oci/data_integration/models/data_asset_summary_from_object_storage.rb', line 28 def default_connection @default_connection end |
#namespace ⇒ String
The namespace for the specified Oracle Object storage resource. You can find the namespace under Object Storage Settings in the Console.
25 26 27 |
# File 'lib/oci/data_integration/models/data_asset_summary_from_object_storage.rb', line 25 def namespace @namespace end |
#oci_region ⇒ String
The Oracle Object storage Region ie. us-ashburn-1
13 14 15 |
# File 'lib/oci/data_integration/models/data_asset_summary_from_object_storage.rb', line 13 def oci_region @oci_region end |
#tenancy_id ⇒ String
The OCI tenancy OCID.
21 22 23 |
# File 'lib/oci/data_integration/models/data_asset_summary_from_object_storage.rb', line 21 def tenancy_id @tenancy_id end |
#url ⇒ String
The Oracle Object storage URL.
17 18 19 |
# File 'lib/oci/data_integration/models/data_asset_summary_from_object_storage.rb', line 17 def url @url end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/oci/data_integration/models/data_asset_summary_from_object_storage.rb', line 31 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'key': :'key', 'model_version': :'modelVersion', 'name': :'name', 'description': :'description', 'object_status': :'objectStatus', 'identifier': :'identifier', 'external_key': :'externalKey', 'asset_properties': :'assetProperties', 'native_type_system': :'nativeTypeSystem', 'object_version': :'objectVersion', 'parent_ref': :'parentRef', 'metadata': :'metadata', 'oci_region': :'ociRegion', 'url': :'url', 'tenancy_id': :'tenancyId', 'namespace': :'namespace', 'default_connection': :'defaultConnection' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/oci/data_integration/models/data_asset_summary_from_object_storage.rb', line 57 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'key': :'String', 'model_version': :'String', 'name': :'String', 'description': :'String', 'object_status': :'Integer', 'identifier': :'String', 'external_key': :'String', 'asset_properties': :'Hash<String, String>', 'native_type_system': :'OCI::DataIntegration::Models::TypeSystem', 'object_version': :'Integer', 'parent_ref': :'OCI::DataIntegration::Models::ParentReference', 'metadata': :'OCI::DataIntegration::Models::ObjectMetadata', 'oci_region': :'String', 'url': :'String', 'tenancy_id': :'String', 'namespace': :'String', 'default_connection': :'OCI::DataIntegration::Models::ConnectionSummaryFromObjectStorage' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/oci/data_integration/models/data_asset_summary_from_object_storage.rb', line 145 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && key == other.key && model_version == other.model_version && name == other.name && description == other.description && object_status == other.object_status && identifier == other.identifier && external_key == other.external_key && asset_properties == other.asset_properties && native_type_system == other.native_type_system && object_version == other.object_version && parent_ref == other.parent_ref && == other. && oci_region == other.oci_region && url == other.url && tenancy_id == other.tenancy_id && namespace == other.namespace && default_connection == other.default_connection end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/oci/data_integration/models/data_asset_summary_from_object_storage.rb', line 192 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
172 173 174 |
# File 'lib/oci/data_integration/models/data_asset_summary_from_object_storage.rb', line 172 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
181 182 183 |
# File 'lib/oci/data_integration/models/data_asset_summary_from_object_storage.rb', line 181 def hash [model_type, key, model_version, name, description, object_status, identifier, external_key, asset_properties, native_type_system, object_version, parent_ref, , oci_region, url, tenancy_id, namespace, default_connection].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
225 226 227 228 229 230 231 232 233 234 |
# File 'lib/oci/data_integration/models/data_asset_summary_from_object_storage.rb', line 225 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
219 220 221 |
# File 'lib/oci/data_integration/models/data_asset_summary_from_object_storage.rb', line 219 def to_s to_hash.to_s end |