Class: OCI::DataIntegration::Models::DataEntityFromDataStoreEntityDetails
- Inherits:
-
DataEntityDetails
- Object
- DataEntityDetails
- OCI::DataIntegration::Models::DataEntityFromDataStoreEntityDetails
- Defined in:
- lib/oci/data_integration/models/data_entity_from_data_store_entity_details.rb
Overview
The view entity data entity details.
Constant Summary collapse
- ENTITY_TYPE_ENUM =
[ ENTITY_TYPE_TABLE = 'TABLE'.freeze, ENTITY_TYPE_VIEW = 'VIEW'.freeze, ENTITY_TYPE_FILE = 'FILE'.freeze, ENTITY_TYPE_QUEUE = 'QUEUE'.freeze, ENTITY_TYPE_STREAM = 'STREAM'.freeze, ENTITY_TYPE_OTHER = 'OTHER'.freeze, ENTITY_TYPE_DATA_STORE = 'DATA_STORE'.freeze ].freeze
Constants inherited from DataEntityDetails
OCI::DataIntegration::Models::DataEntityDetails::MODEL_TYPE_ENUM
Instance Attribute Summary collapse
-
#description ⇒ String
Detailed description for the object.
-
#entity_type ⇒ String
The entity type.
-
#external_key ⇒ String
The external key for the object.
-
#filters ⇒ String
Filters present in the Datastore.
-
#foreign_keys ⇒ Array<OCI::DataIntegration::Models::ForeignKey>
An array of foreign keys.
-
#identifier ⇒ String
Value can only contain upper case letters, underscore and numbers.
-
#is_effective_date_disabled ⇒ BOOLEAN
It shows whether or not effective date is disabled.
-
#is_flex_data_store ⇒ BOOLEAN
It shows whether the datastore is of flex type.
-
#is_silent_error ⇒ BOOLEAN
It shows whether the extraction of this datastore will stop on error.
-
#key ⇒ String
The object key.
-
#model_version ⇒ String
The object’s model version.
-
#name ⇒ String
Free form text without any restriction on permitted characters.
-
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
-
#object_version ⇒ Integer
The version of the object that is used to track changes in the object instance.
-
#other_type_label ⇒ String
Specifies other type labels.
- #parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
-
#resource_name ⇒ String
The resource name.
- #shape ⇒ OCI::DataIntegration::Models::Shape
-
#shape_id ⇒ String
The shape ID.
-
#supports_incremental ⇒ BOOLEAN
It shows whether the datastore supports Incremental Extract or not.
- #types ⇒ OCI::DataIntegration::Models::TypeLibrary
-
#unique_keys ⇒ Array<OCI::DataIntegration::Models::UniqueKey>
An array of unique keys.
Attributes inherited from DataEntityDetails
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DataEntityFromDataStoreEntityDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from DataEntityDetails
Constructor Details
#initialize(attributes = {}) ⇒ DataEntityFromDataStoreEntityDetails
Initializes the object
196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 |
# File 'lib/oci/data_integration/models/data_entity_from_data_store_entity_details.rb', line 196 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['modelType'] = 'DATA_STORE_ENTITY' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.key = attributes[:'key'] if attributes[:'key'] self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion'] raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version') self.model_version = attributes[:'model_version'] if attributes[:'model_version'] self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef'] raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref') self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref'] self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.object_version = attributes[:'objectVersion'] if attributes[:'objectVersion'] raise 'You cannot provide both :objectVersion and :object_version' if attributes.key?(:'objectVersion') && attributes.key?(:'object_version') self.object_version = attributes[:'object_version'] if attributes[:'object_version'] self.external_key = attributes[:'externalKey'] if attributes[:'externalKey'] raise 'You cannot provide both :externalKey and :external_key' if attributes.key?(:'externalKey') && attributes.key?(:'external_key') self.external_key = attributes[:'external_key'] if attributes[:'external_key'] self.shape = attributes[:'shape'] if attributes[:'shape'] self.shape_id = attributes[:'shapeId'] if attributes[:'shapeId'] raise 'You cannot provide both :shapeId and :shape_id' if attributes.key?(:'shapeId') && attributes.key?(:'shape_id') self.shape_id = attributes[:'shape_id'] if attributes[:'shape_id'] self.types = attributes[:'types'] if attributes[:'types'] self.entity_type = attributes[:'entityType'] if attributes[:'entityType'] raise 'You cannot provide both :entityType and :entity_type' if attributes.key?(:'entityType') && attributes.key?(:'entity_type') self.entity_type = attributes[:'entity_type'] if attributes[:'entity_type'] self.other_type_label = attributes[:'otherTypeLabel'] if attributes[:'otherTypeLabel'] raise 'You cannot provide both :otherTypeLabel and :other_type_label' if attributes.key?(:'otherTypeLabel') && attributes.key?(:'other_type_label') self.other_type_label = attributes[:'other_type_label'] if attributes[:'other_type_label'] self.unique_keys = attributes[:'uniqueKeys'] if attributes[:'uniqueKeys'] raise 'You cannot provide both :uniqueKeys and :unique_keys' if attributes.key?(:'uniqueKeys') && attributes.key?(:'unique_keys') self.unique_keys = attributes[:'unique_keys'] if attributes[:'unique_keys'] self.foreign_keys = attributes[:'foreignKeys'] if attributes[:'foreignKeys'] raise 'You cannot provide both :foreignKeys and :foreign_keys' if attributes.key?(:'foreignKeys') && attributes.key?(:'foreign_keys') self.foreign_keys = attributes[:'foreign_keys'] if attributes[:'foreign_keys'] self.resource_name = attributes[:'resourceName'] if attributes[:'resourceName'] raise 'You cannot provide both :resourceName and :resource_name' if attributes.key?(:'resourceName') && attributes.key?(:'resource_name') self.resource_name = attributes[:'resource_name'] if attributes[:'resource_name'] self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus'] raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status') self.object_status = attributes[:'object_status'] if attributes[:'object_status'] self.identifier = attributes[:'identifier'] if attributes[:'identifier'] self.filters = attributes[:'filters'] if attributes[:'filters'] self.is_effective_date_disabled = attributes[:'isEffectiveDateDisabled'] unless attributes[:'isEffectiveDateDisabled'].nil? raise 'You cannot provide both :isEffectiveDateDisabled and :is_effective_date_disabled' if attributes.key?(:'isEffectiveDateDisabled') && attributes.key?(:'is_effective_date_disabled') self.is_effective_date_disabled = attributes[:'is_effective_date_disabled'] unless attributes[:'is_effective_date_disabled'].nil? self.is_flex_data_store = attributes[:'isFlexDataStore'] unless attributes[:'isFlexDataStore'].nil? raise 'You cannot provide both :isFlexDataStore and :is_flex_data_store' if attributes.key?(:'isFlexDataStore') && attributes.key?(:'is_flex_data_store') self.is_flex_data_store = attributes[:'is_flex_data_store'] unless attributes[:'is_flex_data_store'].nil? self.is_silent_error = attributes[:'isSilentError'] unless attributes[:'isSilentError'].nil? raise 'You cannot provide both :isSilentError and :is_silent_error' if attributes.key?(:'isSilentError') && attributes.key?(:'is_silent_error') self.is_silent_error = attributes[:'is_silent_error'] unless attributes[:'is_silent_error'].nil? self.supports_incremental = attributes[:'supportsIncremental'] unless attributes[:'supportsIncremental'].nil? raise 'You cannot provide both :supportsIncremental and :supports_incremental' if attributes.key?(:'supportsIncremental') && attributes.key?(:'supports_incremental') self.supports_incremental = attributes[:'supports_incremental'] unless attributes[:'supports_incremental'].nil? end |
Instance Attribute Details
#description ⇒ String
Detailed description for the object.
38 39 40 |
# File 'lib/oci/data_integration/models/data_entity_from_data_store_entity_details.rb', line 38 def description @description end |
#entity_type ⇒ String
The entity type.
60 61 62 |
# File 'lib/oci/data_integration/models/data_entity_from_data_store_entity_details.rb', line 60 def entity_type @entity_type end |
#external_key ⇒ String
The external key for the object
46 47 48 |
# File 'lib/oci/data_integration/models/data_entity_from_data_store_entity_details.rb', line 46 def external_key @external_key end |
#filters ⇒ String
Filters present in the Datastore. It can be Null.
88 89 90 |
# File 'lib/oci/data_integration/models/data_entity_from_data_store_entity_details.rb', line 88 def filters @filters end |
#foreign_keys ⇒ Array<OCI::DataIntegration::Models::ForeignKey>
An array of foreign keys.
72 73 74 |
# File 'lib/oci/data_integration/models/data_entity_from_data_store_entity_details.rb', line 72 def foreign_keys @foreign_keys end |
#identifier ⇒ String
Value can only contain upper case letters, underscore and numbers. It should begin with upper case letter or underscore. The value can be modified.
84 85 86 |
# File 'lib/oci/data_integration/models/data_entity_from_data_store_entity_details.rb', line 84 def identifier @identifier end |
#is_effective_date_disabled ⇒ BOOLEAN
It shows whether or not effective date is disabled
92 93 94 |
# File 'lib/oci/data_integration/models/data_entity_from_data_store_entity_details.rb', line 92 def is_effective_date_disabled @is_effective_date_disabled end |
#is_flex_data_store ⇒ BOOLEAN
It shows whether the datastore is of flex type
96 97 98 |
# File 'lib/oci/data_integration/models/data_entity_from_data_store_entity_details.rb', line 96 def is_flex_data_store @is_flex_data_store end |
#is_silent_error ⇒ BOOLEAN
It shows whether the extraction of this datastore will stop on error
100 101 102 |
# File 'lib/oci/data_integration/models/data_entity_from_data_store_entity_details.rb', line 100 def is_silent_error @is_silent_error end |
#key ⇒ String
The object key.
23 24 25 |
# File 'lib/oci/data_integration/models/data_entity_from_data_store_entity_details.rb', line 23 def key @key end |
#model_version ⇒ String
The object’s model version.
27 28 29 |
# File 'lib/oci/data_integration/models/data_entity_from_data_store_entity_details.rb', line 27 def model_version @model_version end |
#name ⇒ String
Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.
34 35 36 |
# File 'lib/oci/data_integration/models/data_entity_from_data_store_entity_details.rb', line 34 def name @name end |
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
80 81 82 |
# File 'lib/oci/data_integration/models/data_entity_from_data_store_entity_details.rb', line 80 def object_status @object_status end |
#object_version ⇒ Integer
The version of the object that is used to track changes in the object instance.
42 43 44 |
# File 'lib/oci/data_integration/models/data_entity_from_data_store_entity_details.rb', line 42 def object_version @object_version end |
#other_type_label ⇒ String
Specifies other type labels.
64 65 66 |
# File 'lib/oci/data_integration/models/data_entity_from_data_store_entity_details.rb', line 64 def other_type_label @other_type_label end |
#parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
30 31 32 |
# File 'lib/oci/data_integration/models/data_entity_from_data_store_entity_details.rb', line 30 def parent_ref @parent_ref end |
#resource_name ⇒ String
The resource name.
76 77 78 |
# File 'lib/oci/data_integration/models/data_entity_from_data_store_entity_details.rb', line 76 def resource_name @resource_name end |
#shape ⇒ OCI::DataIntegration::Models::Shape
49 50 51 |
# File 'lib/oci/data_integration/models/data_entity_from_data_store_entity_details.rb', line 49 def shape @shape end |
#shape_id ⇒ String
The shape ID.
53 54 55 |
# File 'lib/oci/data_integration/models/data_entity_from_data_store_entity_details.rb', line 53 def shape_id @shape_id end |
#supports_incremental ⇒ BOOLEAN
It shows whether the datastore supports Incremental Extract or not.
104 105 106 |
# File 'lib/oci/data_integration/models/data_entity_from_data_store_entity_details.rb', line 104 def supports_incremental @supports_incremental end |
#types ⇒ OCI::DataIntegration::Models::TypeLibrary
56 57 58 |
# File 'lib/oci/data_integration/models/data_entity_from_data_store_entity_details.rb', line 56 def types @types end |
#unique_keys ⇒ Array<OCI::DataIntegration::Models::UniqueKey>
An array of unique keys.
68 69 70 |
# File 'lib/oci/data_integration/models/data_entity_from_data_store_entity_details.rb', line 68 def unique_keys @unique_keys end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/oci/data_integration/models/data_entity_from_data_store_entity_details.rb', line 107 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'key': :'key', 'model_version': :'modelVersion', 'parent_ref': :'parentRef', 'name': :'name', 'description': :'description', 'object_version': :'objectVersion', 'external_key': :'externalKey', 'shape': :'shape', 'shape_id': :'shapeId', 'types': :'types', 'entity_type': :'entityType', 'other_type_label': :'otherTypeLabel', 'unique_keys': :'uniqueKeys', 'foreign_keys': :'foreignKeys', 'resource_name': :'resourceName', 'object_status': :'objectStatus', 'identifier': :'identifier', 'filters': :'filters', 'is_effective_date_disabled': :'isEffectiveDateDisabled', 'is_flex_data_store': :'isFlexDataStore', 'is_silent_error': :'isSilentError', 'supports_incremental': :'supportsIncremental' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/oci/data_integration/models/data_entity_from_data_store_entity_details.rb', line 138 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'key': :'String', 'model_version': :'String', 'parent_ref': :'OCI::DataIntegration::Models::ParentReference', 'name': :'String', 'description': :'String', 'object_version': :'Integer', 'external_key': :'String', 'shape': :'OCI::DataIntegration::Models::Shape', 'shape_id': :'String', 'types': :'OCI::DataIntegration::Models::TypeLibrary', 'entity_type': :'String', 'other_type_label': :'String', 'unique_keys': :'Array<OCI::DataIntegration::Models::UniqueKey>', 'foreign_keys': :'Array<OCI::DataIntegration::Models::ForeignKey>', 'resource_name': :'String', 'object_status': :'Integer', 'identifier': :'String', 'filters': :'String', 'is_effective_date_disabled': :'BOOLEAN', 'is_flex_data_store': :'BOOLEAN', 'is_silent_error': :'BOOLEAN', 'supports_incremental': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 |
# File 'lib/oci/data_integration/models/data_entity_from_data_store_entity_details.rb', line 326 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && key == other.key && model_version == other.model_version && parent_ref == other.parent_ref && name == other.name && description == other.description && object_version == other.object_version && external_key == other.external_key && shape == other.shape && shape_id == other.shape_id && types == other.types && entity_type == other.entity_type && other_type_label == other.other_type_label && unique_keys == other.unique_keys && foreign_keys == other.foreign_keys && resource_name == other.resource_name && object_status == other.object_status && identifier == other.identifier && filters == other.filters && is_effective_date_disabled == other.is_effective_date_disabled && is_flex_data_store == other.is_flex_data_store && is_silent_error == other.is_silent_error && supports_incremental == other.supports_incremental end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 |
# File 'lib/oci/data_integration/models/data_entity_from_data_store_entity_details.rb', line 378 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
358 359 360 |
# File 'lib/oci/data_integration/models/data_entity_from_data_store_entity_details.rb', line 358 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
367 368 369 |
# File 'lib/oci/data_integration/models/data_entity_from_data_store_entity_details.rb', line 367 def hash [model_type, key, model_version, parent_ref, name, description, object_version, external_key, shape, shape_id, types, entity_type, other_type_label, unique_keys, foreign_keys, resource_name, object_status, identifier, filters, is_effective_date_disabled, is_flex_data_store, is_silent_error, supports_incremental].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
411 412 413 414 415 416 417 418 419 420 |
# File 'lib/oci/data_integration/models/data_entity_from_data_store_entity_details.rb', line 411 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
405 406 407 |
# File 'lib/oci/data_integration/models/data_entity_from_data_store_entity_details.rb', line 405 def to_s to_hash.to_s end |