Class: OCI::DataIntegration::Models::DataFlow

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_integration/models/data_flow.rb

Overview

The data flow type contains the audit summary information and the definition of the data flow.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DataFlow

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/oci/data_integration/models/data_flow.rb', line 127

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.key = attributes[:'key'] if attributes[:'key']

  self.model_type = attributes[:'modelType'] if attributes[:'modelType']

  raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type')

  self.model_type = attributes[:'model_type'] if attributes[:'model_type']

  self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion']

  raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version')

  self.model_version = attributes[:'model_version'] if attributes[:'model_version']

  self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef']

  raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref')

  self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref']

  self.name = attributes[:'name'] if attributes[:'name']

  self.identifier = attributes[:'identifier'] if attributes[:'identifier']

  self.object_version = attributes[:'objectVersion'] if attributes[:'objectVersion']

  raise 'You cannot provide both :objectVersion and :object_version' if attributes.key?(:'objectVersion') && attributes.key?(:'object_version')

  self.object_version = attributes[:'object_version'] if attributes[:'object_version']

  self.nodes = attributes[:'nodes'] if attributes[:'nodes']

  self.parameters = attributes[:'parameters'] if attributes[:'parameters']

  self.description = attributes[:'description'] if attributes[:'description']

  self.flow_config_values = attributes[:'flowConfigValues'] if attributes[:'flowConfigValues']

  raise 'You cannot provide both :flowConfigValues and :flow_config_values' if attributes.key?(:'flowConfigValues') && attributes.key?(:'flow_config_values')

  self.flow_config_values = attributes[:'flow_config_values'] if attributes[:'flow_config_values']

  self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus']

  raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status')

  self.object_status = attributes[:'object_status'] if attributes[:'object_status']

  self. = attributes[:'metadata'] if attributes[:'metadata']

  self.key_map = attributes[:'keyMap'] if attributes[:'keyMap']

  raise 'You cannot provide both :keyMap and :key_map' if attributes.key?(:'keyMap') && attributes.key?(:'key_map')

  self.key_map = attributes[:'key_map'] if attributes[:'key_map']
end

Instance Attribute Details

#descriptionString

Detailed description for the object.

Returns:

  • (String)


47
48
49
# File 'lib/oci/data_integration/models/data_flow.rb', line 47

def description
  @description
end

#flow_config_valuesOCI::DataIntegration::Models::ConfigValues



50
51
52
# File 'lib/oci/data_integration/models/data_flow.rb', line 50

def flow_config_values
  @flow_config_values
end

#identifierString

Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.

Returns:

  • (String)


31
32
33
# File 'lib/oci/data_integration/models/data_flow.rb', line 31

def identifier
  @identifier
end

#keyString

Generated key that can be used in API calls to identify data flow. On scenarios where reference to the data flow is needed, a value can be passed in create.

Returns:

  • (String)


12
13
14
# File 'lib/oci/data_integration/models/data_flow.rb', line 12

def key
  @key
end

#key_mapHash<String, String>

A key map. If provided, key is replaced with generated key. This structure provides mapping between user provided key and generated key.

Returns:

  • (Hash<String, String>)


61
62
63
# File 'lib/oci/data_integration/models/data_flow.rb', line 61

def key_map
  @key_map
end

#metadataOCI::DataIntegration::Models::ObjectMetadata



57
58
59
# File 'lib/oci/data_integration/models/data_flow.rb', line 57

def 
  @metadata
end

#model_typeString

The type of the object.

Returns:

  • (String)


16
17
18
# File 'lib/oci/data_integration/models/data_flow.rb', line 16

def model_type
  @model_type
end

#model_versionString

The model version of an object.

Returns:

  • (String)


20
21
22
# File 'lib/oci/data_integration/models/data_flow.rb', line 20

def model_version
  @model_version
end

#nameString

Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.

Returns:

  • (String)


27
28
29
# File 'lib/oci/data_integration/models/data_flow.rb', line 27

def name
  @name
end

#nodesArray<OCI::DataIntegration::Models::FlowNode>

An array of nodes.



39
40
41
# File 'lib/oci/data_integration/models/data_flow.rb', line 39

def nodes
  @nodes
end

#object_statusInteger

The status of an object that can be set to value 1 for shallow references across objects, other values reserved.

Returns:

  • (Integer)


54
55
56
# File 'lib/oci/data_integration/models/data_flow.rb', line 54

def object_status
  @object_status
end

#object_versionInteger

The version of the object that is used to track changes in the object instance.

Returns:

  • (Integer)


35
36
37
# File 'lib/oci/data_integration/models/data_flow.rb', line 35

def object_version
  @object_version
end

#parametersArray<OCI::DataIntegration::Models::Parameter>

An array of parameters.



43
44
45
# File 'lib/oci/data_integration/models/data_flow.rb', line 43

def parameters
  @parameters
end

#parent_refOCI::DataIntegration::Models::ParentReference



23
24
25
# File 'lib/oci/data_integration/models/data_flow.rb', line 23

def parent_ref
  @parent_ref
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/oci/data_integration/models/data_flow.rb', line 64

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'key',
    'model_type': :'modelType',
    'model_version': :'modelVersion',
    'parent_ref': :'parentRef',
    'name': :'name',
    'identifier': :'identifier',
    'object_version': :'objectVersion',
    'nodes': :'nodes',
    'parameters': :'parameters',
    'description': :'description',
    'flow_config_values': :'flowConfigValues',
    'object_status': :'objectStatus',
    'metadata': :'metadata',
    'key_map': :'keyMap'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/oci/data_integration/models/data_flow.rb', line 86

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'String',
    'model_type': :'String',
    'model_version': :'String',
    'parent_ref': :'OCI::DataIntegration::Models::ParentReference',
    'name': :'String',
    'identifier': :'String',
    'object_version': :'Integer',
    'nodes': :'Array<OCI::DataIntegration::Models::FlowNode>',
    'parameters': :'Array<OCI::DataIntegration::Models::Parameter>',
    'description': :'String',
    'flow_config_values': :'OCI::DataIntegration::Models::ConfigValues',
    'object_status': :'Integer',
    'metadata': :'OCI::DataIntegration::Models::ObjectMetadata',
    'key_map': :'Hash<String, String>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/oci/data_integration/models/data_flow.rb', line 197

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    key == other.key &&
    model_type == other.model_type &&
    model_version == other.model_version &&
    parent_ref == other.parent_ref &&
    name == other.name &&
    identifier == other.identifier &&
    object_version == other.object_version &&
    nodes == other.nodes &&
    parameters == other.parameters &&
    description == other.description &&
    flow_config_values == other.flow_config_values &&
    object_status == other.object_status &&
     == other. &&
    key_map == other.key_map
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
# File 'lib/oci/data_integration/models/data_flow.rb', line 240

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


220
221
222
# File 'lib/oci/data_integration/models/data_flow.rb', line 220

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



229
230
231
# File 'lib/oci/data_integration/models/data_flow.rb', line 229

def hash
  [key, model_type, model_version, parent_ref, name, identifier, object_version, nodes, parameters, description, flow_config_values, object_status, , key_map].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



273
274
275
276
277
278
279
280
281
282
# File 'lib/oci/data_integration/models/data_flow.rb', line 273

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



267
268
269
# File 'lib/oci/data_integration/models/data_flow.rb', line 267

def to_s
  to_hash.to_s
end