Class: OCI::DataIntegration::Models::DataFlowDetails
- Inherits:
-
Object
- Object
- OCI::DataIntegration::Models::DataFlowDetails
- Defined in:
- lib/oci/data_integration/models/data_flow_details.rb
Overview
The information about a data flow.
Instance Attribute Summary collapse
-
#description ⇒ String
Detailed description for the object.
- #flow_config_values ⇒ OCI::DataIntegration::Models::ConfigValues
-
#identifier ⇒ String
Value can only contain upper case letters, underscore, and numbers.
-
#key ⇒ String
[Required] Generated key that can be used in API calls to identify data flow.
-
#model_type ⇒ String
[Required] The type of the object.
-
#model_version ⇒ String
The model version of an object.
-
#name ⇒ String
Free form text without any restriction on permitted characters.
-
#nodes ⇒ Array<OCI::DataIntegration::Models::FlowNode>
An array of nodes.
-
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
-
#object_version ⇒ Integer
[Required] The version of the object that is used to track changes in the object instance.
-
#parameters ⇒ Array<OCI::DataIntegration::Models::Parameter>
An array of parameters.
- #parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
- #registry_metadata ⇒ OCI::DataIntegration::Models::RegistryMetadata
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DataFlowDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DataFlowDetails
Initializes the object
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/oci/data_integration/models/data_flow_details.rb', line 120 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.key = attributes[:'key'] if attributes[:'key'] self.model_type = attributes[:'modelType'] if attributes[:'modelType'] raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type') self.model_type = attributes[:'model_type'] if attributes[:'model_type'] self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion'] raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version') self.model_version = attributes[:'model_version'] if attributes[:'model_version'] self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef'] raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref') self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref'] self.name = attributes[:'name'] if attributes[:'name'] self.identifier = attributes[:'identifier'] if attributes[:'identifier'] self.object_version = attributes[:'objectVersion'] if attributes[:'objectVersion'] raise 'You cannot provide both :objectVersion and :object_version' if attributes.key?(:'objectVersion') && attributes.key?(:'object_version') self.object_version = attributes[:'object_version'] if attributes[:'object_version'] self.nodes = attributes[:'nodes'] if attributes[:'nodes'] self.parameters = attributes[:'parameters'] if attributes[:'parameters'] self.description = attributes[:'description'] if attributes[:'description'] self.flow_config_values = attributes[:'flowConfigValues'] if attributes[:'flowConfigValues'] raise 'You cannot provide both :flowConfigValues and :flow_config_values' if attributes.key?(:'flowConfigValues') && attributes.key?(:'flow_config_values') self.flow_config_values = attributes[:'flow_config_values'] if attributes[:'flow_config_values'] self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus'] raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status') self.object_status = attributes[:'object_status'] if attributes[:'object_status'] self. = attributes[:'registryMetadata'] if attributes[:'registryMetadata'] raise 'You cannot provide both :registryMetadata and :registry_metadata' if attributes.key?(:'registryMetadata') && attributes.key?(:'registry_metadata') self. = attributes[:'registry_metadata'] if attributes[:'registry_metadata'] end |
Instance Attribute Details
#description ⇒ String
Detailed description for the object.
47 48 49 |
# File 'lib/oci/data_integration/models/data_flow_details.rb', line 47 def description @description end |
#flow_config_values ⇒ OCI::DataIntegration::Models::ConfigValues
50 51 52 |
# File 'lib/oci/data_integration/models/data_flow_details.rb', line 50 def flow_config_values @flow_config_values end |
#identifier ⇒ String
Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.
31 32 33 |
# File 'lib/oci/data_integration/models/data_flow_details.rb', line 31 def identifier @identifier end |
#key ⇒ String
[Required] Generated key that can be used in API calls to identify data flow. On scenarios where reference to the data flow is needed, a value can be passed in create.
12 13 14 |
# File 'lib/oci/data_integration/models/data_flow_details.rb', line 12 def key @key end |
#model_type ⇒ String
[Required] The type of the object.
16 17 18 |
# File 'lib/oci/data_integration/models/data_flow_details.rb', line 16 def model_type @model_type end |
#model_version ⇒ String
The model version of an object.
20 21 22 |
# File 'lib/oci/data_integration/models/data_flow_details.rb', line 20 def model_version @model_version end |
#name ⇒ String
Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.
27 28 29 |
# File 'lib/oci/data_integration/models/data_flow_details.rb', line 27 def name @name end |
#nodes ⇒ Array<OCI::DataIntegration::Models::FlowNode>
An array of nodes.
39 40 41 |
# File 'lib/oci/data_integration/models/data_flow_details.rb', line 39 def nodes @nodes end |
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
54 55 56 |
# File 'lib/oci/data_integration/models/data_flow_details.rb', line 54 def object_status @object_status end |
#object_version ⇒ Integer
[Required] The version of the object that is used to track changes in the object instance.
35 36 37 |
# File 'lib/oci/data_integration/models/data_flow_details.rb', line 35 def object_version @object_version end |
#parameters ⇒ Array<OCI::DataIntegration::Models::Parameter>
An array of parameters.
43 44 45 |
# File 'lib/oci/data_integration/models/data_flow_details.rb', line 43 def parameters @parameters end |
#parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
23 24 25 |
# File 'lib/oci/data_integration/models/data_flow_details.rb', line 23 def parent_ref @parent_ref end |
#registry_metadata ⇒ OCI::DataIntegration::Models::RegistryMetadata
57 58 59 |
# File 'lib/oci/data_integration/models/data_flow_details.rb', line 57 def @registry_metadata end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/oci/data_integration/models/data_flow_details.rb', line 60 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'key': :'key', 'model_type': :'modelType', 'model_version': :'modelVersion', 'parent_ref': :'parentRef', 'name': :'name', 'identifier': :'identifier', 'object_version': :'objectVersion', 'nodes': :'nodes', 'parameters': :'parameters', 'description': :'description', 'flow_config_values': :'flowConfigValues', 'object_status': :'objectStatus', 'registry_metadata': :'registryMetadata' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/oci/data_integration/models/data_flow_details.rb', line 81 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'key': :'String', 'model_type': :'String', 'model_version': :'String', 'parent_ref': :'OCI::DataIntegration::Models::ParentReference', 'name': :'String', 'identifier': :'String', 'object_version': :'Integer', 'nodes': :'Array<OCI::DataIntegration::Models::FlowNode>', 'parameters': :'Array<OCI::DataIntegration::Models::Parameter>', 'description': :'String', 'flow_config_values': :'OCI::DataIntegration::Models::ConfigValues', 'object_status': :'Integer', 'registry_metadata': :'OCI::DataIntegration::Models::RegistryMetadata' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/oci/data_integration/models/data_flow_details.rb', line 188 def ==(other) return true if equal?(other) self.class == other.class && key == other.key && model_type == other.model_type && model_version == other.model_version && parent_ref == other.parent_ref && name == other.name && identifier == other.identifier && object_version == other.object_version && nodes == other.nodes && parameters == other.parameters && description == other.description && flow_config_values == other.flow_config_values && object_status == other.object_status && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/oci/data_integration/models/data_flow_details.rb', line 230 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
210 211 212 |
# File 'lib/oci/data_integration/models/data_flow_details.rb', line 210 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
219 220 221 |
# File 'lib/oci/data_integration/models/data_flow_details.rb', line 219 def hash [key, model_type, model_version, parent_ref, name, identifier, object_version, nodes, parameters, description, flow_config_values, object_status, ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
263 264 265 266 267 268 269 270 271 272 |
# File 'lib/oci/data_integration/models/data_flow_details.rb', line 263 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
257 258 259 |
# File 'lib/oci/data_integration/models/data_flow_details.rb', line 257 def to_s to_hash.to_s end |