Class: OCI::DataIntegration::Models::DataFormat

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_integration/models/data_format.rb

Overview

The data format object.

Constant Summary collapse

TYPE_ENUM =
[
  TYPE_XML = 'XML'.freeze,
  TYPE_JSON = 'JSON'.freeze,
  TYPE_CSV = 'CSV'.freeze,
  TYPE_ORC = 'ORC'.freeze,
  TYPE_PARQUET = 'PARQUET'.freeze,
  TYPE_AVRO = 'AVRO'.freeze,
  TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DataFormat

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/oci/data_integration/models/data_format.rb', line 56

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.format_attribute = attributes[:'formatAttribute'] if attributes[:'formatAttribute']

  raise 'You cannot provide both :formatAttribute and :format_attribute' if attributes.key?(:'formatAttribute') && attributes.key?(:'format_attribute')

  self.format_attribute = attributes[:'format_attribute'] if attributes[:'format_attribute']

  self.type = attributes[:'type'] if attributes[:'type']
end

Instance Attribute Details

#format_attributeOCI::DataIntegration::Models::AbstractFormatAttribute



22
23
24
# File 'lib/oci/data_integration/models/data_format.rb', line 22

def format_attribute
  @format_attribute
end

#typeString

type

Returns:

  • (String)


26
27
28
# File 'lib/oci/data_integration/models/data_format.rb', line 26

def type
  @type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



29
30
31
32
33
34
35
36
# File 'lib/oci/data_integration/models/data_format.rb', line 29

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'format_attribute': :'formatAttribute',
    'type': :'type'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



39
40
41
42
43
44
45
46
# File 'lib/oci/data_integration/models/data_format.rb', line 39

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'format_attribute': :'OCI::DataIntegration::Models::AbstractFormatAttribute',
    'type': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



91
92
93
94
95
96
97
# File 'lib/oci/data_integration/models/data_format.rb', line 91

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    format_attribute == other.format_attribute &&
    type == other.type
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/oci/data_integration/models/data_format.rb', line 122

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


102
103
104
# File 'lib/oci/data_integration/models/data_format.rb', line 102

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



111
112
113
# File 'lib/oci/data_integration/models/data_format.rb', line 111

def hash
  [format_attribute, type].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



155
156
157
158
159
160
161
162
163
164
# File 'lib/oci/data_integration/models/data_format.rb', line 155

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



149
150
151
# File 'lib/oci/data_integration/models/data_format.rb', line 149

def to_s
  to_hash.to_s
end