Class: OCI::DataIntegration::Models::DependentObject
- Inherits:
-
Object
- Object
- OCI::DataIntegration::Models::DependentObject
- Defined in:
- lib/oci/data_integration/models/dependent_object.rb
Overview
The information about a dependent object.
Instance Attribute Summary collapse
-
#application_version ⇒ Integer
The application’s version.
-
#dependent_object_metadata ⇒ Array<OCI::DataIntegration::Models::PatchObjectMetadata>
A list of dependent objects in this patch.
-
#description ⇒ String
Detailed description for the object.
-
#identifier ⇒ String
Value can only contain upper case letters, underscore, and numbers.
-
#key ⇒ String
Generated key that can be used in API calls to identify application.
-
#key_map ⇒ Hash<String, String>
A key map.
- #metadata ⇒ OCI::DataIntegration::Models::ObjectMetadata
-
#model_type ⇒ String
The object type.
-
#model_version ⇒ String
The object’s model version.
-
#name ⇒ String
Free form text without any restriction on permitted characters.
-
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
-
#object_version ⇒ Integer
The version of the object that is used to track changes in the object instance.
- #parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
-
#published_object_metadata ⇒ Hash<String, OCI::DataIntegration::Models::PatchObjectMetadata>
A list of objects that are published or unpublished in this patch.
- #source_application_info ⇒ OCI::DataIntegration::Models::SourceApplicationInfo
-
#time_patched ⇒ DateTime
The date and time the application was patched, in the timestamp format defined by RFC3339.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DependentObject
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DependentObject
Initializes the object
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/oci/data_integration/models/dependent_object.rb', line 142 def initialize(attributes = {}) return unless attributes.is_a?(Hash) self.key = attributes[:'key'] if attributes[:'key'] self.model_type = attributes[:'modelType'] if attributes[:'modelType'] raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type') self.model_type = attributes[:'model_type'] if attributes[:'model_type'] self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion'] raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version') self.model_version = attributes[:'model_version'] if attributes[:'model_version'] self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.application_version = attributes[:'applicationVersion'] if attributes[:'applicationVersion'] raise 'You cannot provide both :applicationVersion and :application_version' if attributes.key?(:'applicationVersion') && attributes.key?(:'application_version') self.application_version = attributes[:'application_version'] if attributes[:'application_version'] self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus'] raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status') self.object_status = attributes[:'object_status'] if attributes[:'object_status'] self.identifier = attributes[:'identifier'] if attributes[:'identifier'] self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef'] raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref') self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref'] self.object_version = attributes[:'objectVersion'] if attributes[:'objectVersion'] raise 'You cannot provide both :objectVersion and :object_version' if attributes.key?(:'objectVersion') && attributes.key?(:'object_version') self.object_version = attributes[:'object_version'] if attributes[:'object_version'] self. = attributes[:'dependentObjectMetadata'] if attributes[:'dependentObjectMetadata'] raise 'You cannot provide both :dependentObjectMetadata and :dependent_object_metadata' if attributes.key?(:'dependentObjectMetadata') && attributes.key?(:'dependent_object_metadata') self. = attributes[:'dependent_object_metadata'] if attributes[:'dependent_object_metadata'] self. = attributes[:'publishedObjectMetadata'] if attributes[:'publishedObjectMetadata'] raise 'You cannot provide both :publishedObjectMetadata and :published_object_metadata' if attributes.key?(:'publishedObjectMetadata') && attributes.key?(:'published_object_metadata') self. = attributes[:'published_object_metadata'] if attributes[:'published_object_metadata'] self.source_application_info = attributes[:'sourceApplicationInfo'] if attributes[:'sourceApplicationInfo'] raise 'You cannot provide both :sourceApplicationInfo and :source_application_info' if attributes.key?(:'sourceApplicationInfo') && attributes.key?(:'source_application_info') self.source_application_info = attributes[:'source_application_info'] if attributes[:'source_application_info'] self.time_patched = attributes[:'timePatched'] if attributes[:'timePatched'] raise 'You cannot provide both :timePatched and :time_patched' if attributes.key?(:'timePatched') && attributes.key?(:'time_patched') self.time_patched = attributes[:'time_patched'] if attributes[:'time_patched'] self. = attributes[:'metadata'] if attributes[:'metadata'] self.key_map = attributes[:'keyMap'] if attributes[:'keyMap'] raise 'You cannot provide both :keyMap and :key_map' if attributes.key?(:'keyMap') && attributes.key?(:'key_map') self.key_map = attributes[:'key_map'] if attributes[:'key_map'] end |
Instance Attribute Details
#application_version ⇒ Integer
The application’s version.
32 33 34 |
# File 'lib/oci/data_integration/models/dependent_object.rb', line 32 def application_version @application_version end |
#dependent_object_metadata ⇒ Array<OCI::DataIntegration::Models::PatchObjectMetadata>
A list of dependent objects in this patch.
51 52 53 |
# File 'lib/oci/data_integration/models/dependent_object.rb', line 51 def end |
#description ⇒ String
Detailed description for the object.
28 29 30 |
# File 'lib/oci/data_integration/models/dependent_object.rb', line 28 def description @description end |
#identifier ⇒ String
Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.
40 41 42 |
# File 'lib/oci/data_integration/models/dependent_object.rb', line 40 def identifier @identifier end |
#key ⇒ String
Generated key that can be used in API calls to identify application.
12 13 14 |
# File 'lib/oci/data_integration/models/dependent_object.rb', line 12 def key @key end |
#key_map ⇒ Hash<String, String>
A key map. If provided, key is replaced with generated key. This structure provides mapping between user provided key and generated key.
70 71 72 |
# File 'lib/oci/data_integration/models/dependent_object.rb', line 70 def key_map @key_map end |
#metadata ⇒ OCI::DataIntegration::Models::ObjectMetadata
66 67 68 |
# File 'lib/oci/data_integration/models/dependent_object.rb', line 66 def end |
#model_type ⇒ String
The object type.
16 17 18 |
# File 'lib/oci/data_integration/models/dependent_object.rb', line 16 def model_type @model_type end |
#model_version ⇒ String
The object’s model version.
20 21 22 |
# File 'lib/oci/data_integration/models/dependent_object.rb', line 20 def model_version @model_version end |
#name ⇒ String
Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.
24 25 26 |
# File 'lib/oci/data_integration/models/dependent_object.rb', line 24 def name @name end |
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
36 37 38 |
# File 'lib/oci/data_integration/models/dependent_object.rb', line 36 def object_status @object_status end |
#object_version ⇒ Integer
The version of the object that is used to track changes in the object instance.
47 48 49 |
# File 'lib/oci/data_integration/models/dependent_object.rb', line 47 def object_version @object_version end |
#parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
43 44 45 |
# File 'lib/oci/data_integration/models/dependent_object.rb', line 43 def parent_ref @parent_ref end |
#published_object_metadata ⇒ Hash<String, OCI::DataIntegration::Models::PatchObjectMetadata>
A list of objects that are published or unpublished in this patch.
55 56 57 |
# File 'lib/oci/data_integration/models/dependent_object.rb', line 55 def end |
#source_application_info ⇒ OCI::DataIntegration::Models::SourceApplicationInfo
58 59 60 |
# File 'lib/oci/data_integration/models/dependent_object.rb', line 58 def source_application_info @source_application_info end |
#time_patched ⇒ DateTime
The date and time the application was patched, in the timestamp format defined by RFC3339.
63 64 65 |
# File 'lib/oci/data_integration/models/dependent_object.rb', line 63 def time_patched @time_patched end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/oci/data_integration/models/dependent_object.rb', line 73 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'key': :'key', 'model_type': :'modelType', 'model_version': :'modelVersion', 'name': :'name', 'description': :'description', 'application_version': :'applicationVersion', 'object_status': :'objectStatus', 'identifier': :'identifier', 'parent_ref': :'parentRef', 'object_version': :'objectVersion', 'dependent_object_metadata': :'dependentObjectMetadata', 'published_object_metadata': :'publishedObjectMetadata', 'source_application_info': :'sourceApplicationInfo', 'time_patched': :'timePatched', 'metadata': :'metadata', 'key_map': :'keyMap' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/oci/data_integration/models/dependent_object.rb', line 97 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'key': :'String', 'model_type': :'String', 'model_version': :'String', 'name': :'String', 'description': :'String', 'application_version': :'Integer', 'object_status': :'Integer', 'identifier': :'String', 'parent_ref': :'OCI::DataIntegration::Models::ParentReference', 'object_version': :'Integer', 'dependent_object_metadata': :'Array<OCI::DataIntegration::Models::PatchObjectMetadata>', 'published_object_metadata': :'Hash<String, OCI::DataIntegration::Models::PatchObjectMetadata>', 'source_application_info': :'OCI::DataIntegration::Models::SourceApplicationInfo', 'time_patched': :'DateTime', 'metadata': :'OCI::DataIntegration::Models::ObjectMetadata', 'key_map': :'Hash<String, String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/oci/data_integration/models/dependent_object.rb', line 229 def ==(other) return true if equal?(other) self.class == other.class && key == other.key && model_type == other.model_type && model_version == other.model_version && name == other.name && description == other.description && application_version == other.application_version && object_status == other.object_status && identifier == other.identifier && parent_ref == other.parent_ref && object_version == other.object_version && == other. && == other. && source_application_info == other.source_application_info && time_patched == other.time_patched && == other. && key_map == other.key_map end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 |
# File 'lib/oci/data_integration/models/dependent_object.rb', line 274 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
254 255 256 |
# File 'lib/oci/data_integration/models/dependent_object.rb', line 254 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
263 264 265 |
# File 'lib/oci/data_integration/models/dependent_object.rb', line 263 def hash [key, model_type, model_version, name, description, application_version, object_status, identifier, parent_ref, object_version, , , source_application_info, time_patched, , key_map].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
307 308 309 310 311 312 313 314 315 316 |
# File 'lib/oci/data_integration/models/dependent_object.rb', line 307 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
301 302 303 |
# File 'lib/oci/data_integration/models/dependent_object.rb', line 301 def to_s to_hash.to_s end |