Class: OCI::DataIntegration::Models::DerivedField
- Inherits:
-
TypedObject
- Object
- TypedObject
- OCI::DataIntegration::Models::DerivedField
- Defined in:
- lib/oci/data_integration/models/derived_field.rb
Overview
The type representing the derived field concept. Derived fields have an expression to define how to derive the field.
Constant Summary
Constants inherited from TypedObject
Instance Attribute Summary collapse
- #expr ⇒ OCI::DataIntegration::Models::Expression
-
#is_use_inferred_type ⇒ BOOLEAN
Specifies whether to use inferred expression output type as output type of the derived field.
-
#labels ⇒ Array<String>
Labels are keywords or labels that you can add to data assets, dataflows and so on.
-
#type ⇒ String
The type of the field.
Attributes inherited from TypedObject
#config_values, #description, #key, #model_type, #model_version, #name, #object_status, #parent_ref
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DerivedField
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from TypedObject
Constructor Details
#initialize(attributes = {}) ⇒ DerivedField
Initializes the object
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/oci/data_integration/models/derived_field.rb', line 83 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['modelType'] = 'DERIVED_FIELD' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.expr = attributes[:'expr'] if attributes[:'expr'] self.type = attributes[:'type'] if attributes[:'type'] self.is_use_inferred_type = attributes[:'isUseInferredType'] unless attributes[:'isUseInferredType'].nil? self.is_use_inferred_type = false if is_use_inferred_type.nil? && !attributes.key?(:'isUseInferredType') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isUseInferredType and :is_use_inferred_type' if attributes.key?(:'isUseInferredType') && attributes.key?(:'is_use_inferred_type') self.is_use_inferred_type = attributes[:'is_use_inferred_type'] unless attributes[:'is_use_inferred_type'].nil? self.is_use_inferred_type = false if is_use_inferred_type.nil? && !attributes.key?(:'isUseInferredType') && !attributes.key?(:'is_use_inferred_type') # rubocop:disable Style/StringLiterals self.labels = attributes[:'labels'] if attributes[:'labels'] end |
Instance Attribute Details
#expr ⇒ OCI::DataIntegration::Models::Expression
12 13 14 |
# File 'lib/oci/data_integration/models/derived_field.rb', line 12 def expr @expr end |
#is_use_inferred_type ⇒ BOOLEAN
Specifies whether to use inferred expression output type as output type of the derived field. Default value of this flag is false.
20 21 22 |
# File 'lib/oci/data_integration/models/derived_field.rb', line 20 def is_use_inferred_type @is_use_inferred_type end |
#labels ⇒ Array<String>
Labels are keywords or labels that you can add to data assets, dataflows and so on. You can define your own labels and use them to categorize content.
24 25 26 |
# File 'lib/oci/data_integration/models/derived_field.rb', line 24 def labels @labels end |
#type ⇒ String
The type of the field.
16 17 18 |
# File 'lib/oci/data_integration/models/derived_field.rb', line 16 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 |
# File 'lib/oci/data_integration/models/derived_field.rb', line 27 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'key': :'key', 'model_version': :'modelVersion', 'parent_ref': :'parentRef', 'config_values': :'configValues', 'object_status': :'objectStatus', 'name': :'name', 'description': :'description', 'expr': :'expr', 'type': :'type', 'is_use_inferred_type': :'isUseInferredType', 'labels': :'labels' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/oci/data_integration/models/derived_field.rb', line 47 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'key': :'String', 'model_version': :'String', 'parent_ref': :'OCI::DataIntegration::Models::ParentReference', 'config_values': :'OCI::DataIntegration::Models::ConfigValues', 'object_status': :'Integer', 'name': :'String', 'description': :'String', 'expr': :'OCI::DataIntegration::Models::Expression', 'type': :'String', 'is_use_inferred_type': :'BOOLEAN', 'labels': :'Array<String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/oci/data_integration/models/derived_field.rb', line 115 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && key == other.key && model_version == other.model_version && parent_ref == other.parent_ref && config_values == other.config_values && object_status == other.object_status && name == other.name && description == other.description && expr == other.expr && type == other.type && is_use_inferred_type == other.is_use_inferred_type && labels == other.labels end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/oci/data_integration/models/derived_field.rb', line 156 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
136 137 138 |
# File 'lib/oci/data_integration/models/derived_field.rb', line 136 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
145 146 147 |
# File 'lib/oci/data_integration/models/derived_field.rb', line 145 def hash [model_type, key, model_version, parent_ref, config_values, object_status, name, description, expr, type, is_use_inferred_type, labels].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
189 190 191 192 193 194 195 196 197 198 |
# File 'lib/oci/data_integration/models/derived_field.rb', line 189 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
183 184 185 |
# File 'lib/oci/data_integration/models/derived_field.rb', line 183 def to_s to_hash.to_s end |