Class: OCI::DataIntegration::Models::DirectNamedFieldMap
- Defined in:
- lib/oci/data_integration/models/direct_named_field_map.rb
Overview
A named field map.
Constant Summary
Constants inherited from FieldMap
Instance Attribute Summary collapse
- #config_values ⇒ OCI::DataIntegration::Models::ConfigValues
-
#key ⇒ String
The object key.
-
#model_version ⇒ String
The object's model version.
-
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
- #parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
-
#source_field_name ⇒ String
The source field name.
- #source_scope_reference ⇒ OCI::DataIntegration::Models::ScopeReference
-
#source_typed_object ⇒ String
Deprecated - Reference to a typed object.
-
#target_field_name ⇒ String
The target field name.
- #target_scope_reference ⇒ OCI::DataIntegration::Models::ScopeReference
-
#target_typed_object ⇒ String
Deprecated - Reference to a typed object.
Attributes inherited from FieldMap
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DirectNamedFieldMap
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from FieldMap
Constructor Details
#initialize(attributes = {}) ⇒ DirectNamedFieldMap
Initializes the object
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/oci/data_integration/models/direct_named_field_map.rb', line 111 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['modelType'] = 'DIRECT_NAMED_FIELD_MAP' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.key = attributes[:'key'] if attributes[:'key'] self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion'] raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version') self.model_version = attributes[:'model_version'] if attributes[:'model_version'] self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef'] raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref') self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref'] self.config_values = attributes[:'configValues'] if attributes[:'configValues'] raise 'You cannot provide both :configValues and :config_values' if attributes.key?(:'configValues') && attributes.key?(:'config_values') self.config_values = attributes[:'config_values'] if attributes[:'config_values'] self.source_typed_object = attributes[:'sourceTypedObject'] if attributes[:'sourceTypedObject'] raise 'You cannot provide both :sourceTypedObject and :source_typed_object' if attributes.key?(:'sourceTypedObject') && attributes.key?(:'source_typed_object') self.source_typed_object = attributes[:'source_typed_object'] if attributes[:'source_typed_object'] self.target_typed_object = attributes[:'targetTypedObject'] if attributes[:'targetTypedObject'] raise 'You cannot provide both :targetTypedObject and :target_typed_object' if attributes.key?(:'targetTypedObject') && attributes.key?(:'target_typed_object') self.target_typed_object = attributes[:'target_typed_object'] if attributes[:'target_typed_object'] self.source_scope_reference = attributes[:'sourceScopeReference'] if attributes[:'sourceScopeReference'] raise 'You cannot provide both :sourceScopeReference and :source_scope_reference' if attributes.key?(:'sourceScopeReference') && attributes.key?(:'source_scope_reference') self.source_scope_reference = attributes[:'source_scope_reference'] if attributes[:'source_scope_reference'] self.target_scope_reference = attributes[:'targetScopeReference'] if attributes[:'targetScopeReference'] raise 'You cannot provide both :targetScopeReference and :target_scope_reference' if attributes.key?(:'targetScopeReference') && attributes.key?(:'target_scope_reference') self.target_scope_reference = attributes[:'target_scope_reference'] if attributes[:'target_scope_reference'] self.source_field_name = attributes[:'sourceFieldName'] if attributes[:'sourceFieldName'] raise 'You cannot provide both :sourceFieldName and :source_field_name' if attributes.key?(:'sourceFieldName') && attributes.key?(:'source_field_name') self.source_field_name = attributes[:'source_field_name'] if attributes[:'source_field_name'] self.target_field_name = attributes[:'targetFieldName'] if attributes[:'targetFieldName'] raise 'You cannot provide both :targetFieldName and :target_field_name' if attributes.key?(:'targetFieldName') && attributes.key?(:'target_field_name') self.target_field_name = attributes[:'target_field_name'] if attributes[:'target_field_name'] self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus'] raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status') self.object_status = attributes[:'object_status'] if attributes[:'object_status'] end |
Instance Attribute Details
#config_values ⇒ OCI::DataIntegration::Models::ConfigValues
23 24 25 |
# File 'lib/oci/data_integration/models/direct_named_field_map.rb', line 23 def config_values @config_values end |
#key ⇒ String
The object key.
13 14 15 |
# File 'lib/oci/data_integration/models/direct_named_field_map.rb', line 13 def key @key end |
#model_version ⇒ String
The object's model version.
17 18 19 |
# File 'lib/oci/data_integration/models/direct_named_field_map.rb', line 17 def model_version @model_version end |
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
49 50 51 |
# File 'lib/oci/data_integration/models/direct_named_field_map.rb', line 49 def object_status @object_status end |
#parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
20 21 22 |
# File 'lib/oci/data_integration/models/direct_named_field_map.rb', line 20 def parent_ref @parent_ref end |
#source_field_name ⇒ String
The source field name.
41 42 43 |
# File 'lib/oci/data_integration/models/direct_named_field_map.rb', line 41 def source_field_name @source_field_name end |
#source_scope_reference ⇒ OCI::DataIntegration::Models::ScopeReference
34 35 36 |
# File 'lib/oci/data_integration/models/direct_named_field_map.rb', line 34 def source_scope_reference @source_scope_reference end |
#source_typed_object ⇒ String
Deprecated - Reference to a typed object.
27 28 29 |
# File 'lib/oci/data_integration/models/direct_named_field_map.rb', line 27 def source_typed_object @source_typed_object end |
#target_field_name ⇒ String
The target field name.
45 46 47 |
# File 'lib/oci/data_integration/models/direct_named_field_map.rb', line 45 def target_field_name @target_field_name end |
#target_scope_reference ⇒ OCI::DataIntegration::Models::ScopeReference
37 38 39 |
# File 'lib/oci/data_integration/models/direct_named_field_map.rb', line 37 def target_scope_reference @target_scope_reference end |
#target_typed_object ⇒ String
Deprecated - Reference to a typed object
31 32 33 |
# File 'lib/oci/data_integration/models/direct_named_field_map.rb', line 31 def target_typed_object @target_typed_object end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/oci/data_integration/models/direct_named_field_map.rb', line 52 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'description': :'description', 'key': :'key', 'model_version': :'modelVersion', 'parent_ref': :'parentRef', 'config_values': :'configValues', 'source_typed_object': :'sourceTypedObject', 'target_typed_object': :'targetTypedObject', 'source_scope_reference': :'sourceScopeReference', 'target_scope_reference': :'targetScopeReference', 'source_field_name': :'sourceFieldName', 'target_field_name': :'targetFieldName', 'object_status': :'objectStatus' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/oci/data_integration/models/direct_named_field_map.rb', line 73 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'description': :'String', 'key': :'String', 'model_version': :'String', 'parent_ref': :'OCI::DataIntegration::Models::ParentReference', 'config_values': :'OCI::DataIntegration::Models::ConfigValues', 'source_typed_object': :'String', 'target_typed_object': :'String', 'source_scope_reference': :'OCI::DataIntegration::Models::ScopeReference', 'target_scope_reference': :'OCI::DataIntegration::Models::ScopeReference', 'source_field_name': :'String', 'target_field_name': :'String', 'object_status': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/oci/data_integration/models/direct_named_field_map.rb', line 191 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && description == other.description && key == other.key && model_version == other.model_version && parent_ref == other.parent_ref && config_values == other.config_values && source_typed_object == other.source_typed_object && target_typed_object == other.target_typed_object && source_scope_reference == other.source_scope_reference && target_scope_reference == other.target_scope_reference && source_field_name == other.source_field_name && target_field_name == other.target_field_name && object_status == other.object_status end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/oci/data_integration/models/direct_named_field_map.rb', line 233 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
213 214 215 |
# File 'lib/oci/data_integration/models/direct_named_field_map.rb', line 213 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
222 223 224 |
# File 'lib/oci/data_integration/models/direct_named_field_map.rb', line 222 def hash [model_type, description, key, model_version, parent_ref, config_values, source_typed_object, target_typed_object, source_scope_reference, target_scope_reference, source_field_name, target_field_name, object_status].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
266 267 268 269 270 271 272 273 274 275 |
# File 'lib/oci/data_integration/models/direct_named_field_map.rb', line 266 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
260 261 262 |
# File 'lib/oci/data_integration/models/direct_named_field_map.rb', line 260 def to_s to_hash.to_s end |