Class: OCI::DataIntegration::Models::DisApplicationSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_integration/models/dis_application_summary.rb

Overview

The application summary type contains the audit summary information and the definition of the application.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DisApplicationSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
# File 'lib/oci/data_integration/models/dis_application_summary.rb', line 216

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  self.key = attributes[:'key'] if attributes[:'key']

  self.model_type = attributes[:'modelType'] if attributes[:'modelType']

  raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type')

  self.model_type = attributes[:'model_type'] if attributes[:'model_type']

  self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion']

  raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version')

  self.model_version = attributes[:'model_version'] if attributes[:'model_version']

  self.name = attributes[:'name'] if attributes[:'name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.application_version = attributes[:'applicationVersion'] if attributes[:'applicationVersion']

  raise 'You cannot provide both :applicationVersion and :application_version' if attributes.key?(:'applicationVersion') && attributes.key?(:'application_version')

  self.application_version = attributes[:'application_version'] if attributes[:'application_version']

  self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus']

  raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status')

  self.object_status = attributes[:'object_status'] if attributes[:'object_status']

  self.identifier = attributes[:'identifier'] if attributes[:'identifier']

  self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef']

  raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref')

  self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref']

  self.object_version = attributes[:'objectVersion'] if attributes[:'objectVersion']

  raise 'You cannot provide both :objectVersion and :object_version' if attributes.key?(:'objectVersion') && attributes.key?(:'object_version')

  self.object_version = attributes[:'object_version'] if attributes[:'object_version']

  self. = attributes[:'dependentObjectMetadata'] if attributes[:'dependentObjectMetadata']

  raise 'You cannot provide both :dependentObjectMetadata and :dependent_object_metadata' if attributes.key?(:'dependentObjectMetadata') && attributes.key?(:'dependent_object_metadata')

  self. = attributes[:'dependent_object_metadata'] if attributes[:'dependent_object_metadata']

  self. = attributes[:'publishedObjectMetadata'] if attributes[:'publishedObjectMetadata']

  raise 'You cannot provide both :publishedObjectMetadata and :published_object_metadata' if attributes.key?(:'publishedObjectMetadata') && attributes.key?(:'published_object_metadata')

  self. = attributes[:'published_object_metadata'] if attributes[:'published_object_metadata']

  self.source_application_info = attributes[:'sourceApplicationInfo'] if attributes[:'sourceApplicationInfo']

  raise 'You cannot provide both :sourceApplicationInfo and :source_application_info' if attributes.key?(:'sourceApplicationInfo') && attributes.key?(:'source_application_info')

  self.source_application_info = attributes[:'source_application_info'] if attributes[:'source_application_info']

  self.time_patched = attributes[:'timePatched'] if attributes[:'timePatched']

  raise 'You cannot provide both :timePatched and :time_patched' if attributes.key?(:'timePatched') && attributes.key?(:'time_patched')

  self.time_patched = attributes[:'time_patched'] if attributes[:'time_patched']

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self. = attributes[:'metadata'] if attributes[:'metadata']

  self.key_map = attributes[:'keyMap'] if attributes[:'keyMap']

  raise 'You cannot provide both :keyMap and :key_map' if attributes.key?(:'keyMap') && attributes.key?(:'key_map')

  self.key_map = attributes[:'key_map'] if attributes[:'key_map']
end

Instance Attribute Details

#application_versionInteger

The application's version.

Returns:

  • (Integer)


43
44
45
# File 'lib/oci/data_integration/models/dis_application_summary.rb', line 43

def application_version
  @application_version
end

#compartment_idString

OCID of the compartment that this resource belongs to. Defaults to compartment of the Workspace.

Returns:

  • (String)


82
83
84
# File 'lib/oci/data_integration/models/dis_application_summary.rb', line 82

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Usage of predefined tag keys. These predefined keys are scoped to namespaces. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


109
110
111
# File 'lib/oci/data_integration/models/dis_application_summary.rb', line 109

def defined_tags
  @defined_tags
end

#dependent_object_metadataArray<OCI::DataIntegration::Models::PatchObjectMetadata>

A list of dependent objects in this patch.



62
63
64
# File 'lib/oci/data_integration/models/dis_application_summary.rb', line 62

def 
  @dependent_object_metadata
end

#descriptionString

Detailed description for the object.

Returns:

  • (String)


39
40
41
# File 'lib/oci/data_integration/models/dis_application_summary.rb', line 39

def description
  @description
end

#display_nameString

Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.

Returns:

  • (String)


86
87
88
# File 'lib/oci/data_integration/models/dis_application_summary.rb', line 86

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`

Returns:

  • (Hash<String, String>)


103
104
105
# File 'lib/oci/data_integration/models/dis_application_summary.rb', line 103

def freeform_tags
  @freeform_tags
end

#idString

OCID of the resource that is used to uniquely identify the application

Returns:

  • (String)


78
79
80
# File 'lib/oci/data_integration/models/dis_application_summary.rb', line 78

def id
  @id
end

#identifierString

Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.

Returns:

  • (String)


51
52
53
# File 'lib/oci/data_integration/models/dis_application_summary.rb', line 51

def identifier
  @identifier
end

#keyString

Generated key that can be used in API calls to identify application.

Returns:

  • (String)


23
24
25
# File 'lib/oci/data_integration/models/dis_application_summary.rb', line 23

def key
  @key
end

#key_mapHash<String, String>

A key map. If provided, key is replaced with generated key. This structure provides mapping between user provided key and generated key.

Returns:

  • (Hash<String, String>)


120
121
122
# File 'lib/oci/data_integration/models/dis_application_summary.rb', line 120

def key_map
  @key_map
end

#lifecycle_stateString

The current state of the workspace.

Returns:

  • (String)


113
114
115
# File 'lib/oci/data_integration/models/dis_application_summary.rb', line 113

def lifecycle_state
  @lifecycle_state
end

#metadataOCI::DataIntegration::Models::ObjectMetadata



116
117
118
# File 'lib/oci/data_integration/models/dis_application_summary.rb', line 116

def 
  @metadata
end

#model_typeString

The object type.

Returns:

  • (String)


27
28
29
# File 'lib/oci/data_integration/models/dis_application_summary.rb', line 27

def model_type
  @model_type
end

#model_versionString

The object's model version.

Returns:

  • (String)


31
32
33
# File 'lib/oci/data_integration/models/dis_application_summary.rb', line 31

def model_version
  @model_version
end

#nameString

Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.

Returns:

  • (String)


35
36
37
# File 'lib/oci/data_integration/models/dis_application_summary.rb', line 35

def name
  @name
end

#object_statusInteger

The status of an object that can be set to value 1 for shallow references across objects, other values reserved.

Returns:

  • (Integer)


47
48
49
# File 'lib/oci/data_integration/models/dis_application_summary.rb', line 47

def object_status
  @object_status
end

#object_versionInteger

The version of the object that is used to track changes in the object instance.

Returns:

  • (Integer)


58
59
60
# File 'lib/oci/data_integration/models/dis_application_summary.rb', line 58

def object_version
  @object_version
end

#parent_refOCI::DataIntegration::Models::ParentReference



54
55
56
# File 'lib/oci/data_integration/models/dis_application_summary.rb', line 54

def parent_ref
  @parent_ref
end

#published_object_metadataHash<String, OCI::DataIntegration::Models::PatchObjectMetadata>

A list of objects that are published or unpublished in this patch.



66
67
68
# File 'lib/oci/data_integration/models/dis_application_summary.rb', line 66

def 
  @published_object_metadata
end

#source_application_infoOCI::DataIntegration::Models::SourceApplicationInfo



69
70
71
# File 'lib/oci/data_integration/models/dis_application_summary.rb', line 69

def source_application_info
  @source_application_info
end

#time_createdDateTime

The date and time the application was created, in the timestamp format defined by RFC3339.

Returns:

  • (DateTime)


91
92
93
# File 'lib/oci/data_integration/models/dis_application_summary.rb', line 91

def time_created
  @time_created
end

#time_patchedDateTime

The date and time the application was patched, in the timestamp format defined by RFC3339.

Returns:

  • (DateTime)


74
75
76
# File 'lib/oci/data_integration/models/dis_application_summary.rb', line 74

def time_patched
  @time_patched
end

#time_updatedDateTime

The date and time the application was updated, in the timestamp format defined by RFC3339. example: 2019-08-25T21:10:29.41Z

Returns:

  • (DateTime)


97
98
99
# File 'lib/oci/data_integration/models/dis_application_summary.rb', line 97

def time_updated
  @time_updated
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/oci/data_integration/models/dis_application_summary.rb', line 123

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'key',
    'model_type': :'modelType',
    'model_version': :'modelVersion',
    'name': :'name',
    'description': :'description',
    'application_version': :'applicationVersion',
    'object_status': :'objectStatus',
    'identifier': :'identifier',
    'parent_ref': :'parentRef',
    'object_version': :'objectVersion',
    'dependent_object_metadata': :'dependentObjectMetadata',
    'published_object_metadata': :'publishedObjectMetadata',
    'source_application_info': :'sourceApplicationInfo',
    'time_patched': :'timePatched',
    'id': :'id',
    'compartment_id': :'compartmentId',
    'display_name': :'displayName',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'lifecycle_state': :'lifecycleState',
    'metadata': :'metadata',
    'key_map': :'keyMap'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/oci/data_integration/models/dis_application_summary.rb', line 155

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'String',
    'model_type': :'String',
    'model_version': :'String',
    'name': :'String',
    'description': :'String',
    'application_version': :'Integer',
    'object_status': :'Integer',
    'identifier': :'String',
    'parent_ref': :'OCI::DataIntegration::Models::ParentReference',
    'object_version': :'Integer',
    'dependent_object_metadata': :'Array<OCI::DataIntegration::Models::PatchObjectMetadata>',
    'published_object_metadata': :'Hash<String, OCI::DataIntegration::Models::PatchObjectMetadata>',
    'source_application_info': :'OCI::DataIntegration::Models::SourceApplicationInfo',
    'time_patched': :'DateTime',
    'id': :'String',
    'compartment_id': :'String',
    'display_name': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'lifecycle_state': :'String',
    'metadata': :'OCI::DataIntegration::Models::ObjectMetadata',
    'key_map': :'Hash<String, String>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
# File 'lib/oci/data_integration/models/dis_application_summary.rb', line 360

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    key == other.key &&
    model_type == other.model_type &&
    model_version == other.model_version &&
    name == other.name &&
    description == other.description &&
    application_version == other.application_version &&
    object_status == other.object_status &&
    identifier == other.identifier &&
    parent_ref == other.parent_ref &&
    object_version == other.object_version &&
     == other. &&
     == other. &&
    source_application_info == other.source_application_info &&
    time_patched == other.time_patched &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    display_name == other.display_name &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    lifecycle_state == other.lifecycle_state &&
     == other. &&
    key_map == other.key_map
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
# File 'lib/oci/data_integration/models/dis_application_summary.rb', line 413

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


393
394
395
# File 'lib/oci/data_integration/models/dis_application_summary.rb', line 393

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



402
403
404
# File 'lib/oci/data_integration/models/dis_application_summary.rb', line 402

def hash
  [key, model_type, model_version, name, description, application_version, object_status, identifier, parent_ref, object_version, , , source_application_info, time_patched, id, compartment_id, display_name, time_created, time_updated, freeform_tags, defined_tags, lifecycle_state, , key_map].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



446
447
448
449
450
451
452
453
454
455
# File 'lib/oci/data_integration/models/dis_application_summary.rb', line 446

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



440
441
442
# File 'lib/oci/data_integration/models/dis_application_summary.rb', line 440

def to_s
  to_hash.to_s
end