Class: OCI::DataIntegration::Models::DynamicProxyField

Inherits:
TypedObject
  • Object
show all
Defined in:
lib/oci/data_integration/models/dynamic_proxy_field.rb

Overview

The type representing the dynamic proxy field concept. Dynamic proxy fields have a reference to another field.

Constant Summary

Constants inherited from TypedObject

TypedObject::MODEL_TYPE_ENUM

Instance Attribute Summary collapse

Attributes inherited from TypedObject

#config_values, #description, #key, #model_type, #model_version, #name, #object_status, #parent_ref

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from TypedObject

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ DynamicProxyField

Initializes the object

Options Hash (attributes):



69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/oci/data_integration/models/dynamic_proxy_field.rb', line 69

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['modelType'] = 'DYNAMIC_PROXY_FIELD'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.type = attributes[:'type'] if attributes[:'type']

  self.labels = attributes[:'labels'] if attributes[:'labels']
end

Instance Attribute Details

#labelsArray<String>

Labels are keywords or labels that you can add to data assets, dataflows and so on. You can define your own labels and use them to categorize content.



16
17
18
# File 'lib/oci/data_integration/models/dynamic_proxy_field.rb', line 16

def labels
  @labels
end

#typeOCI::DataIntegration::Models::BaseType



12
13
14
# File 'lib/oci/data_integration/models/dynamic_proxy_field.rb', line 12

def type
  @type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
# File 'lib/oci/data_integration/models/dynamic_proxy_field.rb', line 19

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'modelType',
    'key': :'key',
    'model_version': :'modelVersion',
    'parent_ref': :'parentRef',
    'config_values': :'configValues',
    'object_status': :'objectStatus',
    'name': :'name',
    'description': :'description',
    'type': :'type',
    'labels': :'labels'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
# File 'lib/oci/data_integration/models/dynamic_proxy_field.rb', line 37

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'String',
    'key': :'String',
    'model_version': :'String',
    'parent_ref': :'OCI::DataIntegration::Models::ParentReference',
    'config_values': :'OCI::DataIntegration::Models::ConfigValues',
    'object_status': :'Integer',
    'name': :'String',
    'description': :'String',
    'type': :'OCI::DataIntegration::Models::BaseType',
    'labels': :'Array<String>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/oci/data_integration/models/dynamic_proxy_field.rb', line 91

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    model_type == other.model_type &&
    key == other.key &&
    model_version == other.model_version &&
    parent_ref == other.parent_ref &&
    config_values == other.config_values &&
    object_status == other.object_status &&
    name == other.name &&
    description == other.description &&
    type == other.type &&
    labels == other.labels
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/oci/data_integration/models/dynamic_proxy_field.rb', line 130

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method


110
111
112
# File 'lib/oci/data_integration/models/dynamic_proxy_field.rb', line 110

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.



119
120
121
# File 'lib/oci/data_integration/models/dynamic_proxy_field.rb', line 119

def hash
  [model_type, key, model_version, parent_ref, config_values, object_status, name, description, type, labels].hash
end

#to_hashHash

Returns the object in the form of hash



163
164
165
166
167
168
169
170
171
172
# File 'lib/oci/data_integration/models/dynamic_proxy_field.rb', line 163

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



157
158
159
# File 'lib/oci/data_integration/models/dynamic_proxy_field.rb', line 157

def to_s
  to_hash.to_s
end