Class: OCI::DataIntegration::Models::EnrichedEntity

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_integration/models/enriched_entity.rb

Overview

This is used to specify runtime parameters for data entities such as files that need both the data entity and the format.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ EnrichedEntity

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/oci/data_integration/models/enriched_entity.rb', line 57

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.entity = attributes[:'entity'] if attributes[:'entity']

  self.data_format = attributes[:'dataFormat'] if attributes[:'dataFormat']

  raise 'You cannot provide both :dataFormat and :data_format' if attributes.key?(:'dataFormat') && attributes.key?(:'data_format')

  self.data_format = attributes[:'data_format'] if attributes[:'data_format']

  self.model_type = attributes[:'modelType'] if attributes[:'modelType']

  raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type')

  self.model_type = attributes[:'model_type'] if attributes[:'model_type']

  self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef']

  raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref')

  self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref']
end

Instance Attribute Details

#data_formatOCI::DataIntegration::Models::DataFormat



14
15
16
# File 'lib/oci/data_integration/models/enriched_entity.rb', line 14

def data_format
  @data_format
end

#entityOCI::DataIntegration::Models::DataEntity



11
12
13
# File 'lib/oci/data_integration/models/enriched_entity.rb', line 11

def entity
  @entity
end

#model_typeString

The model type for the entity which is referenced.

Returns:

  • (String)


18
19
20
# File 'lib/oci/data_integration/models/enriched_entity.rb', line 18

def model_type
  @model_type
end

#parent_refOCI::DataIntegration::Models::ParentReference



21
22
23
# File 'lib/oci/data_integration/models/enriched_entity.rb', line 21

def parent_ref
  @parent_ref
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



24
25
26
27
28
29
30
31
32
33
# File 'lib/oci/data_integration/models/enriched_entity.rb', line 24

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'entity': :'entity',
    'data_format': :'dataFormat',
    'model_type': :'modelType',
    'parent_ref': :'parentRef'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



36
37
38
39
40
41
42
43
44
45
# File 'lib/oci/data_integration/models/enriched_entity.rb', line 36

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'entity': :'OCI::DataIntegration::Models::DataEntity',
    'data_format': :'OCI::DataIntegration::Models::DataFormat',
    'model_type': :'String',
    'parent_ref': :'OCI::DataIntegration::Models::ParentReference'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



91
92
93
94
95
96
97
98
99
# File 'lib/oci/data_integration/models/enriched_entity.rb', line 91

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    entity == other.entity &&
    data_format == other.data_format &&
    model_type == other.model_type &&
    parent_ref == other.parent_ref
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/oci/data_integration/models/enriched_entity.rb', line 124

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


104
105
106
# File 'lib/oci/data_integration/models/enriched_entity.rb', line 104

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



113
114
115
# File 'lib/oci/data_integration/models/enriched_entity.rb', line 113

def hash
  [entity, data_format, model_type, parent_ref].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



157
158
159
160
161
162
163
164
165
166
# File 'lib/oci/data_integration/models/enriched_entity.rb', line 157

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



151
152
153
# File 'lib/oci/data_integration/models/enriched_entity.rb', line 151

def to_s
  to_hash.to_s
end