Class: OCI::DataIntegration::Models::ExternalPublication
- Inherits:
-
Object
- Object
- OCI::DataIntegration::Models::ExternalPublication
- Defined in:
- lib/oci/data_integration/models/external_publication.rb
Overview
The external published object contains the audit summary information and the definition of the task.
Constant Summary collapse
- STATUS_ENUM =
[ STATUS_SUCCESSFUL = 'SUCCESSFUL'.freeze, STATUS_FAILED = 'FAILED'.freeze, STATUS_PUBLISHING = 'PUBLISHING'.freeze, STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#application_compartment_id ⇒ String
The OCID of the compartment where the application is created in the Oracle Cloud Infrastructure Data Flow Service.
-
#application_id ⇒ String
The unique OCID of the identifier that is returned after creating the Oracle Cloud Infrastructure Data Flow application.
- #configuration_details ⇒ OCI::DataIntegration::Models::ConfigurationDetails
-
#description ⇒ String
Detailed description for the object.
-
#display_name ⇒ String
The name of the application.
-
#error_message ⇒ String
The error of the published object in the application.
-
#identifier ⇒ String
Value can only contain upper case letters, underscore, and numbers.
-
#key ⇒ String
The object key.
-
#key_map ⇒ Hash<String, String>
A key map.
- #metadata ⇒ OCI::DataIntegration::Models::ObjectMetadata
-
#model_type ⇒ String
The object type.
-
#model_version ⇒ String
This is a version number that is used by the service to upgrade objects if needed through releases of the service.
-
#name ⇒ String
Free form text without any restriction on permitted characters.
-
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects.
-
#object_version ⇒ Integer
The version of the object that is used to track changes in the object instance.
- #parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
- #resource_configuration ⇒ OCI::DataIntegration::Models::ResourceConfiguration
-
#status ⇒ String
The status of the publishing action to Oracle Cloud Infrastructure Data Flow.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ExternalPublication
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ExternalPublication
Initializes the object
162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/oci/data_integration/models/external_publication.rb', line 162 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.application_id = attributes[:'applicationId'] if attributes[:'applicationId'] raise 'You cannot provide both :applicationId and :application_id' if attributes.key?(:'applicationId') && attributes.key?(:'application_id') self.application_id = attributes[:'application_id'] if attributes[:'application_id'] self.application_compartment_id = attributes[:'applicationCompartmentId'] if attributes[:'applicationCompartmentId'] raise 'You cannot provide both :applicationCompartmentId and :application_compartment_id' if attributes.key?(:'applicationCompartmentId') && attributes.key?(:'application_compartment_id') self.application_compartment_id = attributes[:'application_compartment_id'] if attributes[:'application_compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.resource_configuration = attributes[:'resourceConfiguration'] if attributes[:'resourceConfiguration'] raise 'You cannot provide both :resourceConfiguration and :resource_configuration' if attributes.key?(:'resourceConfiguration') && attributes.key?(:'resource_configuration') self.resource_configuration = attributes[:'resource_configuration'] if attributes[:'resource_configuration'] self.configuration_details = attributes[:'configurationDetails'] if attributes[:'configurationDetails'] raise 'You cannot provide both :configurationDetails and :configuration_details' if attributes.key?(:'configurationDetails') && attributes.key?(:'configuration_details') self.configuration_details = attributes[:'configuration_details'] if attributes[:'configuration_details'] self.status = attributes[:'status'] if attributes[:'status'] self. = attributes[:'errorMessage'] if attributes[:'errorMessage'] raise 'You cannot provide both :errorMessage and :error_message' if attributes.key?(:'errorMessage') && attributes.key?(:'error_message') self. = attributes[:'error_message'] if attributes[:'error_message'] self.key = attributes[:'key'] if attributes[:'key'] self.model_type = attributes[:'modelType'] if attributes[:'modelType'] raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type') self.model_type = attributes[:'model_type'] if attributes[:'model_type'] self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion'] raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version') self.model_version = attributes[:'model_version'] if attributes[:'model_version'] self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.object_version = attributes[:'objectVersion'] if attributes[:'objectVersion'] raise 'You cannot provide both :objectVersion and :object_version' if attributes.key?(:'objectVersion') && attributes.key?(:'object_version') self.object_version = attributes[:'object_version'] if attributes[:'object_version'] self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus'] raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status') self.object_status = attributes[:'object_status'] if attributes[:'object_status'] self.identifier = attributes[:'identifier'] if attributes[:'identifier'] self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef'] raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref') self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref'] self. = attributes[:'metadata'] if attributes[:'metadata'] self.key_map = attributes[:'keyMap'] if attributes[:'keyMap'] raise 'You cannot provide both :keyMap and :key_map' if attributes.key?(:'keyMap') && attributes.key?(:'key_map') self.key_map = attributes[:'key_map'] if attributes[:'key_map'] end |
Instance Attribute Details
#application_compartment_id ⇒ String
The OCID of the compartment where the application is created in the Oracle Cloud Infrastructure Data Flow Service.
24 25 26 |
# File 'lib/oci/data_integration/models/external_publication.rb', line 24 def application_compartment_id @application_compartment_id end |
#application_id ⇒ String
The unique OCID of the identifier that is returned after creating the Oracle Cloud Infrastructure Data Flow application.
20 21 22 |
# File 'lib/oci/data_integration/models/external_publication.rb', line 20 def application_id @application_id end |
#configuration_details ⇒ OCI::DataIntegration::Models::ConfigurationDetails
34 35 36 |
# File 'lib/oci/data_integration/models/external_publication.rb', line 34 def configuration_details @configuration_details end |
#description ⇒ String
Detailed description for the object.
62 63 64 |
# File 'lib/oci/data_integration/models/external_publication.rb', line 62 def description @description end |
#display_name ⇒ String
The name of the application.
28 29 30 |
# File 'lib/oci/data_integration/models/external_publication.rb', line 28 def display_name @display_name end |
#error_message ⇒ String
The error of the published object in the application.
42 43 44 |
# File 'lib/oci/data_integration/models/external_publication.rb', line 42 def end |
#identifier ⇒ String
Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.
74 75 76 |
# File 'lib/oci/data_integration/models/external_publication.rb', line 74 def identifier @identifier end |
#key ⇒ String
The object key.
46 47 48 |
# File 'lib/oci/data_integration/models/external_publication.rb', line 46 def key @key end |
#key_map ⇒ Hash<String, String>
A key map. If provided, key is replaced with generated key. This structure provides mapping between user provided key and generated key.
84 85 86 |
# File 'lib/oci/data_integration/models/external_publication.rb', line 84 def key_map @key_map end |
#metadata ⇒ OCI::DataIntegration::Models::ObjectMetadata
80 81 82 |
# File 'lib/oci/data_integration/models/external_publication.rb', line 80 def end |
#model_type ⇒ String
The object type.
50 51 52 |
# File 'lib/oci/data_integration/models/external_publication.rb', line 50 def model_type @model_type end |
#model_version ⇒ String
This is a version number that is used by the service to upgrade objects if needed through releases of the service.
54 55 56 |
# File 'lib/oci/data_integration/models/external_publication.rb', line 54 def model_version @model_version end |
#name ⇒ String
Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.
58 59 60 |
# File 'lib/oci/data_integration/models/external_publication.rb', line 58 def name @name end |
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects. Other values are reserved.
70 71 72 |
# File 'lib/oci/data_integration/models/external_publication.rb', line 70 def object_status @object_status end |
#object_version ⇒ Integer
The version of the object that is used to track changes in the object instance.
66 67 68 |
# File 'lib/oci/data_integration/models/external_publication.rb', line 66 def object_version @object_version end |
#parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
77 78 79 |
# File 'lib/oci/data_integration/models/external_publication.rb', line 77 def parent_ref @parent_ref end |
#resource_configuration ⇒ OCI::DataIntegration::Models::ResourceConfiguration
31 32 33 |
# File 'lib/oci/data_integration/models/external_publication.rb', line 31 def resource_configuration @resource_configuration end |
#status ⇒ String
The status of the publishing action to Oracle Cloud Infrastructure Data Flow.
38 39 40 |
# File 'lib/oci/data_integration/models/external_publication.rb', line 38 def status @status end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/oci/data_integration/models/external_publication.rb', line 87 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'application_id': :'applicationId', 'application_compartment_id': :'applicationCompartmentId', 'display_name': :'displayName', 'resource_configuration': :'resourceConfiguration', 'configuration_details': :'configurationDetails', 'status': :'status', 'error_message': :'errorMessage', 'key': :'key', 'model_type': :'modelType', 'model_version': :'modelVersion', 'name': :'name', 'description': :'description', 'object_version': :'objectVersion', 'object_status': :'objectStatus', 'identifier': :'identifier', 'parent_ref': :'parentRef', 'metadata': :'metadata', 'key_map': :'keyMap' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/oci/data_integration/models/external_publication.rb', line 113 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'application_id': :'String', 'application_compartment_id': :'String', 'display_name': :'String', 'resource_configuration': :'OCI::DataIntegration::Models::ResourceConfiguration', 'configuration_details': :'OCI::DataIntegration::Models::ConfigurationDetails', 'status': :'String', 'error_message': :'String', 'key': :'String', 'model_type': :'String', 'model_version': :'String', 'name': :'String', 'description': :'String', 'object_version': :'Integer', 'object_status': :'Integer', 'identifier': :'String', 'parent_ref': :'OCI::DataIntegration::Models::ParentReference', 'metadata': :'OCI::DataIntegration::Models::ObjectMetadata', 'key_map': :'Hash<String, String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/oci/data_integration/models/external_publication.rb', line 273 def ==(other) return true if equal?(other) self.class == other.class && application_id == other.application_id && application_compartment_id == other.application_compartment_id && display_name == other.display_name && resource_configuration == other.resource_configuration && configuration_details == other.configuration_details && status == other.status && == other. && key == other.key && model_type == other.model_type && model_version == other.model_version && name == other.name && description == other.description && object_version == other.object_version && object_status == other.object_status && identifier == other.identifier && parent_ref == other.parent_ref && == other. && key_map == other.key_map end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 |
# File 'lib/oci/data_integration/models/external_publication.rb', line 320 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
300 301 302 |
# File 'lib/oci/data_integration/models/external_publication.rb', line 300 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
309 310 311 |
# File 'lib/oci/data_integration/models/external_publication.rb', line 309 def hash [application_id, application_compartment_id, display_name, resource_configuration, configuration_details, status, , key, model_type, model_version, name, description, object_version, object_status, identifier, parent_ref, , key_map].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
353 354 355 356 357 358 359 360 361 362 |
# File 'lib/oci/data_integration/models/external_publication.rb', line 353 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
347 348 349 |
# File 'lib/oci/data_integration/models/external_publication.rb', line 347 def to_s to_hash.to_s end |