Class: OCI::DataIntegration::Models::ExternalPublicationValidation
- Inherits:
-
Object
- Object
- OCI::DataIntegration::Models::ExternalPublicationValidation
- Defined in:
- lib/oci/data_integration/models/external_publication_validation.rb
Overview
The information about external published task validation.
Instance Attribute Summary collapse
-
#error_message_count ⇒ Integer
Total number of validation error messages.
-
#info_message_count ⇒ Integer
Total number of validation information messages.
-
#key ⇒ String
Objects use a 36 character key as unique ID.
-
#total_message_count ⇒ Integer
Total number of validation messages.
-
#validation_messages ⇒ Hash<String, Array<OCI::DataIntegration::Models::ValidationMessage>>
Detailed information of the data flow object validation.
-
#warn_message_count ⇒ Integer
Total number of validation warning messages.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ExternalPublicationValidation
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ExternalPublicationValidation
Initializes the object
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/oci/data_integration/models/external_publication_validation.rb', line 74 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self. = attributes[:'totalMessageCount'] if attributes[:'totalMessageCount'] raise 'You cannot provide both :totalMessageCount and :total_message_count' if attributes.key?(:'totalMessageCount') && attributes.key?(:'total_message_count') self. = attributes[:'total_message_count'] if attributes[:'total_message_count'] self. = attributes[:'errorMessageCount'] if attributes[:'errorMessageCount'] raise 'You cannot provide both :errorMessageCount and :error_message_count' if attributes.key?(:'errorMessageCount') && attributes.key?(:'error_message_count') self. = attributes[:'error_message_count'] if attributes[:'error_message_count'] self. = attributes[:'warnMessageCount'] if attributes[:'warnMessageCount'] raise 'You cannot provide both :warnMessageCount and :warn_message_count' if attributes.key?(:'warnMessageCount') && attributes.key?(:'warn_message_count') self. = attributes[:'warn_message_count'] if attributes[:'warn_message_count'] self. = attributes[:'infoMessageCount'] if attributes[:'infoMessageCount'] raise 'You cannot provide both :infoMessageCount and :info_message_count' if attributes.key?(:'infoMessageCount') && attributes.key?(:'info_message_count') self. = attributes[:'info_message_count'] if attributes[:'info_message_count'] self. = attributes[:'validationMessages'] if attributes[:'validationMessages'] raise 'You cannot provide both :validationMessages and :validation_messages' if attributes.key?(:'validationMessages') && attributes.key?(:'validation_messages') self. = attributes[:'validation_messages'] if attributes[:'validation_messages'] self.key = attributes[:'key'] if attributes[:'key'] end |
Instance Attribute Details
#error_message_count ⇒ Integer
Total number of validation error messages.
16 17 18 |
# File 'lib/oci/data_integration/models/external_publication_validation.rb', line 16 def @error_message_count end |
#info_message_count ⇒ Integer
Total number of validation information messages.
24 25 26 |
# File 'lib/oci/data_integration/models/external_publication_validation.rb', line 24 def @info_message_count end |
#key ⇒ String
Objects use a 36 character key as unique ID. It is system generated and cannot be modified.
32 33 34 |
# File 'lib/oci/data_integration/models/external_publication_validation.rb', line 32 def key @key end |
#total_message_count ⇒ Integer
Total number of validation messages.
12 13 14 |
# File 'lib/oci/data_integration/models/external_publication_validation.rb', line 12 def @total_message_count end |
#validation_messages ⇒ Hash<String, Array<OCI::DataIntegration::Models::ValidationMessage>>
Detailed information of the data flow object validation.
28 29 30 |
# File 'lib/oci/data_integration/models/external_publication_validation.rb', line 28 def @validation_messages end |
#warn_message_count ⇒ Integer
Total number of validation warning messages.
20 21 22 |
# File 'lib/oci/data_integration/models/external_publication_validation.rb', line 20 def @warn_message_count end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/oci/data_integration/models/external_publication_validation.rb', line 35 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'total_message_count': :'totalMessageCount', 'error_message_count': :'errorMessageCount', 'warn_message_count': :'warnMessageCount', 'info_message_count': :'infoMessageCount', 'validation_messages': :'validationMessages', 'key': :'key' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/oci/data_integration/models/external_publication_validation.rb', line 49 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'total_message_count': :'Integer', 'error_message_count': :'Integer', 'warn_message_count': :'Integer', 'info_message_count': :'Integer', 'validation_messages': :'Hash<String, Array<OCI::DataIntegration::Models::ValidationMessage>>', 'key': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/oci/data_integration/models/external_publication_validation.rb', line 120 def ==(other) return true if equal?(other) self.class == other.class && == other. && == other. && == other. && == other. && == other. && key == other.key end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/oci/data_integration/models/external_publication_validation.rb', line 155 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
135 136 137 |
# File 'lib/oci/data_integration/models/external_publication_validation.rb', line 135 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
144 145 146 |
# File 'lib/oci/data_integration/models/external_publication_validation.rb', line 144 def hash [, , , , , key].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
188 189 190 191 192 193 194 195 196 197 |
# File 'lib/oci/data_integration/models/external_publication_validation.rb', line 188 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
182 183 184 |
# File 'lib/oci/data_integration/models/external_publication_validation.rb', line 182 def to_s to_hash.to_s end |