Class: OCI::DataIntegration::Models::ExternalStorage
- Inherits:
-
ConnectorAttribute
- Object
- ConnectorAttribute
- OCI::DataIntegration::Models::ExternalStorage
- Defined in:
- lib/oci/data_integration/models/external_storage.rb
Overview
BICC Connector Attribute.Object Storage as External storage where the BICC extracted files are written
Constant Summary
Constants inherited from ConnectorAttribute
ConnectorAttribute::MODEL_TYPE_ENUM
Instance Attribute Summary collapse
-
#bucket ⇒ String
Bucket Name where BICC extracts stores the files.
-
#host ⇒ String
Object Storage host Url.
-
#namespace ⇒ String
Namespace for the OOS bucket.
-
#storage_id ⇒ String
Id of the external stoarge configured in BICC console.
-
#storage_name ⇒ String
Name of the external storage configured in BICC console.
-
#tenancy_id ⇒ String
Tenancy OCID for the OOS bucket.
Attributes inherited from ConnectorAttribute
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ExternalStorage
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from ConnectorAttribute
Constructor Details
#initialize(attributes = {}) ⇒ ExternalStorage
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/oci/data_integration/models/external_storage.rb', line 78 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['modelType'] = 'EXTERNAL_STORAGE' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.storage_id = attributes[:'storageId'] if attributes[:'storageId'] raise 'You cannot provide both :storageId and :storage_id' if attributes.key?(:'storageId') && attributes.key?(:'storage_id') self.storage_id = attributes[:'storage_id'] if attributes[:'storage_id'] self.storage_name = attributes[:'storageName'] if attributes[:'storageName'] raise 'You cannot provide both :storageName and :storage_name' if attributes.key?(:'storageName') && attributes.key?(:'storage_name') self.storage_name = attributes[:'storage_name'] if attributes[:'storage_name'] self.host = attributes[:'host'] if attributes[:'host'] self.tenancy_id = attributes[:'tenancyId'] if attributes[:'tenancyId'] raise 'You cannot provide both :tenancyId and :tenancy_id' if attributes.key?(:'tenancyId') && attributes.key?(:'tenancy_id') self.tenancy_id = attributes[:'tenancy_id'] if attributes[:'tenancy_id'] self.namespace = attributes[:'namespace'] if attributes[:'namespace'] self.bucket = attributes[:'bucket'] if attributes[:'bucket'] end |
Instance Attribute Details
#bucket ⇒ String
Bucket Name where BICC extracts stores the files
34 35 36 |
# File 'lib/oci/data_integration/models/external_storage.rb', line 34 def bucket @bucket end |
#host ⇒ String
Object Storage host Url. DO not give http/https.
22 23 24 |
# File 'lib/oci/data_integration/models/external_storage.rb', line 22 def host @host end |
#namespace ⇒ String
Namespace for the OOS bucket
30 31 32 |
# File 'lib/oci/data_integration/models/external_storage.rb', line 30 def namespace @namespace end |
#storage_id ⇒ String
Id of the external stoarge configured in BICC console. Usually its numeric.
14 15 16 |
# File 'lib/oci/data_integration/models/external_storage.rb', line 14 def storage_id @storage_id end |
#storage_name ⇒ String
Name of the external storage configured in BICC console
18 19 20 |
# File 'lib/oci/data_integration/models/external_storage.rb', line 18 def storage_name @storage_name end |
#tenancy_id ⇒ String
Tenancy OCID for the OOS bucket
26 27 28 |
# File 'lib/oci/data_integration/models/external_storage.rb', line 26 def tenancy_id @tenancy_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 47 48 49 |
# File 'lib/oci/data_integration/models/external_storage.rb', line 37 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'storage_id': :'storageId', 'storage_name': :'storageName', 'host': :'host', 'tenancy_id': :'tenancyId', 'namespace': :'namespace', 'bucket': :'bucket' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/oci/data_integration/models/external_storage.rb', line 52 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'storage_id': :'String', 'storage_name': :'String', 'host': :'String', 'tenancy_id': :'String', 'namespace': :'String', 'bucket': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/oci/data_integration/models/external_storage.rb', line 120 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && storage_id == other.storage_id && storage_name == other.storage_name && host == other.host && tenancy_id == other.tenancy_id && namespace == other.namespace && bucket == other.bucket end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/oci/data_integration/models/external_storage.rb', line 156 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
136 137 138 |
# File 'lib/oci/data_integration/models/external_storage.rb', line 136 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
145 146 147 |
# File 'lib/oci/data_integration/models/external_storage.rb', line 145 def hash [model_type, storage_id, storage_name, host, tenancy_id, namespace, bucket].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
189 190 191 192 193 194 195 196 197 198 |
# File 'lib/oci/data_integration/models/external_storage.rb', line 189 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
183 184 185 |
# File 'lib/oci/data_integration/models/external_storage.rb', line 183 def to_s to_hash.to_s end |