Class: OCI::DataIntegration::Models::FlowNode
- Inherits:
-
Object
- Object
- OCI::DataIntegration::Models::FlowNode
- Defined in:
- lib/oci/data_integration/models/flow_node.rb
Overview
The flow node can be connected to other nodes in a data flow with input and output links and is bound to an opertor which defines the semantics of the node.
Instance Attribute Summary collapse
- #config_provider_delegate ⇒ OCI::DataIntegration::Models::ConfigProvider
-
#description ⇒ String
Detailed description for the object.
-
#input_links ⇒ Array<OCI::DataIntegration::Models::InputLink>
An array of input links.
-
#key ⇒ String
The key of the object.
-
#model_type ⇒ String
The type of the object.
-
#model_version ⇒ String
The model version of an object.
-
#name ⇒ String
Free form text without any restriction on permitted characters.
-
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
- #operator ⇒ OCI::DataIntegration::Models::Operator
-
#output_links ⇒ Array<OCI::DataIntegration::Models::OutputLink>
An array of output links.
- #parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
- #ui_properties ⇒ OCI::DataIntegration::Models::UIProperties
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ FlowNode
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ FlowNode
Initializes the object
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/oci/data_integration/models/flow_node.rb', line 112 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.key = attributes[:'key'] if attributes[:'key'] self.model_type = attributes[:'modelType'] if attributes[:'modelType'] raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type') self.model_type = attributes[:'model_type'] if attributes[:'model_type'] self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion'] raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version') self.model_version = attributes[:'model_version'] if attributes[:'model_version'] self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef'] raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref') self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref'] self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.input_links = attributes[:'inputLinks'] if attributes[:'inputLinks'] raise 'You cannot provide both :inputLinks and :input_links' if attributes.key?(:'inputLinks') && attributes.key?(:'input_links') self.input_links = attributes[:'input_links'] if attributes[:'input_links'] self.output_links = attributes[:'outputLinks'] if attributes[:'outputLinks'] raise 'You cannot provide both :outputLinks and :output_links' if attributes.key?(:'outputLinks') && attributes.key?(:'output_links') self.output_links = attributes[:'output_links'] if attributes[:'output_links'] self.operator = attributes[:'operator'] if attributes[:'operator'] self.ui_properties = attributes[:'uiProperties'] if attributes[:'uiProperties'] raise 'You cannot provide both :uiProperties and :ui_properties' if attributes.key?(:'uiProperties') && attributes.key?(:'ui_properties') self.ui_properties = attributes[:'ui_properties'] if attributes[:'ui_properties'] self.config_provider_delegate = attributes[:'configProviderDelegate'] if attributes[:'configProviderDelegate'] raise 'You cannot provide both :configProviderDelegate and :config_provider_delegate' if attributes.key?(:'configProviderDelegate') && attributes.key?(:'config_provider_delegate') self.config_provider_delegate = attributes[:'config_provider_delegate'] if attributes[:'config_provider_delegate'] self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus'] raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status') self.object_status = attributes[:'object_status'] if attributes[:'object_status'] end |
Instance Attribute Details
#config_provider_delegate ⇒ OCI::DataIntegration::Models::ConfigProvider
48 49 50 |
# File 'lib/oci/data_integration/models/flow_node.rb', line 48 def config_provider_delegate @config_provider_delegate end |
#description ⇒ String
Detailed description for the object.
31 32 33 |
# File 'lib/oci/data_integration/models/flow_node.rb', line 31 def description @description end |
#input_links ⇒ Array<OCI::DataIntegration::Models::InputLink>
An array of input links.
35 36 37 |
# File 'lib/oci/data_integration/models/flow_node.rb', line 35 def input_links @input_links end |
#key ⇒ String
The key of the object.
12 13 14 |
# File 'lib/oci/data_integration/models/flow_node.rb', line 12 def key @key end |
#model_type ⇒ String
The type of the object.
16 17 18 |
# File 'lib/oci/data_integration/models/flow_node.rb', line 16 def model_type @model_type end |
#model_version ⇒ String
The model version of an object.
20 21 22 |
# File 'lib/oci/data_integration/models/flow_node.rb', line 20 def model_version @model_version end |
#name ⇒ String
Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.
27 28 29 |
# File 'lib/oci/data_integration/models/flow_node.rb', line 27 def name @name end |
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
52 53 54 |
# File 'lib/oci/data_integration/models/flow_node.rb', line 52 def object_status @object_status end |
#operator ⇒ OCI::DataIntegration::Models::Operator
42 43 44 |
# File 'lib/oci/data_integration/models/flow_node.rb', line 42 def operator @operator end |
#output_links ⇒ Array<OCI::DataIntegration::Models::OutputLink>
An array of output links.
39 40 41 |
# File 'lib/oci/data_integration/models/flow_node.rb', line 39 def output_links @output_links end |
#parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
23 24 25 |
# File 'lib/oci/data_integration/models/flow_node.rb', line 23 def parent_ref @parent_ref end |
#ui_properties ⇒ OCI::DataIntegration::Models::UIProperties
45 46 47 |
# File 'lib/oci/data_integration/models/flow_node.rb', line 45 def ui_properties @ui_properties end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/oci/data_integration/models/flow_node.rb', line 55 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'key': :'key', 'model_type': :'modelType', 'model_version': :'modelVersion', 'parent_ref': :'parentRef', 'name': :'name', 'description': :'description', 'input_links': :'inputLinks', 'output_links': :'outputLinks', 'operator': :'operator', 'ui_properties': :'uiProperties', 'config_provider_delegate': :'configProviderDelegate', 'object_status': :'objectStatus' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/oci/data_integration/models/flow_node.rb', line 75 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'key': :'String', 'model_type': :'String', 'model_version': :'String', 'parent_ref': :'OCI::DataIntegration::Models::ParentReference', 'name': :'String', 'description': :'String', 'input_links': :'Array<OCI::DataIntegration::Models::InputLink>', 'output_links': :'Array<OCI::DataIntegration::Models::OutputLink>', 'operator': :'OCI::DataIntegration::Models::Operator', 'ui_properties': :'OCI::DataIntegration::Models::UIProperties', 'config_provider_delegate': :'OCI::DataIntegration::Models::ConfigProvider', 'object_status': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/oci/data_integration/models/flow_node.rb', line 182 def ==(other) return true if equal?(other) self.class == other.class && key == other.key && model_type == other.model_type && model_version == other.model_version && parent_ref == other.parent_ref && name == other.name && description == other.description && input_links == other.input_links && output_links == other.output_links && operator == other.operator && ui_properties == other.ui_properties && config_provider_delegate == other.config_provider_delegate && object_status == other.object_status end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/oci/data_integration/models/flow_node.rb', line 223 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
203 204 205 |
# File 'lib/oci/data_integration/models/flow_node.rb', line 203 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
212 213 214 |
# File 'lib/oci/data_integration/models/flow_node.rb', line 212 def hash [key, model_type, model_version, parent_ref, name, description, input_links, output_links, operator, ui_properties, config_provider_delegate, object_status].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
256 257 258 259 260 261 262 263 264 265 |
# File 'lib/oci/data_integration/models/flow_node.rb', line 256 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
250 251 252 |
# File 'lib/oci/data_integration/models/flow_node.rb', line 250 def to_s to_hash.to_s end |