Class: OCI::DataIntegration::Models::ForeignKey
- Inherits:
-
DataIntegration::Models::Key
- Object
- DataIntegration::Models::Key
- OCI::DataIntegration::Models::ForeignKey
- Defined in:
- lib/oci/data_integration/models/foreign_key.rb
Overview
The foreign key object.
Instance Attribute Summary collapse
-
#attribute_refs ⇒ Array<OCI::DataIntegration::Models::KeyAttribute>
An array of attribute references.
-
#delete_rule ⇒ Integer
The delete rule.
-
#key ⇒ String
The object key.
-
#model_version ⇒ String
The object’s model version.
-
#name ⇒ String
Free form text without any restriction on permitted characters.
-
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
- #parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
- #reference_unique_key ⇒ OCI::DataIntegration::Models::UniqueKey
-
#update_rule ⇒ Integer
The update rule.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ForeignKey
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ForeignKey
Initializes the object
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/oci/data_integration/models/foreign_key.rb', line 97 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['modelType'] = 'FOREIGN_KEY' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.key = attributes[:'key'] if attributes[:'key'] self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion'] raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version') self.model_version = attributes[:'model_version'] if attributes[:'model_version'] self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef'] raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref') self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref'] self.name = attributes[:'name'] if attributes[:'name'] self.attribute_refs = attributes[:'attributeRefs'] if attributes[:'attributeRefs'] raise 'You cannot provide both :attributeRefs and :attribute_refs' if attributes.key?(:'attributeRefs') && attributes.key?(:'attribute_refs') self.attribute_refs = attributes[:'attribute_refs'] if attributes[:'attribute_refs'] self.update_rule = attributes[:'updateRule'] if attributes[:'updateRule'] raise 'You cannot provide both :updateRule and :update_rule' if attributes.key?(:'updateRule') && attributes.key?(:'update_rule') self.update_rule = attributes[:'update_rule'] if attributes[:'update_rule'] self.delete_rule = attributes[:'deleteRule'] if attributes[:'deleteRule'] raise 'You cannot provide both :deleteRule and :delete_rule' if attributes.key?(:'deleteRule') && attributes.key?(:'delete_rule') self.delete_rule = attributes[:'delete_rule'] if attributes[:'delete_rule'] self.reference_unique_key = attributes[:'referenceUniqueKey'] if attributes[:'referenceUniqueKey'] raise 'You cannot provide both :referenceUniqueKey and :reference_unique_key' if attributes.key?(:'referenceUniqueKey') && attributes.key?(:'reference_unique_key') self.reference_unique_key = attributes[:'reference_unique_key'] if attributes[:'reference_unique_key'] self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus'] raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status') self.object_status = attributes[:'object_status'] if attributes[:'object_status'] end |
Instance Attribute Details
#attribute_refs ⇒ Array<OCI::DataIntegration::Models::KeyAttribute>
An array of attribute references.
29 30 31 |
# File 'lib/oci/data_integration/models/foreign_key.rb', line 29 def attribute_refs @attribute_refs end |
#delete_rule ⇒ Integer
The delete rule.
37 38 39 |
# File 'lib/oci/data_integration/models/foreign_key.rb', line 37 def delete_rule @delete_rule end |
#key ⇒ String
The object key.
14 15 16 |
# File 'lib/oci/data_integration/models/foreign_key.rb', line 14 def key @key end |
#model_version ⇒ String
The object’s model version.
18 19 20 |
# File 'lib/oci/data_integration/models/foreign_key.rb', line 18 def model_version @model_version end |
#name ⇒ String
Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.
25 26 27 |
# File 'lib/oci/data_integration/models/foreign_key.rb', line 25 def name @name end |
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
44 45 46 |
# File 'lib/oci/data_integration/models/foreign_key.rb', line 44 def object_status @object_status end |
#parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
21 22 23 |
# File 'lib/oci/data_integration/models/foreign_key.rb', line 21 def parent_ref @parent_ref end |
#reference_unique_key ⇒ OCI::DataIntegration::Models::UniqueKey
40 41 42 |
# File 'lib/oci/data_integration/models/foreign_key.rb', line 40 def reference_unique_key @reference_unique_key end |
#update_rule ⇒ Integer
The update rule.
33 34 35 |
# File 'lib/oci/data_integration/models/foreign_key.rb', line 33 def update_rule @update_rule end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/oci/data_integration/models/foreign_key.rb', line 47 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'key': :'key', 'model_version': :'modelVersion', 'parent_ref': :'parentRef', 'name': :'name', 'attribute_refs': :'attributeRefs', 'update_rule': :'updateRule', 'delete_rule': :'deleteRule', 'reference_unique_key': :'referenceUniqueKey', 'object_status': :'objectStatus' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/oci/data_integration/models/foreign_key.rb', line 65 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'key': :'String', 'model_version': :'String', 'parent_ref': :'OCI::DataIntegration::Models::ParentReference', 'name': :'String', 'attribute_refs': :'Array<OCI::DataIntegration::Models::KeyAttribute>', 'update_rule': :'Integer', 'delete_rule': :'Integer', 'reference_unique_key': :'OCI::DataIntegration::Models::UniqueKey', 'object_status': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/oci/data_integration/models/foreign_key.rb', line 161 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && key == other.key && model_version == other.model_version && parent_ref == other.parent_ref && name == other.name && attribute_refs == other.attribute_refs && update_rule == other.update_rule && delete_rule == other.delete_rule && reference_unique_key == other.reference_unique_key && object_status == other.object_status end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/oci/data_integration/models/foreign_key.rb', line 200 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
180 181 182 |
# File 'lib/oci/data_integration/models/foreign_key.rb', line 180 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
189 190 191 |
# File 'lib/oci/data_integration/models/foreign_key.rb', line 189 def hash [model_type, key, model_version, parent_ref, name, attribute_refs, update_rule, delete_rule, reference_unique_key, object_status].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
233 234 235 236 237 238 239 240 241 242 |
# File 'lib/oci/data_integration/models/foreign_key.rb', line 233 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
227 228 229 |
# File 'lib/oci/data_integration/models/foreign_key.rb', line 227 def to_s to_hash.to_s end |