Class: OCI::DataIntegration::Models::FunctionSignature
- Inherits:
-
Object
- Object
- OCI::DataIntegration::Models::FunctionSignature
- Defined in:
- lib/oci/data_integration/models/function_signature.rb
Overview
The function signature can specify function paramaters and/or function return type.
Constant Summary collapse
- MODEL_TYPE_ENUM =
[ MODEL_TYPE_DIS_FUNCTION_SIGNATURE = 'DIS_FUNCTION_SIGNATURE'.freeze, MODEL_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#arguments ⇒ Array<OCI::DataIntegration::Models::TypedObject>
An array of function arguments.
-
#description ⇒ String
Detailed description for the object.
-
#key ⇒ String
The key of the object.
-
#model_type ⇒ String
The type of the object.
-
#model_version ⇒ String
The model version of an object.
-
#name ⇒ String
Free form text without any restriction on permitted characters.
-
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
- #parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
- #ret_type ⇒ OCI::DataIntegration::Models::ConfiguredType
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ FunctionSignature
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ FunctionSignature
Initializes the object
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/oci/data_integration/models/function_signature.rb', line 99 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.key = attributes[:'key'] if attributes[:'key'] self.model_type = attributes[:'modelType'] if attributes[:'modelType'] raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type') self.model_type = attributes[:'model_type'] if attributes[:'model_type'] self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion'] raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version') self.model_version = attributes[:'model_version'] if attributes[:'model_version'] self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef'] raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref') self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref'] self.name = attributes[:'name'] if attributes[:'name'] self.ret_type = attributes[:'retType'] if attributes[:'retType'] raise 'You cannot provide both :retType and :ret_type' if attributes.key?(:'retType') && attributes.key?(:'ret_type') self.ret_type = attributes[:'ret_type'] if attributes[:'ret_type'] self.arguments = attributes[:'arguments'] if attributes[:'arguments'] self.description = attributes[:'description'] if attributes[:'description'] self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus'] raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status') self.object_status = attributes[:'object_status'] if attributes[:'object_status'] end |
Instance Attribute Details
#arguments ⇒ Array<OCI::DataIntegration::Models::TypedObject>
An array of function arguments.
40 41 42 |
# File 'lib/oci/data_integration/models/function_signature.rb', line 40 def arguments @arguments end |
#description ⇒ String
Detailed description for the object.
44 45 46 |
# File 'lib/oci/data_integration/models/function_signature.rb', line 44 def description @description end |
#key ⇒ String
The key of the object.
18 19 20 |
# File 'lib/oci/data_integration/models/function_signature.rb', line 18 def key @key end |
#model_type ⇒ String
The type of the object.
22 23 24 |
# File 'lib/oci/data_integration/models/function_signature.rb', line 22 def model_type @model_type end |
#model_version ⇒ String
The model version of an object.
26 27 28 |
# File 'lib/oci/data_integration/models/function_signature.rb', line 26 def model_version @model_version end |
#name ⇒ String
Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.
33 34 35 |
# File 'lib/oci/data_integration/models/function_signature.rb', line 33 def name @name end |
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
48 49 50 |
# File 'lib/oci/data_integration/models/function_signature.rb', line 48 def object_status @object_status end |
#parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
29 30 31 |
# File 'lib/oci/data_integration/models/function_signature.rb', line 29 def parent_ref @parent_ref end |
#ret_type ⇒ OCI::DataIntegration::Models::ConfiguredType
36 37 38 |
# File 'lib/oci/data_integration/models/function_signature.rb', line 36 def ret_type @ret_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/oci/data_integration/models/function_signature.rb', line 51 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'key': :'key', 'model_type': :'modelType', 'model_version': :'modelVersion', 'parent_ref': :'parentRef', 'name': :'name', 'ret_type': :'retType', 'arguments': :'arguments', 'description': :'description', 'object_status': :'objectStatus' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/oci/data_integration/models/function_signature.rb', line 68 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'key': :'String', 'model_type': :'String', 'model_version': :'String', 'parent_ref': :'OCI::DataIntegration::Models::ParentReference', 'name': :'String', 'ret_type': :'OCI::DataIntegration::Models::ConfiguredType', 'arguments': :'Array<OCI::DataIntegration::Models::TypedObject>', 'description': :'String', 'object_status': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/oci/data_integration/models/function_signature.rb', line 164 def ==(other) return true if equal?(other) self.class == other.class && key == other.key && model_type == other.model_type && model_version == other.model_version && parent_ref == other.parent_ref && name == other.name && ret_type == other.ret_type && arguments == other.arguments && description == other.description && object_status == other.object_status end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/oci/data_integration/models/function_signature.rb', line 202 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
182 183 184 |
# File 'lib/oci/data_integration/models/function_signature.rb', line 182 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
191 192 193 |
# File 'lib/oci/data_integration/models/function_signature.rb', line 191 def hash [key, model_type, model_version, parent_ref, name, ret_type, arguments, description, object_status].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
235 236 237 238 239 240 241 242 243 244 |
# File 'lib/oci/data_integration/models/function_signature.rb', line 235 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
229 230 231 |
# File 'lib/oci/data_integration/models/function_signature.rb', line 229 def to_s to_hash.to_s end |