Class: OCI::DataIntegration::Models::Intersect
- Inherits:
-
DataIntegration::Models::Operator
- Object
- DataIntegration::Models::Operator
- OCI::DataIntegration::Models::Intersect
- Defined in:
- lib/oci/data_integration/models/intersect.rb
Overview
The information about a intersect object.
Constant Summary collapse
- INTERSECT_TYPE_ENUM =
[ INTERSECT_TYPE_NAME = 'NAME'.freeze, INTERSECT_TYPE_POSITION = 'POSITION'.freeze, INTERSECT_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#intersect_type ⇒ String
intersectType.
-
#is_all ⇒ BOOLEAN
The information about the intersect all.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Intersect
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Intersect
Initializes the object
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/oci/data_integration/models/intersect.rb', line 92 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['modelType'] = 'INTERSECT_OPERATOR' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.intersect_type = attributes[:'intersectType'] if attributes[:'intersectType'] raise 'You cannot provide both :intersectType and :intersect_type' if attributes.key?(:'intersectType') && attributes.key?(:'intersect_type') self.intersect_type = attributes[:'intersect_type'] if attributes[:'intersect_type'] self.is_all = attributes[:'isAll'] unless attributes[:'isAll'].nil? self.is_all = false if is_all.nil? && !attributes.key?(:'isAll') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isAll and :is_all' if attributes.key?(:'isAll') && attributes.key?(:'is_all') self.is_all = attributes[:'is_all'] unless attributes[:'is_all'].nil? self.is_all = false if is_all.nil? && !attributes.key?(:'isAll') && !attributes.key?(:'is_all') # rubocop:disable Style/StringLiterals end |
Instance Attribute Details
#intersect_type ⇒ String
intersectType
20 21 22 |
# File 'lib/oci/data_integration/models/intersect.rb', line 20 def intersect_type @intersect_type end |
#is_all ⇒ BOOLEAN
The information about the intersect all.
24 25 26 |
# File 'lib/oci/data_integration/models/intersect.rb', line 24 def is_all @is_all end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 |
# File 'lib/oci/data_integration/models/intersect.rb', line 27 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'key': :'key', 'model_version': :'modelVersion', 'parent_ref': :'parentRef', 'name': :'name', 'description': :'description', 'object_version': :'objectVersion', 'input_ports': :'inputPorts', 'output_ports': :'outputPorts', 'object_status': :'objectStatus', 'identifier': :'identifier', 'parameters': :'parameters', 'op_config_values': :'opConfigValues', 'intersect_type': :'intersectType', 'is_all': :'isAll' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/oci/data_integration/models/intersect.rb', line 50 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'key': :'String', 'model_version': :'String', 'parent_ref': :'OCI::DataIntegration::Models::ParentReference', 'name': :'String', 'description': :'String', 'object_version': :'Integer', 'input_ports': :'Array<OCI::DataIntegration::Models::InputPort>', 'output_ports': :'Array<OCI::DataIntegration::Models::OutputPort>', 'object_status': :'Integer', 'identifier': :'String', 'parameters': :'Array<OCI::DataIntegration::Models::Parameter>', 'op_config_values': :'OCI::DataIntegration::Models::ConfigValues', 'intersect_type': :'String', 'is_all': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/oci/data_integration/models/intersect.rb', line 137 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && key == other.key && model_version == other.model_version && parent_ref == other.parent_ref && name == other.name && description == other.description && object_version == other.object_version && input_ports == other.input_ports && output_ports == other.output_ports && object_status == other.object_status && identifier == other.identifier && parameters == other.parameters && op_config_values == other.op_config_values && intersect_type == other.intersect_type && is_all == other.is_all end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/oci/data_integration/models/intersect.rb', line 181 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
161 162 163 |
# File 'lib/oci/data_integration/models/intersect.rb', line 161 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
170 171 172 |
# File 'lib/oci/data_integration/models/intersect.rb', line 170 def hash [model_type, key, model_version, parent_ref, name, description, object_version, input_ports, output_ports, object_status, identifier, parameters, op_config_values, intersect_type, is_all].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
214 215 216 217 218 219 220 221 222 223 |
# File 'lib/oci/data_integration/models/intersect.rb', line 214 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
208 209 210 |
# File 'lib/oci/data_integration/models/intersect.rb', line 208 def to_s to_hash.to_s end |