Class: OCI::DataIntegration::Models::MacroField
- Inherits:
-
TypedObject
- Object
- TypedObject
- OCI::DataIntegration::Models::MacroField
- Defined in:
- lib/oci/data_integration/models/macro_field.rb
Overview
The type representing the macro field concept. Macro fields have an expression to define a macro.
Constant Summary
Constants inherited from TypedObject
Instance Attribute Summary collapse
- #expr ⇒ OCI::DataIntegration::Models::Expression
-
#is_use_source_type ⇒ BOOLEAN
Specifies whether the type of macro fields is inferred from an expression or useType (false) or the source field (true).
-
#labels ⇒ Array<String>
Labels are keywords or labels that you can add to data assets, dataflows, and so on.
- #type ⇒ OCI::DataIntegration::Models::BaseType
- #use_type ⇒ OCI::DataIntegration::Models::ConfiguredType
Attributes inherited from TypedObject
#config_values, #description, #key, #model_type, #model_version, #name, #object_status, #parent_ref
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MacroField
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from TypedObject
Constructor Details
#initialize(attributes = {}) ⇒ MacroField
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/oci/data_integration/models/macro_field.rb', line 88 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['modelType'] = 'MACRO_FIELD' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.expr = attributes[:'expr'] if attributes[:'expr'] self.type = attributes[:'type'] if attributes[:'type'] self.is_use_source_type = attributes[:'isUseSourceType'] unless attributes[:'isUseSourceType'].nil? raise 'You cannot provide both :isUseSourceType and :is_use_source_type' if attributes.key?(:'isUseSourceType') && attributes.key?(:'is_use_source_type') self.is_use_source_type = attributes[:'is_use_source_type'] unless attributes[:'is_use_source_type'].nil? self.use_type = attributes[:'useType'] if attributes[:'useType'] raise 'You cannot provide both :useType and :use_type' if attributes.key?(:'useType') && attributes.key?(:'use_type') self.use_type = attributes[:'use_type'] if attributes[:'use_type'] self.labels = attributes[:'labels'] if attributes[:'labels'] end |
Instance Attribute Details
#expr ⇒ OCI::DataIntegration::Models::Expression
12 13 14 |
# File 'lib/oci/data_integration/models/macro_field.rb', line 12 def expr @expr end |
#is_use_source_type ⇒ BOOLEAN
Specifies whether the type of macro fields is inferred from an expression or useType (false) or the source field (true).
19 20 21 |
# File 'lib/oci/data_integration/models/macro_field.rb', line 19 def is_use_source_type @is_use_source_type end |
#labels ⇒ Array<String>
Labels are keywords or labels that you can add to data assets, dataflows, and so on. You can define your own labels and use them to categorize content.
26 27 28 |
# File 'lib/oci/data_integration/models/macro_field.rb', line 26 def labels @labels end |
#type ⇒ OCI::DataIntegration::Models::BaseType
15 16 17 |
# File 'lib/oci/data_integration/models/macro_field.rb', line 15 def type @type end |
#use_type ⇒ OCI::DataIntegration::Models::ConfiguredType
22 23 24 |
# File 'lib/oci/data_integration/models/macro_field.rb', line 22 def use_type @use_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 |
# File 'lib/oci/data_integration/models/macro_field.rb', line 29 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'key': :'key', 'model_version': :'modelVersion', 'parent_ref': :'parentRef', 'config_values': :'configValues', 'object_status': :'objectStatus', 'name': :'name', 'description': :'description', 'expr': :'expr', 'type': :'type', 'is_use_source_type': :'isUseSourceType', 'use_type': :'useType', 'labels': :'labels' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/oci/data_integration/models/macro_field.rb', line 50 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'key': :'String', 'model_version': :'String', 'parent_ref': :'OCI::DataIntegration::Models::ParentReference', 'config_values': :'OCI::DataIntegration::Models::ConfigValues', 'object_status': :'Integer', 'name': :'String', 'description': :'String', 'expr': :'OCI::DataIntegration::Models::Expression', 'type': :'OCI::DataIntegration::Models::BaseType', 'is_use_source_type': :'BOOLEAN', 'use_type': :'OCI::DataIntegration::Models::ConfiguredType', 'labels': :'Array<String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/oci/data_integration/models/macro_field.rb', line 124 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && key == other.key && model_version == other.model_version && parent_ref == other.parent_ref && config_values == other.config_values && object_status == other.object_status && name == other.name && description == other.description && expr == other.expr && type == other.type && is_use_source_type == other.is_use_source_type && use_type == other.use_type && labels == other.labels end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/oci/data_integration/models/macro_field.rb', line 166 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
146 147 148 |
# File 'lib/oci/data_integration/models/macro_field.rb', line 146 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
155 156 157 |
# File 'lib/oci/data_integration/models/macro_field.rb', line 155 def hash [model_type, key, model_version, parent_ref, config_values, object_status, name, description, expr, type, is_use_source_type, use_type, labels].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
199 200 201 202 203 204 205 206 207 208 |
# File 'lib/oci/data_integration/models/macro_field.rb', line 199 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
193 194 195 |
# File 'lib/oci/data_integration/models/macro_field.rb', line 193 def to_s to_hash.to_s end |