Class: OCI::DataIntegration::Models::MergeOperator

Inherits:
DataIntegration::Models::Operator
  • Object
show all
Defined in:
lib/oci/data_integration/models/merge_operator.rb

Overview

Represents the start of a pipeline.

Constant Summary collapse

TRIGGER_RULE_ENUM =
[
  TRIGGER_RULE_ALL_SUCCESS = 'ALL_SUCCESS'.freeze,
  TRIGGER_RULE_ALL_FAILED = 'ALL_FAILED'.freeze,
  TRIGGER_RULE_ALL_COMPLETE = 'ALL_COMPLETE'.freeze,
  TRIGGER_RULE_ONE_SUCCESS = 'ONE_SUCCESS'.freeze,
  TRIGGER_RULE_ONE_FAILED = 'ONE_FAILED'.freeze,
  TRIGGER_RULE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ MergeOperator

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :key (String)

    The value to assign to the #key proprety

  • :model_version (String)

    The value to assign to the #model_version proprety

  • :parent_ref (OCI::DataIntegration::Models::ParentReference)

    The value to assign to the #parent_ref proprety

  • :name (String)

    The value to assign to the #name proprety

  • :description (String)

    The value to assign to the #description proprety

  • :object_version (Integer)

    The value to assign to the #object_version proprety

  • :input_ports (Array<OCI::DataIntegration::Models::InputPort>)

    The value to assign to the #input_ports proprety

  • :output_ports (Array<OCI::DataIntegration::Models::OutputPort>)

    The value to assign to the #output_ports proprety

  • :object_status (Integer)

    The value to assign to the #object_status proprety

  • :identifier (String)

    The value to assign to the #identifier proprety

  • :parameters (Array<OCI::DataIntegration::Models::Parameter>)

    The value to assign to the #parameters proprety

  • :op_config_values (OCI::DataIntegration::Models::ConfigValues)

    The value to assign to the #op_config_values proprety

  • :trigger_rule (String)

    The value to assign to the #trigger_rule property



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/oci/data_integration/models/merge_operator.rb', line 94

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['modelType'] = 'MERGE_OPERATOR'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.trigger_rule = attributes[:'triggerRule'] if attributes[:'triggerRule']
  self.trigger_rule = "ALL_SUCCESS" if trigger_rule.nil? && !attributes.key?(:'triggerRule') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :triggerRule and :trigger_rule' if attributes.key?(:'triggerRule') && attributes.key?(:'trigger_rule')

  self.trigger_rule = attributes[:'trigger_rule'] if attributes[:'trigger_rule']
  self.trigger_rule = "ALL_SUCCESS" if trigger_rule.nil? && !attributes.key?(:'triggerRule') && !attributes.key?(:'trigger_rule') # rubocop:disable Style/StringLiterals
end

Instance Attribute Details

#trigger_ruleString

The merge condition. The conditions are ALL_SUCCESS - All the preceeding operators need to be successful. ALL_FAILED - All the preceeding operators should have failed. ALL_COMPLETE - All the preceeding operators should have completed. It could have executed successfully or failed. ONE_SUCCESS - Atleast one of the preceeding operators should have succeeded. ONE_FAILED - Atleast one of the preceeding operators should have failed.

Returns:

  • (String)


29
30
31
# File 'lib/oci/data_integration/models/merge_operator.rb', line 29

def trigger_rule
  @trigger_rule
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
# File 'lib/oci/data_integration/models/merge_operator.rb', line 32

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'modelType',
    'key': :'key',
    'model_version': :'modelVersion',
    'parent_ref': :'parentRef',
    'name': :'name',
    'description': :'description',
    'object_version': :'objectVersion',
    'input_ports': :'inputPorts',
    'output_ports': :'outputPorts',
    'object_status': :'objectStatus',
    'identifier': :'identifier',
    'parameters': :'parameters',
    'op_config_values': :'opConfigValues',
    'trigger_rule': :'triggerRule'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/oci/data_integration/models/merge_operator.rb', line 54

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'String',
    'key': :'String',
    'model_version': :'String',
    'parent_ref': :'OCI::DataIntegration::Models::ParentReference',
    'name': :'String',
    'description': :'String',
    'object_version': :'Integer',
    'input_ports': :'Array<OCI::DataIntegration::Models::InputPort>',
    'output_ports': :'Array<OCI::DataIntegration::Models::OutputPort>',
    'object_status': :'Integer',
    'identifier': :'String',
    'parameters': :'Array<OCI::DataIntegration::Models::Parameter>',
    'op_config_values': :'OCI::DataIntegration::Models::ConfigValues',
    'trigger_rule': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/oci/data_integration/models/merge_operator.rb', line 133

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    model_type == other.model_type &&
    key == other.key &&
    model_version == other.model_version &&
    parent_ref == other.parent_ref &&
    name == other.name &&
    description == other.description &&
    object_version == other.object_version &&
    input_ports == other.input_ports &&
    output_ports == other.output_ports &&
    object_status == other.object_status &&
    identifier == other.identifier &&
    parameters == other.parameters &&
    op_config_values == other.op_config_values &&
    trigger_rule == other.trigger_rule
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/oci/data_integration/models/merge_operator.rb', line 176

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


156
157
158
# File 'lib/oci/data_integration/models/merge_operator.rb', line 156

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



165
166
167
# File 'lib/oci/data_integration/models/merge_operator.rb', line 165

def hash
  [model_type, key, model_version, parent_ref, name, description, object_version, input_ports, output_ports, object_status, identifier, parameters, op_config_values, trigger_rule].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



209
210
211
212
213
214
215
216
217
218
# File 'lib/oci/data_integration/models/merge_operator.rb', line 209

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



203
204
205
# File 'lib/oci/data_integration/models/merge_operator.rb', line 203

def to_s
  to_hash.to_s
end