Class: OCI::DataIntegration::Models::MonthlyFrequencyDetails
- Inherits:
-
AbstractFrequencyDetails
- Object
- AbstractFrequencyDetails
- OCI::DataIntegration::Models::MonthlyFrequencyDetails
- Defined in:
- lib/oci/data_integration/models/monthly_frequency_details.rb
Overview
Frequency Details model for monthly frequency.
Constant Summary
Constants inherited from AbstractFrequencyDetails
AbstractFrequencyDetails::FREQUENCY_ENUM, AbstractFrequencyDetails::MODEL_TYPE_ENUM
Instance Attribute Summary collapse
-
#days ⇒ Array<Integer>
A list of days of the month to be scheduled.
-
#interval ⇒ Integer
This hold the repeatability aspect of a schedule.
- #time ⇒ OCI::DataIntegration::Models::Time
Attributes inherited from AbstractFrequencyDetails
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MonthlyFrequencyDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from AbstractFrequencyDetails
Constructor Details
#initialize(attributes = {}) ⇒ MonthlyFrequencyDetails
Initializes the object
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/oci/data_integration/models/monthly_frequency_details.rb', line 58 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['modelType'] = 'MONTHLY' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.interval = attributes[:'interval'] if attributes[:'interval'] self.time = attributes[:'time'] if attributes[:'time'] self.days = attributes[:'days'] if attributes[:'days'] end |
Instance Attribute Details
#days ⇒ Array<Integer>
A list of days of the month to be scheduled. i.e. excute every 2nd,3rd, 10th of the month.
20 21 22 |
# File 'lib/oci/data_integration/models/monthly_frequency_details.rb', line 20 def days @days end |
#interval ⇒ Integer
This hold the repeatability aspect of a schedule. i.e. in a monhtly frequency, a task can be scheduled for every month, once in two months, once in tree months etc.
13 14 15 |
# File 'lib/oci/data_integration/models/monthly_frequency_details.rb', line 13 def interval @interval end |
#time ⇒ OCI::DataIntegration::Models::Time
16 17 18 |
# File 'lib/oci/data_integration/models/monthly_frequency_details.rb', line 16 def time @time end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
23 24 25 26 27 28 29 30 31 32 33 |
# File 'lib/oci/data_integration/models/monthly_frequency_details.rb', line 23 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'frequency': :'frequency', 'interval': :'interval', 'time': :'time', 'days': :'days' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/oci/data_integration/models/monthly_frequency_details.rb', line 36 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'frequency': :'String', 'interval': :'Integer', 'time': :'OCI::DataIntegration::Models::Time', 'days': :'Array<Integer>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
82 83 84 85 86 87 88 89 90 91 |
# File 'lib/oci/data_integration/models/monthly_frequency_details.rb', line 82 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && frequency == other.frequency && interval == other.interval && time == other.time && days == other.days end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/oci/data_integration/models/monthly_frequency_details.rb', line 116 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
96 97 98 |
# File 'lib/oci/data_integration/models/monthly_frequency_details.rb', line 96 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
105 106 107 |
# File 'lib/oci/data_integration/models/monthly_frequency_details.rb', line 105 def hash [model_type, frequency, interval, time, days].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
149 150 151 152 153 154 155 156 157 158 |
# File 'lib/oci/data_integration/models/monthly_frequency_details.rb', line 149 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
143 144 145 |
# File 'lib/oci/data_integration/models/monthly_frequency_details.rb', line 143 def to_s to_hash.to_s end |