Class: OCI::DataIntegration::Models::NativeShapeField
- Inherits:
-
Object
- Object
- OCI::DataIntegration::Models::NativeShapeField
- Defined in:
- lib/oci/data_integration/models/native_shape_field.rb
Overview
The native shape field object.
Instance Attribute Summary collapse
- #config_values ⇒ OCI::DataIntegration::Models::ConfigValues
-
#default_value_string ⇒ String
The default value.
-
#is_mandatory ⇒ BOOLEAN
Specifies whether the field is mandatory.
-
#model_type ⇒ String
The model type reference.
-
#name ⇒ String
Free form text without any restriction on permitted characters.
-
#position ⇒ Integer
The position of the attribute.
-
#type ⇒ Object
The type reference.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NativeShapeField
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ NativeShapeField
Initializes the object
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/oci/data_integration/models/native_shape_field.rb', line 80 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.model_type = attributes[:'modelType'] if attributes[:'modelType'] raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type') self.model_type = attributes[:'model_type'] if attributes[:'model_type'] self.type = attributes[:'type'] if attributes[:'type'] self.config_values = attributes[:'configValues'] if attributes[:'configValues'] raise 'You cannot provide both :configValues and :config_values' if attributes.key?(:'configValues') && attributes.key?(:'config_values') self.config_values = attributes[:'config_values'] if attributes[:'config_values'] self.position = attributes[:'position'] if attributes[:'position'] self.default_value_string = attributes[:'defaultValueString'] if attributes[:'defaultValueString'] raise 'You cannot provide both :defaultValueString and :default_value_string' if attributes.key?(:'defaultValueString') && attributes.key?(:'default_value_string') self.default_value_string = attributes[:'default_value_string'] if attributes[:'default_value_string'] self.is_mandatory = attributes[:'isMandatory'] unless attributes[:'isMandatory'].nil? raise 'You cannot provide both :isMandatory and :is_mandatory' if attributes.key?(:'isMandatory') && attributes.key?(:'is_mandatory') self.is_mandatory = attributes[:'is_mandatory'] unless attributes[:'is_mandatory'].nil? end |
Instance Attribute Details
#config_values ⇒ OCI::DataIntegration::Models::ConfigValues
23 24 25 |
# File 'lib/oci/data_integration/models/native_shape_field.rb', line 23 def config_values @config_values end |
#default_value_string ⇒ String
The default value.
31 32 33 |
# File 'lib/oci/data_integration/models/native_shape_field.rb', line 31 def default_value_string @default_value_string end |
#is_mandatory ⇒ BOOLEAN
Specifies whether the field is mandatory.
35 36 37 |
# File 'lib/oci/data_integration/models/native_shape_field.rb', line 35 def is_mandatory @is_mandatory end |
#model_type ⇒ String
The model type reference.
16 17 18 |
# File 'lib/oci/data_integration/models/native_shape_field.rb', line 16 def model_type @model_type end |
#name ⇒ String
Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.
12 13 14 |
# File 'lib/oci/data_integration/models/native_shape_field.rb', line 12 def name @name end |
#position ⇒ Integer
The position of the attribute.
27 28 29 |
# File 'lib/oci/data_integration/models/native_shape_field.rb', line 27 def position @position end |
#type ⇒ Object
The type reference.
20 21 22 |
# File 'lib/oci/data_integration/models/native_shape_field.rb', line 20 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
38 39 40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/oci/data_integration/models/native_shape_field.rb', line 38 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'model_type': :'modelType', 'type': :'type', 'config_values': :'configValues', 'position': :'position', 'default_value_string': :'defaultValueString', 'is_mandatory': :'isMandatory' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/oci/data_integration/models/native_shape_field.rb', line 53 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'model_type': :'String', 'type': :'Object', 'config_values': :'OCI::DataIntegration::Models::ConfigValues', 'position': :'Integer', 'default_value_string': :'String', 'is_mandatory': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/oci/data_integration/models/native_shape_field.rb', line 124 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && model_type == other.model_type && type == other.type && config_values == other.config_values && position == other.position && default_value_string == other.default_value_string && is_mandatory == other.is_mandatory end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/oci/data_integration/models/native_shape_field.rb', line 160 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
140 141 142 |
# File 'lib/oci/data_integration/models/native_shape_field.rb', line 140 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
149 150 151 |
# File 'lib/oci/data_integration/models/native_shape_field.rb', line 149 def hash [name, model_type, type, config_values, position, default_value_string, is_mandatory].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
193 194 195 196 197 198 199 200 201 202 |
# File 'lib/oci/data_integration/models/native_shape_field.rb', line 193 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
187 188 189 |
# File 'lib/oci/data_integration/models/native_shape_field.rb', line 187 def to_s to_hash.to_s end |