Class: OCI::DataIntegration::Models::OciFunction
- Inherits:
-
Object
- Object
- OCI::DataIntegration::Models::OciFunction
- Defined in:
- lib/oci/data_integration/models/oci_function.rb
Overview
The information about the OCI Function.
Instance Attribute Summary collapse
- #fn_config_definition ⇒ OCI::DataIntegration::Models::ConfigDefinition
-
#function_id ⇒ String
Ocid of the OCI Function.
- #input_shape ⇒ OCI::DataIntegration::Models::Shape
- #output_shape ⇒ OCI::DataIntegration::Models::Shape
-
#region_id ⇒ String
Region where the OCI Function is deployed.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OciFunction
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ OciFunction
Initializes the object
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/oci/data_integration/models/oci_function.rb', line 64 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.function_id = attributes[:'functionId'] if attributes[:'functionId'] raise 'You cannot provide both :functionId and :function_id' if attributes.key?(:'functionId') && attributes.key?(:'function_id') self.function_id = attributes[:'function_id'] if attributes[:'function_id'] self.region_id = attributes[:'regionId'] if attributes[:'regionId'] raise 'You cannot provide both :regionId and :region_id' if attributes.key?(:'regionId') && attributes.key?(:'region_id') self.region_id = attributes[:'region_id'] if attributes[:'region_id'] self.fn_config_definition = attributes[:'fnConfigDefinition'] if attributes[:'fnConfigDefinition'] raise 'You cannot provide both :fnConfigDefinition and :fn_config_definition' if attributes.key?(:'fnConfigDefinition') && attributes.key?(:'fn_config_definition') self.fn_config_definition = attributes[:'fn_config_definition'] if attributes[:'fn_config_definition'] self.input_shape = attributes[:'inputShape'] if attributes[:'inputShape'] raise 'You cannot provide both :inputShape and :input_shape' if attributes.key?(:'inputShape') && attributes.key?(:'input_shape') self.input_shape = attributes[:'input_shape'] if attributes[:'input_shape'] self.output_shape = attributes[:'outputShape'] if attributes[:'outputShape'] raise 'You cannot provide both :outputShape and :output_shape' if attributes.key?(:'outputShape') && attributes.key?(:'output_shape') self.output_shape = attributes[:'output_shape'] if attributes[:'output_shape'] end |
Instance Attribute Details
#fn_config_definition ⇒ OCI::DataIntegration::Models::ConfigDefinition
19 20 21 |
# File 'lib/oci/data_integration/models/oci_function.rb', line 19 def fn_config_definition @fn_config_definition end |
#function_id ⇒ String
Ocid of the OCI Function.
12 13 14 |
# File 'lib/oci/data_integration/models/oci_function.rb', line 12 def function_id @function_id end |
#input_shape ⇒ OCI::DataIntegration::Models::Shape
22 23 24 |
# File 'lib/oci/data_integration/models/oci_function.rb', line 22 def input_shape @input_shape end |
#output_shape ⇒ OCI::DataIntegration::Models::Shape
25 26 27 |
# File 'lib/oci/data_integration/models/oci_function.rb', line 25 def output_shape @output_shape end |
#region_id ⇒ String
Region where the OCI Function is deployed.
16 17 18 |
# File 'lib/oci/data_integration/models/oci_function.rb', line 16 def region_id @region_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 35 36 37 38 |
# File 'lib/oci/data_integration/models/oci_function.rb', line 28 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'function_id': :'functionId', 'region_id': :'regionId', 'fn_config_definition': :'fnConfigDefinition', 'input_shape': :'inputShape', 'output_shape': :'outputShape' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/oci/data_integration/models/oci_function.rb', line 41 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'function_id': :'String', 'region_id': :'String', 'fn_config_definition': :'OCI::DataIntegration::Models::ConfigDefinition', 'input_shape': :'OCI::DataIntegration::Models::Shape', 'output_shape': :'OCI::DataIntegration::Models::Shape' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
108 109 110 111 112 113 114 115 116 117 |
# File 'lib/oci/data_integration/models/oci_function.rb', line 108 def ==(other) return true if equal?(other) self.class == other.class && function_id == other.function_id && region_id == other.region_id && fn_config_definition == other.fn_config_definition && input_shape == other.input_shape && output_shape == other.output_shape end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/oci/data_integration/models/oci_function.rb', line 142 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
122 123 124 |
# File 'lib/oci/data_integration/models/oci_function.rb', line 122 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
131 132 133 |
# File 'lib/oci/data_integration/models/oci_function.rb', line 131 def hash [function_id, region_id, fn_config_definition, input_shape, output_shape].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
175 176 177 178 179 180 181 182 183 184 |
# File 'lib/oci/data_integration/models/oci_function.rb', line 175 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
169 170 171 |
# File 'lib/oci/data_integration/models/oci_function.rb', line 169 def to_s to_hash.to_s end |