Class: OCI::DataIntegration::Models::OracleAtpWriteAttributes

Inherits:
AbstractWriteAttribute show all
Defined in:
lib/oci/data_integration/models/oracle_atp_write_attributes.rb

Overview

Properties to configure when writing to Oracle Autonomous Data Warehouse Cloud.

Constant Summary

Constants inherited from AbstractWriteAttribute

AbstractWriteAttribute::MODEL_TYPE_ENUM

Instance Attribute Summary collapse

Attributes inherited from AbstractWriteAttribute

#model_type

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from AbstractWriteAttribute

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ OracleAtpWriteAttributes

Initializes the object

Options Hash (attributes):

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/oci/data_integration/models/oracle_atp_write_attributes.rb', line 60

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['modelType'] = 'ORACLE_ATP_WRITE_ATTRIBUTE'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.bucket_schema = attributes[:'bucketSchema'] if attributes[:'bucketSchema']

  raise 'You cannot provide both :bucketSchema and :bucket_schema' if attributes.key?(:'bucketSchema') && attributes.key?(:'bucket_schema')

  self.bucket_schema = attributes[:'bucket_schema'] if attributes[:'bucket_schema']

  self.staging_file_name = attributes[:'stagingFileName'] if attributes[:'stagingFileName']

  raise 'You cannot provide both :stagingFileName and :staging_file_name' if attributes.key?(:'stagingFileName') && attributes.key?(:'staging_file_name')

  self.staging_file_name = attributes[:'staging_file_name'] if attributes[:'staging_file_name']

  self.staging_data_asset = attributes[:'stagingDataAsset'] if attributes[:'stagingDataAsset']

  raise 'You cannot provide both :stagingDataAsset and :staging_data_asset' if attributes.key?(:'stagingDataAsset') && attributes.key?(:'staging_data_asset')

  self.staging_data_asset = attributes[:'staging_data_asset'] if attributes[:'staging_data_asset']

  self.staging_connection = attributes[:'stagingConnection'] if attributes[:'stagingConnection']

  raise 'You cannot provide both :stagingConnection and :staging_connection' if attributes.key?(:'stagingConnection') && attributes.key?(:'staging_connection')

  self.staging_connection = attributes[:'staging_connection'] if attributes[:'staging_connection']
end

Instance Attribute Details

#bucket_schemaOCI::DataIntegration::Models::Schema

Returns:



12
13
14
# File 'lib/oci/data_integration/models/oracle_atp_write_attributes.rb', line 12

def bucket_schema
  @bucket_schema
end

#staging_connectionOCI::DataIntegration::Models::Connection

Returns:



22
23
24
# File 'lib/oci/data_integration/models/oracle_atp_write_attributes.rb', line 22

def staging_connection
  @staging_connection
end

#staging_data_assetOCI::DataIntegration::Models::DataAsset

Returns:



19
20
21
# File 'lib/oci/data_integration/models/oracle_atp_write_attributes.rb', line 19

def staging_data_asset
  @staging_data_asset
end

#staging_file_nameString

The file name for the attribute.

Returns:



16
17
18
# File 'lib/oci/data_integration/models/oracle_atp_write_attributes.rb', line 16

def staging_file_name
  @staging_file_name
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



25
26
27
28
29
30
31
32
33
34
35
# File 'lib/oci/data_integration/models/oracle_atp_write_attributes.rb', line 25

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'modelType',
    'bucket_schema': :'bucketSchema',
    'staging_file_name': :'stagingFileName',
    'staging_data_asset': :'stagingDataAsset',
    'staging_connection': :'stagingConnection'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



38
39
40
41
42
43
44
45
46
47
48
# File 'lib/oci/data_integration/models/oracle_atp_write_attributes.rb', line 38

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'String',
    'bucket_schema': :'OCI::DataIntegration::Models::Schema',
    'staging_file_name': :'String',
    'staging_data_asset': :'OCI::DataIntegration::Models::DataAsset',
    'staging_connection': :'OCI::DataIntegration::Models::Connection'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • the other object to be compared



102
103
104
105
106
107
108
109
110
111
# File 'lib/oci/data_integration/models/oracle_atp_write_attributes.rb', line 102

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    model_type == other.model_type &&
    bucket_schema == other.bucket_schema &&
    staging_file_name == other.staging_file_name &&
    staging_data_asset == other.staging_data_asset &&
    staging_connection == other.staging_connection
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/oci/data_integration/models/oracle_atp_write_attributes.rb', line 136

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method

Parameters:

  • the other object to be compared

Returns:



116
117
118
# File 'lib/oci/data_integration/models/oracle_atp_write_attributes.rb', line 116

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • Hash code



125
126
127
# File 'lib/oci/data_integration/models/oracle_atp_write_attributes.rb', line 125

def hash
  [model_type, bucket_schema, staging_file_name, staging_data_asset, staging_connection].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



169
170
171
172
173
174
175
176
177
178
# File 'lib/oci/data_integration/models/oracle_atp_write_attributes.rb', line 169

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



163
164
165
# File 'lib/oci/data_integration/models/oracle_atp_write_attributes.rb', line 163

def to_s
  to_hash.to_s
end