Class: OCI::DataIntegration::Models::OracleReadAttributes
- Inherits:
-
Object
- Object
- OCI::DataIntegration::Models::OracleReadAttributes
- Defined in:
- lib/oci/data_integration/models/oracle_read_attributes.rb
Overview
Properties to configure reading from an Oracle Database.
Instance Attribute Summary collapse
-
#fetch_size ⇒ Integer
The fetch size for reading.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OracleReadAttributes
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ OracleReadAttributes
Initializes the object
39 40 41 42 43 44 45 46 47 |
# File 'lib/oci/data_integration/models/oracle_read_attributes.rb', line 39 def initialize(attributes = {}) return unless attributes.is_a?(Hash) self.fetch_size = attributes[:'fetchSize'] if attributes[:'fetchSize'] raise 'You cannot provide both :fetchSize and :fetch_size' if attributes.key?(:'fetchSize') && attributes.key?(:'fetch_size') self.fetch_size = attributes[:'fetch_size'] if attributes[:'fetch_size'] end |
Instance Attribute Details
#fetch_size ⇒ Integer
The fetch size for reading.
12 13 14 |
# File 'lib/oci/data_integration/models/oracle_read_attributes.rb', line 12 def fetch_size @fetch_size end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
15 16 17 18 19 20 21 |
# File 'lib/oci/data_integration/models/oracle_read_attributes.rb', line 15 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'fetch_size': :'fetchSize' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
24 25 26 27 28 29 30 |
# File 'lib/oci/data_integration/models/oracle_read_attributes.rb', line 24 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'fetch_size': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
56 57 58 59 60 61 |
# File 'lib/oci/data_integration/models/oracle_read_attributes.rb', line 56 def ==(other) return true if equal?(other) self.class == other.class && fetch_size == other.fetch_size end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/oci/data_integration/models/oracle_read_attributes.rb', line 86 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
66 67 68 |
# File 'lib/oci/data_integration/models/oracle_read_attributes.rb', line 66 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
75 76 77 |
# File 'lib/oci/data_integration/models/oracle_read_attributes.rb', line 75 def hash [fetch_size].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
119 120 121 122 123 124 125 126 127 128 |
# File 'lib/oci/data_integration/models/oracle_read_attributes.rb', line 119 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
113 114 115 |
# File 'lib/oci/data_integration/models/oracle_read_attributes.rb', line 113 def to_s to_hash.to_s end |