Class: OCI::DataIntegration::Models::OracleWriteAttributes
- Inherits:
-
Object
- Object
- OCI::DataIntegration::Models::OracleWriteAttributes
- Defined in:
- lib/oci/data_integration/models/oracle_write_attributes.rb
Overview
Properties to configure when writing to an Oracle Database.
Instance Attribute Summary collapse
-
#batch_size ⇒ Integer
The batch size for writing.
-
#is_truncate ⇒ BOOLEAN
Specifies whether to truncate.
-
#isolation_level ⇒ String
Specifies the isolation level.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OracleWriteAttributes
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ OracleWriteAttributes
Initializes the object
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/oci/data_integration/models/oracle_write_attributes.rb', line 53 def initialize(attributes = {}) return unless attributes.is_a?(Hash) self.batch_size = attributes[:'batchSize'] if attributes[:'batchSize'] raise 'You cannot provide both :batchSize and :batch_size' if attributes.key?(:'batchSize') && attributes.key?(:'batch_size') self.batch_size = attributes[:'batch_size'] if attributes[:'batch_size'] self.is_truncate = attributes[:'isTruncate'] unless attributes[:'isTruncate'].nil? raise 'You cannot provide both :isTruncate and :is_truncate' if attributes.key?(:'isTruncate') && attributes.key?(:'is_truncate') self.is_truncate = attributes[:'is_truncate'] unless attributes[:'is_truncate'].nil? self.isolation_level = attributes[:'isolationLevel'] if attributes[:'isolationLevel'] raise 'You cannot provide both :isolationLevel and :isolation_level' if attributes.key?(:'isolationLevel') && attributes.key?(:'isolation_level') self.isolation_level = attributes[:'isolation_level'] if attributes[:'isolation_level'] end |
Instance Attribute Details
#batch_size ⇒ Integer
The batch size for writing.
12 13 14 |
# File 'lib/oci/data_integration/models/oracle_write_attributes.rb', line 12 def batch_size @batch_size end |
#is_truncate ⇒ BOOLEAN
Specifies whether to truncate.
16 17 18 |
# File 'lib/oci/data_integration/models/oracle_write_attributes.rb', line 16 def is_truncate @is_truncate end |
#isolation_level ⇒ String
Specifies the isolation level.
20 21 22 |
# File 'lib/oci/data_integration/models/oracle_write_attributes.rb', line 20 def isolation_level @isolation_level end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
23 24 25 26 27 28 29 30 31 |
# File 'lib/oci/data_integration/models/oracle_write_attributes.rb', line 23 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'batch_size': :'batchSize', 'is_truncate': :'isTruncate', 'isolation_level': :'isolationLevel' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
34 35 36 37 38 39 40 41 42 |
# File 'lib/oci/data_integration/models/oracle_write_attributes.rb', line 34 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'batch_size': :'Integer', 'is_truncate': :'BOOLEAN', 'isolation_level': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
82 83 84 85 86 87 88 89 |
# File 'lib/oci/data_integration/models/oracle_write_attributes.rb', line 82 def ==(other) return true if equal?(other) self.class == other.class && batch_size == other.batch_size && is_truncate == other.is_truncate && isolation_level == other.isolation_level end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/oci/data_integration/models/oracle_write_attributes.rb', line 114 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
94 95 96 |
# File 'lib/oci/data_integration/models/oracle_write_attributes.rb', line 94 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
103 104 105 |
# File 'lib/oci/data_integration/models/oracle_write_attributes.rb', line 103 def hash [batch_size, is_truncate, isolation_level].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
147 148 149 150 151 152 153 154 155 156 |
# File 'lib/oci/data_integration/models/oracle_write_attributes.rb', line 147 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
141 142 143 |
# File 'lib/oci/data_integration/models/oracle_write_attributes.rb', line 141 def to_s to_hash.to_s end |