Class: OCI::DataIntegration::Models::PatchChangeSummary
- Inherits:
-
Object
- Object
- OCI::DataIntegration::Models::PatchChangeSummary
- Defined in:
- lib/oci/data_integration/models/patch_change_summary.rb
Overview
This is the patch report summary information.
Constant Summary collapse
- TYPE_ENUM =
[ TYPE_INTEGRATION_TASK = 'INTEGRATION_TASK'.freeze, TYPE_DATA_LOADER_TASK = 'DATA_LOADER_TASK'.freeze, TYPE_PIPELINE_TASK = 'PIPELINE_TASK'.freeze, TYPE_SQL_TASK = 'SQL_TASK'.freeze, TYPE_OCI_DATAFLOW_TASK = 'OCI_DATAFLOW_TASK'.freeze, TYPE_REST_TASK = 'REST_TASK'.freeze, TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- ACTION_ENUM =
[ ACTION_CREATED = 'CREATED'.freeze, ACTION_DELETED = 'DELETED'.freeze, ACTION_UPDATED = 'UPDATED'.freeze, ACTION_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#action ⇒ String
The patch action indicating if object was created, updated, or deleted.
-
#identifier ⇒ String
Value can only contain upper case letters, underscore and numbers.
-
#key ⇒ String
The key of the object.
-
#name ⇒ String
Free form text without any restriction on permitted characters.
-
#name_path ⇒ String
The fully qualified path of the published object, which would include its project and folder.
-
#object_version ⇒ Integer
The object version.
-
#type ⇒ String
The type of the object in patch.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PatchChangeSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ PatchChangeSummary
Initializes the object
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/oci/data_integration/models/patch_change_summary.rb', line 99 def initialize(attributes = {}) return unless attributes.is_a?(Hash) self.key = attributes[:'key'] if attributes[:'key'] self.name = attributes[:'name'] if attributes[:'name'] self.name_path = attributes[:'namePath'] if attributes[:'namePath'] raise 'You cannot provide both :namePath and :name_path' if attributes.key?(:'namePath') && attributes.key?(:'name_path') self.name_path = attributes[:'name_path'] if attributes[:'name_path'] self.type = attributes[:'type'] if attributes[:'type'] self.object_version = attributes[:'objectVersion'] if attributes[:'objectVersion'] raise 'You cannot provide both :objectVersion and :object_version' if attributes.key?(:'objectVersion') && attributes.key?(:'object_version') self.object_version = attributes[:'object_version'] if attributes[:'object_version'] self.identifier = attributes[:'identifier'] if attributes[:'identifier'] self.action = attributes[:'action'] if attributes[:'action'] end |
Instance Attribute Details
#action ⇒ String
The patch action indicating if object was created, updated, or deleted.
54 55 56 |
# File 'lib/oci/data_integration/models/patch_change_summary.rb', line 54 def action @action end |
#identifier ⇒ String
Value can only contain upper case letters, underscore and numbers. It should begin with upper case letter or underscore. The value can be modified.
50 51 52 |
# File 'lib/oci/data_integration/models/patch_change_summary.rb', line 50 def identifier @identifier end |
#key ⇒ String
The key of the object.
30 31 32 |
# File 'lib/oci/data_integration/models/patch_change_summary.rb', line 30 def key @key end |
#name ⇒ String
Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.
34 35 36 |
# File 'lib/oci/data_integration/models/patch_change_summary.rb', line 34 def name @name end |
#name_path ⇒ String
The fully qualified path of the published object, which would include its project and folder.
38 39 40 |
# File 'lib/oci/data_integration/models/patch_change_summary.rb', line 38 def name_path @name_path end |
#object_version ⇒ Integer
The object version.
46 47 48 |
# File 'lib/oci/data_integration/models/patch_change_summary.rb', line 46 def object_version @object_version end |
#type ⇒ String
The type of the object in patch.
42 43 44 |
# File 'lib/oci/data_integration/models/patch_change_summary.rb', line 42 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/oci/data_integration/models/patch_change_summary.rb', line 57 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'key': :'key', 'name': :'name', 'name_path': :'namePath', 'type': :'type', 'object_version': :'objectVersion', 'identifier': :'identifier', 'action': :'action' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/oci/data_integration/models/patch_change_summary.rb', line 72 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'key': :'String', 'name': :'String', 'name_path': :'String', 'type': :'String', 'object_version': :'Integer', 'identifier': :'String', 'action': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/oci/data_integration/models/patch_change_summary.rb', line 158 def ==(other) return true if equal?(other) self.class == other.class && key == other.key && name == other.name && name_path == other.name_path && type == other.type && object_version == other.object_version && identifier == other.identifier && action == other.action end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/oci/data_integration/models/patch_change_summary.rb', line 194 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
174 175 176 |
# File 'lib/oci/data_integration/models/patch_change_summary.rb', line 174 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
183 184 185 |
# File 'lib/oci/data_integration/models/patch_change_summary.rb', line 183 def hash [key, name, name_path, type, object_version, identifier, action].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
227 228 229 230 231 232 233 234 235 236 |
# File 'lib/oci/data_integration/models/patch_change_summary.rb', line 227 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
221 222 223 |
# File 'lib/oci/data_integration/models/patch_change_summary.rb', line 221 def to_s to_hash.to_s end |