Class: OCI::DataIntegration::Models::PatchSummary
- Inherits:
-
Object
- Object
- OCI::DataIntegration::Models::PatchSummary
- Defined in:
- lib/oci/data_integration/models/patch_summary.rb
Overview
The patch summary type contains the audit summary information and the definition of the patch.
Constant Summary collapse
- PATCH_TYPE_ENUM =
[ PATCH_TYPE_PUBLISH = 'PUBLISH'.freeze, PATCH_TYPE_REFRESH = 'REFRESH'.freeze, PATCH_TYPE_UNPUBLISH = 'UNPUBLISH'.freeze, PATCH_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- PATCH_STATUS_ENUM =
[ PATCH_STATUS_QUEUED = 'QUEUED'.freeze, PATCH_STATUS_SUCCESSFUL = 'SUCCESSFUL'.freeze, PATCH_STATUS_FAILED = 'FAILED'.freeze, PATCH_STATUS_IN_PROGRESS = 'IN_PROGRESS'.freeze, PATCH_STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#application_version ⇒ Integer
The application version of the patch.
-
#dependent_object_metadata ⇒ Array<OCI::DataIntegration::Models::PatchObjectMetadata>
List of dependent objects in this patch.
-
#description ⇒ String
Detailed description for the object.
-
#error_messages ⇒ Hash<String, String>
The errors encountered while applying the patch, if any.
-
#identifier ⇒ String
Value can only contain upper case letters, underscore, and numbers.
-
#key ⇒ String
The object key.
-
#key_map ⇒ Hash<String, String>
A key map.
- #metadata ⇒ OCI::DataIntegration::Models::ObjectMetadata
-
#model_type ⇒ String
The object type.
-
#model_version ⇒ String
The object’s model version.
-
#name ⇒ String
Free form text without any restriction on permitted characters.
-
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
-
#object_version ⇒ Integer
The version of the object that is used to track changes in the object instance.
- #parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
-
#patch_object_metadata ⇒ Array<OCI::DataIntegration::Models::PatchObjectMetadata>
List of objects that are published or unpublished in this patch.
-
#patch_status ⇒ String
Status of the patch applied or being applied on the application.
-
#patch_type ⇒ String
The type of the patch applied or being applied on the application.
-
#time_patched ⇒ DateTime
The date and time the patch was applied, in the timestamp format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PatchSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ PatchSummary
Initializes the object
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 |
# File 'lib/oci/data_integration/models/patch_summary.rb', line 172 def initialize(attributes = {}) return unless attributes.is_a?(Hash) self.key = attributes[:'key'] if attributes[:'key'] self.model_type = attributes[:'modelType'] if attributes[:'modelType'] raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type') self.model_type = attributes[:'model_type'] if attributes[:'model_type'] self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion'] raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version') self.model_version = attributes[:'model_version'] if attributes[:'model_version'] self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.object_version = attributes[:'objectVersion'] if attributes[:'objectVersion'] raise 'You cannot provide both :objectVersion and :object_version' if attributes.key?(:'objectVersion') && attributes.key?(:'object_version') self.object_version = attributes[:'object_version'] if attributes[:'object_version'] self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus'] raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status') self.object_status = attributes[:'object_status'] if attributes[:'object_status'] self.identifier = attributes[:'identifier'] if attributes[:'identifier'] self.time_patched = attributes[:'timePatched'] if attributes[:'timePatched'] raise 'You cannot provide both :timePatched and :time_patched' if attributes.key?(:'timePatched') && attributes.key?(:'time_patched') self.time_patched = attributes[:'time_patched'] if attributes[:'time_patched'] self. = attributes[:'errorMessages'] if attributes[:'errorMessages'] raise 'You cannot provide both :errorMessages and :error_messages' if attributes.key?(:'errorMessages') && attributes.key?(:'error_messages') self. = attributes[:'error_messages'] if attributes[:'error_messages'] self.application_version = attributes[:'applicationVersion'] if attributes[:'applicationVersion'] raise 'You cannot provide both :applicationVersion and :application_version' if attributes.key?(:'applicationVersion') && attributes.key?(:'application_version') self.application_version = attributes[:'application_version'] if attributes[:'application_version'] self.patch_type = attributes[:'patchType'] if attributes[:'patchType'] raise 'You cannot provide both :patchType and :patch_type' if attributes.key?(:'patchType') && attributes.key?(:'patch_type') self.patch_type = attributes[:'patch_type'] if attributes[:'patch_type'] self.patch_status = attributes[:'patchStatus'] if attributes[:'patchStatus'] raise 'You cannot provide both :patchStatus and :patch_status' if attributes.key?(:'patchStatus') && attributes.key?(:'patch_status') self.patch_status = attributes[:'patch_status'] if attributes[:'patch_status'] self. = attributes[:'dependentObjectMetadata'] if attributes[:'dependentObjectMetadata'] raise 'You cannot provide both :dependentObjectMetadata and :dependent_object_metadata' if attributes.key?(:'dependentObjectMetadata') && attributes.key?(:'dependent_object_metadata') self. = attributes[:'dependent_object_metadata'] if attributes[:'dependent_object_metadata'] self. = attributes[:'patchObjectMetadata'] if attributes[:'patchObjectMetadata'] raise 'You cannot provide both :patchObjectMetadata and :patch_object_metadata' if attributes.key?(:'patchObjectMetadata') && attributes.key?(:'patch_object_metadata') self. = attributes[:'patch_object_metadata'] if attributes[:'patch_object_metadata'] self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef'] raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref') self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref'] self. = attributes[:'metadata'] if attributes[:'metadata'] self.key_map = attributes[:'keyMap'] if attributes[:'keyMap'] raise 'You cannot provide both :keyMap and :key_map' if attributes.key?(:'keyMap') && attributes.key?(:'key_map') self.key_map = attributes[:'key_map'] if attributes[:'key_map'] end |
Instance Attribute Details
#application_version ⇒ Integer
The application version of the patch.
68 69 70 |
# File 'lib/oci/data_integration/models/patch_summary.rb', line 68 def application_version @application_version end |
#dependent_object_metadata ⇒ Array<OCI::DataIntegration::Models::PatchObjectMetadata>
List of dependent objects in this patch.
80 81 82 |
# File 'lib/oci/data_integration/models/patch_summary.rb', line 80 def end |
#description ⇒ String
Detailed description for the object.
44 45 46 |
# File 'lib/oci/data_integration/models/patch_summary.rb', line 44 def description @description end |
#error_messages ⇒ Hash<String, String>
The errors encountered while applying the patch, if any.
64 65 66 |
# File 'lib/oci/data_integration/models/patch_summary.rb', line 64 def end |
#identifier ⇒ String
Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.
56 57 58 |
# File 'lib/oci/data_integration/models/patch_summary.rb', line 56 def identifier @identifier end |
#key ⇒ String
The object key.
28 29 30 |
# File 'lib/oci/data_integration/models/patch_summary.rb', line 28 def key @key end |
#key_map ⇒ Hash<String, String>
A key map. If provided, key is replaced with generated key. This structure provides mapping between user provided key and generated key.
94 95 96 |
# File 'lib/oci/data_integration/models/patch_summary.rb', line 94 def key_map @key_map end |
#metadata ⇒ OCI::DataIntegration::Models::ObjectMetadata
90 91 92 |
# File 'lib/oci/data_integration/models/patch_summary.rb', line 90 def end |
#model_type ⇒ String
The object type.
32 33 34 |
# File 'lib/oci/data_integration/models/patch_summary.rb', line 32 def model_type @model_type end |
#model_version ⇒ String
The object’s model version.
36 37 38 |
# File 'lib/oci/data_integration/models/patch_summary.rb', line 36 def model_version @model_version end |
#name ⇒ String
Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.
40 41 42 |
# File 'lib/oci/data_integration/models/patch_summary.rb', line 40 def name @name end |
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
52 53 54 |
# File 'lib/oci/data_integration/models/patch_summary.rb', line 52 def object_status @object_status end |
#object_version ⇒ Integer
The version of the object that is used to track changes in the object instance.
48 49 50 |
# File 'lib/oci/data_integration/models/patch_summary.rb', line 48 def object_version @object_version end |
#parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
87 88 89 |
# File 'lib/oci/data_integration/models/patch_summary.rb', line 87 def parent_ref @parent_ref end |
#patch_object_metadata ⇒ Array<OCI::DataIntegration::Models::PatchObjectMetadata>
List of objects that are published or unpublished in this patch.
84 85 86 |
# File 'lib/oci/data_integration/models/patch_summary.rb', line 84 def end |
#patch_status ⇒ String
Status of the patch applied or being applied on the application
76 77 78 |
# File 'lib/oci/data_integration/models/patch_summary.rb', line 76 def patch_status @patch_status end |
#patch_type ⇒ String
The type of the patch applied or being applied on the application.
72 73 74 |
# File 'lib/oci/data_integration/models/patch_summary.rb', line 72 def patch_type @patch_type end |
#time_patched ⇒ DateTime
The date and time the patch was applied, in the timestamp format defined by [RFC3339](tools.ietf.org/html/rfc3339).
60 61 62 |
# File 'lib/oci/data_integration/models/patch_summary.rb', line 60 def time_patched @time_patched end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/oci/data_integration/models/patch_summary.rb', line 97 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'key': :'key', 'model_type': :'modelType', 'model_version': :'modelVersion', 'name': :'name', 'description': :'description', 'object_version': :'objectVersion', 'object_status': :'objectStatus', 'identifier': :'identifier', 'time_patched': :'timePatched', 'error_messages': :'errorMessages', 'application_version': :'applicationVersion', 'patch_type': :'patchType', 'patch_status': :'patchStatus', 'dependent_object_metadata': :'dependentObjectMetadata', 'patch_object_metadata': :'patchObjectMetadata', 'parent_ref': :'parentRef', 'metadata': :'metadata', 'key_map': :'keyMap' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/oci/data_integration/models/patch_summary.rb', line 123 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'key': :'String', 'model_type': :'String', 'model_version': :'String', 'name': :'String', 'description': :'String', 'object_version': :'Integer', 'object_status': :'Integer', 'identifier': :'String', 'time_patched': :'DateTime', 'error_messages': :'Hash<String, String>', 'application_version': :'Integer', 'patch_type': :'String', 'patch_status': :'String', 'dependent_object_metadata': :'Array<OCI::DataIntegration::Models::PatchObjectMetadata>', 'patch_object_metadata': :'Array<OCI::DataIntegration::Models::PatchObjectMetadata>', 'parent_ref': :'OCI::DataIntegration::Models::ParentReference', 'metadata': :'OCI::DataIntegration::Models::ObjectMetadata', 'key_map': :'Hash<String, String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 |
# File 'lib/oci/data_integration/models/patch_summary.rb', line 297 def ==(other) return true if equal?(other) self.class == other.class && key == other.key && model_type == other.model_type && model_version == other.model_version && name == other.name && description == other.description && object_version == other.object_version && object_status == other.object_status && identifier == other.identifier && time_patched == other.time_patched && == other. && application_version == other.application_version && patch_type == other.patch_type && patch_status == other.patch_status && == other. && == other. && parent_ref == other.parent_ref && == other. && key_map == other.key_map end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 |
# File 'lib/oci/data_integration/models/patch_summary.rb', line 344 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
324 325 326 |
# File 'lib/oci/data_integration/models/patch_summary.rb', line 324 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
333 334 335 |
# File 'lib/oci/data_integration/models/patch_summary.rb', line 333 def hash [key, model_type, model_version, name, description, object_version, object_status, identifier, time_patched, , application_version, patch_type, patch_status, , , parent_ref, , key_map].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
377 378 379 380 381 382 383 384 385 386 |
# File 'lib/oci/data_integration/models/patch_summary.rb', line 377 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
371 372 373 |
# File 'lib/oci/data_integration/models/patch_summary.rb', line 371 def to_s to_hash.to_s end |