Class: DataIntegration::Models::Pivot
- Inherits:
-
Operator
- Object
- Operator
- DataIntegration::Models::Pivot
- Defined in:
- lib/oci/data_integration/models/pivot.rb
Overview
Pivot operator has one input and one output. Pivot operator takes group by columns, a pivot key with values and aggregations. Output is the pivoted table.
Instance Attribute Summary collapse
- #group_by_columns ⇒ OCI::DataIntegration::Models::DynamicProxyField
- #pivot_keys ⇒ OCI::DataIntegration::Models::PivotKeys
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Pivot
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Pivot
Initializes the object
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/oci/data_integration/models/pivot.rb', line 83 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['modelType'] = 'PIVOT_OPERATOR' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.group_by_columns = attributes[:'groupByColumns'] if attributes[:'groupByColumns'] raise 'You cannot provide both :groupByColumns and :group_by_columns' if attributes.key?(:'groupByColumns') && attributes.key?(:'group_by_columns') self.group_by_columns = attributes[:'group_by_columns'] if attributes[:'group_by_columns'] self.pivot_keys = attributes[:'pivotKeys'] if attributes[:'pivotKeys'] raise 'You cannot provide both :pivotKeys and :pivot_keys' if attributes.key?(:'pivotKeys') && attributes.key?(:'pivot_keys') self.pivot_keys = attributes[:'pivot_keys'] if attributes[:'pivot_keys'] end |
Instance Attribute Details
#group_by_columns ⇒ OCI::DataIntegration::Models::DynamicProxyField
12 13 14 |
# File 'lib/oci/data_integration/models/pivot.rb', line 12 def group_by_columns @group_by_columns end |
#pivot_keys ⇒ OCI::DataIntegration::Models::PivotKeys
15 16 17 |
# File 'lib/oci/data_integration/models/pivot.rb', line 15 def pivot_keys @pivot_keys end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 |
# File 'lib/oci/data_integration/models/pivot.rb', line 18 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'key': :'key', 'model_version': :'modelVersion', 'parent_ref': :'parentRef', 'name': :'name', 'description': :'description', 'object_version': :'objectVersion', 'input_ports': :'inputPorts', 'output_ports': :'outputPorts', 'object_status': :'objectStatus', 'identifier': :'identifier', 'parameters': :'parameters', 'op_config_values': :'opConfigValues', 'group_by_columns': :'groupByColumns', 'pivot_keys': :'pivotKeys' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/oci/data_integration/models/pivot.rb', line 41 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'key': :'String', 'model_version': :'String', 'parent_ref': :'OCI::DataIntegration::Models::ParentReference', 'name': :'String', 'description': :'String', 'object_version': :'Integer', 'input_ports': :'Array<OCI::DataIntegration::Models::InputPort>', 'output_ports': :'Array<OCI::DataIntegration::Models::TypedObject>', 'object_status': :'Integer', 'identifier': :'String', 'parameters': :'Array<OCI::DataIntegration::Models::Parameter>', 'op_config_values': :'OCI::DataIntegration::Models::ConfigValues', 'group_by_columns': :'OCI::DataIntegration::Models::DynamicProxyField', 'pivot_keys': :'OCI::DataIntegration::Models::PivotKeys' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/oci/data_integration/models/pivot.rb', line 113 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && key == other.key && model_version == other.model_version && parent_ref == other.parent_ref && name == other.name && description == other.description && object_version == other.object_version && input_ports == other.input_ports && output_ports == other.output_ports && object_status == other.object_status && identifier == other.identifier && parameters == other.parameters && op_config_values == other.op_config_values && group_by_columns == other.group_by_columns && pivot_keys == other.pivot_keys end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/oci/data_integration/models/pivot.rb', line 157 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
137 138 139 |
# File 'lib/oci/data_integration/models/pivot.rb', line 137 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
146 147 148 |
# File 'lib/oci/data_integration/models/pivot.rb', line 146 def hash [model_type, key, model_version, parent_ref, name, description, object_version, input_ports, output_ports, object_status, identifier, parameters, op_config_values, group_by_columns, pivot_keys].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
190 191 192 193 194 195 196 197 198 199 |
# File 'lib/oci/data_integration/models/pivot.rb', line 190 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
184 185 186 |
# File 'lib/oci/data_integration/models/pivot.rb', line 184 def to_s to_hash.to_s end |