Class: OCI::DataIntegration::Models::ProjectionRule
- Inherits:
-
Object
- Object
- OCI::DataIntegration::Models::ProjectionRule
- Defined in:
- lib/oci/data_integration/models/projection_rule.rb
Overview
Base type for how fields are projected. There are many different mechanisms for doing this such as by a name pattern, datatype and so on. See the modelType property for the types. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
NameListRule, NamePatternRule, RenameRule, TypeListRule, TypedNamePatternRule
Constant Summary collapse
- MODEL_TYPE_ENUM =
[ MODEL_TYPE_NAME_PATTERN_RULE = 'NAME_PATTERN_RULE'.freeze, MODEL_TYPE_TYPE_LIST_RULE = 'TYPE_LIST_RULE'.freeze, MODEL_TYPE_NAME_LIST_RULE = 'NAME_LIST_RULE'.freeze, MODEL_TYPE_TYPED_NAME_PATTERN_RULE = 'TYPED_NAME_PATTERN_RULE'.freeze, MODEL_TYPE_RENAME_RULE = 'RENAME_RULE'.freeze, MODEL_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
- #config_values ⇒ OCI::DataIntegration::Models::ConfigValues
-
#description ⇒ String
A user defined description for the object.
-
#is_java_regex_syntax ⇒ BOOLEAN
Specifies whether the rule uses a java regex syntax.
-
#key ⇒ String
The key of the object.
-
#model_type ⇒ String
[Required] The type of the project rule.
-
#model_version ⇒ String
The model version of an object.
-
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
- #parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ProjectionRule
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ProjectionRule
Initializes the object
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/oci/data_integration/models/projection_rule.rb', line 116 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.model_type = attributes[:'modelType'] if attributes[:'modelType'] raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type') self.model_type = attributes[:'model_type'] if attributes[:'model_type'] self.key = attributes[:'key'] if attributes[:'key'] self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion'] raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version') self.model_version = attributes[:'model_version'] if attributes[:'model_version'] self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef'] raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref') self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref'] self.is_java_regex_syntax = attributes[:'isJavaRegexSyntax'] unless attributes[:'isJavaRegexSyntax'].nil? raise 'You cannot provide both :isJavaRegexSyntax and :is_java_regex_syntax' if attributes.key?(:'isJavaRegexSyntax') && attributes.key?(:'is_java_regex_syntax') self.is_java_regex_syntax = attributes[:'is_java_regex_syntax'] unless attributes[:'is_java_regex_syntax'].nil? self.config_values = attributes[:'configValues'] if attributes[:'configValues'] raise 'You cannot provide both :configValues and :config_values' if attributes.key?(:'configValues') && attributes.key?(:'config_values') self.config_values = attributes[:'config_values'] if attributes[:'config_values'] self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus'] raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status') self.object_status = attributes[:'object_status'] if attributes[:'object_status'] self.description = attributes[:'description'] if attributes[:'description'] end |
Instance Attribute Details
#config_values ⇒ OCI::DataIntegration::Models::ConfigValues
41 42 43 |
# File 'lib/oci/data_integration/models/projection_rule.rb', line 41 def config_values @config_values end |
#description ⇒ String
A user defined description for the object.
49 50 51 |
# File 'lib/oci/data_integration/models/projection_rule.rb', line 49 def description @description end |
#is_java_regex_syntax ⇒ BOOLEAN
Specifies whether the rule uses a java regex syntax.
38 39 40 |
# File 'lib/oci/data_integration/models/projection_rule.rb', line 38 def is_java_regex_syntax @is_java_regex_syntax end |
#key ⇒ String
The key of the object.
27 28 29 |
# File 'lib/oci/data_integration/models/projection_rule.rb', line 27 def key @key end |
#model_type ⇒ String
[Required] The type of the project rule.
23 24 25 |
# File 'lib/oci/data_integration/models/projection_rule.rb', line 23 def model_type @model_type end |
#model_version ⇒ String
The model version of an object.
31 32 33 |
# File 'lib/oci/data_integration/models/projection_rule.rb', line 31 def model_version @model_version end |
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
45 46 47 |
# File 'lib/oci/data_integration/models/projection_rule.rb', line 45 def object_status @object_status end |
#parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
34 35 36 |
# File 'lib/oci/data_integration/models/projection_rule.rb', line 34 def parent_ref @parent_ref end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/oci/data_integration/models/projection_rule.rb', line 52 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'key': :'key', 'model_version': :'modelVersion', 'parent_ref': :'parentRef', 'is_java_regex_syntax': :'isJavaRegexSyntax', 'config_values': :'configValues', 'object_status': :'objectStatus', 'description': :'description' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/oci/data_integration/models/projection_rule.rb', line 88 def self.get_subtype(object_hash) type = object_hash[:'modelType'] # rubocop:disable Style/SymbolLiteral return 'OCI::DataIntegration::Models::RenameRule' if type == 'RENAME_RULE' return 'OCI::DataIntegration::Models::TypeListRule' if type == 'TYPE_LIST_RULE' return 'OCI::DataIntegration::Models::TypedNamePatternRule' if type == 'TYPED_NAME_PATTERN_RULE' return 'OCI::DataIntegration::Models::NamePatternRule' if type == 'NAME_PATTERN_RULE' return 'OCI::DataIntegration::Models::NameListRule' if type == 'NAME_LIST_RULE' # TODO: Log a warning when the subtype is not found. 'OCI::DataIntegration::Models::ProjectionRule' end |
.swagger_types ⇒ Object
Attribute type mapping.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/oci/data_integration/models/projection_rule.rb', line 68 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'key': :'String', 'model_version': :'String', 'parent_ref': :'OCI::DataIntegration::Models::ParentReference', 'is_java_regex_syntax': :'BOOLEAN', 'config_values': :'OCI::DataIntegration::Models::ConfigValues', 'object_status': :'Integer', 'description': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/oci/data_integration/models/projection_rule.rb', line 183 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && key == other.key && model_version == other.model_version && parent_ref == other.parent_ref && is_java_regex_syntax == other.is_java_regex_syntax && config_values == other.config_values && object_status == other.object_status && description == other.description end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/oci/data_integration/models/projection_rule.rb', line 220 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
200 201 202 |
# File 'lib/oci/data_integration/models/projection_rule.rb', line 200 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
209 210 211 |
# File 'lib/oci/data_integration/models/projection_rule.rb', line 209 def hash [model_type, key, model_version, parent_ref, is_java_regex_syntax, config_values, object_status, description].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
253 254 255 256 257 258 259 260 261 262 |
# File 'lib/oci/data_integration/models/projection_rule.rb', line 253 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
247 248 249 |
# File 'lib/oci/data_integration/models/projection_rule.rb', line 247 def to_s to_hash.to_s end |