Class: OCI::DataIntegration::Models::ProxyField
- Inherits:
-
TypedObject
- Object
- TypedObject
- OCI::DataIntegration::Models::ProxyField
- Defined in:
- lib/oci/data_integration/models/proxy_field.rb
Overview
A proxy field.
Constant Summary
Constants inherited from TypedObject
Instance Attribute Summary collapse
-
#labels ⇒ Array<String>
Labels are keywords or labels that you can add to data assets, dataflows and so on.
-
#scope ⇒ Object
Deprecated - Reference to a typed object.
- #scope_reference ⇒ OCI::DataIntegration::Models::ScopeReference
- #type ⇒ OCI::DataIntegration::Models::BaseType
Attributes inherited from TypedObject
#config_values, #description, #key, #model_type, #model_version, #name, #object_status, #parent_ref
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ProxyField
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from TypedObject
Constructor Details
#initialize(attributes = {}) ⇒ ProxyField
Initializes the object
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/oci/data_integration/models/proxy_field.rb', line 82 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['modelType'] = 'PROXY_FIELD' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.scope = attributes[:'scope'] if attributes[:'scope'] self.scope_reference = attributes[:'scopeReference'] if attributes[:'scopeReference'] raise 'You cannot provide both :scopeReference and :scope_reference' if attributes.key?(:'scopeReference') && attributes.key?(:'scope_reference') self.scope_reference = attributes[:'scope_reference'] if attributes[:'scope_reference'] self.type = attributes[:'type'] if attributes[:'type'] self.labels = attributes[:'labels'] if attributes[:'labels'] end |
Instance Attribute Details
#labels ⇒ Array<String>
Labels are keywords or labels that you can add to data assets, dataflows and so on. You can define your own labels and use them to categorize content.
23 24 25 |
# File 'lib/oci/data_integration/models/proxy_field.rb', line 23 def labels @labels end |
#scope ⇒ Object
Deprecated - Reference to a typed object. This can be either a key value to an object within the document, a shall referenced to a `TypedObject`, or a full `TypedObject` definition.
13 14 15 |
# File 'lib/oci/data_integration/models/proxy_field.rb', line 13 def scope @scope end |
#scope_reference ⇒ OCI::DataIntegration::Models::ScopeReference
16 17 18 |
# File 'lib/oci/data_integration/models/proxy_field.rb', line 16 def scope_reference @scope_reference end |
#type ⇒ OCI::DataIntegration::Models::BaseType
19 20 21 |
# File 'lib/oci/data_integration/models/proxy_field.rb', line 19 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 |
# File 'lib/oci/data_integration/models/proxy_field.rb', line 26 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'key': :'key', 'model_version': :'modelVersion', 'parent_ref': :'parentRef', 'config_values': :'configValues', 'object_status': :'objectStatus', 'name': :'name', 'description': :'description', 'scope': :'scope', 'scope_reference': :'scopeReference', 'type': :'type', 'labels': :'labels' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/oci/data_integration/models/proxy_field.rb', line 46 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'key': :'String', 'model_version': :'String', 'parent_ref': :'OCI::DataIntegration::Models::ParentReference', 'config_values': :'OCI::DataIntegration::Models::ConfigValues', 'object_status': :'Integer', 'name': :'String', 'description': :'String', 'scope': :'Object', 'scope_reference': :'OCI::DataIntegration::Models::ScopeReference', 'type': :'OCI::DataIntegration::Models::BaseType', 'labels': :'Array<String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/oci/data_integration/models/proxy_field.rb', line 112 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && key == other.key && model_version == other.model_version && parent_ref == other.parent_ref && config_values == other.config_values && object_status == other.object_status && name == other.name && description == other.description && scope == other.scope && scope_reference == other.scope_reference && type == other.type && labels == other.labels end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/oci/data_integration/models/proxy_field.rb', line 153 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
133 134 135 |
# File 'lib/oci/data_integration/models/proxy_field.rb', line 133 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
142 143 144 |
# File 'lib/oci/data_integration/models/proxy_field.rb', line 142 def hash [model_type, key, model_version, parent_ref, config_values, object_status, name, description, scope, scope_reference, type, labels].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
186 187 188 189 190 191 192 193 194 195 |
# File 'lib/oci/data_integration/models/proxy_field.rb', line 186 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
180 181 182 |
# File 'lib/oci/data_integration/models/proxy_field.rb', line 180 def to_s to_hash.to_s end |