Class: OCI::DataIntegration::Models::PublishedObject
- Inherits:
-
Object
- Object
- OCI::DataIntegration::Models::PublishedObject
- Defined in:
- lib/oci/data_integration/models/published_object.rb
Overview
The information about the published object. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
PublishedObjectFromDataLoaderTask, PublishedObjectFromIntegrationTask, PublishedObjectFromPipelineTask
Constant Summary collapse
- MODEL_TYPE_ENUM =
[ MODEL_TYPE_INTEGRATION_TASK = 'INTEGRATION_TASK'.freeze, MODEL_TYPE_DATA_LOADER_TASK = 'DATA_LOADER_TASK'.freeze, MODEL_TYPE_PIPELINE_TASK = 'PIPELINE_TASK'.freeze, MODEL_TYPE_SQL_TASK = 'SQL_TASK'.freeze, MODEL_TYPE_OCI_DATAFLOW_TASK = 'OCI_DATAFLOW_TASK'.freeze, MODEL_TYPE_REST_TASK = 'REST_TASK'.freeze, MODEL_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#description ⇒ String
Detailed description for the object.
-
#identifier ⇒ String
Value can only contain upper case letters, underscore, and numbers.
-
#key ⇒ String
Generated key that can be used in API calls to identify task.
-
#model_type ⇒ String
[Required] The type of the published object.
-
#model_version ⇒ String
The object’s model version.
-
#name ⇒ String
Free form text without any restriction on permitted characters.
-
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
-
#object_version ⇒ Integer
The version of the object that is used to track changes in the object instance.
- #parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PublishedObject
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ PublishedObject
Initializes the object
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/oci/data_integration/models/published_object.rb', line 123 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.model_type = attributes[:'modelType'] if attributes[:'modelType'] raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type') self.model_type = attributes[:'model_type'] if attributes[:'model_type'] self.key = attributes[:'key'] if attributes[:'key'] self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion'] raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version') self.model_version = attributes[:'model_version'] if attributes[:'model_version'] self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef'] raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref') self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref'] self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.object_version = attributes[:'objectVersion'] if attributes[:'objectVersion'] raise 'You cannot provide both :objectVersion and :object_version' if attributes.key?(:'objectVersion') && attributes.key?(:'object_version') self.object_version = attributes[:'object_version'] if attributes[:'object_version'] self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus'] raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status') self.object_status = attributes[:'object_status'] if attributes[:'object_status'] self.identifier = attributes[:'identifier'] if attributes[:'identifier'] end |
Instance Attribute Details
#description ⇒ String
Detailed description for the object.
43 44 45 |
# File 'lib/oci/data_integration/models/published_object.rb', line 43 def description @description end |
#identifier ⇒ String
Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.
55 56 57 |
# File 'lib/oci/data_integration/models/published_object.rb', line 55 def identifier @identifier end |
#key ⇒ String
Generated key that can be used in API calls to identify task. On scenarios where reference to the task is needed, a value can be passed in create.
28 29 30 |
# File 'lib/oci/data_integration/models/published_object.rb', line 28 def key @key end |
#model_type ⇒ String
[Required] The type of the published object.
24 25 26 |
# File 'lib/oci/data_integration/models/published_object.rb', line 24 def model_type @model_type end |
#model_version ⇒ String
The object’s model version.
32 33 34 |
# File 'lib/oci/data_integration/models/published_object.rb', line 32 def model_version @model_version end |
#name ⇒ String
Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.
39 40 41 |
# File 'lib/oci/data_integration/models/published_object.rb', line 39 def name @name end |
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
51 52 53 |
# File 'lib/oci/data_integration/models/published_object.rb', line 51 def object_status @object_status end |
#object_version ⇒ Integer
The version of the object that is used to track changes in the object instance.
47 48 49 |
# File 'lib/oci/data_integration/models/published_object.rb', line 47 def object_version @object_version end |
#parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
35 36 37 |
# File 'lib/oci/data_integration/models/published_object.rb', line 35 def parent_ref @parent_ref end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/oci/data_integration/models/published_object.rb', line 58 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'key': :'key', 'model_version': :'modelVersion', 'parent_ref': :'parentRef', 'name': :'name', 'description': :'description', 'object_version': :'objectVersion', 'object_status': :'objectStatus', 'identifier': :'identifier' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
96 97 98 99 100 101 102 103 104 105 |
# File 'lib/oci/data_integration/models/published_object.rb', line 96 def self.get_subtype(object_hash) type = object_hash[:'modelType'] # rubocop:disable Style/SymbolLiteral return 'OCI::DataIntegration::Models::PublishedObjectFromDataLoaderTask' if type == 'DATA_LOADER_TASK' return 'OCI::DataIntegration::Models::PublishedObjectFromPipelineTask' if type == 'PIPELINE_TASK' return 'OCI::DataIntegration::Models::PublishedObjectFromIntegrationTask' if type == 'INTEGRATION_TASK' # TODO: Log a warning when the subtype is not found. 'OCI::DataIntegration::Models::PublishedObject' end |
.swagger_types ⇒ Object
Attribute type mapping.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/oci/data_integration/models/published_object.rb', line 75 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'key': :'String', 'model_version': :'String', 'parent_ref': :'OCI::DataIntegration::Models::ParentReference', 'name': :'String', 'description': :'String', 'object_version': :'Integer', 'object_status': :'Integer', 'identifier': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/oci/data_integration/models/published_object.rb', line 188 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && key == other.key && model_version == other.model_version && parent_ref == other.parent_ref && name == other.name && description == other.description && object_version == other.object_version && object_status == other.object_status && identifier == other.identifier end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/oci/data_integration/models/published_object.rb', line 226 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
206 207 208 |
# File 'lib/oci/data_integration/models/published_object.rb', line 206 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
215 216 217 |
# File 'lib/oci/data_integration/models/published_object.rb', line 215 def hash [model_type, key, model_version, parent_ref, name, description, object_version, object_status, identifier].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
259 260 261 262 263 264 265 266 267 268 |
# File 'lib/oci/data_integration/models/published_object.rb', line 259 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
253 254 255 |
# File 'lib/oci/data_integration/models/published_object.rb', line 253 def to_s to_hash.to_s end |