Class: OCI::DataIntegration::Models::PublishedObjectFromIntegrationTask

Inherits:
PublishedObject
  • Object
show all
Defined in:
lib/oci/data_integration/models/published_object_from_integration_task.rb

Overview

The integration task published object.

Constant Summary

Constants inherited from PublishedObject

OCI::DataIntegration::Models::PublishedObject::MODEL_TYPE_ENUM

Instance Attribute Summary collapse

Attributes inherited from PublishedObject

#description, #identifier, #key, #model_type, #model_version, #name, #object_status, #object_version, #parent_ref

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from PublishedObject

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ PublishedObjectFromIntegrationTask

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/oci/data_integration/models/published_object_from_integration_task.rb', line 98

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['modelType'] = 'INTEGRATION_TASK'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.input_ports = attributes[:'inputPorts'] if attributes[:'inputPorts']

  raise 'You cannot provide both :inputPorts and :input_ports' if attributes.key?(:'inputPorts') && attributes.key?(:'input_ports')

  self.input_ports = attributes[:'input_ports'] if attributes[:'input_ports']

  self.output_ports = attributes[:'outputPorts'] if attributes[:'outputPorts']

  raise 'You cannot provide both :outputPorts and :output_ports' if attributes.key?(:'outputPorts') && attributes.key?(:'output_ports')

  self.output_ports = attributes[:'output_ports'] if attributes[:'output_ports']

  self.parameters = attributes[:'parameters'] if attributes[:'parameters']

  self.op_config_values = attributes[:'opConfigValues'] if attributes[:'opConfigValues']

  raise 'You cannot provide both :opConfigValues and :op_config_values' if attributes.key?(:'opConfigValues') && attributes.key?(:'op_config_values')

  self.op_config_values = attributes[:'op_config_values'] if attributes[:'op_config_values']

  self.config_provider_delegate = attributes[:'configProviderDelegate'] if attributes[:'configProviderDelegate']

  raise 'You cannot provide both :configProviderDelegate and :config_provider_delegate' if attributes.key?(:'configProviderDelegate') && attributes.key?(:'config_provider_delegate')

  self.config_provider_delegate = attributes[:'config_provider_delegate'] if attributes[:'config_provider_delegate']

  self.data_flow = attributes[:'dataFlow'] if attributes[:'dataFlow']

  raise 'You cannot provide both :dataFlow and :data_flow' if attributes.key?(:'dataFlow') && attributes.key?(:'data_flow')

  self.data_flow = attributes[:'data_flow'] if attributes[:'data_flow']
end

Instance Attribute Details

#config_provider_delegateOCI::DataIntegration::Models::ConfigProvider



27
28
29
# File 'lib/oci/data_integration/models/published_object_from_integration_task.rb', line 27

def config_provider_delegate
  @config_provider_delegate
end

#data_flowOCI::DataIntegration::Models::DataFlow



30
31
32
# File 'lib/oci/data_integration/models/published_object_from_integration_task.rb', line 30

def data_flow
  @data_flow
end

#input_portsArray<OCI::DataIntegration::Models::InputPort>

An array of input ports.



13
14
15
# File 'lib/oci/data_integration/models/published_object_from_integration_task.rb', line 13

def input_ports
  @input_ports
end

#op_config_valuesOCI::DataIntegration::Models::ConfigValues



24
25
26
# File 'lib/oci/data_integration/models/published_object_from_integration_task.rb', line 24

def op_config_values
  @op_config_values
end

#output_portsArray<OCI::DataIntegration::Models::OutputPort>

An array of output ports.



17
18
19
# File 'lib/oci/data_integration/models/published_object_from_integration_task.rb', line 17

def output_ports
  @output_ports
end

#parametersArray<OCI::DataIntegration::Models::Parameter>

An array of parameters.



21
22
23
# File 'lib/oci/data_integration/models/published_object_from_integration_task.rb', line 21

def parameters
  @parameters
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
# File 'lib/oci/data_integration/models/published_object_from_integration_task.rb', line 33

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'modelType',
    'key': :'key',
    'model_version': :'modelVersion',
    'parent_ref': :'parentRef',
    'name': :'name',
    'description': :'description',
    'object_version': :'objectVersion',
    'object_status': :'objectStatus',
    'identifier': :'identifier',
    'input_ports': :'inputPorts',
    'output_ports': :'outputPorts',
    'parameters': :'parameters',
    'op_config_values': :'opConfigValues',
    'config_provider_delegate': :'configProviderDelegate',
    'data_flow': :'dataFlow'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/oci/data_integration/models/published_object_from_integration_task.rb', line 56

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'String',
    'key': :'String',
    'model_version': :'String',
    'parent_ref': :'OCI::DataIntegration::Models::ParentReference',
    'name': :'String',
    'description': :'String',
    'object_version': :'Integer',
    'object_status': :'Integer',
    'identifier': :'String',
    'input_ports': :'Array<OCI::DataIntegration::Models::InputPort>',
    'output_ports': :'Array<OCI::DataIntegration::Models::OutputPort>',
    'parameters': :'Array<OCI::DataIntegration::Models::Parameter>',
    'op_config_values': :'OCI::DataIntegration::Models::ConfigValues',
    'config_provider_delegate': :'OCI::DataIntegration::Models::ConfigProvider',
    'data_flow': :'OCI::DataIntegration::Models::DataFlow'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/oci/data_integration/models/published_object_from_integration_task.rb', line 148

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    model_type == other.model_type &&
    key == other.key &&
    model_version == other.model_version &&
    parent_ref == other.parent_ref &&
    name == other.name &&
    description == other.description &&
    object_version == other.object_version &&
    object_status == other.object_status &&
    identifier == other.identifier &&
    input_ports == other.input_ports &&
    output_ports == other.output_ports &&
    parameters == other.parameters &&
    op_config_values == other.op_config_values &&
    config_provider_delegate == other.config_provider_delegate &&
    data_flow == other.data_flow
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/oci/data_integration/models/published_object_from_integration_task.rb', line 192

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


172
173
174
# File 'lib/oci/data_integration/models/published_object_from_integration_task.rb', line 172

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



181
182
183
# File 'lib/oci/data_integration/models/published_object_from_integration_task.rb', line 181

def hash
  [model_type, key, model_version, parent_ref, name, description, object_version, object_status, identifier, input_ports, output_ports, parameters, op_config_values, config_provider_delegate, data_flow].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



225
226
227
228
229
230
231
232
233
234
# File 'lib/oci/data_integration/models/published_object_from_integration_task.rb', line 225

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



219
220
221
# File 'lib/oci/data_integration/models/published_object_from_integration_task.rb', line 219

def to_s
  to_hash.to_s
end