Class: OCI::DataIntegration::Models::ReadOperationConfig

Inherits:
AbstractDataOperationConfig show all
Defined in:
lib/oci/data_integration/models/read_operation_config.rb

Overview

The information about the read operation.

Constant Summary

Constants inherited from AbstractDataOperationConfig

AbstractDataOperationConfig::MODEL_TYPE_ENUM

Instance Attribute Summary collapse

Attributes inherited from AbstractDataOperationConfig

#model_type

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from AbstractDataOperationConfig

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ ReadOperationConfig

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/oci/data_integration/models/read_operation_config.rb', line 88

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['modelType'] = 'READ_OPERATION_CONFIG'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.key = attributes[:'key'] if attributes[:'key']

  self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion']

  raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version')

  self.model_version = attributes[:'model_version'] if attributes[:'model_version']

  self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef']

  raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref')

  self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref']

  self.operations = attributes[:'operations'] if attributes[:'operations']

  self.data_format = attributes[:'dataFormat'] if attributes[:'dataFormat']

  raise 'You cannot provide both :dataFormat and :data_format' if attributes.key?(:'dataFormat') && attributes.key?(:'data_format')

  self.data_format = attributes[:'data_format'] if attributes[:'data_format']

  self.partition_config = attributes[:'partitionConfig'] if attributes[:'partitionConfig']

  raise 'You cannot provide both :partitionConfig and :partition_config' if attributes.key?(:'partitionConfig') && attributes.key?(:'partition_config')

  self.partition_config = attributes[:'partition_config'] if attributes[:'partition_config']

  self.read_attribute = attributes[:'readAttribute'] if attributes[:'readAttribute']

  raise 'You cannot provide both :readAttribute and :read_attribute' if attributes.key?(:'readAttribute') && attributes.key?(:'read_attribute')

  self.read_attribute = attributes[:'read_attribute'] if attributes[:'read_attribute']

  self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus']

  raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status')

  self.object_status = attributes[:'object_status'] if attributes[:'object_status']
end

Instance Attribute Details

#data_formatOCI::DataIntegration::Models::DataFormat



28
29
30
# File 'lib/oci/data_integration/models/read_operation_config.rb', line 28

def data_format
  @data_format
end

#keyString

The object key.

Returns:

  • (String)


14
15
16
# File 'lib/oci/data_integration/models/read_operation_config.rb', line 14

def key
  @key
end

#model_versionString

The object’s model version.

Returns:

  • (String)


18
19
20
# File 'lib/oci/data_integration/models/read_operation_config.rb', line 18

def model_version
  @model_version
end

#object_statusInteger

The status of an object that can be set to value 1 for shallow references across objects, other values reserved.

Returns:

  • (Integer)


38
39
40
# File 'lib/oci/data_integration/models/read_operation_config.rb', line 38

def object_status
  @object_status
end

#operationsArray<OCI::DataIntegration::Models::PushDownOperation>

An array of operations.



25
26
27
# File 'lib/oci/data_integration/models/read_operation_config.rb', line 25

def operations
  @operations
end

#parent_refOCI::DataIntegration::Models::ParentReference



21
22
23
# File 'lib/oci/data_integration/models/read_operation_config.rb', line 21

def parent_ref
  @parent_ref
end

#partition_configOCI::DataIntegration::Models::PartitionConfig



31
32
33
# File 'lib/oci/data_integration/models/read_operation_config.rb', line 31

def partition_config
  @partition_config
end

#read_attributeOCI::DataIntegration::Models::AbstractReadAttribute



34
35
36
# File 'lib/oci/data_integration/models/read_operation_config.rb', line 34

def read_attribute
  @read_attribute
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/oci/data_integration/models/read_operation_config.rb', line 41

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'modelType',
    'key': :'key',
    'model_version': :'modelVersion',
    'parent_ref': :'parentRef',
    'operations': :'operations',
    'data_format': :'dataFormat',
    'partition_config': :'partitionConfig',
    'read_attribute': :'readAttribute',
    'object_status': :'objectStatus'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/oci/data_integration/models/read_operation_config.rb', line 58

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'String',
    'key': :'String',
    'model_version': :'String',
    'parent_ref': :'OCI::DataIntegration::Models::ParentReference',
    'operations': :'Array<OCI::DataIntegration::Models::PushDownOperation>',
    'data_format': :'OCI::DataIntegration::Models::DataFormat',
    'partition_config': :'OCI::DataIntegration::Models::PartitionConfig',
    'read_attribute': :'OCI::DataIntegration::Models::AbstractReadAttribute',
    'object_status': :'Integer'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/oci/data_integration/models/read_operation_config.rb', line 146

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    model_type == other.model_type &&
    key == other.key &&
    model_version == other.model_version &&
    parent_ref == other.parent_ref &&
    operations == other.operations &&
    data_format == other.data_format &&
    partition_config == other.partition_config &&
    read_attribute == other.read_attribute &&
    object_status == other.object_status
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/oci/data_integration/models/read_operation_config.rb', line 184

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


164
165
166
# File 'lib/oci/data_integration/models/read_operation_config.rb', line 164

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



173
174
175
# File 'lib/oci/data_integration/models/read_operation_config.rb', line 173

def hash
  [model_type, key, model_version, parent_ref, operations, data_format, partition_config, read_attribute, object_status].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



217
218
219
220
221
222
223
224
225
226
# File 'lib/oci/data_integration/models/read_operation_config.rb', line 217

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



211
212
213
# File 'lib/oci/data_integration/models/read_operation_config.rb', line 211

def to_s
  to_hash.to_s
end