Class: OCI::DataIntegration::Models::Reference

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_integration/models/reference.rb

Overview

Reference contains application configuration information.

Constant Summary collapse

TYPE_ENUM =
[
  TYPE_ORACLE_DATA_ASSET = 'ORACLE_DATA_ASSET'.freeze,
  TYPE_ORACLE_OBJECT_STORAGE_DATA_ASSET = 'ORACLE_OBJECT_STORAGE_DATA_ASSET'.freeze,
  TYPE_ORACLE_ATP_DATA_ASSET = 'ORACLE_ATP_DATA_ASSET'.freeze,
  TYPE_ORACLE_ADWC_DATA_ASSET = 'ORACLE_ADWC_DATA_ASSET'.freeze,
  TYPE_MYSQL_DATA_ASSET = 'MYSQL_DATA_ASSET'.freeze,
  TYPE_GENERIC_JDBC_DATA_ASSET = 'GENERIC_JDBC_DATA_ASSET'.freeze,
  TYPE_FUSION_APP_DATA_ASSET = 'FUSION_APP_DATA_ASSET'.freeze,
  TYPE_AMAZON_S3_DATA_ASSET = 'AMAZON_S3_DATA_ASSET'.freeze,
  TYPE_SCHEMA = 'SCHEMA'.freeze,
  TYPE_INTEGRATION_TASK = 'INTEGRATION_TASK'.freeze,
  TYPE_DATA_LOADER_TASK = 'DATA_LOADER_TASK'.freeze,
  TYPE_SQL_TASK = 'SQL_TASK'.freeze,
  TYPE_OCI_DATAFLOW_TASK = 'OCI_DATAFLOW_TASK'.freeze,
  TYPE_PIPELINE_TASK = 'PIPELINE_TASK'.freeze,
  TYPE_REST_TASK = 'REST_TASK'.freeze,
  TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Reference

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/oci/data_integration/models/reference.rb', line 122

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.key = attributes[:'key'] if attributes[:'key']

  self.name = attributes[:'name'] if attributes[:'name']

  self.identifier = attributes[:'identifier'] if attributes[:'identifier']

  self.identifier_path = attributes[:'identifierPath'] if attributes[:'identifierPath']

  raise 'You cannot provide both :identifierPath and :identifier_path' if attributes.key?(:'identifierPath') && attributes.key?(:'identifier_path')

  self.identifier_path = attributes[:'identifier_path'] if attributes[:'identifier_path']

  self.description = attributes[:'description'] if attributes[:'description']

  self.type = attributes[:'type'] if attributes[:'type']

  self.target_object = attributes[:'targetObject'] if attributes[:'targetObject']

  raise 'You cannot provide both :targetObject and :target_object' if attributes.key?(:'targetObject') && attributes.key?(:'target_object')

  self.target_object = attributes[:'target_object'] if attributes[:'target_object']

  self.application_key = attributes[:'applicationKey'] if attributes[:'applicationKey']

  raise 'You cannot provide both :applicationKey and :application_key' if attributes.key?(:'applicationKey') && attributes.key?(:'application_key')

  self.application_key = attributes[:'application_key'] if attributes[:'application_key']

  self.used_by = attributes[:'usedBy'] if attributes[:'usedBy']

  raise 'You cannot provide both :usedBy and :used_by' if attributes.key?(:'usedBy') && attributes.key?(:'used_by')

  self.used_by = attributes[:'used_by'] if attributes[:'used_by']

  self.child_references = attributes[:'childReferences'] if attributes[:'childReferences']

  raise 'You cannot provide both :childReferences and :child_references' if attributes.key?(:'childReferences') && attributes.key?(:'child_references')

  self.child_references = attributes[:'child_references'] if attributes[:'child_references']
end

Instance Attribute Details

#application_keyString

The application key of the reference object.

Returns:

  • (String)


60
61
62
# File 'lib/oci/data_integration/models/reference.rb', line 60

def application_key
  @application_key
end

#child_referencesArray<OCI::DataIntegration::Models::ChildReference>

List of references that are dependent on this reference.



68
69
70
# File 'lib/oci/data_integration/models/reference.rb', line 68

def child_references
  @child_references
end

#descriptionString

The description of reference object.

Returns:

  • (String)


48
49
50
# File 'lib/oci/data_integration/models/reference.rb', line 48

def description
  @description
end

#identifierString

The identifier of reference object.

Returns:

  • (String)


40
41
42
# File 'lib/oci/data_integration/models/reference.rb', line 40

def identifier
  @identifier
end

#identifier_pathString

The identifier path of reference object.

Returns:

  • (String)


44
45
46
# File 'lib/oci/data_integration/models/reference.rb', line 44

def identifier_path
  @identifier_path
end

#keyString

The reference's key, key of the object that is being used by a published object or its dependents.

Returns:

  • (String)


32
33
34
# File 'lib/oci/data_integration/models/reference.rb', line 32

def key
  @key
end

#nameString

The name of reference object.

Returns:

  • (String)


36
37
38
# File 'lib/oci/data_integration/models/reference.rb', line 36

def name
  @name
end

#target_objectObject

The new reference object to use instead of the original reference. For example, this can be a data asset reference.

Returns:

  • (Object)


56
57
58
# File 'lib/oci/data_integration/models/reference.rb', line 56

def target_object
  @target_object
end

#typeString

The type of reference object.

Returns:

  • (String)


52
53
54
# File 'lib/oci/data_integration/models/reference.rb', line 52

def type
  @type
end

#used_byArray<OCI::DataIntegration::Models::ReferenceUsedBy>

List of published objects where this is used.



64
65
66
# File 'lib/oci/data_integration/models/reference.rb', line 64

def used_by
  @used_by
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/oci/data_integration/models/reference.rb', line 71

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'key',
    'name': :'name',
    'identifier': :'identifier',
    'identifier_path': :'identifierPath',
    'description': :'description',
    'type': :'type',
    'target_object': :'targetObject',
    'application_key': :'applicationKey',
    'used_by': :'usedBy',
    'child_references': :'childReferences'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/oci/data_integration/models/reference.rb', line 89

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'String',
    'name': :'String',
    'identifier': :'String',
    'identifier_path': :'String',
    'description': :'String',
    'type': :'String',
    'target_object': :'Object',
    'application_key': :'String',
    'used_by': :'Array<OCI::DataIntegration::Models::ReferenceUsedBy>',
    'child_references': :'Array<OCI::DataIntegration::Models::ChildReference>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/oci/data_integration/models/reference.rb', line 189

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    key == other.key &&
    name == other.name &&
    identifier == other.identifier &&
    identifier_path == other.identifier_path &&
    description == other.description &&
    type == other.type &&
    target_object == other.target_object &&
    application_key == other.application_key &&
    used_by == other.used_by &&
    child_references == other.child_references
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
# File 'lib/oci/data_integration/models/reference.rb', line 228

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


208
209
210
# File 'lib/oci/data_integration/models/reference.rb', line 208

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



217
218
219
# File 'lib/oci/data_integration/models/reference.rb', line 217

def hash
  [key, name, identifier, identifier_path, description, type, target_object, application_key, used_by, child_references].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



261
262
263
264
265
266
267
268
269
270
# File 'lib/oci/data_integration/models/reference.rb', line 261

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



255
256
257
# File 'lib/oci/data_integration/models/reference.rb', line 255

def to_s
  to_hash.to_s
end