Class: OCI::DataIntegration::Models::RegistryMetadata

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_integration/models/registry_metadata.rb

Overview

Information about the object and its parent.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ RegistryMetadata

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :aggregator_key (String)

    The value to assign to the #aggregator_key property

  • :labels (Array<String>)

    The value to assign to the #labels property

  • :registry_version (Integer)

    The value to assign to the #registry_version property

  • :key (String)

    The value to assign to the #key property

  • :is_favorite (BOOLEAN)

    The value to assign to the #is_favorite property



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/oci/data_integration/models/registry_metadata.rb', line 67

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.aggregator_key = attributes[:'aggregatorKey'] if attributes[:'aggregatorKey']

  raise 'You cannot provide both :aggregatorKey and :aggregator_key' if attributes.key?(:'aggregatorKey') && attributes.key?(:'aggregator_key')

  self.aggregator_key = attributes[:'aggregator_key'] if attributes[:'aggregator_key']

  self.labels = attributes[:'labels'] if attributes[:'labels']

  self.registry_version = attributes[:'registryVersion'] if attributes[:'registryVersion']

  raise 'You cannot provide both :registryVersion and :registry_version' if attributes.key?(:'registryVersion') && attributes.key?(:'registry_version')

  self.registry_version = attributes[:'registry_version'] if attributes[:'registry_version']

  self.key = attributes[:'key'] if attributes[:'key']

  self.is_favorite = attributes[:'isFavorite'] unless attributes[:'isFavorite'].nil?
  self.is_favorite = false if is_favorite.nil? && !attributes.key?(:'isFavorite') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isFavorite and :is_favorite' if attributes.key?(:'isFavorite') && attributes.key?(:'is_favorite')

  self.is_favorite = attributes[:'is_favorite'] unless attributes[:'is_favorite'].nil?
  self.is_favorite = false if is_favorite.nil? && !attributes.key?(:'isFavorite') && !attributes.key?(:'is_favorite') # rubocop:disable Style/StringLiterals
end

Instance Attribute Details

#aggregator_keyString

The owning object’s key for this object.

Returns:

  • (String)


12
13
14
# File 'lib/oci/data_integration/models/registry_metadata.rb', line 12

def aggregator_key
  @aggregator_key
end

#is_favoriteBOOLEAN

Specifies whether this object is a favorite or not.

Returns:

  • (BOOLEAN)


28
29
30
# File 'lib/oci/data_integration/models/registry_metadata.rb', line 28

def is_favorite
  @is_favorite
end

#keyString

The identifying key for the object.

Returns:

  • (String)


24
25
26
# File 'lib/oci/data_integration/models/registry_metadata.rb', line 24

def key
  @key
end

#labelsArray<String>

Labels are keywords or labels that you can add to data assets, dataflows etc. You can define your own labels and use them to categorize content.

Returns:

  • (Array<String>)


16
17
18
# File 'lib/oci/data_integration/models/registry_metadata.rb', line 16

def labels
  @labels
end

#registry_versionInteger

The registry version.

Returns:

  • (Integer)


20
21
22
# File 'lib/oci/data_integration/models/registry_metadata.rb', line 20

def registry_version
  @registry_version
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
40
41
# File 'lib/oci/data_integration/models/registry_metadata.rb', line 31

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'aggregator_key': :'aggregatorKey',
    'labels': :'labels',
    'registry_version': :'registryVersion',
    'key': :'key',
    'is_favorite': :'isFavorite'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



44
45
46
47
48
49
50
51
52
53
54
# File 'lib/oci/data_integration/models/registry_metadata.rb', line 44

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'aggregator_key': :'String',
    'labels': :'Array<String>',
    'registry_version': :'Integer',
    'key': :'String',
    'is_favorite': :'BOOLEAN'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



105
106
107
108
109
110
111
112
113
114
# File 'lib/oci/data_integration/models/registry_metadata.rb', line 105

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    aggregator_key == other.aggregator_key &&
    labels == other.labels &&
    registry_version == other.registry_version &&
    key == other.key &&
    is_favorite == other.is_favorite
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/oci/data_integration/models/registry_metadata.rb', line 139

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


119
120
121
# File 'lib/oci/data_integration/models/registry_metadata.rb', line 119

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



128
129
130
# File 'lib/oci/data_integration/models/registry_metadata.rb', line 128

def hash
  [aggregator_key, labels, registry_version, key, is_favorite].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



172
173
174
175
176
177
178
179
180
181
# File 'lib/oci/data_integration/models/registry_metadata.rb', line 172

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



166
167
168
# File 'lib/oci/data_integration/models/registry_metadata.rb', line 166

def to_s
  to_hash.to_s
end