Class: OCI::DataIntegration::Models::RuleBasedEntityMap
- Defined in:
- lib/oci/data_integration/models/rule_based_entity_map.rb
Overview
A map of rule patterns.
Constant Summary collapse
- MAP_TYPE_ENUM =
[ MAP_TYPE_MAPBYNAME = 'MAPBYNAME'.freeze, MAP_TYPE_MAPBYPATTERN = 'MAPBYPATTERN'.freeze, MAP_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Constants inherited from FieldMap
Instance Attribute Summary collapse
- #config_values ⇒ OCI::DataIntegration::Models::ConfigValues
-
#from_pattern ⇒ String
The pattern to map from.
-
#is_java_regex_syntax ⇒ BOOLEAN
Specifies whether the rule uses a java regex syntax.
-
#key ⇒ String
The object key.
-
#map_type ⇒ String
mapType.
-
#model_version ⇒ String
The object's model version.
-
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
- #parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
-
#to_pattern ⇒ String
The pattern to map to.
Attributes inherited from FieldMap
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RuleBasedEntityMap
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from FieldMap
Constructor Details
#initialize(attributes = {}) ⇒ RuleBasedEntityMap
Initializes the object
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/oci/data_integration/models/rule_based_entity_map.rb', line 106 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['modelType'] = 'RULE_BASED_ENTITY_MAP' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.key = attributes[:'key'] if attributes[:'key'] self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion'] raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version') self.model_version = attributes[:'model_version'] if attributes[:'model_version'] self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef'] raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref') self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref'] self.config_values = attributes[:'configValues'] if attributes[:'configValues'] raise 'You cannot provide both :configValues and :config_values' if attributes.key?(:'configValues') && attributes.key?(:'config_values') self.config_values = attributes[:'config_values'] if attributes[:'config_values'] self.map_type = attributes[:'mapType'] if attributes[:'mapType'] raise 'You cannot provide both :mapType and :map_type' if attributes.key?(:'mapType') && attributes.key?(:'map_type') self.map_type = attributes[:'map_type'] if attributes[:'map_type'] self.from_pattern = attributes[:'fromPattern'] if attributes[:'fromPattern'] raise 'You cannot provide both :fromPattern and :from_pattern' if attributes.key?(:'fromPattern') && attributes.key?(:'from_pattern') self.from_pattern = attributes[:'from_pattern'] if attributes[:'from_pattern'] self.to_pattern = attributes[:'toPattern'] if attributes[:'toPattern'] raise 'You cannot provide both :toPattern and :to_pattern' if attributes.key?(:'toPattern') && attributes.key?(:'to_pattern') self.to_pattern = attributes[:'to_pattern'] if attributes[:'to_pattern'] self.is_java_regex_syntax = attributes[:'isJavaRegexSyntax'] unless attributes[:'isJavaRegexSyntax'].nil? raise 'You cannot provide both :isJavaRegexSyntax and :is_java_regex_syntax' if attributes.key?(:'isJavaRegexSyntax') && attributes.key?(:'is_java_regex_syntax') self.is_java_regex_syntax = attributes[:'is_java_regex_syntax'] unless attributes[:'is_java_regex_syntax'].nil? self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus'] raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status') self.object_status = attributes[:'object_status'] if attributes[:'object_status'] end |
Instance Attribute Details
#config_values ⇒ OCI::DataIntegration::Models::ConfigValues
30 31 32 |
# File 'lib/oci/data_integration/models/rule_based_entity_map.rb', line 30 def config_values @config_values end |
#from_pattern ⇒ String
The pattern to map from.
38 39 40 |
# File 'lib/oci/data_integration/models/rule_based_entity_map.rb', line 38 def from_pattern @from_pattern end |
#is_java_regex_syntax ⇒ BOOLEAN
Specifies whether the rule uses a java regex syntax.
46 47 48 |
# File 'lib/oci/data_integration/models/rule_based_entity_map.rb', line 46 def is_java_regex_syntax @is_java_regex_syntax end |
#key ⇒ String
The object key.
20 21 22 |
# File 'lib/oci/data_integration/models/rule_based_entity_map.rb', line 20 def key @key end |
#map_type ⇒ String
mapType
34 35 36 |
# File 'lib/oci/data_integration/models/rule_based_entity_map.rb', line 34 def map_type @map_type end |
#model_version ⇒ String
The object's model version.
24 25 26 |
# File 'lib/oci/data_integration/models/rule_based_entity_map.rb', line 24 def model_version @model_version end |
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
50 51 52 |
# File 'lib/oci/data_integration/models/rule_based_entity_map.rb', line 50 def object_status @object_status end |
#parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
27 28 29 |
# File 'lib/oci/data_integration/models/rule_based_entity_map.rb', line 27 def parent_ref @parent_ref end |
#to_pattern ⇒ String
The pattern to map to.
42 43 44 |
# File 'lib/oci/data_integration/models/rule_based_entity_map.rb', line 42 def to_pattern @to_pattern end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/oci/data_integration/models/rule_based_entity_map.rb', line 53 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'description': :'description', 'key': :'key', 'model_version': :'modelVersion', 'parent_ref': :'parentRef', 'config_values': :'configValues', 'map_type': :'mapType', 'from_pattern': :'fromPattern', 'to_pattern': :'toPattern', 'is_java_regex_syntax': :'isJavaRegexSyntax', 'object_status': :'objectStatus' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/oci/data_integration/models/rule_based_entity_map.rb', line 72 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'description': :'String', 'key': :'String', 'model_version': :'String', 'parent_ref': :'OCI::DataIntegration::Models::ParentReference', 'config_values': :'OCI::DataIntegration::Models::ConfigValues', 'map_type': :'String', 'from_pattern': :'String', 'to_pattern': :'String', 'is_java_regex_syntax': :'BOOLEAN', 'object_status': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/oci/data_integration/models/rule_based_entity_map.rb', line 187 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && description == other.description && key == other.key && model_version == other.model_version && parent_ref == other.parent_ref && config_values == other.config_values && map_type == other.map_type && from_pattern == other.from_pattern && to_pattern == other.to_pattern && is_java_regex_syntax == other.is_java_regex_syntax && object_status == other.object_status end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/oci/data_integration/models/rule_based_entity_map.rb', line 227 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
207 208 209 |
# File 'lib/oci/data_integration/models/rule_based_entity_map.rb', line 207 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
216 217 218 |
# File 'lib/oci/data_integration/models/rule_based_entity_map.rb', line 216 def hash [model_type, description, key, model_version, parent_ref, config_values, map_type, from_pattern, to_pattern, is_java_regex_syntax, object_status].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
260 261 262 263 264 265 266 267 268 269 |
# File 'lib/oci/data_integration/models/rule_based_entity_map.rb', line 260 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
254 255 256 |
# File 'lib/oci/data_integration/models/rule_based_entity_map.rb', line 254 def to_s to_hash.to_s end |