Class: OCI::DataIntegration::Models::RuleTypeConfig
- Inherits:
-
DynamicTypeHandler
- Object
- DynamicTypeHandler
- OCI::DataIntegration::Models::RuleTypeConfig
- Defined in:
- lib/oci/data_integration/models/rule_type_config.rb
Overview
The rule type config.
Constant Summary
Constants inherited from DynamicTypeHandler
DynamicTypeHandler::MODEL_TYPE_ENUM
Instance Attribute Summary collapse
- #config_values ⇒ OCI::DataIntegration::Models::ConfigValues
-
#is_order_by_rule ⇒ BOOLEAN
Specifies whether it is ordered by rule.
-
#key ⇒ String
The key of the object.
-
#model_version ⇒ String
The model version of an object.
-
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
- #parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
-
#projection_rules ⇒ Array<OCI::DataIntegration::Models::ProjectionRule>
The projection rules.
-
#scope ⇒ Object
Reference to a typed object, this can be either a key value to an object within the document, a shall referenced to a
TypedObjector a fullTypedObjectdefinition.
Attributes inherited from DynamicTypeHandler
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RuleTypeConfig
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from DynamicTypeHandler
Constructor Details
#initialize(attributes = {}) ⇒ RuleTypeConfig
Initializes the object
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/oci/data_integration/models/rule_type_config.rb', line 90 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['modelType'] = 'RULE_TYPE_CONFIGS' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.key = attributes[:'key'] if attributes[:'key'] self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion'] raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version') self.model_version = attributes[:'model_version'] if attributes[:'model_version'] self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef'] raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref') self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref'] self.scope = attributes[:'scope'] if attributes[:'scope'] self.is_order_by_rule = attributes[:'isOrderByRule'] unless attributes[:'isOrderByRule'].nil? raise 'You cannot provide both :isOrderByRule and :is_order_by_rule' if attributes.key?(:'isOrderByRule') && attributes.key?(:'is_order_by_rule') self.is_order_by_rule = attributes[:'is_order_by_rule'] unless attributes[:'is_order_by_rule'].nil? self.projection_rules = attributes[:'projectionRules'] if attributes[:'projectionRules'] raise 'You cannot provide both :projectionRules and :projection_rules' if attributes.key?(:'projectionRules') && attributes.key?(:'projection_rules') self.projection_rules = attributes[:'projection_rules'] if attributes[:'projection_rules'] self.config_values = attributes[:'configValues'] if attributes[:'configValues'] raise 'You cannot provide both :configValues and :config_values' if attributes.key?(:'configValues') && attributes.key?(:'config_values') self.config_values = attributes[:'config_values'] if attributes[:'config_values'] self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus'] raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status') self.object_status = attributes[:'object_status'] if attributes[:'object_status'] end |
Instance Attribute Details
#config_values ⇒ OCI::DataIntegration::Models::ConfigValues
36 37 38 |
# File 'lib/oci/data_integration/models/rule_type_config.rb', line 36 def config_values @config_values end |
#is_order_by_rule ⇒ BOOLEAN
Specifies whether it is ordered by rule.
29 30 31 |
# File 'lib/oci/data_integration/models/rule_type_config.rb', line 29 def is_order_by_rule @is_order_by_rule end |
#key ⇒ String
The key of the object.
14 15 16 |
# File 'lib/oci/data_integration/models/rule_type_config.rb', line 14 def key @key end |
#model_version ⇒ String
The model version of an object.
18 19 20 |
# File 'lib/oci/data_integration/models/rule_type_config.rb', line 18 def model_version @model_version end |
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
40 41 42 |
# File 'lib/oci/data_integration/models/rule_type_config.rb', line 40 def object_status @object_status end |
#parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
21 22 23 |
# File 'lib/oci/data_integration/models/rule_type_config.rb', line 21 def parent_ref @parent_ref end |
#projection_rules ⇒ Array<OCI::DataIntegration::Models::ProjectionRule>
The projection rules.
33 34 35 |
# File 'lib/oci/data_integration/models/rule_type_config.rb', line 33 def projection_rules @projection_rules end |
#scope ⇒ Object
Reference to a typed object, this can be either a key value to an object within the document, a shall referenced to a TypedObject or a full TypedObject definition.
25 26 27 |
# File 'lib/oci/data_integration/models/rule_type_config.rb', line 25 def scope @scope end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/oci/data_integration/models/rule_type_config.rb', line 43 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'key': :'key', 'model_version': :'modelVersion', 'parent_ref': :'parentRef', 'scope': :'scope', 'is_order_by_rule': :'isOrderByRule', 'projection_rules': :'projectionRules', 'config_values': :'configValues', 'object_status': :'objectStatus' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/oci/data_integration/models/rule_type_config.rb', line 60 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'key': :'String', 'model_version': :'String', 'parent_ref': :'OCI::DataIntegration::Models::ParentReference', 'scope': :'Object', 'is_order_by_rule': :'BOOLEAN', 'projection_rules': :'Array<OCI::DataIntegration::Models::ProjectionRule>', 'config_values': :'OCI::DataIntegration::Models::ConfigValues', 'object_status': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/oci/data_integration/models/rule_type_config.rb', line 148 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && key == other.key && model_version == other.model_version && parent_ref == other.parent_ref && scope == other.scope && is_order_by_rule == other.is_order_by_rule && projection_rules == other.projection_rules && config_values == other.config_values && object_status == other.object_status end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/oci/data_integration/models/rule_type_config.rb', line 186 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
166 167 168 |
# File 'lib/oci/data_integration/models/rule_type_config.rb', line 166 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
175 176 177 |
# File 'lib/oci/data_integration/models/rule_type_config.rb', line 175 def hash [model_type, key, model_version, parent_ref, scope, is_order_by_rule, projection_rules, config_values, object_status].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
219 220 221 222 223 224 225 226 227 228 |
# File 'lib/oci/data_integration/models/rule_type_config.rb', line 219 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
213 214 215 |
# File 'lib/oci/data_integration/models/rule_type_config.rb', line 213 def to_s to_hash.to_s end |