Class: DataIntegration::Models::Split

Inherits:
Operator
  • Object
show all
Defined in:
lib/oci/data_integration/models/split.rb

Overview

The information about the split operator. Split operator has one input and many output links. Split operator allows users to take one data set and based on conditions produce many different outputs.

Constant Summary collapse

DATA_ROUTING_STRATEGY_ENUM =
[
  DATA_ROUTING_STRATEGY_FIRST = 'FIRST'.freeze,
  DATA_ROUTING_STRATEGY_ALL = 'ALL'.freeze,
  DATA_ROUTING_STRATEGY_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Split

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :key (String)

    The value to assign to the #key proprety

  • :model_version (String)

    The value to assign to the #model_version proprety

  • :parent_ref (OCI::DataIntegration::Models::ParentReference)

    The value to assign to the #parent_ref proprety

  • :name (String)

    The value to assign to the #name proprety

  • :description (String)

    The value to assign to the #description proprety

  • :object_version (Integer)

    The value to assign to the #object_version proprety

  • :input_ports (Array<OCI::DataIntegration::Models::InputPort>)

    The value to assign to the #input_ports proprety

  • :output_ports (Array<OCI::DataIntegration::Models::TypedObject>)

    The value to assign to the #output_ports proprety

  • :object_status (Integer)

    The value to assign to the #object_status proprety

  • :identifier (String)

    The value to assign to the #identifier proprety

  • :parameters (Array<OCI::DataIntegration::Models::Parameter>)

    The value to assign to the #parameters proprety

  • :op_config_values (OCI::DataIntegration::Models::ConfigValues)

    The value to assign to the #op_config_values proprety

  • :data_routing_strategy (String)

    The value to assign to the #data_routing_strategy property



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/oci/data_integration/models/split.rb', line 85

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['modelType'] = 'SPLIT_OPERATOR'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.data_routing_strategy = attributes[:'dataRoutingStrategy'] if attributes[:'dataRoutingStrategy']
  self.data_routing_strategy = "FIRST" if data_routing_strategy.nil? && !attributes.key?(:'dataRoutingStrategy') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :dataRoutingStrategy and :data_routing_strategy' if attributes.key?(:'dataRoutingStrategy') && attributes.key?(:'data_routing_strategy')

  self.data_routing_strategy = attributes[:'data_routing_strategy'] if attributes[:'data_routing_strategy']
  self.data_routing_strategy = "FIRST" if data_routing_strategy.nil? && !attributes.key?(:'dataRoutingStrategy') && !attributes.key?(:'data_routing_strategy') # rubocop:disable Style/StringLiterals
end

Instance Attribute Details

#data_routing_strategyString

Specify how to handle data that matches a split condition. Either data that matches the first condition should be removed from further processing by other conditions, or all matched data should be evaluated for all conditions.

Returns:

  • (String)


20
21
22
# File 'lib/oci/data_integration/models/split.rb', line 20

def data_routing_strategy
  @data_routing_strategy
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
# File 'lib/oci/data_integration/models/split.rb', line 23

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'modelType',
    'key': :'key',
    'model_version': :'modelVersion',
    'parent_ref': :'parentRef',
    'name': :'name',
    'description': :'description',
    'object_version': :'objectVersion',
    'input_ports': :'inputPorts',
    'output_ports': :'outputPorts',
    'object_status': :'objectStatus',
    'identifier': :'identifier',
    'parameters': :'parameters',
    'op_config_values': :'opConfigValues',
    'data_routing_strategy': :'dataRoutingStrategy'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/oci/data_integration/models/split.rb', line 45

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'String',
    'key': :'String',
    'model_version': :'String',
    'parent_ref': :'OCI::DataIntegration::Models::ParentReference',
    'name': :'String',
    'description': :'String',
    'object_version': :'Integer',
    'input_ports': :'Array<OCI::DataIntegration::Models::InputPort>',
    'output_ports': :'Array<OCI::DataIntegration::Models::TypedObject>',
    'object_status': :'Integer',
    'identifier': :'String',
    'parameters': :'Array<OCI::DataIntegration::Models::Parameter>',
    'op_config_values': :'OCI::DataIntegration::Models::ConfigValues',
    'data_routing_strategy': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
# File 'lib/oci/data_integration/models/split.rb', line 124

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    model_type == other.model_type &&
    key == other.key &&
    model_version == other.model_version &&
    parent_ref == other.parent_ref &&
    name == other.name &&
    description == other.description &&
    object_version == other.object_version &&
    input_ports == other.input_ports &&
    output_ports == other.output_ports &&
    object_status == other.object_status &&
    identifier == other.identifier &&
    parameters == other.parameters &&
    op_config_values == other.op_config_values &&
    data_routing_strategy == other.data_routing_strategy
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/oci/data_integration/models/split.rb', line 167

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


147
148
149
# File 'lib/oci/data_integration/models/split.rb', line 147

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



156
157
158
# File 'lib/oci/data_integration/models/split.rb', line 156

def hash
  [model_type, key, model_version, parent_ref, name, description, object_version, input_ports, output_ports, object_status, identifier, parameters, op_config_values, data_routing_strategy].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



200
201
202
203
204
205
206
207
208
209
# File 'lib/oci/data_integration/models/split.rb', line 200

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



194
195
196
# File 'lib/oci/data_integration/models/split.rb', line 194

def to_s
  to_hash.to_s
end