Class: OCI::DataIntegration::Models::StructuredType

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_integration/models/structured_type.rb

Overview

A StructuredType object represents a data type that exists in a physical data asset object such as a table column, but is more complex. For example, an Oracle database OBJECT type. It can be composed of multiple DataType objects.

Constant Summary collapse

DT_TYPE_ENUM =
[
  DT_TYPE_PRIMITIVE = 'PRIMITIVE'.freeze,
  DT_TYPE_STRUCTURED = 'STRUCTURED'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ StructuredType

Initializes the object

Options Hash (attributes):

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/oci/data_integration/models/structured_type.rb', line 63

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.schema = attributes[:'schema'] if attributes[:'schema']

  self.dt_type = attributes[:'dtType'] if attributes[:'dtType']

  raise 'You cannot provide both :dtType and :dt_type' if attributes.key?(:'dtType') && attributes.key?(:'dt_type')

  self.dt_type = attributes[:'dt_type'] if attributes[:'dt_type']

  self.type_system_name = attributes[:'typeSystemName'] if attributes[:'typeSystemName']

  raise 'You cannot provide both :typeSystemName and :type_system_name' if attributes.key?(:'typeSystemName') && attributes.key?(:'type_system_name')

  self.type_system_name = attributes[:'type_system_name'] if attributes[:'type_system_name']

  self.config_definition = attributes[:'configDefinition'] if attributes[:'configDefinition']

  raise 'You cannot provide both :configDefinition and :config_definition' if attributes.key?(:'configDefinition') && attributes.key?(:'config_definition')

  self.config_definition = attributes[:'config_definition'] if attributes[:'config_definition']
end

Instance Attribute Details

#config_definitionOCI::DataIntegration::Models::ConfigDefinition

Returns:



27
28
29
# File 'lib/oci/data_integration/models/structured_type.rb', line 27

def config_definition
  @config_definition
end

#dt_typeString

The data type.

Returns:



20
21
22
# File 'lib/oci/data_integration/models/structured_type.rb', line 20

def dt_type
  @dt_type
end

#schemaOCI::DataIntegration::Models::BaseType

Returns:



16
17
18
# File 'lib/oci/data_integration/models/structured_type.rb', line 16

def schema
  @schema
end

#type_system_nameString

The data type system name.

Returns:



24
25
26
# File 'lib/oci/data_integration/models/structured_type.rb', line 24

def type_system_name
  @type_system_name
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



30
31
32
33
34
35
36
37
38
39
# File 'lib/oci/data_integration/models/structured_type.rb', line 30

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'schema': :'schema',
    'dt_type': :'dtType',
    'type_system_name': :'typeSystemName',
    'config_definition': :'configDefinition'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



42
43
44
45
46
47
48
49
50
51
# File 'lib/oci/data_integration/models/structured_type.rb', line 42

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'schema': :'OCI::DataIntegration::Models::BaseType',
    'dt_type': :'String',
    'type_system_name': :'String',
    'config_definition': :'OCI::DataIntegration::Models::ConfigDefinition'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • the other object to be compared



105
106
107
108
109
110
111
112
113
# File 'lib/oci/data_integration/models/structured_type.rb', line 105

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    schema == other.schema &&
    dt_type == other.dt_type &&
    type_system_name == other.type_system_name &&
    config_definition == other.config_definition
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/oci/data_integration/models/structured_type.rb', line 138

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method

Parameters:

  • the other object to be compared

Returns:



118
119
120
# File 'lib/oci/data_integration/models/structured_type.rb', line 118

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • Hash code



127
128
129
# File 'lib/oci/data_integration/models/structured_type.rb', line 127

def hash
  [schema, dt_type, type_system_name, config_definition].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



171
172
173
174
175
176
177
178
179
180
# File 'lib/oci/data_integration/models/structured_type.rb', line 171

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



165
166
167
# File 'lib/oci/data_integration/models/structured_type.rb', line 165

def to_s
  to_hash.to_s
end