Class: DataIntegration::Models::Target

Inherits:
Operator
  • Object
show all
Defined in:
lib/oci/data_integration/models/target.rb

Overview

The information about the target operator. The target operator lets you specify the data entity to store the transformed data.

Constant Summary collapse

DATA_PROPERTY_ENUM =
[
  DATA_PROPERTY_TRUNCATE = 'TRUNCATE'.freeze,
  DATA_PROPERTY_MERGE = 'MERGE'.freeze,
  DATA_PROPERTY_BACKUP = 'BACKUP'.freeze,
  DATA_PROPERTY_OVERWRITE = 'OVERWRITE'.freeze,
  DATA_PROPERTY_APPEND = 'APPEND'.freeze,
  DATA_PROPERTY_IGNORE = 'IGNORE'.freeze,
  DATA_PROPERTY_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Target

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/oci/data_integration/models/target.rb', line 162

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['modelType'] = 'TARGET_OPERATOR'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.entity = attributes[:'entity'] if attributes[:'entity']

  self.is_read_access = attributes[:'isReadAccess'] unless attributes[:'isReadAccess'].nil?

  raise 'You cannot provide both :isReadAccess and :is_read_access' if attributes.key?(:'isReadAccess') && attributes.key?(:'is_read_access')

  self.is_read_access = attributes[:'is_read_access'] unless attributes[:'is_read_access'].nil?

  self.is_copy_fields = attributes[:'isCopyFields'] unless attributes[:'isCopyFields'].nil?

  raise 'You cannot provide both :isCopyFields and :is_copy_fields' if attributes.key?(:'isCopyFields') && attributes.key?(:'is_copy_fields')

  self.is_copy_fields = attributes[:'is_copy_fields'] unless attributes[:'is_copy_fields'].nil?

  self.is_predefined_shape = attributes[:'isPredefinedShape'] unless attributes[:'isPredefinedShape'].nil?

  raise 'You cannot provide both :isPredefinedShape and :is_predefined_shape' if attributes.key?(:'isPredefinedShape') && attributes.key?(:'is_predefined_shape')

  self.is_predefined_shape = attributes[:'is_predefined_shape'] unless attributes[:'is_predefined_shape'].nil?

  self.is_use_same_source_name = attributes[:'isUseSameSourceName'] unless attributes[:'isUseSameSourceName'].nil?
  self.is_use_same_source_name = true if is_use_same_source_name.nil? && !attributes.key?(:'isUseSameSourceName') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isUseSameSourceName and :is_use_same_source_name' if attributes.key?(:'isUseSameSourceName') && attributes.key?(:'is_use_same_source_name')

  self.is_use_same_source_name = attributes[:'is_use_same_source_name'] unless attributes[:'is_use_same_source_name'].nil?
  self.is_use_same_source_name = true if is_use_same_source_name.nil? && !attributes.key?(:'isUseSameSourceName') && !attributes.key?(:'is_use_same_source_name') # rubocop:disable Style/StringLiterals

  self.target_entity_name_prefix = attributes[:'targetEntityNamePrefix'] if attributes[:'targetEntityNamePrefix']
  self.target_entity_name_prefix = "null" if target_entity_name_prefix.nil? && !attributes.key?(:'targetEntityNamePrefix') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :targetEntityNamePrefix and :target_entity_name_prefix' if attributes.key?(:'targetEntityNamePrefix') && attributes.key?(:'target_entity_name_prefix')

  self.target_entity_name_prefix = attributes[:'target_entity_name_prefix'] if attributes[:'target_entity_name_prefix']
  self.target_entity_name_prefix = "null" if target_entity_name_prefix.nil? && !attributes.key?(:'targetEntityNamePrefix') && !attributes.key?(:'target_entity_name_prefix') # rubocop:disable Style/StringLiterals

  self.target_entity_name_suffix = attributes[:'targetEntityNameSuffix'] if attributes[:'targetEntityNameSuffix']
  self.target_entity_name_suffix = "null" if target_entity_name_suffix.nil? && !attributes.key?(:'targetEntityNameSuffix') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :targetEntityNameSuffix and :target_entity_name_suffix' if attributes.key?(:'targetEntityNameSuffix') && attributes.key?(:'target_entity_name_suffix')

  self.target_entity_name_suffix = attributes[:'target_entity_name_suffix'] if attributes[:'target_entity_name_suffix']
  self.target_entity_name_suffix = "null" if target_entity_name_suffix.nil? && !attributes.key?(:'targetEntityNameSuffix') && !attributes.key?(:'target_entity_name_suffix') # rubocop:disable Style/StringLiterals

  self.data_property = attributes[:'dataProperty'] if attributes[:'dataProperty']

  raise 'You cannot provide both :dataProperty and :data_property' if attributes.key?(:'dataProperty') && attributes.key?(:'data_property')

  self.data_property = attributes[:'data_property'] if attributes[:'data_property']

  self.schema_drift_config = attributes[:'schemaDriftConfig'] if attributes[:'schemaDriftConfig']

  raise 'You cannot provide both :schemaDriftConfig and :schema_drift_config' if attributes.key?(:'schemaDriftConfig') && attributes.key?(:'schema_drift_config')

  self.schema_drift_config = attributes[:'schema_drift_config'] if attributes[:'schema_drift_config']

  self.fixed_data_shape = attributes[:'fixedDataShape'] if attributes[:'fixedDataShape']

  raise 'You cannot provide both :fixedDataShape and :fixed_data_shape' if attributes.key?(:'fixedDataShape') && attributes.key?(:'fixed_data_shape')

  self.fixed_data_shape = attributes[:'fixed_data_shape'] if attributes[:'fixed_data_shape']

  self.write_operation_config = attributes[:'writeOperationConfig'] if attributes[:'writeOperationConfig']

  raise 'You cannot provide both :writeOperationConfig and :write_operation_config' if attributes.key?(:'writeOperationConfig') && attributes.key?(:'write_operation_config')

  self.write_operation_config = attributes[:'write_operation_config'] if attributes[:'write_operation_config']

  self.load_order = attributes[:'loadOrder'] if attributes[:'loadOrder']

  raise 'You cannot provide both :loadOrder and :load_order' if attributes.key?(:'loadOrder') && attributes.key?(:'load_order')

  self.load_order = attributes[:'load_order'] if attributes[:'load_order']
end

Instance Attribute Details

#data_propertyString

Specifies the data property.

Returns:

  • (String)


51
52
53
# File 'lib/oci/data_integration/models/target.rb', line 51

def data_property
  @data_property
end

#entityOCI::DataIntegration::Models::DataEntity



23
24
25
# File 'lib/oci/data_integration/models/target.rb', line 23

def entity
  @entity
end

#fixed_data_shapeOCI::DataIntegration::Models::Shape

Returns:

  • (OCI::DataIntegration::Models::Shape)


57
58
59
# File 'lib/oci/data_integration/models/target.rb', line 57

def fixed_data_shape
  @fixed_data_shape
end

#is_copy_fieldsBOOLEAN

Specifies the copy fields.

Returns:

  • (BOOLEAN)


31
32
33
# File 'lib/oci/data_integration/models/target.rb', line 31

def is_copy_fields
  @is_copy_fields
end

#is_predefined_shapeBOOLEAN

Specifies if this uses a predefined shape.

Returns:

  • (BOOLEAN)


35
36
37
# File 'lib/oci/data_integration/models/target.rb', line 35

def is_predefined_shape
  @is_predefined_shape
end

#is_read_accessBOOLEAN

Specifies the read access.

Returns:

  • (BOOLEAN)


27
28
29
# File 'lib/oci/data_integration/models/target.rb', line 27

def is_read_access
  @is_read_access
end

#is_use_same_source_nameBOOLEAN

Specifies if entity name is the same as source.

Returns:

  • (BOOLEAN)


39
40
41
# File 'lib/oci/data_integration/models/target.rb', line 39

def is_use_same_source_name
  @is_use_same_source_name
end

#load_orderInteger

A numeric loading order number for the target.

Returns:

  • (Integer)


64
65
66
# File 'lib/oci/data_integration/models/target.rb', line 64

def load_order
  @load_order
end

#schema_drift_configOCI::DataIntegration::Models::SchemaDriftConfig



54
55
56
# File 'lib/oci/data_integration/models/target.rb', line 54

def schema_drift_config
  @schema_drift_config
end

#target_entity_name_prefixString

Prefix for the entity Name.

Returns:

  • (String)


43
44
45
# File 'lib/oci/data_integration/models/target.rb', line 43

def target_entity_name_prefix
  @target_entity_name_prefix
end

#target_entity_name_suffixString

Suffix for the entity Name.

Returns:

  • (String)


47
48
49
# File 'lib/oci/data_integration/models/target.rb', line 47

def target_entity_name_suffix
  @target_entity_name_suffix
end

#write_operation_configOCI::DataIntegration::Models::WriteOperationConfig



60
61
62
# File 'lib/oci/data_integration/models/target.rb', line 60

def write_operation_config
  @write_operation_config
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/oci/data_integration/models/target.rb', line 67

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'modelType',
    'key': :'key',
    'model_version': :'modelVersion',
    'parent_ref': :'parentRef',
    'name': :'name',
    'description': :'description',
    'object_version': :'objectVersion',
    'input_ports': :'inputPorts',
    'output_ports': :'outputPorts',
    'object_status': :'objectStatus',
    'identifier': :'identifier',
    'parameters': :'parameters',
    'op_config_values': :'opConfigValues',
    'entity': :'entity',
    'is_read_access': :'isReadAccess',
    'is_copy_fields': :'isCopyFields',
    'is_predefined_shape': :'isPredefinedShape',
    'is_use_same_source_name': :'isUseSameSourceName',
    'target_entity_name_prefix': :'targetEntityNamePrefix',
    'target_entity_name_suffix': :'targetEntityNameSuffix',
    'data_property': :'dataProperty',
    'schema_drift_config': :'schemaDriftConfig',
    'fixed_data_shape': :'fixedDataShape',
    'write_operation_config': :'writeOperationConfig',
    'load_order': :'loadOrder'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/oci/data_integration/models/target.rb', line 100

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'String',
    'key': :'String',
    'model_version': :'String',
    'parent_ref': :'OCI::DataIntegration::Models::ParentReference',
    'name': :'String',
    'description': :'String',
    'object_version': :'Integer',
    'input_ports': :'Array<OCI::DataIntegration::Models::InputPort>',
    'output_ports': :'Array<OCI::DataIntegration::Models::TypedObject>',
    'object_status': :'Integer',
    'identifier': :'String',
    'parameters': :'Array<OCI::DataIntegration::Models::Parameter>',
    'op_config_values': :'OCI::DataIntegration::Models::ConfigValues',
    'entity': :'OCI::DataIntegration::Models::DataEntity',
    'is_read_access': :'BOOLEAN',
    'is_copy_fields': :'BOOLEAN',
    'is_predefined_shape': :'BOOLEAN',
    'is_use_same_source_name': :'BOOLEAN',
    'target_entity_name_prefix': :'String',
    'target_entity_name_suffix': :'String',
    'data_property': :'String',
    'schema_drift_config': :'OCI::DataIntegration::Models::SchemaDriftConfig',
    'fixed_data_shape': :'OCI::DataIntegration::Models::Shape',
    'write_operation_config': :'OCI::DataIntegration::Models::WriteOperationConfig',
    'load_order': :'Integer'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
# File 'lib/oci/data_integration/models/target.rb', line 267

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    model_type == other.model_type &&
    key == other.key &&
    model_version == other.model_version &&
    parent_ref == other.parent_ref &&
    name == other.name &&
    description == other.description &&
    object_version == other.object_version &&
    input_ports == other.input_ports &&
    output_ports == other.output_ports &&
    object_status == other.object_status &&
    identifier == other.identifier &&
    parameters == other.parameters &&
    op_config_values == other.op_config_values &&
    entity == other.entity &&
    is_read_access == other.is_read_access &&
    is_copy_fields == other.is_copy_fields &&
    is_predefined_shape == other.is_predefined_shape &&
    is_use_same_source_name == other.is_use_same_source_name &&
    target_entity_name_prefix == other.target_entity_name_prefix &&
    target_entity_name_suffix == other.target_entity_name_suffix &&
    data_property == other.data_property &&
    schema_drift_config == other.schema_drift_config &&
    fixed_data_shape == other.fixed_data_shape &&
    write_operation_config == other.write_operation_config &&
    load_order == other.load_order
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
# File 'lib/oci/data_integration/models/target.rb', line 321

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


301
302
303
# File 'lib/oci/data_integration/models/target.rb', line 301

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



310
311
312
# File 'lib/oci/data_integration/models/target.rb', line 310

def hash
  [model_type, key, model_version, parent_ref, name, description, object_version, input_ports, output_ports, object_status, identifier, parameters, op_config_values, entity, is_read_access, is_copy_fields, is_predefined_shape, is_use_same_source_name, target_entity_name_prefix, target_entity_name_suffix, data_property, schema_drift_config, fixed_data_shape, write_operation_config, load_order].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



354
355
356
357
358
359
360
361
362
363
# File 'lib/oci/data_integration/models/target.rb', line 354

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



348
349
350
# File 'lib/oci/data_integration/models/target.rb', line 348

def to_s
  to_hash.to_s
end