Class: OCI::DataIntegration::Models::TaskOperator

Inherits:
DataIntegration::Models::Operator
  • Object
show all
Defined in:
lib/oci/data_integration/models/task_operator.rb

Overview

An operator for task

Constant Summary collapse

RETRY_DELAY_UNIT_ENUM =
[
  RETRY_DELAY_UNIT_SECONDS = 'SECONDS'.freeze,
  RETRY_DELAY_UNIT_MINUTES = 'MINUTES'.freeze,
  RETRY_DELAY_UNIT_HOURS = 'HOURS'.freeze,
  RETRY_DELAY_UNIT_DAYS = 'DAYS'.freeze,
  RETRY_DELAY_UNIT_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
EXPECTED_DURATION_UNIT_ENUM =
[
  EXPECTED_DURATION_UNIT_SECONDS = 'SECONDS'.freeze,
  EXPECTED_DURATION_UNIT_MINUTES = 'MINUTES'.freeze,
  EXPECTED_DURATION_UNIT_HOURS = 'HOURS'.freeze,
  EXPECTED_DURATION_UNIT_DAYS = 'DAYS'.freeze,
  EXPECTED_DURATION_UNIT_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
TASK_TYPE_ENUM =
[
  TASK_TYPE_PIPELINE_TASK = 'PIPELINE_TASK'.freeze,
  TASK_TYPE_INTEGRATION_TASK = 'INTEGRATION_TASK'.freeze,
  TASK_TYPE_DATA_LOADER_TASK = 'DATA_LOADER_TASK'.freeze,
  TASK_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
TRIGGER_RULE_ENUM =
[
  TRIGGER_RULE_ALL_SUCCESS = 'ALL_SUCCESS'.freeze,
  TRIGGER_RULE_ALL_FAILED = 'ALL_FAILED'.freeze,
  TRIGGER_RULE_ALL_COMPLETE = 'ALL_COMPLETE'.freeze,
  TRIGGER_RULE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ TaskOperator

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/oci/data_integration/models/task_operator.rb', line 167

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['modelType'] = 'TASK_OPERATOR'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.retry_attempts = attributes[:'retryAttempts'] if attributes[:'retryAttempts']

  raise 'You cannot provide both :retryAttempts and :retry_attempts' if attributes.key?(:'retryAttempts') && attributes.key?(:'retry_attempts')

  self.retry_attempts = attributes[:'retry_attempts'] if attributes[:'retry_attempts']

  self.retry_delay_unit = attributes[:'retryDelayUnit'] if attributes[:'retryDelayUnit']

  raise 'You cannot provide both :retryDelayUnit and :retry_delay_unit' if attributes.key?(:'retryDelayUnit') && attributes.key?(:'retry_delay_unit')

  self.retry_delay_unit = attributes[:'retry_delay_unit'] if attributes[:'retry_delay_unit']

  self.retry_delay = attributes[:'retryDelay'] if attributes[:'retryDelay']

  raise 'You cannot provide both :retryDelay and :retry_delay' if attributes.key?(:'retryDelay') && attributes.key?(:'retry_delay')

  self.retry_delay = attributes[:'retry_delay'] if attributes[:'retry_delay']

  self.expected_duration = attributes[:'expectedDuration'] if attributes[:'expectedDuration']

  raise 'You cannot provide both :expectedDuration and :expected_duration' if attributes.key?(:'expectedDuration') && attributes.key?(:'expected_duration')

  self.expected_duration = attributes[:'expected_duration'] if attributes[:'expected_duration']

  self.expected_duration_unit = attributes[:'expectedDurationUnit'] if attributes[:'expectedDurationUnit']

  raise 'You cannot provide both :expectedDurationUnit and :expected_duration_unit' if attributes.key?(:'expectedDurationUnit') && attributes.key?(:'expected_duration_unit')

  self.expected_duration_unit = attributes[:'expected_duration_unit'] if attributes[:'expected_duration_unit']

  self.task_type = attributes[:'taskType'] if attributes[:'taskType']

  raise 'You cannot provide both :taskType and :task_type' if attributes.key?(:'taskType') && attributes.key?(:'task_type')

  self.task_type = attributes[:'task_type'] if attributes[:'task_type']

  self.task = attributes[:'task'] if attributes[:'task']

  self.trigger_rule = attributes[:'triggerRule'] if attributes[:'triggerRule']
  self.trigger_rule = "ALL_SUCCESS" if trigger_rule.nil? && !attributes.key?(:'triggerRule') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :triggerRule and :trigger_rule' if attributes.key?(:'triggerRule') && attributes.key?(:'trigger_rule')

  self.trigger_rule = attributes[:'trigger_rule'] if attributes[:'trigger_rule']
  self.trigger_rule = "ALL_SUCCESS" if trigger_rule.nil? && !attributes.key?(:'triggerRule') && !attributes.key?(:'trigger_rule') # rubocop:disable Style/StringLiterals

  self.config_provider_delegate = attributes[:'configProviderDelegate'] if attributes[:'configProviderDelegate']

  raise 'You cannot provide both :configProviderDelegate and :config_provider_delegate' if attributes.key?(:'configProviderDelegate') && attributes.key?(:'config_provider_delegate')

  self.config_provider_delegate = attributes[:'config_provider_delegate'] if attributes[:'config_provider_delegate']
end

Instance Attribute Details

#config_provider_delegateOCI::DataIntegration::Models::ConfigProvider



78
79
80
# File 'lib/oci/data_integration/models/task_operator.rb', line 78

def config_provider_delegate
  @config_provider_delegate
end

#expected_durationFloat

The expected duration for the task run.

Returns:

  • (Float)


56
57
58
# File 'lib/oci/data_integration/models/task_operator.rb', line 56

def expected_duration
  @expected_duration
end

#expected_duration_unitString

The expected duration unit of measure.

Returns:

  • (String)


60
61
62
# File 'lib/oci/data_integration/models/task_operator.rb', line 60

def expected_duration_unit
  @expected_duration_unit
end

#retry_attemptsInteger

The number of retry attempts.

Returns:

  • (Integer)


44
45
46
# File 'lib/oci/data_integration/models/task_operator.rb', line 44

def retry_attempts
  @retry_attempts
end

#retry_delayFloat

The retry delay, the unit for measurement is in the property retry delay unit.

Returns:

  • (Float)


52
53
54
# File 'lib/oci/data_integration/models/task_operator.rb', line 52

def retry_delay
  @retry_delay
end

#retry_delay_unitString

The unit for the retry delay.

Returns:

  • (String)


48
49
50
# File 'lib/oci/data_integration/models/task_operator.rb', line 48

def retry_delay_unit
  @retry_delay_unit
end

#taskOCI::DataIntegration::Models::Task

Returns:

  • (OCI::DataIntegration::Models::Task)


67
68
69
# File 'lib/oci/data_integration/models/task_operator.rb', line 67

def task
  @task
end

#task_typeString

The type of the task referenced in the task property.

Returns:

  • (String)


64
65
66
# File 'lib/oci/data_integration/models/task_operator.rb', line 64

def task_type
  @task_type
end

#trigger_ruleString

The merge condition. The conditions are ALL_SUCCESS - All the preceeding operators need to be successful. ALL_FAILED - All the preceeding operators should have failed. ALL_COMPLETE - All the preceeding operators should have completed. It could have executed successfully or failed.

Returns:

  • (String)


75
76
77
# File 'lib/oci/data_integration/models/task_operator.rb', line 75

def trigger_rule
  @trigger_rule
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/oci/data_integration/models/task_operator.rb', line 81

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'modelType',
    'key': :'key',
    'model_version': :'modelVersion',
    'parent_ref': :'parentRef',
    'name': :'name',
    'description': :'description',
    'object_version': :'objectVersion',
    'input_ports': :'inputPorts',
    'output_ports': :'outputPorts',
    'object_status': :'objectStatus',
    'identifier': :'identifier',
    'parameters': :'parameters',
    'op_config_values': :'opConfigValues',
    'retry_attempts': :'retryAttempts',
    'retry_delay_unit': :'retryDelayUnit',
    'retry_delay': :'retryDelay',
    'expected_duration': :'expectedDuration',
    'expected_duration_unit': :'expectedDurationUnit',
    'task_type': :'taskType',
    'task': :'task',
    'trigger_rule': :'triggerRule',
    'config_provider_delegate': :'configProviderDelegate'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/oci/data_integration/models/task_operator.rb', line 111

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'String',
    'key': :'String',
    'model_version': :'String',
    'parent_ref': :'OCI::DataIntegration::Models::ParentReference',
    'name': :'String',
    'description': :'String',
    'object_version': :'Integer',
    'input_ports': :'Array<OCI::DataIntegration::Models::InputPort>',
    'output_ports': :'Array<OCI::DataIntegration::Models::OutputPort>',
    'object_status': :'Integer',
    'identifier': :'String',
    'parameters': :'Array<OCI::DataIntegration::Models::Parameter>',
    'op_config_values': :'OCI::DataIntegration::Models::ConfigValues',
    'retry_attempts': :'Integer',
    'retry_delay_unit': :'String',
    'retry_delay': :'Float',
    'expected_duration': :'Float',
    'expected_duration_unit': :'String',
    'task_type': :'String',
    'task': :'OCI::DataIntegration::Models::Task',
    'trigger_rule': :'String',
    'config_provider_delegate': :'OCI::DataIntegration::Models::ConfigProvider'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
# File 'lib/oci/data_integration/models/task_operator.rb', line 289

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    model_type == other.model_type &&
    key == other.key &&
    model_version == other.model_version &&
    parent_ref == other.parent_ref &&
    name == other.name &&
    description == other.description &&
    object_version == other.object_version &&
    input_ports == other.input_ports &&
    output_ports == other.output_ports &&
    object_status == other.object_status &&
    identifier == other.identifier &&
    parameters == other.parameters &&
    op_config_values == other.op_config_values &&
    retry_attempts == other.retry_attempts &&
    retry_delay_unit == other.retry_delay_unit &&
    retry_delay == other.retry_delay &&
    expected_duration == other.expected_duration &&
    expected_duration_unit == other.expected_duration_unit &&
    task_type == other.task_type &&
    task == other.task &&
    trigger_rule == other.trigger_rule &&
    config_provider_delegate == other.config_provider_delegate
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
# File 'lib/oci/data_integration/models/task_operator.rb', line 340

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


320
321
322
# File 'lib/oci/data_integration/models/task_operator.rb', line 320

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



329
330
331
# File 'lib/oci/data_integration/models/task_operator.rb', line 329

def hash
  [model_type, key, model_version, parent_ref, name, description, object_version, input_ports, output_ports, object_status, identifier, parameters, op_config_values, retry_attempts, retry_delay_unit, retry_delay, expected_duration, expected_duration_unit, task_type, task, trigger_rule, config_provider_delegate].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



373
374
375
376
377
378
379
380
381
382
# File 'lib/oci/data_integration/models/task_operator.rb', line 373

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



367
368
369
# File 'lib/oci/data_integration/models/task_operator.rb', line 367

def to_s
  to_hash.to_s
end