Class: OCI::DataIntegration::Models::TaskValidation
- Inherits:
-
Object
- Object
- OCI::DataIntegration::Models::TaskValidation
- Defined in:
- lib/oci/data_integration/models/task_validation.rb
Overview
The information about task validation.
Instance Attribute Summary collapse
-
#description ⇒ String
Detailed description for the object.
-
#error_message_count ⇒ Integer
Total number of validation error messages.
-
#identifier ⇒ String
Value can only contain upper case letters, underscore, and numbers.
-
#info_message_count ⇒ Integer
Total number of validation information messages.
-
#key ⇒ String
Objects use a 36 character key as unique ID.
- #metadata ⇒ OCI::DataIntegration::Models::ObjectMetadata
-
#model_type ⇒ String
The type of the object.
-
#model_version ⇒ String
The model version of an object.
-
#name ⇒ String
Free form text without any restriction on permitted characters.
-
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
-
#object_version ⇒ Integer
The version of the object that is used to track changes in the object instance.
- #parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
-
#total_message_count ⇒ Integer
Total number of validation messages.
-
#validation_messages ⇒ Hash<String, Array<OCI::DataIntegration::Models::ValidationMessage>>
Detailed information of the data flow object validation.
-
#warn_message_count ⇒ Integer
Total number of validation warning messages.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TaskValidation
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ TaskValidation
Initializes the object
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/oci/data_integration/models/task_validation.rb', line 135 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self. = attributes[:'totalMessageCount'] if attributes[:'totalMessageCount'] raise 'You cannot provide both :totalMessageCount and :total_message_count' if attributes.key?(:'totalMessageCount') && attributes.key?(:'total_message_count') self. = attributes[:'total_message_count'] if attributes[:'total_message_count'] self. = attributes[:'errorMessageCount'] if attributes[:'errorMessageCount'] raise 'You cannot provide both :errorMessageCount and :error_message_count' if attributes.key?(:'errorMessageCount') && attributes.key?(:'error_message_count') self. = attributes[:'error_message_count'] if attributes[:'error_message_count'] self. = attributes[:'warnMessageCount'] if attributes[:'warnMessageCount'] raise 'You cannot provide both :warnMessageCount and :warn_message_count' if attributes.key?(:'warnMessageCount') && attributes.key?(:'warn_message_count') self. = attributes[:'warn_message_count'] if attributes[:'warn_message_count'] self. = attributes[:'infoMessageCount'] if attributes[:'infoMessageCount'] raise 'You cannot provide both :infoMessageCount and :info_message_count' if attributes.key?(:'infoMessageCount') && attributes.key?(:'info_message_count') self. = attributes[:'info_message_count'] if attributes[:'info_message_count'] self. = attributes[:'validationMessages'] if attributes[:'validationMessages'] raise 'You cannot provide both :validationMessages and :validation_messages' if attributes.key?(:'validationMessages') && attributes.key?(:'validation_messages') self. = attributes[:'validation_messages'] if attributes[:'validation_messages'] self.key = attributes[:'key'] if attributes[:'key'] self.model_type = attributes[:'modelType'] if attributes[:'modelType'] raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type') self.model_type = attributes[:'model_type'] if attributes[:'model_type'] self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion'] raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version') self.model_version = attributes[:'model_version'] if attributes[:'model_version'] self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef'] raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref') self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref'] self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.object_version = attributes[:'objectVersion'] if attributes[:'objectVersion'] raise 'You cannot provide both :objectVersion and :object_version' if attributes.key?(:'objectVersion') && attributes.key?(:'object_version') self.object_version = attributes[:'object_version'] if attributes[:'object_version'] self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus'] raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status') self.object_status = attributes[:'object_status'] if attributes[:'object_status'] self.identifier = attributes[:'identifier'] if attributes[:'identifier'] self. = attributes[:'metadata'] if attributes[:'metadata'] end |
Instance Attribute Details
#description ⇒ String
Detailed description for the object.
51 52 53 |
# File 'lib/oci/data_integration/models/task_validation.rb', line 51 def description @description end |
#error_message_count ⇒ Integer
Total number of validation error messages.
16 17 18 |
# File 'lib/oci/data_integration/models/task_validation.rb', line 16 def @error_message_count end |
#identifier ⇒ String
Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.
63 64 65 |
# File 'lib/oci/data_integration/models/task_validation.rb', line 63 def identifier @identifier end |
#info_message_count ⇒ Integer
Total number of validation information messages.
24 25 26 |
# File 'lib/oci/data_integration/models/task_validation.rb', line 24 def @info_message_count end |
#key ⇒ String
Objects use a 36 character key as unique ID. It is system generated and cannot be modified.
32 33 34 |
# File 'lib/oci/data_integration/models/task_validation.rb', line 32 def key @key end |
#metadata ⇒ OCI::DataIntegration::Models::ObjectMetadata
66 67 68 |
# File 'lib/oci/data_integration/models/task_validation.rb', line 66 def @metadata end |
#model_type ⇒ String
The type of the object.
36 37 38 |
# File 'lib/oci/data_integration/models/task_validation.rb', line 36 def model_type @model_type end |
#model_version ⇒ String
The model version of an object.
40 41 42 |
# File 'lib/oci/data_integration/models/task_validation.rb', line 40 def model_version @model_version end |
#name ⇒ String
Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.
47 48 49 |
# File 'lib/oci/data_integration/models/task_validation.rb', line 47 def name @name end |
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
59 60 61 |
# File 'lib/oci/data_integration/models/task_validation.rb', line 59 def object_status @object_status end |
#object_version ⇒ Integer
The version of the object that is used to track changes in the object instance.
55 56 57 |
# File 'lib/oci/data_integration/models/task_validation.rb', line 55 def object_version @object_version end |
#parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
43 44 45 |
# File 'lib/oci/data_integration/models/task_validation.rb', line 43 def parent_ref @parent_ref end |
#total_message_count ⇒ Integer
Total number of validation messages.
12 13 14 |
# File 'lib/oci/data_integration/models/task_validation.rb', line 12 def @total_message_count end |
#validation_messages ⇒ Hash<String, Array<OCI::DataIntegration::Models::ValidationMessage>>
Detailed information of the data flow object validation.
28 29 30 |
# File 'lib/oci/data_integration/models/task_validation.rb', line 28 def @validation_messages end |
#warn_message_count ⇒ Integer
Total number of validation warning messages.
20 21 22 |
# File 'lib/oci/data_integration/models/task_validation.rb', line 20 def @warn_message_count end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/oci/data_integration/models/task_validation.rb', line 69 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'total_message_count': :'totalMessageCount', 'error_message_count': :'errorMessageCount', 'warn_message_count': :'warnMessageCount', 'info_message_count': :'infoMessageCount', 'validation_messages': :'validationMessages', 'key': :'key', 'model_type': :'modelType', 'model_version': :'modelVersion', 'parent_ref': :'parentRef', 'name': :'name', 'description': :'description', 'object_version': :'objectVersion', 'object_status': :'objectStatus', 'identifier': :'identifier', 'metadata': :'metadata' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/oci/data_integration/models/task_validation.rb', line 92 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'total_message_count': :'Integer', 'error_message_count': :'Integer', 'warn_message_count': :'Integer', 'info_message_count': :'Integer', 'validation_messages': :'Hash<String, Array<OCI::DataIntegration::Models::ValidationMessage>>', 'key': :'String', 'model_type': :'String', 'model_version': :'String', 'parent_ref': :'OCI::DataIntegration::Models::ParentReference', 'name': :'String', 'description': :'String', 'object_version': :'Integer', 'object_status': :'Integer', 'identifier': :'String', 'metadata': :'OCI::DataIntegration::Models::ObjectMetadata' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/oci/data_integration/models/task_validation.rb', line 219 def ==(other) return true if equal?(other) self.class == other.class && == other. && == other. && == other. && == other. && == other. && key == other.key && model_type == other.model_type && model_version == other.model_version && parent_ref == other.parent_ref && name == other.name && description == other.description && object_version == other.object_version && object_status == other.object_status && identifier == other.identifier && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 |
# File 'lib/oci/data_integration/models/task_validation.rb', line 263 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
243 244 245 |
# File 'lib/oci/data_integration/models/task_validation.rb', line 243 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
252 253 254 |
# File 'lib/oci/data_integration/models/task_validation.rb', line 252 def hash [, , , , , key, model_type, model_version, parent_ref, name, description, object_version, object_status, identifier, ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
296 297 298 299 300 301 302 303 304 305 |
# File 'lib/oci/data_integration/models/task_validation.rb', line 296 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
290 291 292 |
# File 'lib/oci/data_integration/models/task_validation.rb', line 290 def to_s to_hash.to_s end |