Class: OCI::DataIntegration::Models::UpdateConnectionDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_integration/models/update_connection_details.rb

Overview

Properties used in connection update operations. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class

Constant Summary collapse

MODEL_TYPE_ENUM =
[
  MODEL_TYPE_ORACLE_ADWC_CONNECTION = 'ORACLE_ADWC_CONNECTION'.freeze,
  MODEL_TYPE_ORACLE_ATP_CONNECTION = 'ORACLE_ATP_CONNECTION'.freeze,
  MODEL_TYPE_ORACLE_OBJECT_STORAGE_CONNECTION = 'ORACLE_OBJECT_STORAGE_CONNECTION'.freeze,
  MODEL_TYPE_ORACLEDB_CONNECTION = 'ORACLEDB_CONNECTION'.freeze,
  MODEL_TYPE_MYSQL_CONNECTION = 'MYSQL_CONNECTION'.freeze,
  MODEL_TYPE_GENERIC_JDBC_CONNECTION = 'GENERIC_JDBC_CONNECTION'.freeze,
  MODEL_TYPE_BICC_CONNECTION = 'BICC_CONNECTION'.freeze,
  MODEL_TYPE_AMAZON_S3_CONNECTION = 'AMAZON_S3_CONNECTION'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateConnectionDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/oci/data_integration/models/update_connection_details.rb', line 141

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.model_type = attributes[:'modelType'] if attributes[:'modelType']

  raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type')

  self.model_type = attributes[:'model_type'] if attributes[:'model_type']

  self.key = attributes[:'key'] if attributes[:'key']

  self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion']

  raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version')

  self.model_version = attributes[:'model_version'] if attributes[:'model_version']

  self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef']

  raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref')

  self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref']

  self.name = attributes[:'name'] if attributes[:'name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus']

  raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status')

  self.object_status = attributes[:'object_status'] if attributes[:'object_status']

  self.object_version = attributes[:'objectVersion'] if attributes[:'objectVersion']

  raise 'You cannot provide both :objectVersion and :object_version' if attributes.key?(:'objectVersion') && attributes.key?(:'object_version')

  self.object_version = attributes[:'object_version'] if attributes[:'object_version']

  self.identifier = attributes[:'identifier'] if attributes[:'identifier']

  self.connection_properties = attributes[:'connectionProperties'] if attributes[:'connectionProperties']

  raise 'You cannot provide both :connectionProperties and :connection_properties' if attributes.key?(:'connectionProperties') && attributes.key?(:'connection_properties')

  self.connection_properties = attributes[:'connection_properties'] if attributes[:'connection_properties']

  self. = attributes[:'registryMetadata'] if attributes[:'registryMetadata']

  raise 'You cannot provide both :registryMetadata and :registry_metadata' if attributes.key?(:'registryMetadata') && attributes.key?(:'registry_metadata')

  self. = attributes[:'registry_metadata'] if attributes[:'registry_metadata']
end

Instance Attribute Details

#connection_propertiesArray<OCI::DataIntegration::Models::ConnectionProperty>

The properties for the connection.



59
60
61
# File 'lib/oci/data_integration/models/update_connection_details.rb', line 59

def connection_properties
  @connection_properties
end

#descriptionString

User-defined description for the connection.

Returns:

  • (String)


43
44
45
# File 'lib/oci/data_integration/models/update_connection_details.rb', line 43

def description
  @description
end

#identifierString

Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.

Returns:

  • (String)


55
56
57
# File 'lib/oci/data_integration/models/update_connection_details.rb', line 55

def identifier
  @identifier
end

#keyString

[Required] Generated key that can be used in API calls to identify connection. On scenarios where reference to the connection is needed, a value can be passed in create.

Returns:

  • (String)


28
29
30
# File 'lib/oci/data_integration/models/update_connection_details.rb', line 28

def key
  @key
end

#model_typeString

[Required] The type of the connection.

Returns:

  • (String)


24
25
26
# File 'lib/oci/data_integration/models/update_connection_details.rb', line 24

def model_type
  @model_type
end

#model_versionString

The model version of an object.

Returns:

  • (String)


32
33
34
# File 'lib/oci/data_integration/models/update_connection_details.rb', line 32

def model_version
  @model_version
end

#nameString

Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.

Returns:

  • (String)


39
40
41
# File 'lib/oci/data_integration/models/update_connection_details.rb', line 39

def name
  @name
end

#object_statusInteger

The status of an object that can be set to value 1 for shallow references across objects, other values reserved.

Returns:

  • (Integer)


47
48
49
# File 'lib/oci/data_integration/models/update_connection_details.rb', line 47

def object_status
  @object_status
end

#object_versionInteger

[Required] The version of the object that is used to track changes in the object instance.

Returns:

  • (Integer)


51
52
53
# File 'lib/oci/data_integration/models/update_connection_details.rb', line 51

def object_version
  @object_version
end

#parent_refOCI::DataIntegration::Models::ParentReference



35
36
37
# File 'lib/oci/data_integration/models/update_connection_details.rb', line 35

def parent_ref
  @parent_ref
end

#registry_metadataOCI::DataIntegration::Models::RegistryMetadata



62
63
64
# File 'lib/oci/data_integration/models/update_connection_details.rb', line 62

def 
  @registry_metadata
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/oci/data_integration/models/update_connection_details.rb', line 65

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'modelType',
    'key': :'key',
    'model_version': :'modelVersion',
    'parent_ref': :'parentRef',
    'name': :'name',
    'description': :'description',
    'object_status': :'objectStatus',
    'object_version': :'objectVersion',
    'identifier': :'identifier',
    'connection_properties': :'connectionProperties',
    'registry_metadata': :'registryMetadata'
    # rubocop:enable Style/SymbolLiteral
  }
end

.get_subtype(object_hash) ⇒ Object

Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/oci/data_integration/models/update_connection_details.rb', line 107

def self.get_subtype(object_hash)
  type = object_hash[:'modelType'] # rubocop:disable Style/SymbolLiteral

  return 'OCI::DataIntegration::Models::UpdateConnectionFromJdbc' if type == 'GENERIC_JDBC_CONNECTION'
  return 'OCI::DataIntegration::Models::UpdateConnectionFromObjectStorage' if type == 'ORACLE_OBJECT_STORAGE_CONNECTION'
  return 'OCI::DataIntegration::Models::UpdateConnectionFromBICC' if type == 'BICC_CONNECTION'
  return 'OCI::DataIntegration::Models::UpdateConnectionFromAmazonS3' if type == 'AMAZON_S3_CONNECTION'
  return 'OCI::DataIntegration::Models::UpdateConnectionFromAtp' if type == 'ORACLE_ATP_CONNECTION'
  return 'OCI::DataIntegration::Models::UpdateConnectionFromOracle' if type == 'ORACLEDB_CONNECTION'
  return 'OCI::DataIntegration::Models::UpdateConnectionFromAdwc' if type == 'ORACLE_ADWC_CONNECTION'
  return 'OCI::DataIntegration::Models::UpdateConnectionFromMySQL' if type == 'MYSQL_CONNECTION'

  # TODO: Log a warning when the subtype is not found.
  'OCI::DataIntegration::Models::UpdateConnectionDetails'
end

.swagger_typesObject

Attribute type mapping.



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/oci/data_integration/models/update_connection_details.rb', line 84

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'String',
    'key': :'String',
    'model_version': :'String',
    'parent_ref': :'OCI::DataIntegration::Models::ParentReference',
    'name': :'String',
    'description': :'String',
    'object_status': :'Integer',
    'object_version': :'Integer',
    'identifier': :'String',
    'connection_properties': :'Array<OCI::DataIntegration::Models::ConnectionProperty>',
    'registry_metadata': :'OCI::DataIntegration::Models::RegistryMetadata'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/oci/data_integration/models/update_connection_details.rb', line 213

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    model_type == other.model_type &&
    key == other.key &&
    model_version == other.model_version &&
    parent_ref == other.parent_ref &&
    name == other.name &&
    description == other.description &&
    object_status == other.object_status &&
    object_version == other.object_version &&
    identifier == other.identifier &&
    connection_properties == other.connection_properties &&
     == other.
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/oci/data_integration/models/update_connection_details.rb', line 253

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


233
234
235
# File 'lib/oci/data_integration/models/update_connection_details.rb', line 233

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



242
243
244
# File 'lib/oci/data_integration/models/update_connection_details.rb', line 242

def hash
  [model_type, key, model_version, parent_ref, name, description, object_status, object_version, identifier, connection_properties, ].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



286
287
288
289
290
291
292
293
294
295
# File 'lib/oci/data_integration/models/update_connection_details.rb', line 286

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



280
281
282
# File 'lib/oci/data_integration/models/update_connection_details.rb', line 280

def to_s
  to_hash.to_s
end