Class: OCI::DataIntegration::Models::UpdateDataAssetFromAtp
- Inherits:
-
UpdateDataAssetDetails
- Object
- UpdateDataAssetDetails
- OCI::DataIntegration::Models::UpdateDataAssetFromAtp
- Defined in:
- lib/oci/data_integration/models/update_data_asset_from_atp.rb
Overview
Details for the Autonomous Transaction Processing data asset type.
Constant Summary
Constants inherited from UpdateDataAssetDetails
OCI::DataIntegration::Models::UpdateDataAssetDetails::MODEL_TYPE_ENUM
Instance Attribute Summary collapse
-
#autonomous_db_id ⇒ String
Tha Autonomous Database Id.
-
#compartment_id ⇒ String
The Autonomous Data Warehouse instance compartment Id.
-
#credential_file_content ⇒ String
The credential file content from an Autonomous Transaction Processing wallet.
- #default_connection ⇒ OCI::DataIntegration::Models::UpdateConnectionFromAtp
-
#driver_class ⇒ String
The Autonomous Transaction Processing driver class.
-
#region_id ⇒ String
The Autonomous Data Warehouse instance region Id.
-
#service_name ⇒ String
The Autonomous Transaction Processing instance service name.
-
#tenancy_id ⇒ String
The Autonomous Data Warehouse instance tenancy Id.
- #wallet_password_secret ⇒ OCI::DataIntegration::Models::SensitiveAttribute
- #wallet_secret ⇒ OCI::DataIntegration::Models::SensitiveAttribute
Attributes inherited from UpdateDataAssetDetails
#asset_properties, #description, #external_key, #identifier, #key, #model_type, #model_version, #name, #object_status, #object_version, #registry_metadata
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateDataAssetFromAtp
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from UpdateDataAssetDetails
Constructor Details
#initialize(attributes = {}) ⇒ UpdateDataAssetFromAtp
Initializes the object
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/oci/data_integration/models/update_data_asset_from_atp.rb', line 132 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['modelType'] = 'ORACLE_ATP_DATA_ASSET' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.service_name = attributes[:'serviceName'] if attributes[:'serviceName'] raise 'You cannot provide both :serviceName and :service_name' if attributes.key?(:'serviceName') && attributes.key?(:'service_name') self.service_name = attributes[:'service_name'] if attributes[:'service_name'] self.driver_class = attributes[:'driverClass'] if attributes[:'driverClass'] raise 'You cannot provide both :driverClass and :driver_class' if attributes.key?(:'driverClass') && attributes.key?(:'driver_class') self.driver_class = attributes[:'driver_class'] if attributes[:'driver_class'] self.credential_file_content = attributes[:'credentialFileContent'] if attributes[:'credentialFileContent'] raise 'You cannot provide both :credentialFileContent and :credential_file_content' if attributes.key?(:'credentialFileContent') && attributes.key?(:'credential_file_content') self.credential_file_content = attributes[:'credential_file_content'] if attributes[:'credential_file_content'] self.wallet_secret = attributes[:'walletSecret'] if attributes[:'walletSecret'] raise 'You cannot provide both :walletSecret and :wallet_secret' if attributes.key?(:'walletSecret') && attributes.key?(:'wallet_secret') self.wallet_secret = attributes[:'wallet_secret'] if attributes[:'wallet_secret'] self.wallet_password_secret = attributes[:'walletPasswordSecret'] if attributes[:'walletPasswordSecret'] raise 'You cannot provide both :walletPasswordSecret and :wallet_password_secret' if attributes.key?(:'walletPasswordSecret') && attributes.key?(:'wallet_password_secret') self.wallet_password_secret = attributes[:'wallet_password_secret'] if attributes[:'wallet_password_secret'] self.region_id = attributes[:'regionId'] if attributes[:'regionId'] raise 'You cannot provide both :regionId and :region_id' if attributes.key?(:'regionId') && attributes.key?(:'region_id') self.region_id = attributes[:'region_id'] if attributes[:'region_id'] self.tenancy_id = attributes[:'tenancyId'] if attributes[:'tenancyId'] raise 'You cannot provide both :tenancyId and :tenancy_id' if attributes.key?(:'tenancyId') && attributes.key?(:'tenancy_id') self.tenancy_id = attributes[:'tenancy_id'] if attributes[:'tenancy_id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.autonomous_db_id = attributes[:'autonomousDbId'] if attributes[:'autonomousDbId'] raise 'You cannot provide both :autonomousDbId and :autonomous_db_id' if attributes.key?(:'autonomousDbId') && attributes.key?(:'autonomous_db_id') self.autonomous_db_id = attributes[:'autonomous_db_id'] if attributes[:'autonomous_db_id'] self.default_connection = attributes[:'defaultConnection'] if attributes[:'defaultConnection'] raise 'You cannot provide both :defaultConnection and :default_connection' if attributes.key?(:'defaultConnection') && attributes.key?(:'default_connection') self.default_connection = attributes[:'default_connection'] if attributes[:'default_connection'] end |
Instance Attribute Details
#autonomous_db_id ⇒ String
Tha Autonomous Database Id
43 44 45 |
# File 'lib/oci/data_integration/models/update_data_asset_from_atp.rb', line 43 def autonomous_db_id @autonomous_db_id end |
#compartment_id ⇒ String
The Autonomous Data Warehouse instance compartment Id.
39 40 41 |
# File 'lib/oci/data_integration/models/update_data_asset_from_atp.rb', line 39 def compartment_id @compartment_id end |
#credential_file_content ⇒ String
The credential file content from an Autonomous Transaction Processing wallet.
21 22 23 |
# File 'lib/oci/data_integration/models/update_data_asset_from_atp.rb', line 21 def credential_file_content @credential_file_content end |
#default_connection ⇒ OCI::DataIntegration::Models::UpdateConnectionFromAtp
46 47 48 |
# File 'lib/oci/data_integration/models/update_data_asset_from_atp.rb', line 46 def default_connection @default_connection end |
#driver_class ⇒ String
The Autonomous Transaction Processing driver class
17 18 19 |
# File 'lib/oci/data_integration/models/update_data_asset_from_atp.rb', line 17 def driver_class @driver_class end |
#region_id ⇒ String
The Autonomous Data Warehouse instance region Id.
31 32 33 |
# File 'lib/oci/data_integration/models/update_data_asset_from_atp.rb', line 31 def region_id @region_id end |
#service_name ⇒ String
The Autonomous Transaction Processing instance service name.
13 14 15 |
# File 'lib/oci/data_integration/models/update_data_asset_from_atp.rb', line 13 def service_name @service_name end |
#tenancy_id ⇒ String
The Autonomous Data Warehouse instance tenancy Id.
35 36 37 |
# File 'lib/oci/data_integration/models/update_data_asset_from_atp.rb', line 35 def tenancy_id @tenancy_id end |
#wallet_password_secret ⇒ OCI::DataIntegration::Models::SensitiveAttribute
27 28 29 |
# File 'lib/oci/data_integration/models/update_data_asset_from_atp.rb', line 27 def wallet_password_secret @wallet_password_secret end |
#wallet_secret ⇒ OCI::DataIntegration::Models::SensitiveAttribute
24 25 26 |
# File 'lib/oci/data_integration/models/update_data_asset_from_atp.rb', line 24 def wallet_secret @wallet_secret end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/oci/data_integration/models/update_data_asset_from_atp.rb', line 49 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'key': :'key', 'model_version': :'modelVersion', 'name': :'name', 'description': :'description', 'object_status': :'objectStatus', 'object_version': :'objectVersion', 'identifier': :'identifier', 'external_key': :'externalKey', 'asset_properties': :'assetProperties', 'registry_metadata': :'registryMetadata', 'service_name': :'serviceName', 'driver_class': :'driverClass', 'credential_file_content': :'credentialFileContent', 'wallet_secret': :'walletSecret', 'wallet_password_secret': :'walletPasswordSecret', 'region_id': :'regionId', 'tenancy_id': :'tenancyId', 'compartment_id': :'compartmentId', 'autonomous_db_id': :'autonomousDbId', 'default_connection': :'defaultConnection' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/oci/data_integration/models/update_data_asset_from_atp.rb', line 78 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'key': :'String', 'model_version': :'String', 'name': :'String', 'description': :'String', 'object_status': :'Integer', 'object_version': :'Integer', 'identifier': :'String', 'external_key': :'String', 'asset_properties': :'Hash<String, String>', 'registry_metadata': :'OCI::DataIntegration::Models::RegistryMetadata', 'service_name': :'String', 'driver_class': :'String', 'credential_file_content': :'String', 'wallet_secret': :'OCI::DataIntegration::Models::SensitiveAttribute', 'wallet_password_secret': :'OCI::DataIntegration::Models::SensitiveAttribute', 'region_id': :'String', 'tenancy_id': :'String', 'compartment_id': :'String', 'autonomous_db_id': :'String', 'default_connection': :'OCI::DataIntegration::Models::UpdateConnectionFromAtp' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 |
# File 'lib/oci/data_integration/models/update_data_asset_from_atp.rb', line 210 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && key == other.key && model_version == other.model_version && name == other.name && description == other.description && object_status == other.object_status && object_version == other.object_version && identifier == other.identifier && external_key == other.external_key && asset_properties == other.asset_properties && == other. && service_name == other.service_name && driver_class == other.driver_class && credential_file_content == other.credential_file_content && wallet_secret == other.wallet_secret && wallet_password_secret == other.wallet_password_secret && region_id == other.region_id && tenancy_id == other.tenancy_id && compartment_id == other.compartment_id && autonomous_db_id == other.autonomous_db_id && default_connection == other.default_connection end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/oci/data_integration/models/update_data_asset_from_atp.rb', line 260 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
240 241 242 |
# File 'lib/oci/data_integration/models/update_data_asset_from_atp.rb', line 240 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
249 250 251 |
# File 'lib/oci/data_integration/models/update_data_asset_from_atp.rb', line 249 def hash [model_type, key, model_version, name, description, object_status, object_version, identifier, external_key, asset_properties, , service_name, driver_class, credential_file_content, wallet_secret, wallet_password_secret, region_id, tenancy_id, compartment_id, autonomous_db_id, default_connection].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
293 294 295 296 297 298 299 300 301 302 |
# File 'lib/oci/data_integration/models/update_data_asset_from_atp.rb', line 293 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
287 288 289 |
# File 'lib/oci/data_integration/models/update_data_asset_from_atp.rb', line 287 def to_s to_hash.to_s end |