Class: OCI::DataIntegration::Models::UpdateFolderDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_integration/models/update_folder_details.rb

Overview

The properties used in folder update operations.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateFolderDetails

Initializes the object

Options Hash (attributes):



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/oci/data_integration/models/update_folder_details.rb', line 107

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  self.key = attributes[:'key'] if attributes[:'key']

  self.model_type = attributes[:'modelType'] if attributes[:'modelType']

  raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type')

  self.model_type = attributes[:'model_type'] if attributes[:'model_type']

  self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion']

  raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version')

  self.model_version = attributes[:'model_version'] if attributes[:'model_version']

  self.name = attributes[:'name'] if attributes[:'name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.category_name = attributes[:'categoryName'] if attributes[:'categoryName']

  raise 'You cannot provide both :categoryName and :category_name' if attributes.key?(:'categoryName') && attributes.key?(:'category_name')

  self.category_name = attributes[:'category_name'] if attributes[:'category_name']

  self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus']

  raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status')

  self.object_status = attributes[:'object_status'] if attributes[:'object_status']

  self.identifier = attributes[:'identifier'] if attributes[:'identifier']

  self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef']

  raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref')

  self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref']

  self.object_version = attributes[:'objectVersion'] if attributes[:'objectVersion']

  raise 'You cannot provide both :objectVersion and :object_version' if attributes.key?(:'objectVersion') && attributes.key?(:'object_version')

  self.object_version = attributes[:'object_version'] if attributes[:'object_version']

  self. = attributes[:'registryMetadata'] if attributes[:'registryMetadata']

  raise 'You cannot provide both :registryMetadata and :registry_metadata' if attributes.key?(:'registryMetadata') && attributes.key?(:'registry_metadata')

  self. = attributes[:'registry_metadata'] if attributes[:'registry_metadata']
end

Instance Attribute Details

#category_nameString

The category name.



32
33
34
# File 'lib/oci/data_integration/models/update_folder_details.rb', line 32

def category_name
  @category_name
end

#descriptionString

A user defined description for the folder.



28
29
30
# File 'lib/oci/data_integration/models/update_folder_details.rb', line 28

def description
  @description
end

#identifierString

Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.



40
41
42
# File 'lib/oci/data_integration/models/update_folder_details.rb', line 40

def identifier
  @identifier
end

#keyString

[Required] Generated key that can be used in API calls to identify folder.



12
13
14
# File 'lib/oci/data_integration/models/update_folder_details.rb', line 12

def key
  @key
end

#model_typeString

[Required] The type of the object.



16
17
18
# File 'lib/oci/data_integration/models/update_folder_details.rb', line 16

def model_type
  @model_type
end

#model_versionString

The model version of an object.



20
21
22
# File 'lib/oci/data_integration/models/update_folder_details.rb', line 20

def model_version
  @model_version
end

#nameString

Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.



24
25
26
# File 'lib/oci/data_integration/models/update_folder_details.rb', line 24

def name
  @name
end

#object_statusInteger

The status of an object that can be set to value 1 for shallow references across objects, other values reserved.



36
37
38
# File 'lib/oci/data_integration/models/update_folder_details.rb', line 36

def object_status
  @object_status
end

#object_versionInteger

[Required] The version of the object that is used to track changes in the object instance.



47
48
49
# File 'lib/oci/data_integration/models/update_folder_details.rb', line 47

def object_version
  @object_version
end

#parent_refOCI::DataIntegration::Models::ParentReference



43
44
45
# File 'lib/oci/data_integration/models/update_folder_details.rb', line 43

def parent_ref
  @parent_ref
end

#registry_metadataOCI::DataIntegration::Models::RegistryMetadata



50
51
52
# File 'lib/oci/data_integration/models/update_folder_details.rb', line 50

def 
  
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/oci/data_integration/models/update_folder_details.rb', line 53

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'key',
    'model_type': :'modelType',
    'model_version': :'modelVersion',
    'name': :'name',
    'description': :'description',
    'category_name': :'categoryName',
    'object_status': :'objectStatus',
    'identifier': :'identifier',
    'parent_ref': :'parentRef',
    'object_version': :'objectVersion',
    'registry_metadata': :'registryMetadata'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/oci/data_integration/models/update_folder_details.rb', line 72

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'String',
    'model_type': :'String',
    'model_version': :'String',
    'name': :'String',
    'description': :'String',
    'category_name': :'String',
    'object_status': :'Integer',
    'identifier': :'String',
    'parent_ref': :'OCI::DataIntegration::Models::ParentReference',
    'object_version': :'Integer',
    'registry_metadata': :'OCI::DataIntegration::Models::RegistryMetadata'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/oci/data_integration/models/update_folder_details.rb', line 168

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    key == other.key &&
    model_type == other.model_type &&
    model_version == other.model_version &&
    name == other.name &&
    description == other.description &&
    category_name == other.category_name &&
    object_status == other.object_status &&
    identifier == other.identifier &&
    parent_ref == other.parent_ref &&
    object_version == other.object_version &&
     == other.
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/oci/data_integration/models/update_folder_details.rb', line 208

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method


188
189
190
# File 'lib/oci/data_integration/models/update_folder_details.rb', line 188

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.



197
198
199
# File 'lib/oci/data_integration/models/update_folder_details.rb', line 197

def hash
  [key, model_type, model_version, name, description, category_name, object_status, identifier, parent_ref, object_version, ].hash
end

#to_hashHash

Returns the object in the form of hash



241
242
243
244
245
246
247
248
249
250
# File 'lib/oci/data_integration/models/update_folder_details.rb', line 241

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



235
236
237
# File 'lib/oci/data_integration/models/update_folder_details.rb', line 235

def to_s
  to_hash.to_s
end