Class: OCI::DataIntegration::Models::UpdateFunctionLibraryDetails
- Inherits:
-
Object
- Object
- OCI::DataIntegration::Models::UpdateFunctionLibraryDetails
- Defined in:
- lib/oci/data_integration/models/update_function_library_details.rb
Overview
The properties used in FunctionLibrary update operations.
Instance Attribute Summary collapse
-
#category_name ⇒ String
The category name.
-
#description ⇒ String
A user defined description for the FunctionLibrary.
-
#identifier ⇒ String
Value can only contain upper case letters, underscore, and numbers.
-
#model_version ⇒ String
The model version of an object.
-
#name ⇒ String
Free form text without any restriction on permitted characters.
-
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
-
#object_version ⇒ Integer
The version of the object that is used to track changes in the object instance.
- #registry_metadata ⇒ OCI::DataIntegration::Models::RegistryMetadata
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateFunctionLibraryDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateFunctionLibraryDetails
Initializes the object
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/oci/data_integration/models/update_function_library_details.rb', line 87 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.category_name = attributes[:'categoryName'] if attributes[:'categoryName'] raise 'You cannot provide both :categoryName and :category_name' if attributes.key?(:'categoryName') && attributes.key?(:'category_name') self.category_name = attributes[:'category_name'] if attributes[:'category_name'] self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus'] raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status') self.object_status = attributes[:'object_status'] if attributes[:'object_status'] self.identifier = attributes[:'identifier'] if attributes[:'identifier'] self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion'] raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version') self.model_version = attributes[:'model_version'] if attributes[:'model_version'] self.object_version = attributes[:'objectVersion'] if attributes[:'objectVersion'] raise 'You cannot provide both :objectVersion and :object_version' if attributes.key?(:'objectVersion') && attributes.key?(:'object_version') self.object_version = attributes[:'object_version'] if attributes[:'object_version'] self. = attributes[:'registryMetadata'] if attributes[:'registryMetadata'] raise 'You cannot provide both :registryMetadata and :registry_metadata' if attributes.key?(:'registryMetadata') && attributes.key?(:'registry_metadata') self. = attributes[:'registry_metadata'] if attributes[:'registry_metadata'] end |
Instance Attribute Details
#category_name ⇒ String
The category name.
20 21 22 |
# File 'lib/oci/data_integration/models/update_function_library_details.rb', line 20 def category_name @category_name end |
#description ⇒ String
A user defined description for the FunctionLibrary.
16 17 18 |
# File 'lib/oci/data_integration/models/update_function_library_details.rb', line 16 def description @description end |
#identifier ⇒ String
Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.
28 29 30 |
# File 'lib/oci/data_integration/models/update_function_library_details.rb', line 28 def identifier @identifier end |
#model_version ⇒ String
The model version of an object.
32 33 34 |
# File 'lib/oci/data_integration/models/update_function_library_details.rb', line 32 def model_version @model_version end |
#name ⇒ String
Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.
12 13 14 |
# File 'lib/oci/data_integration/models/update_function_library_details.rb', line 12 def name @name end |
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
24 25 26 |
# File 'lib/oci/data_integration/models/update_function_library_details.rb', line 24 def object_status @object_status end |
#object_version ⇒ Integer
The version of the object that is used to track changes in the object instance.
36 37 38 |
# File 'lib/oci/data_integration/models/update_function_library_details.rb', line 36 def object_version @object_version end |
#registry_metadata ⇒ OCI::DataIntegration::Models::RegistryMetadata
39 40 41 |
# File 'lib/oci/data_integration/models/update_function_library_details.rb', line 39 def end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
42 43 44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/oci/data_integration/models/update_function_library_details.rb', line 42 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'description': :'description', 'category_name': :'categoryName', 'object_status': :'objectStatus', 'identifier': :'identifier', 'model_version': :'modelVersion', 'object_version': :'objectVersion', 'registry_metadata': :'registryMetadata' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/oci/data_integration/models/update_function_library_details.rb', line 58 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'description': :'String', 'category_name': :'String', 'object_status': :'Integer', 'identifier': :'String', 'model_version': :'String', 'object_version': :'Integer', 'registry_metadata': :'OCI::DataIntegration::Models::RegistryMetadata' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/oci/data_integration/models/update_function_library_details.rb', line 137 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && description == other.description && category_name == other.category_name && object_status == other.object_status && identifier == other.identifier && model_version == other.model_version && object_version == other.object_version && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/oci/data_integration/models/update_function_library_details.rb', line 174 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
154 155 156 |
# File 'lib/oci/data_integration/models/update_function_library_details.rb', line 154 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
163 164 165 |
# File 'lib/oci/data_integration/models/update_function_library_details.rb', line 163 def hash [name, description, category_name, object_status, identifier, model_version, object_version, ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
207 208 209 210 211 212 213 214 215 216 |
# File 'lib/oci/data_integration/models/update_function_library_details.rb', line 207 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
201 202 203 |
# File 'lib/oci/data_integration/models/update_function_library_details.rb', line 201 def to_s to_hash.to_s end |