Class: OCI::DataIntegration::Models::UpdateTaskFromDataLoaderTask

Inherits:
UpdateTaskDetails
  • Object
show all
Defined in:
lib/oci/data_integration/models/update_task_from_data_loader_task.rb

Overview

The information about the data loader task.

Constant Summary

Constants inherited from UpdateTaskDetails

OCI::DataIntegration::Models::UpdateTaskDetails::MODEL_TYPE_ENUM

Instance Attribute Summary collapse

Attributes inherited from UpdateTaskDetails

#config_provider_delegate, #description, #identifier, #input_ports, #key, #model_type, #model_version, #name, #object_status, #object_version, #op_config_values, #output_ports, #parameters, #parent_ref, #registry_metadata

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from UpdateTaskDetails

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ UpdateTaskFromDataLoaderTask

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/oci/data_integration/models/update_task_from_data_loader_task.rb', line 103

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['modelType'] = 'DATA_LOADER_TASK'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.data_flow = attributes[:'dataFlow'] if attributes[:'dataFlow']

  raise 'You cannot provide both :dataFlow and :data_flow' if attributes.key?(:'dataFlow') && attributes.key?(:'data_flow')

  self.data_flow = attributes[:'data_flow'] if attributes[:'data_flow']

  self.conditional_composite_field_map = attributes[:'conditionalCompositeFieldMap'] if attributes[:'conditionalCompositeFieldMap']

  raise 'You cannot provide both :conditionalCompositeFieldMap and :conditional_composite_field_map' if attributes.key?(:'conditionalCompositeFieldMap') && attributes.key?(:'conditional_composite_field_map')

  self.conditional_composite_field_map = attributes[:'conditional_composite_field_map'] if attributes[:'conditional_composite_field_map']

  self.is_single_load = attributes[:'isSingleLoad'] unless attributes[:'isSingleLoad'].nil?
  self.is_single_load = false if is_single_load.nil? && !attributes.key?(:'isSingleLoad') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isSingleLoad and :is_single_load' if attributes.key?(:'isSingleLoad') && attributes.key?(:'is_single_load')

  self.is_single_load = attributes[:'is_single_load'] unless attributes[:'is_single_load'].nil?
  self.is_single_load = false if is_single_load.nil? && !attributes.key?(:'isSingleLoad') && !attributes.key?(:'is_single_load') # rubocop:disable Style/StringLiterals

  self.parallel_load_limit = attributes[:'parallelLoadLimit'] if attributes[:'parallelLoadLimit']

  raise 'You cannot provide both :parallelLoadLimit and :parallel_load_limit' if attributes.key?(:'parallelLoadLimit') && attributes.key?(:'parallel_load_limit')

  self.parallel_load_limit = attributes[:'parallel_load_limit'] if attributes[:'parallel_load_limit']
end

Instance Attribute Details

#conditional_composite_field_mapOCI::DataIntegration::Models::ConditionalCompositeFieldMap



15
16
17
# File 'lib/oci/data_integration/models/update_task_from_data_loader_task.rb', line 15

def conditional_composite_field_map
  @conditional_composite_field_map
end

#data_flowOCI::DataIntegration::Models::DataFlow



12
13
14
# File 'lib/oci/data_integration/models/update_task_from_data_loader_task.rb', line 12

def data_flow
  @data_flow
end

#is_single_loadBOOLEAN

Defines whether Data Loader task is used for single load or multiple

Returns:

  • (BOOLEAN)


19
20
21
# File 'lib/oci/data_integration/models/update_task_from_data_loader_task.rb', line 19

def is_single_load
  @is_single_load
end

#parallel_load_limitInteger

Defines the number of entities being loaded in parallel at a time for a Data Loader task

Returns:

  • (Integer)


23
24
25
# File 'lib/oci/data_integration/models/update_task_from_data_loader_task.rb', line 23

def parallel_load_limit
  @parallel_load_limit
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
# File 'lib/oci/data_integration/models/update_task_from_data_loader_task.rb', line 26

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'modelType',
    'key': :'key',
    'model_version': :'modelVersion',
    'parent_ref': :'parentRef',
    'name': :'name',
    'description': :'description',
    'object_status': :'objectStatus',
    'object_version': :'objectVersion',
    'identifier': :'identifier',
    'input_ports': :'inputPorts',
    'output_ports': :'outputPorts',
    'parameters': :'parameters',
    'op_config_values': :'opConfigValues',
    'config_provider_delegate': :'configProviderDelegate',
    'registry_metadata': :'registryMetadata',
    'data_flow': :'dataFlow',
    'conditional_composite_field_map': :'conditionalCompositeFieldMap',
    'is_single_load': :'isSingleLoad',
    'parallel_load_limit': :'parallelLoadLimit'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/oci/data_integration/models/update_task_from_data_loader_task.rb', line 53

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'String',
    'key': :'String',
    'model_version': :'String',
    'parent_ref': :'OCI::DataIntegration::Models::ParentReference',
    'name': :'String',
    'description': :'String',
    'object_status': :'Integer',
    'object_version': :'Integer',
    'identifier': :'String',
    'input_ports': :'Array<OCI::DataIntegration::Models::InputPort>',
    'output_ports': :'Array<OCI::DataIntegration::Models::OutputPort>',
    'parameters': :'Array<OCI::DataIntegration::Models::Parameter>',
    'op_config_values': :'OCI::DataIntegration::Models::ConfigValues',
    'config_provider_delegate': :'OCI::DataIntegration::Models::ConfigProvider',
    'registry_metadata': :'OCI::DataIntegration::Models::RegistryMetadata',
    'data_flow': :'OCI::DataIntegration::Models::DataFlow',
    'conditional_composite_field_map': :'OCI::DataIntegration::Models::ConditionalCompositeFieldMap',
    'is_single_load': :'BOOLEAN',
    'parallel_load_limit': :'Integer'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/oci/data_integration/models/update_task_from_data_loader_task.rb', line 147

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    model_type == other.model_type &&
    key == other.key &&
    model_version == other.model_version &&
    parent_ref == other.parent_ref &&
    name == other.name &&
    description == other.description &&
    object_status == other.object_status &&
    object_version == other.object_version &&
    identifier == other.identifier &&
    input_ports == other.input_ports &&
    output_ports == other.output_ports &&
    parameters == other.parameters &&
    op_config_values == other.op_config_values &&
    config_provider_delegate == other.config_provider_delegate &&
     == other. &&
    data_flow == other.data_flow &&
    conditional_composite_field_map == other.conditional_composite_field_map &&
    is_single_load == other.is_single_load &&
    parallel_load_limit == other.parallel_load_limit
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/oci/data_integration/models/update_task_from_data_loader_task.rb', line 195

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


175
176
177
# File 'lib/oci/data_integration/models/update_task_from_data_loader_task.rb', line 175

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



184
185
186
# File 'lib/oci/data_integration/models/update_task_from_data_loader_task.rb', line 184

def hash
  [model_type, key, model_version, parent_ref, name, description, object_status, object_version, identifier, input_ports, output_ports, parameters, op_config_values, config_provider_delegate, , data_flow, conditional_composite_field_map, is_single_load, parallel_load_limit].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



228
229
230
231
232
233
234
235
236
237
# File 'lib/oci/data_integration/models/update_task_from_data_loader_task.rb', line 228

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



222
223
224
# File 'lib/oci/data_integration/models/update_task_from_data_loader_task.rb', line 222

def to_s
  to_hash.to_s
end