Class: OCI::DataIntegration::Models::UpdateTaskFromSQLTask

Inherits:
UpdateTaskDetails show all
Defined in:
lib/oci/data_integration/models/update_task_from_sql_task.rb

Overview

The information about the SQL task.

Constant Summary collapse

SQL_SCRIPT_TYPE_ENUM =
[
  SQL_SCRIPT_TYPE_STORED_PROCEDURE = 'STORED_PROCEDURE'.freeze,
  SQL_SCRIPT_TYPE_SQL_CODE = 'SQL_CODE'.freeze
].freeze

Constants inherited from UpdateTaskDetails

OCI::DataIntegration::Models::UpdateTaskDetails::MODEL_TYPE_ENUM

Instance Attribute Summary collapse

Attributes inherited from UpdateTaskDetails

#config_provider_delegate, #description, #identifier, #input_ports, #key, #model_type, #model_version, #name, #object_status, #object_version, #op_config_values, #output_ports, #parameters, #parent_ref, #registry_metadata

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from UpdateTaskDetails

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ UpdateTaskFromSQLTask

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/oci/data_integration/models/update_task_from_sql_task.rb', line 102

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['modelType'] = 'SQL_TASK'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.script = attributes[:'script'] if attributes[:'script']

  self.sql_script_type = attributes[:'sqlScriptType'] if attributes[:'sqlScriptType']

  raise 'You cannot provide both :sqlScriptType and :sql_script_type' if attributes.key?(:'sqlScriptType') && attributes.key?(:'sql_script_type')

  self.sql_script_type = attributes[:'sql_script_type'] if attributes[:'sql_script_type']

  self.operation = attributes[:'operation'] if attributes[:'operation']
end

Instance Attribute Details

#operationObject

Describes the shape of the execution result

Returns:

  • (Object)


25
26
27
# File 'lib/oci/data_integration/models/update_task_from_sql_task.rb', line 25

def operation
  @operation
end

#scriptOCI::DataIntegration::Models::Script

Returns:

  • (OCI::DataIntegration::Models::Script)


17
18
19
# File 'lib/oci/data_integration/models/update_task_from_sql_task.rb', line 17

def script
  @script
end

#sql_script_typeString

Indicates whether the task is invoking a custom SQL script or stored procedure.

Returns:

  • (String)


21
22
23
# File 'lib/oci/data_integration/models/update_task_from_sql_task.rb', line 21

def sql_script_type
  @sql_script_type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
# File 'lib/oci/data_integration/models/update_task_from_sql_task.rb', line 28

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'modelType',
    'key': :'key',
    'model_version': :'modelVersion',
    'parent_ref': :'parentRef',
    'name': :'name',
    'description': :'description',
    'object_status': :'objectStatus',
    'object_version': :'objectVersion',
    'identifier': :'identifier',
    'input_ports': :'inputPorts',
    'output_ports': :'outputPorts',
    'parameters': :'parameters',
    'op_config_values': :'opConfigValues',
    'config_provider_delegate': :'configProviderDelegate',
    'registry_metadata': :'registryMetadata',
    'script': :'script',
    'sql_script_type': :'sqlScriptType',
    'operation': :'operation'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/oci/data_integration/models/update_task_from_sql_task.rb', line 54

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'String',
    'key': :'String',
    'model_version': :'String',
    'parent_ref': :'OCI::DataIntegration::Models::ParentReference',
    'name': :'String',
    'description': :'String',
    'object_status': :'Integer',
    'object_version': :'Integer',
    'identifier': :'String',
    'input_ports': :'Array<OCI::DataIntegration::Models::InputPort>',
    'output_ports': :'Array<OCI::DataIntegration::Models::OutputPort>',
    'parameters': :'Array<OCI::DataIntegration::Models::Parameter>',
    'op_config_values': :'OCI::DataIntegration::Models::ConfigValues',
    'config_provider_delegate': :'OCI::DataIntegration::Models::ConfigProvider',
    'registry_metadata': :'OCI::DataIntegration::Models::RegistryMetadata',
    'script': :'OCI::DataIntegration::Models::Script',
    'sql_script_type': :'String',
    'operation': :'Object'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/oci/data_integration/models/update_task_from_sql_task.rb', line 138

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    model_type == other.model_type &&
    key == other.key &&
    model_version == other.model_version &&
    parent_ref == other.parent_ref &&
    name == other.name &&
    description == other.description &&
    object_status == other.object_status &&
    object_version == other.object_version &&
    identifier == other.identifier &&
    input_ports == other.input_ports &&
    output_ports == other.output_ports &&
    parameters == other.parameters &&
    op_config_values == other.op_config_values &&
    config_provider_delegate == other.config_provider_delegate &&
     == other. &&
    script == other.script &&
    sql_script_type == other.sql_script_type &&
    operation == other.operation
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/oci/data_integration/models/update_task_from_sql_task.rb', line 185

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


165
166
167
# File 'lib/oci/data_integration/models/update_task_from_sql_task.rb', line 165

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



174
175
176
# File 'lib/oci/data_integration/models/update_task_from_sql_task.rb', line 174

def hash
  [model_type, key, model_version, parent_ref, name, description, object_status, object_version, identifier, input_ports, output_ports, parameters, op_config_values, config_provider_delegate, , script, sql_script_type, operation].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



218
219
220
221
222
223
224
225
226
227
# File 'lib/oci/data_integration/models/update_task_from_sql_task.rb', line 218

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



212
213
214
# File 'lib/oci/data_integration/models/update_task_from_sql_task.rb', line 212

def to_s
  to_hash.to_s
end