Class: OCI::DataIntegration::Models::UpdateUserDefinedFunctionDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_integration/models/update_user_defined_function_details.rb

Overview

Properties used in user defined function update operations.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateUserDefinedFunctionDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/oci/data_integration/models/update_user_defined_function_details.rb', line 99

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef']

  raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref')

  self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref']

  self.name = attributes[:'name'] if attributes[:'name']

  self.identifier = attributes[:'identifier'] if attributes[:'identifier']

  self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion']

  raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version')

  self.model_version = attributes[:'model_version'] if attributes[:'model_version']

  self.object_version = attributes[:'objectVersion'] if attributes[:'objectVersion']

  raise 'You cannot provide both :objectVersion and :object_version' if attributes.key?(:'objectVersion') && attributes.key?(:'object_version')

  self.object_version = attributes[:'object_version'] if attributes[:'object_version']

  self.signatures = attributes[:'signatures'] if attributes[:'signatures']

  self.expr = attributes[:'expr'] if attributes[:'expr']

  self.description = attributes[:'description'] if attributes[:'description']

  self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus']

  raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status')

  self.object_status = attributes[:'object_status'] if attributes[:'object_status']

  self. = attributes[:'registryMetadata'] if attributes[:'registryMetadata']

  raise 'You cannot provide both :registryMetadata and :registry_metadata' if attributes.key?(:'registryMetadata') && attributes.key?(:'registry_metadata')

  self. = attributes[:'registry_metadata'] if attributes[:'registry_metadata']
end

Instance Attribute Details

#descriptionString

Detailed description for the object.

Returns:

  • (String)


38
39
40
# File 'lib/oci/data_integration/models/update_user_defined_function_details.rb', line 38

def description
  @description
end

#exprOCI::DataIntegration::Models::Expression



34
35
36
# File 'lib/oci/data_integration/models/update_user_defined_function_details.rb', line 34

def expr
  @expr
end

#identifierString

Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.

Returns:

  • (String)


19
20
21
# File 'lib/oci/data_integration/models/update_user_defined_function_details.rb', line 19

def identifier
  @identifier
end

#model_versionString

The model version of an object.

Returns:

  • (String)


23
24
25
# File 'lib/oci/data_integration/models/update_user_defined_function_details.rb', line 23

def model_version
  @model_version
end

#nameString

Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.

Returns:

  • (String)


15
16
17
# File 'lib/oci/data_integration/models/update_user_defined_function_details.rb', line 15

def name
  @name
end

#object_statusInteger

The status of an object that can be set to value 1 for shallow references across objects, other values reserved.

Returns:

  • (Integer)


42
43
44
# File 'lib/oci/data_integration/models/update_user_defined_function_details.rb', line 42

def object_status
  @object_status
end

#object_versionInteger

The version of the object that is used to track changes in the object instance.

Returns:

  • (Integer)


27
28
29
# File 'lib/oci/data_integration/models/update_user_defined_function_details.rb', line 27

def object_version
  @object_version
end

#parent_refOCI::DataIntegration::Models::ParentReference



11
12
13
# File 'lib/oci/data_integration/models/update_user_defined_function_details.rb', line 11

def parent_ref
  @parent_ref
end

#registry_metadataOCI::DataIntegration::Models::RegistryMetadata



45
46
47
# File 'lib/oci/data_integration/models/update_user_defined_function_details.rb', line 45

def 
  
end

#signaturesArray<OCI::DataIntegration::Models::FunctionSignature>

An array of function signature.



31
32
33
# File 'lib/oci/data_integration/models/update_user_defined_function_details.rb', line 31

def signatures
  @signatures
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/oci/data_integration/models/update_user_defined_function_details.rb', line 48

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'parent_ref': :'parentRef',
    'name': :'name',
    'identifier': :'identifier',
    'model_version': :'modelVersion',
    'object_version': :'objectVersion',
    'signatures': :'signatures',
    'expr': :'expr',
    'description': :'description',
    'object_status': :'objectStatus',
    'registry_metadata': :'registryMetadata'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/oci/data_integration/models/update_user_defined_function_details.rb', line 66

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'parent_ref': :'OCI::DataIntegration::Models::ParentReference',
    'name': :'String',
    'identifier': :'String',
    'model_version': :'String',
    'object_version': :'Integer',
    'signatures': :'Array<OCI::DataIntegration::Models::FunctionSignature>',
    'expr': :'OCI::DataIntegration::Models::Expression',
    'description': :'String',
    'object_status': :'Integer',
    'registry_metadata': :'OCI::DataIntegration::Models::RegistryMetadata'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/oci/data_integration/models/update_user_defined_function_details.rb', line 153

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    parent_ref == other.parent_ref &&
    name == other.name &&
    identifier == other.identifier &&
    model_version == other.model_version &&
    object_version == other.object_version &&
    signatures == other.signatures &&
    expr == other.expr &&
    description == other.description &&
    object_status == other.object_status &&
     == other.
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/oci/data_integration/models/update_user_defined_function_details.rb', line 192

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


172
173
174
# File 'lib/oci/data_integration/models/update_user_defined_function_details.rb', line 172

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



181
182
183
# File 'lib/oci/data_integration/models/update_user_defined_function_details.rb', line 181

def hash
  [parent_ref, name, identifier, model_version, object_version, signatures, expr, description, object_status, ].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



225
226
227
228
229
230
231
232
233
234
# File 'lib/oci/data_integration/models/update_user_defined_function_details.rb', line 225

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



219
220
221
# File 'lib/oci/data_integration/models/update_user_defined_function_details.rb', line 219

def to_s
  to_hash.to_s
end