Class: OCI::DataIntegration::Models::UpdateWorkspaceDetails
- Inherits:
-
Object
- Object
- OCI::DataIntegration::Models::UpdateWorkspaceDetails
- Defined in:
- lib/oci/data_integration/models/update_workspace_details.rb
Overview
The information to be updated, the private network can be enabled and VCN and subnet set only when initially it is has been created with it off.
Instance Attribute Summary collapse
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
A user defined description for the workspace.
-
#display_name ⇒ String
A user-friendly display name for the workspace.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateWorkspaceDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateWorkspaceDetails
Initializes the object
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/oci/data_integration/models/update_workspace_details.rb', line 64 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.description = attributes[:'description'] if attributes[:'description'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] end |
Instance Attribute Details
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"CostCenter": "42"}`
20 21 22 |
# File 'lib/oci/data_integration/models/update_workspace_details.rb', line 20 def end |
#description ⇒ String
A user defined description for the workspace.
24 25 26 |
# File 'lib/oci/data_integration/models/update_workspace_details.rb', line 24 def description @description end |
#display_name ⇒ String
A user-friendly display name for the workspace. Does not have to be unique, and can be modified. Avoid entering confidential information.
28 29 30 |
# File 'lib/oci/data_integration/models/update_workspace_details.rb', line 28 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"Finance"`
14 15 16 |
# File 'lib/oci/data_integration/models/update_workspace_details.rb', line 14 def end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 40 |
# File 'lib/oci/data_integration/models/update_workspace_details.rb', line 31 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'description': :'description', 'display_name': :'displayName' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
43 44 45 46 47 48 49 50 51 52 |
# File 'lib/oci/data_integration/models/update_workspace_details.rb', line 43 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'description': :'String', 'display_name': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
98 99 100 101 102 103 104 105 106 |
# File 'lib/oci/data_integration/models/update_workspace_details.rb', line 98 def ==(other) return true if equal?(other) self.class == other.class && == other. && == other. && description == other.description && display_name == other.display_name end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/oci/data_integration/models/update_workspace_details.rb', line 131 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
111 112 113 |
# File 'lib/oci/data_integration/models/update_workspace_details.rb', line 111 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
120 121 122 |
# File 'lib/oci/data_integration/models/update_workspace_details.rb', line 120 def hash [, , description, display_name].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
164 165 166 167 168 169 170 171 172 173 |
# File 'lib/oci/data_integration/models/update_workspace_details.rb', line 164 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
158 159 160 |
# File 'lib/oci/data_integration/models/update_workspace_details.rb', line 158 def to_s to_hash.to_s end |