Class: DataIntegration::Models::Variable

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_integration/models/variable.rb

Overview

Variable definitions in the pipeline.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Variable

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/oci/data_integration/models/variable.rb', line 119

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.key = attributes[:'key'] if attributes[:'key']

  self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion']

  raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version')

  self.model_version = attributes[:'model_version'] if attributes[:'model_version']

  self.model_type = attributes[:'modelType'] if attributes[:'modelType']

  raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type')

  self.model_type = attributes[:'model_type'] if attributes[:'model_type']

  self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef']

  raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref')

  self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref']

  self.name = attributes[:'name'] if attributes[:'name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.object_version = attributes[:'objectVersion'] if attributes[:'objectVersion']

  raise 'You cannot provide both :objectVersion and :object_version' if attributes.key?(:'objectVersion') && attributes.key?(:'object_version')

  self.object_version = attributes[:'object_version'] if attributes[:'object_version']

  self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus']

  raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status')

  self.object_status = attributes[:'object_status'] if attributes[:'object_status']

  self.identifier = attributes[:'identifier'] if attributes[:'identifier']

  self.type = attributes[:'type'] if attributes[:'type']

  self.config_values = attributes[:'configValues'] if attributes[:'configValues']

  raise 'You cannot provide both :configValues and :config_values' if attributes.key?(:'configValues') && attributes.key?(:'config_values')

  self.config_values = attributes[:'config_values'] if attributes[:'config_values']

  self.default_value = attributes[:'defaultValue'] if attributes[:'defaultValue']

  raise 'You cannot provide both :defaultValue and :default_value' if attributes.key?(:'defaultValue') && attributes.key?(:'default_value')

  self.default_value = attributes[:'default_value'] if attributes[:'default_value']

  self.root_object_default_value = attributes[:'rootObjectDefaultValue'] if attributes[:'rootObjectDefaultValue']

  raise 'You cannot provide both :rootObjectDefaultValue and :root_object_default_value' if attributes.key?(:'rootObjectDefaultValue') && attributes.key?(:'root_object_default_value')

  self.root_object_default_value = attributes[:'root_object_default_value'] if attributes[:'root_object_default_value']
end

Instance Attribute Details

#config_valuesOCI::DataIntegration::Models::ConfigValues



49
50
51
# File 'lib/oci/data_integration/models/variable.rb', line 49

def config_values
  @config_values
end

#default_valueObject

A default value for the vairable.

Returns:

  • (Object)


53
54
55
# File 'lib/oci/data_integration/models/variable.rb', line 53

def default_value
  @default_value
end

#descriptionString

Detailed description for the object.

Returns:

  • (String)


31
32
33
# File 'lib/oci/data_integration/models/variable.rb', line 31

def description
  @description
end

#identifierString

Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.

Returns:

  • (String)


43
44
45
# File 'lib/oci/data_integration/models/variable.rb', line 43

def identifier
  @identifier
end

#keyString

Generated key that can be used in API calls to identify variable. On scenarios where reference to the variable is needed, a value can be passed in create.

Returns:

  • (String)


12
13
14
# File 'lib/oci/data_integration/models/variable.rb', line 12

def key
  @key
end

#model_typeString

The type of the object.

Returns:

  • (String)


20
21
22
# File 'lib/oci/data_integration/models/variable.rb', line 20

def model_type
  @model_type
end

#model_versionString

This is a version number that is used by the service to upgrade objects if needed through releases of the service.

Returns:

  • (String)


16
17
18
# File 'lib/oci/data_integration/models/variable.rb', line 16

def model_version
  @model_version
end

#nameString

Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.

Returns:

  • (String)


27
28
29
# File 'lib/oci/data_integration/models/variable.rb', line 27

def name
  @name
end

#object_statusInteger

The status of an object that can be set to value 1 for shallow references across objects, other values reserved.

Returns:

  • (Integer)


39
40
41
# File 'lib/oci/data_integration/models/variable.rb', line 39

def object_status
  @object_status
end

#object_versionInteger

This is used by the service for optimistic locking of the object, to prevent multiple users from simultaneously updating the object.

Returns:

  • (Integer)


35
36
37
# File 'lib/oci/data_integration/models/variable.rb', line 35

def object_version
  @object_version
end

#parent_refOCI::DataIntegration::Models::ParentReference



23
24
25
# File 'lib/oci/data_integration/models/variable.rb', line 23

def parent_ref
  @parent_ref
end

#root_object_default_valueOCI::DataIntegration::Models::RootObject



56
57
58
# File 'lib/oci/data_integration/models/variable.rb', line 56

def root_object_default_value
  @root_object_default_value
end

#typeOCI::DataIntegration::Models::BaseType



46
47
48
# File 'lib/oci/data_integration/models/variable.rb', line 46

def type
  @type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/oci/data_integration/models/variable.rb', line 59

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'key',
    'model_version': :'modelVersion',
    'model_type': :'modelType',
    'parent_ref': :'parentRef',
    'name': :'name',
    'description': :'description',
    'object_version': :'objectVersion',
    'object_status': :'objectStatus',
    'identifier': :'identifier',
    'type': :'type',
    'config_values': :'configValues',
    'default_value': :'defaultValue',
    'root_object_default_value': :'rootObjectDefaultValue'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/oci/data_integration/models/variable.rb', line 80

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'String',
    'model_version': :'String',
    'model_type': :'String',
    'parent_ref': :'OCI::DataIntegration::Models::ParentReference',
    'name': :'String',
    'description': :'String',
    'object_version': :'Integer',
    'object_status': :'Integer',
    'identifier': :'String',
    'type': :'OCI::DataIntegration::Models::BaseType',
    'config_values': :'OCI::DataIntegration::Models::ConfigValues',
    'default_value': :'Object',
    'root_object_default_value': :'OCI::DataIntegration::Models::RootObject'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/oci/data_integration/models/variable.rb', line 191

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    key == other.key &&
    model_version == other.model_version &&
    model_type == other.model_type &&
    parent_ref == other.parent_ref &&
    name == other.name &&
    description == other.description &&
    object_version == other.object_version &&
    object_status == other.object_status &&
    identifier == other.identifier &&
    type == other.type &&
    config_values == other.config_values &&
    default_value == other.default_value &&
    root_object_default_value == other.root_object_default_value
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/oci/data_integration/models/variable.rb', line 233

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


213
214
215
# File 'lib/oci/data_integration/models/variable.rb', line 213

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



222
223
224
# File 'lib/oci/data_integration/models/variable.rb', line 222

def hash
  [key, model_version, model_type, parent_ref, name, description, object_version, object_status, identifier, type, config_values, default_value, root_object_default_value].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



266
267
268
269
270
271
272
273
274
275
# File 'lib/oci/data_integration/models/variable.rb', line 266

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



260
261
262
# File 'lib/oci/data_integration/models/variable.rb', line 260

def to_s
  to_hash.to_s
end