Class: OCI::DataIntegration::Models::Workspace
- Inherits:
-
Object
- Object
- OCI::DataIntegration::Models::Workspace
- Defined in:
- lib/oci/data_integration/models/workspace.rb
Overview
A workspace is an organizational construct to keep multiple data integration solutions and their resources (data assets, data flows, tasks, and so on) separate from each other, helping you to stay organized. For example, you could have separate workspaces for development, testing, and production.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_STARTING = 'STARTING'.freeze, LIFECYCLE_STATE_STOPPING = 'STOPPING'.freeze, LIFECYCLE_STATE_STOPPED = 'STOPPED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
The OCID of the compartment containing the workspace.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
A detailed description for the workspace.
-
#display_name ⇒ String
[Required] A user-friendly display name for the workspace.
-
#dns_server_ip ⇒ String
The IP of the custom DNS.
-
#dns_server_zone ⇒ String
The DNS zone of the custom DNS to use to resolve names.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] A system-generated and immutable identifier assigned to the workspace upon creation.
-
#is_private_network_enabled ⇒ BOOLEAN
Specifies whether the private network connection is enabled or disabled.
-
#lifecycle_state ⇒ String
Lifecycle states for workspaces in Data Integration Service CREATING - The resource is being created and may not be usable until the entire metadata is defined UPDATING - The resource is being updated and may not be usable until all changes are commited DELETING - The resource is being deleted and might require deep cleanup of children.
-
#state_message ⇒ String
A message describing the current state in more detail.
-
#subnet_id ⇒ String
The OCID of the subnet for customer connected databases.
-
#time_created ⇒ DateTime
The date and time the workspace was created, in the timestamp format defined by RFC3339.
-
#time_updated ⇒ DateTime
The date and time the workspace was updated, in the timestamp format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#vcn_id ⇒ String
The OCID of the VCN the subnet is in.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Workspace
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Workspace
Initializes the object
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/oci/data_integration/models/workspace.rb', line 169 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.vcn_id = attributes[:'vcnId'] if attributes[:'vcnId'] raise 'You cannot provide both :vcnId and :vcn_id' if attributes.key?(:'vcnId') && attributes.key?(:'vcn_id') self.vcn_id = attributes[:'vcn_id'] if attributes[:'vcn_id'] self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId'] raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id') self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id'] self.dns_server_ip = attributes[:'dnsServerIp'] if attributes[:'dnsServerIp'] raise 'You cannot provide both :dnsServerIp and :dns_server_ip' if attributes.key?(:'dnsServerIp') && attributes.key?(:'dns_server_ip') self.dns_server_ip = attributes[:'dns_server_ip'] if attributes[:'dns_server_ip'] self.dns_server_zone = attributes[:'dnsServerZone'] if attributes[:'dnsServerZone'] raise 'You cannot provide both :dnsServerZone and :dns_server_zone' if attributes.key?(:'dnsServerZone') && attributes.key?(:'dns_server_zone') self.dns_server_zone = attributes[:'dns_server_zone'] if attributes[:'dns_server_zone'] self.is_private_network_enabled = attributes[:'isPrivateNetworkEnabled'] unless attributes[:'isPrivateNetworkEnabled'].nil? raise 'You cannot provide both :isPrivateNetworkEnabled and :is_private_network_enabled' if attributes.key?(:'isPrivateNetworkEnabled') && attributes.key?(:'is_private_network_enabled') self.is_private_network_enabled = attributes[:'is_private_network_enabled'] unless attributes[:'is_private_network_enabled'].nil? self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.description = attributes[:'description'] if attributes[:'description'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self. = attributes[:'stateMessage'] if attributes[:'stateMessage'] raise 'You cannot provide both :stateMessage and :state_message' if attributes.key?(:'stateMessage') && attributes.key?(:'state_message') self. = attributes[:'state_message'] if attributes[:'state_message'] self.id = attributes[:'id'] if attributes[:'id'] end |
Instance Attribute Details
#compartment_id ⇒ String
The OCID of the compartment containing the workspace.
67 68 69 |
# File 'lib/oci/data_integration/models/workspace.rb', line 67 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"CostCenter": "42"}`
55 56 57 |
# File 'lib/oci/data_integration/models/workspace.rb', line 55 def end |
#description ⇒ String
A detailed description for the workspace.
59 60 61 |
# File 'lib/oci/data_integration/models/workspace.rb', line 59 def description @description end |
#display_name ⇒ String
[Required] A user-friendly display name for the workspace. Does not have to be unique, and can be modified. Avoid entering confidential information.
63 64 65 |
# File 'lib/oci/data_integration/models/workspace.rb', line 63 def display_name @display_name end |
#dns_server_ip ⇒ String
The IP of the custom DNS.
35 36 37 |
# File 'lib/oci/data_integration/models/workspace.rb', line 35 def dns_server_ip @dns_server_ip end |
#dns_server_zone ⇒ String
The DNS zone of the custom DNS to use to resolve names.
39 40 41 |
# File 'lib/oci/data_integration/models/workspace.rb', line 39 def dns_server_zone @dns_server_zone end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"Finance"`
49 50 51 |
# File 'lib/oci/data_integration/models/workspace.rb', line 49 def end |
#id ⇒ String
[Required] A system-generated and immutable identifier assigned to the workspace upon creation.
100 101 102 |
# File 'lib/oci/data_integration/models/workspace.rb', line 100 def id @id end |
#is_private_network_enabled ⇒ BOOLEAN
Specifies whether the private network connection is enabled or disabled.
43 44 45 |
# File 'lib/oci/data_integration/models/workspace.rb', line 43 def is_private_network_enabled @is_private_network_enabled end |
#lifecycle_state ⇒ String
Lifecycle states for workspaces in Data Integration Service CREATING - The resource is being created and may not be usable until the entire metadata is defined UPDATING - The resource is being updated and may not be usable until all changes are commited DELETING - The resource is being deleted and might require deep cleanup of children. ACTIVE - The resource is valid and available for access INACTIVE - The resource might be incomplete in its definition or might have been made unavailable for
administrative reasons
DELETED - The resource has been deleted and isn’t available FAILED - The resource is in a failed state due to validation or other errors STARTING - The resource is being started and may not be usable until becomes ACTIVE again STOPPING - The resource is in the process of Stopping and may not be usable until it Stops or fails STOPPED - The resource is in Stopped state due to stop operation.
92 93 94 |
# File 'lib/oci/data_integration/models/workspace.rb', line 92 def lifecycle_state @lifecycle_state end |
#state_message ⇒ String
A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in failed state.
96 97 98 |
# File 'lib/oci/data_integration/models/workspace.rb', line 96 def end |
#subnet_id ⇒ String
The OCID of the subnet for customer connected databases.
31 32 33 |
# File 'lib/oci/data_integration/models/workspace.rb', line 31 def subnet_id @subnet_id end |
#time_created ⇒ DateTime
The date and time the workspace was created, in the timestamp format defined by RFC3339.
72 73 74 |
# File 'lib/oci/data_integration/models/workspace.rb', line 72 def time_created @time_created end |
#time_updated ⇒ DateTime
The date and time the workspace was updated, in the timestamp format defined by [RFC3339](tools.ietf.org/html/rfc3339).
76 77 78 |
# File 'lib/oci/data_integration/models/workspace.rb', line 76 def time_updated @time_updated end |
#vcn_id ⇒ String
The OCID of the VCN the subnet is in.
27 28 29 |
# File 'lib/oci/data_integration/models/workspace.rb', line 27 def vcn_id @vcn_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/oci/data_integration/models/workspace.rb', line 103 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'vcn_id': :'vcnId', 'subnet_id': :'subnetId', 'dns_server_ip': :'dnsServerIp', 'dns_server_zone': :'dnsServerZone', 'is_private_network_enabled': :'isPrivateNetworkEnabled', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'description': :'description', 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'state_message': :'stateMessage', 'id': :'id' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/oci/data_integration/models/workspace.rb', line 126 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'vcn_id': :'String', 'subnet_id': :'String', 'dns_server_ip': :'String', 'dns_server_zone': :'String', 'is_private_network_enabled': :'BOOLEAN', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'description': :'String', 'display_name': :'String', 'compartment_id': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'state_message': :'String', 'id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/oci/data_integration/models/workspace.rb', line 278 def ==(other) return true if equal?(other) self.class == other.class && vcn_id == other.vcn_id && subnet_id == other.subnet_id && dns_server_ip == other.dns_server_ip && dns_server_zone == other.dns_server_zone && is_private_network_enabled == other.is_private_network_enabled && == other. && == other. && description == other.description && display_name == other.display_name && compartment_id == other.compartment_id && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && == other. && id == other.id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 |
# File 'lib/oci/data_integration/models/workspace.rb', line 322 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
302 303 304 |
# File 'lib/oci/data_integration/models/workspace.rb', line 302 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
311 312 313 |
# File 'lib/oci/data_integration/models/workspace.rb', line 311 def hash [vcn_id, subnet_id, dns_server_ip, dns_server_zone, is_private_network_enabled, , , description, display_name, compartment_id, time_created, time_updated, lifecycle_state, , id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
355 356 357 358 359 360 361 362 363 364 |
# File 'lib/oci/data_integration/models/workspace.rb', line 355 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
349 350 351 |
# File 'lib/oci/data_integration/models/workspace.rb', line 349 def to_s to_hash.to_s end |