Class: OCI::DataIntegration::Models::WriteOperationConfig

Inherits:
AbstractDataOperationConfig show all
Defined in:
lib/oci/data_integration/models/write_operation_config.rb

Overview

The information about the write operation.

Constant Summary collapse

WRITE_MODE_ENUM =
[
  WRITE_MODE_OVERWRITE = 'OVERWRITE'.freeze,
  WRITE_MODE_APPEND = 'APPEND'.freeze,
  WRITE_MODE_MERGE = 'MERGE'.freeze,
  WRITE_MODE_IGNORE = 'IGNORE'.freeze,
  WRITE_MODE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Constants inherited from AbstractDataOperationConfig

AbstractDataOperationConfig::MODEL_TYPE_ENUM

Instance Attribute Summary collapse

Attributes inherited from AbstractDataOperationConfig

#call_attribute, #derived_attributes, #metadata_config_properties, #model_type

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from AbstractDataOperationConfig

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ WriteOperationConfig

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/oci/data_integration/models/write_operation_config.rb', line 118

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['modelType'] = 'WRITE_OPERATION_CONFIG'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.key = attributes[:'key'] if attributes[:'key']

  self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion']

  raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version')

  self.model_version = attributes[:'model_version'] if attributes[:'model_version']

  self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef']

  raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref')

  self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref']

  self.operations = attributes[:'operations'] if attributes[:'operations']

  self.data_format = attributes[:'dataFormat'] if attributes[:'dataFormat']

  raise 'You cannot provide both :dataFormat and :data_format' if attributes.key?(:'dataFormat') && attributes.key?(:'data_format')

  self.data_format = attributes[:'data_format'] if attributes[:'data_format']

  self.partition_config = attributes[:'partitionConfig'] if attributes[:'partitionConfig']

  raise 'You cannot provide both :partitionConfig and :partition_config' if attributes.key?(:'partitionConfig') && attributes.key?(:'partition_config')

  self.partition_config = attributes[:'partition_config'] if attributes[:'partition_config']

  self.write_attribute = attributes[:'writeAttribute'] if attributes[:'writeAttribute']

  raise 'You cannot provide both :writeAttribute and :write_attribute' if attributes.key?(:'writeAttribute') && attributes.key?(:'write_attribute')

  self.write_attribute = attributes[:'write_attribute'] if attributes[:'write_attribute']

  self.write_mode = attributes[:'writeMode'] if attributes[:'writeMode']

  raise 'You cannot provide both :writeMode and :write_mode' if attributes.key?(:'writeMode') && attributes.key?(:'write_mode')

  self.write_mode = attributes[:'write_mode'] if attributes[:'write_mode']

  self.merge_key = attributes[:'mergeKey'] if attributes[:'mergeKey']

  raise 'You cannot provide both :mergeKey and :merge_key' if attributes.key?(:'mergeKey') && attributes.key?(:'merge_key')

  self.merge_key = attributes[:'merge_key'] if attributes[:'merge_key']

  self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus']

  raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status')

  self.object_status = attributes[:'object_status'] if attributes[:'object_status']
end

Instance Attribute Details

#data_formatOCI::DataIntegration::Models::DataFormat



36
37
38
# File 'lib/oci/data_integration/models/write_operation_config.rb', line 36

def data_format
  @data_format
end

#keyString

The object key.

Returns:

  • (String)


22
23
24
# File 'lib/oci/data_integration/models/write_operation_config.rb', line 22

def key
  @key
end

#merge_keyOCI::DataIntegration::Models::UniqueKey



49
50
51
# File 'lib/oci/data_integration/models/write_operation_config.rb', line 49

def merge_key
  @merge_key
end

#model_versionString

The object's model version.

Returns:

  • (String)


26
27
28
# File 'lib/oci/data_integration/models/write_operation_config.rb', line 26

def model_version
  @model_version
end

#object_statusInteger

The status of an object that can be set to value 1 for shallow references across objects, other values reserved.

Returns:

  • (Integer)


53
54
55
# File 'lib/oci/data_integration/models/write_operation_config.rb', line 53

def object_status
  @object_status
end

#operationsArray<OCI::DataIntegration::Models::PushDownOperation>

An array of operations.



33
34
35
# File 'lib/oci/data_integration/models/write_operation_config.rb', line 33

def operations
  @operations
end

#parent_refOCI::DataIntegration::Models::ParentReference



29
30
31
# File 'lib/oci/data_integration/models/write_operation_config.rb', line 29

def parent_ref
  @parent_ref
end

#partition_configOCI::DataIntegration::Models::PartitionConfig



39
40
41
# File 'lib/oci/data_integration/models/write_operation_config.rb', line 39

def partition_config
  @partition_config
end

#write_attributeOCI::DataIntegration::Models::AbstractWriteAttribute



42
43
44
# File 'lib/oci/data_integration/models/write_operation_config.rb', line 42

def write_attribute
  @write_attribute
end

#write_modeString

The mode for the write operation.

Returns:

  • (String)


46
47
48
# File 'lib/oci/data_integration/models/write_operation_config.rb', line 46

def write_mode
  @write_mode
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/oci/data_integration/models/write_operation_config.rb', line 56

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'modelType',
    'metadata_config_properties': :'metadataConfigProperties',
    'derived_attributes': :'derivedAttributes',
    'call_attribute': :'callAttribute',
    'key': :'key',
    'model_version': :'modelVersion',
    'parent_ref': :'parentRef',
    'operations': :'operations',
    'data_format': :'dataFormat',
    'partition_config': :'partitionConfig',
    'write_attribute': :'writeAttribute',
    'write_mode': :'writeMode',
    'merge_key': :'mergeKey',
    'object_status': :'objectStatus'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/oci/data_integration/models/write_operation_config.rb', line 78

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'String',
    'metadata_config_properties': :'Hash<String, String>',
    'derived_attributes': :'Hash<String, String>',
    'call_attribute': :'OCI::DataIntegration::Models::BipCallAttribute',
    'key': :'String',
    'model_version': :'String',
    'parent_ref': :'OCI::DataIntegration::Models::ParentReference',
    'operations': :'Array<OCI::DataIntegration::Models::PushDownOperation>',
    'data_format': :'OCI::DataIntegration::Models::DataFormat',
    'partition_config': :'OCI::DataIntegration::Models::PartitionConfig',
    'write_attribute': :'OCI::DataIntegration::Models::AbstractWriteAttribute',
    'write_mode': :'String',
    'merge_key': :'OCI::DataIntegration::Models::UniqueKey',
    'object_status': :'Integer'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/oci/data_integration/models/write_operation_config.rb', line 201

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    model_type == other.model_type &&
     == other. &&
    derived_attributes == other.derived_attributes &&
    call_attribute == other.call_attribute &&
    key == other.key &&
    model_version == other.model_version &&
    parent_ref == other.parent_ref &&
    operations == other.operations &&
    data_format == other.data_format &&
    partition_config == other.partition_config &&
    write_attribute == other.write_attribute &&
    write_mode == other.write_mode &&
    merge_key == other.merge_key &&
    object_status == other.object_status
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
# File 'lib/oci/data_integration/models/write_operation_config.rb', line 244

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


224
225
226
# File 'lib/oci/data_integration/models/write_operation_config.rb', line 224

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



233
234
235
# File 'lib/oci/data_integration/models/write_operation_config.rb', line 233

def hash
  [model_type, , derived_attributes, call_attribute, key, model_version, parent_ref, operations, data_format, partition_config, write_attribute, write_mode, merge_key, object_status].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



277
278
279
280
281
282
283
284
285
286
# File 'lib/oci/data_integration/models/write_operation_config.rb', line 277

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



271
272
273
# File 'lib/oci/data_integration/models/write_operation_config.rb', line 271

def to_s
  to_hash.to_s
end