Class: OCI::DataLabelingService::Models::DatasetFormatDetails
- Inherits:
-
Object
- Object
- OCI::DataLabelingService::Models::DatasetFormatDetails
- Defined in:
- lib/oci/data_labeling_service/models/dataset_format_details.rb
Overview
Specifies how to process the data. Supported formats include DOCUMENT, IMAGE and TEXT. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
DocumentDatasetFormatDetails, ImageDatasetFormatDetails, TextDatasetFormatDetails
Constant Summary collapse
- FORMAT_TYPE_ENUM =
[ FORMAT_TYPE_DOCUMENT = 'DOCUMENT'.freeze, FORMAT_TYPE_IMAGE = 'IMAGE'.freeze, FORMAT_TYPE_TEXT = 'TEXT'.freeze, FORMAT_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#format_type ⇒ String
[Required] Format type.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DatasetFormatDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DatasetFormatDetails
Initializes the object
65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/oci/data_labeling_service/models/dataset_format_details.rb', line 65 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.format_type = attributes[:'formatType'] if attributes[:'formatType'] raise 'You cannot provide both :formatType and :format_type' if attributes.key?(:'formatType') && attributes.key?(:'format_type') self.format_type = attributes[:'format_type'] if attributes[:'format_type'] end |
Instance Attribute Details
#format_type ⇒ String
[Required] Format type. DOCUMENT format is for record contents that are PDFs or TIFFs. IMAGE format is for record contents that are JPEGs or PNGs. TEXT format is for record contents that are txt files.
21 22 23 |
# File 'lib/oci/data_labeling_service/models/dataset_format_details.rb', line 21 def format_type @format_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
24 25 26 27 28 29 30 |
# File 'lib/oci/data_labeling_service/models/dataset_format_details.rb', line 24 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'format_type': :'formatType' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
46 47 48 49 50 51 52 53 54 55 |
# File 'lib/oci/data_labeling_service/models/dataset_format_details.rb', line 46 def self.get_subtype(object_hash) type = object_hash[:'formatType'] # rubocop:disable Style/SymbolLiteral return 'OCI::DataLabelingService::Models::ImageDatasetFormatDetails' if type == 'IMAGE' return 'OCI::DataLabelingService::Models::DocumentDatasetFormatDetails' if type == 'DOCUMENT' return 'OCI::DataLabelingService::Models::TextDatasetFormatDetails' if type == 'TEXT' # TODO: Log a warning when the subtype is not found. 'OCI::DataLabelingService::Models::DatasetFormatDetails' end |
.swagger_types ⇒ Object
Attribute type mapping.
33 34 35 36 37 38 39 |
# File 'lib/oci/data_labeling_service/models/dataset_format_details.rb', line 33 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'format_type': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
98 99 100 101 102 103 |
# File 'lib/oci/data_labeling_service/models/dataset_format_details.rb', line 98 def ==(other) return true if equal?(other) self.class == other.class && format_type == other.format_type end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/oci/data_labeling_service/models/dataset_format_details.rb', line 128 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
108 109 110 |
# File 'lib/oci/data_labeling_service/models/dataset_format_details.rb', line 108 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
117 118 119 |
# File 'lib/oci/data_labeling_service/models/dataset_format_details.rb', line 117 def hash [format_type].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
161 162 163 164 165 166 167 168 169 170 |
# File 'lib/oci/data_labeling_service/models/dataset_format_details.rb', line 161 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
155 156 157 |
# File 'lib/oci/data_labeling_service/models/dataset_format_details.rb', line 155 def to_s to_hash.to_s end |