Class: OCI::DataLabelingService::Models::DatasetSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_labeling_service/models/dataset_summary.rb

Overview

A dataset summary is the representation returned in list views. It is usually a subset of the full dataset entity and should not contain any potentially sensitive information.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DatasetSummary

Initializes the object

Options Hash (attributes):



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/oci/data_labeling_service/models/dataset_summary.rb', line 122

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.annotation_format = attributes[:'annotationFormat'] if attributes[:'annotationFormat']

  raise 'You cannot provide both :annotationFormat and :annotation_format' if attributes.key?(:'annotationFormat') && attributes.key?(:'annotation_format')

  self.annotation_format = attributes[:'annotation_format'] if attributes[:'annotation_format']

  self.dataset_format_details = attributes[:'datasetFormatDetails'] if attributes[:'datasetFormatDetails']

  raise 'You cannot provide both :datasetFormatDetails and :dataset_format_details' if attributes.key?(:'datasetFormatDetails') && attributes.key?(:'dataset_format_details')

  self.dataset_format_details = attributes[:'dataset_format_details'] if attributes[:'dataset_format_details']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

  raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

  self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']
end

Instance Attribute Details

#annotation_formatString

[Required] The annotation format name required for labeling records.



40
41
42
# File 'lib/oci/data_labeling_service/models/dataset_summary.rb', line 40

def annotation_format
  @annotation_format
end

#compartment_idString

[Required] Compartment Identifier



20
21
22
# File 'lib/oci/data_labeling_service/models/dataset_summary.rb', line 20

def compartment_id
  @compartment_id
end

#dataset_format_detailsOCI::DataLabelingService::Models::DatasetFormatDetails

This attribute is required.



44
45
46
# File 'lib/oci/data_labeling_service/models/dataset_summary.rb', line 44

def dataset_format_details
  @dataset_format_details
end

#defined_tagsHash<String, Hash<String, Object>>

The defined tags for this resource. Each key is predefined and scoped to a namespace. For example: ‘{"bar-key": "value"}`



56
57
58
# File 'lib/oci/data_labeling_service/models/dataset_summary.rb', line 56

def defined_tags
  @defined_tags
end

#display_nameString

A user-friendly display name for the resource.



16
17
18
# File 'lib/oci/data_labeling_service/models/dataset_summary.rb', line 16

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

A simple key-value pair that is applied without any predefined name, type, or scope. It exists for cross-compatibility only. For example: ‘"value"`



50
51
52
# File 'lib/oci/data_labeling_service/models/dataset_summary.rb', line 50

def freeform_tags
  @freeform_tags
end

#idString

[Required] The OCID of the Dataset



12
13
14
# File 'lib/oci/data_labeling_service/models/dataset_summary.rb', line 12

def id
  @id
end

#lifecycle_detailsString

A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.



36
37
38
# File 'lib/oci/data_labeling_service/models/dataset_summary.rb', line 36

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

[Required] The state of a Dataset.



32
33
34
# File 'lib/oci/data_labeling_service/models/dataset_summary.rb', line 32

def lifecycle_state
  @lifecycle_state
end

#system_tagsHash<String, Hash<String, Object>>

The usage of system tag keys. These predefined keys are scoped to namespaces. For example: ‘{"free-tier-retained": "true"}`



62
63
64
# File 'lib/oci/data_labeling_service/models/dataset_summary.rb', line 62

def system_tags
  @system_tags
end

#time_createdDateTime

[Required] The time the the Dataset was created. An RFC3339 formatted datetime string



24
25
26
# File 'lib/oci/data_labeling_service/models/dataset_summary.rb', line 24

def time_created
  @time_created
end

#time_updatedDateTime

[Required] The date and time the resource was last updated, in the timestamp format defined by RFC3339.



28
29
30
# File 'lib/oci/data_labeling_service/models/dataset_summary.rb', line 28

def time_updated
  @time_updated
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/oci/data_labeling_service/models/dataset_summary.rb', line 65

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'display_name': :'displayName',
    'compartment_id': :'compartmentId',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'annotation_format': :'annotationFormat',
    'dataset_format_details': :'datasetFormatDetails',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/oci/data_labeling_service/models/dataset_summary.rb', line 85

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'display_name': :'String',
    'compartment_id': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'annotation_format': :'String',
    'dataset_format_details': :'OCI::DataLabelingService::Models::DatasetFormatDetails',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.



204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/oci/data_labeling_service/models/dataset_summary.rb', line 204

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    display_name == other.display_name &&
    compartment_id == other.compartment_id &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    annotation_format == other.annotation_format &&
    dataset_format_details == other.dataset_format_details &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
# File 'lib/oci/data_labeling_service/models/dataset_summary.rb', line 245

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method


225
226
227
# File 'lib/oci/data_labeling_service/models/dataset_summary.rb', line 225

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.



234
235
236
# File 'lib/oci/data_labeling_service/models/dataset_summary.rb', line 234

def hash
  [id, display_name, compartment_id, time_created, time_updated, lifecycle_state, lifecycle_details, annotation_format, dataset_format_details, freeform_tags, defined_tags, system_tags].hash
end

#to_hashHash

Returns the object in the form of hash



278
279
280
281
282
283
284
285
286
287
# File 'lib/oci/data_labeling_service/models/dataset_summary.rb', line 278

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



272
273
274
# File 'lib/oci/data_labeling_service/models/dataset_summary.rb', line 272

def to_s
  to_hash.to_s
end