Class: OCI::DataLabelingService::Models::DocumentDatasetFormatDetails

Inherits:
DatasetFormatDetails show all
Defined in:
lib/oci/data_labeling_service/models/document_dataset_format_details.rb

Overview

Allows the user to specify that the dataset is comprised of document files (e.g. PDFs, DOCs, etc.). It is open for further configurability.

Constant Summary

Constants inherited from DatasetFormatDetails

OCI::DataLabelingService::Models::DatasetFormatDetails::FORMAT_TYPE_ENUM

Instance Attribute Summary

Attributes inherited from DatasetFormatDetails

#format_type

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from DatasetFormatDetails

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ DocumentDatasetFormatDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



35
36
37
38
39
40
41
# File 'lib/oci/data_labeling_service/models/document_dataset_format_details.rb', line 35

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['formatType'] = 'DOCUMENT'

  super(attributes)
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



12
13
14
15
16
17
18
# File 'lib/oci/data_labeling_service/models/document_dataset_format_details.rb', line 12

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'format_type': :'formatType'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



21
22
23
24
25
26
27
# File 'lib/oci/data_labeling_service/models/document_dataset_format_details.rb', line 21

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'format_type': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



50
51
52
53
54
55
# File 'lib/oci/data_labeling_service/models/document_dataset_format_details.rb', line 50

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    format_type == other.format_type
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/oci/data_labeling_service/models/document_dataset_format_details.rb', line 80

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


60
61
62
# File 'lib/oci/data_labeling_service/models/document_dataset_format_details.rb', line 60

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



69
70
71
# File 'lib/oci/data_labeling_service/models/document_dataset_format_details.rb', line 69

def hash
  [format_type].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



113
114
115
116
117
118
119
120
121
122
# File 'lib/oci/data_labeling_service/models/document_dataset_format_details.rb', line 113

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



107
108
109
# File 'lib/oci/data_labeling_service/models/document_dataset_format_details.rb', line 107

def to_s
  to_hash.to_s
end