Class: OCI::DataLabelingService::Models::RenameDatasetLabelsDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_labeling_service/models/rename_dataset_labels_details.rb

Overview

Renames a subset of Labels in the Dataset’s LabelSet. The Labels in the source LabelSet will be replaced with the Labels in the target LabelSet. Labels are correlated by index, i.e. the first Label in the source LabelSet will be replaced by the first Label in the target LabelSet. If the size of theu00A0source and target LabelSets are not equal, the request will be rejected.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ RenameDatasetLabelsDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :source_label_set (OCI::DataLabelingService::Models::LabelSet)

    The value to assign to the #source_label_set property

  • :target_label_set (OCI::DataLabelingService::Models::LabelSet)

    The value to assign to the #target_label_set property



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/oci/data_labeling_service/models/rename_dataset_labels_details.rb', line 47

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.source_label_set = attributes[:'sourceLabelSet'] if attributes[:'sourceLabelSet']

  raise 'You cannot provide both :sourceLabelSet and :source_label_set' if attributes.key?(:'sourceLabelSet') && attributes.key?(:'source_label_set')

  self.source_label_set = attributes[:'source_label_set'] if attributes[:'source_label_set']

  self.target_label_set = attributes[:'targetLabelSet'] if attributes[:'targetLabelSet']

  raise 'You cannot provide both :targetLabelSet and :target_label_set' if attributes.key?(:'targetLabelSet') && attributes.key?(:'target_label_set')

  self.target_label_set = attributes[:'target_label_set'] if attributes[:'target_label_set']
end

Instance Attribute Details

#source_label_setOCI::DataLabelingService::Models::LabelSet

Returns:

  • (OCI::DataLabelingService::Models::LabelSet)


14
15
16
# File 'lib/oci/data_labeling_service/models/rename_dataset_labels_details.rb', line 14

def source_label_set
  @source_label_set
end

#target_label_setOCI::DataLabelingService::Models::LabelSet

Returns:

  • (OCI::DataLabelingService::Models::LabelSet)


17
18
19
# File 'lib/oci/data_labeling_service/models/rename_dataset_labels_details.rb', line 17

def target_label_set
  @target_label_set
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



20
21
22
23
24
25
26
27
# File 'lib/oci/data_labeling_service/models/rename_dataset_labels_details.rb', line 20

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'source_label_set': :'sourceLabelSet',
    'target_label_set': :'targetLabelSet'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



30
31
32
33
34
35
36
37
# File 'lib/oci/data_labeling_service/models/rename_dataset_labels_details.rb', line 30

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'source_label_set': :'OCI::DataLabelingService::Models::LabelSet',
    'target_label_set': :'OCI::DataLabelingService::Models::LabelSet'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



73
74
75
76
77
78
79
# File 'lib/oci/data_labeling_service/models/rename_dataset_labels_details.rb', line 73

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    source_label_set == other.source_label_set &&
    target_label_set == other.target_label_set
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/oci/data_labeling_service/models/rename_dataset_labels_details.rb', line 104

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


84
85
86
# File 'lib/oci/data_labeling_service/models/rename_dataset_labels_details.rb', line 84

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



93
94
95
# File 'lib/oci/data_labeling_service/models/rename_dataset_labels_details.rb', line 93

def hash
  [source_label_set, target_label_set].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



137
138
139
140
141
142
143
144
145
146
# File 'lib/oci/data_labeling_service/models/rename_dataset_labels_details.rb', line 137

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



131
132
133
# File 'lib/oci/data_labeling_service/models/rename_dataset_labels_details.rb', line 131

def to_s
  to_hash.to_s
end