Class: OCI::DataLabelingService::Models::UpdateDatasetDetails
- Inherits:
-
Object
- Object
- OCI::DataLabelingService::Models::UpdateDatasetDetails
- Defined in:
- lib/oci/data_labeling_service/models/update_dataset_details.rb
Overview
Once the Dataset is defined, it’s largely immutable from a metadata perspective. The records found in the data source itself, may change over time.
Instance Attribute Summary collapse
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
The defined tags for this resource.
-
#description ⇒ String
A user provided description of the dataset.
-
#display_name ⇒ String
A user-friendly display name for the resource.
-
#freeform_tags ⇒ Hash<String, String>
A simple key-value pair that is applied without any predefined name, type, or scope.
-
#labeling_instructions ⇒ String
The labeling instructions for human labelers in rich text format.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateDatasetDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateDatasetDetails
Initializes the object
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/oci/data_labeling_service/models/update_dataset_details.rb', line 72 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.labeling_instructions = attributes[:'labelingInstructions'] if attributes[:'labelingInstructions'] raise 'You cannot provide both :labelingInstructions and :labeling_instructions' if attributes.key?(:'labelingInstructions') && attributes.key?(:'labeling_instructions') self.labeling_instructions = attributes[:'labeling_instructions'] if attributes[:'labeling_instructions'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#defined_tags ⇒ Hash<String, Hash<String, Object>>
The defined tags for this resource. Each key is predefined and scoped to a namespace. For example: ‘{"bar-key": "value"}`
33 34 35 |
# File 'lib/oci/data_labeling_service/models/update_dataset_details.rb', line 33 def end |
#description ⇒ String
A user provided description of the dataset
17 18 19 |
# File 'lib/oci/data_labeling_service/models/update_dataset_details.rb', line 17 def description @description end |
#display_name ⇒ String
A user-friendly display name for the resource.
13 14 15 |
# File 'lib/oci/data_labeling_service/models/update_dataset_details.rb', line 13 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
A simple key-value pair that is applied without any predefined name, type, or scope. It exists for cross-compatibility only. For example: ‘"value"`
27 28 29 |
# File 'lib/oci/data_labeling_service/models/update_dataset_details.rb', line 27 def end |
#labeling_instructions ⇒ String
The labeling instructions for human labelers in rich text format
21 22 23 |
# File 'lib/oci/data_labeling_service/models/update_dataset_details.rb', line 21 def labeling_instructions @labeling_instructions end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/oci/data_labeling_service/models/update_dataset_details.rb', line 36 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'description': :'description', 'labeling_instructions': :'labelingInstructions', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/oci/data_labeling_service/models/update_dataset_details.rb', line 49 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'description': :'String', 'labeling_instructions': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
112 113 114 115 116 117 118 119 120 121 |
# File 'lib/oci/data_labeling_service/models/update_dataset_details.rb', line 112 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && description == other.description && labeling_instructions == other.labeling_instructions && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/oci/data_labeling_service/models/update_dataset_details.rb', line 146 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
126 127 128 |
# File 'lib/oci/data_labeling_service/models/update_dataset_details.rb', line 126 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
135 136 137 |
# File 'lib/oci/data_labeling_service/models/update_dataset_details.rb', line 135 def hash [display_name, description, labeling_instructions, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
179 180 181 182 183 184 185 186 187 188 |
# File 'lib/oci/data_labeling_service/models/update_dataset_details.rb', line 179 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
173 174 175 |
# File 'lib/oci/data_labeling_service/models/update_dataset_details.rb', line 173 def to_s to_hash.to_s end |