Class: OCI::DataLabelingServiceDataplane::DataLabelingClientCompositeOperations

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_labeling_service_dataplane/data_labeling_client_composite_operations.rb

Overview

This class provides a wrapper around DataLabelingClient and offers convenience methods for operations that would otherwise need to be chained together. For example, instead of performing an action on a resource (e.g. launching an instance, creating a load balancer) and then using a waiter to wait for the resource to enter a given state, you can call a single method in this class to accomplish the same functionality

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(service_client = OCI::DataLabelingServiceDataplane::DataLabelingClient.new) ⇒ DataLabelingClientCompositeOperations

Initializes a new DataLabelingClientCompositeOperations

Parameters:

  • service_client (OCI::DataLabelingServiceDataplane::DataLabelingClient) (defaults to: OCI::DataLabelingServiceDataplane::DataLabelingClient.new)

    The client used to communicate with the service. Defaults to a new service client created via OCI::DataLabelingServiceDataplane::DataLabelingClient#initialize with no arguments



20
21
22
# File 'lib/oci/data_labeling_service_dataplane/data_labeling_client_composite_operations.rb', line 20

def initialize(service_client = OCI::DataLabelingServiceDataplane::DataLabelingClient.new)
  @service_client = service_client
end

Instance Attribute Details

#service_clientOCI::DataLabelingServiceDataplane::DataLabelingClient (readonly)

The OCI::DataLabelingServiceDataplane::DataLabelingClient used to communicate with the service_client

Returns:

  • (OCI::DataLabelingServiceDataplane::DataLabelingClient)


14
15
16
# File 'lib/oci/data_labeling_service_dataplane/data_labeling_client_composite_operations.rb', line 14

def service_client
  @service_client
end

Instance Method Details

#create_annotation_and_wait_for_state(create_annotation_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response

Calls OCI::DataLabelingServiceDataplane::DataLabelingClient#create_annotation and then waits for the Models::Annotation acted upon to enter the given state(s).

Parameters:

  • create_annotation_details (OCI::DataLabelingServiceDataplane::Models::CreateAnnotationDetails)

    Details for the new CreateAnnotation.

  • wait_for_states (Array<String>) (defaults to: [])

    An array of states to wait on. These should be valid values for Models::Annotation#lifecycle_state

  • base_operation_opts (Hash) (defaults to: {})

    Any optional arguments accepted by OCI::DataLabelingServiceDataplane::DataLabelingClient#create_annotation

  • waiter_opts (Hash) (defaults to: {})

    Optional arguments for the waiter. Keys should be symbols, and the following keys are supported:

    • max_interval_seconds: The maximum interval between queries, in seconds.

    • max_wait_seconds The maximum time to wait, in seconds

Returns:



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/oci/data_labeling_service_dataplane/data_labeling_client_composite_operations.rb', line 39

def create_annotation_and_wait_for_state(create_annotation_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {})
  operation_result = @service_client.create_annotation(create_annotation_details, base_operation_opts)

  return operation_result if wait_for_states.empty?

  lowered_wait_for_states = wait_for_states.map(&:downcase)
  wait_for_resource_id = operation_result.data.id

  begin
    waiter_result = @service_client.get_annotation(wait_for_resource_id).wait_until(
      eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) },
      max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30,
      max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200
    )
    result_to_return = waiter_result

    return result_to_return
  rescue StandardError
    raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result])
  end
end

#create_record_and_wait_for_state(create_record_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response

Calls OCI::DataLabelingServiceDataplane::DataLabelingClient#create_record and then waits for the Models::Record acted upon to enter the given state(s).

Parameters:

  • create_record_details (OCI::DataLabelingServiceDataplane::Models::CreateRecordDetails)

    The details for the new record.

  • wait_for_states (Array<String>) (defaults to: [])

    An array of states to wait on. These should be valid values for Models::Record#lifecycle_state

  • base_operation_opts (Hash) (defaults to: {})

    Any optional arguments accepted by OCI::DataLabelingServiceDataplane::DataLabelingClient#create_record

  • waiter_opts (Hash) (defaults to: {})

    Optional arguments for the waiter. Keys should be symbols, and the following keys are supported:

    • max_interval_seconds: The maximum interval between queries, in seconds.

    • max_wait_seconds The maximum time to wait, in seconds

Returns:



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/oci/data_labeling_service_dataplane/data_labeling_client_composite_operations.rb', line 78

def create_record_and_wait_for_state(create_record_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {})
  operation_result = @service_client.create_record(create_record_details, base_operation_opts)

  return operation_result if wait_for_states.empty?

  lowered_wait_for_states = wait_for_states.map(&:downcase)
  wait_for_resource_id = operation_result.data.id

  begin
    waiter_result = @service_client.get_record(wait_for_resource_id).wait_until(
      eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) },
      max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30,
      max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200
    )
    result_to_return = waiter_result

    return result_to_return
  rescue StandardError
    raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result])
  end
end

#delete_annotation_and_wait_for_state(annotation_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response

Calls OCI::DataLabelingServiceDataplane::DataLabelingClient#delete_annotation and then waits for the Models::Annotation acted upon to enter the given state(s).

Parameters:

  • annotation_id (String)

    A unique annotation identifier.

  • wait_for_states (Array<String>) (defaults to: [])

    An array of states to wait on. These should be valid values for Models::Annotation#lifecycle_state

  • base_operation_opts (Hash) (defaults to: {})

    Any optional arguments accepted by OCI::DataLabelingServiceDataplane::DataLabelingClient#delete_annotation

  • waiter_opts (Hash) (defaults to: {})

    Optional arguments for the waiter. Keys should be symbols, and the following keys are supported:

    • max_interval_seconds: The maximum interval between queries, in seconds.

    • max_wait_seconds The maximum time to wait, in seconds

Returns:



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/oci/data_labeling_service_dataplane/data_labeling_client_composite_operations.rb', line 117

def delete_annotation_and_wait_for_state(annotation_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {})
  initial_get_result = @service_client.get_annotation(annotation_id)
  operation_result = @service_client.delete_annotation(annotation_id, base_operation_opts)

  return operation_result if wait_for_states.empty?

  lowered_wait_for_states = wait_for_states.map(&:downcase)

  begin
    waiter_result = initial_get_result.wait_until(
      eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) },
      max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30,
      max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200,
      succeed_on_not_found: true
    )
    result_to_return = waiter_result

    return result_to_return
  rescue StandardError
    raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result])
  end
end

#delete_record_and_wait_for_state(record_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response

Calls OCI::DataLabelingServiceDataplane::DataLabelingClient#delete_record and then waits for the Models::Record acted upon to enter the given state(s).

Parameters:

  • record_id (String)

    The OCID of the record annotated.

  • wait_for_states (Array<String>) (defaults to: [])

    An array of states to wait on. These should be valid values for Models::Record#lifecycle_state

  • base_operation_opts (Hash) (defaults to: {})

    Any optional arguments accepted by OCI::DataLabelingServiceDataplane::DataLabelingClient#delete_record

  • waiter_opts (Hash) (defaults to: {})

    Optional arguments for the waiter. Keys should be symbols, and the following keys are supported:

    • max_interval_seconds: The maximum interval between queries, in seconds.

    • max_wait_seconds The maximum time to wait, in seconds

Returns:



157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/oci/data_labeling_service_dataplane/data_labeling_client_composite_operations.rb', line 157

def delete_record_and_wait_for_state(record_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {})
  initial_get_result = @service_client.get_record(record_id)
  operation_result = @service_client.delete_record(record_id, base_operation_opts)

  return operation_result if wait_for_states.empty?

  lowered_wait_for_states = wait_for_states.map(&:downcase)

  begin
    waiter_result = initial_get_result.wait_until(
      eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) },
      max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30,
      max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200,
      succeed_on_not_found: true
    )
    result_to_return = waiter_result

    return result_to_return
  rescue StandardError
    raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result])
  end
end

#update_annotation_and_wait_for_state(annotation_id, update_annotation_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response

Calls OCI::DataLabelingServiceDataplane::DataLabelingClient#update_annotation and then waits for the Models::Annotation acted upon to enter the given state(s).

Parameters:

  • annotation_id (String)

    A unique annotation identifier.

  • update_annotation_details (OCI::DataLabelingServiceDataplane::Models::UpdateAnnotationDetails)

    The information to be updated.

  • wait_for_states (Array<String>) (defaults to: [])

    An array of states to wait on. These should be valid values for Models::Annotation#lifecycle_state

  • base_operation_opts (Hash) (defaults to: {})

    Any optional arguments accepted by OCI::DataLabelingServiceDataplane::DataLabelingClient#update_annotation

  • waiter_opts (Hash) (defaults to: {})

    Optional arguments for the waiter. Keys should be symbols, and the following keys are supported:

    • max_interval_seconds: The maximum interval between queries, in seconds.

    • max_wait_seconds The maximum time to wait, in seconds

Returns:



198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/oci/data_labeling_service_dataplane/data_labeling_client_composite_operations.rb', line 198

def update_annotation_and_wait_for_state(annotation_id, update_annotation_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {})
  operation_result = @service_client.update_annotation(annotation_id, update_annotation_details, base_operation_opts)

  return operation_result if wait_for_states.empty?

  lowered_wait_for_states = wait_for_states.map(&:downcase)
  wait_for_resource_id = operation_result.data.id

  begin
    waiter_result = @service_client.get_annotation(wait_for_resource_id).wait_until(
      eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) },
      max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30,
      max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200
    )
    result_to_return = waiter_result

    return result_to_return
  rescue StandardError
    raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result])
  end
end

#update_record_and_wait_for_state(record_id, update_record_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response

Calls OCI::DataLabelingServiceDataplane::DataLabelingClient#update_record and then waits for the Models::Record acted upon to enter the given state(s).

Parameters:

  • record_id (String)

    The OCID of the record annotated.

  • update_record_details (OCI::DataLabelingServiceDataplane::Models::UpdateRecordDetails)

    Information to be updated.

  • wait_for_states (Array<String>) (defaults to: [])

    An array of states to wait on. These should be valid values for Models::Record#lifecycle_state

  • base_operation_opts (Hash) (defaults to: {})

    Any optional arguments accepted by OCI::DataLabelingServiceDataplane::DataLabelingClient#update_record

  • waiter_opts (Hash) (defaults to: {})

    Optional arguments for the waiter. Keys should be symbols, and the following keys are supported:

    • max_interval_seconds: The maximum interval between queries, in seconds.

    • max_wait_seconds The maximum time to wait, in seconds

Returns:



238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/oci/data_labeling_service_dataplane/data_labeling_client_composite_operations.rb', line 238

def update_record_and_wait_for_state(record_id, update_record_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {})
  operation_result = @service_client.update_record(record_id, update_record_details, base_operation_opts)

  return operation_result if wait_for_states.empty?

  lowered_wait_for_states = wait_for_states.map(&:downcase)
  wait_for_resource_id = operation_result.data.id

  begin
    waiter_result = @service_client.get_record(wait_for_resource_id).wait_until(
      eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) },
      max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30,
      max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200
    )
    result_to_return = waiter_result

    return result_to_return
  rescue StandardError
    raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result])
  end
end