Class: DataLabelingServiceDataplane::Models::AnnotationSummary
- Inherits:
-
Object
- Object
- DataLabelingServiceDataplane::Models::AnnotationSummary
- Defined in:
- lib/oci/data_labeling_service_dataplane/models/annotation_summary.rb
Overview
An annotation summary is the representation returned in list views. It is usually a subset of the full annotation entity and should not contain any potentially sensitive information.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The OCID of the compartment for the annotation.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
The defined tags for this resource.
-
#freeform_tags ⇒ Hash<String, String>
A simple key-value pair that is applied without any predefined name, type, or scope.
-
#id ⇒ String
**[Required]** The OCID of the annotation.
-
#lifecycle_state ⇒ String
**[Required]** Describes the lifecycle state.
-
#record_id ⇒ String
**[Required]** The OCID of the record annotated.
-
#time_created ⇒ DateTime
**[Required]** The date and time the annotation was created, in the timestamp format defined by RFC3339.
-
#time_updated ⇒ DateTime
**[Required]** The date and time the resource was updated, in the timestamp format defined by RFC3339.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AnnotationSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ AnnotationSummary
Initializes the object
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/oci/data_labeling_service_dataplane/models/annotation_summary.rb', line 92 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.record_id = attributes[:'recordId'] if attributes[:'recordId'] raise 'You cannot provide both :recordId and :record_id' if attributes.key?(:'recordId') && attributes.key?(:'record_id') self.record_id = attributes[:'record_id'] if attributes[:'record_id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The OCID of the compartment for the annotation.
28 29 30 |
# File 'lib/oci/data_labeling_service_dataplane/models/annotation_summary.rb', line 28 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
The defined tags for this resource. Each key is predefined and scoped to a namespace. For example: `{"bar-key": "value"}`
44 45 46 |
# File 'lib/oci/data_labeling_service_dataplane/models/annotation_summary.rb', line 44 def @defined_tags end |
#freeform_tags ⇒ Hash<String, String>
A simple key-value pair that is applied without any predefined name, type, or scope. It exists for cross-compatibility only. For example: `"value"`
38 39 40 |
# File 'lib/oci/data_labeling_service_dataplane/models/annotation_summary.rb', line 38 def @freeform_tags end |
#id ⇒ String
**[Required]** The OCID of the annotation.
12 13 14 |
# File 'lib/oci/data_labeling_service_dataplane/models/annotation_summary.rb', line 12 def id @id end |
#lifecycle_state ⇒ String
**[Required]** Describes the lifecycle state.
32 33 34 |
# File 'lib/oci/data_labeling_service_dataplane/models/annotation_summary.rb', line 32 def lifecycle_state @lifecycle_state end |
#record_id ⇒ String
**[Required]** The OCID of the record annotated.
24 25 26 |
# File 'lib/oci/data_labeling_service_dataplane/models/annotation_summary.rb', line 24 def record_id @record_id end |
#time_created ⇒ DateTime
**[Required]** The date and time the annotation was created, in the timestamp format defined by RFC3339.
16 17 18 |
# File 'lib/oci/data_labeling_service_dataplane/models/annotation_summary.rb', line 16 def time_created @time_created end |
#time_updated ⇒ DateTime
**[Required]** The date and time the resource was updated, in the timestamp format defined by RFC3339.
20 21 22 |
# File 'lib/oci/data_labeling_service_dataplane/models/annotation_summary.rb', line 20 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/oci/data_labeling_service_dataplane/models/annotation_summary.rb', line 47 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'record_id': :'recordId', 'compartment_id': :'compartmentId', 'lifecycle_state': :'lifecycleState', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/oci/data_labeling_service_dataplane/models/annotation_summary.rb', line 63 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'record_id': :'String', 'compartment_id': :'String', 'lifecycle_state': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/oci/data_labeling_service_dataplane/models/annotation_summary.rb', line 150 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && time_created == other.time_created && time_updated == other.time_updated && record_id == other.record_id && compartment_id == other.compartment_id && lifecycle_state == other.lifecycle_state && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/oci/data_labeling_service_dataplane/models/annotation_summary.rb', line 187 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
167 168 169 |
# File 'lib/oci/data_labeling_service_dataplane/models/annotation_summary.rb', line 167 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
176 177 178 |
# File 'lib/oci/data_labeling_service_dataplane/models/annotation_summary.rb', line 176 def hash [id, time_created, time_updated, record_id, compartment_id, lifecycle_state, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
220 221 222 223 224 225 226 227 228 229 |
# File 'lib/oci/data_labeling_service_dataplane/models/annotation_summary.rb', line 220 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
214 215 216 |
# File 'lib/oci/data_labeling_service_dataplane/models/annotation_summary.rb', line 214 def to_s to_hash.to_s end |