Class: DataLabelingServiceDataplane::Models::CreateRecordDetails
- Inherits:
-
Object
- Object
- DataLabelingServiceDataplane::Models::CreateRecordDetails
- Defined in:
- lib/oci/data_labeling_service_dataplane/models/create_record_details.rb
Overview
A record represents an entry in a dataset that needs labeling.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The OCID of the compartment for the record.
-
#dataset_id ⇒ String
**[Required]** The OCID of the dataset to associate the record with.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
The defined tags for this resource.
-
#freeform_tags ⇒ Hash<String, String>
A simple key-value pair that is applied without any predefined name, type, or scope.
-
#name ⇒ String
**[Required]** The name is automatically assigned by the service.
- #record_metadata ⇒ OCI::DataLabelingServiceDataplane::Models::RecordMetadata
-
#source_details ⇒ OCI::DataLabelingServiceDataplane::Models::CreateSourceDetails
This attribute is required.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateRecordDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateRecordDetails
Initializes the object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/oci/data_labeling_service_dataplane/models/create_record_details.rb', line 84 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.dataset_id = attributes[:'datasetId'] if attributes[:'datasetId'] raise 'You cannot provide both :datasetId and :dataset_id' if attributes.key?(:'datasetId') && attributes.key?(:'dataset_id') self.dataset_id = attributes[:'dataset_id'] if attributes[:'dataset_id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.source_details = attributes[:'sourceDetails'] if attributes[:'sourceDetails'] raise 'You cannot provide both :sourceDetails and :source_details' if attributes.key?(:'sourceDetails') && attributes.key?(:'source_details') self.source_details = attributes[:'source_details'] if attributes[:'source_details'] self. = attributes[:'recordMetadata'] if attributes[:'recordMetadata'] raise 'You cannot provide both :recordMetadata and :record_metadata' if attributes.key?(:'recordMetadata') && attributes.key?(:'record_metadata') self. = attributes[:'record_metadata'] if attributes[:'record_metadata'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The OCID of the compartment for the record. This is tied to the dataset. It is not changeable on the record itself.
20 21 22 |
# File 'lib/oci/data_labeling_service_dataplane/models/create_record_details.rb', line 20 def compartment_id @compartment_id end |
#dataset_id ⇒ String
**[Required]** The OCID of the dataset to associate the record with.
16 17 18 |
# File 'lib/oci/data_labeling_service_dataplane/models/create_record_details.rb', line 16 def dataset_id @dataset_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
The defined tags for this resource. Each key is predefined and scoped to a namespace. For example: `{"bar-key": "value"}`
39 40 41 |
# File 'lib/oci/data_labeling_service_dataplane/models/create_record_details.rb', line 39 def @defined_tags end |
#freeform_tags ⇒ Hash<String, String>
A simple key-value pair that is applied without any predefined name, type, or scope. It exists for cross-compatibility only. For example: `"value"`
33 34 35 |
# File 'lib/oci/data_labeling_service_dataplane/models/create_record_details.rb', line 33 def @freeform_tags end |
#name ⇒ String
**[Required]** The name is automatically assigned by the service. It is unique and immutable.
12 13 14 |
# File 'lib/oci/data_labeling_service_dataplane/models/create_record_details.rb', line 12 def name @name end |
#record_metadata ⇒ OCI::DataLabelingServiceDataplane::Models::RecordMetadata
27 28 29 |
# File 'lib/oci/data_labeling_service_dataplane/models/create_record_details.rb', line 27 def @record_metadata end |
#source_details ⇒ OCI::DataLabelingServiceDataplane::Models::CreateSourceDetails
This attribute is required.
24 25 26 |
# File 'lib/oci/data_labeling_service_dataplane/models/create_record_details.rb', line 24 def source_details @source_details end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
42 43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/oci/data_labeling_service_dataplane/models/create_record_details.rb', line 42 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'dataset_id': :'datasetId', 'compartment_id': :'compartmentId', 'source_details': :'sourceDetails', 'record_metadata': :'recordMetadata', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/oci/data_labeling_service_dataplane/models/create_record_details.rb', line 57 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'dataset_id': :'String', 'compartment_id': :'String', 'source_details': :'OCI::DataLabelingServiceDataplane::Models::CreateSourceDetails', 'record_metadata': :'OCI::DataLabelingServiceDataplane::Models::RecordMetadata', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/oci/data_labeling_service_dataplane/models/create_record_details.rb', line 136 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && dataset_id == other.dataset_id && compartment_id == other.compartment_id && source_details == other.source_details && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/oci/data_labeling_service_dataplane/models/create_record_details.rb', line 172 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
152 153 154 |
# File 'lib/oci/data_labeling_service_dataplane/models/create_record_details.rb', line 152 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
161 162 163 |
# File 'lib/oci/data_labeling_service_dataplane/models/create_record_details.rb', line 161 def hash [name, dataset_id, compartment_id, source_details, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
205 206 207 208 209 210 211 212 213 214 |
# File 'lib/oci/data_labeling_service_dataplane/models/create_record_details.rb', line 205 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
199 200 201 |
# File 'lib/oci/data_labeling_service_dataplane/models/create_record_details.rb', line 199 def to_s to_hash.to_s end |