Class: DataLabelingServiceDataplane::Models::CreateSourceDetails
- Inherits:
-
Object
- Object
- DataLabelingServiceDataplane::Models::CreateSourceDetails
- Defined in:
- lib/oci/data_labeling_service_dataplane/models/create_source_details.rb
Overview
The source information is a polymorphic entity. It captures the details of how to access the data for record creation. The discriminator type must match the dataset's source type. The convention will be enforced by the API. It should only provide the difference in data necessary to access the content, i.e. the object storage path, or the database record id.
This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
OCI::DataLabelingServiceDataplane::Models::CreateObjectStorageSourceDetails
Constant Summary collapse
- SOURCE_TYPE_ENUM =
[ SOURCE_TYPE_OBJECT_STORAGE = 'OBJECT_STORAGE'.freeze ].freeze
Instance Attribute Summary collapse
-
#source_type ⇒ String
**[Required]** The type of data source.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateSourceDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateSourceDetails
Initializes the object
62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/oci/data_labeling_service_dataplane/models/create_source_details.rb', line 62 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.source_type = attributes[:'sourceType'] if attributes[:'sourceType'] raise 'You cannot provide both :sourceType and :source_type' if attributes.key?(:'sourceType') && attributes.key?(:'source_type') self.source_type = attributes[:'source_type'] if attributes[:'source_type'] end |
Instance Attribute Details
#source_type ⇒ String
**[Required]** The type of data source. OBJECT_STORAGE - The source details for an object storage bucket.
20 21 22 |
# File 'lib/oci/data_labeling_service_dataplane/models/create_source_details.rb', line 20 def source_type @source_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
23 24 25 26 27 28 29 |
# File 'lib/oci/data_labeling_service_dataplane/models/create_source_details.rb', line 23 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'source_type': :'sourceType' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
45 46 47 48 49 50 51 52 |
# File 'lib/oci/data_labeling_service_dataplane/models/create_source_details.rb', line 45 def self.get_subtype(object_hash) type = object_hash[:'sourceType'] # rubocop:disable Style/SymbolLiteral return 'OCI::DataLabelingServiceDataplane::Models::CreateObjectStorageSourceDetails' if type == 'OBJECT_STORAGE' # TODO: Log a warning when the subtype is not found. 'OCI::DataLabelingServiceDataplane::Models::CreateSourceDetails' end |
.swagger_types ⇒ Object
Attribute type mapping.
32 33 34 35 36 37 38 |
# File 'lib/oci/data_labeling_service_dataplane/models/create_source_details.rb', line 32 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'source_type': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
90 91 92 93 94 95 |
# File 'lib/oci/data_labeling_service_dataplane/models/create_source_details.rb', line 90 def ==(other) return true if equal?(other) self.class == other.class && source_type == other.source_type end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/oci/data_labeling_service_dataplane/models/create_source_details.rb', line 120 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
100 101 102 |
# File 'lib/oci/data_labeling_service_dataplane/models/create_source_details.rb', line 100 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
109 110 111 |
# File 'lib/oci/data_labeling_service_dataplane/models/create_source_details.rb', line 109 def hash [source_type].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
153 154 155 156 157 158 159 160 161 162 |
# File 'lib/oci/data_labeling_service_dataplane/models/create_source_details.rb', line 153 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
147 148 149 |
# File 'lib/oci/data_labeling_service_dataplane/models/create_source_details.rb', line 147 def to_s to_hash.to_s end |