Class: DataLabelingServiceDataplane::Models::Entity
- Inherits:
-
Object
- Object
- DataLabelingServiceDataplane::Models::Entity
- Defined in:
- lib/oci/data_labeling_service_dataplane/models/entity.rb
Overview
An entity allows the labeler to identify an object in the record to label. This can be, for example, a snippet of text, an entire image, or a bounding box within an image. All entity types have an array of labels that are indexed. If more than one label is provided, but the annotationType on the corresponding dataset is for a single class, the API rejects the create annotation request.
This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
GenericEntity, TextSelectionEntity, OCI::DataLabelingServiceDataplane::Models::ImageObjectSelectionEntity
Constant Summary collapse
- ENTITY_TYPE_ENUM =
[ ENTITY_TYPE_GENERIC = 'GENERIC'.freeze, ENTITY_TYPE_IMAGEOBJECTSELECTION = 'IMAGEOBJECTSELECTION'.freeze, ENTITY_TYPE_TEXTSELECTION = 'TEXTSELECTION'.freeze, ENTITY_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#entity_type ⇒ String
**[Required]** The entity type described in the annotation.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Entity
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Entity
Initializes the object
70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/oci/data_labeling_service_dataplane/models/entity.rb', line 70 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.entity_type = attributes[:'entityType'] if attributes[:'entityType'] raise 'You cannot provide both :entityType and :entity_type' if attributes.key?(:'entityType') && attributes.key?(:'entity_type') self.entity_type = attributes[:'entity_type'] if attributes[:'entity_type'] end |
Instance Attribute Details
#entity_type ⇒ String
**[Required]** The entity type described in the annotation. GENERIC - An extensible entity type that is the base entity type for some annotation formats. IMAGEOBJECTSELECTION- - This allows the labeler to use specify a bounding polygon on the image to represent an object and apply labels to it. TEXTSELECTION - This allows the labeler to highlight text, by specifying an offset and a length, and apply labels to it.
26 27 28 |
# File 'lib/oci/data_labeling_service_dataplane/models/entity.rb', line 26 def entity_type @entity_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 |
# File 'lib/oci/data_labeling_service_dataplane/models/entity.rb', line 29 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'entity_type': :'entityType' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
51 52 53 54 55 56 57 58 59 60 |
# File 'lib/oci/data_labeling_service_dataplane/models/entity.rb', line 51 def self.get_subtype(object_hash) type = object_hash[:'entityType'] # rubocop:disable Style/SymbolLiteral return 'OCI::DataLabelingServiceDataplane::Models::ImageObjectSelectionEntity' if type == 'IMAGEOBJECTSELECTION' return 'OCI::DataLabelingServiceDataplane::Models::GenericEntity' if type == 'GENERIC' return 'OCI::DataLabelingServiceDataplane::Models::TextSelectionEntity' if type == 'TEXTSELECTION' # TODO: Log a warning when the subtype is not found. 'OCI::DataLabelingServiceDataplane::Models::Entity' end |
.swagger_types ⇒ Object
Attribute type mapping.
38 39 40 41 42 43 44 |
# File 'lib/oci/data_labeling_service_dataplane/models/entity.rb', line 38 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'entity_type': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
103 104 105 106 107 108 |
# File 'lib/oci/data_labeling_service_dataplane/models/entity.rb', line 103 def ==(other) return true if equal?(other) self.class == other.class && entity_type == other.entity_type end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/oci/data_labeling_service_dataplane/models/entity.rb', line 133 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
113 114 115 |
# File 'lib/oci/data_labeling_service_dataplane/models/entity.rb', line 113 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
122 123 124 |
# File 'lib/oci/data_labeling_service_dataplane/models/entity.rb', line 122 def hash [entity_type].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
166 167 168 169 170 171 172 173 174 175 |
# File 'lib/oci/data_labeling_service_dataplane/models/entity.rb', line 166 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
160 161 162 |
# File 'lib/oci/data_labeling_service_dataplane/models/entity.rb', line 160 def to_s to_hash.to_s end |