Class: OCI::DataLabelingServiceDataplane::Models::ObjectStorageDatasetSourceDetails

Inherits:
DataLabelingServiceDataplane::Models::DatasetSourceDetails
  • Object
show all
Defined in:
lib/oci/data_labeling_service_dataplane/models/object_storage_dataset_source_details.rb

Overview

Specifies the dataset location in object storage. This requires that all records are in this bucket, and under this prefix. We do not support a dataset with objects in arbitrary locations across buckets or prefixes.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ObjectStorageDatasetSourceDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :namespace (String)

    The value to assign to the #namespace property

  • :bucket (String)

    The value to assign to the #bucket property

  • :prefix (String)

    The value to assign to the #prefix property



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/oci/data_labeling_service_dataplane/models/object_storage_dataset_source_details.rb', line 57

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['sourceType'] = 'OBJECT_STORAGE'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.namespace = attributes[:'namespace'] if attributes[:'namespace']

  self.bucket = attributes[:'bucket'] if attributes[:'bucket']

  self.prefix = attributes[:'prefix'] if attributes[:'prefix']
end

Instance Attribute Details

#bucketString

**[Required]** The object storage bucket that contains the dataset data source.

Returns:

  • (String)


18
19
20
# File 'lib/oci/data_labeling_service_dataplane/models/object_storage_dataset_source_details.rb', line 18

def bucket
  @bucket
end

#namespaceString

**[Required]** The namespace of the bucket that contains the dataset data source.

Returns:

  • (String)


14
15
16
# File 'lib/oci/data_labeling_service_dataplane/models/object_storage_dataset_source_details.rb', line 14

def namespace
  @namespace
end

#prefixString

A common path prefix shared by the objects that make up the dataset. Except for the CSV file type, records are not generated for the objects whose names exactly match with the prefix.

Returns:

  • (String)


22
23
24
# File 'lib/oci/data_labeling_service_dataplane/models/object_storage_dataset_source_details.rb', line 22

def prefix
  @prefix
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



25
26
27
28
29
30
31
32
33
34
# File 'lib/oci/data_labeling_service_dataplane/models/object_storage_dataset_source_details.rb', line 25

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'source_type': :'sourceType',
    'namespace': :'namespace',
    'bucket': :'bucket',
    'prefix': :'prefix'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



37
38
39
40
41
42
43
44
45
46
# File 'lib/oci/data_labeling_service_dataplane/models/object_storage_dataset_source_details.rb', line 37

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'source_type': :'String',
    'namespace': :'String',
    'bucket': :'String',
    'prefix': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



81
82
83
84
85
86
87
88
89
# File 'lib/oci/data_labeling_service_dataplane/models/object_storage_dataset_source_details.rb', line 81

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    source_type == other.source_type &&
    namespace == other.namespace &&
    bucket == other.bucket &&
    prefix == other.prefix
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/oci/data_labeling_service_dataplane/models/object_storage_dataset_source_details.rb', line 114

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


94
95
96
# File 'lib/oci/data_labeling_service_dataplane/models/object_storage_dataset_source_details.rb', line 94

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



103
104
105
# File 'lib/oci/data_labeling_service_dataplane/models/object_storage_dataset_source_details.rb', line 103

def hash
  [source_type, namespace, bucket, prefix].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



147
148
149
150
151
152
153
154
155
156
# File 'lib/oci/data_labeling_service_dataplane/models/object_storage_dataset_source_details.rb', line 147

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



141
142
143
# File 'lib/oci/data_labeling_service_dataplane/models/object_storage_dataset_source_details.rb', line 141

def to_s
  to_hash.to_s
end