Class: OCI::DataLabelingServiceDataplane::Models::ObjectStorageSourceDetails
- Inherits:
-
DataLabelingServiceDataplane::Models::SourceDetails
- Object
- DataLabelingServiceDataplane::Models::SourceDetails
- OCI::DataLabelingServiceDataplane::Models::ObjectStorageSourceDetails
- Defined in:
- lib/oci/data_labeling_service_dataplane/models/object_storage_source_details.rb
Overview
Object Storage Source Details.
Instance Attribute Summary collapse
-
#length ⇒ Float
The length from the offset into the file containing the content.
-
#offset ⇒ Float
The offset into the file containing the content.
-
#path ⇒ String
[Required] The full path of the file this record belongs to.
-
#relative_path ⇒ String
[Required] The path relative to the prefix specified in the dataset source details (file name).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ObjectStorageSourceDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ObjectStorageSourceDetails
Initializes the object
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/oci/data_labeling_service_dataplane/models/object_storage_source_details.rb', line 63 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['sourceType'] = 'OBJECT_STORAGE' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.relative_path = attributes[:'relativePath'] if attributes[:'relativePath'] raise 'You cannot provide both :relativePath and :relative_path' if attributes.key?(:'relativePath') && attributes.key?(:'relative_path') self.relative_path = attributes[:'relative_path'] if attributes[:'relative_path'] self.path = attributes[:'path'] if attributes[:'path'] self.offset = attributes[:'offset'] if attributes[:'offset'] self.length = attributes[:'length'] if attributes[:'length'] end |
Instance Attribute Details
#length ⇒ Float
The length from the offset into the file containing the content.
25 26 27 |
# File 'lib/oci/data_labeling_service_dataplane/models/object_storage_source_details.rb', line 25 def length @length end |
#offset ⇒ Float
The offset into the file containing the content.
21 22 23 |
# File 'lib/oci/data_labeling_service_dataplane/models/object_storage_source_details.rb', line 21 def offset @offset end |
#path ⇒ String
[Required] The full path of the file this record belongs to.
17 18 19 |
# File 'lib/oci/data_labeling_service_dataplane/models/object_storage_source_details.rb', line 17 def path @path end |
#relative_path ⇒ String
[Required] The path relative to the prefix specified in the dataset source details (file name).
13 14 15 |
# File 'lib/oci/data_labeling_service_dataplane/models/object_storage_source_details.rb', line 13 def relative_path @relative_path end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 35 36 37 38 |
# File 'lib/oci/data_labeling_service_dataplane/models/object_storage_source_details.rb', line 28 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'source_type': :'sourceType', 'relative_path': :'relativePath', 'path': :'path', 'offset': :'offset', 'length': :'length' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/oci/data_labeling_service_dataplane/models/object_storage_source_details.rb', line 41 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'source_type': :'String', 'relative_path': :'String', 'path': :'String', 'offset': :'Float', 'length': :'Float' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
93 94 95 96 97 98 99 100 101 102 |
# File 'lib/oci/data_labeling_service_dataplane/models/object_storage_source_details.rb', line 93 def ==(other) return true if equal?(other) self.class == other.class && source_type == other.source_type && relative_path == other.relative_path && path == other.path && offset == other.offset && length == other.length end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/oci/data_labeling_service_dataplane/models/object_storage_source_details.rb', line 127 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
107 108 109 |
# File 'lib/oci/data_labeling_service_dataplane/models/object_storage_source_details.rb', line 107 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
116 117 118 |
# File 'lib/oci/data_labeling_service_dataplane/models/object_storage_source_details.rb', line 116 def hash [source_type, relative_path, path, offset, length].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
160 161 162 163 164 165 166 167 168 169 |
# File 'lib/oci/data_labeling_service_dataplane/models/object_storage_source_details.rb', line 160 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
154 155 156 |
# File 'lib/oci/data_labeling_service_dataplane/models/object_storage_source_details.rb', line 154 def to_s to_hash.to_s end |