Class: OCI::DataLabelingServiceDataplane::Models::RecordAnalyticsAggregation
- Inherits:
-
Object
- Object
- OCI::DataLabelingServiceDataplane::Models::RecordAnalyticsAggregation
- Defined in:
- lib/oci/data_labeling_service_dataplane/models/record_analytics_aggregation.rb
Overview
Aggregation entities are required by the API consistency guidelines for API Consistency Guidelines#AnalyticsAPIs. These are used to summarize record information for a given dataset and are used to populate UI elements. Aggregations need to have the fields that identify the exact scope that they’re summarizing. Any filters applied to the list API, have to show up in the aggregation.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] ocid of the compartment the records.
-
#count ⇒ Float
[Required] the count of the matching results.
-
#dataset_id ⇒ String
[Required] ocid of the dataset the annotation belongs to.
- #dimensions ⇒ OCI::DataLabelingServiceDataplane::Models::RecordAggregationDimensions
-
#lifecycle_state ⇒ String
Describes the lifecycle state.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RecordAnalyticsAggregation
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ RecordAnalyticsAggregation
Initializes the object
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/oci/data_labeling_service_dataplane/models/record_analytics_aggregation.rb', line 66 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.count = attributes[:'count'] if attributes[:'count'] self.dimensions = attributes[:'dimensions'] if attributes[:'dimensions'] self.dataset_id = attributes[:'datasetId'] if attributes[:'datasetId'] raise 'You cannot provide both :datasetId and :dataset_id' if attributes.key?(:'datasetId') && attributes.key?(:'dataset_id') self.dataset_id = attributes[:'dataset_id'] if attributes[:'dataset_id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] ocid of the compartment the records
23 24 25 |
# File 'lib/oci/data_labeling_service_dataplane/models/record_analytics_aggregation.rb', line 23 def compartment_id @compartment_id end |
#count ⇒ Float
[Required] the count of the matching results
12 13 14 |
# File 'lib/oci/data_labeling_service_dataplane/models/record_analytics_aggregation.rb', line 12 def count @count end |
#dataset_id ⇒ String
[Required] ocid of the dataset the annotation belongs to
19 20 21 |
# File 'lib/oci/data_labeling_service_dataplane/models/record_analytics_aggregation.rb', line 19 def dataset_id @dataset_id end |
#dimensions ⇒ OCI::DataLabelingServiceDataplane::Models::RecordAggregationDimensions
15 16 17 |
# File 'lib/oci/data_labeling_service_dataplane/models/record_analytics_aggregation.rb', line 15 def dimensions @dimensions end |
#lifecycle_state ⇒ String
Describes the lifecycle state.
27 28 29 |
# File 'lib/oci/data_labeling_service_dataplane/models/record_analytics_aggregation.rb', line 27 def lifecycle_state @lifecycle_state end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
30 31 32 33 34 35 36 37 38 39 40 |
# File 'lib/oci/data_labeling_service_dataplane/models/record_analytics_aggregation.rb', line 30 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'count': :'count', 'dimensions': :'dimensions', 'dataset_id': :'datasetId', 'compartment_id': :'compartmentId', 'lifecycle_state': :'lifecycleState' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/oci/data_labeling_service_dataplane/models/record_analytics_aggregation.rb', line 43 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'count': :'Float', 'dimensions': :'OCI::DataLabelingServiceDataplane::Models::RecordAggregationDimensions', 'dataset_id': :'String', 'compartment_id': :'String', 'lifecycle_state': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
102 103 104 105 106 107 108 109 110 111 |
# File 'lib/oci/data_labeling_service_dataplane/models/record_analytics_aggregation.rb', line 102 def ==(other) return true if equal?(other) self.class == other.class && count == other.count && dimensions == other.dimensions && dataset_id == other.dataset_id && compartment_id == other.compartment_id && lifecycle_state == other.lifecycle_state end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/oci/data_labeling_service_dataplane/models/record_analytics_aggregation.rb', line 136 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
116 117 118 |
# File 'lib/oci/data_labeling_service_dataplane/models/record_analytics_aggregation.rb', line 116 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
125 126 127 |
# File 'lib/oci/data_labeling_service_dataplane/models/record_analytics_aggregation.rb', line 125 def hash [count, dimensions, dataset_id, compartment_id, lifecycle_state].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
169 170 171 172 173 174 175 176 177 178 |
# File 'lib/oci/data_labeling_service_dataplane/models/record_analytics_aggregation.rb', line 169 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
163 164 165 |
# File 'lib/oci/data_labeling_service_dataplane/models/record_analytics_aggregation.rb', line 163 def to_s to_hash.to_s end |