Class: DataLabelingServiceDataplane::Models::RecordSummary
- Inherits:
-
Object
- Object
- DataLabelingServiceDataplane::Models::RecordSummary
- Defined in:
- lib/oci/data_labeling_service_dataplane/models/record_summary.rb
Overview
A record summary is the representation returned in list views. It is usually a subset of the full record entity and should not contain any potentially sensitive information.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The OCID of the compartment for the task.
-
#dataset_id ⇒ String
**[Required]** The OCID of the dataset to associate the record with.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
The defined tags for this resource.
-
#freeform_tags ⇒ Hash<String, String>
A simple key-value pair that is applied without any predefined name, type, or scope.
-
#id ⇒ String
**[Required]** The OCID of the record.
-
#is_labeled ⇒ BOOLEAN
**[Required]** Whether or not the record has been labeled and has associated annotations.
-
#lifecycle_state ⇒ String
**[Required]** Describes the lifecycle state.
-
#name ⇒ String
**[Required]** The name is automatically assigned by the service.
-
#time_created ⇒ DateTime
**[Required]** The date and time the resource was created, in the timestamp format defined by RFC3339.
-
#time_updated ⇒ DateTime
**[Required]** The date and time the resource was updated, in the timestamp format defined by RFC3339.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RecordSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ RecordSummary
Initializes the object
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/oci/data_labeling_service_dataplane/models/record_summary.rb', line 106 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.name = attributes[:'name'] if attributes[:'name'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.dataset_id = attributes[:'datasetId'] if attributes[:'datasetId'] raise 'You cannot provide both :datasetId and :dataset_id' if attributes.key?(:'datasetId') && attributes.key?(:'dataset_id') self.dataset_id = attributes[:'dataset_id'] if attributes[:'dataset_id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.is_labeled = attributes[:'isLabeled'] unless attributes[:'isLabeled'].nil? raise 'You cannot provide both :isLabeled and :is_labeled' if attributes.key?(:'isLabeled') && attributes.key?(:'is_labeled') self.is_labeled = attributes[:'is_labeled'] unless attributes[:'is_labeled'].nil? self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The OCID of the compartment for the task.
32 33 34 |
# File 'lib/oci/data_labeling_service_dataplane/models/record_summary.rb', line 32 def compartment_id @compartment_id end |
#dataset_id ⇒ String
**[Required]** The OCID of the dataset to associate the record with.
28 29 30 |
# File 'lib/oci/data_labeling_service_dataplane/models/record_summary.rb', line 28 def dataset_id @dataset_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
The defined tags for this resource. Each key is predefined and scoped to a namespace. For example: `{"bar-key": "value"}`
52 53 54 |
# File 'lib/oci/data_labeling_service_dataplane/models/record_summary.rb', line 52 def @defined_tags end |
#freeform_tags ⇒ Hash<String, String>
A simple key-value pair that is applied without any predefined name, type, or scope. It exists for cross-compatibility only. For example: `"value"`
46 47 48 |
# File 'lib/oci/data_labeling_service_dataplane/models/record_summary.rb', line 46 def @freeform_tags end |
#id ⇒ String
**[Required]** The OCID of the record.
12 13 14 |
# File 'lib/oci/data_labeling_service_dataplane/models/record_summary.rb', line 12 def id @id end |
#is_labeled ⇒ BOOLEAN
**[Required]** Whether or not the record has been labeled and has associated annotations.
36 37 38 |
# File 'lib/oci/data_labeling_service_dataplane/models/record_summary.rb', line 36 def is_labeled @is_labeled end |
#lifecycle_state ⇒ String
**[Required]** Describes the lifecycle state.
40 41 42 |
# File 'lib/oci/data_labeling_service_dataplane/models/record_summary.rb', line 40 def lifecycle_state @lifecycle_state end |
#name ⇒ String
**[Required]** The name is automatically assigned by the service. It is unique and immutable
16 17 18 |
# File 'lib/oci/data_labeling_service_dataplane/models/record_summary.rb', line 16 def name @name end |
#time_created ⇒ DateTime
**[Required]** The date and time the resource was created, in the timestamp format defined by RFC3339.
20 21 22 |
# File 'lib/oci/data_labeling_service_dataplane/models/record_summary.rb', line 20 def time_created @time_created end |
#time_updated ⇒ DateTime
**[Required]** The date and time the resource was updated, in the timestamp format defined by RFC3339.
24 25 26 |
# File 'lib/oci/data_labeling_service_dataplane/models/record_summary.rb', line 24 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/oci/data_labeling_service_dataplane/models/record_summary.rb', line 55 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'name': :'name', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'dataset_id': :'datasetId', 'compartment_id': :'compartmentId', 'is_labeled': :'isLabeled', 'lifecycle_state': :'lifecycleState', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/oci/data_labeling_service_dataplane/models/record_summary.rb', line 73 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'name': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'dataset_id': :'String', 'compartment_id': :'String', 'is_labeled': :'BOOLEAN', 'lifecycle_state': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/oci/data_labeling_service_dataplane/models/record_summary.rb', line 172 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && name == other.name && time_created == other.time_created && time_updated == other.time_updated && dataset_id == other.dataset_id && compartment_id == other.compartment_id && is_labeled == other.is_labeled && lifecycle_state == other.lifecycle_state && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/oci/data_labeling_service_dataplane/models/record_summary.rb', line 211 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
191 192 193 |
# File 'lib/oci/data_labeling_service_dataplane/models/record_summary.rb', line 191 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
200 201 202 |
# File 'lib/oci/data_labeling_service_dataplane/models/record_summary.rb', line 200 def hash [id, name, time_created, time_updated, dataset_id, compartment_id, is_labeled, lifecycle_state, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
244 245 246 247 248 249 250 251 252 253 |
# File 'lib/oci/data_labeling_service_dataplane/models/record_summary.rb', line 244 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
238 239 240 |
# File 'lib/oci/data_labeling_service_dataplane/models/record_summary.rb', line 238 def to_s to_hash.to_s end |