Class: OCI::DataSafe::Models::Alert
- Inherits:
-
Object
- Object
- OCI::DataSafe::Models::Alert
- Defined in:
- lib/oci/data_safe/models/alert.rb
Overview
The details of a Data Safe Alert, that shows alerts generated by a Data Safe feature.
Constant Summary collapse
- STATUS_ENUM =
[ STATUS_OPEN = 'OPEN'.freeze, STATUS_CLOSED = 'CLOSED'.freeze, STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- SEVERITY_ENUM =
[ SEVERITY_CRITICAL = 'CRITICAL'.freeze, SEVERITY_HIGH = 'HIGH'.freeze, SEVERITY_MEDIUM = 'MEDIUM'.freeze, SEVERITY_LOW = 'LOW'.freeze, SEVERITY_EVALUATE = 'EVALUATE'.freeze, SEVERITY_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- OPERATION_STATUS_ENUM =
[ OPERATION_STATUS_SUCCEEDED = 'SUCCEEDED'.freeze, OPERATION_STATUS_FAILED = 'FAILED'.freeze, OPERATION_STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- ALERT_TYPE_ENUM =
[ ALERT_TYPE_AUDITING = 'AUDITING'.freeze, ALERT_TYPE_SECURITY_ASSESSMENT = 'SECURITY_ASSESSMENT'.freeze, ALERT_TYPE_USER_ASSESSMENT = 'USER_ASSESSMENT'.freeze, ALERT_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_SUCCEEDED = 'SUCCEEDED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#alert_type ⇒ String
Type of the alert.
-
#comment ⇒ String
A comment for the alert.
-
#compartment_id ⇒ String
[Required] The OCID of the compartment that contains the alert.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
The description of the alert.
-
#display_name ⇒ String
[Required] The display name of the alert.
-
#feature_details ⇒ Hash<String, Hash<String, Object>>
Map that contains maps of values.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] The OCID of the alert.
-
#lifecycle_state ⇒ String
[Required] The current state of the alert.
-
#operation ⇒ String
The operation (event) that triggered alert.
-
#operation_status ⇒ String
The result of the operation (event) that triggered alert.
-
#operation_time ⇒ DateTime
Creation date and time of the operation that triggered alert, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#policy_id ⇒ String
The OCID of the policy that triggered alert.
-
#resource_name ⇒ String
The resource endpoint that triggered the alert.
-
#severity ⇒ String
Severity level of the alert.
-
#status ⇒ String
The status of the alert.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
System tags for this resource.
-
#target_ids ⇒ Array<String>
Array of OCIDs of the target database which are associated with the alert.
-
#target_names ⇒ Array<String>
Array of names of the target database.
-
#time_created ⇒ DateTime
[Required] Creation date and time of the alert, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#time_updated ⇒ DateTime
[Required] Last date and time the alert was updated, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Alert
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Alert
Initializes the object
232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/oci/data_safe/models/alert.rb', line 232 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.status = attributes[:'status'] if attributes[:'status'] self.severity = attributes[:'severity'] if attributes[:'severity'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.operation_time = attributes[:'operationTime'] if attributes[:'operationTime'] raise 'You cannot provide both :operationTime and :operation_time' if attributes.key?(:'operationTime') && attributes.key?(:'operation_time') self.operation_time = attributes[:'operation_time'] if attributes[:'operation_time'] self.operation = attributes[:'operation'] if attributes[:'operation'] self.operation_status = attributes[:'operationStatus'] if attributes[:'operationStatus'] raise 'You cannot provide both :operationStatus and :operation_status' if attributes.key?(:'operationStatus') && attributes.key?(:'operation_status') self.operation_status = attributes[:'operation_status'] if attributes[:'operation_status'] self.target_ids = attributes[:'targetIds'] if attributes[:'targetIds'] raise 'You cannot provide both :targetIds and :target_ids' if attributes.key?(:'targetIds') && attributes.key?(:'target_ids') self.target_ids = attributes[:'target_ids'] if attributes[:'target_ids'] self.target_names = attributes[:'targetNames'] if attributes[:'targetNames'] raise 'You cannot provide both :targetNames and :target_names' if attributes.key?(:'targetNames') && attributes.key?(:'target_names') self.target_names = attributes[:'target_names'] if attributes[:'target_names'] self.policy_id = attributes[:'policyId'] if attributes[:'policyId'] raise 'You cannot provide both :policyId and :policy_id' if attributes.key?(:'policyId') && attributes.key?(:'policy_id') self.policy_id = attributes[:'policy_id'] if attributes[:'policy_id'] self.alert_type = attributes[:'alertType'] if attributes[:'alertType'] raise 'You cannot provide both :alertType and :alert_type' if attributes.key?(:'alertType') && attributes.key?(:'alert_type') self.alert_type = attributes[:'alert_type'] if attributes[:'alert_type'] self.resource_name = attributes[:'resourceName'] if attributes[:'resourceName'] raise 'You cannot provide both :resourceName and :resource_name' if attributes.key?(:'resourceName') && attributes.key?(:'resource_name') self.resource_name = attributes[:'resource_name'] if attributes[:'resource_name'] self.feature_details = attributes[:'featureDetails'] if attributes[:'featureDetails'] raise 'You cannot provide both :featureDetails and :feature_details' if attributes.key?(:'featureDetails') && attributes.key?(:'feature_details') self.feature_details = attributes[:'feature_details'] if attributes[:'feature_details'] self.comment = attributes[:'comment'] if attributes[:'comment'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#alert_type ⇒ String
Type of the alert. Indicates the Data Safe feature triggering the alert.
92 93 94 |
# File 'lib/oci/data_safe/models/alert.rb', line 92 def alert_type @alert_type end |
#comment ⇒ String
A comment for the alert. Entered by the user.
106 107 108 |
# File 'lib/oci/data_safe/models/alert.rb', line 106 def comment @comment end |
#compartment_id ⇒ String
[Required] The OCID of the compartment that contains the alert.
110 111 112 |
# File 'lib/oci/data_safe/models/alert.rb', line 110 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)
Example: ‘{"CostCenter": "42"}`
136 137 138 |
# File 'lib/oci/data_safe/models/alert.rb', line 136 def end |
#description ⇒ String
The description of the alert.
64 65 66 |
# File 'lib/oci/data_safe/models/alert.rb', line 64 def description @description end |
#display_name ⇒ String
[Required] The display name of the alert.
60 61 62 |
# File 'lib/oci/data_safe/models/alert.rb', line 60 def display_name @display_name end |
#feature_details ⇒ Hash<String, Hash<String, Object>>
Map that contains maps of values.
Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`
102 103 104 |
# File 'lib/oci/data_safe/models/alert.rb', line 102 def feature_details @feature_details end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)
Example: ‘"Finance"`
129 130 131 |
# File 'lib/oci/data_safe/models/alert.rb', line 129 def end |
#id ⇒ String
[Required] The OCID of the alert.
48 49 50 |
# File 'lib/oci/data_safe/models/alert.rb', line 48 def id @id end |
#lifecycle_state ⇒ String
[Required] The current state of the alert.
114 115 116 |
# File 'lib/oci/data_safe/models/alert.rb', line 114 def lifecycle_state @lifecycle_state end |
#operation ⇒ String
The operation (event) that triggered alert.
72 73 74 |
# File 'lib/oci/data_safe/models/alert.rb', line 72 def operation @operation end |
#operation_status ⇒ String
The result of the operation (event) that triggered alert.
76 77 78 |
# File 'lib/oci/data_safe/models/alert.rb', line 76 def operation_status @operation_status end |
#operation_time ⇒ DateTime
Creation date and time of the operation that triggered alert, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
68 69 70 |
# File 'lib/oci/data_safe/models/alert.rb', line 68 def operation_time @operation_time end |
#policy_id ⇒ String
The OCID of the policy that triggered alert.
88 89 90 |
# File 'lib/oci/data_safe/models/alert.rb', line 88 def policy_id @policy_id end |
#resource_name ⇒ String
The resource endpoint that triggered the alert.
96 97 98 |
# File 'lib/oci/data_safe/models/alert.rb', line 96 def resource_name @resource_name end |
#severity ⇒ String
Severity level of the alert.
56 57 58 |
# File 'lib/oci/data_safe/models/alert.rb', line 56 def severity @severity end |
#status ⇒ String
The status of the alert.
52 53 54 |
# File 'lib/oci/data_safe/models/alert.rb', line 52 def status @status end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
System tags for this resource. Each key is predefined and scoped to a namespace. For more information, see Resource Tags. Example: ‘{"free-tier-retained": "true"}`
142 143 144 |
# File 'lib/oci/data_safe/models/alert.rb', line 142 def end |
#target_ids ⇒ Array<String>
Array of OCIDs of the target database which are associated with the alert.
80 81 82 |
# File 'lib/oci/data_safe/models/alert.rb', line 80 def target_ids @target_ids end |
#target_names ⇒ Array<String>
Array of names of the target database.
84 85 86 |
# File 'lib/oci/data_safe/models/alert.rb', line 84 def target_names @target_names end |
#time_created ⇒ DateTime
[Required] Creation date and time of the alert, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
118 119 120 |
# File 'lib/oci/data_safe/models/alert.rb', line 118 def time_created @time_created end |
#time_updated ⇒ DateTime
[Required] Last date and time the alert was updated, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
122 123 124 |
# File 'lib/oci/data_safe/models/alert.rb', line 122 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/oci/data_safe/models/alert.rb', line 145 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'status': :'status', 'severity': :'severity', 'display_name': :'displayName', 'description': :'description', 'operation_time': :'operationTime', 'operation': :'operation', 'operation_status': :'operationStatus', 'target_ids': :'targetIds', 'target_names': :'targetNames', 'policy_id': :'policyId', 'alert_type': :'alertType', 'resource_name': :'resourceName', 'feature_details': :'featureDetails', 'comment': :'comment', 'compartment_id': :'compartmentId', 'lifecycle_state': :'lifecycleState', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/oci/data_safe/models/alert.rb', line 175 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'status': :'String', 'severity': :'String', 'display_name': :'String', 'description': :'String', 'operation_time': :'DateTime', 'operation': :'String', 'operation_status': :'String', 'target_ids': :'Array<String>', 'target_names': :'Array<String>', 'policy_id': :'String', 'alert_type': :'String', 'resource_name': :'String', 'feature_details': :'Hash<String, Hash<String, Object>>', 'comment': :'String', 'compartment_id': :'String', 'lifecycle_state': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 |
# File 'lib/oci/data_safe/models/alert.rb', line 419 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && status == other.status && severity == other.severity && display_name == other.display_name && description == other.description && operation_time == other.operation_time && operation == other.operation && operation_status == other.operation_status && target_ids == other.target_ids && target_names == other.target_names && policy_id == other.policy_id && alert_type == other.alert_type && resource_name == other.resource_name && feature_details == other.feature_details && comment == other.comment && compartment_id == other.compartment_id && lifecycle_state == other.lifecycle_state && time_created == other.time_created && time_updated == other.time_updated && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 |
# File 'lib/oci/data_safe/models/alert.rb', line 470 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
450 451 452 |
# File 'lib/oci/data_safe/models/alert.rb', line 450 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
459 460 461 |
# File 'lib/oci/data_safe/models/alert.rb', line 459 def hash [id, status, severity, display_name, description, operation_time, operation, operation_status, target_ids, target_names, policy_id, alert_type, resource_name, feature_details, comment, compartment_id, lifecycle_state, time_created, time_updated, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
503 504 505 506 507 508 509 510 511 512 |
# File 'lib/oci/data_safe/models/alert.rb', line 503 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
497 498 499 |
# File 'lib/oci/data_safe/models/alert.rb', line 497 def to_s to_hash.to_s end |