Class: OCI::DataSafe::Models::AlertPolicy
- Inherits:
-
Object
- Object
- OCI::DataSafe::Models::AlertPolicy
- Defined in:
- lib/oci/data_safe/models/alert_policy.rb
Overview
An Alert Policy is a set of alerting rules evaluated against a target. The alert policy is said to be satisfied when all rules in the policy evaulate to true. If there are three rules: rule1,rule2 and rule3, the policy is satisfied if rule1 AND rule2 AND rule3 is True.
Constant Summary collapse
- ALERT_POLICY_TYPE_ENUM =
[ ALERT_POLICY_TYPE_AUDITING = 'AUDITING'.freeze, ALERT_POLICY_TYPE_SECURITY_ASSESSMENT = 'SECURITY_ASSESSMENT'.freeze, ALERT_POLICY_TYPE_USER_ASSESSMENT = 'USER_ASSESSMENT'.freeze, ALERT_POLICY_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- SEVERITY_ENUM =
[ SEVERITY_CRITICAL = 'CRITICAL'.freeze, SEVERITY_HIGH = 'HIGH'.freeze, SEVERITY_MEDIUM = 'MEDIUM'.freeze, SEVERITY_LOW = 'LOW'.freeze, SEVERITY_EVALUATE = 'EVALUATE'.freeze, SEVERITY_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#alert_policy_type ⇒ String
Indicates the Data Safe feature to which the alert policy belongs.
-
#compartment_id ⇒ String
[Required] The OCID of the compartment that contains the alert policy.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
The description of the alert policy.
-
#display_name ⇒ String
[Required] The display name of the alert policy.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] The OCID of the alert policy.
-
#is_user_defined ⇒ BOOLEAN
Indicates if the alert policy is user-defined (true) or pre-defined (false).
-
#lifecycle_state ⇒ String
[Required] The current state of the alert.
-
#severity ⇒ String
Severity level of the alert raised by this policy.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
System tags for this resource.
-
#time_created ⇒ DateTime
[Required] Creation date and time of the alert policy, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#time_updated ⇒ DateTime
[Required] Last date and time the alert policy was updated, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AlertPolicy
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ AlertPolicy
Initializes the object
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/oci/data_safe/models/alert_policy.rb', line 161 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.alert_policy_type = attributes[:'alertPolicyType'] if attributes[:'alertPolicyType'] raise 'You cannot provide both :alertPolicyType and :alert_policy_type' if attributes.key?(:'alertPolicyType') && attributes.key?(:'alert_policy_type') self.alert_policy_type = attributes[:'alert_policy_type'] if attributes[:'alert_policy_type'] self.is_user_defined = attributes[:'isUserDefined'] unless attributes[:'isUserDefined'].nil? raise 'You cannot provide both :isUserDefined and :is_user_defined' if attributes.key?(:'isUserDefined') && attributes.key?(:'is_user_defined') self.is_user_defined = attributes[:'is_user_defined'] unless attributes[:'is_user_defined'].nil? self.severity = attributes[:'severity'] if attributes[:'severity'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#alert_policy_type ⇒ String
Indicates the Data Safe feature to which the alert policy belongs.
54 55 56 |
# File 'lib/oci/data_safe/models/alert_policy.rb', line 54 def alert_policy_type @alert_policy_type end |
#compartment_id ⇒ String
[Required] The OCID of the compartment that contains the alert policy.
66 67 68 |
# File 'lib/oci/data_safe/models/alert_policy.rb', line 66 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)
Example: ‘{"CostCenter": "42"}`
92 93 94 |
# File 'lib/oci/data_safe/models/alert_policy.rb', line 92 def @defined_tags end |
#description ⇒ String
The description of the alert policy.
50 51 52 |
# File 'lib/oci/data_safe/models/alert_policy.rb', line 50 def description @description end |
#display_name ⇒ String
[Required] The display name of the alert policy.
46 47 48 |
# File 'lib/oci/data_safe/models/alert_policy.rb', line 46 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)
Example: ‘"Finance"`
85 86 87 |
# File 'lib/oci/data_safe/models/alert_policy.rb', line 85 def @freeform_tags end |
#id ⇒ String
[Required] The OCID of the alert policy.
42 43 44 |
# File 'lib/oci/data_safe/models/alert_policy.rb', line 42 def id @id end |
#is_user_defined ⇒ BOOLEAN
Indicates if the alert policy is user-defined (true) or pre-defined (false).
58 59 60 |
# File 'lib/oci/data_safe/models/alert_policy.rb', line 58 def is_user_defined @is_user_defined end |
#lifecycle_state ⇒ String
[Required] The current state of the alert.
78 79 80 |
# File 'lib/oci/data_safe/models/alert_policy.rb', line 78 def lifecycle_state @lifecycle_state end |
#severity ⇒ String
Severity level of the alert raised by this policy.
62 63 64 |
# File 'lib/oci/data_safe/models/alert_policy.rb', line 62 def severity @severity end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
System tags for this resource. Each key is predefined and scoped to a namespace. For more information, see Resource Tags. Example: ‘{"free-tier-retained": "true"}`
98 99 100 |
# File 'lib/oci/data_safe/models/alert_policy.rb', line 98 def @system_tags end |
#time_created ⇒ DateTime
[Required] Creation date and time of the alert policy, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
70 71 72 |
# File 'lib/oci/data_safe/models/alert_policy.rb', line 70 def time_created @time_created end |
#time_updated ⇒ DateTime
[Required] Last date and time the alert policy was updated, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
74 75 76 |
# File 'lib/oci/data_safe/models/alert_policy.rb', line 74 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/oci/data_safe/models/alert_policy.rb', line 101 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'description': :'description', 'alert_policy_type': :'alertPolicyType', 'is_user_defined': :'isUserDefined', 'severity': :'severity', 'compartment_id': :'compartmentId', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/oci/data_safe/models/alert_policy.rb', line 122 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'description': :'String', 'alert_policy_type': :'String', 'is_user_defined': :'BOOLEAN', 'severity': :'String', 'compartment_id': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/oci/data_safe/models/alert_policy.rb', line 280 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && description == other.description && alert_policy_type == other.alert_policy_type && is_user_defined == other.is_user_defined && severity == other.severity && compartment_id == other.compartment_id && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 |
# File 'lib/oci/data_safe/models/alert_policy.rb', line 322 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
302 303 304 |
# File 'lib/oci/data_safe/models/alert_policy.rb', line 302 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
311 312 313 |
# File 'lib/oci/data_safe/models/alert_policy.rb', line 311 def hash [id, display_name, description, alert_policy_type, is_user_defined, severity, compartment_id, time_created, time_updated, lifecycle_state, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
355 356 357 358 359 360 361 362 363 364 |
# File 'lib/oci/data_safe/models/alert_policy.rb', line 355 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
349 350 351 |
# File 'lib/oci/data_safe/models/alert_policy.rb', line 349 def to_s to_hash.to_s end |