Class: OCI::DataSafe::Models::AuditArchiveRetrieval

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_safe/models/audit_archive_retrieval.rb

Overview

Represents the archive retrieve request for the audit data. You can retrieve audit data for a target database from the archive and store it online. For more information, see [Retrieve Audit Data for a Target Database from the Archive](docs.oracle.com/en/cloud/paas/data-safe/udscs/security-assessment-overview.html).

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_NEEDS_ATTENTION = 'NEEDS_ATTENTION'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ AuditArchiveRetrieval

Initializes the object

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :display_name (String)

    The value to assign to the #display_name property

  • :description (String)

    The value to assign to the #description property

  • :start_date (DateTime)

    The value to assign to the #start_date property

  • :end_date (DateTime)

    The value to assign to the #end_date property

  • :target_id (String)

    The value to assign to the #target_id property

  • :time_requested (DateTime)

    The value to assign to the #time_requested property

  • :time_completed (DateTime)

    The value to assign to the #time_completed property

  • :time_of_expiry (DateTime)

    The value to assign to the #time_of_expiry property

  • :audit_event_count (Integer)

    The value to assign to the #audit_event_count property

  • :error_info (String)

    The value to assign to the #error_info property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :lifecycle_details (String)

    The value to assign to the #lifecycle_details property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property

  • :system_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #system_tags property



172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/oci/data_safe/models/audit_archive_retrieval.rb', line 172

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.start_date = attributes[:'startDate'] if attributes[:'startDate']

  raise 'You cannot provide both :startDate and :start_date' if attributes.key?(:'startDate') && attributes.key?(:'start_date')

  self.start_date = attributes[:'start_date'] if attributes[:'start_date']

  self.end_date = attributes[:'endDate'] if attributes[:'endDate']

  raise 'You cannot provide both :endDate and :end_date' if attributes.key?(:'endDate') && attributes.key?(:'end_date')

  self.end_date = attributes[:'end_date'] if attributes[:'end_date']

  self.target_id = attributes[:'targetId'] if attributes[:'targetId']

  raise 'You cannot provide both :targetId and :target_id' if attributes.key?(:'targetId') && attributes.key?(:'target_id')

  self.target_id = attributes[:'target_id'] if attributes[:'target_id']

  self.time_requested = attributes[:'timeRequested'] if attributes[:'timeRequested']

  raise 'You cannot provide both :timeRequested and :time_requested' if attributes.key?(:'timeRequested') && attributes.key?(:'time_requested')

  self.time_requested = attributes[:'time_requested'] if attributes[:'time_requested']

  self.time_completed = attributes[:'timeCompleted'] if attributes[:'timeCompleted']

  raise 'You cannot provide both :timeCompleted and :time_completed' if attributes.key?(:'timeCompleted') && attributes.key?(:'time_completed')

  self.time_completed = attributes[:'time_completed'] if attributes[:'time_completed']

  self.time_of_expiry = attributes[:'timeOfExpiry'] if attributes[:'timeOfExpiry']

  raise 'You cannot provide both :timeOfExpiry and :time_of_expiry' if attributes.key?(:'timeOfExpiry') && attributes.key?(:'time_of_expiry')

  self.time_of_expiry = attributes[:'time_of_expiry'] if attributes[:'time_of_expiry']

  self.audit_event_count = attributes[:'auditEventCount'] if attributes[:'auditEventCount']

  raise 'You cannot provide both :auditEventCount and :audit_event_count' if attributes.key?(:'auditEventCount') && attributes.key?(:'audit_event_count')

  self.audit_event_count = attributes[:'audit_event_count'] if attributes[:'audit_event_count']

  self.error_info = attributes[:'errorInfo'] if attributes[:'errorInfo']

  raise 'You cannot provide both :errorInfo and :error_info' if attributes.key?(:'errorInfo') && attributes.key?(:'error_info')

  self.error_info = attributes[:'error_info'] if attributes[:'error_info']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

  raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

  self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']
end

Instance Attribute Details

#audit_event_countInteger

Total count of audit events to be retrieved from the archive for the specified date range.



65
66
67
# File 'lib/oci/data_safe/models/audit_archive_retrieval.rb', line 65

def audit_event_count
  @audit_event_count
end

#compartment_idString

[Required] The OCID of the compartment that contains archive retrieval.



29
30
31
# File 'lib/oci/data_safe/models/audit_archive_retrieval.rb', line 29

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)

Example: ‘{\“CostCenter\”: \“42\”}`



91
92
93
# File 'lib/oci/data_safe/models/audit_archive_retrieval.rb', line 91

def defined_tags
  @defined_tags
end

#descriptionString

Description of the archive retrieval.



37
38
39
# File 'lib/oci/data_safe/models/audit_archive_retrieval.rb', line 37

def description
  @description
end

#display_nameString

[Required] The display name of the archive retrieval. The name does not have to be unique, and is changeable.



33
34
35
# File 'lib/oci/data_safe/models/audit_archive_retrieval.rb', line 33

def display_name
  @display_name
end

#end_dateDateTime

[Required] End month of the archive retrieval, in the format defined by RFC3339.



45
46
47
# File 'lib/oci/data_safe/models/audit_archive_retrieval.rb', line 45

def end_date
  @end_date
end

#error_infoString

The Error details of a failed archive retrieval.



69
70
71
# File 'lib/oci/data_safe/models/audit_archive_retrieval.rb', line 69

def error_info
  @error_info
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)

Example: ‘\“Finance\”`



84
85
86
# File 'lib/oci/data_safe/models/audit_archive_retrieval.rb', line 84

def freeform_tags
  @freeform_tags
end

#idString

[Required] The OCID of the archive retrieval.



25
26
27
# File 'lib/oci/data_safe/models/audit_archive_retrieval.rb', line 25

def id
  @id
end

#lifecycle_detailsString

Details about the current state of the archive retrieval.



77
78
79
# File 'lib/oci/data_safe/models/audit_archive_retrieval.rb', line 77

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

[Required] The current state of the archive retrieval.



73
74
75
# File 'lib/oci/data_safe/models/audit_archive_retrieval.rb', line 73

def lifecycle_state
  @lifecycle_state
end

#start_dateDateTime

[Required] Start month of the archive retrieval, in the format defined by RFC3339.



41
42
43
# File 'lib/oci/data_safe/models/audit_archive_retrieval.rb', line 41

def start_date
  @start_date
end

#system_tagsHash<String, Hash<String, Object>>

System tags for this resource. Each key is predefined and scoped to a namespace. For more information, see Resource Tags. Example: ‘{\“free-tier-retained\”: \“true\”}`



97
98
99
# File 'lib/oci/data_safe/models/audit_archive_retrieval.rb', line 97

def system_tags
  @system_tags
end

#target_idString

[Required] The OCID of the target associated with the archive retrieval.



49
50
51
# File 'lib/oci/data_safe/models/audit_archive_retrieval.rb', line 49

def target_id
  @target_id
end

#time_completedDateTime

The date time when archive retrieval request was fulfilled, in the format defined by RFC3339.



57
58
59
# File 'lib/oci/data_safe/models/audit_archive_retrieval.rb', line 57

def time_completed
  @time_completed
end

#time_of_expiryDateTime

The date time when retrieved archive data will be deleted from Data Safe and unloaded back into archival.



61
62
63
# File 'lib/oci/data_safe/models/audit_archive_retrieval.rb', line 61

def time_of_expiry
  @time_of_expiry
end

#time_requestedDateTime

The date time when archive retrieval was requested, in the format defined by RFC3339.



53
54
55
# File 'lib/oci/data_safe/models/audit_archive_retrieval.rb', line 53

def time_requested
  @time_requested
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/oci/data_safe/models/audit_archive_retrieval.rb', line 100

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'compartment_id': :'compartmentId',
    'display_name': :'displayName',
    'description': :'description',
    'start_date': :'startDate',
    'end_date': :'endDate',
    'target_id': :'targetId',
    'time_requested': :'timeRequested',
    'time_completed': :'timeCompleted',
    'time_of_expiry': :'timeOfExpiry',
    'audit_event_count': :'auditEventCount',
    'error_info': :'errorInfo',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/oci/data_safe/models/audit_archive_retrieval.rb', line 125

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'compartment_id': :'String',
    'display_name': :'String',
    'description': :'String',
    'start_date': :'DateTime',
    'end_date': :'DateTime',
    'target_id': :'String',
    'time_requested': :'DateTime',
    'time_completed': :'DateTime',
    'time_of_expiry': :'DateTime',
    'audit_event_count': :'Integer',
    'error_info': :'String',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.



293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/oci/data_safe/models/audit_archive_retrieval.rb', line 293

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    display_name == other.display_name &&
    description == other.description &&
    start_date == other.start_date &&
    end_date == other.end_date &&
    target_id == other.target_id &&
    time_requested == other.time_requested &&
    time_completed == other.time_completed &&
    time_of_expiry == other.time_of_expiry &&
    audit_event_count == other.audit_event_count &&
    error_info == other.error_info &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
# File 'lib/oci/data_safe/models/audit_archive_retrieval.rb', line 339

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method


319
320
321
# File 'lib/oci/data_safe/models/audit_archive_retrieval.rb', line 319

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.



328
329
330
# File 'lib/oci/data_safe/models/audit_archive_retrieval.rb', line 328

def hash
  [id, compartment_id, display_name, description, start_date, end_date, target_id, time_requested, time_completed, time_of_expiry, audit_event_count, error_info, lifecycle_state, lifecycle_details, freeform_tags, defined_tags, system_tags].hash
end

#to_hashHash

Returns the object in the form of hash



372
373
374
375
376
377
378
379
380
381
# File 'lib/oci/data_safe/models/audit_archive_retrieval.rb', line 372

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



366
367
368
# File 'lib/oci/data_safe/models/audit_archive_retrieval.rb', line 366

def to_s
  to_hash.to_s
end