Class: OCI::DataSafe::Models::AuditEventAggregationDimensions

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_safe/models/audit_event_aggregation_dimensions.rb

Overview

Details of aggregation dimensions used for summarizing audit events.

Constant Summary collapse

TARGET_CLASS_ENUM =
[
  TARGET_CLASS_DATABASE = 'DATABASE'.freeze,
  TARGET_CLASS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
AUDIT_TYPE_ENUM =
[
  AUDIT_TYPE_STANDARD = 'STANDARD'.freeze,
  AUDIT_TYPE_FINE_GRAINED = 'FINE_GRAINED'.freeze,
  AUDIT_TYPE_XS = 'XS'.freeze,
  AUDIT_TYPE_DATABASE_VAULT = 'DATABASE_VAULT'.freeze,
  AUDIT_TYPE_LABEL_SECURITY = 'LABEL_SECURITY'.freeze,
  AUDIT_TYPE_RMAN = 'RMAN'.freeze,
  AUDIT_TYPE_DATAPUMP = 'DATAPUMP'.freeze,
  AUDIT_TYPE_DIRECT_PATH_API = 'DIRECT_PATH_API'.freeze,
  AUDIT_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ AuditEventAggregationDimensions

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :audit_event_time (Array<DateTime>)

    The value to assign to the #audit_event_time property

  • :db_user_name (Array<String>)

    The value to assign to the #db_user_name property

  • :target_id (Array<String>)

    The value to assign to the #target_id property

  • :target_name (Array<String>)

    The value to assign to the #target_name property

  • :target_class (Array<String>)

    The value to assign to the #target_class property

  • :object_type (Array<String>)

    The value to assign to the #object_type property

  • :client_hostname (Array<String>)

    The value to assign to the #client_hostname property

  • :client_program (Array<String>)

    The value to assign to the #client_program property

  • :client_id (Array<String>)

    The value to assign to the #client_id property

  • :audit_type (Array<String>)

    The value to assign to the #audit_type property

  • :event_name (Array<String>)

    The value to assign to the #event_name property



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/oci/data_safe/models/audit_event_aggregation_dimensions.rb', line 127

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.audit_event_time = attributes[:'auditEventTime'] if attributes[:'auditEventTime']

  raise 'You cannot provide both :auditEventTime and :audit_event_time' if attributes.key?(:'auditEventTime') && attributes.key?(:'audit_event_time')

  self.audit_event_time = attributes[:'audit_event_time'] if attributes[:'audit_event_time']

  self.db_user_name = attributes[:'dbUserName'] if attributes[:'dbUserName']

  raise 'You cannot provide both :dbUserName and :db_user_name' if attributes.key?(:'dbUserName') && attributes.key?(:'db_user_name')

  self.db_user_name = attributes[:'db_user_name'] if attributes[:'db_user_name']

  self.target_id = attributes[:'targetId'] if attributes[:'targetId']

  raise 'You cannot provide both :targetId and :target_id' if attributes.key?(:'targetId') && attributes.key?(:'target_id')

  self.target_id = attributes[:'target_id'] if attributes[:'target_id']

  self.target_name = attributes[:'targetName'] if attributes[:'targetName']

  raise 'You cannot provide both :targetName and :target_name' if attributes.key?(:'targetName') && attributes.key?(:'target_name')

  self.target_name = attributes[:'target_name'] if attributes[:'target_name']

  self.target_class = attributes[:'targetClass'] if attributes[:'targetClass']

  raise 'You cannot provide both :targetClass and :target_class' if attributes.key?(:'targetClass') && attributes.key?(:'target_class')

  self.target_class = attributes[:'target_class'] if attributes[:'target_class']

  self.object_type = attributes[:'objectType'] if attributes[:'objectType']

  raise 'You cannot provide both :objectType and :object_type' if attributes.key?(:'objectType') && attributes.key?(:'object_type')

  self.object_type = attributes[:'object_type'] if attributes[:'object_type']

  self.client_hostname = attributes[:'clientHostname'] if attributes[:'clientHostname']

  raise 'You cannot provide both :clientHostname and :client_hostname' if attributes.key?(:'clientHostname') && attributes.key?(:'client_hostname')

  self.client_hostname = attributes[:'client_hostname'] if attributes[:'client_hostname']

  self.client_program = attributes[:'clientProgram'] if attributes[:'clientProgram']

  raise 'You cannot provide both :clientProgram and :client_program' if attributes.key?(:'clientProgram') && attributes.key?(:'client_program')

  self.client_program = attributes[:'client_program'] if attributes[:'client_program']

  self.client_id = attributes[:'clientId'] if attributes[:'clientId']

  raise 'You cannot provide both :clientId and :client_id' if attributes.key?(:'clientId') && attributes.key?(:'client_id')

  self.client_id = attributes[:'client_id'] if attributes[:'client_id']

  self.audit_type = attributes[:'auditType'] if attributes[:'auditType']

  raise 'You cannot provide both :auditType and :audit_type' if attributes.key?(:'auditType') && attributes.key?(:'audit_type')

  self.audit_type = attributes[:'audit_type'] if attributes[:'audit_type']

  self.event_name = attributes[:'eventName'] if attributes[:'eventName']

  raise 'You cannot provide both :eventName and :event_name' if attributes.key?(:'eventName') && attributes.key?(:'event_name')

  self.event_name = attributes[:'event_name'] if attributes[:'event_name']
end

Instance Attribute Details

#audit_event_timeArray<DateTime>

Time of audit event occurrence in the target database.

Returns:

  • (Array<DateTime>)


30
31
32
# File 'lib/oci/data_safe/models/audit_event_aggregation_dimensions.rb', line 30

def audit_event_time
  @audit_event_time
end

#audit_typeArray<String>

Type of auditing.

Returns:

  • (Array<String>)


66
67
68
# File 'lib/oci/data_safe/models/audit_event_aggregation_dimensions.rb', line 66

def audit_type
  @audit_type
end

#client_hostnameArray<String>

Name of the host machine from which the session was spawned.

Returns:

  • (Array<String>)


54
55
56
# File 'lib/oci/data_safe/models/audit_event_aggregation_dimensions.rb', line 54

def client_hostname
  @client_hostname
end

#client_idArray<String>

The client identifier in each Oracle session.

Returns:

  • (Array<String>)


62
63
64
# File 'lib/oci/data_safe/models/audit_event_aggregation_dimensions.rb', line 62

def client_id
  @client_id
end

#client_programArray<String>

The application from which the audit event was generated. Examples SQL Plus or SQL Developer.

Returns:

  • (Array<String>)


58
59
60
# File 'lib/oci/data_safe/models/audit_event_aggregation_dimensions.rb', line 58

def client_program
  @client_program
end

#db_user_nameArray<String>

Name of the database user whose actions were audited.

Returns:

  • (Array<String>)


34
35
36
# File 'lib/oci/data_safe/models/audit_event_aggregation_dimensions.rb', line 34

def db_user_name
  @db_user_name
end

#event_nameArray<String>

Name of the detail action executed by the user on the target database. i.e ALTER SEQUENCE, CREATE TRIGGER, CREATE INDEX.

Returns:

  • (Array<String>)


70
71
72
# File 'lib/oci/data_safe/models/audit_event_aggregation_dimensions.rb', line 70

def event_name
  @event_name
end

#object_typeArray<String>

Type of object in the source database affected by the action. i.e PL/SQL, SYNONYM, PACKAGE BODY.

Returns:

  • (Array<String>)


50
51
52
# File 'lib/oci/data_safe/models/audit_event_aggregation_dimensions.rb', line 50

def object_type
  @object_type
end

#target_classArray<String>

Class of the target that was audited.

Returns:

  • (Array<String>)


46
47
48
# File 'lib/oci/data_safe/models/audit_event_aggregation_dimensions.rb', line 46

def target_class
  @target_class
end

#target_idArray<String>

The OCID of the target database that was audited.

Returns:

  • (Array<String>)


38
39
40
# File 'lib/oci/data_safe/models/audit_event_aggregation_dimensions.rb', line 38

def target_id
  @target_id
end

#target_nameArray<String>

The name of the target database that was audited.

Returns:

  • (Array<String>)


42
43
44
# File 'lib/oci/data_safe/models/audit_event_aggregation_dimensions.rb', line 42

def target_name
  @target_name
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/oci/data_safe/models/audit_event_aggregation_dimensions.rb', line 73

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'audit_event_time': :'auditEventTime',
    'db_user_name': :'dbUserName',
    'target_id': :'targetId',
    'target_name': :'targetName',
    'target_class': :'targetClass',
    'object_type': :'objectType',
    'client_hostname': :'clientHostname',
    'client_program': :'clientProgram',
    'client_id': :'clientId',
    'audit_type': :'auditType',
    'event_name': :'eventName'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/oci/data_safe/models/audit_event_aggregation_dimensions.rb', line 92

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'audit_event_time': :'Array<DateTime>',
    'db_user_name': :'Array<String>',
    'target_id': :'Array<String>',
    'target_name': :'Array<String>',
    'target_class': :'Array<String>',
    'object_type': :'Array<String>',
    'client_hostname': :'Array<String>',
    'client_program': :'Array<String>',
    'client_id': :'Array<String>',
    'audit_type': :'Array<String>',
    'event_name': :'Array<String>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
# File 'lib/oci/data_safe/models/audit_event_aggregation_dimensions.rb', line 247

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    audit_event_time == other.audit_event_time &&
    db_user_name == other.db_user_name &&
    target_id == other.target_id &&
    target_name == other.target_name &&
    target_class == other.target_class &&
    object_type == other.object_type &&
    client_hostname == other.client_hostname &&
    client_program == other.client_program &&
    client_id == other.client_id &&
    audit_type == other.audit_type &&
    event_name == other.event_name
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
# File 'lib/oci/data_safe/models/audit_event_aggregation_dimensions.rb', line 287

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


267
268
269
# File 'lib/oci/data_safe/models/audit_event_aggregation_dimensions.rb', line 267

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



276
277
278
# File 'lib/oci/data_safe/models/audit_event_aggregation_dimensions.rb', line 276

def hash
  [audit_event_time, db_user_name, target_id, target_name, target_class, object_type, client_hostname, client_program, client_id, audit_type, event_name].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



320
321
322
323
324
325
326
327
328
329
# File 'lib/oci/data_safe/models/audit_event_aggregation_dimensions.rb', line 320

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



314
315
316
# File 'lib/oci/data_safe/models/audit_event_aggregation_dimensions.rb', line 314

def to_s
  to_hash.to_s
end