Class: OCI::DataSafe::Models::AuditTrailSummary
- Inherits:
-
Object
- Object
- OCI::DataSafe::Models::AuditTrailSummary
- Defined in:
- lib/oci/data_safe/models/audit_trail_summary.rb
Overview
Summary of an audit trail.
Constant Summary collapse
- STATUS_ENUM =
[ STATUS_STARTING = 'STARTING'.freeze, STATUS_COLLECTING = 'COLLECTING'.freeze, STATUS_RECOVERING = 'RECOVERING'.freeze, STATUS_IDLE = 'IDLE'.freeze, STATUS_STOPPING = 'STOPPING'.freeze, STATUS_STOPPED = 'STOPPED'.freeze, STATUS_RESUMING = 'RESUMING'.freeze, STATUS_RETRYING = 'RETRYING'.freeze, STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_NEEDS_ATTENTION = 'NEEDS_ATTENTION'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#audit_collection_start_time ⇒ DateTime
The date from which the audit trail must start collecting data, in the format defined by RFC3339.
-
#audit_profile_id ⇒ String
**[Required]** The OCID of the parent audit.
-
#compartment_id ⇒ String
**[Required]** The OCID of the compartment that contains the audit.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
The description of audit trail.
-
#display_name ⇒ String
**[Required]** The display name of the audit trail.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
**[Required]** The OCID of the audit trail.
-
#is_auto_purge_enabled ⇒ BOOLEAN
Indicates if auto purge is enabled on the target database, which helps delete audit data in the target database every seven days so that the database's audit trail does not become too large.
-
#lifecycle_details ⇒ String
Details about the current state of the audit trail in Data Safe.
-
#lifecycle_state ⇒ String
**[Required]** The current state of the audit trail.
-
#status ⇒ String
**[Required]** The current sub-state of the audit trail.
-
#target_id ⇒ String
**[Required]** The OCID of the Data Safe target for which the audit trail is created.
-
#time_created ⇒ DateTime
**[Required]** The date and time the audit trail was created, in the format defined by RFC3339.
-
#time_updated ⇒ DateTime
**[Required]** The date and time the audit trail was updated, in the format defined by RFC3339.
-
#trail_location ⇒ String
An audit trail location represents the source of audit records that provides documentary evidence of the sequence of activities in the target database.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AuditTrailSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ AuditTrailSummary
Initializes the object
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/oci/data_safe/models/audit_trail_summary.rb', line 175 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.audit_profile_id = attributes[:'auditProfileId'] if attributes[:'auditProfileId'] raise 'You cannot provide both :auditProfileId and :audit_profile_id' if attributes.key?(:'auditProfileId') && attributes.key?(:'audit_profile_id') self.audit_profile_id = attributes[:'audit_profile_id'] if attributes[:'audit_profile_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.status = attributes[:'status'] if attributes[:'status'] self.description = attributes[:'description'] if attributes[:'description'] self.trail_location = attributes[:'trailLocation'] if attributes[:'trailLocation'] raise 'You cannot provide both :trailLocation and :trail_location' if attributes.key?(:'trailLocation') && attributes.key?(:'trail_location') self.trail_location = attributes[:'trail_location'] if attributes[:'trail_location'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.target_id = attributes[:'targetId'] if attributes[:'targetId'] raise 'You cannot provide both :targetId and :target_id' if attributes.key?(:'targetId') && attributes.key?(:'target_id') self.target_id = attributes[:'target_id'] if attributes[:'target_id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.is_auto_purge_enabled = attributes[:'isAutoPurgeEnabled'] unless attributes[:'isAutoPurgeEnabled'].nil? self.is_auto_purge_enabled = false if is_auto_purge_enabled.nil? && !attributes.key?(:'isAutoPurgeEnabled') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isAutoPurgeEnabled and :is_auto_purge_enabled' if attributes.key?(:'isAutoPurgeEnabled') && attributes.key?(:'is_auto_purge_enabled') self.is_auto_purge_enabled = attributes[:'is_auto_purge_enabled'] unless attributes[:'is_auto_purge_enabled'].nil? self.is_auto_purge_enabled = false if is_auto_purge_enabled.nil? && !attributes.key?(:'isAutoPurgeEnabled') && !attributes.key?(:'is_auto_purge_enabled') # rubocop:disable Style/StringLiterals self.audit_collection_start_time = attributes[:'auditCollectionStartTime'] if attributes[:'auditCollectionStartTime'] raise 'You cannot provide both :auditCollectionStartTime and :audit_collection_start_time' if attributes.key?(:'auditCollectionStartTime') && attributes.key?(:'audit_collection_start_time') self.audit_collection_start_time = attributes[:'audit_collection_start_time'] if attributes[:'audit_collection_start_time'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#audit_collection_start_time ⇒ DateTime
The date from which the audit trail must start collecting data, in the format defined by RFC3339.
89 90 91 |
# File 'lib/oci/data_safe/models/audit_trail_summary.rb', line 89 def audit_collection_start_time @audit_collection_start_time end |
#audit_profile_id ⇒ String
**[Required]** The OCID of the parent audit.
39 40 41 |
# File 'lib/oci/data_safe/models/audit_trail_summary.rb', line 39 def audit_profile_id @audit_profile_id end |
#compartment_id ⇒ String
**[Required]** The OCID of the compartment that contains the audit.
67 68 69 |
# File 'lib/oci/data_safe/models/audit_trail_summary.rb', line 67 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)
Example: `{"CostCenter": "42"}`
103 104 105 |
# File 'lib/oci/data_safe/models/audit_trail_summary.rb', line 103 def @defined_tags end |
#description ⇒ String
The description of audit trail.
59 60 61 |
# File 'lib/oci/data_safe/models/audit_trail_summary.rb', line 59 def description @description end |
#display_name ⇒ String
**[Required]** The display name of the audit trail.
43 44 45 |
# File 'lib/oci/data_safe/models/audit_trail_summary.rb', line 43 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)
Example: `"Finance"`
96 97 98 |
# File 'lib/oci/data_safe/models/audit_trail_summary.rb', line 96 def @freeform_tags end |
#id ⇒ String
**[Required]** The OCID of the audit trail.
35 36 37 |
# File 'lib/oci/data_safe/models/audit_trail_summary.rb', line 35 def id @id end |
#is_auto_purge_enabled ⇒ BOOLEAN
Indicates if auto purge is enabled on the target database, which helps delete audit data in the target database every seven days so that the database's audit trail does not become too large.
85 86 87 |
# File 'lib/oci/data_safe/models/audit_trail_summary.rb', line 85 def is_auto_purge_enabled @is_auto_purge_enabled end |
#lifecycle_details ⇒ String
Details about the current state of the audit trail in Data Safe.
79 80 81 |
# File 'lib/oci/data_safe/models/audit_trail_summary.rb', line 79 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
**[Required]** The current state of the audit trail.
75 76 77 |
# File 'lib/oci/data_safe/models/audit_trail_summary.rb', line 75 def lifecycle_state @lifecycle_state end |
#status ⇒ String
**[Required]** The current sub-state of the audit trail.
55 56 57 |
# File 'lib/oci/data_safe/models/audit_trail_summary.rb', line 55 def status @status end |
#target_id ⇒ String
**[Required]** The OCID of the Data Safe target for which the audit trail is created.
71 72 73 |
# File 'lib/oci/data_safe/models/audit_trail_summary.rb', line 71 def target_id @target_id end |
#time_created ⇒ DateTime
**[Required]** The date and time the audit trail was created, in the format defined by RFC3339.
47 48 49 |
# File 'lib/oci/data_safe/models/audit_trail_summary.rb', line 47 def time_created @time_created end |
#time_updated ⇒ DateTime
**[Required]** The date and time the audit trail was updated, in the format defined by RFC3339.
51 52 53 |
# File 'lib/oci/data_safe/models/audit_trail_summary.rb', line 51 def time_updated @time_updated end |
#trail_location ⇒ String
An audit trail location represents the source of audit records that provides documentary evidence of the sequence of activities in the target database.
63 64 65 |
# File 'lib/oci/data_safe/models/audit_trail_summary.rb', line 63 def trail_location @trail_location end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/oci/data_safe/models/audit_trail_summary.rb', line 106 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'audit_profile_id': :'auditProfileId', 'display_name': :'displayName', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'status': :'status', 'description': :'description', 'trail_location': :'trailLocation', 'compartment_id': :'compartmentId', 'target_id': :'targetId', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'is_auto_purge_enabled': :'isAutoPurgeEnabled', 'audit_collection_start_time': :'auditCollectionStartTime', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/oci/data_safe/models/audit_trail_summary.rb', line 130 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'audit_profile_id': :'String', 'display_name': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'status': :'String', 'description': :'String', 'trail_location': :'String', 'compartment_id': :'String', 'target_id': :'String', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'is_auto_purge_enabled': :'BOOLEAN', 'audit_collection_start_time': :'DateTime', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/oci/data_safe/models/audit_trail_summary.rb', line 301 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && audit_profile_id == other.audit_profile_id && display_name == other.display_name && time_created == other.time_created && time_updated == other.time_updated && status == other.status && description == other.description && trail_location == other.trail_location && compartment_id == other.compartment_id && target_id == other.target_id && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && is_auto_purge_enabled == other.is_auto_purge_enabled && audit_collection_start_time == other.audit_collection_start_time && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 |
# File 'lib/oci/data_safe/models/audit_trail_summary.rb', line 346 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
326 327 328 |
# File 'lib/oci/data_safe/models/audit_trail_summary.rb', line 326 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
335 336 337 |
# File 'lib/oci/data_safe/models/audit_trail_summary.rb', line 335 def hash [id, audit_profile_id, display_name, time_created, time_updated, status, description, trail_location, compartment_id, target_id, lifecycle_state, lifecycle_details, is_auto_purge_enabled, audit_collection_start_time, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
379 380 381 382 383 384 385 386 387 388 |
# File 'lib/oci/data_safe/models/audit_trail_summary.rb', line 379 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
373 374 375 |
# File 'lib/oci/data_safe/models/audit_trail_summary.rb', line 373 def to_s to_hash.to_s end |