Class: OCI::DataSafe::Models::ColumnFilter
- Inherits:
-
Object
- Object
- OCI::DataSafe::Models::ColumnFilter
- Defined in:
- lib/oci/data_safe/models/column_filter.rb
Overview
Filters that are applied to the data at the column level.
Constant Summary collapse
- OPERATOR_ENUM =
[ OPERATOR_IN = 'IN'.freeze, OPERATOR_EQ = 'EQ'.freeze, OPERATOR_GT = 'GT'.freeze, OPERATOR_GE = 'GE'.freeze, OPERATOR_LT = 'LT'.freeze, OPERATOR_LE = 'LE'.freeze, OPERATOR_AND = 'AND'.freeze, OPERATOR_OR = 'OR'.freeze, OPERATOR_NE = 'NE'.freeze, OPERATOR_CO = 'CO'.freeze, OPERATOR_NOT = 'NOT'.freeze, OPERATOR_NOT_IN = 'NOT_IN'.freeze, OPERATOR_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#expressions ⇒ Array<String>
[Required] An array of expressions based on the operator type.
-
#field_name ⇒ String
[Required] Name of the column on which the filter must be applied.
-
#is_enabled ⇒ BOOLEAN
[Required] Indicates if the filter is enabled.
-
#is_hidden ⇒ BOOLEAN
[Required] Indicates if the filter is hidden.
-
#operator ⇒ String
[Required] Specifies the type of operator that must be applied for example in, eq etc.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ColumnFilter
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ColumnFilter
Initializes the object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/oci/data_safe/models/column_filter.rb', line 84 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.field_name = attributes[:'fieldName'] if attributes[:'fieldName'] raise 'You cannot provide both :fieldName and :field_name' if attributes.key?(:'fieldName') && attributes.key?(:'field_name') self.field_name = attributes[:'field_name'] if attributes[:'field_name'] self.operator = attributes[:'operator'] if attributes[:'operator'] self.expressions = attributes[:'expressions'] if attributes[:'expressions'] self.is_enabled = attributes[:'isEnabled'] unless attributes[:'isEnabled'].nil? raise 'You cannot provide both :isEnabled and :is_enabled' if attributes.key?(:'isEnabled') && attributes.key?(:'is_enabled') self.is_enabled = attributes[:'is_enabled'] unless attributes[:'is_enabled'].nil? self.is_hidden = attributes[:'isHidden'] unless attributes[:'isHidden'].nil? self.is_hidden = true if is_hidden.nil? && !attributes.key?(:'isHidden') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isHidden and :is_hidden' if attributes.key?(:'isHidden') && attributes.key?(:'is_hidden') self.is_hidden = attributes[:'is_hidden'] unless attributes[:'is_hidden'].nil? self.is_hidden = true if is_hidden.nil? && !attributes.key?(:'isHidden') && !attributes.key?(:'is_hidden') # rubocop:disable Style/StringLiterals end |
Instance Attribute Details
#expressions ⇒ Array<String>
[Required] An array of expressions based on the operator type. A filter may have one or more expressions.
37 38 39 |
# File 'lib/oci/data_safe/models/column_filter.rb', line 37 def expressions @expressions end |
#field_name ⇒ String
[Required] Name of the column on which the filter must be applied.
29 30 31 |
# File 'lib/oci/data_safe/models/column_filter.rb', line 29 def field_name @field_name end |
#is_enabled ⇒ BOOLEAN
[Required] Indicates if the filter is enabled. Values can either be ‘true’ or ‘false’.
41 42 43 |
# File 'lib/oci/data_safe/models/column_filter.rb', line 41 def is_enabled @is_enabled end |
#is_hidden ⇒ BOOLEAN
[Required] Indicates if the filter is hidden. Values can either be ‘true’ or ‘false’.
45 46 47 |
# File 'lib/oci/data_safe/models/column_filter.rb', line 45 def is_hidden @is_hidden end |
#operator ⇒ String
[Required] Specifies the type of operator that must be applied for example in, eq etc.
33 34 35 |
# File 'lib/oci/data_safe/models/column_filter.rb', line 33 def operator @operator end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/oci/data_safe/models/column_filter.rb', line 48 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'field_name': :'fieldName', 'operator': :'operator', 'expressions': :'expressions', 'is_enabled': :'isEnabled', 'is_hidden': :'isHidden' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/oci/data_safe/models/column_filter.rb', line 61 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'field_name': :'String', 'operator': :'String', 'expressions': :'Array<String>', 'is_enabled': :'BOOLEAN', 'is_hidden': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
135 136 137 138 139 140 141 142 143 144 |
# File 'lib/oci/data_safe/models/column_filter.rb', line 135 def ==(other) return true if equal?(other) self.class == other.class && field_name == other.field_name && operator == other.operator && expressions == other.expressions && is_enabled == other.is_enabled && is_hidden == other.is_hidden end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/oci/data_safe/models/column_filter.rb', line 169 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
149 150 151 |
# File 'lib/oci/data_safe/models/column_filter.rb', line 149 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
158 159 160 |
# File 'lib/oci/data_safe/models/column_filter.rb', line 158 def hash [field_name, operator, expressions, is_enabled, is_hidden].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
202 203 204 205 206 207 208 209 210 211 |
# File 'lib/oci/data_safe/models/column_filter.rb', line 202 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
196 197 198 |
# File 'lib/oci/data_safe/models/column_filter.rb', line 196 def to_s to_hash.to_s end |