Class: OCI::DataSafe::Models::ColumnSummary
- Inherits:
-
Object
- Object
- OCI::DataSafe::Models::ColumnSummary
- Defined in:
- lib/oci/data_safe/models/column_summary.rb
Overview
Details of a column in a table fetched from the database.
Instance Attribute Summary collapse
-
#character_length ⇒ Integer
Character length.
-
#column_name ⇒ String
[Required] Name of the column.
-
#data_type ⇒ String
[Required] Data type of the column.
-
#length ⇒ Integer
[Required] Length of the data represented by the column.
-
#precision ⇒ Integer
Precision of the column.
-
#scale ⇒ Integer
Scale of the column.
-
#schema_name ⇒ String
[Required] Name of the schema.
-
#table_name ⇒ String
[Required] Name of the table.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ColumnSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ColumnSummary
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/oci/data_safe/models/column_summary.rb', line 88 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.column_name = attributes[:'columnName'] if attributes[:'columnName'] raise 'You cannot provide both :columnName and :column_name' if attributes.key?(:'columnName') && attributes.key?(:'column_name') self.column_name = attributes[:'column_name'] if attributes[:'column_name'] self.data_type = attributes[:'dataType'] if attributes[:'dataType'] raise 'You cannot provide both :dataType and :data_type' if attributes.key?(:'dataType') && attributes.key?(:'data_type') self.data_type = attributes[:'data_type'] if attributes[:'data_type'] self.length = attributes[:'length'] if attributes[:'length'] self.precision = attributes[:'precision'] if attributes[:'precision'] self.scale = attributes[:'scale'] if attributes[:'scale'] self.character_length = attributes[:'characterLength'] if attributes[:'characterLength'] raise 'You cannot provide both :characterLength and :character_length' if attributes.key?(:'characterLength') && attributes.key?(:'character_length') self.character_length = attributes[:'character_length'] if attributes[:'character_length'] self.table_name = attributes[:'tableName'] if attributes[:'tableName'] raise 'You cannot provide both :tableName and :table_name' if attributes.key?(:'tableName') && attributes.key?(:'table_name') self.table_name = attributes[:'table_name'] if attributes[:'table_name'] self.schema_name = attributes[:'schemaName'] if attributes[:'schemaName'] raise 'You cannot provide both :schemaName and :schema_name' if attributes.key?(:'schemaName') && attributes.key?(:'schema_name') self.schema_name = attributes[:'schema_name'] if attributes[:'schema_name'] end |
Instance Attribute Details
#character_length ⇒ Integer
Character length.
32 33 34 |
# File 'lib/oci/data_safe/models/column_summary.rb', line 32 def character_length @character_length end |
#column_name ⇒ String
[Required] Name of the column.
12 13 14 |
# File 'lib/oci/data_safe/models/column_summary.rb', line 12 def column_name @column_name end |
#data_type ⇒ String
[Required] Data type of the column.
16 17 18 |
# File 'lib/oci/data_safe/models/column_summary.rb', line 16 def data_type @data_type end |
#length ⇒ Integer
[Required] Length of the data represented by the column.
20 21 22 |
# File 'lib/oci/data_safe/models/column_summary.rb', line 20 def length @length end |
#precision ⇒ Integer
Precision of the column.
24 25 26 |
# File 'lib/oci/data_safe/models/column_summary.rb', line 24 def precision @precision end |
#scale ⇒ Integer
Scale of the column.
28 29 30 |
# File 'lib/oci/data_safe/models/column_summary.rb', line 28 def scale @scale end |
#schema_name ⇒ String
[Required] Name of the schema.
40 41 42 |
# File 'lib/oci/data_safe/models/column_summary.rb', line 40 def schema_name @schema_name end |
#table_name ⇒ String
[Required] Name of the table.
36 37 38 |
# File 'lib/oci/data_safe/models/column_summary.rb', line 36 def table_name @table_name end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/oci/data_safe/models/column_summary.rb', line 43 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'column_name': :'columnName', 'data_type': :'dataType', 'length': :'length', 'precision': :'precision', 'scale': :'scale', 'character_length': :'characterLength', 'table_name': :'tableName', 'schema_name': :'schemaName' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/oci/data_safe/models/column_summary.rb', line 59 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'column_name': :'String', 'data_type': :'String', 'length': :'Integer', 'precision': :'Integer', 'scale': :'Integer', 'character_length': :'Integer', 'table_name': :'String', 'schema_name': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/oci/data_safe/models/column_summary.rb', line 138 def ==(other) return true if equal?(other) self.class == other.class && column_name == other.column_name && data_type == other.data_type && length == other.length && precision == other.precision && scale == other.scale && character_length == other.character_length && table_name == other.table_name && schema_name == other.schema_name end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/oci/data_safe/models/column_summary.rb', line 175 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
155 156 157 |
# File 'lib/oci/data_safe/models/column_summary.rb', line 155 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
164 165 166 |
# File 'lib/oci/data_safe/models/column_summary.rb', line 164 def hash [column_name, data_type, length, precision, scale, character_length, table_name, schema_name].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
208 209 210 211 212 213 214 215 216 217 |
# File 'lib/oci/data_safe/models/column_summary.rb', line 208 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
202 203 204 |
# File 'lib/oci/data_safe/models/column_summary.rb', line 202 def to_s to_hash.to_s end |