Class: OCI::DataSafe::Models::CreateAuditProfileDetails
- Inherits:
-
Object
- Object
- OCI::DataSafe::Models::CreateAuditProfileDetails
- Defined in:
- lib/oci/data_safe/models/create_audit_profile_details.rb
Overview
The details used to create a new audit profile.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The OCID of the compartment where you want to create the audit profile.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
The description of the audit profile.
-
#display_name ⇒ String
The display name of the audit profile.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#is_paid_usage_enabled ⇒ BOOLEAN
Indicates if you want to continue collecting audit records beyond the free limit of one million audit records per month per target database, potentially incurring additional charges.
-
#target_id ⇒ String
[Required] The OCID of the Data Safe target for which the audit profile is created.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateAuditProfileDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateAuditProfileDetails
Initializes the object
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/oci/data_safe/models/create_audit_profile_details.rb', line 90 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.target_id = attributes[:'targetId'] if attributes[:'targetId'] raise 'You cannot provide both :targetId and :target_id' if attributes.key?(:'targetId') && attributes.key?(:'target_id') self.target_id = attributes[:'target_id'] if attributes[:'target_id'] self.description = attributes[:'description'] if attributes[:'description'] self.is_paid_usage_enabled = attributes[:'isPaidUsageEnabled'] unless attributes[:'isPaidUsageEnabled'].nil? raise 'You cannot provide both :isPaidUsageEnabled and :is_paid_usage_enabled' if attributes.key?(:'isPaidUsageEnabled') && attributes.key?(:'is_paid_usage_enabled') self.is_paid_usage_enabled = attributes[:'is_paid_usage_enabled'] unless attributes[:'is_paid_usage_enabled'].nil? self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The OCID of the compartment where you want to create the audit profile.
16 17 18 |
# File 'lib/oci/data_safe/models/create_audit_profile_details.rb', line 16 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)
Example: ‘{"CostCenter": "42"}`
45 46 47 |
# File 'lib/oci/data_safe/models/create_audit_profile_details.rb', line 45 def end |
#description ⇒ String
The description of the audit profile.
24 25 26 |
# File 'lib/oci/data_safe/models/create_audit_profile_details.rb', line 24 def description @description end |
#display_name ⇒ String
The display name of the audit profile. The name does not have to be unique, and it’s changeable.
12 13 14 |
# File 'lib/oci/data_safe/models/create_audit_profile_details.rb', line 12 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)
Example: ‘"Finance"`
38 39 40 |
# File 'lib/oci/data_safe/models/create_audit_profile_details.rb', line 38 def end |
#is_paid_usage_enabled ⇒ BOOLEAN
Indicates if you want to continue collecting audit records beyond the free limit of one million audit records per month per target database, potentially incurring additional charges. The default value is inherited from the global settings. You can change at the global level or at the target level.
31 32 33 |
# File 'lib/oci/data_safe/models/create_audit_profile_details.rb', line 31 def is_paid_usage_enabled @is_paid_usage_enabled end |
#target_id ⇒ String
[Required] The OCID of the Data Safe target for which the audit profile is created.
20 21 22 |
# File 'lib/oci/data_safe/models/create_audit_profile_details.rb', line 20 def target_id @target_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/oci/data_safe/models/create_audit_profile_details.rb', line 48 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'target_id': :'targetId', 'description': :'description', 'is_paid_usage_enabled': :'isPaidUsageEnabled', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/oci/data_safe/models/create_audit_profile_details.rb', line 63 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'compartment_id': :'String', 'target_id': :'String', 'description': :'String', 'is_paid_usage_enabled': :'BOOLEAN', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/oci/data_safe/models/create_audit_profile_details.rb', line 142 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && compartment_id == other.compartment_id && target_id == other.target_id && description == other.description && is_paid_usage_enabled == other.is_paid_usage_enabled && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/oci/data_safe/models/create_audit_profile_details.rb', line 178 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
158 159 160 |
# File 'lib/oci/data_safe/models/create_audit_profile_details.rb', line 158 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
167 168 169 |
# File 'lib/oci/data_safe/models/create_audit_profile_details.rb', line 167 def hash [display_name, compartment_id, target_id, description, is_paid_usage_enabled, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
211 212 213 214 215 216 217 218 219 220 |
# File 'lib/oci/data_safe/models/create_audit_profile_details.rb', line 211 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
205 206 207 |
# File 'lib/oci/data_safe/models/create_audit_profile_details.rb', line 205 def to_s to_hash.to_s end |