Class: OCI::DataSafe::Models::CreateSensitiveTypeDetails
- Inherits:
-
Object
- Object
- OCI::DataSafe::Models::CreateSensitiveTypeDetails
- Defined in:
- lib/oci/data_safe/models/create_sensitive_type_details.rb
Overview
Details to create a new sensitive type. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
CreateSensitiveCategoryDetails, CreateSensitiveTypePatternDetails
Constant Summary collapse
- ENTITY_TYPE_ENUM =
[ ENTITY_TYPE_SENSITIVE_TYPE = 'SENSITIVE_TYPE'.freeze, ENTITY_TYPE_SENSITIVE_CATEGORY = 'SENSITIVE_CATEGORY'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The OCID of the compartment where the sensitive type should be created.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
The description of the sensitive type.
-
#display_name ⇒ String
The display name of the sensitive type.
-
#entity_type ⇒ String
[Required] The entity type.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#parent_category_id ⇒ String
The OCID of the parent sensitive category.
-
#short_name ⇒ String
The short name of the sensitive type.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateSensitiveTypeDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateSensitiveTypeDetails
Initializes the object
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/oci/data_safe/models/create_sensitive_type_details.rb', line 118 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.entity_type = attributes[:'entityType'] if attributes[:'entityType'] raise 'You cannot provide both :entityType and :entity_type' if attributes.key?(:'entityType') && attributes.key?(:'entity_type') self.entity_type = attributes[:'entity_type'] if attributes[:'entity_type'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.short_name = attributes[:'shortName'] if attributes[:'shortName'] raise 'You cannot provide both :shortName and :short_name' if attributes.key?(:'shortName') && attributes.key?(:'short_name') self.short_name = attributes[:'short_name'] if attributes[:'short_name'] self.description = attributes[:'description'] if attributes[:'description'] self.parent_category_id = attributes[:'parentCategoryId'] if attributes[:'parentCategoryId'] raise 'You cannot provide both :parentCategoryId and :parent_category_id' if attributes.key?(:'parentCategoryId') && attributes.key?(:'parent_category_id') self.parent_category_id = attributes[:'parent_category_id'] if attributes[:'parent_category_id'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The OCID of the compartment where the sensitive type should be created.
28 29 30 |
# File 'lib/oci/data_safe/models/create_sensitive_type_details.rb', line 28 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)
Example: ‘{"CostCenter": "42"}`
54 55 56 |
# File 'lib/oci/data_safe/models/create_sensitive_type_details.rb', line 54 def end |
#description ⇒ String
The description of the sensitive type.
36 37 38 |
# File 'lib/oci/data_safe/models/create_sensitive_type_details.rb', line 36 def description @description end |
#display_name ⇒ String
The display name of the sensitive type. The name does not have to be unique, and it’s changeable.
24 25 26 |
# File 'lib/oci/data_safe/models/create_sensitive_type_details.rb', line 24 def display_name @display_name end |
#entity_type ⇒ String
[Required] The entity type. It can be either a sensitive type with regular expressions or a sensitive category used for grouping similar sensitive types.
20 21 22 |
# File 'lib/oci/data_safe/models/create_sensitive_type_details.rb', line 20 def entity_type @entity_type end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)
Example: ‘"Finance"`
47 48 49 |
# File 'lib/oci/data_safe/models/create_sensitive_type_details.rb', line 47 def end |
#parent_category_id ⇒ String
The OCID of the parent sensitive category.
40 41 42 |
# File 'lib/oci/data_safe/models/create_sensitive_type_details.rb', line 40 def parent_category_id @parent_category_id end |
#short_name ⇒ String
The short name of the sensitive type.
32 33 34 |
# File 'lib/oci/data_safe/models/create_sensitive_type_details.rb', line 32 def short_name @short_name end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/oci/data_safe/models/create_sensitive_type_details.rb', line 57 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'entity_type': :'entityType', 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'short_name': :'shortName', 'description': :'description', 'parent_category_id': :'parentCategoryId', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
93 94 95 96 97 98 99 100 101 |
# File 'lib/oci/data_safe/models/create_sensitive_type_details.rb', line 93 def self.get_subtype(object_hash) type = object_hash[:'entityType'] # rubocop:disable Style/SymbolLiteral return 'OCI::DataSafe::Models::CreateSensitiveCategoryDetails' if type == 'SENSITIVE_CATEGORY' return 'OCI::DataSafe::Models::CreateSensitiveTypePatternDetails' if type == 'SENSITIVE_TYPE' # TODO: Log a warning when the subtype is not found. 'OCI::DataSafe::Models::CreateSensitiveTypeDetails' end |
.swagger_types ⇒ Object
Attribute type mapping.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/oci/data_safe/models/create_sensitive_type_details.rb', line 73 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'entity_type': :'String', 'display_name': :'String', 'compartment_id': :'String', 'short_name': :'String', 'description': :'String', 'parent_category_id': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/oci/data_safe/models/create_sensitive_type_details.rb', line 184 def ==(other) return true if equal?(other) self.class == other.class && entity_type == other.entity_type && display_name == other.display_name && compartment_id == other.compartment_id && short_name == other.short_name && description == other.description && parent_category_id == other.parent_category_id && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/oci/data_safe/models/create_sensitive_type_details.rb', line 221 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
201 202 203 |
# File 'lib/oci/data_safe/models/create_sensitive_type_details.rb', line 201 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
210 211 212 |
# File 'lib/oci/data_safe/models/create_sensitive_type_details.rb', line 210 def hash [entity_type, display_name, compartment_id, short_name, description, parent_category_id, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
254 255 256 257 258 259 260 261 262 263 |
# File 'lib/oci/data_safe/models/create_sensitive_type_details.rb', line 254 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
248 249 250 |
# File 'lib/oci/data_safe/models/create_sensitive_type_details.rb', line 248 def to_s to_hash.to_s end |