Class: OCI::DataSafe::Models::CreateTargetDatabaseDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_safe/models/create_target_database_details.rb

Overview

The details used to register the database in Data Safe and to create the Data Safe target database.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateTargetDatabaseDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/oci/data_safe/models/create_target_database_details.rb', line 98

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.database_details = attributes[:'databaseDetails'] if attributes[:'databaseDetails']

  raise 'You cannot provide both :databaseDetails and :database_details' if attributes.key?(:'databaseDetails') && attributes.key?(:'database_details')

  self.database_details = attributes[:'database_details'] if attributes[:'database_details']

  self.credentials = attributes[:'credentials'] if attributes[:'credentials']

  self.tls_config = attributes[:'tlsConfig'] if attributes[:'tlsConfig']

  raise 'You cannot provide both :tlsConfig and :tls_config' if attributes.key?(:'tlsConfig') && attributes.key?(:'tls_config')

  self.tls_config = attributes[:'tls_config'] if attributes[:'tls_config']

  self.connection_option = attributes[:'connectionOption'] if attributes[:'connectionOption']

  raise 'You cannot provide both :connectionOption and :connection_option' if attributes.key?(:'connectionOption') && attributes.key?(:'connection_option')

  self.connection_option = attributes[:'connection_option'] if attributes[:'connection_option']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#compartment_idString

[Required] The OCID of the compartment in which to create the Data Safe target database.

Returns:

  • (String)


12
13
14
# File 'lib/oci/data_safe/models/create_target_database_details.rb', line 12

def compartment_id
  @compartment_id
end

#connection_optionOCI::DataSafe::Models::ConnectionOption



33
34
35
# File 'lib/oci/data_safe/models/create_target_database_details.rb', line 33

def connection_option
  @connection_option
end

#credentialsOCI::DataSafe::Models::Credentials



27
28
29
# File 'lib/oci/data_safe/models/create_target_database_details.rb', line 27

def credentials
  @credentials
end

#database_detailsOCI::DataSafe::Models::DatabaseDetails

This attribute is required.



24
25
26
# File 'lib/oci/data_safe/models/create_target_database_details.rb', line 24

def database_details
  @database_details
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)

Example: ‘{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


47
48
49
# File 'lib/oci/data_safe/models/create_target_database_details.rb', line 47

def defined_tags
  @defined_tags
end

#descriptionString

The description of the target database in Data Safe.

Returns:

  • (String)


20
21
22
# File 'lib/oci/data_safe/models/create_target_database_details.rb', line 20

def description
  @description
end

#display_nameString

The display name of the target database in Data Safe. The name is modifiable and does not need to be unique.

Returns:

  • (String)


16
17
18
# File 'lib/oci/data_safe/models/create_target_database_details.rb', line 16

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)

Example: ‘"Finance"`

Returns:

  • (Hash<String, String>)


40
41
42
# File 'lib/oci/data_safe/models/create_target_database_details.rb', line 40

def freeform_tags
  @freeform_tags
end

#tls_configOCI::DataSafe::Models::TlsConfig



30
31
32
# File 'lib/oci/data_safe/models/create_target_database_details.rb', line 30

def tls_config
  @tls_config
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/oci/data_safe/models/create_target_database_details.rb', line 50

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'compartmentId',
    'display_name': :'displayName',
    'description': :'description',
    'database_details': :'databaseDetails',
    'credentials': :'credentials',
    'tls_config': :'tlsConfig',
    'connection_option': :'connectionOption',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/oci/data_safe/models/create_target_database_details.rb', line 67

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'String',
    'display_name': :'String',
    'description': :'String',
    'database_details': :'OCI::DataSafe::Models::DatabaseDetails',
    'credentials': :'OCI::DataSafe::Models::Credentials',
    'tls_config': :'OCI::DataSafe::Models::TlsConfig',
    'connection_option': :'OCI::DataSafe::Models::ConnectionOption',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/oci/data_safe/models/create_target_database_details.rb', line 158

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    compartment_id == other.compartment_id &&
    display_name == other.display_name &&
    description == other.description &&
    database_details == other.database_details &&
    credentials == other.credentials &&
    tls_config == other.tls_config &&
    connection_option == other.connection_option &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/oci/data_safe/models/create_target_database_details.rb', line 196

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


176
177
178
# File 'lib/oci/data_safe/models/create_target_database_details.rb', line 176

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



185
186
187
# File 'lib/oci/data_safe/models/create_target_database_details.rb', line 185

def hash
  [compartment_id, display_name, description, database_details, credentials, tls_config, connection_option, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



229
230
231
232
233
234
235
236
237
238
# File 'lib/oci/data_safe/models/create_target_database_details.rb', line 229

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



223
224
225
# File 'lib/oci/data_safe/models/create_target_database_details.rb', line 223

def to_s
  to_hash.to_s
end