Class: OCI::DataSafe::Models::CreateUserAssessmentDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_safe/models/create_user_assessment_details.rb

Overview

The details required to save a user assessment.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateUserAssessmentDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :description (String)

    The value to assign to the #description property

  • :display_name (String)

    The value to assign to the #display_name property

  • :schedule (String)

    The value to assign to the #schedule property

  • :target_id (String)

    The value to assign to the #target_id property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
# File 'lib/oci/data_safe/models/create_user_assessment_details.rb', line 103

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.description = attributes[:'description'] if attributes[:'description']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.schedule = attributes[:'schedule'] if attributes[:'schedule']

  self.target_id = attributes[:'targetId'] if attributes[:'targetId']

  raise 'You cannot provide both :targetId and :target_id' if attributes.key?(:'targetId') && attributes.key?(:'target_id')

  self.target_id = attributes[:'target_id'] if attributes[:'target_id']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#compartment_idString

[Required] The OCID of the compartment that contains the user assessment.

Returns:

  • (String)


12
13
14
# File 'lib/oci/data_safe/models/create_user_assessment_details.rb', line 12

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)

Example: ‘{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


58
59
60
# File 'lib/oci/data_safe/models/create_user_assessment_details.rb', line 58

def defined_tags
  @defined_tags
end

#descriptionString

The description of the user assessment.

Returns:

  • (String)


16
17
18
# File 'lib/oci/data_safe/models/create_user_assessment_details.rb', line 16

def description
  @description
end

#display_nameString

The display name of the user assessment.

Returns:

  • (String)


20
21
22
# File 'lib/oci/data_safe/models/create_user_assessment_details.rb', line 20

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)

Example: ‘"Finance"`

Returns:

  • (Hash<String, String>)


51
52
53
# File 'lib/oci/data_safe/models/create_user_assessment_details.rb', line 51

def freeform_tags
  @freeform_tags
end

#scheduleString

To schedule the assessment for saving periodically, specify the schedule in this attribute. Create or schedule one assessment per compartment. If not defined, the assessment runs immediately.

Format -
 <version-string>;<version-specific-schedule>

 Allowed version strings - \"v1\"
 v1's version specific schedule -<ss> <mm> <hh> <day-of-week> <day-of-month>
 Each of the above fields potentially introduce constraints. A workrequest is created only
 when clock time satisfies all the constraints. Constraints introduced:
 1. seconds = <ss> (So, the allowed range for <ss> is [0, 59])
 2. minutes = <mm> (So, the allowed range for <mm> is [0, 59])
 3. hours = <hh> (So, the allowed range for <hh> is [0, 23])
 <day-of-week> can be either '*' (without quotes or a number between 1(Monday) and 7(Sunday))
 4. No constraint introduced when it is '*'. When not, day of week must equal the given value
 <day-of-month> can be either '*' (without quotes or a number between 1 and 28)
 5. No constraint introduced when it is '*'. When not, day of month must equal the given value

Returns:

  • (String)


40
41
42
# File 'lib/oci/data_safe/models/create_user_assessment_details.rb', line 40

def schedule
  @schedule
end

#target_idString

[Required] The OCID of the target database on which the user assessment is to be run.

Returns:

  • (String)


44
45
46
# File 'lib/oci/data_safe/models/create_user_assessment_details.rb', line 44

def target_id
  @target_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/oci/data_safe/models/create_user_assessment_details.rb', line 61

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'compartmentId',
    'description': :'description',
    'display_name': :'displayName',
    'schedule': :'schedule',
    'target_id': :'targetId',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/oci/data_safe/models/create_user_assessment_details.rb', line 76

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'String',
    'description': :'String',
    'display_name': :'String',
    'schedule': :'String',
    'target_id': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/oci/data_safe/models/create_user_assessment_details.rb', line 151

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    compartment_id == other.compartment_id &&
    description == other.description &&
    display_name == other.display_name &&
    schedule == other.schedule &&
    target_id == other.target_id &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/oci/data_safe/models/create_user_assessment_details.rb', line 187

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


167
168
169
# File 'lib/oci/data_safe/models/create_user_assessment_details.rb', line 167

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



176
177
178
# File 'lib/oci/data_safe/models/create_user_assessment_details.rb', line 176

def hash
  [compartment_id, description, display_name, schedule, target_id, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



220
221
222
223
224
225
226
227
228
229
# File 'lib/oci/data_safe/models/create_user_assessment_details.rb', line 220

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



214
215
216
# File 'lib/oci/data_safe/models/create_user_assessment_details.rb', line 214

def to_s
  to_hash.to_s
end