Class: OCI::DataSafe::Models::DeterministicEncryptionDateFormatEntry
- Inherits:
-
FormatEntry
- Object
- FormatEntry
- OCI::DataSafe::Models::DeterministicEncryptionDateFormatEntry
- Defined in:
- lib/oci/data_safe/models/deterministic_encryption_date_format_entry.rb
Overview
The Deterministic Encryption (Date) masking format encrypts column data using a cryptographic key and Advanced Encryption Standard (AES 128). It can be used to encrypt date columns only. It requires a range of dates as input defined by the startDate and endDate attributes. The start date must be less than or equal to the end date.
The original column values in all the rows must be within the specified date range. The encrypted values are also within the specified range. Therefore, to ensure uniqueness, the total number of dates in the range must be greater than or equal to the number of distinct original values in the column. If an original value is not in the specified date range, it might not produce a one-to-one mapping. All non-confirming values are mapped to a single encrypted value, thereby producing a many-to-one mapping.
Deterministic Encryption (Date) is a format-preserving, deterministic and reversible masking format, which requires a seed value while submitting a masking work request. Passing the same seed value when masking multiple times or masking different databases ensures that the data is masked deterministically. To learn more, check Deterministic Encryption in the Data Safe documentation.
Constant Summary
Constants inherited from FormatEntry
Instance Attribute Summary collapse
-
#end_date ⇒ DateTime
[Required] The upper bound of the range within which all the original column values fall.
-
#start_date ⇒ DateTime
[Required] The lower bound of the range within which all the original column values fall.
Attributes inherited from FormatEntry
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DeterministicEncryptionDateFormatEntry
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from FormatEntry
Constructor Details
#initialize(attributes = {}) ⇒ DeterministicEncryptionDateFormatEntry
Initializes the object
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/oci/data_safe/models/deterministic_encryption_date_format_entry.rb', line 73 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['type'] = 'DETERMINISTIC_ENCRYPTION_DATE' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.start_date = attributes[:'startDate'] if attributes[:'startDate'] raise 'You cannot provide both :startDate and :start_date' if attributes.key?(:'startDate') && attributes.key?(:'start_date') self.start_date = attributes[:'start_date'] if attributes[:'start_date'] self.end_date = attributes[:'endDate'] if attributes[:'endDate'] raise 'You cannot provide both :endDate and :end_date' if attributes.key?(:'endDate') && attributes.key?(:'end_date') self.end_date = attributes[:'end_date'] if attributes[:'end_date'] end |
Instance Attribute Details
#end_date ⇒ DateTime
[Required] The upper bound of the range within which all the original column values fall. The end date must be greater than or equal to the start date.
38 39 40 |
# File 'lib/oci/data_safe/models/deterministic_encryption_date_format_entry.rb', line 38 def end_date @end_date end |
#start_date ⇒ DateTime
[Required] The lower bound of the range within which all the original column values fall. The start date must be less than or equal to the end date.
32 33 34 |
# File 'lib/oci/data_safe/models/deterministic_encryption_date_format_entry.rb', line 32 def start_date @start_date end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 |
# File 'lib/oci/data_safe/models/deterministic_encryption_date_format_entry.rb', line 41 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'type': :'type', 'description': :'description', 'start_date': :'startDate', 'end_date': :'endDate' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
53 54 55 56 57 58 59 60 61 62 |
# File 'lib/oci/data_safe/models/deterministic_encryption_date_format_entry.rb', line 53 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'type': :'String', 'description': :'String', 'start_date': :'DateTime', 'end_date': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
103 104 105 106 107 108 109 110 111 |
# File 'lib/oci/data_safe/models/deterministic_encryption_date_format_entry.rb', line 103 def ==(other) return true if equal?(other) self.class == other.class && type == other.type && description == other.description && start_date == other.start_date && end_date == other.end_date end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/oci/data_safe/models/deterministic_encryption_date_format_entry.rb', line 136 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
116 117 118 |
# File 'lib/oci/data_safe/models/deterministic_encryption_date_format_entry.rb', line 116 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
125 126 127 |
# File 'lib/oci/data_safe/models/deterministic_encryption_date_format_entry.rb', line 125 def hash [type, description, start_date, end_date].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
169 170 171 172 173 174 175 176 177 178 |
# File 'lib/oci/data_safe/models/deterministic_encryption_date_format_entry.rb', line 169 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
163 164 165 |
# File 'lib/oci/data_safe/models/deterministic_encryption_date_format_entry.rb', line 163 def to_s to_hash.to_s end |