Class: OCI::DataSafe::Models::Diffs
- Inherits:
-
Object
- Object
- OCI::DataSafe::Models::Diffs
- Defined in:
- lib/oci/data_safe/models/diffs.rb
Overview
Results of the comparison of an item between two security assessments.
Constant Summary collapse
- SEVERITY_ENUM =
[ SEVERITY_HIGH = 'HIGH'.freeze, SEVERITY_MEDIUM = 'MEDIUM'.freeze, SEVERITY_LOW = 'LOW'.freeze, SEVERITY_EVALUATE = 'EVALUATE'.freeze, SEVERITY_ADVISORY = 'ADVISORY'.freeze, SEVERITY_PASS = 'PASS'.freeze, SEVERITY_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#added_items ⇒ Array<String>
This array identifies the items that are present in the current assessment, but are missing from the baseline.
- #baseline ⇒ OCI::DataSafe::Models::Finding
- #current ⇒ OCI::DataSafe::Models::Finding
-
#modified_items ⇒ Array<String>
This array contains the items that are present in both the current assessment and the baseline, but are different in the two assessments.
-
#removed_items ⇒ Array<String>
This array identifies the items that are present in the baseline, but are missing from the current assessment.
-
#severity ⇒ String
The severity of this diff.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Diffs
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Diffs
Initializes the object
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/oci/data_safe/models/diffs.rb', line 85 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.current = attributes[:'current'] if attributes[:'current'] self.baseline = attributes[:'baseline'] if attributes[:'baseline'] self.removed_items = attributes[:'removedItems'] if attributes[:'removedItems'] raise 'You cannot provide both :removedItems and :removed_items' if attributes.key?(:'removedItems') && attributes.key?(:'removed_items') self.removed_items = attributes[:'removed_items'] if attributes[:'removed_items'] self.added_items = attributes[:'addedItems'] if attributes[:'addedItems'] raise 'You cannot provide both :addedItems and :added_items' if attributes.key?(:'addedItems') && attributes.key?(:'added_items') self.added_items = attributes[:'added_items'] if attributes[:'added_items'] self.modified_items = attributes[:'modifiedItems'] if attributes[:'modifiedItems'] raise 'You cannot provide both :modifiedItems and :modified_items' if attributes.key?(:'modifiedItems') && attributes.key?(:'modified_items') self.modified_items = attributes[:'modified_items'] if attributes[:'modified_items'] self.severity = attributes[:'severity'] if attributes[:'severity'] end |
Instance Attribute Details
#added_items ⇒ Array<String>
This array identifies the items that are present in the current assessment, but are missing from the baseline.
34 35 36 |
# File 'lib/oci/data_safe/models/diffs.rb', line 34 def added_items @added_items end |
#baseline ⇒ OCI::DataSafe::Models::Finding
26 27 28 |
# File 'lib/oci/data_safe/models/diffs.rb', line 26 def baseline @baseline end |
#current ⇒ OCI::DataSafe::Models::Finding
23 24 25 |
# File 'lib/oci/data_safe/models/diffs.rb', line 23 def current @current end |
#modified_items ⇒ Array<String>
This array contains the items that are present in both the current assessment and the baseline, but are different in the two assessments.
39 40 41 |
# File 'lib/oci/data_safe/models/diffs.rb', line 39 def modified_items @modified_items end |
#removed_items ⇒ Array<String>
This array identifies the items that are present in the baseline, but are missing from the current assessment.
30 31 32 |
# File 'lib/oci/data_safe/models/diffs.rb', line 30 def removed_items @removed_items end |
#severity ⇒ String
The severity of this diff.
43 44 45 |
# File 'lib/oci/data_safe/models/diffs.rb', line 43 def severity @severity end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/oci/data_safe/models/diffs.rb', line 46 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'current': :'current', 'baseline': :'baseline', 'removed_items': :'removedItems', 'added_items': :'addedItems', 'modified_items': :'modifiedItems', 'severity': :'severity' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/oci/data_safe/models/diffs.rb', line 60 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'current': :'OCI::DataSafe::Models::Finding', 'baseline': :'OCI::DataSafe::Models::Finding', 'removed_items': :'Array<String>', 'added_items': :'Array<String>', 'modified_items': :'Array<String>', 'severity': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/oci/data_safe/models/diffs.rb', line 136 def ==(other) return true if equal?(other) self.class == other.class && current == other.current && baseline == other.baseline && removed_items == other.removed_items && added_items == other.added_items && modified_items == other.modified_items && severity == other.severity end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/oci/data_safe/models/diffs.rb', line 171 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
151 152 153 |
# File 'lib/oci/data_safe/models/diffs.rb', line 151 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
160 161 162 |
# File 'lib/oci/data_safe/models/diffs.rb', line 160 def hash [current, baseline, removed_items, added_items, modified_items, severity].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
204 205 206 207 208 209 210 211 212 213 |
# File 'lib/oci/data_safe/models/diffs.rb', line 204 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
198 199 200 |
# File 'lib/oci/data_safe/models/diffs.rb', line 198 def to_s to_hash.to_s end |