Class: OCI::DataSafe::Models::DiscoveryJob

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_safe/models/discovery_job.rb

Overview

A data discovery job. It helps track job’s metadata as well as result statistics.

Constant Summary collapse

DISCOVERY_TYPE_ENUM =
[
  DISCOVERY_TYPE_ALL = 'ALL'.freeze,
  DISCOVERY_TYPE_NEW = 'NEW'.freeze,
  DISCOVERY_TYPE_MODIFIED = 'MODIFIED'.freeze,
  DISCOVERY_TYPE_DELETED = 'DELETED'.freeze,
  DISCOVERY_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DiscoveryJob

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/oci/data_safe/models/discovery_job.rb', line 246

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.discovery_type = attributes[:'discoveryType'] if attributes[:'discoveryType']

  raise 'You cannot provide both :discoveryType and :discovery_type' if attributes.key?(:'discoveryType') && attributes.key?(:'discovery_type')

  self.discovery_type = attributes[:'discovery_type'] if attributes[:'discovery_type']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.time_started = attributes[:'timeStarted'] if attributes[:'timeStarted']

  raise 'You cannot provide both :timeStarted and :time_started' if attributes.key?(:'timeStarted') && attributes.key?(:'time_started')

  self.time_started = attributes[:'time_started'] if attributes[:'time_started']

  self.time_finished = attributes[:'timeFinished'] if attributes[:'timeFinished']

  raise 'You cannot provide both :timeFinished and :time_finished' if attributes.key?(:'timeFinished') && attributes.key?(:'time_finished')

  self.time_finished = attributes[:'time_finished'] if attributes[:'time_finished']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.sensitive_data_model_id = attributes[:'sensitiveDataModelId'] if attributes[:'sensitiveDataModelId']

  raise 'You cannot provide both :sensitiveDataModelId and :sensitive_data_model_id' if attributes.key?(:'sensitiveDataModelId') && attributes.key?(:'sensitive_data_model_id')

  self.sensitive_data_model_id = attributes[:'sensitive_data_model_id'] if attributes[:'sensitive_data_model_id']

  self.target_id = attributes[:'targetId'] if attributes[:'targetId']

  raise 'You cannot provide both :targetId and :target_id' if attributes.key?(:'targetId') && attributes.key?(:'target_id')

  self.target_id = attributes[:'target_id'] if attributes[:'target_id']

  self.schemas_for_discovery = attributes[:'schemasForDiscovery'] if attributes[:'schemasForDiscovery']

  raise 'You cannot provide both :schemasForDiscovery and :schemas_for_discovery' if attributes.key?(:'schemasForDiscovery') && attributes.key?(:'schemas_for_discovery')

  self.schemas_for_discovery = attributes[:'schemas_for_discovery'] if attributes[:'schemas_for_discovery']

  self.sensitive_type_ids_for_discovery = attributes[:'sensitiveTypeIdsForDiscovery'] if attributes[:'sensitiveTypeIdsForDiscovery']

  raise 'You cannot provide both :sensitiveTypeIdsForDiscovery and :sensitive_type_ids_for_discovery' if attributes.key?(:'sensitiveTypeIdsForDiscovery') && attributes.key?(:'sensitive_type_ids_for_discovery')

  self.sensitive_type_ids_for_discovery = attributes[:'sensitive_type_ids_for_discovery'] if attributes[:'sensitive_type_ids_for_discovery']

  self.is_sample_data_collection_enabled = attributes[:'isSampleDataCollectionEnabled'] unless attributes[:'isSampleDataCollectionEnabled'].nil?

  raise 'You cannot provide both :isSampleDataCollectionEnabled and :is_sample_data_collection_enabled' if attributes.key?(:'isSampleDataCollectionEnabled') && attributes.key?(:'is_sample_data_collection_enabled')

  self.is_sample_data_collection_enabled = attributes[:'is_sample_data_collection_enabled'] unless attributes[:'is_sample_data_collection_enabled'].nil?

  self.is_app_defined_relation_discovery_enabled = attributes[:'isAppDefinedRelationDiscoveryEnabled'] unless attributes[:'isAppDefinedRelationDiscoveryEnabled'].nil?

  raise 'You cannot provide both :isAppDefinedRelationDiscoveryEnabled and :is_app_defined_relation_discovery_enabled' if attributes.key?(:'isAppDefinedRelationDiscoveryEnabled') && attributes.key?(:'is_app_defined_relation_discovery_enabled')

  self.is_app_defined_relation_discovery_enabled = attributes[:'is_app_defined_relation_discovery_enabled'] unless attributes[:'is_app_defined_relation_discovery_enabled'].nil?

  self.is_include_all_schemas = attributes[:'isIncludeAllSchemas'] unless attributes[:'isIncludeAllSchemas'].nil?

  raise 'You cannot provide both :isIncludeAllSchemas and :is_include_all_schemas' if attributes.key?(:'isIncludeAllSchemas') && attributes.key?(:'is_include_all_schemas')

  self.is_include_all_schemas = attributes[:'is_include_all_schemas'] unless attributes[:'is_include_all_schemas'].nil?

  self.is_include_all_sensitive_types = attributes[:'isIncludeAllSensitiveTypes'] unless attributes[:'isIncludeAllSensitiveTypes'].nil?

  raise 'You cannot provide both :isIncludeAllSensitiveTypes and :is_include_all_sensitive_types' if attributes.key?(:'isIncludeAllSensitiveTypes') && attributes.key?(:'is_include_all_sensitive_types')

  self.is_include_all_sensitive_types = attributes[:'is_include_all_sensitive_types'] unless attributes[:'is_include_all_sensitive_types'].nil?

  self.total_schemas_scanned = attributes[:'totalSchemasScanned'] if attributes[:'totalSchemasScanned']

  raise 'You cannot provide both :totalSchemasScanned and :total_schemas_scanned' if attributes.key?(:'totalSchemasScanned') && attributes.key?(:'total_schemas_scanned')

  self.total_schemas_scanned = attributes[:'total_schemas_scanned'] if attributes[:'total_schemas_scanned']

  self.total_objects_scanned = attributes[:'totalObjectsScanned'] if attributes[:'totalObjectsScanned']

  raise 'You cannot provide both :totalObjectsScanned and :total_objects_scanned' if attributes.key?(:'totalObjectsScanned') && attributes.key?(:'total_objects_scanned')

  self.total_objects_scanned = attributes[:'total_objects_scanned'] if attributes[:'total_objects_scanned']

  self.total_columns_scanned = attributes[:'totalColumnsScanned'] if attributes[:'totalColumnsScanned']

  raise 'You cannot provide both :totalColumnsScanned and :total_columns_scanned' if attributes.key?(:'totalColumnsScanned') && attributes.key?(:'total_columns_scanned')

  self.total_columns_scanned = attributes[:'total_columns_scanned'] if attributes[:'total_columns_scanned']

  self.total_new_sensitive_columns = attributes[:'totalNewSensitiveColumns'] if attributes[:'totalNewSensitiveColumns']

  raise 'You cannot provide both :totalNewSensitiveColumns and :total_new_sensitive_columns' if attributes.key?(:'totalNewSensitiveColumns') && attributes.key?(:'total_new_sensitive_columns')

  self.total_new_sensitive_columns = attributes[:'total_new_sensitive_columns'] if attributes[:'total_new_sensitive_columns']

  self.total_modified_sensitive_columns = attributes[:'totalModifiedSensitiveColumns'] if attributes[:'totalModifiedSensitiveColumns']

  raise 'You cannot provide both :totalModifiedSensitiveColumns and :total_modified_sensitive_columns' if attributes.key?(:'totalModifiedSensitiveColumns') && attributes.key?(:'total_modified_sensitive_columns')

  self.total_modified_sensitive_columns = attributes[:'total_modified_sensitive_columns'] if attributes[:'total_modified_sensitive_columns']

  self.total_deleted_sensitive_columns = attributes[:'totalDeletedSensitiveColumns'] if attributes[:'totalDeletedSensitiveColumns']

  raise 'You cannot provide both :totalDeletedSensitiveColumns and :total_deleted_sensitive_columns' if attributes.key?(:'totalDeletedSensitiveColumns') && attributes.key?(:'total_deleted_sensitive_columns')

  self.total_deleted_sensitive_columns = attributes[:'total_deleted_sensitive_columns'] if attributes[:'total_deleted_sensitive_columns']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

  raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

  self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']
end

Instance Attribute Details

#compartment_idString

[Required] The OCID of the compartment that contains the discovery job.

Returns:

  • (String)


48
49
50
# File 'lib/oci/data_safe/models/discovery_job.rb', line 48

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)

Example: ‘{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


144
145
146
# File 'lib/oci/data_safe/models/discovery_job.rb', line 144

def defined_tags
  @defined_tags
end

#discovery_typeString

[Required] The type of the discovery job. It defines the job’s scope. NEW identifies new sensitive columns in the target database that are not in the sensitive data model. DELETED identifies columns that are present in the sensitive data model but have been deleted from the target database. MODIFIED identifies columns that are present in the target database as well as the sensitive data model but some of their attributes have been modified. ALL covers all the above three scenarios and reports new, deleted and modified columns.

Returns:

  • (String)


40
41
42
# File 'lib/oci/data_safe/models/discovery_job.rb', line 40

def discovery_type
  @discovery_type
end

#display_nameString

[Required] The display name of the discovery job.

Returns:

  • (String)


44
45
46
# File 'lib/oci/data_safe/models/discovery_job.rb', line 44

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)

Example: ‘"Finance"`

Returns:

  • (Hash<String, String>)


137
138
139
# File 'lib/oci/data_safe/models/discovery_job.rb', line 137

def freeform_tags
  @freeform_tags
end

#idString

[Required] The OCID of the discovery job.

Returns:

  • (String)


31
32
33
# File 'lib/oci/data_safe/models/discovery_job.rb', line 31

def id
  @id
end

#is_app_defined_relation_discovery_enabledBOOLEAN

[Required] Indicates if the discovery job should identify potential application-level (non-dictionary) referential relationships between columns. Note that data discovery automatically identifies and adds database-level (dictionary-defined) relationships. This option helps identify application-level relationships that are not defined in the database dictionary, which in turn, helps identify additional sensitive columns and preserve referential integrity during data masking. It’s disabled by default and should be used only if there is a need to identify application-level relationships.

Returns:

  • (BOOLEAN)


94
95
96
# File 'lib/oci/data_safe/models/discovery_job.rb', line 94

def is_app_defined_relation_discovery_enabled
  @is_app_defined_relation_discovery_enabled
end

#is_include_all_schemasBOOLEAN

[Required] Indicates if all the schemas in the associated target database are used for data discovery. If it’s set to true, the schemasForDiscovery attribute is ignored and all schemas are used.

Returns:

  • (BOOLEAN)


100
101
102
# File 'lib/oci/data_safe/models/discovery_job.rb', line 100

def is_include_all_schemas
  @is_include_all_schemas
end

#is_include_all_sensitive_typesBOOLEAN

[Required] Indicates if all the existing sensitive types are used for data discovery. If it’s set to true, the sensitiveTypeIdsForDiscovery attribute is ignored and all sensitive types are used.

Returns:

  • (BOOLEAN)


106
107
108
# File 'lib/oci/data_safe/models/discovery_job.rb', line 106

def is_include_all_sensitive_types
  @is_include_all_sensitive_types
end

#is_sample_data_collection_enabledBOOLEAN

[Required] Indicates if the discovery job should collect and store sample data values for the discovered columns. Sample data helps review the discovered columns and ensure that they actually contain sensitive data. As it collects original data from the target database, it’s disabled by default and should be used only if it’s acceptable to store sample data in Data Safe’s repository in Oracle Cloud. Note that sample data values are not collected for columns with the following data types: LONG, LOB, RAW, XMLTYPE and BFILE.

Returns:

  • (BOOLEAN)


85
86
87
# File 'lib/oci/data_safe/models/discovery_job.rb', line 85

def is_sample_data_collection_enabled
  @is_sample_data_collection_enabled
end

#lifecycle_stateString

[Required] The current state of the discovery job.

Returns:

  • (String)


60
61
62
# File 'lib/oci/data_safe/models/discovery_job.rb', line 60

def lifecycle_state
  @lifecycle_state
end

#schemas_for_discoveryArray<String>

The schemas used for data discovery.

Returns:

  • (Array<String>)


72
73
74
# File 'lib/oci/data_safe/models/discovery_job.rb', line 72

def schemas_for_discovery
  @schemas_for_discovery
end

#sensitive_data_model_idString

[Required] The OCID of the sensitive data model associated with the discovery job.

Returns:

  • (String)


64
65
66
# File 'lib/oci/data_safe/models/discovery_job.rb', line 64

def sensitive_data_model_id
  @sensitive_data_model_id
end

#sensitive_type_ids_for_discoveryArray<String>

The OCIDs of the sensitive types used for data discovery.

Returns:

  • (Array<String>)


76
77
78
# File 'lib/oci/data_safe/models/discovery_job.rb', line 76

def sensitive_type_ids_for_discovery
  @sensitive_type_ids_for_discovery
end

#system_tagsHash<String, Hash<String, Object>>

System tags for this resource. Each key is predefined and scoped to a namespace. For more information, see Resource Tags. Example: ‘{"free-tier-retained": "true"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


150
151
152
# File 'lib/oci/data_safe/models/discovery_job.rb', line 150

def system_tags
  @system_tags
end

#target_idString

[Required] The OCID of the target database associated with the discovery job.

Returns:

  • (String)


68
69
70
# File 'lib/oci/data_safe/models/discovery_job.rb', line 68

def target_id
  @target_id
end

#time_finishedDateTime

[Required] The date and time the discovery job finished, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339)..

Returns:

  • (DateTime)


56
57
58
# File 'lib/oci/data_safe/models/discovery_job.rb', line 56

def time_finished
  @time_finished
end

#time_startedDateTime

[Required] The date and time the discovery job started, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).

Returns:

  • (DateTime)


52
53
54
# File 'lib/oci/data_safe/models/discovery_job.rb', line 52

def time_started
  @time_started
end

#total_columns_scannedInteger

[Required] The total number of columns scanned by the discovery job.

Returns:

  • (Integer)


118
119
120
# File 'lib/oci/data_safe/models/discovery_job.rb', line 118

def total_columns_scanned
  @total_columns_scanned
end

#total_deleted_sensitive_columnsInteger

[Required] The total number of deleted sensitive columns identified by the discovery job.

Returns:

  • (Integer)


130
131
132
# File 'lib/oci/data_safe/models/discovery_job.rb', line 130

def total_deleted_sensitive_columns
  @total_deleted_sensitive_columns
end

#total_modified_sensitive_columnsInteger

[Required] The total number of modified sensitive columns identified by the discovery job.

Returns:

  • (Integer)


126
127
128
# File 'lib/oci/data_safe/models/discovery_job.rb', line 126

def total_modified_sensitive_columns
  @total_modified_sensitive_columns
end

#total_new_sensitive_columnsInteger

[Required] The total number of new sensitive columns identified by the discovery job.

Returns:

  • (Integer)


122
123
124
# File 'lib/oci/data_safe/models/discovery_job.rb', line 122

def total_new_sensitive_columns
  @total_new_sensitive_columns
end

#total_objects_scannedInteger

[Required] The total number of objects (tables and editioning views) scanned by the discovery job.

Returns:

  • (Integer)


114
115
116
# File 'lib/oci/data_safe/models/discovery_job.rb', line 114

def total_objects_scanned
  @total_objects_scanned
end

#total_schemas_scannedInteger

[Required] The total number of schemas scanned by the discovery job.

Returns:

  • (Integer)


110
111
112
# File 'lib/oci/data_safe/models/discovery_job.rb', line 110

def total_schemas_scanned
  @total_schemas_scanned
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/oci/data_safe/models/discovery_job.rb', line 153

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'discovery_type': :'discoveryType',
    'display_name': :'displayName',
    'compartment_id': :'compartmentId',
    'time_started': :'timeStarted',
    'time_finished': :'timeFinished',
    'lifecycle_state': :'lifecycleState',
    'sensitive_data_model_id': :'sensitiveDataModelId',
    'target_id': :'targetId',
    'schemas_for_discovery': :'schemasForDiscovery',
    'sensitive_type_ids_for_discovery': :'sensitiveTypeIdsForDiscovery',
    'is_sample_data_collection_enabled': :'isSampleDataCollectionEnabled',
    'is_app_defined_relation_discovery_enabled': :'isAppDefinedRelationDiscoveryEnabled',
    'is_include_all_schemas': :'isIncludeAllSchemas',
    'is_include_all_sensitive_types': :'isIncludeAllSensitiveTypes',
    'total_schemas_scanned': :'totalSchemasScanned',
    'total_objects_scanned': :'totalObjectsScanned',
    'total_columns_scanned': :'totalColumnsScanned',
    'total_new_sensitive_columns': :'totalNewSensitiveColumns',
    'total_modified_sensitive_columns': :'totalModifiedSensitiveColumns',
    'total_deleted_sensitive_columns': :'totalDeletedSensitiveColumns',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/oci/data_safe/models/discovery_job.rb', line 185

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'discovery_type': :'String',
    'display_name': :'String',
    'compartment_id': :'String',
    'time_started': :'DateTime',
    'time_finished': :'DateTime',
    'lifecycle_state': :'String',
    'sensitive_data_model_id': :'String',
    'target_id': :'String',
    'schemas_for_discovery': :'Array<String>',
    'sensitive_type_ids_for_discovery': :'Array<String>',
    'is_sample_data_collection_enabled': :'BOOLEAN',
    'is_app_defined_relation_discovery_enabled': :'BOOLEAN',
    'is_include_all_schemas': :'BOOLEAN',
    'is_include_all_sensitive_types': :'BOOLEAN',
    'total_schemas_scanned': :'Integer',
    'total_objects_scanned': :'Integer',
    'total_columns_scanned': :'Integer',
    'total_new_sensitive_columns': :'Integer',
    'total_modified_sensitive_columns': :'Integer',
    'total_deleted_sensitive_columns': :'Integer',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
# File 'lib/oci/data_safe/models/discovery_job.rb', line 426

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    discovery_type == other.discovery_type &&
    display_name == other.display_name &&
    compartment_id == other.compartment_id &&
    time_started == other.time_started &&
    time_finished == other.time_finished &&
    lifecycle_state == other.lifecycle_state &&
    sensitive_data_model_id == other.sensitive_data_model_id &&
    target_id == other.target_id &&
    schemas_for_discovery == other.schemas_for_discovery &&
    sensitive_type_ids_for_discovery == other.sensitive_type_ids_for_discovery &&
    is_sample_data_collection_enabled == other.is_sample_data_collection_enabled &&
    is_app_defined_relation_discovery_enabled == other.is_app_defined_relation_discovery_enabled &&
    is_include_all_schemas == other.is_include_all_schemas &&
    is_include_all_sensitive_types == other.is_include_all_sensitive_types &&
    total_schemas_scanned == other.total_schemas_scanned &&
    total_objects_scanned == other.total_objects_scanned &&
    total_columns_scanned == other.total_columns_scanned &&
    total_new_sensitive_columns == other.total_new_sensitive_columns &&
    total_modified_sensitive_columns == other.total_modified_sensitive_columns &&
    total_deleted_sensitive_columns == other.total_deleted_sensitive_columns &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
# File 'lib/oci/data_safe/models/discovery_job.rb', line 479

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


459
460
461
# File 'lib/oci/data_safe/models/discovery_job.rb', line 459

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



468
469
470
# File 'lib/oci/data_safe/models/discovery_job.rb', line 468

def hash
  [id, discovery_type, display_name, compartment_id, time_started, time_finished, lifecycle_state, sensitive_data_model_id, target_id, schemas_for_discovery, sensitive_type_ids_for_discovery, is_sample_data_collection_enabled, is_app_defined_relation_discovery_enabled, is_include_all_schemas, is_include_all_sensitive_types, total_schemas_scanned, total_objects_scanned, total_columns_scanned, total_new_sensitive_columns, total_modified_sensitive_columns, total_deleted_sensitive_columns, freeform_tags, defined_tags, system_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



512
513
514
515
516
517
518
519
520
521
# File 'lib/oci/data_safe/models/discovery_job.rb', line 512

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



506
507
508
# File 'lib/oci/data_safe/models/discovery_job.rb', line 506

def to_s
  to_hash.to_s
end