Class: OCI::DataSafe::Models::GenerateMaskingReportForDownloadDetails
- Inherits:
-
Object
- Object
- OCI::DataSafe::Models::GenerateMaskingReportForDownloadDetails
- Defined in:
- lib/oci/data_safe/models/generate_masking_report_for_download_details.rb
Overview
Details to generate a downloadable masking report.
Constant Summary collapse
- REPORT_FORMAT_ENUM =
[ REPORT_FORMAT_PDF = 'PDF'.freeze, REPORT_FORMAT_XLS = 'XLS'.freeze ].freeze
Instance Attribute Summary collapse
-
#report_format ⇒ String
[Required] Format of the report.
-
#report_id ⇒ String
[Required] The OCID of the masking report for which a downloadable file is to be generated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GenerateMaskingReportForDownloadDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ GenerateMaskingReportForDownloadDetails
Initializes the object
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/oci/data_safe/models/generate_masking_report_for_download_details.rb', line 51 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.report_id = attributes[:'reportId'] if attributes[:'reportId'] raise 'You cannot provide both :reportId and :report_id' if attributes.key?(:'reportId') && attributes.key?(:'report_id') self.report_id = attributes[:'report_id'] if attributes[:'report_id'] self.report_format = attributes[:'reportFormat'] if attributes[:'reportFormat'] self.report_format = "PDF" if report_format.nil? && !attributes.key?(:'reportFormat') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :reportFormat and :report_format' if attributes.key?(:'reportFormat') && attributes.key?(:'report_format') self.report_format = attributes[:'report_format'] if attributes[:'report_format'] self.report_format = "PDF" if report_format.nil? && !attributes.key?(:'reportFormat') && !attributes.key?(:'report_format') # rubocop:disable Style/StringLiterals end |
Instance Attribute Details
#report_format ⇒ String
[Required] Format of the report.
21 22 23 |
# File 'lib/oci/data_safe/models/generate_masking_report_for_download_details.rb', line 21 def report_format @report_format end |
#report_id ⇒ String
[Required] The OCID of the masking report for which a downloadable file is to be generated.
17 18 19 |
# File 'lib/oci/data_safe/models/generate_masking_report_for_download_details.rb', line 17 def report_id @report_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
24 25 26 27 28 29 30 31 |
# File 'lib/oci/data_safe/models/generate_masking_report_for_download_details.rb', line 24 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'report_id': :'reportId', 'report_format': :'reportFormat' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
34 35 36 37 38 39 40 41 |
# File 'lib/oci/data_safe/models/generate_masking_report_for_download_details.rb', line 34 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'report_id': :'String', 'report_format': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
87 88 89 90 91 92 93 |
# File 'lib/oci/data_safe/models/generate_masking_report_for_download_details.rb', line 87 def ==(other) return true if equal?(other) self.class == other.class && report_id == other.report_id && report_format == other.report_format end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/oci/data_safe/models/generate_masking_report_for_download_details.rb', line 118 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
98 99 100 |
# File 'lib/oci/data_safe/models/generate_masking_report_for_download_details.rb', line 98 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
107 108 109 |
# File 'lib/oci/data_safe/models/generate_masking_report_for_download_details.rb', line 107 def hash [report_id, report_format].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
151 152 153 154 155 156 157 158 159 160 |
# File 'lib/oci/data_safe/models/generate_masking_report_for_download_details.rb', line 151 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
145 146 147 |
# File 'lib/oci/data_safe/models/generate_masking_report_for_download_details.rb', line 145 def to_s to_hash.to_s end |