Class: OCI::DataSafe::Models::LibraryMaskingFormatEntry

Inherits:
FormatEntry
  • Object
show all
Defined in:
lib/oci/data_safe/models/library_masking_format_entry.rb

Overview

A library masking format to be used for masking. It can be either a predefined or a user-defined library masking format. It enables reuse of an existing library masking format and helps avoid defining the masking logic again. Use the ListLibraryMaskingFormats operation to view the existing library masking formats.

Constant Summary

Constants inherited from FormatEntry

FormatEntry::TYPE_ENUM

Instance Attribute Summary collapse

Attributes inherited from FormatEntry

#description, #type

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from FormatEntry

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ LibraryMaskingFormatEntry

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
# File 'lib/oci/data_safe/models/library_masking_format_entry.rb', line 50

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['type'] = 'LIBRARY_MASKING_FORMAT'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.library_masking_format_id = attributes[:'libraryMaskingFormatId'] if attributes[:'libraryMaskingFormatId']

  raise 'You cannot provide both :libraryMaskingFormatId and :library_masking_format_id' if attributes.key?(:'libraryMaskingFormatId') && attributes.key?(:'library_masking_format_id')

  self.library_masking_format_id = attributes[:'library_masking_format_id'] if attributes[:'library_masking_format_id']
end

Instance Attribute Details

#library_masking_format_idString

[Required] The OCID of the library masking format.

Returns:

  • (String)


18
19
20
# File 'lib/oci/data_safe/models/library_masking_format_entry.rb', line 18

def library_masking_format_id
  @library_masking_format_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



21
22
23
24
25
26
27
28
29
# File 'lib/oci/data_safe/models/library_masking_format_entry.rb', line 21

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'type': :'type',
    'description': :'description',
    'library_masking_format_id': :'libraryMaskingFormatId'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



32
33
34
35
36
37
38
39
40
# File 'lib/oci/data_safe/models/library_masking_format_entry.rb', line 32

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'type': :'String',
    'description': :'String',
    'library_masking_format_id': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



74
75
76
77
78
79
80
81
# File 'lib/oci/data_safe/models/library_masking_format_entry.rb', line 74

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    type == other.type &&
    description == other.description &&
    library_masking_format_id == other.library_masking_format_id
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/oci/data_safe/models/library_masking_format_entry.rb', line 106

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


86
87
88
# File 'lib/oci/data_safe/models/library_masking_format_entry.rb', line 86

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



95
96
97
# File 'lib/oci/data_safe/models/library_masking_format_entry.rb', line 95

def hash
  [type, description, library_masking_format_id].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



139
140
141
142
143
144
145
146
147
148
# File 'lib/oci/data_safe/models/library_masking_format_entry.rb', line 139

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



133
134
135
# File 'lib/oci/data_safe/models/library_masking_format_entry.rb', line 133

def to_s
  to_hash.to_s
end