Class: OCI::DataSafe::Models::MaskedColumnSummary
- Inherits:
-
Object
- Object
- OCI::DataSafe::Models::MaskedColumnSummary
- Defined in:
- lib/oci/data_safe/models/masked_column_summary.rb
Overview
Summary of a masked column. A masked column is a database column masked by a data masking request.
Constant Summary collapse
- OBJECT_TYPE_ENUM =
[ OBJECT_TYPE_TABLE = 'TABLE'.freeze, OBJECT_TYPE_EDITIONING_VIEW = 'EDITIONING_VIEW'.freeze, OBJECT_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#column_name ⇒ String
[Required] The name of the masked column.
-
#key ⇒ String
[Required] The unique key that identifies the masked column.
-
#masking_column_group ⇒ String
The masking group of the masked column.
-
#masking_format_used ⇒ String
[Required] The masking format used for masking the column.
-
#object_name ⇒ String
[Required] The name of the object (table or editioning view) that contains the masked column.
-
#object_type ⇒ String
[Required] The type of the object (table or editioning view) that contains the masked column.
-
#parent_column_key ⇒ String
The unique key that identifies the parent column of the masked column.
-
#schema_name ⇒ String
[Required] The name of the schema that contains the masked column.
-
#sensitive_type_id ⇒ String
The OCID of the sensitive type associated with the masked column.
-
#total_masked_values ⇒ Integer
[Required] The total number of values masked in the column.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MaskedColumnSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ MaskedColumnSummary
Initializes the object
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/oci/data_safe/models/masked_column_summary.rb', line 109 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.key = attributes[:'key'] if attributes[:'key'] self.parent_column_key = attributes[:'parentColumnKey'] if attributes[:'parentColumnKey'] raise 'You cannot provide both :parentColumnKey and :parent_column_key' if attributes.key?(:'parentColumnKey') && attributes.key?(:'parent_column_key') self.parent_column_key = attributes[:'parent_column_key'] if attributes[:'parent_column_key'] self.sensitive_type_id = attributes[:'sensitiveTypeId'] if attributes[:'sensitiveTypeId'] raise 'You cannot provide both :sensitiveTypeId and :sensitive_type_id' if attributes.key?(:'sensitiveTypeId') && attributes.key?(:'sensitive_type_id') self.sensitive_type_id = attributes[:'sensitive_type_id'] if attributes[:'sensitive_type_id'] self.schema_name = attributes[:'schemaName'] if attributes[:'schemaName'] raise 'You cannot provide both :schemaName and :schema_name' if attributes.key?(:'schemaName') && attributes.key?(:'schema_name') self.schema_name = attributes[:'schema_name'] if attributes[:'schema_name'] self.object_name = attributes[:'objectName'] if attributes[:'objectName'] raise 'You cannot provide both :objectName and :object_name' if attributes.key?(:'objectName') && attributes.key?(:'object_name') self.object_name = attributes[:'object_name'] if attributes[:'object_name'] self.object_type = attributes[:'objectType'] if attributes[:'objectType'] raise 'You cannot provide both :objectType and :object_type' if attributes.key?(:'objectType') && attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] if attributes[:'object_type'] self.column_name = attributes[:'columnName'] if attributes[:'columnName'] raise 'You cannot provide both :columnName and :column_name' if attributes.key?(:'columnName') && attributes.key?(:'column_name') self.column_name = attributes[:'column_name'] if attributes[:'column_name'] self.masking_column_group = attributes[:'maskingColumnGroup'] if attributes[:'maskingColumnGroup'] raise 'You cannot provide both :maskingColumnGroup and :masking_column_group' if attributes.key?(:'maskingColumnGroup') && attributes.key?(:'masking_column_group') self.masking_column_group = attributes[:'masking_column_group'] if attributes[:'masking_column_group'] self.masking_format_used = attributes[:'maskingFormatUsed'] if attributes[:'maskingFormatUsed'] raise 'You cannot provide both :maskingFormatUsed and :masking_format_used' if attributes.key?(:'maskingFormatUsed') && attributes.key?(:'masking_format_used') self.masking_format_used = attributes[:'masking_format_used'] if attributes[:'masking_format_used'] self.total_masked_values = attributes[:'totalMaskedValues'] if attributes[:'totalMaskedValues'] raise 'You cannot provide both :totalMaskedValues and :total_masked_values' if attributes.key?(:'totalMaskedValues') && attributes.key?(:'total_masked_values') self.total_masked_values = attributes[:'total_masked_values'] if attributes[:'total_masked_values'] end |
Instance Attribute Details
#column_name ⇒ String
[Required] The name of the masked column.
43 44 45 |
# File 'lib/oci/data_safe/models/masked_column_summary.rb', line 43 def column_name @column_name end |
#key ⇒ String
[Required] The unique key that identifies the masked column. It’s numeric and unique within a masking policy.
19 20 21 |
# File 'lib/oci/data_safe/models/masked_column_summary.rb', line 19 def key @key end |
#masking_column_group ⇒ String
The masking group of the masked column.
47 48 49 |
# File 'lib/oci/data_safe/models/masked_column_summary.rb', line 47 def masking_column_group @masking_column_group end |
#masking_format_used ⇒ String
[Required] The masking format used for masking the column.
51 52 53 |
# File 'lib/oci/data_safe/models/masked_column_summary.rb', line 51 def masking_format_used @masking_format_used end |
#object_name ⇒ String
[Required] The name of the object (table or editioning view) that contains the masked column.
35 36 37 |
# File 'lib/oci/data_safe/models/masked_column_summary.rb', line 35 def object_name @object_name end |
#object_type ⇒ String
[Required] The type of the object (table or editioning view) that contains the masked column.
39 40 41 |
# File 'lib/oci/data_safe/models/masked_column_summary.rb', line 39 def object_type @object_type end |
#parent_column_key ⇒ String
The unique key that identifies the parent column of the masked column.
23 24 25 |
# File 'lib/oci/data_safe/models/masked_column_summary.rb', line 23 def parent_column_key @parent_column_key end |
#schema_name ⇒ String
[Required] The name of the schema that contains the masked column.
31 32 33 |
# File 'lib/oci/data_safe/models/masked_column_summary.rb', line 31 def schema_name @schema_name end |
#sensitive_type_id ⇒ String
The OCID of the sensitive type associated with the masked column.
27 28 29 |
# File 'lib/oci/data_safe/models/masked_column_summary.rb', line 27 def sensitive_type_id @sensitive_type_id end |
#total_masked_values ⇒ Integer
[Required] The total number of values masked in the column.
55 56 57 |
# File 'lib/oci/data_safe/models/masked_column_summary.rb', line 55 def total_masked_values @total_masked_values end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/oci/data_safe/models/masked_column_summary.rb', line 58 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'key': :'key', 'parent_column_key': :'parentColumnKey', 'sensitive_type_id': :'sensitiveTypeId', 'schema_name': :'schemaName', 'object_name': :'objectName', 'object_type': :'objectType', 'column_name': :'columnName', 'masking_column_group': :'maskingColumnGroup', 'masking_format_used': :'maskingFormatUsed', 'total_masked_values': :'totalMaskedValues' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/oci/data_safe/models/masked_column_summary.rb', line 76 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'key': :'String', 'parent_column_key': :'String', 'sensitive_type_id': :'String', 'schema_name': :'String', 'object_name': :'String', 'object_type': :'String', 'column_name': :'String', 'masking_column_group': :'String', 'masking_format_used': :'String', 'total_masked_values': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/oci/data_safe/models/masked_column_summary.rb', line 192 def ==(other) return true if equal?(other) self.class == other.class && key == other.key && parent_column_key == other.parent_column_key && sensitive_type_id == other.sensitive_type_id && schema_name == other.schema_name && object_name == other.object_name && object_type == other.object_type && column_name == other.column_name && masking_column_group == other.masking_column_group && masking_format_used == other.masking_format_used && total_masked_values == other.total_masked_values end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/oci/data_safe/models/masked_column_summary.rb', line 231 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
211 212 213 |
# File 'lib/oci/data_safe/models/masked_column_summary.rb', line 211 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
220 221 222 |
# File 'lib/oci/data_safe/models/masked_column_summary.rb', line 220 def hash [key, parent_column_key, sensitive_type_id, schema_name, object_name, object_type, column_name, masking_column_group, masking_format_used, total_masked_values].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
264 265 266 267 268 269 270 271 272 273 |
# File 'lib/oci/data_safe/models/masked_column_summary.rb', line 264 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
258 259 260 |
# File 'lib/oci/data_safe/models/masked_column_summary.rb', line 258 def to_s to_hash.to_s end |