Class: OCI::DataSafe::Models::MaskingFormat
- Inherits:
-
Object
- Object
- OCI::DataSafe::Models::MaskingFormat
- Defined in:
- lib/oci/data_safe/models/masking_format.rb
Overview
A masking format defines the logic to mask data in a database column. The condition attribute defines the condition that must be true for applying the masking format. It enables you to do <a href="docs.oracle.com/en/cloud/paas/data-safe/udscs/conditional-masking.html">conditional masking</a> so that you can mask the column data values differently using different masking formats and the associated conditions. A masking format can have one or more format entries. A format entry can be a basic masking format such as Random Number, or it can be a library masking format.The combined output of all the format entries is used for masking. It provides the flexibility to define a masking format that can generate different parts of a data value separately and then combine them to get the final data value for masking.
Instance Attribute Summary collapse
-
#condition ⇒ String
A condition that must be true for applying the masking format.
-
#description ⇒ String
The description of the masking format.
-
#format_entries ⇒ Array<OCI::DataSafe::Models::FormatEntry>
[Required] An array of format entries.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MaskingFormat
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ MaskingFormat
Initializes the object
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/oci/data_safe/models/masking_format.rb', line 69 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.condition = attributes[:'condition'] if attributes[:'condition'] self.description = attributes[:'description'] if attributes[:'description'] self.format_entries = attributes[:'formatEntries'] if attributes[:'formatEntries'] raise 'You cannot provide both :formatEntries and :format_entries' if attributes.key?(:'formatEntries') && attributes.key?(:'format_entries') self.format_entries = attributes[:'format_entries'] if attributes[:'format_entries'] end |
Instance Attribute Details
#condition ⇒ String
A condition that must be true for applying the masking format. It can be any valid SQL construct that can be used in a SQL predicate. It enables you to do <a href="docs.oracle.com/en/cloud/paas/data-safe/udscs/conditional-masking.html">conditional masking</a> so that you can mask the column data values differently using different masking formats and the associated conditions.
26 27 28 |
# File 'lib/oci/data_safe/models/masking_format.rb', line 26 def condition @condition end |
#description ⇒ String
The description of the masking format.
30 31 32 |
# File 'lib/oci/data_safe/models/masking_format.rb', line 30 def description @description end |
#format_entries ⇒ Array<OCI::DataSafe::Models::FormatEntry>
[Required] An array of format entries. The combined output of all the format entries is used for masking the column data values.
36 37 38 |
# File 'lib/oci/data_safe/models/masking_format.rb', line 36 def format_entries @format_entries end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 |
# File 'lib/oci/data_safe/models/masking_format.rb', line 39 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'condition': :'condition', 'description': :'description', 'format_entries': :'formatEntries' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
50 51 52 53 54 55 56 57 58 |
# File 'lib/oci/data_safe/models/masking_format.rb', line 50 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'condition': :'String', 'description': :'String', 'format_entries': :'Array<OCI::DataSafe::Models::FormatEntry>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
93 94 95 96 97 98 99 100 |
# File 'lib/oci/data_safe/models/masking_format.rb', line 93 def ==(other) return true if equal?(other) self.class == other.class && condition == other.condition && description == other.description && format_entries == other.format_entries end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/oci/data_safe/models/masking_format.rb', line 125 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
105 106 107 |
# File 'lib/oci/data_safe/models/masking_format.rb', line 105 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
114 115 116 |
# File 'lib/oci/data_safe/models/masking_format.rb', line 114 def hash [condition, description, format_entries].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
158 159 160 161 162 163 164 165 166 167 |
# File 'lib/oci/data_safe/models/masking_format.rb', line 158 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
152 153 154 |
# File 'lib/oci/data_safe/models/masking_format.rb', line 152 def to_s to_hash.to_s end |