Class: OCI::DataSafe::Models::MaskingReportSummary
- Inherits:
-
Object
- Object
- OCI::DataSafe::Models::MaskingReportSummary
- Defined in:
- lib/oci/data_safe/models/masking_report_summary.rb
Overview
Summary of a masking report.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The OCID of the compartment that contains the masking report.
-
#id ⇒ String
[Required] The OCID of the masking report.
-
#masking_policy_id ⇒ String
[Required] The OCID of the masking policy used.
-
#masking_work_request_id ⇒ String
[Required] The OCID of the masking work request that resulted in this masking report.
-
#target_id ⇒ String
[Required] The OCID of the target database masked.
-
#time_masking_finished ⇒ DateTime
[Required] The date and time data masking finished, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#time_masking_started ⇒ DateTime
[Required] The date and time data masking started, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#total_masked_columns ⇒ Integer
[Required] The total number of masked columns.
-
#total_masked_objects ⇒ Integer
[Required] The total number of unique objects (tables and editioning views) that contain the masked columns.
-
#total_masked_schemas ⇒ Integer
[Required] The total number of unique schemas that contain the masked columns.
-
#total_masked_sensitive_types ⇒ Integer
[Required] The total number of unique sensitive types associated with the masked columns.
-
#total_masked_values ⇒ Integer
[Required] The total number of masked values.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MaskingReportSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ MaskingReportSummary
Initializes the object
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/oci/data_safe/models/masking_report_summary.rb', line 116 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.masking_work_request_id = attributes[:'maskingWorkRequestId'] if attributes[:'maskingWorkRequestId'] raise 'You cannot provide both :maskingWorkRequestId and :masking_work_request_id' if attributes.key?(:'maskingWorkRequestId') && attributes.key?(:'masking_work_request_id') self.masking_work_request_id = attributes[:'masking_work_request_id'] if attributes[:'masking_work_request_id'] self.masking_policy_id = attributes[:'maskingPolicyId'] if attributes[:'maskingPolicyId'] raise 'You cannot provide both :maskingPolicyId and :masking_policy_id' if attributes.key?(:'maskingPolicyId') && attributes.key?(:'masking_policy_id') self.masking_policy_id = attributes[:'masking_policy_id'] if attributes[:'masking_policy_id'] self.target_id = attributes[:'targetId'] if attributes[:'targetId'] raise 'You cannot provide both :targetId and :target_id' if attributes.key?(:'targetId') && attributes.key?(:'target_id') self.target_id = attributes[:'target_id'] if attributes[:'target_id'] self.total_masked_sensitive_types = attributes[:'totalMaskedSensitiveTypes'] if attributes[:'totalMaskedSensitiveTypes'] raise 'You cannot provide both :totalMaskedSensitiveTypes and :total_masked_sensitive_types' if attributes.key?(:'totalMaskedSensitiveTypes') && attributes.key?(:'total_masked_sensitive_types') self.total_masked_sensitive_types = attributes[:'total_masked_sensitive_types'] if attributes[:'total_masked_sensitive_types'] self.total_masked_schemas = attributes[:'totalMaskedSchemas'] if attributes[:'totalMaskedSchemas'] raise 'You cannot provide both :totalMaskedSchemas and :total_masked_schemas' if attributes.key?(:'totalMaskedSchemas') && attributes.key?(:'total_masked_schemas') self.total_masked_schemas = attributes[:'total_masked_schemas'] if attributes[:'total_masked_schemas'] self.total_masked_objects = attributes[:'totalMaskedObjects'] if attributes[:'totalMaskedObjects'] raise 'You cannot provide both :totalMaskedObjects and :total_masked_objects' if attributes.key?(:'totalMaskedObjects') && attributes.key?(:'total_masked_objects') self.total_masked_objects = attributes[:'total_masked_objects'] if attributes[:'total_masked_objects'] self.total_masked_columns = attributes[:'totalMaskedColumns'] if attributes[:'totalMaskedColumns'] raise 'You cannot provide both :totalMaskedColumns and :total_masked_columns' if attributes.key?(:'totalMaskedColumns') && attributes.key?(:'total_masked_columns') self.total_masked_columns = attributes[:'total_masked_columns'] if attributes[:'total_masked_columns'] self.total_masked_values = attributes[:'totalMaskedValues'] if attributes[:'totalMaskedValues'] raise 'You cannot provide both :totalMaskedValues and :total_masked_values' if attributes.key?(:'totalMaskedValues') && attributes.key?(:'total_masked_values') self.total_masked_values = attributes[:'total_masked_values'] if attributes[:'total_masked_values'] self.time_masking_started = attributes[:'timeMaskingStarted'] if attributes[:'timeMaskingStarted'] raise 'You cannot provide both :timeMaskingStarted and :time_masking_started' if attributes.key?(:'timeMaskingStarted') && attributes.key?(:'time_masking_started') self.time_masking_started = attributes[:'time_masking_started'] if attributes[:'time_masking_started'] self.time_masking_finished = attributes[:'timeMaskingFinished'] if attributes[:'timeMaskingFinished'] raise 'You cannot provide both :timeMaskingFinished and :time_masking_finished' if attributes.key?(:'timeMaskingFinished') && attributes.key?(:'time_masking_finished') self.time_masking_finished = attributes[:'time_masking_finished'] if attributes[:'time_masking_finished'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The OCID of the compartment that contains the masking report.
16 17 18 |
# File 'lib/oci/data_safe/models/masking_report_summary.rb', line 16 def compartment_id @compartment_id end |
#id ⇒ String
[Required] The OCID of the masking report.
12 13 14 |
# File 'lib/oci/data_safe/models/masking_report_summary.rb', line 12 def id @id end |
#masking_policy_id ⇒ String
[Required] The OCID of the masking policy used.
24 25 26 |
# File 'lib/oci/data_safe/models/masking_report_summary.rb', line 24 def masking_policy_id @masking_policy_id end |
#masking_work_request_id ⇒ String
[Required] The OCID of the masking work request that resulted in this masking report.
20 21 22 |
# File 'lib/oci/data_safe/models/masking_report_summary.rb', line 20 def masking_work_request_id @masking_work_request_id end |
#target_id ⇒ String
[Required] The OCID of the target database masked.
28 29 30 |
# File 'lib/oci/data_safe/models/masking_report_summary.rb', line 28 def target_id @target_id end |
#time_masking_finished ⇒ DateTime
[Required] The date and time data masking finished, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339)
56 57 58 |
# File 'lib/oci/data_safe/models/masking_report_summary.rb', line 56 def time_masking_finished @time_masking_finished end |
#time_masking_started ⇒ DateTime
[Required] The date and time data masking started, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339)
52 53 54 |
# File 'lib/oci/data_safe/models/masking_report_summary.rb', line 52 def time_masking_started @time_masking_started end |
#total_masked_columns ⇒ Integer
[Required] The total number of masked columns.
44 45 46 |
# File 'lib/oci/data_safe/models/masking_report_summary.rb', line 44 def total_masked_columns @total_masked_columns end |
#total_masked_objects ⇒ Integer
[Required] The total number of unique objects (tables and editioning views) that contain the masked columns.
40 41 42 |
# File 'lib/oci/data_safe/models/masking_report_summary.rb', line 40 def total_masked_objects @total_masked_objects end |
#total_masked_schemas ⇒ Integer
[Required] The total number of unique schemas that contain the masked columns.
36 37 38 |
# File 'lib/oci/data_safe/models/masking_report_summary.rb', line 36 def total_masked_schemas @total_masked_schemas end |
#total_masked_sensitive_types ⇒ Integer
[Required] The total number of unique sensitive types associated with the masked columns.
32 33 34 |
# File 'lib/oci/data_safe/models/masking_report_summary.rb', line 32 def total_masked_sensitive_types @total_masked_sensitive_types end |
#total_masked_values ⇒ Integer
[Required] The total number of masked values.
48 49 50 |
# File 'lib/oci/data_safe/models/masking_report_summary.rb', line 48 def total_masked_values @total_masked_values end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/oci/data_safe/models/masking_report_summary.rb', line 59 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'masking_work_request_id': :'maskingWorkRequestId', 'masking_policy_id': :'maskingPolicyId', 'target_id': :'targetId', 'total_masked_sensitive_types': :'totalMaskedSensitiveTypes', 'total_masked_schemas': :'totalMaskedSchemas', 'total_masked_objects': :'totalMaskedObjects', 'total_masked_columns': :'totalMaskedColumns', 'total_masked_values': :'totalMaskedValues', 'time_masking_started': :'timeMaskingStarted', 'time_masking_finished': :'timeMaskingFinished' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/oci/data_safe/models/masking_report_summary.rb', line 79 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'masking_work_request_id': :'String', 'masking_policy_id': :'String', 'target_id': :'String', 'total_masked_sensitive_types': :'Integer', 'total_masked_schemas': :'Integer', 'total_masked_objects': :'Integer', 'total_masked_columns': :'Integer', 'total_masked_values': :'Integer', 'time_masking_started': :'DateTime', 'time_masking_finished': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/oci/data_safe/models/masking_report_summary.rb', line 198 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && masking_work_request_id == other.masking_work_request_id && masking_policy_id == other.masking_policy_id && target_id == other.target_id && total_masked_sensitive_types == other.total_masked_sensitive_types && total_masked_schemas == other.total_masked_schemas && total_masked_objects == other.total_masked_objects && total_masked_columns == other.total_masked_columns && total_masked_values == other.total_masked_values && time_masking_started == other.time_masking_started && time_masking_finished == other.time_masking_finished end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/oci/data_safe/models/masking_report_summary.rb', line 239 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
219 220 221 |
# File 'lib/oci/data_safe/models/masking_report_summary.rb', line 219 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
228 229 230 |
# File 'lib/oci/data_safe/models/masking_report_summary.rb', line 228 def hash [id, compartment_id, masking_work_request_id, masking_policy_id, target_id, total_masked_sensitive_types, total_masked_schemas, total_masked_objects, total_masked_columns, total_masked_values, time_masking_started, time_masking_finished].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
272 273 274 275 276 277 278 279 280 281 |
# File 'lib/oci/data_safe/models/masking_report_summary.rb', line 272 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
266 267 268 |
# File 'lib/oci/data_safe/models/masking_report_summary.rb', line 266 def to_s to_hash.to_s end |