Class: OCI::DataSafe::Models::PPFFormatEntry
- Inherits:
-
FormatEntry
- Object
- FormatEntry
- OCI::DataSafe::Models::PPFFormatEntry
- Defined in:
- lib/oci/data_safe/models/ppf_format_entry.rb
Overview
The Post Processing Function masking format is a special masking option that enables you to use a custom function to further transform column values after they have been masked using some other masking formats. It takes the intermediate masked values as input and returns the final masked values. For example, you can use it for adding checksums or special encodings to the masked values.
A post-processing function has the same signature as a user-defined function, but it passes in the masked values the masking engine generates, and returns the final masked values that should be used for masking. To learn more, check Post Processing Function in the Data Safe documentation.
Constant Summary
Constants inherited from FormatEntry
Instance Attribute Summary collapse
-
#post_processing_function ⇒ String
[Required] The post processing function in SCHEMA_NAME.PACKAGE_NAME.FUNCTION_NAME format.
Attributes inherited from FormatEntry
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PPFFormatEntry
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from FormatEntry
Constructor Details
#initialize(attributes = {}) ⇒ PPFFormatEntry
Initializes the object
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/oci/data_safe/models/ppf_format_entry.rb', line 58 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['type'] = 'POST_PROCESSING_FUNCTION' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.post_processing_function = attributes[:'postProcessingFunction'] if attributes[:'postProcessingFunction'] raise 'You cannot provide both :postProcessingFunction and :post_processing_function' if attributes.key?(:'postProcessingFunction') && attributes.key?(:'post_processing_function') self.post_processing_function = attributes[:'post_processing_function'] if attributes[:'post_processing_function'] end |
Instance Attribute Details
#post_processing_function ⇒ String
[Required] The post processing function in SCHEMA_NAME.PACKAGE_NAME.FUNCTION_NAME format. It can be a standalone or packaged function, so PACKAGE_NAME is optional.
26 27 28 |
# File 'lib/oci/data_safe/models/ppf_format_entry.rb', line 26 def post_processing_function @post_processing_function end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 36 37 |
# File 'lib/oci/data_safe/models/ppf_format_entry.rb', line 29 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'type': :'type', 'description': :'description', 'post_processing_function': :'postProcessingFunction' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
40 41 42 43 44 45 46 47 48 |
# File 'lib/oci/data_safe/models/ppf_format_entry.rb', line 40 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'type': :'String', 'description': :'String', 'post_processing_function': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
82 83 84 85 86 87 88 89 |
# File 'lib/oci/data_safe/models/ppf_format_entry.rb', line 82 def ==(other) return true if equal?(other) self.class == other.class && type == other.type && description == other.description && post_processing_function == other.post_processing_function end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/oci/data_safe/models/ppf_format_entry.rb', line 114 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
94 95 96 |
# File 'lib/oci/data_safe/models/ppf_format_entry.rb', line 94 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
103 104 105 |
# File 'lib/oci/data_safe/models/ppf_format_entry.rb', line 103 def hash [type, description, post_processing_function].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
147 148 149 150 151 152 153 154 155 156 |
# File 'lib/oci/data_safe/models/ppf_format_entry.rb', line 147 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
141 142 143 |
# File 'lib/oci/data_safe/models/ppf_format_entry.rb', line 141 def to_s to_hash.to_s end |