Class: OCI::DataSafe::Models::RandomListFormatEntry

Inherits:
FormatEntry
  • Object
show all
Defined in:
lib/oci/data_safe/models/random_list_format_entry.rb

Overview

The Random List masking format randomly selects values from a list of values to replace the original values. To learn more, check Random List in the Data Safe documentation.

Constant Summary

Constants inherited from FormatEntry

FormatEntry::TYPE_ENUM

Instance Attribute Summary collapse

Attributes inherited from FormatEntry

#description, #type

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from FormatEntry

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ RandomListFormatEntry

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :description (String)

    The value to assign to the #description proprety

  • :random_list (Array<String>)

    The value to assign to the #random_list property



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/oci/data_safe/models/random_list_format_entry.rb', line 52

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['type'] = 'RANDOM_LIST'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.random_list = attributes[:'randomList'] if attributes[:'randomList']

  raise 'You cannot provide both :randomList and :random_list' if attributes.key?(:'randomList') && attributes.key?(:'random_list')

  self.random_list = attributes[:'random_list'] if attributes[:'random_list']
end

Instance Attribute Details

#random_listArray<String>

[Required] A comma-separated list of values to be used to replace column values. The list can be of strings, numbers, or dates. The data type of each value in the list must be compatible with the data type of the column. The number of entries in the list cannot be more than 999.

Returns:

  • (Array<String>)


20
21
22
# File 'lib/oci/data_safe/models/random_list_format_entry.rb', line 20

def random_list
  @random_list
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



23
24
25
26
27
28
29
30
31
# File 'lib/oci/data_safe/models/random_list_format_entry.rb', line 23

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'type': :'type',
    'description': :'description',
    'random_list': :'randomList'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



34
35
36
37
38
39
40
41
42
# File 'lib/oci/data_safe/models/random_list_format_entry.rb', line 34

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'type': :'String',
    'description': :'String',
    'random_list': :'Array<String>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



76
77
78
79
80
81
82
83
# File 'lib/oci/data_safe/models/random_list_format_entry.rb', line 76

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    type == other.type &&
    description == other.description &&
    random_list == other.random_list
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/oci/data_safe/models/random_list_format_entry.rb', line 108

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


88
89
90
# File 'lib/oci/data_safe/models/random_list_format_entry.rb', line 88

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



97
98
99
# File 'lib/oci/data_safe/models/random_list_format_entry.rb', line 97

def hash
  [type, description, random_list].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



141
142
143
144
145
146
147
148
149
150
# File 'lib/oci/data_safe/models/random_list_format_entry.rb', line 141

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



135
136
137
# File 'lib/oci/data_safe/models/random_list_format_entry.rb', line 135

def to_s
  to_hash.to_s
end