Class: OCI::DataSafe::Models::RandomNumberFormatEntry
- Inherits:
-
FormatEntry
- Object
- FormatEntry
- OCI::DataSafe::Models::RandomNumberFormatEntry
- Defined in:
- lib/oci/data_safe/models/random_number_format_entry.rb
Overview
The Random Number masking format generates random and unique integers within a range. The range is defined by the startValue and endValue attributes. The start value must be less than or equal to the end value. When masking columns with uniqueness constraint, ensure that the range is sufficient enough to generate unique values. To learn more, check Random Number in the Data Safe documentation.
Constant Summary
Constants inherited from FormatEntry
Instance Attribute Summary collapse
-
#end_value ⇒ Integer
[Required] The upper bound of the range within which random numbers should be generated.
-
#start_value ⇒ Integer
[Required] The lower bound of the range within which random numbers should be generated.
Attributes inherited from FormatEntry
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RandomNumberFormatEntry
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from FormatEntry
Constructor Details
#initialize(attributes = {}) ⇒ RandomNumberFormatEntry
Initializes the object
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/oci/data_safe/models/random_number_format_entry.rb', line 64 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['type'] = 'RANDOM_NUMBER' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.start_value = attributes[:'startValue'] if attributes[:'startValue'] raise 'You cannot provide both :startValue and :start_value' if attributes.key?(:'startValue') && attributes.key?(:'start_value') self.start_value = attributes[:'start_value'] if attributes[:'start_value'] self.end_value = attributes[:'endValue'] if attributes[:'endValue'] raise 'You cannot provide both :endValue and :end_value' if attributes.key?(:'endValue') && attributes.key?(:'end_value') self.end_value = attributes[:'end_value'] if attributes[:'end_value'] end |
Instance Attribute Details
#end_value ⇒ Integer
[Required] The upper bound of the range within which random numbers should be generated. It must be greater than or equal to the start value. It supports input of long type.
29 30 31 |
# File 'lib/oci/data_safe/models/random_number_format_entry.rb', line 29 def end_value @end_value end |
#start_value ⇒ Integer
[Required] The lower bound of the range within which random numbers should be generated. It must be less than or equal to the end value. It supports input of long type.
22 23 24 |
# File 'lib/oci/data_safe/models/random_number_format_entry.rb', line 22 def start_value @start_value end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 40 41 |
# File 'lib/oci/data_safe/models/random_number_format_entry.rb', line 32 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'type': :'type', 'description': :'description', 'start_value': :'startValue', 'end_value': :'endValue' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
44 45 46 47 48 49 50 51 52 53 |
# File 'lib/oci/data_safe/models/random_number_format_entry.rb', line 44 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'type': :'String', 'description': :'String', 'start_value': :'Integer', 'end_value': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
94 95 96 97 98 99 100 101 102 |
# File 'lib/oci/data_safe/models/random_number_format_entry.rb', line 94 def ==(other) return true if equal?(other) self.class == other.class && type == other.type && description == other.description && start_value == other.start_value && end_value == other.end_value end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/oci/data_safe/models/random_number_format_entry.rb', line 127 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
107 108 109 |
# File 'lib/oci/data_safe/models/random_number_format_entry.rb', line 107 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
116 117 118 |
# File 'lib/oci/data_safe/models/random_number_format_entry.rb', line 116 def hash [type, description, start_value, end_value].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
160 161 162 163 164 165 166 167 168 169 |
# File 'lib/oci/data_safe/models/random_number_format_entry.rb', line 160 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
154 155 156 |
# File 'lib/oci/data_safe/models/random_number_format_entry.rb', line 154 def to_s to_hash.to_s end |