Class: OCI::DataSafe::Models::RandomSubstitutionFormatEntry
- Inherits:
-
FormatEntry
- Object
- FormatEntry
- OCI::DataSafe::Models::RandomSubstitutionFormatEntry
- Defined in:
- lib/oci/data_safe/models/random_substitution_format_entry.rb
Overview
The Random Substitution masking format uses the specified substitution column as the source of masked values. The values in the substitution column are randomly ordered before mapping them to the original column values. As a masking operation renames tables temporarily, the substitution column must be in a table that has no masking column. Also, you may want to ensure that the substitution column has sufficient values to uniquely mask the target column.
Unlike Deterministic Substitution, Random Substitution doesn’t do deterministic masking, and thus, doesn’t require a seed value. To learn more, check Random Substitution in the Data Safe documentation.
Constant Summary
Constants inherited from FormatEntry
Instance Attribute Summary collapse
-
#column_name ⇒ String
[Required] The name of the substitution column.
-
#schema_name ⇒ String
[Required] The name of the schema that contains the substitution column.
-
#table_name ⇒ String
[Required] The name of the table that contains the substitution column.
Attributes inherited from FormatEntry
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RandomSubstitutionFormatEntry
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from FormatEntry
Constructor Details
#initialize(attributes = {}) ⇒ RandomSubstitutionFormatEntry
Initializes the object
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/oci/data_safe/models/random_substitution_format_entry.rb', line 69 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['type'] = 'RANDOM_SUBSTITUTION' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.schema_name = attributes[:'schemaName'] if attributes[:'schemaName'] raise 'You cannot provide both :schemaName and :schema_name' if attributes.key?(:'schemaName') && attributes.key?(:'schema_name') self.schema_name = attributes[:'schema_name'] if attributes[:'schema_name'] self.table_name = attributes[:'tableName'] if attributes[:'tableName'] raise 'You cannot provide both :tableName and :table_name' if attributes.key?(:'tableName') && attributes.key?(:'table_name') self.table_name = attributes[:'table_name'] if attributes[:'table_name'] self.column_name = attributes[:'columnName'] if attributes[:'columnName'] raise 'You cannot provide both :columnName and :column_name' if attributes.key?(:'columnName') && attributes.key?(:'column_name') self.column_name = attributes[:'column_name'] if attributes[:'column_name'] end |
Instance Attribute Details
#column_name ⇒ String
[Required] The name of the substitution column.
31 32 33 |
# File 'lib/oci/data_safe/models/random_substitution_format_entry.rb', line 31 def column_name @column_name end |
#schema_name ⇒ String
[Required] The name of the schema that contains the substitution column.
23 24 25 |
# File 'lib/oci/data_safe/models/random_substitution_format_entry.rb', line 23 def schema_name @schema_name end |
#table_name ⇒ String
[Required] The name of the table that contains the substitution column.
27 28 29 |
# File 'lib/oci/data_safe/models/random_substitution_format_entry.rb', line 27 def table_name @table_name end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 43 44 |
# File 'lib/oci/data_safe/models/random_substitution_format_entry.rb', line 34 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'type': :'type', 'description': :'description', 'schema_name': :'schemaName', 'table_name': :'tableName', 'column_name': :'columnName' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/oci/data_safe/models/random_substitution_format_entry.rb', line 47 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'type': :'String', 'description': :'String', 'schema_name': :'String', 'table_name': :'String', 'column_name': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
105 106 107 108 109 110 111 112 113 114 |
# File 'lib/oci/data_safe/models/random_substitution_format_entry.rb', line 105 def ==(other) return true if equal?(other) self.class == other.class && type == other.type && description == other.description && schema_name == other.schema_name && table_name == other.table_name && column_name == other.column_name end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/oci/data_safe/models/random_substitution_format_entry.rb', line 139 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
119 120 121 |
# File 'lib/oci/data_safe/models/random_substitution_format_entry.rb', line 119 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
128 129 130 |
# File 'lib/oci/data_safe/models/random_substitution_format_entry.rb', line 128 def hash [type, description, schema_name, table_name, column_name].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
172 173 174 175 176 177 178 179 180 181 |
# File 'lib/oci/data_safe/models/random_substitution_format_entry.rb', line 172 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
166 167 168 |
# File 'lib/oci/data_safe/models/random_substitution_format_entry.rb', line 166 def to_s to_hash.to_s end |