Class: OCI::DataSafe::Models::Report
- Inherits:
-
Object
- Object
- OCI::DataSafe::Models::Report
- Defined in:
- lib/oci/data_safe/models/report.rb
Overview
Description of Report.
Constant Summary collapse
- MIME_TYPE_ENUM =
[ MIME_TYPE_PDF = 'PDF'.freeze, MIME_TYPE_XLS = 'XLS'.freeze, MIME_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The OCID of the compartment containing the report.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
Specifies a description of the report.
-
#display_name ⇒ String
[Required] Name of the report.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] The OCID of the report.
-
#lifecycle_state ⇒ String
[Required] The current state of the report.
-
#mime_type ⇒ String
Specifies the format of report to be excel or pdf.
-
#report_definition_id ⇒ String
The OCID of the report definition.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
System tags for this resource.
-
#time_generated ⇒ DateTime
[Required] Specifies the time at which the report was generated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Report
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Report
Initializes the object
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/oci/data_safe/models/report.rb', line 130 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.report_definition_id = attributes[:'reportDefinitionId'] if attributes[:'reportDefinitionId'] raise 'You cannot provide both :reportDefinitionId and :report_definition_id' if attributes.key?(:'reportDefinitionId') && attributes.key?(:'report_definition_id') self.report_definition_id = attributes[:'report_definition_id'] if attributes[:'report_definition_id'] self.description = attributes[:'description'] if attributes[:'description'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.mime_type = attributes[:'mimeType'] if attributes[:'mimeType'] raise 'You cannot provide both :mimeType and :mime_type' if attributes.key?(:'mimeType') && attributes.key?(:'mime_type') self.mime_type = attributes[:'mime_type'] if attributes[:'mime_type'] self.time_generated = attributes[:'timeGenerated'] if attributes[:'timeGenerated'] raise 'You cannot provide both :timeGenerated and :time_generated' if attributes.key?(:'timeGenerated') && attributes.key?(:'time_generated') self.time_generated = attributes[:'time_generated'] if attributes[:'time_generated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The OCID of the compartment containing the report.
41 42 43 |
# File 'lib/oci/data_safe/models/report.rb', line 41 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)
Example: ‘{"CostCenter": "42"}`
67 68 69 |
# File 'lib/oci/data_safe/models/report.rb', line 67 def end |
#description ⇒ String
Specifies a description of the report.
37 38 39 |
# File 'lib/oci/data_safe/models/report.rb', line 37 def description @description end |
#display_name ⇒ String
[Required] Name of the report.
29 30 31 |
# File 'lib/oci/data_safe/models/report.rb', line 29 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)
Example: ‘"Finance"`
60 61 62 |
# File 'lib/oci/data_safe/models/report.rb', line 60 def end |
#id ⇒ String
[Required] The OCID of the report.
25 26 27 |
# File 'lib/oci/data_safe/models/report.rb', line 25 def id @id end |
#lifecycle_state ⇒ String
[Required] The current state of the report.
53 54 55 |
# File 'lib/oci/data_safe/models/report.rb', line 53 def lifecycle_state @lifecycle_state end |
#mime_type ⇒ String
Specifies the format of report to be excel or pdf
45 46 47 |
# File 'lib/oci/data_safe/models/report.rb', line 45 def mime_type @mime_type end |
#report_definition_id ⇒ String
The OCID of the report definition.
33 34 35 |
# File 'lib/oci/data_safe/models/report.rb', line 33 def report_definition_id @report_definition_id end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
System tags for this resource. Each key is predefined and scoped to a namespace. For more information, see Resource Tags. Example: ‘{"free-tier-retained": "true"}`
73 74 75 |
# File 'lib/oci/data_safe/models/report.rb', line 73 def end |
#time_generated ⇒ DateTime
[Required] Specifies the time at which the report was generated.
49 50 51 |
# File 'lib/oci/data_safe/models/report.rb', line 49 def time_generated @time_generated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/oci/data_safe/models/report.rb', line 76 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'report_definition_id': :'reportDefinitionId', 'description': :'description', 'compartment_id': :'compartmentId', 'mime_type': :'mimeType', 'time_generated': :'timeGenerated', 'lifecycle_state': :'lifecycleState', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/oci/data_safe/models/report.rb', line 95 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'report_definition_id': :'String', 'description': :'String', 'compartment_id': :'String', 'mime_type': :'String', 'time_generated': :'DateTime', 'lifecycle_state': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/oci/data_safe/models/report.rb', line 228 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && report_definition_id == other.report_definition_id && description == other.description && compartment_id == other.compartment_id && mime_type == other.mime_type && time_generated == other.time_generated && lifecycle_state == other.lifecycle_state && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 |
# File 'lib/oci/data_safe/models/report.rb', line 268 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
248 249 250 |
# File 'lib/oci/data_safe/models/report.rb', line 248 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
257 258 259 |
# File 'lib/oci/data_safe/models/report.rb', line 257 def hash [id, display_name, report_definition_id, description, compartment_id, mime_type, time_generated, lifecycle_state, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
301 302 303 304 305 306 307 308 309 310 |
# File 'lib/oci/data_safe/models/report.rb', line 301 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
295 296 297 |
# File 'lib/oci/data_safe/models/report.rb', line 295 def to_s to_hash.to_s end |