Class: OCI::DataSafe::Models::ReportDefinitionSummary
- Inherits:
-
Object
- Object
- OCI::DataSafe::Models::ReportDefinitionSummary
- Defined in:
- lib/oci/data_safe/models/report_definition_summary.rb
Overview
Summary of report definition.
Constant Summary collapse
- CATEGORY_ENUM =
[ CATEGORY_CUSTOM_REPORTS = 'CUSTOM_REPORTS'.freeze, CATEGORY_SUMMARY = 'SUMMARY'.freeze, CATEGORY_ACTIVITY_AUDITING = 'ACTIVITY_AUDITING'.freeze, CATEGORY_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- DATA_SOURCE_ENUM =
[ DATA_SOURCE_EVENTS = 'EVENTS'.freeze, DATA_SOURCE_ALERTS = 'ALERTS'.freeze, DATA_SOURCE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#category ⇒ String
Specifies the name of the category that this report belongs to.
-
#compartment_id ⇒ String
[Required] The OCID of the compartment containing the report definition.
-
#data_source ⇒ String
Specifies the name of a resource that provides data for the report.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
A description of the report definition.
-
#display_name ⇒ String
[Required] Name of the report definition.
-
#display_order ⇒ Integer
Specifies how the report definitions are ordered in the display.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] The OCID of the report definition.
-
#is_seeded ⇒ BOOLEAN
Signifies whether the definition is seeded or user defined.
-
#lifecycle_state ⇒ String
[Required] The current state of the report.
-
#time_created ⇒ DateTime
[Required] Specifies the time at which the report definition was created.
-
#time_updated ⇒ DateTime
The date and time of the report definition update in Data Safe.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ReportDefinitionSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ReportDefinitionSummary
Initializes the object
152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/oci/data_safe/models/report_definition_summary.rb', line 152 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.id = attributes[:'id'] if attributes[:'id'] self.category = attributes[:'category'] if attributes[:'category'] self.description = attributes[:'description'] if attributes[:'description'] self.is_seeded = attributes[:'isSeeded'] unless attributes[:'isSeeded'].nil? raise 'You cannot provide both :isSeeded and :is_seeded' if attributes.key?(:'isSeeded') && attributes.key?(:'is_seeded') self.is_seeded = attributes[:'is_seeded'] unless attributes[:'is_seeded'].nil? self.display_order = attributes[:'displayOrder'] if attributes[:'displayOrder'] raise 'You cannot provide both :displayOrder and :display_order' if attributes.key?(:'displayOrder') && attributes.key?(:'display_order') self.display_order = attributes[:'display_order'] if attributes[:'display_order'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.data_source = attributes[:'dataSource'] if attributes[:'dataSource'] raise 'You cannot provide both :dataSource and :data_source' if attributes.key?(:'dataSource') && attributes.key?(:'data_source') self.data_source = attributes[:'data_source'] if attributes[:'data_source'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#category ⇒ String
Specifies the name of the category that this report belongs to.
43 44 45 |
# File 'lib/oci/data_safe/models/report_definition_summary.rb', line 43 def category @category end |
#compartment_id ⇒ String
[Required] The OCID of the compartment containing the report definition.
67 68 69 |
# File 'lib/oci/data_safe/models/report_definition_summary.rb', line 67 def compartment_id @compartment_id end |
#data_source ⇒ String
Specifies the name of a resource that provides data for the report. For example alerts, events.
71 72 73 |
# File 'lib/oci/data_safe/models/report_definition_summary.rb', line 71 def data_source @data_source end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)
Example: ‘{"CostCenter": "42"}`
89 90 91 |
# File 'lib/oci/data_safe/models/report_definition_summary.rb', line 89 def @defined_tags end |
#description ⇒ String
A description of the report definition.
47 48 49 |
# File 'lib/oci/data_safe/models/report_definition_summary.rb', line 47 def description @description end |
#display_name ⇒ String
[Required] Name of the report definition.
35 36 37 |
# File 'lib/oci/data_safe/models/report_definition_summary.rb', line 35 def display_name @display_name end |
#display_order ⇒ Integer
Specifies how the report definitions are ordered in the display.
55 56 57 |
# File 'lib/oci/data_safe/models/report_definition_summary.rb', line 55 def display_order @display_order end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)
Example: ‘"Finance"`
82 83 84 |
# File 'lib/oci/data_safe/models/report_definition_summary.rb', line 82 def @freeform_tags end |
#id ⇒ String
[Required] The OCID of the report definition.
39 40 41 |
# File 'lib/oci/data_safe/models/report_definition_summary.rb', line 39 def id @id end |
#is_seeded ⇒ BOOLEAN
Signifies whether the definition is seeded or user defined. Values can either be ‘true’ or ‘false’.
51 52 53 |
# File 'lib/oci/data_safe/models/report_definition_summary.rb', line 51 def is_seeded @is_seeded end |
#lifecycle_state ⇒ String
[Required] The current state of the report
75 76 77 |
# File 'lib/oci/data_safe/models/report_definition_summary.rb', line 75 def lifecycle_state @lifecycle_state end |
#time_created ⇒ DateTime
[Required] Specifies the time at which the report definition was created.
59 60 61 |
# File 'lib/oci/data_safe/models/report_definition_summary.rb', line 59 def time_created @time_created end |
#time_updated ⇒ DateTime
The date and time of the report definition update in Data Safe.
63 64 65 |
# File 'lib/oci/data_safe/models/report_definition_summary.rb', line 63 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/oci/data_safe/models/report_definition_summary.rb', line 92 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'id': :'id', 'category': :'category', 'description': :'description', 'is_seeded': :'isSeeded', 'display_order': :'displayOrder', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'compartment_id': :'compartmentId', 'data_source': :'dataSource', 'lifecycle_state': :'lifecycleState', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/oci/data_safe/models/report_definition_summary.rb', line 113 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'id': :'String', 'category': :'String', 'description': :'String', 'is_seeded': :'BOOLEAN', 'display_order': :'Integer', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'compartment_id': :'String', 'data_source': :'String', 'lifecycle_state': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/oci/data_safe/models/report_definition_summary.rb', line 271 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && id == other.id && category == other.category && description == other.description && is_seeded == other.is_seeded && display_order == other.display_order && time_created == other.time_created && time_updated == other.time_updated && compartment_id == other.compartment_id && data_source == other.data_source && lifecycle_state == other.lifecycle_state && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'lib/oci/data_safe/models/report_definition_summary.rb', line 313 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
293 294 295 |
# File 'lib/oci/data_safe/models/report_definition_summary.rb', line 293 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
302 303 304 |
# File 'lib/oci/data_safe/models/report_definition_summary.rb', line 302 def hash [display_name, id, category, description, is_seeded, display_order, time_created, time_updated, compartment_id, data_source, lifecycle_state, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
346 347 348 349 350 351 352 353 354 355 |
# File 'lib/oci/data_safe/models/report_definition_summary.rb', line 346 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
340 341 342 |
# File 'lib/oci/data_safe/models/report_definition_summary.rb', line 340 def to_s to_hash.to_s end |