Class: OCI::DataSafe::Models::RoleSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_safe/models/role_summary.rb

Overview

Details of a role fetched from the database.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ RoleSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :role_name (String)

    The value to assign to the #role_name property

  • :authentication_type (String)

    The value to assign to the #authentication_type property

  • :is_password_required (BOOLEAN)

    The value to assign to the #is_password_required property

  • :is_common (BOOLEAN)

    The value to assign to the #is_common property

  • :is_oracle_maintained (BOOLEAN)

    The value to assign to the #is_oracle_maintained property

  • :is_inherited (BOOLEAN)

    The value to assign to the #is_inherited property

  • :is_implicit (BOOLEAN)

    The value to assign to the #is_implicit property



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/oci/data_safe/models/role_summary.rb', line 81

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.role_name = attributes[:'roleName'] if attributes[:'roleName']

  raise 'You cannot provide both :roleName and :role_name' if attributes.key?(:'roleName') && attributes.key?(:'role_name')

  self.role_name = attributes[:'role_name'] if attributes[:'role_name']

  self.authentication_type = attributes[:'authenticationType'] if attributes[:'authenticationType']

  raise 'You cannot provide both :authenticationType and :authentication_type' if attributes.key?(:'authenticationType') && attributes.key?(:'authentication_type')

  self.authentication_type = attributes[:'authentication_type'] if attributes[:'authentication_type']

  self.is_password_required = attributes[:'isPasswordRequired'] unless attributes[:'isPasswordRequired'].nil?

  raise 'You cannot provide both :isPasswordRequired and :is_password_required' if attributes.key?(:'isPasswordRequired') && attributes.key?(:'is_password_required')

  self.is_password_required = attributes[:'is_password_required'] unless attributes[:'is_password_required'].nil?

  self.is_common = attributes[:'isCommon'] unless attributes[:'isCommon'].nil?

  raise 'You cannot provide both :isCommon and :is_common' if attributes.key?(:'isCommon') && attributes.key?(:'is_common')

  self.is_common = attributes[:'is_common'] unless attributes[:'is_common'].nil?

  self.is_oracle_maintained = attributes[:'isOracleMaintained'] unless attributes[:'isOracleMaintained'].nil?

  raise 'You cannot provide both :isOracleMaintained and :is_oracle_maintained' if attributes.key?(:'isOracleMaintained') && attributes.key?(:'is_oracle_maintained')

  self.is_oracle_maintained = attributes[:'is_oracle_maintained'] unless attributes[:'is_oracle_maintained'].nil?

  self.is_inherited = attributes[:'isInherited'] unless attributes[:'isInherited'].nil?

  raise 'You cannot provide both :isInherited and :is_inherited' if attributes.key?(:'isInherited') && attributes.key?(:'is_inherited')

  self.is_inherited = attributes[:'is_inherited'] unless attributes[:'is_inherited'].nil?

  self.is_implicit = attributes[:'isImplicit'] unless attributes[:'isImplicit'].nil?

  raise 'You cannot provide both :isImplicit and :is_implicit' if attributes.key?(:'isImplicit') && attributes.key?(:'is_implicit')

  self.is_implicit = attributes[:'is_implicit'] unless attributes[:'is_implicit'].nil?
end

Instance Attribute Details

#authentication_typeString

[Required] Type of authentication.

Returns:

  • (String)


16
17
18
# File 'lib/oci/data_safe/models/role_summary.rb', line 16

def authentication_type
  @authentication_type
end

#is_commonBOOLEAN

Is the role common.

Returns:

  • (BOOLEAN)


24
25
26
# File 'lib/oci/data_safe/models/role_summary.rb', line 24

def is_common
  @is_common
end

#is_implicitBOOLEAN

Is the role implicit.

Returns:

  • (BOOLEAN)


36
37
38
# File 'lib/oci/data_safe/models/role_summary.rb', line 36

def is_implicit
  @is_implicit
end

#is_inheritedBOOLEAN

Is the role inherited.

Returns:

  • (BOOLEAN)


32
33
34
# File 'lib/oci/data_safe/models/role_summary.rb', line 32

def is_inherited
  @is_inherited
end

#is_oracle_maintainedBOOLEAN

Is the role oracle maintained.

Returns:

  • (BOOLEAN)


28
29
30
# File 'lib/oci/data_safe/models/role_summary.rb', line 28

def is_oracle_maintained
  @is_oracle_maintained
end

#is_password_requiredBOOLEAN

Is password required.

Returns:

  • (BOOLEAN)


20
21
22
# File 'lib/oci/data_safe/models/role_summary.rb', line 20

def is_password_required
  @is_password_required
end

#role_nameString

[Required] Name of the role.

Returns:

  • (String)


12
13
14
# File 'lib/oci/data_safe/models/role_summary.rb', line 12

def role_name
  @role_name
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



39
40
41
42
43
44
45
46
47
48
49
50
51
# File 'lib/oci/data_safe/models/role_summary.rb', line 39

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'role_name': :'roleName',
    'authentication_type': :'authenticationType',
    'is_password_required': :'isPasswordRequired',
    'is_common': :'isCommon',
    'is_oracle_maintained': :'isOracleMaintained',
    'is_inherited': :'isInherited',
    'is_implicit': :'isImplicit'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/oci/data_safe/models/role_summary.rb', line 54

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'role_name': :'String',
    'authentication_type': :'String',
    'is_password_required': :'BOOLEAN',
    'is_common': :'BOOLEAN',
    'is_oracle_maintained': :'BOOLEAN',
    'is_inherited': :'BOOLEAN',
    'is_implicit': :'BOOLEAN'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



137
138
139
140
141
142
143
144
145
146
147
148
# File 'lib/oci/data_safe/models/role_summary.rb', line 137

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    role_name == other.role_name &&
    authentication_type == other.authentication_type &&
    is_password_required == other.is_password_required &&
    is_common == other.is_common &&
    is_oracle_maintained == other.is_oracle_maintained &&
    is_inherited == other.is_inherited &&
    is_implicit == other.is_implicit
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/oci/data_safe/models/role_summary.rb', line 173

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


153
154
155
# File 'lib/oci/data_safe/models/role_summary.rb', line 153

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



162
163
164
# File 'lib/oci/data_safe/models/role_summary.rb', line 162

def hash
  [role_name, authentication_type, is_password_required, is_common, is_oracle_maintained, is_inherited, is_implicit].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



206
207
208
209
210
211
212
213
214
215
# File 'lib/oci/data_safe/models/role_summary.rb', line 206

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



200
201
202
# File 'lib/oci/data_safe/models/role_summary.rb', line 200

def to_s
  to_hash.to_s
end