Class: OCI::DataSafe::Models::SecurityAssessmentComparison
- Inherits:
-
Object
- Object
- OCI::DataSafe::Models::SecurityAssessmentComparison
- Defined in:
- lib/oci/data_safe/models/security_assessment_comparison.rb
Overview
Provides a list of the differences in a comparison of the security assessment with the baseline value.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_SUCCEEDED = 'SUCCEEDED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#baseline_id ⇒ String
The OCID of the security assessment that is set as a baseline.
-
#id ⇒ String
The OCID of the security assessment that is being compared with a baseline security assessment.
-
#lifecycle_state ⇒ String
[Required] The current state of the security assessment comparison.
-
#targets ⇒ Array<OCI::DataSafe::Models::SecurityAssessmentComparisonPerTarget>
A target-based comparison between two security assessments.
-
#time_created ⇒ DateTime
[Required] The date and time when the security assessment comparison was created.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SecurityAssessmentComparison
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ SecurityAssessmentComparison
Initializes the object
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/oci/data_safe/models/security_assessment_comparison.rb', line 76 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.baseline_id = attributes[:'baselineId'] if attributes[:'baselineId'] raise 'You cannot provide both :baselineId and :baseline_id' if attributes.key?(:'baselineId') && attributes.key?(:'baseline_id') self.baseline_id = attributes[:'baseline_id'] if attributes[:'baseline_id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.targets = attributes[:'targets'] if attributes[:'targets'] end |
Instance Attribute Details
#baseline_id ⇒ String
The OCID of the security assessment that is set as a baseline.
25 26 27 |
# File 'lib/oci/data_safe/models/security_assessment_comparison.rb', line 25 def baseline_id @baseline_id end |
#id ⇒ String
The OCID of the security assessment that is being compared with a baseline security assessment.
21 22 23 |
# File 'lib/oci/data_safe/models/security_assessment_comparison.rb', line 21 def id @id end |
#lifecycle_state ⇒ String
[Required] The current state of the security assessment comparison.
29 30 31 |
# File 'lib/oci/data_safe/models/security_assessment_comparison.rb', line 29 def lifecycle_state @lifecycle_state end |
#targets ⇒ Array<OCI::DataSafe::Models::SecurityAssessmentComparisonPerTarget>
A target-based comparison between two security assessments.
37 38 39 |
# File 'lib/oci/data_safe/models/security_assessment_comparison.rb', line 37 def targets @targets end |
#time_created ⇒ DateTime
[Required] The date and time when the security assessment comparison was created. Conforms to the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
33 34 35 |
# File 'lib/oci/data_safe/models/security_assessment_comparison.rb', line 33 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/oci/data_safe/models/security_assessment_comparison.rb', line 40 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'baseline_id': :'baselineId', 'lifecycle_state': :'lifecycleState', 'time_created': :'timeCreated', 'targets': :'targets' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/oci/data_safe/models/security_assessment_comparison.rb', line 53 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'baseline_id': :'String', 'lifecycle_state': :'String', 'time_created': :'DateTime', 'targets': :'Array<OCI::DataSafe::Models::SecurityAssessmentComparisonPerTarget>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
125 126 127 128 129 130 131 132 133 134 |
# File 'lib/oci/data_safe/models/security_assessment_comparison.rb', line 125 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && baseline_id == other.baseline_id && lifecycle_state == other.lifecycle_state && time_created == other.time_created && targets == other.targets end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/oci/data_safe/models/security_assessment_comparison.rb', line 159 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
139 140 141 |
# File 'lib/oci/data_safe/models/security_assessment_comparison.rb', line 139 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
148 149 150 |
# File 'lib/oci/data_safe/models/security_assessment_comparison.rb', line 148 def hash [id, baseline_id, lifecycle_state, time_created, targets].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
192 193 194 195 196 197 198 199 200 201 |
# File 'lib/oci/data_safe/models/security_assessment_comparison.rb', line 192 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
186 187 188 |
# File 'lib/oci/data_safe/models/security_assessment_comparison.rb', line 186 def to_s to_hash.to_s end |