Class: OCI::DataSafe::Models::SensitiveTypeSummary
- Inherits:
-
Object
- Object
- OCI::DataSafe::Models::SensitiveTypeSummary
- Defined in:
- lib/oci/data_safe/models/sensitive_type_summary.rb
Overview
Summary of a sensitive type.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- SOURCE_ENUM =
[ SOURCE_ORACLE = 'ORACLE'.freeze, SOURCE_USER = 'USER'.freeze, SOURCE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- ENTITY_TYPE_ENUM =
[ ENTITY_TYPE_SENSITIVE_TYPE = 'SENSITIVE_TYPE'.freeze, ENTITY_TYPE_SENSITIVE_CATEGORY = 'SENSITIVE_CATEGORY'.freeze, ENTITY_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The OCID of the compartment that contains the sensitive type.
-
#default_masking_format_id ⇒ String
The OCID of the library masking format that should be used to mask the sensitive columns associated with the sensitive type.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
The description of the sensitive type.
-
#display_name ⇒ String
[Required] The display name of the sensitive type.
-
#entity_type ⇒ String
[Required] The entity type.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] The OCID of the sensitive type.
-
#lifecycle_state ⇒ String
[Required] The current state of the sensitive type.
-
#parent_category_id ⇒ String
The OCID of the parent sensitive category.
-
#short_name ⇒ String
The short name of the sensitive type.
-
#source ⇒ String
[Required] Specifies whether the sensitive type is user-defined or predefined.
-
#time_created ⇒ DateTime
[Required] The date and time the sensitive type was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#time_updated ⇒ DateTime
[Required] The date and time the sensitive type was last updated, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SensitiveTypeSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ SensitiveTypeSummary
Initializes the object
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/oci/data_safe/models/sensitive_type_summary.rb', line 161 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.short_name = attributes[:'shortName'] if attributes[:'shortName'] raise 'You cannot provide both :shortName and :short_name' if attributes.key?(:'shortName') && attributes.key?(:'short_name') self.short_name = attributes[:'short_name'] if attributes[:'short_name'] self.source = attributes[:'source'] if attributes[:'source'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.description = attributes[:'description'] if attributes[:'description'] self.entity_type = attributes[:'entityType'] if attributes[:'entityType'] raise 'You cannot provide both :entityType and :entity_type' if attributes.key?(:'entityType') && attributes.key?(:'entity_type') self.entity_type = attributes[:'entity_type'] if attributes[:'entity_type'] self.parent_category_id = attributes[:'parentCategoryId'] if attributes[:'parentCategoryId'] raise 'You cannot provide both :parentCategoryId and :parent_category_id' if attributes.key?(:'parentCategoryId') && attributes.key?(:'parent_category_id') self.parent_category_id = attributes[:'parent_category_id'] if attributes[:'parent_category_id'] self.default_masking_format_id = attributes[:'defaultMaskingFormatId'] if attributes[:'defaultMaskingFormatId'] raise 'You cannot provide both :defaultMaskingFormatId and :default_masking_format_id' if attributes.key?(:'defaultMaskingFormatId') && attributes.key?(:'default_masking_format_id') self.default_masking_format_id = attributes[:'default_masking_format_id'] if attributes[:'default_masking_format_id'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The OCID of the compartment that contains the sensitive type.
43 44 45 |
# File 'lib/oci/data_safe/models/sensitive_type_summary.rb', line 43 def compartment_id @compartment_id end |
#default_masking_format_id ⇒ String
The OCID of the library masking format that should be used to mask the sensitive columns associated with the sensitive type.
81 82 83 |
# File 'lib/oci/data_safe/models/sensitive_type_summary.rb', line 81 def default_masking_format_id @default_masking_format_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)
Example: ‘{"CostCenter": "42"}`
95 96 97 |
# File 'lib/oci/data_safe/models/sensitive_type_summary.rb', line 95 def end |
#description ⇒ String
The description of the sensitive type.
67 68 69 |
# File 'lib/oci/data_safe/models/sensitive_type_summary.rb', line 67 def description @description end |
#display_name ⇒ String
[Required] The display name of the sensitive type.
39 40 41 |
# File 'lib/oci/data_safe/models/sensitive_type_summary.rb', line 39 def display_name @display_name end |
#entity_type ⇒ String
[Required] The entity type. It can be either a sensitive type with regular expressions or a sensitive category used for grouping similar sensitive types.
73 74 75 |
# File 'lib/oci/data_safe/models/sensitive_type_summary.rb', line 73 def entity_type @entity_type end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)
Example: ‘"Finance"`
88 89 90 |
# File 'lib/oci/data_safe/models/sensitive_type_summary.rb', line 88 def end |
#id ⇒ String
[Required] The OCID of the sensitive type.
35 36 37 |
# File 'lib/oci/data_safe/models/sensitive_type_summary.rb', line 35 def id @id end |
#lifecycle_state ⇒ String
[Required] The current state of the sensitive type.
47 48 49 |
# File 'lib/oci/data_safe/models/sensitive_type_summary.rb', line 47 def lifecycle_state @lifecycle_state end |
#parent_category_id ⇒ String
The OCID of the parent sensitive category.
77 78 79 |
# File 'lib/oci/data_safe/models/sensitive_type_summary.rb', line 77 def parent_category_id @parent_category_id end |
#short_name ⇒ String
The short name of the sensitive type.
51 52 53 |
# File 'lib/oci/data_safe/models/sensitive_type_summary.rb', line 51 def short_name @short_name end |
#source ⇒ String
[Required] Specifies whether the sensitive type is user-defined or predefined.
55 56 57 |
# File 'lib/oci/data_safe/models/sensitive_type_summary.rb', line 55 def source @source end |
#time_created ⇒ DateTime
[Required] The date and time the sensitive type was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
59 60 61 |
# File 'lib/oci/data_safe/models/sensitive_type_summary.rb', line 59 def time_created @time_created end |
#time_updated ⇒ DateTime
[Required] The date and time the sensitive type was last updated, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
63 64 65 |
# File 'lib/oci/data_safe/models/sensitive_type_summary.rb', line 63 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/oci/data_safe/models/sensitive_type_summary.rb', line 98 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'lifecycle_state': :'lifecycleState', 'short_name': :'shortName', 'source': :'source', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'description': :'description', 'entity_type': :'entityType', 'parent_category_id': :'parentCategoryId', 'default_masking_format_id': :'defaultMaskingFormatId', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/oci/data_safe/models/sensitive_type_summary.rb', line 120 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'compartment_id': :'String', 'lifecycle_state': :'String', 'short_name': :'String', 'source': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'description': :'String', 'entity_type': :'String', 'parent_category_id': :'String', 'default_masking_format_id': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 |
# File 'lib/oci/data_safe/models/sensitive_type_summary.rb', line 286 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && compartment_id == other.compartment_id && lifecycle_state == other.lifecycle_state && short_name == other.short_name && source == other.source && time_created == other.time_created && time_updated == other.time_updated && description == other.description && entity_type == other.entity_type && parent_category_id == other.parent_category_id && default_masking_format_id == other.default_masking_format_id && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 |
# File 'lib/oci/data_safe/models/sensitive_type_summary.rb', line 329 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
309 310 311 |
# File 'lib/oci/data_safe/models/sensitive_type_summary.rb', line 309 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
318 319 320 |
# File 'lib/oci/data_safe/models/sensitive_type_summary.rb', line 318 def hash [id, display_name, compartment_id, lifecycle_state, short_name, source, time_created, time_updated, description, entity_type, parent_category_id, default_masking_format_id, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
362 363 364 365 366 367 368 369 370 371 |
# File 'lib/oci/data_safe/models/sensitive_type_summary.rb', line 362 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
356 357 358 |
# File 'lib/oci/data_safe/models/sensitive_type_summary.rb', line 356 def to_s to_hash.to_s end |