Class: OCI::DataSafe::Models::SubstringFormatEntry

Inherits:
FormatEntry
  • Object
show all
Defined in:
lib/oci/data_safe/models/substring_format_entry.rb

Overview

The Substring masking format extracts a portion of the original column value and uses it to replace the original value. It internally uses the Oracle SUBSTR function. It takes the start position and length as input, extracts substring from the original value using SUBSTR, and uses the substring to replace the original value. To learn more, check Substring in the Data Safe documentation.

Constant Summary

Constants inherited from FormatEntry

FormatEntry::TYPE_ENUM

Instance Attribute Summary collapse

Attributes inherited from FormatEntry

#description, #type

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from FormatEntry

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ SubstringFormatEntry

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :description (String)

    The value to assign to the #description proprety

  • :start_position (Integer)

    The value to assign to the #start_position property

  • :length (Integer)

    The value to assign to the #length property



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/oci/data_safe/models/substring_format_entry.rb', line 63

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['type'] = 'SUBSTRING'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.start_position = attributes[:'startPosition'] if attributes[:'startPosition']

  raise 'You cannot provide both :startPosition and :start_position' if attributes.key?(:'startPosition') && attributes.key?(:'start_position')

  self.start_position = attributes[:'start_position'] if attributes[:'start_position']

  self.length = attributes[:'length'] if attributes[:'length']
end

Instance Attribute Details

#lengthInteger

[Required] The number of characters that should be there in the substring. It should be an integer and greater than zero.

Returns:

  • (Integer)


28
29
30
# File 'lib/oci/data_safe/models/substring_format_entry.rb', line 28

def length
  @length
end

#start_positionInteger

[Required] The starting position in the original string from where the substring should be extracted. It can be either a positive or a negative integer. If It’s negative, the counting starts from the end of the string.

Returns:

  • (Integer)


22
23
24
# File 'lib/oci/data_safe/models/substring_format_entry.rb', line 22

def start_position
  @start_position
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
40
# File 'lib/oci/data_safe/models/substring_format_entry.rb', line 31

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'type': :'type',
    'description': :'description',
    'start_position': :'startPosition',
    'length': :'length'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



43
44
45
46
47
48
49
50
51
52
# File 'lib/oci/data_safe/models/substring_format_entry.rb', line 43

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'type': :'String',
    'description': :'String',
    'start_position': :'Integer',
    'length': :'Integer'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



89
90
91
92
93
94
95
96
97
# File 'lib/oci/data_safe/models/substring_format_entry.rb', line 89

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    type == other.type &&
    description == other.description &&
    start_position == other.start_position &&
    length == other.length
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/oci/data_safe/models/substring_format_entry.rb', line 122

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


102
103
104
# File 'lib/oci/data_safe/models/substring_format_entry.rb', line 102

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



111
112
113
# File 'lib/oci/data_safe/models/substring_format_entry.rb', line 111

def hash
  [type, description, start_position, length].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



155
156
157
158
159
160
161
162
163
164
# File 'lib/oci/data_safe/models/substring_format_entry.rb', line 155

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



149
150
151
# File 'lib/oci/data_safe/models/substring_format_entry.rb', line 149

def to_s
  to_hash.to_s
end