Class: OCI::DataSafe::Models::TargetDatabase

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_safe/models/target_database.rb

Overview

The details of the Data Safe target database.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_NEEDS_ATTENTION = 'NEEDS_ATTENTION'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ TargetDatabase

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/oci/data_safe/models/target_database.rb', line 162

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.id = attributes[:'id'] if attributes[:'id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.database_details = attributes[:'databaseDetails'] if attributes[:'databaseDetails']

  raise 'You cannot provide both :databaseDetails and :database_details' if attributes.key?(:'databaseDetails') && attributes.key?(:'database_details')

  self.database_details = attributes[:'database_details'] if attributes[:'database_details']

  self.credentials = attributes[:'credentials'] if attributes[:'credentials']

  self.tls_config = attributes[:'tlsConfig'] if attributes[:'tlsConfig']

  raise 'You cannot provide both :tlsConfig and :tls_config' if attributes.key?(:'tlsConfig') && attributes.key?(:'tls_config')

  self.tls_config = attributes[:'tls_config'] if attributes[:'tls_config']

  self.connection_option = attributes[:'connectionOption'] if attributes[:'connectionOption']

  raise 'You cannot provide both :connectionOption and :connection_option' if attributes.key?(:'connectionOption') && attributes.key?(:'connection_option')

  self.connection_option = attributes[:'connection_option'] if attributes[:'connection_option']

  self.associated_resource_ids = attributes[:'associatedResourceIds'] if attributes[:'associatedResourceIds']

  raise 'You cannot provide both :associatedResourceIds and :associated_resource_ids' if attributes.key?(:'associatedResourceIds') && attributes.key?(:'associated_resource_ids')

  self.associated_resource_ids = attributes[:'associated_resource_ids'] if attributes[:'associated_resource_ids']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

  raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

  self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']
end

Instance Attribute Details

#associated_resource_idsArray<String>

The OCIDs of associated resources like Database, Data Safe private endpoint etc.

Returns:

  • (Array<String>)


54
55
56
# File 'lib/oci/data_safe/models/target_database.rb', line 54

def associated_resource_ids
  @associated_resource_ids
end

#compartment_idString

[Required] The OCID of the compartment which contains the Data Safe target database.

Returns:

  • (String)


25
26
27
# File 'lib/oci/data_safe/models/target_database.rb', line 25

def compartment_id
  @compartment_id
end

#connection_optionOCI::DataSafe::Models::ConnectionOption



50
51
52
# File 'lib/oci/data_safe/models/target_database.rb', line 50

def connection_option
  @connection_option
end

#credentialsOCI::DataSafe::Models::Credentials



44
45
46
# File 'lib/oci/data_safe/models/target_database.rb', line 44

def credentials
  @credentials
end

#database_detailsOCI::DataSafe::Models::DatabaseDetails

This attribute is required.



41
42
43
# File 'lib/oci/data_safe/models/target_database.rb', line 41

def database_details
  @database_details
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)

Example: ‘{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


84
85
86
# File 'lib/oci/data_safe/models/target_database.rb', line 84

def defined_tags
  @defined_tags
end

#descriptionString

The description of the target database in Data Safe.

Returns:

  • (String)


37
38
39
# File 'lib/oci/data_safe/models/target_database.rb', line 37

def description
  @description
end

#display_nameString

[Required] The display name of the target database in Data Safe.

Returns:

  • (String)


33
34
35
# File 'lib/oci/data_safe/models/target_database.rb', line 33

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)

Example: ‘"Finance"`

Returns:

  • (Hash<String, String>)


77
78
79
# File 'lib/oci/data_safe/models/target_database.rb', line 77

def freeform_tags
  @freeform_tags
end

#idString

[Required] The OCID of the Data Safe target database.

Returns:

  • (String)


29
30
31
# File 'lib/oci/data_safe/models/target_database.rb', line 29

def id
  @id
end

#lifecycle_detailsString

Details about the current state of the target database in Data Safe.

Returns:

  • (String)


62
63
64
# File 'lib/oci/data_safe/models/target_database.rb', line 62

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

[Required] The current state of the target database in Data Safe.

Returns:

  • (String)


58
59
60
# File 'lib/oci/data_safe/models/target_database.rb', line 58

def lifecycle_state
  @lifecycle_state
end

#system_tagsHash<String, Hash<String, Object>>

System tags for this resource. Each key is predefined and scoped to a namespace. For more information, see Resource Tags. Example: ‘{"free-tier-retained": "true"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


90
91
92
# File 'lib/oci/data_safe/models/target_database.rb', line 90

def system_tags
  @system_tags
end

#time_createdDateTime

[Required] The date and time of target database registration and creation in Data Safe.

Returns:

  • (DateTime)


66
67
68
# File 'lib/oci/data_safe/models/target_database.rb', line 66

def time_created
  @time_created
end

#time_updatedDateTime

The date and time of the target database update in Data Safe.

Returns:

  • (DateTime)


70
71
72
# File 'lib/oci/data_safe/models/target_database.rb', line 70

def time_updated
  @time_updated
end

#tls_configOCI::DataSafe::Models::TlsConfig



47
48
49
# File 'lib/oci/data_safe/models/target_database.rb', line 47

def tls_config
  @tls_config
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/oci/data_safe/models/target_database.rb', line 93

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'compartmentId',
    'id': :'id',
    'display_name': :'displayName',
    'description': :'description',
    'database_details': :'databaseDetails',
    'credentials': :'credentials',
    'tls_config': :'tlsConfig',
    'connection_option': :'connectionOption',
    'associated_resource_ids': :'associatedResourceIds',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/oci/data_safe/models/target_database.rb', line 117

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'String',
    'id': :'String',
    'display_name': :'String',
    'description': :'String',
    'database_details': :'OCI::DataSafe::Models::DatabaseDetails',
    'credentials': :'OCI::DataSafe::Models::Credentials',
    'tls_config': :'OCI::DataSafe::Models::TlsConfig',
    'connection_option': :'OCI::DataSafe::Models::ConnectionOption',
    'associated_resource_ids': :'Array<String>',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'lib/oci/data_safe/models/target_database.rb', line 273

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    compartment_id == other.compartment_id &&
    id == other.id &&
    display_name == other.display_name &&
    description == other.description &&
    database_details == other.database_details &&
    credentials == other.credentials &&
    tls_config == other.tls_config &&
    connection_option == other.connection_option &&
    associated_resource_ids == other.associated_resource_ids &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
# File 'lib/oci/data_safe/models/target_database.rb', line 318

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


298
299
300
# File 'lib/oci/data_safe/models/target_database.rb', line 298

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



307
308
309
# File 'lib/oci/data_safe/models/target_database.rb', line 307

def hash
  [compartment_id, id, display_name, description, database_details, credentials, tls_config, connection_option, associated_resource_ids, lifecycle_state, lifecycle_details, time_created, time_updated, freeform_tags, defined_tags, system_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



351
352
353
354
355
356
357
358
359
360
# File 'lib/oci/data_safe/models/target_database.rb', line 351

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



345
346
347
# File 'lib/oci/data_safe/models/target_database.rb', line 345

def to_s
  to_hash.to_s
end