Class: OCI::DataSafe::Models::TargetDatabaseSummary
- Inherits:
-
Object
- Object
- OCI::DataSafe::Models::TargetDatabaseSummary
- Defined in:
- lib/oci/data_safe/models/target_database_summary.rb
Overview
Summary of a Data Safe target database.
Constant Summary collapse
- INFRASTRUCTURE_TYPE_ENUM =
[ INFRASTRUCTURE_TYPE_ORACLE_CLOUD = 'ORACLE_CLOUD'.freeze, INFRASTRUCTURE_TYPE_CLOUD_AT_CUSTOMER = 'CLOUD_AT_CUSTOMER'.freeze, INFRASTRUCTURE_TYPE_ON_PREMISES = 'ON_PREMISES'.freeze, INFRASTRUCTURE_TYPE_NON_ORACLE_CLOUD = 'NON_ORACLE_CLOUD'.freeze, INFRASTRUCTURE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- DATABASE_TYPE_ENUM =
[ DATABASE_TYPE_DATABASE_CLOUD_SERVICE = 'DATABASE_CLOUD_SERVICE'.freeze, DATABASE_TYPE_AUTONOMOUS_DATABASE = 'AUTONOMOUS_DATABASE'.freeze, DATABASE_TYPE_INSTALLED_DATABASE = 'INSTALLED_DATABASE'.freeze, DATABASE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_NEEDS_ATTENTION = 'NEEDS_ATTENTION'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The OCID of the compartment that contains the Data Safe target database.
-
#database_type ⇒ String
[Required] The database type.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
The description of the target database in Data Safe.
-
#display_name ⇒ String
[Required] The display name of the target database in Data Safe.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] The OCID of the Data Safe target database.
-
#infrastructure_type ⇒ String
[Required] The infrastructure type the database is running on.
-
#lifecycle_details ⇒ String
Details about the current state of the target database in Data Safe.
-
#lifecycle_state ⇒ String
[Required] The current state of the target database in Data Safe.
-
#time_created ⇒ DateTime
[Required] The date and time the database was registered in Data Safe and created as a target database in Data Safe.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TargetDatabaseSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ TargetDatabaseSummary
Initializes the object
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/oci/data_safe/models/target_database_summary.rb', line 143 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.infrastructure_type = attributes[:'infrastructureType'] if attributes[:'infrastructureType'] raise 'You cannot provide both :infrastructureType and :infrastructure_type' if attributes.key?(:'infrastructureType') && attributes.key?(:'infrastructure_type') self.infrastructure_type = attributes[:'infrastructure_type'] if attributes[:'infrastructure_type'] self.database_type = attributes[:'databaseType'] if attributes[:'databaseType'] raise 'You cannot provide both :databaseType and :database_type' if attributes.key?(:'databaseType') && attributes.key?(:'database_type') self.database_type = attributes[:'database_type'] if attributes[:'database_type'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The OCID of the compartment that contains the Data Safe target database.
40 41 42 |
# File 'lib/oci/data_safe/models/target_database_summary.rb', line 40 def compartment_id @compartment_id end |
#database_type ⇒ String
[Required] The database type.
60 61 62 |
# File 'lib/oci/data_safe/models/target_database_summary.rb', line 60 def database_type @database_type end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)
Example: ‘{"CostCenter": "42"}`
86 87 88 |
# File 'lib/oci/data_safe/models/target_database_summary.rb', line 86 def @defined_tags end |
#description ⇒ String
The description of the target database in Data Safe.
52 53 54 |
# File 'lib/oci/data_safe/models/target_database_summary.rb', line 52 def description @description end |
#display_name ⇒ String
[Required] The display name of the target database in Data Safe.
48 49 50 |
# File 'lib/oci/data_safe/models/target_database_summary.rb', line 48 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)
Example: ‘"Finance"`
79 80 81 |
# File 'lib/oci/data_safe/models/target_database_summary.rb', line 79 def @freeform_tags end |
#id ⇒ String
[Required] The OCID of the Data Safe target database.
44 45 46 |
# File 'lib/oci/data_safe/models/target_database_summary.rb', line 44 def id @id end |
#infrastructure_type ⇒ String
[Required] The infrastructure type the database is running on.
56 57 58 |
# File 'lib/oci/data_safe/models/target_database_summary.rb', line 56 def infrastructure_type @infrastructure_type end |
#lifecycle_details ⇒ String
Details about the current state of the target database in Data Safe.
68 69 70 |
# File 'lib/oci/data_safe/models/target_database_summary.rb', line 68 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
[Required] The current state of the target database in Data Safe.
64 65 66 |
# File 'lib/oci/data_safe/models/target_database_summary.rb', line 64 def lifecycle_state @lifecycle_state end |
#time_created ⇒ DateTime
[Required] The date and time the database was registered in Data Safe and created as a target database in Data Safe.
72 73 74 |
# File 'lib/oci/data_safe/models/target_database_summary.rb', line 72 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/oci/data_safe/models/target_database_summary.rb', line 89 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'id': :'id', 'display_name': :'displayName', 'description': :'description', 'infrastructure_type': :'infrastructureType', 'database_type': :'databaseType', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'time_created': :'timeCreated', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/oci/data_safe/models/target_database_summary.rb', line 108 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'id': :'String', 'display_name': :'String', 'description': :'String', 'infrastructure_type': :'String', 'database_type': :'String', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'time_created': :'DateTime', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/oci/data_safe/models/target_database_summary.rb', line 254 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && id == other.id && display_name == other.display_name && description == other.description && infrastructure_type == other.infrastructure_type && database_type == other.database_type && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && time_created == other.time_created && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 |
# File 'lib/oci/data_safe/models/target_database_summary.rb', line 294 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
274 275 276 |
# File 'lib/oci/data_safe/models/target_database_summary.rb', line 274 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
283 284 285 |
# File 'lib/oci/data_safe/models/target_database_summary.rb', line 283 def hash [compartment_id, id, display_name, description, infrastructure_type, database_type, lifecycle_state, lifecycle_details, time_created, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
327 328 329 330 331 332 333 334 335 336 |
# File 'lib/oci/data_safe/models/target_database_summary.rb', line 327 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
321 322 323 |
# File 'lib/oci/data_safe/models/target_database_summary.rb', line 321 def to_s to_hash.to_s end |