Class: OCI::DataSafe::Models::UpdateMaskingColumnDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_safe/models/update_masking_column_details.rb

Overview

Details to update a masking column.

Constant Summary collapse

OBJECT_TYPE_ENUM =
[
  OBJECT_TYPE_TABLE = 'TABLE'.freeze,
  OBJECT_TYPE_EDITIONING_VIEW = 'EDITIONING_VIEW'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateMaskingColumnDetails

Initializes the object

Options Hash (attributes):



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/oci/data_safe/models/update_masking_column_details.rb', line 88

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.object_type = attributes[:'objectType'] if attributes[:'objectType']

  raise 'You cannot provide both :objectType and :object_type' if attributes.key?(:'objectType') && attributes.key?(:'object_type')

  self.object_type = attributes[:'object_type'] if attributes[:'object_type']

  self.masking_column_group = attributes[:'maskingColumnGroup'] if attributes[:'maskingColumnGroup']

  raise 'You cannot provide both :maskingColumnGroup and :masking_column_group' if attributes.key?(:'maskingColumnGroup') && attributes.key?(:'masking_column_group')

  self.masking_column_group = attributes[:'masking_column_group'] if attributes[:'masking_column_group']

  self.sensitive_type_id = attributes[:'sensitiveTypeId'] if attributes[:'sensitiveTypeId']

  raise 'You cannot provide both :sensitiveTypeId and :sensitive_type_id' if attributes.key?(:'sensitiveTypeId') && attributes.key?(:'sensitive_type_id')

  self.sensitive_type_id = attributes[:'sensitive_type_id'] if attributes[:'sensitive_type_id']

  self.is_masking_enabled = attributes[:'isMaskingEnabled'] unless attributes[:'isMaskingEnabled'].nil?

  raise 'You cannot provide both :isMaskingEnabled and :is_masking_enabled' if attributes.key?(:'isMaskingEnabled') && attributes.key?(:'is_masking_enabled')

  self.is_masking_enabled = attributes[:'is_masking_enabled'] unless attributes[:'is_masking_enabled'].nil?

  self.masking_formats = attributes[:'maskingFormats'] if attributes[:'maskingFormats']

  raise 'You cannot provide both :maskingFormats and :masking_formats' if attributes.key?(:'maskingFormats') && attributes.key?(:'masking_formats')

  self.masking_formats = attributes[:'masking_formats'] if attributes[:'masking_formats']
end

Instance Attribute Details

#is_masking_enabledBOOLEAN

Indicates if data masking is enabled for the masking column. Set it to false if you don’t want to mask the column.



36
37
38
# File 'lib/oci/data_safe/models/update_masking_column_details.rb', line 36

def is_masking_enabled
  @is_masking_enabled
end

#masking_column_groupString

The group of the masking column. It’s a masking group identifier and can be any string of acceptable length. All the columns in a group are masked together to ensure that the masked data across these columns continue to retain the same logical relationship. For more details, check <a href=docs.oracle.com/en/cloud/paas/data-safe/udscs/group-masking1.html#GUID-755056B9-9540-48C0-9491-262A44A85037>Group Masking in the Data Safe documentation.</a>



26
27
28
# File 'lib/oci/data_safe/models/update_masking_column_details.rb', line 26

def masking_column_group
  @masking_column_group
end

#masking_formatsArray<OCI::DataSafe::Models::MaskingFormat>

The masking formats to be assigned to the masking column. You can specify a condition as part of each masking format. It enables you to do <a href=\“docs.oracle.com/en/cloud/paas/data-safe/udscs/conditional-masking.html\”>conditional masking</a> so that you can mask the column data values differently using different masking formats and the associated conditions. A masking format can have one or more format entries. The combined output of all the format entries is used for masking. It provides the flexibility to define a masking format that can generate different parts of a data value separately and then combine them to get the final data value for masking.



49
50
51
# File 'lib/oci/data_safe/models/update_masking_column_details.rb', line 49

def masking_formats
  @masking_formats
end

#object_typeString

The type of the object that contains the database column.



17
18
19
# File 'lib/oci/data_safe/models/update_masking_column_details.rb', line 17

def object_type
  @object_type
end

#sensitive_type_idString

The OCID of the sensitive type to be associated with the masking column.



30
31
32
# File 'lib/oci/data_safe/models/update_masking_column_details.rb', line 30

def sensitive_type_id
  @sensitive_type_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



52
53
54
55
56
57
58
59
60
61
62
# File 'lib/oci/data_safe/models/update_masking_column_details.rb', line 52

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'object_type': :'objectType',
    'masking_column_group': :'maskingColumnGroup',
    'sensitive_type_id': :'sensitiveTypeId',
    'is_masking_enabled': :'isMaskingEnabled',
    'masking_formats': :'maskingFormats'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



65
66
67
68
69
70
71
72
73
74
75
# File 'lib/oci/data_safe/models/update_masking_column_details.rb', line 65

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'object_type': :'String',
    'masking_column_group': :'String',
    'sensitive_type_id': :'String',
    'is_masking_enabled': :'BOOLEAN',
    'masking_formats': :'Array<OCI::DataSafe::Models::MaskingFormat>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.



140
141
142
143
144
145
146
147
148
149
# File 'lib/oci/data_safe/models/update_masking_column_details.rb', line 140

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    object_type == other.object_type &&
    masking_column_group == other.masking_column_group &&
    sensitive_type_id == other.sensitive_type_id &&
    is_masking_enabled == other.is_masking_enabled &&
    masking_formats == other.masking_formats
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/oci/data_safe/models/update_masking_column_details.rb', line 174

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method


154
155
156
# File 'lib/oci/data_safe/models/update_masking_column_details.rb', line 154

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.



163
164
165
# File 'lib/oci/data_safe/models/update_masking_column_details.rb', line 163

def hash
  [object_type, masking_column_group, sensitive_type_id, is_masking_enabled, masking_formats].hash
end

#to_hashHash

Returns the object in the form of hash



207
208
209
210
211
212
213
214
215
216
# File 'lib/oci/data_safe/models/update_masking_column_details.rb', line 207

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



201
202
203
# File 'lib/oci/data_safe/models/update_masking_column_details.rb', line 201

def to_s
  to_hash.to_s
end