Class: OCI::DataSafe::Models::UpdateSensitiveDataModelDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_safe/models/update_sensitive_data_model_details.rb

Overview

Details to update a sensitive data model. Note that updating any attribute of a sensitive data model does not perform data discovery.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateSensitiveDataModelDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/oci/data_safe/models/update_sensitive_data_model_details.rb', line 125

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.target_id = attributes[:'targetId'] if attributes[:'targetId']

  raise 'You cannot provide both :targetId and :target_id' if attributes.key?(:'targetId') && attributes.key?(:'target_id')

  self.target_id = attributes[:'target_id'] if attributes[:'target_id']

  self.app_suite_name = attributes[:'appSuiteName'] if attributes[:'appSuiteName']

  raise 'You cannot provide both :appSuiteName and :app_suite_name' if attributes.key?(:'appSuiteName') && attributes.key?(:'app_suite_name')

  self.app_suite_name = attributes[:'app_suite_name'] if attributes[:'app_suite_name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.schemas_for_discovery = attributes[:'schemasForDiscovery'] if attributes[:'schemasForDiscovery']

  raise 'You cannot provide both :schemasForDiscovery and :schemas_for_discovery' if attributes.key?(:'schemasForDiscovery') && attributes.key?(:'schemas_for_discovery')

  self.schemas_for_discovery = attributes[:'schemas_for_discovery'] if attributes[:'schemas_for_discovery']

  self.sensitive_type_ids_for_discovery = attributes[:'sensitiveTypeIdsForDiscovery'] if attributes[:'sensitiveTypeIdsForDiscovery']

  raise 'You cannot provide both :sensitiveTypeIdsForDiscovery and :sensitive_type_ids_for_discovery' if attributes.key?(:'sensitiveTypeIdsForDiscovery') && attributes.key?(:'sensitive_type_ids_for_discovery')

  self.sensitive_type_ids_for_discovery = attributes[:'sensitive_type_ids_for_discovery'] if attributes[:'sensitive_type_ids_for_discovery']

  self.is_sample_data_collection_enabled = attributes[:'isSampleDataCollectionEnabled'] unless attributes[:'isSampleDataCollectionEnabled'].nil?

  raise 'You cannot provide both :isSampleDataCollectionEnabled and :is_sample_data_collection_enabled' if attributes.key?(:'isSampleDataCollectionEnabled') && attributes.key?(:'is_sample_data_collection_enabled')

  self.is_sample_data_collection_enabled = attributes[:'is_sample_data_collection_enabled'] unless attributes[:'is_sample_data_collection_enabled'].nil?

  self.is_app_defined_relation_discovery_enabled = attributes[:'isAppDefinedRelationDiscoveryEnabled'] unless attributes[:'isAppDefinedRelationDiscoveryEnabled'].nil?

  raise 'You cannot provide both :isAppDefinedRelationDiscoveryEnabled and :is_app_defined_relation_discovery_enabled' if attributes.key?(:'isAppDefinedRelationDiscoveryEnabled') && attributes.key?(:'is_app_defined_relation_discovery_enabled')

  self.is_app_defined_relation_discovery_enabled = attributes[:'is_app_defined_relation_discovery_enabled'] unless attributes[:'is_app_defined_relation_discovery_enabled'].nil?

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#app_suite_nameString

The application suite name identifying a collection of applications. It’s useful only if maintaining a sensitive data model for a suite of applications.

Returns:

  • (String)


24
25
26
# File 'lib/oci/data_safe/models/update_sensitive_data_model_details.rb', line 24

def app_suite_name
  @app_suite_name
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)

Example: ‘{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


71
72
73
# File 'lib/oci/data_safe/models/update_sensitive_data_model_details.rb', line 71

def defined_tags
  @defined_tags
end

#descriptionString

The description of the sensitive data model.

Returns:

  • (String)


28
29
30
# File 'lib/oci/data_safe/models/update_sensitive_data_model_details.rb', line 28

def description
  @description
end

#display_nameString

The display name of the sensitive data model. The name does not have to be unique, and it’s changeable.

Returns:

  • (String)


13
14
15
# File 'lib/oci/data_safe/models/update_sensitive_data_model_details.rb', line 13

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)

Example: ‘"Finance"`

Returns:

  • (Hash<String, String>)


64
65
66
# File 'lib/oci/data_safe/models/update_sensitive_data_model_details.rb', line 64

def freeform_tags
  @freeform_tags
end

#is_app_defined_relation_discovery_enabledBOOLEAN

Indicates if data discovery jobs should identify potential application-level (non-dictionary) referential relationships between columns. Note that data discovery automatically identifies and adds database-level (dictionary-defined) relationships. This option helps identify application-level relationships that are not defined in the database dictionary, which in turn, helps identify additional sensitive columns and preserve referential integrity during data masking. It’s disabled by default and should be used only if there is a need to identify application-level relationships.

Returns:

  • (BOOLEAN)


57
58
59
# File 'lib/oci/data_safe/models/update_sensitive_data_model_details.rb', line 57

def is_app_defined_relation_discovery_enabled
  @is_app_defined_relation_discovery_enabled
end

#is_sample_data_collection_enabledBOOLEAN

Indicates if data discovery jobs should collect and store sample data values for the discovered columns. Sample data helps review the discovered columns and ensure that they actually contain sensitive data. As it collects original data from the target database, it’s disabled by default and should be used only if it’s acceptable to store sample data in Data Safe’s repository in Oracle Cloud. Note that sample data values are not collected for columns with the following data types: LONG, LOB, RAW, XMLTYPE and BFILE.

Returns:

  • (BOOLEAN)


47
48
49
# File 'lib/oci/data_safe/models/update_sensitive_data_model_details.rb', line 47

def is_sample_data_collection_enabled
  @is_sample_data_collection_enabled
end

#schemas_for_discoveryArray<String>

The schemas to be used for future data discovery jobs.

Returns:

  • (Array<String>)


32
33
34
# File 'lib/oci/data_safe/models/update_sensitive_data_model_details.rb', line 32

def schemas_for_discovery
  @schemas_for_discovery
end

#sensitive_type_ids_for_discoveryArray<String>

The OCIDs of the sensitive types to be used for future data discovery jobs. If OCID of a sensitive category is provided, all its child sensitive types are used for data discovery.

Returns:

  • (Array<String>)


38
39
40
# File 'lib/oci/data_safe/models/update_sensitive_data_model_details.rb', line 38

def sensitive_type_ids_for_discovery
  @sensitive_type_ids_for_discovery
end

#target_idString

The OCID of the reference target database to be associated with the sensitive data model. All operations such as performing data discovery and adding columns manually are done in the context of the associated target database. Note that updating the targetId attribute does not perform data discovery automatically.

Returns:

  • (String)


20
21
22
# File 'lib/oci/data_safe/models/update_sensitive_data_model_details.rb', line 20

def target_id
  @target_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/oci/data_safe/models/update_sensitive_data_model_details.rb', line 74

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'displayName',
    'target_id': :'targetId',
    'app_suite_name': :'appSuiteName',
    'description': :'description',
    'schemas_for_discovery': :'schemasForDiscovery',
    'sensitive_type_ids_for_discovery': :'sensitiveTypeIdsForDiscovery',
    'is_sample_data_collection_enabled': :'isSampleDataCollectionEnabled',
    'is_app_defined_relation_discovery_enabled': :'isAppDefinedRelationDiscoveryEnabled',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/oci/data_safe/models/update_sensitive_data_model_details.rb', line 92

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'String',
    'target_id': :'String',
    'app_suite_name': :'String',
    'description': :'String',
    'schemas_for_discovery': :'Array<String>',
    'sensitive_type_ids_for_discovery': :'Array<String>',
    'is_sample_data_collection_enabled': :'BOOLEAN',
    'is_app_defined_relation_discovery_enabled': :'BOOLEAN',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/oci/data_safe/models/update_sensitive_data_model_details.rb', line 195

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    display_name == other.display_name &&
    target_id == other.target_id &&
    app_suite_name == other.app_suite_name &&
    description == other.description &&
    schemas_for_discovery == other.schemas_for_discovery &&
    sensitive_type_ids_for_discovery == other.sensitive_type_ids_for_discovery &&
    is_sample_data_collection_enabled == other.is_sample_data_collection_enabled &&
    is_app_defined_relation_discovery_enabled == other.is_app_defined_relation_discovery_enabled &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/oci/data_safe/models/update_sensitive_data_model_details.rb', line 234

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


214
215
216
# File 'lib/oci/data_safe/models/update_sensitive_data_model_details.rb', line 214

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



223
224
225
# File 'lib/oci/data_safe/models/update_sensitive_data_model_details.rb', line 223

def hash
  [display_name, target_id, app_suite_name, description, schemas_for_discovery, sensitive_type_ids_for_discovery, is_sample_data_collection_enabled, is_app_defined_relation_discovery_enabled, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



267
268
269
270
271
272
273
274
275
276
# File 'lib/oci/data_safe/models/update_sensitive_data_model_details.rb', line 267

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



261
262
263
# File 'lib/oci/data_safe/models/update_sensitive_data_model_details.rb', line 261

def to_s
  to_hash.to_s
end