Class: OCI::DataSafe::Models::UpdateSensitiveTypePatternDetails

Inherits:
UpdateSensitiveTypeDetails show all
Defined in:
lib/oci/data_safe/models/update_sensitive_type_pattern_details.rb

Overview

Details to update a sensitive type with regular expressions.

Constant Summary

Constants inherited from UpdateSensitiveTypeDetails

OCI::DataSafe::Models::UpdateSensitiveTypeDetails::ENTITY_TYPE_ENUM

Instance Attribute Summary collapse

Attributes inherited from UpdateSensitiveTypeDetails

#defined_tags, #description, #display_name, #entity_type, #freeform_tags, #parent_category_id, #short_name

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from UpdateSensitiveTypeDetails

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ UpdateSensitiveTypePatternDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :display_name (String)

    The value to assign to the #display_name proprety

  • :short_name (String)

    The value to assign to the #short_name proprety

  • :description (String)

    The value to assign to the #description proprety

  • :parent_category_id (String)

    The value to assign to the #parent_category_id proprety

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags proprety

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags proprety

  • :name_pattern (String)

    The value to assign to the #name_pattern property

  • :comment_pattern (String)

    The value to assign to the #comment_pattern property

  • :data_pattern (String)

    The value to assign to the #data_pattern property

  • :search_type (String)

    The value to assign to the #search_type property

  • :default_masking_format_id (String)

    The value to assign to the #default_masking_format_id property



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/oci/data_safe/models/update_sensitive_type_pattern_details.rb', line 90

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['entityType'] = 'SENSITIVE_TYPE'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.name_pattern = attributes[:'namePattern'] if attributes[:'namePattern']

  raise 'You cannot provide both :namePattern and :name_pattern' if attributes.key?(:'namePattern') && attributes.key?(:'name_pattern')

  self.name_pattern = attributes[:'name_pattern'] if attributes[:'name_pattern']

  self.comment_pattern = attributes[:'commentPattern'] if attributes[:'commentPattern']

  raise 'You cannot provide both :commentPattern and :comment_pattern' if attributes.key?(:'commentPattern') && attributes.key?(:'comment_pattern')

  self.comment_pattern = attributes[:'comment_pattern'] if attributes[:'comment_pattern']

  self.data_pattern = attributes[:'dataPattern'] if attributes[:'dataPattern']

  raise 'You cannot provide both :dataPattern and :data_pattern' if attributes.key?(:'dataPattern') && attributes.key?(:'data_pattern')

  self.data_pattern = attributes[:'data_pattern'] if attributes[:'data_pattern']

  self.search_type = attributes[:'searchType'] if attributes[:'searchType']

  raise 'You cannot provide both :searchType and :search_type' if attributes.key?(:'searchType') && attributes.key?(:'search_type')

  self.search_type = attributes[:'search_type'] if attributes[:'search_type']

  self.default_masking_format_id = attributes[:'defaultMaskingFormatId'] if attributes[:'defaultMaskingFormatId']

  raise 'You cannot provide both :defaultMaskingFormatId and :default_masking_format_id' if attributes.key?(:'defaultMaskingFormatId') && attributes.key?(:'default_masking_format_id')

  self.default_masking_format_id = attributes[:'default_masking_format_id'] if attributes[:'default_masking_format_id']
end

Instance Attribute Details

#comment_patternString

A regular expression to be used by data discovery for matching column comments.

Returns:

  • (String)


17
18
19
# File 'lib/oci/data_safe/models/update_sensitive_type_pattern_details.rb', line 17

def comment_pattern
  @comment_pattern
end

#data_patternString

A regular expression to be used by data discovery for matching column data values.

Returns:

  • (String)


21
22
23
# File 'lib/oci/data_safe/models/update_sensitive_type_pattern_details.rb', line 21

def data_pattern
  @data_pattern
end

#default_masking_format_idString

The OCID of the library masking format that should be used to mask the sensitive columns associated with the sensitive type.

Returns:

  • (String)


31
32
33
# File 'lib/oci/data_safe/models/update_sensitive_type_pattern_details.rb', line 31

def default_masking_format_id
  @default_masking_format_id
end

#name_patternString

A regular expression to be used by data discovery for matching column names.

Returns:

  • (String)


13
14
15
# File 'lib/oci/data_safe/models/update_sensitive_type_pattern_details.rb', line 13

def name_pattern
  @name_pattern
end

#search_typeString

The search type indicating how the column name, comment and data patterns should be used by data discovery. [Learn more](docs.oracle.com/en/cloud/paas/data-safe/udscs/sensitive-types.html#GUID-1D1AD98E-B93F-4FF2-80AE-CB7D8A14F6CC).

Returns:

  • (String)


27
28
29
# File 'lib/oci/data_safe/models/update_sensitive_type_pattern_details.rb', line 27

def search_type
  @search_type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
# File 'lib/oci/data_safe/models/update_sensitive_type_pattern_details.rb', line 34

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'entity_type': :'entityType',
    'display_name': :'displayName',
    'short_name': :'shortName',
    'description': :'description',
    'parent_category_id': :'parentCategoryId',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'name_pattern': :'namePattern',
    'comment_pattern': :'commentPattern',
    'data_pattern': :'dataPattern',
    'search_type': :'searchType',
    'default_masking_format_id': :'defaultMaskingFormatId'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/oci/data_safe/models/update_sensitive_type_pattern_details.rb', line 54

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'entity_type': :'String',
    'display_name': :'String',
    'short_name': :'String',
    'description': :'String',
    'parent_category_id': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'name_pattern': :'String',
    'comment_pattern': :'String',
    'data_pattern': :'String',
    'search_type': :'String',
    'default_masking_format_id': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/oci/data_safe/models/update_sensitive_type_pattern_details.rb', line 138

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    entity_type == other.entity_type &&
    display_name == other.display_name &&
    short_name == other.short_name &&
    description == other.description &&
    parent_category_id == other.parent_category_id &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    name_pattern == other.name_pattern &&
    comment_pattern == other.comment_pattern &&
    data_pattern == other.data_pattern &&
    search_type == other.search_type &&
    default_masking_format_id == other.default_masking_format_id
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/oci/data_safe/models/update_sensitive_type_pattern_details.rb', line 179

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


159
160
161
# File 'lib/oci/data_safe/models/update_sensitive_type_pattern_details.rb', line 159

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



168
169
170
# File 'lib/oci/data_safe/models/update_sensitive_type_pattern_details.rb', line 168

def hash
  [entity_type, display_name, short_name, description, parent_category_id, freeform_tags, defined_tags, name_pattern, comment_pattern, data_pattern, search_type, default_masking_format_id].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



212
213
214
215
216
217
218
219
220
221
# File 'lib/oci/data_safe/models/update_sensitive_type_pattern_details.rb', line 212

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



206
207
208
# File 'lib/oci/data_safe/models/update_sensitive_type_pattern_details.rb', line 206

def to_s
  to_hash.to_s
end