Class: OCI::DataSafe::Models::UpdateTargetDatabaseDetails
- Inherits:
-
Object
- Object
- OCI::DataSafe::Models::UpdateTargetDatabaseDetails
- Defined in:
- lib/oci/data_safe/models/update_target_database_details.rb
Overview
The details of the database used for updating the target database in Data Safe.
Instance Attribute Summary collapse
- #connection_option ⇒ OCI::DataSafe::Models::ConnectionOption
- #credentials ⇒ OCI::DataSafe::Models::Credentials
- #database_details ⇒ OCI::DataSafe::Models::DatabaseDetails
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
The description of the target database in Data Safe.
-
#display_name ⇒ String
The display name of the target database in Data Safe.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
- #tls_config ⇒ OCI::DataSafe::Models::TlsConfig
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateTargetDatabaseDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateTargetDatabaseDetails
Initializes the object
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/oci/data_safe/models/update_target_database_details.rb', line 90 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.database_details = attributes[:'databaseDetails'] if attributes[:'databaseDetails'] raise 'You cannot provide both :databaseDetails and :database_details' if attributes.key?(:'databaseDetails') && attributes.key?(:'database_details') self.database_details = attributes[:'database_details'] if attributes[:'database_details'] self.credentials = attributes[:'credentials'] if attributes[:'credentials'] self.tls_config = attributes[:'tlsConfig'] if attributes[:'tlsConfig'] raise 'You cannot provide both :tlsConfig and :tls_config' if attributes.key?(:'tlsConfig') && attributes.key?(:'tls_config') self.tls_config = attributes[:'tls_config'] if attributes[:'tls_config'] self.connection_option = attributes[:'connectionOption'] if attributes[:'connectionOption'] raise 'You cannot provide both :connectionOption and :connection_option' if attributes.key?(:'connectionOption') && attributes.key?(:'connection_option') self.connection_option = attributes[:'connection_option'] if attributes[:'connection_option'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#connection_option ⇒ OCI::DataSafe::Models::ConnectionOption
28 29 30 |
# File 'lib/oci/data_safe/models/update_target_database_details.rb', line 28 def connection_option @connection_option end |
#credentials ⇒ OCI::DataSafe::Models::Credentials
22 23 24 |
# File 'lib/oci/data_safe/models/update_target_database_details.rb', line 22 def credentials @credentials end |
#database_details ⇒ OCI::DataSafe::Models::DatabaseDetails
19 20 21 |
# File 'lib/oci/data_safe/models/update_target_database_details.rb', line 19 def database_details @database_details end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)
Example: ‘{"CostCenter": "42"}`
42 43 44 |
# File 'lib/oci/data_safe/models/update_target_database_details.rb', line 42 def end |
#description ⇒ String
The description of the target database in Data Safe.
16 17 18 |
# File 'lib/oci/data_safe/models/update_target_database_details.rb', line 16 def description @description end |
#display_name ⇒ String
The display name of the target database in Data Safe.
12 13 14 |
# File 'lib/oci/data_safe/models/update_target_database_details.rb', line 12 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)
Example: ‘"Finance"`
35 36 37 |
# File 'lib/oci/data_safe/models/update_target_database_details.rb', line 35 def end |
#tls_config ⇒ OCI::DataSafe::Models::TlsConfig
25 26 27 |
# File 'lib/oci/data_safe/models/update_target_database_details.rb', line 25 def tls_config @tls_config end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
45 46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/oci/data_safe/models/update_target_database_details.rb', line 45 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'description': :'description', 'database_details': :'databaseDetails', 'credentials': :'credentials', 'tls_config': :'tlsConfig', 'connection_option': :'connectionOption', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/oci/data_safe/models/update_target_database_details.rb', line 61 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'description': :'String', 'database_details': :'OCI::DataSafe::Models::DatabaseDetails', 'credentials': :'OCI::DataSafe::Models::Credentials', 'tls_config': :'OCI::DataSafe::Models::TlsConfig', 'connection_option': :'OCI::DataSafe::Models::ConnectionOption', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/oci/data_safe/models/update_target_database_details.rb', line 144 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && description == other.description && database_details == other.database_details && credentials == other.credentials && tls_config == other.tls_config && connection_option == other.connection_option && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/oci/data_safe/models/update_target_database_details.rb', line 181 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
161 162 163 |
# File 'lib/oci/data_safe/models/update_target_database_details.rb', line 161 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
170 171 172 |
# File 'lib/oci/data_safe/models/update_target_database_details.rb', line 170 def hash [display_name, description, database_details, credentials, tls_config, connection_option, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
214 215 216 217 218 219 220 221 222 223 |
# File 'lib/oci/data_safe/models/update_target_database_details.rb', line 214 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
208 209 210 |
# File 'lib/oci/data_safe/models/update_target_database_details.rb', line 208 def to_s to_hash.to_s end |