Class: OCI::DataSafe::Models::UserDetails
- Inherits:
-
Object
- Object
- OCI::DataSafe::Models::UserDetails
- Defined in:
- lib/oci/data_safe/models/user_details.rb
Overview
The details of a particular user.
Constant Summary collapse
- AUTHENTICATION_TYPE_ENUM =
[ AUTHENTICATION_TYPE_PASSWORD = 'PASSWORD'.freeze, AUTHENTICATION_TYPE_NONE = 'NONE'.freeze ].freeze
Instance Attribute Summary collapse
-
#authentication_type ⇒ String
The authentication type of the user.
-
#is_user_predefined_by_oracle ⇒ BOOLEAN
Indicates whether or not the user is predefined by ORACLE.
-
#name ⇒ String
The name of the user.
-
#profile ⇒ String
The name of the profile assigned to the user.
-
#status ⇒ String
The status of the user account.
-
#tablespace ⇒ String
The default tablespace of the user.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UserDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UserDetails
Initializes the object
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/oci/data_safe/models/user_details.rb', line 80 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.status = attributes[:'status'] if attributes[:'status'] self.profile = attributes[:'profile'] if attributes[:'profile'] self.tablespace = attributes[:'tablespace'] if attributes[:'tablespace'] self.is_user_predefined_by_oracle = attributes[:'isUserPredefinedByOracle'] unless attributes[:'isUserPredefinedByOracle'].nil? raise 'You cannot provide both :isUserPredefinedByOracle and :is_user_predefined_by_oracle' if attributes.key?(:'isUserPredefinedByOracle') && attributes.key?(:'is_user_predefined_by_oracle') self.is_user_predefined_by_oracle = attributes[:'is_user_predefined_by_oracle'] unless attributes[:'is_user_predefined_by_oracle'].nil? self.authentication_type = attributes[:'authenticationType'] if attributes[:'authenticationType'] raise 'You cannot provide both :authenticationType and :authentication_type' if attributes.key?(:'authenticationType') && attributes.key?(:'authentication_type') self.authentication_type = attributes[:'authentication_type'] if attributes[:'authentication_type'] end |
Instance Attribute Details
#authentication_type ⇒ String
The authentication type of the user.
38 39 40 |
# File 'lib/oci/data_safe/models/user_details.rb', line 38 def authentication_type @authentication_type end |
#is_user_predefined_by_oracle ⇒ BOOLEAN
Indicates whether or not the user is predefined by ORACLE.
34 35 36 |
# File 'lib/oci/data_safe/models/user_details.rb', line 34 def is_user_predefined_by_oracle @is_user_predefined_by_oracle end |
#name ⇒ String
The name of the user.
18 19 20 |
# File 'lib/oci/data_safe/models/user_details.rb', line 18 def name @name end |
#profile ⇒ String
The name of the profile assigned to the user.
26 27 28 |
# File 'lib/oci/data_safe/models/user_details.rb', line 26 def profile @profile end |
#status ⇒ String
The status of the user account.
22 23 24 |
# File 'lib/oci/data_safe/models/user_details.rb', line 22 def status @status end |
#tablespace ⇒ String
The default tablespace of the user.
30 31 32 |
# File 'lib/oci/data_safe/models/user_details.rb', line 30 def tablespace @tablespace end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/oci/data_safe/models/user_details.rb', line 41 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'status': :'status', 'profile': :'profile', 'tablespace': :'tablespace', 'is_user_predefined_by_oracle': :'isUserPredefinedByOracle', 'authentication_type': :'authenticationType' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/oci/data_safe/models/user_details.rb', line 55 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'status': :'String', 'profile': :'String', 'tablespace': :'String', 'is_user_predefined_by_oracle': :'BOOLEAN', 'authentication_type': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/oci/data_safe/models/user_details.rb', line 122 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && status == other.status && profile == other.profile && tablespace == other.tablespace && is_user_predefined_by_oracle == other.is_user_predefined_by_oracle && authentication_type == other.authentication_type end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/oci/data_safe/models/user_details.rb', line 157 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
137 138 139 |
# File 'lib/oci/data_safe/models/user_details.rb', line 137 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
146 147 148 |
# File 'lib/oci/data_safe/models/user_details.rb', line 146 def hash [name, status, profile, tablespace, is_user_predefined_by_oracle, authentication_type].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
190 191 192 193 194 195 196 197 198 199 |
# File 'lib/oci/data_safe/models/user_details.rb', line 190 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
184 185 186 |
# File 'lib/oci/data_safe/models/user_details.rb', line 184 def to_s to_hash.to_s end |