Class: OCI::DataSafe::Models::WorkRequestSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_safe/models/work_request_summary.rb

Overview

Summary of a work request.

Constant Summary collapse

OPERATION_TYPE_ENUM =
[
  OPERATION_TYPE_ENABLE_DATA_SAFE_CONFIGURATION = 'ENABLE_DATA_SAFE_CONFIGURATION'.freeze,
  OPERATION_TYPE_CREATE_PRIVATE_ENDPOINT = 'CREATE_PRIVATE_ENDPOINT'.freeze,
  OPERATION_TYPE_UPDATE_PRIVATE_ENDPOINT = 'UPDATE_PRIVATE_ENDPOINT'.freeze,
  OPERATION_TYPE_DELETE_PRIVATE_ENDPOINT = 'DELETE_PRIVATE_ENDPOINT'.freeze,
  OPERATION_TYPE_CHANGE_PRIVATE_ENDPOINT_COMPARTMENT = 'CHANGE_PRIVATE_ENDPOINT_COMPARTMENT'.freeze,
  OPERATION_TYPE_CREATE_ONPREM_CONNECTOR = 'CREATE_ONPREM_CONNECTOR'.freeze,
  OPERATION_TYPE_UPDATE_ONPREM_CONNECTOR = 'UPDATE_ONPREM_CONNECTOR'.freeze,
  OPERATION_TYPE_DELETE_ONPREM_CONNECTOR = 'DELETE_ONPREM_CONNECTOR'.freeze,
  OPERATION_TYPE_UPDATE_ONPREM_CONNECTOR_WALLET = 'UPDATE_ONPREM_CONNECTOR_WALLET'.freeze,
  OPERATION_TYPE_CHANGE_ONPREM_CONNECTOR_COMPARTMENT = 'CHANGE_ONPREM_CONNECTOR_COMPARTMENT'.freeze,
  OPERATION_TYPE_PROVISION_POLICY = 'PROVISION_POLICY'.freeze,
  OPERATION_TYPE_RETRIEVE_POLICY = 'RETRIEVE_POLICY'.freeze,
  OPERATION_TYPE_UPDATE_POLICY = 'UPDATE_POLICY'.freeze,
  OPERATION_TYPE_CHANGE_POLICY_COMPARTMENT = 'CHANGE_POLICY_COMPARTMENT'.freeze,
  OPERATION_TYPE_CREATE_TARGET_DATABASE = 'CREATE_TARGET_DATABASE'.freeze,
  OPERATION_TYPE_UPDATE_TARGET_DATABASE = 'UPDATE_TARGET_DATABASE'.freeze,
  OPERATION_TYPE_ACTIVATE_TARGET_DATABASE = 'ACTIVATE_TARGET_DATABASE'.freeze,
  OPERATION_TYPE_DEACTIVATE_TARGET_DATABASE = 'DEACTIVATE_TARGET_DATABASE'.freeze,
  OPERATION_TYPE_DELETE_TARGET_DATABASE = 'DELETE_TARGET_DATABASE'.freeze,
  OPERATION_TYPE_CHANGE_TARGET_DATABASE_COMPARTMENT = 'CHANGE_TARGET_DATABASE_COMPARTMENT'.freeze,
  OPERATION_TYPE_CREATE_USER_ASSESSMENT = 'CREATE_USER_ASSESSMENT'.freeze,
  OPERATION_TYPE_ASSESS_USER_ASSESSMENT = 'ASSESS_USER_ASSESSMENT'.freeze,
  OPERATION_TYPE_CREATE_SNAPSHOT_USER_ASSESSMENT = 'CREATE_SNAPSHOT_USER_ASSESSMENT'.freeze,
  OPERATION_TYPE_CREATE_SCHEDULE_USER_ASSESSMENT = 'CREATE_SCHEDULE_USER_ASSESSMENT'.freeze,
  OPERATION_TYPE_COMPARE_WITH_BASELINE_USER_ASSESSMENT = 'COMPARE_WITH_BASELINE_USER_ASSESSMENT'.freeze,
  OPERATION_TYPE_DELETE_USER_ASSESSMENT = 'DELETE_USER_ASSESSMENT'.freeze,
  OPERATION_TYPE_UPDATE_USER_ASSESSMENT = 'UPDATE_USER_ASSESSMENT'.freeze,
  OPERATION_TYPE_CHANGE_USER_ASSESSMENT_COMPARTMENT = 'CHANGE_USER_ASSESSMENT_COMPARTMENT'.freeze,
  OPERATION_TYPE_SET_USER_ASSESSMENT_BASELINE = 'SET_USER_ASSESSMENT_BASELINE'.freeze,
  OPERATION_TYPE_UNSET_USER_ASSESSMENT_BASELINE = 'UNSET_USER_ASSESSMENT_BASELINE'.freeze,
  OPERATION_TYPE_GENERATE_USER_ASSESSMENT_REPORT = 'GENERATE_USER_ASSESSMENT_REPORT'.freeze,
  OPERATION_TYPE_CREATE_SECURITY_ASSESSMENT = 'CREATE_SECURITY_ASSESSMENT'.freeze,
  OPERATION_TYPE_CREATE_SECURITY_ASSESSMENT_NOW = 'CREATE_SECURITY_ASSESSMENT_NOW'.freeze,
  OPERATION_TYPE_ASSESS_SECURITY_ASSESSMENT = 'ASSESS_SECURITY_ASSESSMENT'.freeze,
  OPERATION_TYPE_CREATE_SNAPSHOT_SECURITY_ASSESSMENT = 'CREATE_SNAPSHOT_SECURITY_ASSESSMENT'.freeze,
  OPERATION_TYPE_CREATE_SCHEDULE_SECURITY_ASSESSMENT = 'CREATE_SCHEDULE_SECURITY_ASSESSMENT'.freeze,
  OPERATION_TYPE_COMPARE_WITH_BASELINE_SECURITY_ASSESSMENT = 'COMPARE_WITH_BASELINE_SECURITY_ASSESSMENT'.freeze,
  OPERATION_TYPE_DELETE_SECURITY_ASSESSMENT = 'DELETE_SECURITY_ASSESSMENT'.freeze,
  OPERATION_TYPE_UPDATE_SECURITY_ASSESSMENT = 'UPDATE_SECURITY_ASSESSMENT'.freeze,
  OPERATION_TYPE_CHANGE_SECURITY_ASSESSMENT_COMPARTMENT = 'CHANGE_SECURITY_ASSESSMENT_COMPARTMENT'.freeze,
  OPERATION_TYPE_SET_SECURITY_ASSESSMENT_BASELINE = 'SET_SECURITY_ASSESSMENT_BASELINE'.freeze,
  OPERATION_TYPE_UNSET_SECURITY_ASSESSMENT_BASELINE = 'UNSET_SECURITY_ASSESSMENT_BASELINE'.freeze,
  OPERATION_TYPE_GENERATE_SECURITY_ASSESSMENT_REPORT = 'GENERATE_SECURITY_ASSESSMENT_REPORT'.freeze,
  OPERATION_TYPE_CALCULATE_VOLUME = 'CALCULATE_VOLUME'.freeze,
  OPERATION_TYPE_CALCULATE_COLLECTED_VOLUME = 'CALCULATE_COLLECTED_VOLUME'.freeze,
  OPERATION_TYPE_AUDIT_TRAIL = 'AUDIT_TRAIL'.freeze,
  OPERATION_TYPE_DELETE_AUDIT_TRAIL = 'DELETE_AUDIT_TRAIL'.freeze,
  OPERATION_TYPE_DISCOVER_AUDIT_TRAILS = 'DISCOVER_AUDIT_TRAILS'.freeze,
  OPERATION_TYPE_UPDATE_AUDIT_TRAIL = 'UPDATE_AUDIT_TRAIL'.freeze,
  OPERATION_TYPE_UPDATE_AUDIT_PROFILE = 'UPDATE_AUDIT_PROFILE'.freeze,
  OPERATION_TYPE_AUDIT_CHANGE_COMPARTMENT = 'AUDIT_CHANGE_COMPARTMENT'.freeze,
  OPERATION_TYPE_CREATE_REPORT_DEFINITION = 'CREATE_REPORT_DEFINITION'.freeze,
  OPERATION_TYPE_UPDATE_REPORT_DEFINITION = 'UPDATE_REPORT_DEFINITION'.freeze,
  OPERATION_TYPE_CHANGE_REPORT_DEFINITION_COMPARTMENT = 'CHANGE_REPORT_DEFINITION_COMPARTMENT'.freeze,
  OPERATION_TYPE_DELETE_REPORT_DEFINITION = 'DELETE_REPORT_DEFINITION'.freeze,
  OPERATION_TYPE_GENERATE_REPORT = 'GENERATE_REPORT'.freeze,
  OPERATION_TYPE_CHANGE_REPORT_COMPARTMENT = 'CHANGE_REPORT_COMPARTMENT'.freeze,
  OPERATION_TYPE_DELETE_ARCHIVE_RETRIEVAL = 'DELETE_ARCHIVE_RETRIEVAL'.freeze,
  OPERATION_TYPE_CREATE_ARCHIVE_RETRIEVAL = 'CREATE_ARCHIVE_RETRIEVAL'.freeze,
  OPERATION_TYPE_UPDATE_ARCHIVE_RETRIEVAL = 'UPDATE_ARCHIVE_RETRIEVAL'.freeze,
  OPERATION_TYPE_CHANGE_ARCHIVE_RETRIEVAL_COMPARTMENT = 'CHANGE_ARCHIVE_RETRIEVAL_COMPARTMENT'.freeze,
  OPERATION_TYPE_UPDATE_ALERT = 'UPDATE_ALERT'.freeze,
  OPERATION_TYPE_TARGET_ALERT_POLICY_ASSOCIATION = 'TARGET_ALERT_POLICY_ASSOCIATION'.freeze,
  OPERATION_TYPE_CREATE_SENSITIVE_DATA_MODEL = 'CREATE_SENSITIVE_DATA_MODEL'.freeze,
  OPERATION_TYPE_UPDATE_SENSITIVE_DATA_MODEL = 'UPDATE_SENSITIVE_DATA_MODEL'.freeze,
  OPERATION_TYPE_DELETE_SENSITIVE_DATA_MODEL = 'DELETE_SENSITIVE_DATA_MODEL'.freeze,
  OPERATION_TYPE_UPLOAD_SENSITIVE_DATA_MODEL = 'UPLOAD_SENSITIVE_DATA_MODEL'.freeze,
  OPERATION_TYPE_GENERATE_SENSITIVE_DATA_MODEL_FOR_DOWNLOAD = 'GENERATE_SENSITIVE_DATA_MODEL_FOR_DOWNLOAD'.freeze,
  OPERATION_TYPE_CREATE_SENSITIVE_COLUMN = 'CREATE_SENSITIVE_COLUMN'.freeze,
  OPERATION_TYPE_UPDATE_SENSITIVE_COLUMN = 'UPDATE_SENSITIVE_COLUMN'.freeze,
  OPERATION_TYPE_PATCH_SENSITIVE_COLUMNS = 'PATCH_SENSITIVE_COLUMNS'.freeze,
  OPERATION_TYPE_CREATE_DISCOVERY_JOB = 'CREATE_DISCOVERY_JOB'.freeze,
  OPERATION_TYPE_DELETE_DISCOVERY_JOB = 'DELETE_DISCOVERY_JOB'.freeze,
  OPERATION_TYPE_PATCH_DISCOVERY_JOB_RESULT = 'PATCH_DISCOVERY_JOB_RESULT'.freeze,
  OPERATION_TYPE_APPLY_DISCOVERY_JOB_RESULT = 'APPLY_DISCOVERY_JOB_RESULT'.freeze,
  OPERATION_TYPE_GENERATE_DISCOVERY_REPORT = 'GENERATE_DISCOVERY_REPORT'.freeze,
  OPERATION_TYPE_CREATE_SENSITIVE_TYPE = 'CREATE_SENSITIVE_TYPE'.freeze,
  OPERATION_TYPE_UPDATE_SENSITIVE_TYPE = 'UPDATE_SENSITIVE_TYPE'.freeze,
  OPERATION_TYPE_CREATE_MASKING_POLICY = 'CREATE_MASKING_POLICY'.freeze,
  OPERATION_TYPE_UPDATE_MASKING_POLICY = 'UPDATE_MASKING_POLICY'.freeze,
  OPERATION_TYPE_DELETE_MASKING_POLICY = 'DELETE_MASKING_POLICY'.freeze,
  OPERATION_TYPE_UPLOAD_MASKING_POLICY = 'UPLOAD_MASKING_POLICY'.freeze,
  OPERATION_TYPE_GENERATE_MASKING_POLICY_FOR_DOWNLOAD = 'GENERATE_MASKING_POLICY_FOR_DOWNLOAD'.freeze,
  OPERATION_TYPE_CREATE_MASKING_COLUMN = 'CREATE_MASKING_COLUMN'.freeze,
  OPERATION_TYPE_UPDATE_MASKING_COLUMN = 'UPDATE_MASKING_COLUMN'.freeze,
  OPERATION_TYPE_PATCH_MASKING_COLUMNS = 'PATCH_MASKING_COLUMNS'.freeze,
  OPERATION_TYPE_GENERATE_MASKING_REPORT = 'GENERATE_MASKING_REPORT'.freeze,
  OPERATION_TYPE_CREATE_LIBRARY_MASKING_FORMAT = 'CREATE_LIBRARY_MASKING_FORMAT'.freeze,
  OPERATION_TYPE_UPDATE_LIBRARY_MASKING_FORMAT = 'UPDATE_LIBRARY_MASKING_FORMAT'.freeze,
  OPERATION_TYPE_ADD_COLUMNS_FROM_SDM = 'ADD_COLUMNS_FROM_SDM'.freeze,
  OPERATION_TYPE_MASKING_JOB = 'MASKING_JOB'.freeze,
  OPERATION_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
STATUS_ENUM =
[
  STATUS_ACCEPTED = 'ACCEPTED'.freeze,
  STATUS_IN_PROGRESS = 'IN_PROGRESS'.freeze,
  STATUS_FAILED = 'FAILED'.freeze,
  STATUS_SUCCEEDED = 'SUCCEEDED'.freeze,
  STATUS_CANCELING = 'CANCELING'.freeze,
  STATUS_CANCELED = 'CANCELED'.freeze,
  STATUS_SUSPENDING = 'SUSPENDING'.freeze,
  STATUS_SUSPENDED = 'SUSPENDED'.freeze,
  STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ WorkRequestSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
# File 'lib/oci/data_safe/models/work_request_summary.rb', line 207

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.operation_type = attributes[:'operationType'] if attributes[:'operationType']

  raise 'You cannot provide both :operationType and :operation_type' if attributes.key?(:'operationType') && attributes.key?(:'operation_type')

  self.operation_type = attributes[:'operation_type'] if attributes[:'operation_type']

  self.status = attributes[:'status'] if attributes[:'status']

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.resources = attributes[:'resources'] if attributes[:'resources']

  self.percent_complete = attributes[:'percentComplete'] if attributes[:'percentComplete']

  raise 'You cannot provide both :percentComplete and :percent_complete' if attributes.key?(:'percentComplete') && attributes.key?(:'percent_complete')

  self.percent_complete = attributes[:'percent_complete'] if attributes[:'percent_complete']

  self.time_accepted = attributes[:'timeAccepted'] if attributes[:'timeAccepted']

  raise 'You cannot provide both :timeAccepted and :time_accepted' if attributes.key?(:'timeAccepted') && attributes.key?(:'time_accepted')

  self.time_accepted = attributes[:'time_accepted'] if attributes[:'time_accepted']

  self.time_started = attributes[:'timeStarted'] if attributes[:'timeStarted']

  raise 'You cannot provide both :timeStarted and :time_started' if attributes.key?(:'timeStarted') && attributes.key?(:'time_started')

  self.time_started = attributes[:'time_started'] if attributes[:'time_started']

  self.time_finished = attributes[:'timeFinished'] if attributes[:'timeFinished']

  raise 'You cannot provide both :timeFinished and :time_finished' if attributes.key?(:'timeFinished') && attributes.key?(:'time_finished')

  self.time_finished = attributes[:'time_finished'] if attributes[:'time_finished']
end

Instance Attribute Details

#compartment_idString

[Required] The OCID of the compartment that contains the work request.

Returns:

  • (String)


133
134
135
# File 'lib/oci/data_safe/models/work_request_summary.rb', line 133

def compartment_id
  @compartment_id
end

#idString

[Required] The OCID of the work request.

Returns:

  • (String)


128
129
130
# File 'lib/oci/data_safe/models/work_request_summary.rb', line 128

def id
  @id
end

#operation_typeString

[Required] The asynchronous operation tracked by this work request.

Returns:

  • (String)


120
121
122
# File 'lib/oci/data_safe/models/work_request_summary.rb', line 120

def operation_type
  @operation_type
end

#percent_completeFloat

[Required] Progress of the work request in percentage.

Returns:

  • (Float)


141
142
143
# File 'lib/oci/data_safe/models/work_request_summary.rb', line 141

def percent_complete
  @percent_complete
end

#resourcesArray<OCI::DataSafe::Models::WorkRequestResource>

[Required] The resources that are affected by the work request.



137
138
139
# File 'lib/oci/data_safe/models/work_request_summary.rb', line 137

def resources
  @resources
end

#statusString

[Required] The current status of the work request.

Returns:

  • (String)


124
125
126
# File 'lib/oci/data_safe/models/work_request_summary.rb', line 124

def status
  @status
end

#time_acceptedDateTime

[Required] The date and time the work request was accepted, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).

Returns:

  • (DateTime)


146
147
148
# File 'lib/oci/data_safe/models/work_request_summary.rb', line 146

def time_accepted
  @time_accepted
end

#time_finishedDateTime

The date and time the work request reached a terminal state, either FAILED or SUCCEEDED, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).

Returns:

  • (DateTime)


156
157
158
# File 'lib/oci/data_safe/models/work_request_summary.rb', line 156

def time_finished
  @time_finished
end

#time_startedDateTime

The date and time the work request transitioned from ACCEPTED to IN_PROGRESS, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).

Returns:

  • (DateTime)


151
152
153
# File 'lib/oci/data_safe/models/work_request_summary.rb', line 151

def time_started
  @time_started
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/oci/data_safe/models/work_request_summary.rb', line 159

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'operation_type': :'operationType',
    'status': :'status',
    'id': :'id',
    'compartment_id': :'compartmentId',
    'resources': :'resources',
    'percent_complete': :'percentComplete',
    'time_accepted': :'timeAccepted',
    'time_started': :'timeStarted',
    'time_finished': :'timeFinished'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/oci/data_safe/models/work_request_summary.rb', line 176

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'operation_type': :'String',
    'status': :'String',
    'id': :'String',
    'compartment_id': :'String',
    'resources': :'Array<OCI::DataSafe::Models::WorkRequestResource>',
    'percent_complete': :'Float',
    'time_accepted': :'DateTime',
    'time_started': :'DateTime',
    'time_finished': :'DateTime'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



289
290
291
292
293
294
295
296
297
298
299
300
301
302
# File 'lib/oci/data_safe/models/work_request_summary.rb', line 289

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    operation_type == other.operation_type &&
    status == other.status &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    resources == other.resources &&
    percent_complete == other.percent_complete &&
    time_accepted == other.time_accepted &&
    time_started == other.time_started &&
    time_finished == other.time_finished
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
# File 'lib/oci/data_safe/models/work_request_summary.rb', line 327

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


307
308
309
# File 'lib/oci/data_safe/models/work_request_summary.rb', line 307

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



316
317
318
# File 'lib/oci/data_safe/models/work_request_summary.rb', line 316

def hash
  [operation_type, status, id, compartment_id, resources, percent_complete, time_accepted, time_started, time_finished].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



360
361
362
363
364
365
366
367
368
369
# File 'lib/oci/data_safe/models/work_request_summary.rb', line 360

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



354
355
356
# File 'lib/oci/data_safe/models/work_request_summary.rb', line 354

def to_s
  to_hash.to_s
end