Class: OCI::DataScience::Models::CreateJobDetails
- Inherits:
-
Object
- Object
- OCI::DataScience::Models::CreateJobDetails
- Defined in:
- lib/oci/data_science/models/create_job_details.rb
Overview
Parameters needed to create a new job.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment where you want to create the job.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
A short description of the job.
-
#display_name ⇒ String
A user-friendly display name for the resource.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#job_configuration_details ⇒ OCI::DataScience::Models::JobConfigurationDetails
This attribute is required.
-
#job_infrastructure_configuration_details ⇒ OCI::DataScience::Models::JobInfrastructureConfigurationDetails
This attribute is required.
- #job_log_configuration_details ⇒ OCI::DataScience::Models::JobLogConfigurationDetails
-
#project_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the project to associate the job with.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateJobDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateJobDetails
Initializes the object
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/oci/data_science/models/create_job_details.rb', line 99 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.project_id = attributes[:'projectId'] if attributes[:'projectId'] raise 'You cannot provide both :projectId and :project_id' if attributes.key?(:'projectId') && attributes.key?(:'project_id') self.project_id = attributes[:'project_id'] if attributes[:'project_id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.job_configuration_details = attributes[:'jobConfigurationDetails'] if attributes[:'jobConfigurationDetails'] raise 'You cannot provide both :jobConfigurationDetails and :job_configuration_details' if attributes.key?(:'jobConfigurationDetails') && attributes.key?(:'job_configuration_details') self.job_configuration_details = attributes[:'job_configuration_details'] if attributes[:'job_configuration_details'] self.job_infrastructure_configuration_details = attributes[:'jobInfrastructureConfigurationDetails'] if attributes[:'jobInfrastructureConfigurationDetails'] raise 'You cannot provide both :jobInfrastructureConfigurationDetails and :job_infrastructure_configuration_details' if attributes.key?(:'jobInfrastructureConfigurationDetails') && attributes.key?(:'job_infrastructure_configuration_details') self.job_infrastructure_configuration_details = attributes[:'job_infrastructure_configuration_details'] if attributes[:'job_infrastructure_configuration_details'] self.job_log_configuration_details = attributes[:'jobLogConfigurationDetails'] if attributes[:'jobLogConfigurationDetails'] raise 'You cannot provide both :jobLogConfigurationDetails and :job_log_configuration_details' if attributes.key?(:'jobLogConfigurationDetails') && attributes.key?(:'job_log_configuration_details') self.job_log_configuration_details = attributes[:'job_log_configuration_details'] if attributes[:'job_log_configuration_details'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment where you want to create the job.
17 18 19 |
# File 'lib/oci/data_science/models/create_job_details.rb', line 17 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"CostCenter": "42"}`
48 49 50 |
# File 'lib/oci/data_science/models/create_job_details.rb', line 48 def @defined_tags end |
#description ⇒ String
A short description of the job.
25 26 27 |
# File 'lib/oci/data_science/models/create_job_details.rb', line 25 def description @description end |
#display_name ⇒ String
A user-friendly display name for the resource.
21 22 23 |
# File 'lib/oci/data_science/models/create_job_details.rb', line 21 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"Finance"`
42 43 44 |
# File 'lib/oci/data_science/models/create_job_details.rb', line 42 def @freeform_tags end |
#job_configuration_details ⇒ OCI::DataScience::Models::JobConfigurationDetails
This attribute is required.
29 30 31 |
# File 'lib/oci/data_science/models/create_job_details.rb', line 29 def job_configuration_details @job_configuration_details end |
#job_infrastructure_configuration_details ⇒ OCI::DataScience::Models::JobInfrastructureConfigurationDetails
This attribute is required.
33 34 35 |
# File 'lib/oci/data_science/models/create_job_details.rb', line 33 def job_infrastructure_configuration_details @job_infrastructure_configuration_details end |
#job_log_configuration_details ⇒ OCI::DataScience::Models::JobLogConfigurationDetails
36 37 38 |
# File 'lib/oci/data_science/models/create_job_details.rb', line 36 def job_log_configuration_details @job_log_configuration_details end |
#project_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the project to associate the job with.
13 14 15 |
# File 'lib/oci/data_science/models/create_job_details.rb', line 13 def project_id @project_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/oci/data_science/models/create_job_details.rb', line 51 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'project_id': :'projectId', 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'description': :'description', 'job_configuration_details': :'jobConfigurationDetails', 'job_infrastructure_configuration_details': :'jobInfrastructureConfigurationDetails', 'job_log_configuration_details': :'jobLogConfigurationDetails', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/oci/data_science/models/create_job_details.rb', line 68 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'project_id': :'String', 'compartment_id': :'String', 'display_name': :'String', 'description': :'String', 'job_configuration_details': :'OCI::DataScience::Models::JobConfigurationDetails', 'job_infrastructure_configuration_details': :'OCI::DataScience::Models::JobInfrastructureConfigurationDetails', 'job_log_configuration_details': :'OCI::DataScience::Models::JobLogConfigurationDetails', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/oci/data_science/models/create_job_details.rb', line 163 def ==(other) return true if equal?(other) self.class == other.class && project_id == other.project_id && compartment_id == other.compartment_id && display_name == other.display_name && description == other.description && job_configuration_details == other.job_configuration_details && job_infrastructure_configuration_details == other.job_infrastructure_configuration_details && job_log_configuration_details == other.job_log_configuration_details && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/oci/data_science/models/create_job_details.rb', line 201 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
181 182 183 |
# File 'lib/oci/data_science/models/create_job_details.rb', line 181 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
190 191 192 |
# File 'lib/oci/data_science/models/create_job_details.rb', line 190 def hash [project_id, compartment_id, display_name, description, job_configuration_details, job_infrastructure_configuration_details, job_log_configuration_details, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
234 235 236 237 238 239 240 241 242 243 |
# File 'lib/oci/data_science/models/create_job_details.rb', line 234 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
228 229 230 |
# File 'lib/oci/data_science/models/create_job_details.rb', line 228 def to_s to_hash.to_s end |