Class: OCI::DataScience::Models::CreateJobRunDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_science/models/create_job_run_details.rb

Overview

Parameters needed to create a new job run.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateJobRunDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/oci/data_science/models/create_job_run_details.rb', line 91

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.project_id = attributes[:'projectId'] if attributes[:'projectId']

  raise 'You cannot provide both :projectId and :project_id' if attributes.key?(:'projectId') && attributes.key?(:'project_id')

  self.project_id = attributes[:'project_id'] if attributes[:'project_id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.job_id = attributes[:'jobId'] if attributes[:'jobId']

  raise 'You cannot provide both :jobId and :job_id' if attributes.key?(:'jobId') && attributes.key?(:'job_id')

  self.job_id = attributes[:'job_id'] if attributes[:'job_id']

  self.job_configuration_override_details = attributes[:'jobConfigurationOverrideDetails'] if attributes[:'jobConfigurationOverrideDetails']

  raise 'You cannot provide both :jobConfigurationOverrideDetails and :job_configuration_override_details' if attributes.key?(:'jobConfigurationOverrideDetails') && attributes.key?(:'job_configuration_override_details')

  self.job_configuration_override_details = attributes[:'job_configuration_override_details'] if attributes[:'job_configuration_override_details']

  self.job_log_configuration_override_details = attributes[:'jobLogConfigurationOverrideDetails'] if attributes[:'jobLogConfigurationOverrideDetails']

  raise 'You cannot provide both :jobLogConfigurationOverrideDetails and :job_log_configuration_override_details' if attributes.key?(:'jobLogConfigurationOverrideDetails') && attributes.key?(:'job_log_configuration_override_details')

  self.job_log_configuration_override_details = attributes[:'job_log_configuration_override_details'] if attributes[:'job_log_configuration_override_details']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#compartment_idString

[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment where you want to create the job.

Returns:

  • (String)


17
18
19
# File 'lib/oci/data_science/models/create_job_run_details.rb', line 17

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


43
44
45
# File 'lib/oci/data_science/models/create_job_run_details.rb', line 43

def defined_tags
  @defined_tags
end

#display_nameString

A user-friendly display name for the resource.

Returns:

  • (String)


21
22
23
# File 'lib/oci/data_science/models/create_job_run_details.rb', line 21

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"Finance"`

Returns:

  • (Hash<String, String>)


37
38
39
# File 'lib/oci/data_science/models/create_job_run_details.rb', line 37

def freeform_tags
  @freeform_tags
end

#job_configuration_override_detailsOCI::DataScience::Models::JobConfigurationDetails



28
29
30
# File 'lib/oci/data_science/models/create_job_run_details.rb', line 28

def job_configuration_override_details
  @job_configuration_override_details
end

#job_idString

[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the job to create a run for.

Returns:

  • (String)


25
26
27
# File 'lib/oci/data_science/models/create_job_run_details.rb', line 25

def job_id
  @job_id
end

#job_log_configuration_override_detailsOCI::DataScience::Models::JobLogConfigurationDetails



31
32
33
# File 'lib/oci/data_science/models/create_job_run_details.rb', line 31

def job_log_configuration_override_details
  @job_log_configuration_override_details
end

#project_idString

[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the project to associate the job with.

Returns:

  • (String)


13
14
15
# File 'lib/oci/data_science/models/create_job_run_details.rb', line 13

def project_id
  @project_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



46
47
48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/oci/data_science/models/create_job_run_details.rb', line 46

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'project_id': :'projectId',
    'compartment_id': :'compartmentId',
    'display_name': :'displayName',
    'job_id': :'jobId',
    'job_configuration_override_details': :'jobConfigurationOverrideDetails',
    'job_log_configuration_override_details': :'jobLogConfigurationOverrideDetails',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/oci/data_science/models/create_job_run_details.rb', line 62

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'project_id': :'String',
    'compartment_id': :'String',
    'display_name': :'String',
    'job_id': :'String',
    'job_configuration_override_details': :'OCI::DataScience::Models::JobConfigurationDetails',
    'job_log_configuration_override_details': :'OCI::DataScience::Models::JobLogConfigurationDetails',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/oci/data_science/models/create_job_run_details.rb', line 153

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    project_id == other.project_id &&
    compartment_id == other.compartment_id &&
    display_name == other.display_name &&
    job_id == other.job_id &&
    job_configuration_override_details == other.job_configuration_override_details &&
    job_log_configuration_override_details == other.job_log_configuration_override_details &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
# File 'lib/oci/data_science/models/create_job_run_details.rb', line 190

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


170
171
172
# File 'lib/oci/data_science/models/create_job_run_details.rb', line 170

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



179
180
181
# File 'lib/oci/data_science/models/create_job_run_details.rb', line 179

def hash
  [project_id, compartment_id, display_name, job_id, job_configuration_override_details, job_log_configuration_override_details, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



223
224
225
226
227
228
229
230
231
232
# File 'lib/oci/data_science/models/create_job_run_details.rb', line 223

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



217
218
219
# File 'lib/oci/data_science/models/create_job_run_details.rb', line 217

def to_s
  to_hash.to_s
end