Class: OCI::DataScience::Models::CreateModelDeploymentDetails
- Inherits:
-
Object
- Object
- OCI::DataScience::Models::CreateModelDeploymentDetails
- Defined in:
- lib/oci/data_science/models/create_model_deployment_details.rb
Overview
Parameters needed to create a new model deployment. Model deployments are used by data scientists to perform predictions from the model hosted on an HTTP server.
Instance Attribute Summary collapse
- #category_log_details ⇒ OCI::DataScience::Models::CategoryLogDetails
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment where you want to create the model deployment.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
A short description of the model deployment.
-
#display_name ⇒ String
A user-friendly display name for the resource.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#model_deployment_configuration_details ⇒ OCI::DataScience::Models::ModelDeploymentConfigurationDetails
This attribute is required.
-
#project_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the project to associate with the model deployment.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateModelDeploymentDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateModelDeploymentDetails
Initializes the object
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/oci/data_science/models/create_model_deployment_details.rb', line 94 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.project_id = attributes[:'projectId'] if attributes[:'projectId'] raise 'You cannot provide both :projectId and :project_id' if attributes.key?(:'projectId') && attributes.key?(:'project_id') self.project_id = attributes[:'project_id'] if attributes[:'project_id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.model_deployment_configuration_details = attributes[:'modelDeploymentConfigurationDetails'] if attributes[:'modelDeploymentConfigurationDetails'] raise 'You cannot provide both :modelDeploymentConfigurationDetails and :model_deployment_configuration_details' if attributes.key?(:'modelDeploymentConfigurationDetails') && attributes.key?(:'model_deployment_configuration_details') self.model_deployment_configuration_details = attributes[:'model_deployment_configuration_details'] if attributes[:'model_deployment_configuration_details'] self.category_log_details = attributes[:'categoryLogDetails'] if attributes[:'categoryLogDetails'] raise 'You cannot provide both :categoryLogDetails and :category_log_details' if attributes.key?(:'categoryLogDetails') && attributes.key?(:'category_log_details') self.category_log_details = attributes[:'category_log_details'] if attributes[:'category_log_details'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#category_log_details ⇒ OCI::DataScience::Models::CategoryLogDetails
34 35 36 |
# File 'lib/oci/data_science/models/create_model_deployment_details.rb', line 34 def category_log_details @category_log_details end |
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment where you want to create the model deployment.
27 28 29 |
# File 'lib/oci/data_science/models/create_model_deployment_details.rb', line 27 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"CostCenter": "42"}`
46 47 48 |
# File 'lib/oci/data_science/models/create_model_deployment_details.rb', line 46 def end |
#description ⇒ String
A short description of the model deployment.
19 20 21 |
# File 'lib/oci/data_science/models/create_model_deployment_details.rb', line 19 def description @description end |
#display_name ⇒ String
A user-friendly display name for the resource. Does not have to be unique, and can be modified. Avoid entering confidential information. Example: ‘My ModelDeployment`
15 16 17 |
# File 'lib/oci/data_science/models/create_model_deployment_details.rb', line 15 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"Finance"`
40 41 42 |
# File 'lib/oci/data_science/models/create_model_deployment_details.rb', line 40 def end |
#model_deployment_configuration_details ⇒ OCI::DataScience::Models::ModelDeploymentConfigurationDetails
This attribute is required.
31 32 33 |
# File 'lib/oci/data_science/models/create_model_deployment_details.rb', line 31 def model_deployment_configuration_details @model_deployment_configuration_details end |
#project_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the project to associate with the model deployment.
23 24 25 |
# File 'lib/oci/data_science/models/create_model_deployment_details.rb', line 23 def project_id @project_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/oci/data_science/models/create_model_deployment_details.rb', line 49 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'description': :'description', 'project_id': :'projectId', 'compartment_id': :'compartmentId', 'model_deployment_configuration_details': :'modelDeploymentConfigurationDetails', 'category_log_details': :'categoryLogDetails', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/oci/data_science/models/create_model_deployment_details.rb', line 65 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'description': :'String', 'project_id': :'String', 'compartment_id': :'String', 'model_deployment_configuration_details': :'OCI::DataScience::Models::ModelDeploymentConfigurationDetails', 'category_log_details': :'OCI::DataScience::Models::CategoryLogDetails', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/oci/data_science/models/create_model_deployment_details.rb', line 152 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && description == other.description && project_id == other.project_id && compartment_id == other.compartment_id && model_deployment_configuration_details == other.model_deployment_configuration_details && category_log_details == other.category_log_details && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/oci/data_science/models/create_model_deployment_details.rb', line 189 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
169 170 171 |
# File 'lib/oci/data_science/models/create_model_deployment_details.rb', line 169 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
178 179 180 |
# File 'lib/oci/data_science/models/create_model_deployment_details.rb', line 178 def hash [display_name, description, project_id, compartment_id, model_deployment_configuration_details, category_log_details, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
222 223 224 225 226 227 228 229 230 231 |
# File 'lib/oci/data_science/models/create_model_deployment_details.rb', line 222 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
216 217 218 |
# File 'lib/oci/data_science/models/create_model_deployment_details.rb', line 216 def to_s to_hash.to_s end |