Class: OCI::DataScience::Models::CreateModelDetails
- Inherits:
-
Object
- Object
- OCI::DataScience::Models::CreateModelDetails
- Defined in:
- lib/oci/data_science/models/create_model_details.rb
Overview
Parameters needed to create a new model. Models are mathematical representations of the relationships between data. Models are represented by their associated metadata and artifact.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment to create the model in.
-
#custom_metadata_list ⇒ Array<OCI::DataScience::Models::Metadata>
An array of custom metadata details for the model.
-
#defined_metadata_list ⇒ Array<OCI::DataScience::Models::Metadata>
An array of defined metadata details for the model.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
A short description of the model.
-
#display_name ⇒ String
A user-friendly display name for the resource.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#input_schema ⇒ String
Input schema file content in String format.
-
#output_schema ⇒ String
Output schema file content in String format.
-
#project_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the project to associate with the model.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateModelDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateModelDetails
Initializes the object
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/oci/data_science/models/create_model_details.rb', line 108 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.project_id = attributes[:'projectId'] if attributes[:'projectId'] raise 'You cannot provide both :projectId and :project_id' if attributes.key?(:'projectId') && attributes.key?(:'project_id') self.project_id = attributes[:'project_id'] if attributes[:'project_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'customMetadataList'] if attributes[:'customMetadataList'] raise 'You cannot provide both :customMetadataList and :custom_metadata_list' if attributes.key?(:'customMetadataList') && attributes.key?(:'custom_metadata_list') self. = attributes[:'custom_metadata_list'] if attributes[:'custom_metadata_list'] self. = attributes[:'definedMetadataList'] if attributes[:'definedMetadataList'] raise 'You cannot provide both :definedMetadataList and :defined_metadata_list' if attributes.key?(:'definedMetadataList') && attributes.key?(:'defined_metadata_list') self. = attributes[:'defined_metadata_list'] if attributes[:'defined_metadata_list'] self.input_schema = attributes[:'inputSchema'] if attributes[:'inputSchema'] raise 'You cannot provide both :inputSchema and :input_schema' if attributes.key?(:'inputSchema') && attributes.key?(:'input_schema') self.input_schema = attributes[:'input_schema'] if attributes[:'input_schema'] self.output_schema = attributes[:'outputSchema'] if attributes[:'outputSchema'] raise 'You cannot provide both :outputSchema and :output_schema' if attributes.key?(:'outputSchema') && attributes.key?(:'output_schema') self.output_schema = attributes[:'output_schema'] if attributes[:'output_schema'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment to create the model in.
12 13 14 |
# File 'lib/oci/data_science/models/create_model_details.rb', line 12 def compartment_id @compartment_id end |
#custom_metadata_list ⇒ Array<OCI::DataScience::Models::Metadata>
An array of custom metadata details for the model.
42 43 44 |
# File 'lib/oci/data_science/models/create_model_details.rb', line 42 def @custom_metadata_list end |
#defined_metadata_list ⇒ Array<OCI::DataScience::Models::Metadata>
An array of defined metadata details for the model.
46 47 48 |
# File 'lib/oci/data_science/models/create_model_details.rb', line 46 def @defined_metadata_list end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"CostCenter": "42"}`
38 39 40 |
# File 'lib/oci/data_science/models/create_model_details.rb', line 38 def @defined_tags end |
#description ⇒ String
A short description of the model.
26 27 28 |
# File 'lib/oci/data_science/models/create_model_details.rb', line 26 def description @description end |
#display_name ⇒ String
A user-friendly display name for the resource. It does not have to be unique and can be modified. Avoid entering confidential information. Example: ‘My Model`
22 23 24 |
# File 'lib/oci/data_science/models/create_model_details.rb', line 22 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"Finance"`
32 33 34 |
# File 'lib/oci/data_science/models/create_model_details.rb', line 32 def @freeform_tags end |
#input_schema ⇒ String
Input schema file content in String format
50 51 52 |
# File 'lib/oci/data_science/models/create_model_details.rb', line 50 def input_schema @input_schema end |
#output_schema ⇒ String
Output schema file content in String format
54 55 56 |
# File 'lib/oci/data_science/models/create_model_details.rb', line 54 def output_schema @output_schema end |
#project_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the project to associate with the model.
16 17 18 |
# File 'lib/oci/data_science/models/create_model_details.rb', line 16 def project_id @project_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/oci/data_science/models/create_model_details.rb', line 57 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'project_id': :'projectId', 'display_name': :'displayName', 'description': :'description', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'custom_metadata_list': :'customMetadataList', 'defined_metadata_list': :'definedMetadataList', 'input_schema': :'inputSchema', 'output_schema': :'outputSchema' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/oci/data_science/models/create_model_details.rb', line 75 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'project_id': :'String', 'display_name': :'String', 'description': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'custom_metadata_list': :'Array<OCI::DataScience::Models::Metadata>', 'defined_metadata_list': :'Array<OCI::DataScience::Models::Metadata>', 'input_schema': :'String', 'output_schema': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/oci/data_science/models/create_model_details.rb', line 178 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && project_id == other.project_id && display_name == other.display_name && description == other.description && == other. && == other. && == other. && == other. && input_schema == other.input_schema && output_schema == other.output_schema end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/oci/data_science/models/create_model_details.rb', line 217 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
197 198 199 |
# File 'lib/oci/data_science/models/create_model_details.rb', line 197 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
206 207 208 |
# File 'lib/oci/data_science/models/create_model_details.rb', line 206 def hash [compartment_id, project_id, display_name, description, , , , , input_schema, output_schema].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
250 251 252 253 254 255 256 257 258 259 |
# File 'lib/oci/data_science/models/create_model_details.rb', line 250 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
244 245 246 |
# File 'lib/oci/data_science/models/create_model_details.rb', line 244 def to_s to_hash.to_s end |