Class: OCI::DataScience::Models::CreateNotebookSessionDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_science/models/create_notebook_session_details.rb

Overview

Parameters needed to create a new notebook session. Notebook sessions are interactive coding environments for data scientists.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateNotebookSessionDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/oci/data_science/models/create_notebook_session_details.rb', line 86

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.project_id = attributes[:'projectId'] if attributes[:'projectId']

  raise 'You cannot provide both :projectId and :project_id' if attributes.key?(:'projectId') && attributes.key?(:'project_id')

  self.project_id = attributes[:'project_id'] if attributes[:'project_id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.notebook_session_configuration_details = attributes[:'notebookSessionConfigurationDetails'] if attributes[:'notebookSessionConfigurationDetails']

  raise 'You cannot provide both :notebookSessionConfigurationDetails and :notebook_session_configuration_details' if attributes.key?(:'notebookSessionConfigurationDetails') && attributes.key?(:'notebook_session_configuration_details')

  self.notebook_session_configuration_details = attributes[:'notebook_session_configuration_details'] if attributes[:'notebook_session_configuration_details']

  self.notebook_session_config_details = attributes[:'notebookSessionConfigDetails'] if attributes[:'notebookSessionConfigDetails']

  raise 'You cannot provide both :notebookSessionConfigDetails and :notebook_session_config_details' if attributes.key?(:'notebookSessionConfigDetails') && attributes.key?(:'notebook_session_config_details')

  self.notebook_session_config_details = attributes[:'notebook_session_config_details'] if attributes[:'notebook_session_config_details']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#compartment_idString

**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment where you want to create the notebook session.

Returns:

  • (String)


23
24
25
# File 'lib/oci/data_science/models/create_notebook_session_details.rb', line 23

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


41
42
43
# File 'lib/oci/data_science/models/create_notebook_session_details.rb', line 41

def defined_tags
  @defined_tags
end

#display_nameString

A user-friendly display name for the resource. It does not have to be unique and can be modified. Avoid entering confidential information. Example: `My NotebookSession`

Returns:

  • (String)


15
16
17
# File 'lib/oci/data_science/models/create_notebook_session_details.rb', line 15

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `"Finance"`

Returns:

  • (Hash<String, String>)


35
36
37
# File 'lib/oci/data_science/models/create_notebook_session_details.rb', line 35

def freeform_tags
  @freeform_tags
end

#notebook_session_config_detailsOCI::DataScience::Models::NotebookSessionConfigDetails



29
30
31
# File 'lib/oci/data_science/models/create_notebook_session_details.rb', line 29

def notebook_session_config_details
  @notebook_session_config_details
end

#notebook_session_configuration_detailsOCI::DataScience::Models::NotebookSessionConfigurationDetails



26
27
28
# File 'lib/oci/data_science/models/create_notebook_session_details.rb', line 26

def notebook_session_configuration_details
  @notebook_session_configuration_details
end

#project_idString

**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the project to associate with the notebook session.

Returns:

  • (String)


19
20
21
# File 'lib/oci/data_science/models/create_notebook_session_details.rb', line 19

def project_id
  @project_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



44
45
46
47
48
49
50
51
52
53
54
55
56
# File 'lib/oci/data_science/models/create_notebook_session_details.rb', line 44

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'displayName',
    'project_id': :'projectId',
    'compartment_id': :'compartmentId',
    'notebook_session_configuration_details': :'notebookSessionConfigurationDetails',
    'notebook_session_config_details': :'notebookSessionConfigDetails',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/oci/data_science/models/create_notebook_session_details.rb', line 59

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'String',
    'project_id': :'String',
    'compartment_id': :'String',
    'notebook_session_configuration_details': :'OCI::DataScience::Models::NotebookSessionConfigurationDetails',
    'notebook_session_config_details': :'OCI::DataScience::Models::NotebookSessionConfigDetails',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/oci/data_science/models/create_notebook_session_details.rb', line 142

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    display_name == other.display_name &&
    project_id == other.project_id &&
    compartment_id == other.compartment_id &&
    notebook_session_configuration_details == other.notebook_session_configuration_details &&
    notebook_session_config_details == other.notebook_session_config_details &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/oci/data_science/models/create_notebook_session_details.rb', line 178

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


158
159
160
# File 'lib/oci/data_science/models/create_notebook_session_details.rb', line 158

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



167
168
169
# File 'lib/oci/data_science/models/create_notebook_session_details.rb', line 167

def hash
  [display_name, project_id, compartment_id, notebook_session_configuration_details, notebook_session_config_details, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



211
212
213
214
215
216
217
218
219
220
# File 'lib/oci/data_science/models/create_notebook_session_details.rb', line 211

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



205
206
207
# File 'lib/oci/data_science/models/create_notebook_session_details.rb', line 205

def to_s
  to_hash.to_s
end