Class: OCI::DataScience::Models::DefaultJobConfigurationDetails
- Inherits:
-
JobConfigurationDetails
- Object
- JobConfigurationDetails
- OCI::DataScience::Models::DefaultJobConfigurationDetails
- Defined in:
- lib/oci/data_science/models/default_job_configuration_details.rb
Overview
The default job configuration.
Constant Summary
Constants inherited from JobConfigurationDetails
JobConfigurationDetails::JOB_TYPE_ENUM
Instance Attribute Summary collapse
-
#command_line_arguments ⇒ String
The arguments to pass to the job.
-
#environment_variables ⇒ Hash<String, String>
Environment variables to set for the job.
-
#maximum_runtime_in_minutes ⇒ Integer
A time bound for the execution of the job.
Attributes inherited from JobConfigurationDetails
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DefaultJobConfigurationDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from JobConfigurationDetails
Constructor Details
#initialize(attributes = {}) ⇒ DefaultJobConfigurationDetails
Initializes the object
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/oci/data_science/models/default_job_configuration_details.rb', line 59 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['jobType'] = 'DEFAULT' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.environment_variables = attributes[:'environmentVariables'] if attributes[:'environmentVariables'] raise 'You cannot provide both :environmentVariables and :environment_variables' if attributes.key?(:'environmentVariables') && attributes.key?(:'environment_variables') self.environment_variables = attributes[:'environment_variables'] if attributes[:'environment_variables'] self.command_line_arguments = attributes[:'commandLineArguments'] if attributes[:'commandLineArguments'] raise 'You cannot provide both :commandLineArguments and :command_line_arguments' if attributes.key?(:'commandLineArguments') && attributes.key?(:'command_line_arguments') self.command_line_arguments = attributes[:'command_line_arguments'] if attributes[:'command_line_arguments'] self.maximum_runtime_in_minutes = attributes[:'maximumRuntimeInMinutes'] if attributes[:'maximumRuntimeInMinutes'] raise 'You cannot provide both :maximumRuntimeInMinutes and :maximum_runtime_in_minutes' if attributes.key?(:'maximumRuntimeInMinutes') && attributes.key?(:'maximum_runtime_in_minutes') self.maximum_runtime_in_minutes = attributes[:'maximum_runtime_in_minutes'] if attributes[:'maximum_runtime_in_minutes'] end |
Instance Attribute Details
#command_line_arguments ⇒ String
The arguments to pass to the job.
19 20 21 |
# File 'lib/oci/data_science/models/default_job_configuration_details.rb', line 19 def command_line_arguments @command_line_arguments end |
#environment_variables ⇒ Hash<String, String>
Environment variables to set for the job.
14 15 16 |
# File 'lib/oci/data_science/models/default_job_configuration_details.rb', line 14 def environment_variables @environment_variables end |
#maximum_runtime_in_minutes ⇒ Integer
A time bound for the execution of the job. Timer starts when the job becomes active.
24 25 26 |
# File 'lib/oci/data_science/models/default_job_configuration_details.rb', line 24 def maximum_runtime_in_minutes @maximum_runtime_in_minutes end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
27 28 29 30 31 32 33 34 35 36 |
# File 'lib/oci/data_science/models/default_job_configuration_details.rb', line 27 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'job_type': :'jobType', 'environment_variables': :'environmentVariables', 'command_line_arguments': :'commandLineArguments', 'maximum_runtime_in_minutes': :'maximumRuntimeInMinutes' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
39 40 41 42 43 44 45 46 47 48 |
# File 'lib/oci/data_science/models/default_job_configuration_details.rb', line 39 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'job_type': :'String', 'environment_variables': :'Hash<String, String>', 'command_line_arguments': :'String', 'maximum_runtime_in_minutes': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
95 96 97 98 99 100 101 102 103 |
# File 'lib/oci/data_science/models/default_job_configuration_details.rb', line 95 def ==(other) return true if equal?(other) self.class == other.class && job_type == other.job_type && environment_variables == other.environment_variables && command_line_arguments == other.command_line_arguments && maximum_runtime_in_minutes == other.maximum_runtime_in_minutes end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/oci/data_science/models/default_job_configuration_details.rb', line 128 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
108 109 110 |
# File 'lib/oci/data_science/models/default_job_configuration_details.rb', line 108 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
117 118 119 |
# File 'lib/oci/data_science/models/default_job_configuration_details.rb', line 117 def hash [job_type, environment_variables, command_line_arguments, maximum_runtime_in_minutes].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
161 162 163 164 165 166 167 168 169 170 |
# File 'lib/oci/data_science/models/default_job_configuration_details.rb', line 161 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
155 156 157 |
# File 'lib/oci/data_science/models/default_job_configuration_details.rb', line 155 def to_s to_hash.to_s end |