Class: DataScience::Models::Job

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_science/models/job.rb

Overview

A job for training models.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Job

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/oci/data_science/models/job.rb', line 145

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.created_by = attributes[:'createdBy'] if attributes[:'createdBy']

  raise 'You cannot provide both :createdBy and :created_by' if attributes.key?(:'createdBy') && attributes.key?(:'created_by')

  self.created_by = attributes[:'created_by'] if attributes[:'created_by']

  self.project_id = attributes[:'projectId'] if attributes[:'projectId']

  raise 'You cannot provide both :projectId and :project_id' if attributes.key?(:'projectId') && attributes.key?(:'project_id')

  self.project_id = attributes[:'project_id'] if attributes[:'project_id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.job_configuration_details = attributes[:'jobConfigurationDetails'] if attributes[:'jobConfigurationDetails']

  raise 'You cannot provide both :jobConfigurationDetails and :job_configuration_details' if attributes.key?(:'jobConfigurationDetails') && attributes.key?(:'job_configuration_details')

  self.job_configuration_details = attributes[:'job_configuration_details'] if attributes[:'job_configuration_details']

  self.job_infrastructure_configuration_details = attributes[:'jobInfrastructureConfigurationDetails'] if attributes[:'jobInfrastructureConfigurationDetails']

  raise 'You cannot provide both :jobInfrastructureConfigurationDetails and :job_infrastructure_configuration_details' if attributes.key?(:'jobInfrastructureConfigurationDetails') && attributes.key?(:'job_infrastructure_configuration_details')

  self.job_infrastructure_configuration_details = attributes[:'job_infrastructure_configuration_details'] if attributes[:'job_infrastructure_configuration_details']

  self.job_log_configuration_details = attributes[:'jobLogConfigurationDetails'] if attributes[:'jobLogConfigurationDetails']

  raise 'You cannot provide both :jobLogConfigurationDetails and :job_log_configuration_details' if attributes.key?(:'jobLogConfigurationDetails') && attributes.key?(:'job_log_configuration_details')

  self.job_log_configuration_details = attributes[:'job_log_configuration_details'] if attributes[:'job_log_configuration_details']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#compartment_idString

**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment where you want to create the job.

Returns:

  • (String)


40
41
42
# File 'lib/oci/data_science/models/job.rb', line 40

def compartment_id
  @compartment_id
end

#created_byString

**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the user who created the job.

Returns:

  • (String)


32
33
34
# File 'lib/oci/data_science/models/job.rb', line 32

def created_by
  @created_by
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


79
80
81
# File 'lib/oci/data_science/models/job.rb', line 79

def defined_tags
  @defined_tags
end

#descriptionString

A short description of the job.

Returns:

  • (String)


48
49
50
# File 'lib/oci/data_science/models/job.rb', line 48

def description
  @description
end

#display_nameString

A user-friendly display name for the resource.

Returns:

  • (String)


44
45
46
# File 'lib/oci/data_science/models/job.rb', line 44

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `"Finance"`

Returns:

  • (Hash<String, String>)


73
74
75
# File 'lib/oci/data_science/models/job.rb', line 73

def freeform_tags
  @freeform_tags
end

#idString

Returns:

  • (String)


22
23
24
# File 'lib/oci/data_science/models/job.rb', line 22

def id
  @id
end

#job_configuration_detailsOCI::DataScience::Models::JobConfigurationDetails

This attribute is required.



52
53
54
# File 'lib/oci/data_science/models/job.rb', line 52

def job_configuration_details
  @job_configuration_details
end

#job_infrastructure_configuration_detailsOCI::DataScience::Models::JobInfrastructureConfigurationDetails

This attribute is required.



56
57
58
# File 'lib/oci/data_science/models/job.rb', line 56

def job_infrastructure_configuration_details
  @job_infrastructure_configuration_details
end

#job_log_configuration_detailsOCI::DataScience::Models::JobLogConfigurationDetails



59
60
61
# File 'lib/oci/data_science/models/job.rb', line 59

def job_log_configuration_details
  @job_log_configuration_details
end

#lifecycle_detailsString

The state of the job.

Returns:

  • (String)


67
68
69
# File 'lib/oci/data_science/models/job.rb', line 67

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

**[Required]** The state of the job.

Returns:

  • (String)


63
64
65
# File 'lib/oci/data_science/models/job.rb', line 63

def lifecycle_state
  @lifecycle_state
end

#project_idString

**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the project to associate the job with.

Returns:

  • (String)


36
37
38
# File 'lib/oci/data_science/models/job.rb', line 36

def project_id
  @project_id
end

#time_createdDateTime

**[Required]** The date and time the resource was created in the timestamp format defined by [RFC3339](tools.ietf.org/html/rfc3339). Example: 2020-08-06T21:10:29.41Z

Returns:

  • (DateTime)


28
29
30
# File 'lib/oci/data_science/models/job.rb', line 28

def time_created
  @time_created
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/oci/data_science/models/job.rb', line 82

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'time_created': :'timeCreated',
    'created_by': :'createdBy',
    'project_id': :'projectId',
    'compartment_id': :'compartmentId',
    'display_name': :'displayName',
    'description': :'description',
    'job_configuration_details': :'jobConfigurationDetails',
    'job_infrastructure_configuration_details': :'jobInfrastructureConfigurationDetails',
    'job_log_configuration_details': :'jobLogConfigurationDetails',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/oci/data_science/models/job.rb', line 104

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'time_created': :'DateTime',
    'created_by': :'String',
    'project_id': :'String',
    'compartment_id': :'String',
    'display_name': :'String',
    'description': :'String',
    'job_configuration_details': :'OCI::DataScience::Models::JobConfigurationDetails',
    'job_infrastructure_configuration_details': :'OCI::DataScience::Models::JobInfrastructureConfigurationDetails',
    'job_log_configuration_details': :'OCI::DataScience::Models::JobLogConfigurationDetails',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
# File 'lib/oci/data_science/models/job.rb', line 248

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    time_created == other.time_created &&
    created_by == other.created_by &&
    project_id == other.project_id &&
    compartment_id == other.compartment_id &&
    display_name == other.display_name &&
    description == other.description &&
    job_configuration_details == other.job_configuration_details &&
    job_infrastructure_configuration_details == other.job_infrastructure_configuration_details &&
    job_log_configuration_details == other.job_log_configuration_details &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
# File 'lib/oci/data_science/models/job.rb', line 291

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


271
272
273
# File 'lib/oci/data_science/models/job.rb', line 271

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



280
281
282
# File 'lib/oci/data_science/models/job.rb', line 280

def hash
  [id, time_created, created_by, project_id, compartment_id, display_name, description, job_configuration_details, job_infrastructure_configuration_details, job_log_configuration_details, lifecycle_state, lifecycle_details, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



324
325
326
327
328
329
330
331
332
333
# File 'lib/oci/data_science/models/job.rb', line 324

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



318
319
320
# File 'lib/oci/data_science/models/job.rb', line 318

def to_s
  to_hash.to_s
end