Class: OCI::DataScience::Models::JobLogConfigurationDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_science/models/job_log_configuration_details.rb

Overview

Logging configuration for resource.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ JobLogConfigurationDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :enable_logging (BOOLEAN)

    The value to assign to the #enable_logging property

  • :enable_auto_log_creation (BOOLEAN)

    The value to assign to the #enable_auto_log_creation property

  • :log_group_id (String)

    The value to assign to the #log_group_id property

  • :log_id (String)

    The value to assign to the #log_id property



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/oci/data_science/models/job_log_configuration_details.rb', line 64

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.enable_logging = attributes[:'enableLogging'] unless attributes[:'enableLogging'].nil?
  self.enable_logging = false if enable_logging.nil? && !attributes.key?(:'enableLogging') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :enableLogging and :enable_logging' if attributes.key?(:'enableLogging') && attributes.key?(:'enable_logging')

  self.enable_logging = attributes[:'enable_logging'] unless attributes[:'enable_logging'].nil?
  self.enable_logging = false if enable_logging.nil? && !attributes.key?(:'enableLogging') && !attributes.key?(:'enable_logging') # rubocop:disable Style/StringLiterals

  self.enable_auto_log_creation = attributes[:'enableAutoLogCreation'] unless attributes[:'enableAutoLogCreation'].nil?
  self.enable_auto_log_creation = false if enable_auto_log_creation.nil? && !attributes.key?(:'enableAutoLogCreation') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :enableAutoLogCreation and :enable_auto_log_creation' if attributes.key?(:'enableAutoLogCreation') && attributes.key?(:'enable_auto_log_creation')

  self.enable_auto_log_creation = attributes[:'enable_auto_log_creation'] unless attributes[:'enable_auto_log_creation'].nil?
  self.enable_auto_log_creation = false if enable_auto_log_creation.nil? && !attributes.key?(:'enableAutoLogCreation') && !attributes.key?(:'enable_auto_log_creation') # rubocop:disable Style/StringLiterals

  self.log_group_id = attributes[:'logGroupId'] if attributes[:'logGroupId']

  raise 'You cannot provide both :logGroupId and :log_group_id' if attributes.key?(:'logGroupId') && attributes.key?(:'log_group_id')

  self.log_group_id = attributes[:'log_group_id'] if attributes[:'log_group_id']

  self.log_id = attributes[:'logId'] if attributes[:'logId']

  raise 'You cannot provide both :logId and :log_id' if attributes.key?(:'logId') && attributes.key?(:'log_id')

  self.log_id = attributes[:'log_id'] if attributes[:'log_id']
end

Instance Attribute Details

#enable_auto_log_creationBOOLEAN

If automatic on-behalf-of log object creation is enabled for job runs.

Returns:

  • (BOOLEAN)


18
19
20
# File 'lib/oci/data_science/models/job_log_configuration_details.rb', line 18

def enable_auto_log_creation
  @enable_auto_log_creation
end

#enable_loggingBOOLEAN

If customer logging is enabled for job runs.

Returns:

  • (BOOLEAN)


13
14
15
# File 'lib/oci/data_science/models/job_log_configuration_details.rb', line 13

def enable_logging
  @enable_logging
end

#log_group_idString

The log group id for where log objects are for job runs.

Returns:

  • (String)


23
24
25
# File 'lib/oci/data_science/models/job_log_configuration_details.rb', line 23

def log_group_id
  @log_group_id
end

#log_idString

The log id the job run will push logs too.

Returns:

  • (String)


28
29
30
# File 'lib/oci/data_science/models/job_log_configuration_details.rb', line 28

def log_id
  @log_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
40
# File 'lib/oci/data_science/models/job_log_configuration_details.rb', line 31

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'enable_logging': :'enableLogging',
    'enable_auto_log_creation': :'enableAutoLogCreation',
    'log_group_id': :'logGroupId',
    'log_id': :'logId'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



43
44
45
46
47
48
49
50
51
52
# File 'lib/oci/data_science/models/job_log_configuration_details.rb', line 43

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'enable_logging': :'BOOLEAN',
    'enable_auto_log_creation': :'BOOLEAN',
    'log_group_id': :'String',
    'log_id': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



106
107
108
109
110
111
112
113
114
# File 'lib/oci/data_science/models/job_log_configuration_details.rb', line 106

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    enable_logging == other.enable_logging &&
    enable_auto_log_creation == other.enable_auto_log_creation &&
    log_group_id == other.log_group_id &&
    log_id == other.log_id
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/oci/data_science/models/job_log_configuration_details.rb', line 139

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


119
120
121
# File 'lib/oci/data_science/models/job_log_configuration_details.rb', line 119

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



128
129
130
# File 'lib/oci/data_science/models/job_log_configuration_details.rb', line 128

def hash
  [enable_logging, enable_auto_log_creation, log_group_id, log_id].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



172
173
174
175
176
177
178
179
180
181
# File 'lib/oci/data_science/models/job_log_configuration_details.rb', line 172

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



166
167
168
# File 'lib/oci/data_science/models/job_log_configuration_details.rb', line 166

def to_s
  to_hash.to_s
end