Class: OCI::DataScience::Models::Metadata
- Inherits:
-
Object
- Object
- OCI::DataScience::Models::Metadata
- Defined in:
- lib/oci/data_science/models/metadata.rb
Overview
Defines properties of each model metadata.
Instance Attribute Summary collapse
-
#category ⇒ String
Category of model metadata which should be null for defined metadata.For custom metadata is should be one of the following values "Performance,Training Profile,Training and Validation Datasets,Training Environment,other".
-
#description ⇒ String
Description of model metadata.
-
#key ⇒ String
Key of the model Metadata.
-
#value ⇒ String
Allowed values for useCaseType: binary_classification, regression, multinomial_classification, clustering, recommender, dimensionality_reduction/representation, time_series_forecasting, anomaly_detection, topic_modeling, ner, sentiment_analysis, image_classification, object_localization, other.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Metadata
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Metadata
Initializes the object
77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/oci/data_science/models/metadata.rb', line 77 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.key = attributes[:'key'] if attributes[:'key'] self.value = attributes[:'value'] if attributes[:'value'] self.description = attributes[:'description'] if attributes[:'description'] self.category = attributes[:'category'] if attributes[:'category'] end |
Instance Attribute Details
#category ⇒ String
Category of model metadata which should be null for defined metadata.For custom metadata is should be one of the following values "Performance,Training Profile,Training and Validation Datasets,Training Environment,other".
41 42 43 |
# File 'lib/oci/data_science/models/metadata.rb', line 41 def category @category end |
#description ⇒ String
Description of model metadata
37 38 39 |
# File 'lib/oci/data_science/models/metadata.rb', line 37 def description @description end |
#key ⇒ String
Key of the model Metadata. The key can either be user defined or OCI defined.
List of OCI defined keys:
* useCaseType
* libraryName
* libraryVersion
* estimatorClass
* hyperParameters
* testartifactresults
20 21 22 |
# File 'lib/oci/data_science/models/metadata.rb', line 20 def key @key end |
#value ⇒ String
Allowed values for useCaseType:
binary_classification, regression, multinomial_classification, clustering, recommender,
dimensionality_reduction/representation, time_series_forecasting, anomaly_detection,
topic_modeling, ner, sentiment_analysis, image_classification, object_localization, other
Allowed values for libraryName:
scikit-learn, xgboost, tensorflow, pytorch, mxnet, keras, lightGBM, pymc3, pyOD, spacy,
prophet, sktime, statsmodels, cuml, oracle_automl, h2o, transformers, nltk, emcee, pystan,
bert, gensim, flair, word2vec, ensemble, other
33 34 35 |
# File 'lib/oci/data_science/models/metadata.rb', line 33 def value @value end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
44 45 46 47 48 49 50 51 52 53 |
# File 'lib/oci/data_science/models/metadata.rb', line 44 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'key': :'key', 'value': :'value', 'description': :'description', 'category': :'category' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
56 57 58 59 60 61 62 63 64 65 |
# File 'lib/oci/data_science/models/metadata.rb', line 56 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'key': :'String', 'value': :'String', 'description': :'String', 'category': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
99 100 101 102 103 104 105 106 107 |
# File 'lib/oci/data_science/models/metadata.rb', line 99 def ==(other) return true if equal?(other) self.class == other.class && key == other.key && value == other.value && description == other.description && category == other.category end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/oci/data_science/models/metadata.rb', line 132 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
112 113 114 |
# File 'lib/oci/data_science/models/metadata.rb', line 112 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
121 122 123 |
# File 'lib/oci/data_science/models/metadata.rb', line 121 def hash [key, value, description, category].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
165 166 167 168 169 170 171 172 173 174 |
# File 'lib/oci/data_science/models/metadata.rb', line 165 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
159 160 161 |
# File 'lib/oci/data_science/models/metadata.rb', line 159 def to_s to_hash.to_s end |