Class: OCI::DataScience::Models::NotebookSession

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_science/models/notebook_session.rb

Overview

Notebook sessions are interactive coding environments for data scientists.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ NotebookSession

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/oci/data_science/models/notebook_session.rb', line 142

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.project_id = attributes[:'projectId'] if attributes[:'projectId']

  raise 'You cannot provide both :projectId and :project_id' if attributes.key?(:'projectId') && attributes.key?(:'project_id')

  self.project_id = attributes[:'project_id'] if attributes[:'project_id']

  self.created_by = attributes[:'createdBy'] if attributes[:'createdBy']

  raise 'You cannot provide both :createdBy and :created_by' if attributes.key?(:'createdBy') && attributes.key?(:'created_by')

  self.created_by = attributes[:'created_by'] if attributes[:'created_by']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.notebook_session_configuration_details = attributes[:'notebookSessionConfigurationDetails'] if attributes[:'notebookSessionConfigurationDetails']

  raise 'You cannot provide both :notebookSessionConfigurationDetails and :notebook_session_configuration_details' if attributes.key?(:'notebookSessionConfigurationDetails') && attributes.key?(:'notebook_session_configuration_details')

  self.notebook_session_configuration_details = attributes[:'notebook_session_configuration_details'] if attributes[:'notebook_session_configuration_details']

  self.notebook_session_config_details = attributes[:'notebookSessionConfigDetails'] if attributes[:'notebookSessionConfigDetails']

  raise 'You cannot provide both :notebookSessionConfigDetails and :notebook_session_config_details' if attributes.key?(:'notebookSessionConfigDetails') && attributes.key?(:'notebook_session_config_details')

  self.notebook_session_config_details = attributes[:'notebook_session_config_details'] if attributes[:'notebook_session_config_details']

  self.notebook_session_url = attributes[:'notebookSessionUrl'] if attributes[:'notebookSessionUrl']

  raise 'You cannot provide both :notebookSessionUrl and :notebook_session_url' if attributes.key?(:'notebookSessionUrl') && attributes.key?(:'notebook_session_url')

  self.notebook_session_url = attributes[:'notebook_session_url'] if attributes[:'notebook_session_url']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#compartment_idString

**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the notebook session's compartment.

Returns:

  • (String)


49
50
51
# File 'lib/oci/data_science/models/notebook_session.rb', line 49

def compartment_id
  @compartment_id
end

#created_byString

**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the user who created the notebook session.

Returns:

  • (String)


45
46
47
# File 'lib/oci/data_science/models/notebook_session.rb', line 45

def created_by
  @created_by
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


79
80
81
# File 'lib/oci/data_science/models/notebook_session.rb', line 79

def defined_tags
  @defined_tags
end

#display_nameString

**[Required]** A user-friendly display name for the resource. It does not have to be unique and can be modified. Avoid entering confidential information. Example: `My NotebookSession`

Returns:

  • (String)


37
38
39
# File 'lib/oci/data_science/models/notebook_session.rb', line 37

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `"Finance"`

Returns:

  • (Hash<String, String>)


73
74
75
# File 'lib/oci/data_science/models/notebook_session.rb', line 73

def freeform_tags
  @freeform_tags
end

#idString

**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the notebook session.

Returns:

  • (String)


25
26
27
# File 'lib/oci/data_science/models/notebook_session.rb', line 25

def id
  @id
end

#lifecycle_detailsString

Details about the state of the notebook session.

Returns:

  • (String)


67
68
69
# File 'lib/oci/data_science/models/notebook_session.rb', line 67

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

**[Required]** The state of the notebook session.

Returns:

  • (String)


63
64
65
# File 'lib/oci/data_science/models/notebook_session.rb', line 63

def lifecycle_state
  @lifecycle_state
end

#notebook_session_config_detailsOCI::DataScience::Models::NotebookSessionConfigDetails



55
56
57
# File 'lib/oci/data_science/models/notebook_session.rb', line 55

def notebook_session_config_details
  @notebook_session_config_details
end

#notebook_session_configuration_detailsOCI::DataScience::Models::NotebookSessionConfigurationDetails



52
53
54
# File 'lib/oci/data_science/models/notebook_session.rb', line 52

def notebook_session_configuration_details
  @notebook_session_configuration_details
end

#notebook_session_urlString

The URL to interact with the notebook session.

Returns:

  • (String)


59
60
61
# File 'lib/oci/data_science/models/notebook_session.rb', line 59

def notebook_session_url
  @notebook_session_url
end

#project_idString

**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the project associated with the notebook session.

Returns:

  • (String)


41
42
43
# File 'lib/oci/data_science/models/notebook_session.rb', line 41

def project_id
  @project_id
end

#time_createdDateTime

**[Required]** The date and time the resource was created in the timestamp format defined by [RFC3339](tools.ietf.org/html/rfc3339). Example: 2019-08-25T21:10:29.41Z

Returns:

  • (DateTime)


31
32
33
# File 'lib/oci/data_science/models/notebook_session.rb', line 31

def time_created
  @time_created
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/oci/data_science/models/notebook_session.rb', line 82

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'time_created': :'timeCreated',
    'display_name': :'displayName',
    'project_id': :'projectId',
    'created_by': :'createdBy',
    'compartment_id': :'compartmentId',
    'notebook_session_configuration_details': :'notebookSessionConfigurationDetails',
    'notebook_session_config_details': :'notebookSessionConfigDetails',
    'notebook_session_url': :'notebookSessionUrl',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/oci/data_science/models/notebook_session.rb', line 103

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'time_created': :'DateTime',
    'display_name': :'String',
    'project_id': :'String',
    'created_by': :'String',
    'compartment_id': :'String',
    'notebook_session_configuration_details': :'OCI::DataScience::Models::NotebookSessionConfigurationDetails',
    'notebook_session_config_details': :'OCI::DataScience::Models::NotebookSessionConfigDetails',
    'notebook_session_url': :'String',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/oci/data_science/models/notebook_session.rb', line 243

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    time_created == other.time_created &&
    display_name == other.display_name &&
    project_id == other.project_id &&
    created_by == other.created_by &&
    compartment_id == other.compartment_id &&
    notebook_session_configuration_details == other.notebook_session_configuration_details &&
    notebook_session_config_details == other.notebook_session_config_details &&
    notebook_session_url == other.notebook_session_url &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
# File 'lib/oci/data_science/models/notebook_session.rb', line 285

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


265
266
267
# File 'lib/oci/data_science/models/notebook_session.rb', line 265

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



274
275
276
# File 'lib/oci/data_science/models/notebook_session.rb', line 274

def hash
  [id, time_created, display_name, project_id, created_by, compartment_id, notebook_session_configuration_details, notebook_session_config_details, notebook_session_url, lifecycle_state, lifecycle_details, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



318
319
320
321
322
323
324
325
326
327
# File 'lib/oci/data_science/models/notebook_session.rb', line 318

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



312
313
314
# File 'lib/oci/data_science/models/notebook_session.rb', line 312

def to_s
  to_hash.to_s
end