Class: OCI::DataScience::Models::NotebookSessionSummary
- Inherits:
-
Object
- Object
- OCI::DataScience::Models::NotebookSessionSummary
- Defined in:
- lib/oci/data_science/models/notebook_session_summary.rb
Overview
Summary information for a notebook session.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the notebook session's compartment.
-
#created_by ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the user who created the notebook session.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
**[Required]** A user-friendly display name for the resource.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the notebook session.
-
#lifecycle_state ⇒ String
**[Required]** The state of the notebook session.
- #notebook_session_config_details ⇒ OCI::DataScience::Models::NotebookSessionConfigDetails
- #notebook_session_configuration_details ⇒ OCI::DataScience::Models::NotebookSessionConfigurationDetails
-
#notebook_session_url ⇒ String
The URL to interact with the notebook session.
-
#project_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the project associated with the notebook session.
-
#time_created ⇒ DateTime
**[Required]** The date and time the resource was created in the timestamp format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NotebookSessionSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ NotebookSessionSummary
Initializes the object
134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/oci/data_science/models/notebook_session_summary.rb', line 134 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.project_id = attributes[:'projectId'] if attributes[:'projectId'] raise 'You cannot provide both :projectId and :project_id' if attributes.key?(:'projectId') && attributes.key?(:'project_id') self.project_id = attributes[:'project_id'] if attributes[:'project_id'] self.created_by = attributes[:'createdBy'] if attributes[:'createdBy'] raise 'You cannot provide both :createdBy and :created_by' if attributes.key?(:'createdBy') && attributes.key?(:'created_by') self.created_by = attributes[:'created_by'] if attributes[:'created_by'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.notebook_session_configuration_details = attributes[:'notebookSessionConfigurationDetails'] if attributes[:'notebookSessionConfigurationDetails'] raise 'You cannot provide both :notebookSessionConfigurationDetails and :notebook_session_configuration_details' if attributes.key?(:'notebookSessionConfigurationDetails') && attributes.key?(:'notebook_session_configuration_details') self.notebook_session_configuration_details = attributes[:'notebook_session_configuration_details'] if attributes[:'notebook_session_configuration_details'] self.notebook_session_config_details = attributes[:'notebookSessionConfigDetails'] if attributes[:'notebookSessionConfigDetails'] raise 'You cannot provide both :notebookSessionConfigDetails and :notebook_session_config_details' if attributes.key?(:'notebookSessionConfigDetails') && attributes.key?(:'notebook_session_config_details') self.notebook_session_config_details = attributes[:'notebook_session_config_details'] if attributes[:'notebook_session_config_details'] self.notebook_session_url = attributes[:'notebookSessionUrl'] if attributes[:'notebookSessionUrl'] raise 'You cannot provide both :notebookSessionUrl and :notebook_session_url' if attributes.key?(:'notebookSessionUrl') && attributes.key?(:'notebook_session_url') self.notebook_session_url = attributes[:'notebook_session_url'] if attributes[:'notebook_session_url'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the notebook session's compartment.
48 49 50 |
# File 'lib/oci/data_science/models/notebook_session_summary.rb', line 48 def compartment_id @compartment_id end |
#created_by ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the user who created the notebook session.
44 45 46 |
# File 'lib/oci/data_science/models/notebook_session_summary.rb', line 44 def created_by @created_by end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `{"CostCenter": "42"}`
74 75 76 |
# File 'lib/oci/data_science/models/notebook_session_summary.rb', line 74 def @defined_tags end |
#display_name ⇒ String
**[Required]** A user-friendly display name for the resource. It does not have to be unique and can be modified. Avoid entering confidential information. Example: `My NotebookSession`
36 37 38 |
# File 'lib/oci/data_science/models/notebook_session_summary.rb', line 36 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `"Finance"`
68 69 70 |
# File 'lib/oci/data_science/models/notebook_session_summary.rb', line 68 def @freeform_tags end |
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the notebook session.
24 25 26 |
# File 'lib/oci/data_science/models/notebook_session_summary.rb', line 24 def id @id end |
#lifecycle_state ⇒ String
**[Required]** The state of the notebook session.
62 63 64 |
# File 'lib/oci/data_science/models/notebook_session_summary.rb', line 62 def lifecycle_state @lifecycle_state end |
#notebook_session_config_details ⇒ OCI::DataScience::Models::NotebookSessionConfigDetails
54 55 56 |
# File 'lib/oci/data_science/models/notebook_session_summary.rb', line 54 def notebook_session_config_details @notebook_session_config_details end |
#notebook_session_configuration_details ⇒ OCI::DataScience::Models::NotebookSessionConfigurationDetails
51 52 53 |
# File 'lib/oci/data_science/models/notebook_session_summary.rb', line 51 def notebook_session_configuration_details @notebook_session_configuration_details end |
#notebook_session_url ⇒ String
The URL to interact with the notebook session.
58 59 60 |
# File 'lib/oci/data_science/models/notebook_session_summary.rb', line 58 def notebook_session_url @notebook_session_url end |
#project_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the project associated with the notebook session.
40 41 42 |
# File 'lib/oci/data_science/models/notebook_session_summary.rb', line 40 def project_id @project_id end |
#time_created ⇒ DateTime
**[Required]** The date and time the resource was created in the timestamp format defined by [RFC3339](tools.ietf.org/html/rfc3339). Example: 2019-08-25T21:10:29.41Z
30 31 32 |
# File 'lib/oci/data_science/models/notebook_session_summary.rb', line 30 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/oci/data_science/models/notebook_session_summary.rb', line 77 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'time_created': :'timeCreated', 'display_name': :'displayName', 'project_id': :'projectId', 'created_by': :'createdBy', 'compartment_id': :'compartmentId', 'notebook_session_configuration_details': :'notebookSessionConfigurationDetails', 'notebook_session_config_details': :'notebookSessionConfigDetails', 'notebook_session_url': :'notebookSessionUrl', 'lifecycle_state': :'lifecycleState', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/oci/data_science/models/notebook_session_summary.rb', line 97 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'time_created': :'DateTime', 'display_name': :'String', 'project_id': :'String', 'created_by': :'String', 'compartment_id': :'String', 'notebook_session_configuration_details': :'OCI::DataScience::Models::NotebookSessionConfigurationDetails', 'notebook_session_config_details': :'OCI::DataScience::Models::NotebookSessionConfigDetails', 'notebook_session_url': :'String', 'lifecycle_state': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/oci/data_science/models/notebook_session_summary.rb', line 229 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && time_created == other.time_created && display_name == other.display_name && project_id == other.project_id && created_by == other.created_by && compartment_id == other.compartment_id && notebook_session_configuration_details == other.notebook_session_configuration_details && notebook_session_config_details == other.notebook_session_config_details && notebook_session_url == other.notebook_session_url && lifecycle_state == other.lifecycle_state && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 |
# File 'lib/oci/data_science/models/notebook_session_summary.rb', line 270 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
250 251 252 |
# File 'lib/oci/data_science/models/notebook_session_summary.rb', line 250 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
259 260 261 |
# File 'lib/oci/data_science/models/notebook_session_summary.rb', line 259 def hash [id, time_created, display_name, project_id, created_by, compartment_id, notebook_session_configuration_details, notebook_session_config_details, notebook_session_url, lifecycle_state, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
303 304 305 306 307 308 309 310 311 312 |
# File 'lib/oci/data_science/models/notebook_session_summary.rb', line 303 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
297 298 299 |
# File 'lib/oci/data_science/models/notebook_session_summary.rb', line 297 def to_s to_hash.to_s end |