Class: OCI::DataScience::Models::StandaloneJobInfrastructureConfigurationDetails
- Inherits:
-
JobInfrastructureConfigurationDetails
- Object
- JobInfrastructureConfigurationDetails
- OCI::DataScience::Models::StandaloneJobInfrastructureConfigurationDetails
- Defined in:
- lib/oci/data_science/models/standalone_job_infrastructure_configuration_details.rb
Overview
The standalone job infrastructure configuration.
Constant Summary
Constants inherited from JobInfrastructureConfigurationDetails
JobInfrastructureConfigurationDetails::JOB_INFRASTRUCTURE_TYPE_ENUM
Instance Attribute Summary collapse
-
#block_storage_size_in_gbs ⇒ Integer
[Required] The size of the block storage volume to attach to the instance running the job.
-
#shape_name ⇒ String
[Required] The shape used to launch the job run instances.
-
#subnet_id ⇒ String
[Required] The subnet to create a secondary vnic in to attach to the instance running the job.
Attributes inherited from JobInfrastructureConfigurationDetails
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ StandaloneJobInfrastructureConfigurationDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from JobInfrastructureConfigurationDetails
Constructor Details
#initialize(attributes = {}) ⇒ StandaloneJobInfrastructureConfigurationDetails
Initializes the object
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/oci/data_science/models/standalone_job_infrastructure_configuration_details.rb', line 58 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['jobInfrastructureType'] = 'STANDALONE' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.shape_name = attributes[:'shapeName'] if attributes[:'shapeName'] raise 'You cannot provide both :shapeName and :shape_name' if attributes.key?(:'shapeName') && attributes.key?(:'shape_name') self.shape_name = attributes[:'shape_name'] if attributes[:'shape_name'] self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId'] raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id') self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id'] self.block_storage_size_in_gbs = attributes[:'blockStorageSizeInGBs'] if attributes[:'blockStorageSizeInGBs'] raise 'You cannot provide both :blockStorageSizeInGBs and :block_storage_size_in_gbs' if attributes.key?(:'blockStorageSizeInGBs') && attributes.key?(:'block_storage_size_in_gbs') self.block_storage_size_in_gbs = attributes[:'block_storage_size_in_gbs'] if attributes[:'block_storage_size_in_gbs'] end |
Instance Attribute Details
#block_storage_size_in_gbs ⇒ Integer
[Required] The size of the block storage volume to attach to the instance running the job
23 24 25 |
# File 'lib/oci/data_science/models/standalone_job_infrastructure_configuration_details.rb', line 23 def block_storage_size_in_gbs @block_storage_size_in_gbs end |
#shape_name ⇒ String
[Required] The shape used to launch the job run instances.
13 14 15 |
# File 'lib/oci/data_science/models/standalone_job_infrastructure_configuration_details.rb', line 13 def shape_name @shape_name end |
#subnet_id ⇒ String
[Required] The subnet to create a secondary vnic in to attach to the instance running the job
18 19 20 |
# File 'lib/oci/data_science/models/standalone_job_infrastructure_configuration_details.rb', line 18 def subnet_id @subnet_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
26 27 28 29 30 31 32 33 34 35 |
# File 'lib/oci/data_science/models/standalone_job_infrastructure_configuration_details.rb', line 26 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'job_infrastructure_type': :'jobInfrastructureType', 'shape_name': :'shapeName', 'subnet_id': :'subnetId', 'block_storage_size_in_gbs': :'blockStorageSizeInGBs' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
38 39 40 41 42 43 44 45 46 47 |
# File 'lib/oci/data_science/models/standalone_job_infrastructure_configuration_details.rb', line 38 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'job_infrastructure_type': :'String', 'shape_name': :'String', 'subnet_id': :'String', 'block_storage_size_in_gbs': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
94 95 96 97 98 99 100 101 102 |
# File 'lib/oci/data_science/models/standalone_job_infrastructure_configuration_details.rb', line 94 def ==(other) return true if equal?(other) self.class == other.class && job_infrastructure_type == other.job_infrastructure_type && shape_name == other.shape_name && subnet_id == other.subnet_id && block_storage_size_in_gbs == other.block_storage_size_in_gbs end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/oci/data_science/models/standalone_job_infrastructure_configuration_details.rb', line 127 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
107 108 109 |
# File 'lib/oci/data_science/models/standalone_job_infrastructure_configuration_details.rb', line 107 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
116 117 118 |
# File 'lib/oci/data_science/models/standalone_job_infrastructure_configuration_details.rb', line 116 def hash [job_infrastructure_type, shape_name, subnet_id, block_storage_size_in_gbs].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
160 161 162 163 164 165 166 167 168 169 |
# File 'lib/oci/data_science/models/standalone_job_infrastructure_configuration_details.rb', line 160 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
154 155 156 |
# File 'lib/oci/data_science/models/standalone_job_infrastructure_configuration_details.rb', line 154 def to_s to_hash.to_s end |