Class: OCI::DataScience::Models::UpdateModelConfigurationDetails
- Inherits:
-
Object
- Object
- OCI::DataScience::Models::UpdateModelConfigurationDetails
- Defined in:
- lib/oci/data_science/models/update_model_configuration_details.rb
Overview
The model configuration details for update.
Instance Attribute Summary collapse
-
#bandwidth_mbps ⇒ Integer
The network bandwidth for the model.
- #instance_configuration ⇒ OCI::DataScience::Models::InstanceConfiguration
-
#model_id ⇒ String
[Required] The OCID of the model you want to update.
- #scaling_policy ⇒ OCI::DataScience::Models::ScalingPolicy
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateModelConfigurationDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateModelConfigurationDetails
Initializes the object
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/oci/data_science/models/update_model_configuration_details.rb', line 58 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.model_id = attributes[:'modelId'] if attributes[:'modelId'] raise 'You cannot provide both :modelId and :model_id' if attributes.key?(:'modelId') && attributes.key?(:'model_id') self.model_id = attributes[:'model_id'] if attributes[:'model_id'] self.instance_configuration = attributes[:'instanceConfiguration'] if attributes[:'instanceConfiguration'] raise 'You cannot provide both :instanceConfiguration and :instance_configuration' if attributes.key?(:'instanceConfiguration') && attributes.key?(:'instance_configuration') self.instance_configuration = attributes[:'instance_configuration'] if attributes[:'instance_configuration'] self.scaling_policy = attributes[:'scalingPolicy'] if attributes[:'scalingPolicy'] raise 'You cannot provide both :scalingPolicy and :scaling_policy' if attributes.key?(:'scalingPolicy') && attributes.key?(:'scaling_policy') self.scaling_policy = attributes[:'scaling_policy'] if attributes[:'scaling_policy'] self.bandwidth_mbps = attributes[:'bandwidthMbps'] if attributes[:'bandwidthMbps'] raise 'You cannot provide both :bandwidthMbps and :bandwidth_mbps' if attributes.key?(:'bandwidthMbps') && attributes.key?(:'bandwidth_mbps') self.bandwidth_mbps = attributes[:'bandwidth_mbps'] if attributes[:'bandwidth_mbps'] end |
Instance Attribute Details
#bandwidth_mbps ⇒ Integer
The network bandwidth for the model.
22 23 24 |
# File 'lib/oci/data_science/models/update_model_configuration_details.rb', line 22 def bandwidth_mbps @bandwidth_mbps end |
#instance_configuration ⇒ OCI::DataScience::Models::InstanceConfiguration
15 16 17 |
# File 'lib/oci/data_science/models/update_model_configuration_details.rb', line 15 def instance_configuration @instance_configuration end |
#model_id ⇒ String
[Required] The OCID of the model you want to update.
12 13 14 |
# File 'lib/oci/data_science/models/update_model_configuration_details.rb', line 12 def model_id @model_id end |
#scaling_policy ⇒ OCI::DataScience::Models::ScalingPolicy
18 19 20 |
# File 'lib/oci/data_science/models/update_model_configuration_details.rb', line 18 def scaling_policy @scaling_policy end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
25 26 27 28 29 30 31 32 33 34 |
# File 'lib/oci/data_science/models/update_model_configuration_details.rb', line 25 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_id': :'modelId', 'instance_configuration': :'instanceConfiguration', 'scaling_policy': :'scalingPolicy', 'bandwidth_mbps': :'bandwidthMbps' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/oci/data_science/models/update_model_configuration_details.rb', line 37 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_id': :'String', 'instance_configuration': :'OCI::DataScience::Models::InstanceConfiguration', 'scaling_policy': :'OCI::DataScience::Models::ScalingPolicy', 'bandwidth_mbps': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
96 97 98 99 100 101 102 103 104 |
# File 'lib/oci/data_science/models/update_model_configuration_details.rb', line 96 def ==(other) return true if equal?(other) self.class == other.class && model_id == other.model_id && instance_configuration == other.instance_configuration && scaling_policy == other.scaling_policy && bandwidth_mbps == other.bandwidth_mbps end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/oci/data_science/models/update_model_configuration_details.rb', line 129 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
109 110 111 |
# File 'lib/oci/data_science/models/update_model_configuration_details.rb', line 109 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
118 119 120 |
# File 'lib/oci/data_science/models/update_model_configuration_details.rb', line 118 def hash [model_id, instance_configuration, scaling_policy, bandwidth_mbps].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
162 163 164 165 166 167 168 169 170 171 |
# File 'lib/oci/data_science/models/update_model_configuration_details.rb', line 162 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
156 157 158 |
# File 'lib/oci/data_science/models/update_model_configuration_details.rb', line 156 def to_s to_hash.to_s end |