Class: OCI::DataScience::Models::UpdateModelDetails
- Inherits:
-
Object
- Object
- OCI::DataScience::Models::UpdateModelDetails
- Defined in:
- lib/oci/data_science/models/update_model_details.rb
Overview
Details for updating a model.
Instance Attribute Summary collapse
-
#custom_metadata_list ⇒ Array<OCI::DataScience::Models::Metadata>
An array of custom metadata details for the model.
-
#defined_metadata_list ⇒ Array<OCI::DataScience::Models::Metadata>
An array of defined metadata details for the model.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
A short description of the model.
-
#display_name ⇒ String
A user-friendly display name for the resource.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateModelDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateModelDetails
Initializes the object
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/oci/data_science/models/update_model_details.rb', line 81 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'customMetadataList'] if attributes[:'customMetadataList'] raise 'You cannot provide both :customMetadataList and :custom_metadata_list' if attributes.key?(:'customMetadataList') && attributes.key?(:'custom_metadata_list') self. = attributes[:'custom_metadata_list'] if attributes[:'custom_metadata_list'] self. = attributes[:'definedMetadataList'] if attributes[:'definedMetadataList'] raise 'You cannot provide both :definedMetadataList and :defined_metadata_list' if attributes.key?(:'definedMetadataList') && attributes.key?(:'defined_metadata_list') self. = attributes[:'defined_metadata_list'] if attributes[:'defined_metadata_list'] end |
Instance Attribute Details
#custom_metadata_list ⇒ Array<OCI::DataScience::Models::Metadata>
An array of custom metadata details for the model.
35 36 37 |
# File 'lib/oci/data_science/models/update_model_details.rb', line 35 def end |
#defined_metadata_list ⇒ Array<OCI::DataScience::Models::Metadata>
An array of defined metadata details for the model.
39 40 41 |
# File 'lib/oci/data_science/models/update_model_details.rb', line 39 def end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"CostCenter": "42"}`
31 32 33 |
# File 'lib/oci/data_science/models/update_model_details.rb', line 31 def end |
#description ⇒ String
A short description of the model.
19 20 21 |
# File 'lib/oci/data_science/models/update_model_details.rb', line 19 def description @description end |
#display_name ⇒ String
A user-friendly display name for the resource. It does not have to be unique and can be modified. Avoid entering confidential information.
Example: `My Model`
15 16 17 |
# File 'lib/oci/data_science/models/update_model_details.rb', line 15 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"Finance"`
25 26 27 |
# File 'lib/oci/data_science/models/update_model_details.rb', line 25 def end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/oci/data_science/models/update_model_details.rb', line 42 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'description': :'description', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'custom_metadata_list': :'customMetadataList', 'defined_metadata_list': :'definedMetadataList' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/oci/data_science/models/update_model_details.rb', line 56 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'description': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'custom_metadata_list': :'Array<OCI::DataScience::Models::Metadata>', 'defined_metadata_list': :'Array<OCI::DataScience::Models::Metadata>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/oci/data_science/models/update_model_details.rb', line 127 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && description == other.description && == other. && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/oci/data_science/models/update_model_details.rb', line 162 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
142 143 144 |
# File 'lib/oci/data_science/models/update_model_details.rb', line 142 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
151 152 153 |
# File 'lib/oci/data_science/models/update_model_details.rb', line 151 def hash [display_name, description, , , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
195 196 197 198 199 200 201 202 203 204 |
# File 'lib/oci/data_science/models/update_model_details.rb', line 195 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
189 190 191 |
# File 'lib/oci/data_science/models/update_model_details.rb', line 189 def to_s to_hash.to_s end |