Class: OCI::Database::Models::AutonomousContainerDatabaseDataguardAssociation

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database/models/autonomous_container_database_dataguard_association.rb

Overview

The properties that define Autonomous Data Guard association between two different Autonomous Container Databases.

Constant Summary collapse

ROLE_ENUM =
[
  ROLE_PRIMARY = 'PRIMARY'.freeze,
  ROLE_STANDBY = 'STANDBY'.freeze,
  ROLE_DISABLED_STANDBY = 'DISABLED_STANDBY'.freeze,
  ROLE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze,
  LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze,
  LIFECYCLE_STATE_ROLE_CHANGE_IN_PROGRESS = 'ROLE_CHANGE_IN_PROGRESS'.freeze,
  LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze,
  LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNAVAILABLE = 'UNAVAILABLE'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
PEER_ROLE_ENUM =
[
  PEER_ROLE_PRIMARY = 'PRIMARY'.freeze,
  PEER_ROLE_STANDBY = 'STANDBY'.freeze,
  PEER_ROLE_DISABLED_STANDBY = 'DISABLED_STANDBY'.freeze,
  PEER_ROLE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
PEER_LIFECYCLE_STATE_ENUM =
[
  PEER_LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze,
  PEER_LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze,
  PEER_LIFECYCLE_STATE_ROLE_CHANGE_IN_PROGRESS = 'ROLE_CHANGE_IN_PROGRESS'.freeze,
  PEER_LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze,
  PEER_LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze,
  PEER_LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  PEER_LIFECYCLE_STATE_UNAVAILABLE = 'UNAVAILABLE'.freeze,
  PEER_LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
PROTECTION_MODE_ENUM =
[
  PROTECTION_MODE_MAXIMUM_AVAILABILITY = 'MAXIMUM_AVAILABILITY'.freeze,
  PROTECTION_MODE_MAXIMUM_PERFORMANCE = 'MAXIMUM_PERFORMANCE'.freeze,
  PROTECTION_MODE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ AutonomousContainerDatabaseDataguardAssociation

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/oci/database/models/autonomous_container_database_dataguard_association.rb', line 215

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.autonomous_container_database_id = attributes[:'autonomousContainerDatabaseId'] if attributes[:'autonomousContainerDatabaseId']

  raise 'You cannot provide both :autonomousContainerDatabaseId and :autonomous_container_database_id' if attributes.key?(:'autonomousContainerDatabaseId') && attributes.key?(:'autonomous_container_database_id')

  self.autonomous_container_database_id = attributes[:'autonomous_container_database_id'] if attributes[:'autonomous_container_database_id']

  self.role = attributes[:'role'] if attributes[:'role']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.peer_autonomous_container_database_dataguard_association_id = attributes[:'peerAutonomousContainerDatabaseDataguardAssociationId'] if attributes[:'peerAutonomousContainerDatabaseDataguardAssociationId']

  raise 'You cannot provide both :peerAutonomousContainerDatabaseDataguardAssociationId and :peer_autonomous_container_database_dataguard_association_id' if attributes.key?(:'peerAutonomousContainerDatabaseDataguardAssociationId') && attributes.key?(:'peer_autonomous_container_database_dataguard_association_id')

  self.peer_autonomous_container_database_dataguard_association_id = attributes[:'peer_autonomous_container_database_dataguard_association_id'] if attributes[:'peer_autonomous_container_database_dataguard_association_id']

  self.peer_autonomous_container_database_id = attributes[:'peerAutonomousContainerDatabaseId'] if attributes[:'peerAutonomousContainerDatabaseId']

  raise 'You cannot provide both :peerAutonomousContainerDatabaseId and :peer_autonomous_container_database_id' if attributes.key?(:'peerAutonomousContainerDatabaseId') && attributes.key?(:'peer_autonomous_container_database_id')

  self.peer_autonomous_container_database_id = attributes[:'peer_autonomous_container_database_id'] if attributes[:'peer_autonomous_container_database_id']

  self.peer_role = attributes[:'peerRole'] if attributes[:'peerRole']

  raise 'You cannot provide both :peerRole and :peer_role' if attributes.key?(:'peerRole') && attributes.key?(:'peer_role')

  self.peer_role = attributes[:'peer_role'] if attributes[:'peer_role']

  self.peer_lifecycle_state = attributes[:'peerLifecycleState'] if attributes[:'peerLifecycleState']

  raise 'You cannot provide both :peerLifecycleState and :peer_lifecycle_state' if attributes.key?(:'peerLifecycleState') && attributes.key?(:'peer_lifecycle_state')

  self.peer_lifecycle_state = attributes[:'peer_lifecycle_state'] if attributes[:'peer_lifecycle_state']

  self.protection_mode = attributes[:'protectionMode'] if attributes[:'protectionMode']

  raise 'You cannot provide both :protectionMode and :protection_mode' if attributes.key?(:'protectionMode') && attributes.key?(:'protection_mode')

  self.protection_mode = attributes[:'protection_mode'] if attributes[:'protection_mode']

  self.apply_lag = attributes[:'applyLag'] if attributes[:'applyLag']

  raise 'You cannot provide both :applyLag and :apply_lag' if attributes.key?(:'applyLag') && attributes.key?(:'apply_lag')

  self.apply_lag = attributes[:'apply_lag'] if attributes[:'apply_lag']

  self.apply_rate = attributes[:'applyRate'] if attributes[:'applyRate']

  raise 'You cannot provide both :applyRate and :apply_rate' if attributes.key?(:'applyRate') && attributes.key?(:'apply_rate')

  self.apply_rate = attributes[:'apply_rate'] if attributes[:'apply_rate']

  self.is_automatic_failover_enabled = attributes[:'isAutomaticFailoverEnabled'] unless attributes[:'isAutomaticFailoverEnabled'].nil?

  raise 'You cannot provide both :isAutomaticFailoverEnabled and :is_automatic_failover_enabled' if attributes.key?(:'isAutomaticFailoverEnabled') && attributes.key?(:'is_automatic_failover_enabled')

  self.is_automatic_failover_enabled = attributes[:'is_automatic_failover_enabled'] unless attributes[:'is_automatic_failover_enabled'].nil?

  self.transport_lag = attributes[:'transportLag'] if attributes[:'transportLag']

  raise 'You cannot provide both :transportLag and :transport_lag' if attributes.key?(:'transportLag') && attributes.key?(:'transport_lag')

  self.transport_lag = attributes[:'transport_lag'] if attributes[:'transport_lag']

  self.time_last_synced = attributes[:'timeLastSynced'] if attributes[:'timeLastSynced']

  raise 'You cannot provide both :timeLastSynced and :time_last_synced' if attributes.key?(:'timeLastSynced') && attributes.key?(:'time_last_synced')

  self.time_last_synced = attributes[:'time_last_synced'] if attributes[:'time_last_synced']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_last_role_changed = attributes[:'timeLastRoleChanged'] if attributes[:'timeLastRoleChanged']

  raise 'You cannot provide both :timeLastRoleChanged and :time_last_role_changed' if attributes.key?(:'timeLastRoleChanged') && attributes.key?(:'time_last_role_changed')

  self.time_last_role_changed = attributes[:'time_last_role_changed'] if attributes[:'time_last_role_changed']
end

Instance Attribute Details

#apply_lagString

The lag time between updates to the primary Autonomous Container Database and application of the redo data on the standby Autonomous Container Database, as computed by the reporting database.

Example: ‘9 seconds`

Returns:



108
109
110
# File 'lib/oci/database/models/autonomous_container_database_dataguard_association.rb', line 108

def apply_lag
  @apply_lag
end

#apply_rateString

The rate at which redo logs are synchronized between the associated Autonomous Container Databases.

Example: ‘180 Mb per second`

Returns:



115
116
117
# File 'lib/oci/database/models/autonomous_container_database_dataguard_association.rb', line 115

def apply_rate
  @apply_rate
end

#autonomous_container_database_idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Autonomous Container Database that has a relationship with the peer Autonomous Container Database.

Returns:



61
62
63
# File 'lib/oci/database/models/autonomous_container_database_dataguard_association.rb', line 61

def autonomous_container_database_id
  @autonomous_container_database_id
end

#idString

[Required] The OCID of the Autonomous Data Guard created for a given Autonomous Container Database.

Returns:



56
57
58
# File 'lib/oci/database/models/autonomous_container_database_dataguard_association.rb', line 56

def id
  @id
end

#is_automatic_failover_enabledBOOLEAN

Indicates whether Automatic Failover is enabled for Autonomous Container Database Dataguard Association

Returns:



120
121
122
# File 'lib/oci/database/models/autonomous_container_database_dataguard_association.rb', line 120

def is_automatic_failover_enabled
  @is_automatic_failover_enabled
end

#lifecycle_detailsString

Additional information about the current lifecycleState, if available.

Returns:



75
76
77
# File 'lib/oci/database/models/autonomous_container_database_dataguard_association.rb', line 75

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

[Required] The current state of Autonomous Data Guard.

Returns:



70
71
72
# File 'lib/oci/database/models/autonomous_container_database_dataguard_association.rb', line 70

def lifecycle_state
  @lifecycle_state
end

#peer_autonomous_container_database_dataguard_association_idString

The OCID of the peer Autonomous Container Database-Autonomous Data Guard association.

Returns:



79
80
81
# File 'lib/oci/database/models/autonomous_container_database_dataguard_association.rb', line 79

def peer_autonomous_container_database_dataguard_association_id
  @peer_autonomous_container_database_dataguard_association_id
end

#peer_autonomous_container_database_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the peer Autonomous Container Database.

Returns:



84
85
86
# File 'lib/oci/database/models/autonomous_container_database_dataguard_association.rb', line 84

def peer_autonomous_container_database_id
  @peer_autonomous_container_database_id
end

#peer_lifecycle_stateString

The current state of Autonomous Data Guard.

Returns:



93
94
95
# File 'lib/oci/database/models/autonomous_container_database_dataguard_association.rb', line 93

def peer_lifecycle_state
  @peer_lifecycle_state
end

#peer_roleString

[Required] The Data Guard role of the Autonomous Container Database or Autonomous Database, if Autonomous Data Guard is enabled.

Returns:



89
90
91
# File 'lib/oci/database/models/autonomous_container_database_dataguard_association.rb', line 89

def peer_role
  @peer_role
end

#protection_modeString

The protection mode of this Autonomous Data Guard association. For more information, see [Oracle Data Guard Protection Modes](docs.oracle.com/database/122/SBYDB/oracle-data-guard-protection-modes.htm#SBYDB02000) in the Oracle Data Guard documentation.

Returns:



100
101
102
# File 'lib/oci/database/models/autonomous_container_database_dataguard_association.rb', line 100

def protection_mode
  @protection_mode
end

#roleString

[Required] The Data Guard role of the Autonomous Container Database or Autonomous Database, if Autonomous Data Guard is enabled.

Returns:



66
67
68
# File 'lib/oci/database/models/autonomous_container_database_dataguard_association.rb', line 66

def role
  @role
end

#time_createdDateTime

The date and time the Autonomous DataGuard association was created.

Returns:



136
137
138
# File 'lib/oci/database/models/autonomous_container_database_dataguard_association.rb', line 136

def time_created
  @time_created
end

#time_last_role_changedDateTime

The date and time when the last role change action happened.

Returns:



140
141
142
# File 'lib/oci/database/models/autonomous_container_database_dataguard_association.rb', line 140

def time_last_role_changed
  @time_last_role_changed
end

#time_last_syncedDateTime

The date and time of the last update to the apply lag, apply rate, and transport lag values.

Returns:



132
133
134
# File 'lib/oci/database/models/autonomous_container_database_dataguard_association.rb', line 132

def time_last_synced
  @time_last_synced
end

#transport_lagString

The approximate number of seconds of redo data not yet available on the standby Autonomous Container Database, as computed by the reporting database.

Example: ‘7 seconds`

Returns:



128
129
130
# File 'lib/oci/database/models/autonomous_container_database_dataguard_association.rb', line 128

def transport_lag
  @transport_lag
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/oci/database/models/autonomous_container_database_dataguard_association.rb', line 143

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'autonomous_container_database_id': :'autonomousContainerDatabaseId',
    'role': :'role',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'peer_autonomous_container_database_dataguard_association_id': :'peerAutonomousContainerDatabaseDataguardAssociationId',
    'peer_autonomous_container_database_id': :'peerAutonomousContainerDatabaseId',
    'peer_role': :'peerRole',
    'peer_lifecycle_state': :'peerLifecycleState',
    'protection_mode': :'protectionMode',
    'apply_lag': :'applyLag',
    'apply_rate': :'applyRate',
    'is_automatic_failover_enabled': :'isAutomaticFailoverEnabled',
    'transport_lag': :'transportLag',
    'time_last_synced': :'timeLastSynced',
    'time_created': :'timeCreated',
    'time_last_role_changed': :'timeLastRoleChanged'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/oci/database/models/autonomous_container_database_dataguard_association.rb', line 168

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'autonomous_container_database_id': :'String',
    'role': :'String',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'peer_autonomous_container_database_dataguard_association_id': :'String',
    'peer_autonomous_container_database_id': :'String',
    'peer_role': :'String',
    'peer_lifecycle_state': :'String',
    'protection_mode': :'String',
    'apply_lag': :'String',
    'apply_rate': :'String',
    'is_automatic_failover_enabled': :'BOOLEAN',
    'transport_lag': :'String',
    'time_last_synced': :'DateTime',
    'time_created': :'DateTime',
    'time_last_role_changed': :'DateTime'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • the other object to be compared



388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
# File 'lib/oci/database/models/autonomous_container_database_dataguard_association.rb', line 388

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    autonomous_container_database_id == other.autonomous_container_database_id &&
    role == other.role &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    peer_autonomous_container_database_dataguard_association_id == other.peer_autonomous_container_database_dataguard_association_id &&
    peer_autonomous_container_database_id == other.peer_autonomous_container_database_id &&
    peer_role == other.peer_role &&
    peer_lifecycle_state == other.peer_lifecycle_state &&
    protection_mode == other.protection_mode &&
    apply_lag == other.apply_lag &&
    apply_rate == other.apply_rate &&
    is_automatic_failover_enabled == other.is_automatic_failover_enabled &&
    transport_lag == other.transport_lag &&
    time_last_synced == other.time_last_synced &&
    time_created == other.time_created &&
    time_last_role_changed == other.time_last_role_changed
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
# File 'lib/oci/database/models/autonomous_container_database_dataguard_association.rb', line 434

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • the other object to be compared

Returns:

See Also:

  • `==` method


414
415
416
# File 'lib/oci/database/models/autonomous_container_database_dataguard_association.rb', line 414

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • Hash code



423
424
425
# File 'lib/oci/database/models/autonomous_container_database_dataguard_association.rb', line 423

def hash
  [id, autonomous_container_database_id, role, lifecycle_state, lifecycle_details, peer_autonomous_container_database_dataguard_association_id, peer_autonomous_container_database_id, peer_role, peer_lifecycle_state, protection_mode, apply_lag, apply_rate, is_automatic_failover_enabled, transport_lag, time_last_synced, time_created, time_last_role_changed].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



467
468
469
470
471
472
473
474
475
476
# File 'lib/oci/database/models/autonomous_container_database_dataguard_association.rb', line 467

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



461
462
463
# File 'lib/oci/database/models/autonomous_container_database_dataguard_association.rb', line 461

def to_s
  to_hash.to_s
end