Class: OCI::Database::Models::AutonomousContainerDatabaseSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database/models/autonomous_container_database_summary.rb

Overview

An Autonomous Container Database is a container database service that enables the customer to host one or more databases within the container database. A basic container database runs on a single Autonomous Exadata Infrastructure from an availability domain without the Extreme Availability features enabled.

Constant Summary collapse

SERVICE_LEVEL_AGREEMENT_TYPE_ENUM =
[
  SERVICE_LEVEL_AGREEMENT_TYPE_STANDARD = 'STANDARD'.freeze,
  SERVICE_LEVEL_AGREEMENT_TYPE_MISSION_CRITICAL = 'MISSION_CRITICAL'.freeze,
  SERVICE_LEVEL_AGREEMENT_TYPE_AUTONOMOUS_DATAGUARD = 'AUTONOMOUS_DATAGUARD'.freeze,
  SERVICE_LEVEL_AGREEMENT_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
INFRASTRUCTURE_TYPE_ENUM =
[
  INFRASTRUCTURE_TYPE_CLOUD = 'CLOUD'.freeze,
  INFRASTRUCTURE_TYPE_CLOUD_AT_CUSTOMER = 'CLOUD_AT_CUSTOMER'.freeze,
  INFRASTRUCTURE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze,
  LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze,
  LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_BACKUP_IN_PROGRESS = 'BACKUP_IN_PROGRESS'.freeze,
  LIFECYCLE_STATE_RESTORING = 'RESTORING'.freeze,
  LIFECYCLE_STATE_RESTORE_FAILED = 'RESTORE_FAILED'.freeze,
  LIFECYCLE_STATE_RESTARTING = 'RESTARTING'.freeze,
  LIFECYCLE_STATE_MAINTENANCE_IN_PROGRESS = 'MAINTENANCE_IN_PROGRESS'.freeze,
  LIFECYCLE_STATE_ROLE_CHANGE_IN_PROGRESS = 'ROLE_CHANGE_IN_PROGRESS'.freeze,
  LIFECYCLE_STATE_UNAVAILABLE = 'UNAVAILABLE'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
PATCH_MODEL_ENUM =
[
  PATCH_MODEL_RELEASE_UPDATES = 'RELEASE_UPDATES'.freeze,
  PATCH_MODEL_RELEASE_UPDATE_REVISIONS = 'RELEASE_UPDATE_REVISIONS'.freeze,
  PATCH_MODEL_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
ROLE_ENUM =
[
  ROLE_PRIMARY = 'PRIMARY'.freeze,
  ROLE_STANDBY = 'STANDBY'.freeze,
  ROLE_DISABLED_STANDBY = 'DISABLED_STANDBY'.freeze,
  ROLE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ AutonomousContainerDatabaseSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
# File 'lib/oci/database/models/autonomous_container_database_summary.rb', line 331

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.db_unique_name = attributes[:'dbUniqueName'] if attributes[:'dbUniqueName']

  raise 'You cannot provide both :dbUniqueName and :db_unique_name' if attributes.key?(:'dbUniqueName') && attributes.key?(:'db_unique_name')

  self.db_unique_name = attributes[:'db_unique_name'] if attributes[:'db_unique_name']

  self.service_level_agreement_type = attributes[:'serviceLevelAgreementType'] if attributes[:'serviceLevelAgreementType']

  raise 'You cannot provide both :serviceLevelAgreementType and :service_level_agreement_type' if attributes.key?(:'serviceLevelAgreementType') && attributes.key?(:'service_level_agreement_type')

  self.service_level_agreement_type = attributes[:'service_level_agreement_type'] if attributes[:'service_level_agreement_type']

  self.autonomous_exadata_infrastructure_id = attributes[:'autonomousExadataInfrastructureId'] if attributes[:'autonomousExadataInfrastructureId']

  raise 'You cannot provide both :autonomousExadataInfrastructureId and :autonomous_exadata_infrastructure_id' if attributes.key?(:'autonomousExadataInfrastructureId') && attributes.key?(:'autonomous_exadata_infrastructure_id')

  self.autonomous_exadata_infrastructure_id = attributes[:'autonomous_exadata_infrastructure_id'] if attributes[:'autonomous_exadata_infrastructure_id']

  self.autonomous_vm_cluster_id = attributes[:'autonomousVmClusterId'] if attributes[:'autonomousVmClusterId']

  raise 'You cannot provide both :autonomousVmClusterId and :autonomous_vm_cluster_id' if attributes.key?(:'autonomousVmClusterId') && attributes.key?(:'autonomous_vm_cluster_id')

  self.autonomous_vm_cluster_id = attributes[:'autonomous_vm_cluster_id'] if attributes[:'autonomous_vm_cluster_id']

  self.infrastructure_type = attributes[:'infrastructureType'] if attributes[:'infrastructureType']

  raise 'You cannot provide both :infrastructureType and :infrastructure_type' if attributes.key?(:'infrastructureType') && attributes.key?(:'infrastructure_type')

  self.infrastructure_type = attributes[:'infrastructure_type'] if attributes[:'infrastructure_type']

  self.cloud_autonomous_vm_cluster_id = attributes[:'cloudAutonomousVmClusterId'] if attributes[:'cloudAutonomousVmClusterId']

  raise 'You cannot provide both :cloudAutonomousVmClusterId and :cloud_autonomous_vm_cluster_id' if attributes.key?(:'cloudAutonomousVmClusterId') && attributes.key?(:'cloud_autonomous_vm_cluster_id')

  self.cloud_autonomous_vm_cluster_id = attributes[:'cloud_autonomous_vm_cluster_id'] if attributes[:'cloud_autonomous_vm_cluster_id']

  self.kms_key_id = attributes[:'kmsKeyId'] if attributes[:'kmsKeyId']

  raise 'You cannot provide both :kmsKeyId and :kms_key_id' if attributes.key?(:'kmsKeyId') && attributes.key?(:'kms_key_id')

  self.kms_key_id = attributes[:'kms_key_id'] if attributes[:'kms_key_id']

  self.vault_id = attributes[:'vaultId'] if attributes[:'vaultId']

  raise 'You cannot provide both :vaultId and :vault_id' if attributes.key?(:'vaultId') && attributes.key?(:'vault_id')

  self.vault_id = attributes[:'vault_id'] if attributes[:'vault_id']

  self.kms_key_version_id = attributes[:'kmsKeyVersionId'] if attributes[:'kmsKeyVersionId']

  raise 'You cannot provide both :kmsKeyVersionId and :kms_key_version_id' if attributes.key?(:'kmsKeyVersionId') && attributes.key?(:'kms_key_version_id')

  self.kms_key_version_id = attributes[:'kms_key_version_id'] if attributes[:'kms_key_version_id']

  self.key_history_entry = attributes[:'keyHistoryEntry'] if attributes[:'keyHistoryEntry']

  raise 'You cannot provide both :keyHistoryEntry and :key_history_entry' if attributes.key?(:'keyHistoryEntry') && attributes.key?(:'key_history_entry')

  self.key_history_entry = attributes[:'key_history_entry'] if attributes[:'key_history_entry']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.patch_model = attributes[:'patchModel'] if attributes[:'patchModel']

  raise 'You cannot provide both :patchModel and :patch_model' if attributes.key?(:'patchModel') && attributes.key?(:'patch_model')

  self.patch_model = attributes[:'patch_model'] if attributes[:'patch_model']

  self.patch_id = attributes[:'patchId'] if attributes[:'patchId']

  raise 'You cannot provide both :patchId and :patch_id' if attributes.key?(:'patchId') && attributes.key?(:'patch_id')

  self.patch_id = attributes[:'patch_id'] if attributes[:'patch_id']

  self.last_maintenance_run_id = attributes[:'lastMaintenanceRunId'] if attributes[:'lastMaintenanceRunId']

  raise 'You cannot provide both :lastMaintenanceRunId and :last_maintenance_run_id' if attributes.key?(:'lastMaintenanceRunId') && attributes.key?(:'last_maintenance_run_id')

  self.last_maintenance_run_id = attributes[:'last_maintenance_run_id'] if attributes[:'last_maintenance_run_id']

  self.next_maintenance_run_id = attributes[:'nextMaintenanceRunId'] if attributes[:'nextMaintenanceRunId']

  raise 'You cannot provide both :nextMaintenanceRunId and :next_maintenance_run_id' if attributes.key?(:'nextMaintenanceRunId') && attributes.key?(:'next_maintenance_run_id')

  self.next_maintenance_run_id = attributes[:'next_maintenance_run_id'] if attributes[:'next_maintenance_run_id']

  self.maintenance_window = attributes[:'maintenanceWindow'] if attributes[:'maintenanceWindow']

  raise 'You cannot provide both :maintenanceWindow and :maintenance_window' if attributes.key?(:'maintenanceWindow') && attributes.key?(:'maintenance_window')

  self.maintenance_window = attributes[:'maintenance_window'] if attributes[:'maintenance_window']

  self.standby_maintenance_buffer_in_days = attributes[:'standbyMaintenanceBufferInDays'] if attributes[:'standbyMaintenanceBufferInDays']

  raise 'You cannot provide both :standbyMaintenanceBufferInDays and :standby_maintenance_buffer_in_days' if attributes.key?(:'standbyMaintenanceBufferInDays') && attributes.key?(:'standby_maintenance_buffer_in_days')

  self.standby_maintenance_buffer_in_days = attributes[:'standby_maintenance_buffer_in_days'] if attributes[:'standby_maintenance_buffer_in_days']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.role = attributes[:'role'] if attributes[:'role']

  self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain']

  raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain')

  self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain']

  self.db_version = attributes[:'dbVersion'] if attributes[:'dbVersion']

  raise 'You cannot provide both :dbVersion and :db_version' if attributes.key?(:'dbVersion') && attributes.key?(:'db_version')

  self.db_version = attributes[:'db_version'] if attributes[:'db_version']

  self.backup_config = attributes[:'backupConfig'] if attributes[:'backupConfig']

  raise 'You cannot provide both :backupConfig and :backup_config' if attributes.key?(:'backupConfig') && attributes.key?(:'backup_config')

  self.backup_config = attributes[:'backup_config'] if attributes[:'backup_config']

  self.key_store_id = attributes[:'keyStoreId'] if attributes[:'keyStoreId']

  raise 'You cannot provide both :keyStoreId and :key_store_id' if attributes.key?(:'keyStoreId') && attributes.key?(:'key_store_id')

  self.key_store_id = attributes[:'key_store_id'] if attributes[:'key_store_id']

  self.key_store_wallet_name = attributes[:'keyStoreWalletName'] if attributes[:'keyStoreWalletName']

  raise 'You cannot provide both :keyStoreWalletName and :key_store_wallet_name' if attributes.key?(:'keyStoreWalletName') && attributes.key?(:'key_store_wallet_name')

  self.key_store_wallet_name = attributes[:'key_store_wallet_name'] if attributes[:'key_store_wallet_name']

  self.memory_per_oracle_compute_unit_in_gbs = attributes[:'memoryPerOracleComputeUnitInGBs'] if attributes[:'memoryPerOracleComputeUnitInGBs']

  raise 'You cannot provide both :memoryPerOracleComputeUnitInGBs and :memory_per_oracle_compute_unit_in_gbs' if attributes.key?(:'memoryPerOracleComputeUnitInGBs') && attributes.key?(:'memory_per_oracle_compute_unit_in_gbs')

  self.memory_per_oracle_compute_unit_in_gbs = attributes[:'memory_per_oracle_compute_unit_in_gbs'] if attributes[:'memory_per_oracle_compute_unit_in_gbs']

  self.available_cpus = attributes[:'availableCpus'] if attributes[:'availableCpus']

  raise 'You cannot provide both :availableCpus and :available_cpus' if attributes.key?(:'availableCpus') && attributes.key?(:'available_cpus')

  self.available_cpus = attributes[:'available_cpus'] if attributes[:'available_cpus']

  self.total_cpus = attributes[:'totalCpus'] if attributes[:'totalCpus']

  raise 'You cannot provide both :totalCpus and :total_cpus' if attributes.key?(:'totalCpus') && attributes.key?(:'total_cpus')

  self.total_cpus = attributes[:'total_cpus'] if attributes[:'total_cpus']

  self.reclaimable_cpus = attributes[:'reclaimableCpus'] if attributes[:'reclaimableCpus']

  raise 'You cannot provide both :reclaimableCpus and :reclaimable_cpus' if attributes.key?(:'reclaimableCpus') && attributes.key?(:'reclaimable_cpus')

  self.reclaimable_cpus = attributes[:'reclaimable_cpus'] if attributes[:'reclaimable_cpus']

  self.provisionable_cpus = attributes[:'provisionableCpus'] if attributes[:'provisionableCpus']

  raise 'You cannot provide both :provisionableCpus and :provisionable_cpus' if attributes.key?(:'provisionableCpus') && attributes.key?(:'provisionable_cpus')

  self.provisionable_cpus = attributes[:'provisionable_cpus'] if attributes[:'provisionable_cpus']
end

Instance Attribute Details

#autonomous_exadata_infrastructure_idString

**No longer used.** For Autonomous Database on dedicated Exadata infrastructure, the container database is created within a specified `cloudAutonomousVmCluster`.

Returns:

  • (String)


79
80
81
# File 'lib/oci/database/models/autonomous_container_database_summary.rb', line 79

def autonomous_exadata_infrastructure_id
  @autonomous_exadata_infrastructure_id
end

#autonomous_vm_cluster_idString

The OCID of the Autonomous VM Cluster.

Returns:

  • (String)


83
84
85
# File 'lib/oci/database/models/autonomous_container_database_summary.rb', line 83

def autonomous_vm_cluster_id
  @autonomous_vm_cluster_id
end

#availability_domainString

The availability domain of the Autonomous Container Database.

Returns:

  • (String)


167
168
169
# File 'lib/oci/database/models/autonomous_container_database_summary.rb', line 167

def availability_domain
  @availability_domain
end

#available_cpusFloat

Sum of OCPUs available on the Autonomous VM Cluster + Sum of fractional OCPUs available in the Autonomous Container Database.

Returns:

  • (Float)


190
191
192
# File 'lib/oci/database/models/autonomous_container_database_summary.rb', line 190

def available_cpus
  @available_cpus
end

#backup_configOCI::Database::Models::AutonomousContainerDatabaseBackupConfig



174
175
176
# File 'lib/oci/database/models/autonomous_container_database_summary.rb', line 174

def backup_config
  @backup_config
end

#cloud_autonomous_vm_cluster_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the cloud Autonomous Exadata VM Cluster.

Returns:

  • (String)


91
92
93
# File 'lib/oci/database/models/autonomous_container_database_summary.rb', line 91

def cloud_autonomous_vm_cluster_id
  @cloud_autonomous_vm_cluster_id
end

#compartment_idString

**[Required]** The OCID of the compartment.

Returns:

  • (String)


61
62
63
# File 'lib/oci/database/models/autonomous_container_database_summary.rb', line 61

def compartment_id
  @compartment_id
end

#db_unique_nameString

*Deprecated.* The `DB_UNIQUE_NAME` value is set by Oracle Cloud Infrastructure. Do not specify a value for this parameter. Specifying a value for this field will cause Terraform operations to fail.

Returns:

  • (String)


70
71
72
# File 'lib/oci/database/models/autonomous_container_database_summary.rb', line 70

def db_unique_name
  @db_unique_name
end

#db_versionString

Oracle Database version of the Autonomous Container Database.

Returns:

  • (String)


171
172
173
# File 'lib/oci/database/models/autonomous_container_database_summary.rb', line 171

def db_version
  @db_version
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Returns:

  • (Hash<String, Hash<String, Object>>)


159
160
161
# File 'lib/oci/database/models/autonomous_container_database_summary.rb', line 159

def defined_tags
  @defined_tags
end

#display_nameString

**[Required]** The user-provided name for the Autonomous Container Database.

Returns:

  • (String)


65
66
67
# File 'lib/oci/database/models/autonomous_container_database_summary.rb', line 65

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: `"Finance"`

Returns:

  • (Hash<String, String>)


153
154
155
# File 'lib/oci/database/models/autonomous_container_database_summary.rb', line 153

def freeform_tags
  @freeform_tags
end

#idString

**[Required]** The OCID of the Autonomous Container Database.

Returns:

  • (String)


57
58
59
# File 'lib/oci/database/models/autonomous_container_database_summary.rb', line 57

def id
  @id
end

#infrastructure_typeString

The infrastructure type this resource belongs to.

Returns:

  • (String)


87
88
89
# File 'lib/oci/database/models/autonomous_container_database_summary.rb', line 87

def infrastructure_type
  @infrastructure_type
end

#key_history_entryArray<OCI::Database::Models::AutonomousDatabaseKeyHistoryEntry>

Key History Entry.



108
109
110
# File 'lib/oci/database/models/autonomous_container_database_summary.rb', line 108

def key_history_entry
  @key_history_entry
end

#key_store_idString

Returns:

  • (String)


178
179
180
# File 'lib/oci/database/models/autonomous_container_database_summary.rb', line 178

def key_store_id
  @key_store_id
end

#key_store_wallet_nameString

The wallet name for Oracle Key Vault.

Returns:

  • (String)


182
183
184
# File 'lib/oci/database/models/autonomous_container_database_summary.rb', line 182

def key_store_wallet_name
  @key_store_wallet_name
end

#kms_key_idString

The OCID of the key container that is used as the master encryption key in database transparent data encryption (TDE) operations.

Returns:

  • (String)


95
96
97
# File 'lib/oci/database/models/autonomous_container_database_summary.rb', line 95

def kms_key_id
  @kms_key_id
end

#kms_key_version_idString

The OCID of the key container version that is used in database transparent data encryption (TDE) operations KMS Key can have multiple key versions. If none is specified, the current key version (latest) of the Key Id is used for the operation.

Returns:

  • (String)


104
105
106
# File 'lib/oci/database/models/autonomous_container_database_summary.rb', line 104

def kms_key_version_id
  @kms_key_version_id
end

#last_maintenance_run_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the last maintenance run.

Returns:

  • (String)


132
133
134
# File 'lib/oci/database/models/autonomous_container_database_summary.rb', line 132

def last_maintenance_run_id
  @last_maintenance_run_id
end

#lifecycle_detailsString

Additional information about the current lifecycle state.

Returns:

  • (String)


116
117
118
# File 'lib/oci/database/models/autonomous_container_database_summary.rb', line 116

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

**[Required]** The current state of the Autonomous Container Database.

Returns:

  • (String)


112
113
114
# File 'lib/oci/database/models/autonomous_container_database_summary.rb', line 112

def lifecycle_state
  @lifecycle_state
end

#maintenance_windowOCI::Database::Models::MaintenanceWindow



139
140
141
# File 'lib/oci/database/models/autonomous_container_database_summary.rb', line 139

def maintenance_window
  @maintenance_window
end

#memory_per_oracle_compute_unit_in_gbsInteger

The amount of memory (in GBs) enabled per each OCPU core in Autonomous VM Cluster.

Returns:

  • (Integer)


186
187
188
# File 'lib/oci/database/models/autonomous_container_database_summary.rb', line 186

def memory_per_oracle_compute_unit_in_gbs
  @memory_per_oracle_compute_unit_in_gbs
end

#next_maintenance_run_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the next maintenance run.

Returns:

  • (String)


136
137
138
# File 'lib/oci/database/models/autonomous_container_database_summary.rb', line 136

def next_maintenance_run_id
  @next_maintenance_run_id
end

#patch_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the last patch applied on the system.

Returns:

  • (String)


128
129
130
# File 'lib/oci/database/models/autonomous_container_database_summary.rb', line 128

def patch_id
  @patch_id
end

#patch_modelString

**[Required]** Database patch model preference.

Returns:

  • (String)


124
125
126
# File 'lib/oci/database/models/autonomous_container_database_summary.rb', line 124

def patch_model
  @patch_model
end

#provisionable_cpusArray<Float>

An array of CPU values that can be used to successfully provision a single Autonomous Database.

Returns:

  • (Array<Float>)


202
203
204
# File 'lib/oci/database/models/autonomous_container_database_summary.rb', line 202

def provisionable_cpus
  @provisionable_cpus
end

#reclaimable_cpusFloat

CPU cores that continue to be included in the count of OCPUs available to the Autonomous Container Database even after one of its Autonomous Database is terminated or scaled down. You can release them to the available OCPUs at its parent AVMC level by restarting the Autonomous Container Database.

Returns:

  • (Float)


198
199
200
# File 'lib/oci/database/models/autonomous_container_database_summary.rb', line 198

def reclaimable_cpus
  @reclaimable_cpus
end

#roleString

The role of the Autonomous Data Guard-enabled Autonomous Container Database.

Returns:

  • (String)


163
164
165
# File 'lib/oci/database/models/autonomous_container_database_summary.rb', line 163

def role
  @role
end

#service_level_agreement_typeString

**[Required]** The service level agreement type of the container database. The default is STANDARD.

Returns:

  • (String)


74
75
76
# File 'lib/oci/database/models/autonomous_container_database_summary.rb', line 74

def service_level_agreement_type
  @service_level_agreement_type
end

#standby_maintenance_buffer_in_daysInteger

The scheduling detail for the quarterly maintenance window of the standby Autonomous Container Database. This value represents the number of days before scheduled maintenance of the primary database.

Returns:

  • (Integer)


145
146
147
# File 'lib/oci/database/models/autonomous_container_database_summary.rb', line 145

def standby_maintenance_buffer_in_days
  @standby_maintenance_buffer_in_days
end

#time_createdDateTime

The date and time the Autonomous Container Database was created.

Returns:

  • (DateTime)


120
121
122
# File 'lib/oci/database/models/autonomous_container_database_summary.rb', line 120

def time_created
  @time_created
end

#total_cpusInteger

The number of CPU cores allocated to the Autonomous VM cluster.

Returns:

  • (Integer)


194
195
196
# File 'lib/oci/database/models/autonomous_container_database_summary.rb', line 194

def total_cpus
  @total_cpus
end

#vault_idString

Returns:

  • (String)


99
100
101
# File 'lib/oci/database/models/autonomous_container_database_summary.rb', line 99

def vault_id
  @vault_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/oci/database/models/autonomous_container_database_summary.rb', line 205

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'compartment_id': :'compartmentId',
    'display_name': :'displayName',
    'db_unique_name': :'dbUniqueName',
    'service_level_agreement_type': :'serviceLevelAgreementType',
    'autonomous_exadata_infrastructure_id': :'autonomousExadataInfrastructureId',
    'autonomous_vm_cluster_id': :'autonomousVmClusterId',
    'infrastructure_type': :'infrastructureType',
    'cloud_autonomous_vm_cluster_id': :'cloudAutonomousVmClusterId',
    'kms_key_id': :'kmsKeyId',
    'vault_id': :'vaultId',
    'kms_key_version_id': :'kmsKeyVersionId',
    'key_history_entry': :'keyHistoryEntry',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'time_created': :'timeCreated',
    'patch_model': :'patchModel',
    'patch_id': :'patchId',
    'last_maintenance_run_id': :'lastMaintenanceRunId',
    'next_maintenance_run_id': :'nextMaintenanceRunId',
    'maintenance_window': :'maintenanceWindow',
    'standby_maintenance_buffer_in_days': :'standbyMaintenanceBufferInDays',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'role': :'role',
    'availability_domain': :'availabilityDomain',
    'db_version': :'dbVersion',
    'backup_config': :'backupConfig',
    'key_store_id': :'keyStoreId',
    'key_store_wallet_name': :'keyStoreWalletName',
    'memory_per_oracle_compute_unit_in_gbs': :'memoryPerOracleComputeUnitInGBs',
    'available_cpus': :'availableCpus',
    'total_cpus': :'totalCpus',
    'reclaimable_cpus': :'reclaimableCpus',
    'provisionable_cpus': :'provisionableCpus'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
# File 'lib/oci/database/models/autonomous_container_database_summary.rb', line 248

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'compartment_id': :'String',
    'display_name': :'String',
    'db_unique_name': :'String',
    'service_level_agreement_type': :'String',
    'autonomous_exadata_infrastructure_id': :'String',
    'autonomous_vm_cluster_id': :'String',
    'infrastructure_type': :'String',
    'cloud_autonomous_vm_cluster_id': :'String',
    'kms_key_id': :'String',
    'vault_id': :'String',
    'kms_key_version_id': :'String',
    'key_history_entry': :'Array<OCI::Database::Models::AutonomousDatabaseKeyHistoryEntry>',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'time_created': :'DateTime',
    'patch_model': :'String',
    'patch_id': :'String',
    'last_maintenance_run_id': :'String',
    'next_maintenance_run_id': :'String',
    'maintenance_window': :'OCI::Database::Models::MaintenanceWindow',
    'standby_maintenance_buffer_in_days': :'Integer',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'role': :'String',
    'availability_domain': :'String',
    'db_version': :'String',
    'backup_config': :'OCI::Database::Models::AutonomousContainerDatabaseBackupConfig',
    'key_store_id': :'String',
    'key_store_wallet_name': :'String',
    'memory_per_oracle_compute_unit_in_gbs': :'Integer',
    'available_cpus': :'Float',
    'total_cpus': :'Integer',
    'reclaimable_cpus': :'Float',
    'provisionable_cpus': :'Array<Float>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
# File 'lib/oci/database/models/autonomous_container_database_summary.rb', line 612

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    display_name == other.display_name &&
    db_unique_name == other.db_unique_name &&
    service_level_agreement_type == other.service_level_agreement_type &&
    autonomous_exadata_infrastructure_id == other.autonomous_exadata_infrastructure_id &&
    autonomous_vm_cluster_id == other.autonomous_vm_cluster_id &&
    infrastructure_type == other.infrastructure_type &&
    cloud_autonomous_vm_cluster_id == other.cloud_autonomous_vm_cluster_id &&
    kms_key_id == other.kms_key_id &&
    vault_id == other.vault_id &&
    kms_key_version_id == other.kms_key_version_id &&
    key_history_entry == other.key_history_entry &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    time_created == other.time_created &&
    patch_model == other.patch_model &&
    patch_id == other.patch_id &&
    last_maintenance_run_id == other.last_maintenance_run_id &&
    next_maintenance_run_id == other.next_maintenance_run_id &&
    maintenance_window == other.maintenance_window &&
    standby_maintenance_buffer_in_days == other.standby_maintenance_buffer_in_days &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    role == other.role &&
    availability_domain == other.availability_domain &&
    db_version == other.db_version &&
    backup_config == other.backup_config &&
    key_store_id == other.key_store_id &&
    key_store_wallet_name == other.key_store_wallet_name &&
    memory_per_oracle_compute_unit_in_gbs == other.memory_per_oracle_compute_unit_in_gbs &&
    available_cpus == other.available_cpus &&
    total_cpus == other.total_cpus &&
    reclaimable_cpus == other.reclaimable_cpus &&
    provisionable_cpus == other.provisionable_cpus
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
# File 'lib/oci/database/models/autonomous_container_database_summary.rb', line 676

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


656
657
658
# File 'lib/oci/database/models/autonomous_container_database_summary.rb', line 656

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



665
666
667
# File 'lib/oci/database/models/autonomous_container_database_summary.rb', line 665

def hash
  [id, compartment_id, display_name, db_unique_name, service_level_agreement_type, autonomous_exadata_infrastructure_id, autonomous_vm_cluster_id, infrastructure_type, cloud_autonomous_vm_cluster_id, kms_key_id, vault_id, kms_key_version_id, key_history_entry, lifecycle_state, lifecycle_details, time_created, patch_model, patch_id, last_maintenance_run_id, next_maintenance_run_id, maintenance_window, standby_maintenance_buffer_in_days, freeform_tags, defined_tags, role, availability_domain, db_version, backup_config, key_store_id, key_store_wallet_name, memory_per_oracle_compute_unit_in_gbs, available_cpus, total_cpus, reclaimable_cpus, provisionable_cpus].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



709
710
711
712
713
714
715
716
717
718
# File 'lib/oci/database/models/autonomous_container_database_summary.rb', line 709

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



703
704
705
# File 'lib/oci/database/models/autonomous_container_database_summary.rb', line 703

def to_s
  to_hash.to_s
end