Class: OCI::Database::Models::AutonomousDatabase
- Inherits:
-
Object
- Object
- OCI::Database::Models::AutonomousDatabase
- Defined in:
- lib/oci/database/models/autonomous_database.rb
Overview
An Oracle Autonomous Database.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
rubocop:disable Metrics/LineLength
[ LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze, LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze, LIFECYCLE_STATE_STOPPING = 'STOPPING'.freeze, LIFECYCLE_STATE_STOPPED = 'STOPPED'.freeze, LIFECYCLE_STATE_STARTING = 'STARTING'.freeze, LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze, LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze, LIFECYCLE_STATE_UNAVAILABLE = 'UNAVAILABLE'.freeze, LIFECYCLE_STATE_RESTORE_IN_PROGRESS = 'RESTORE_IN_PROGRESS'.freeze, LIFECYCLE_STATE_RESTORE_FAILED = 'RESTORE_FAILED'.freeze, LIFECYCLE_STATE_BACKUP_IN_PROGRESS = 'BACKUP_IN_PROGRESS'.freeze, LIFECYCLE_STATE_SCALE_IN_PROGRESS = 'SCALE_IN_PROGRESS'.freeze, LIFECYCLE_STATE_AVAILABLE_NEEDS_ATTENTION = 'AVAILABLE_NEEDS_ATTENTION'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LICENSE_MODEL_ENUM =
[ LICENSE_MODEL_LICENSE_INCLUDED = 'LICENSE_INCLUDED'.freeze, LICENSE_MODEL_BRING_YOUR_OWN_LICENSE = 'BRING_YOUR_OWN_LICENSE'.freeze, LICENSE_MODEL_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- DB_WORKLOAD_ENUM =
[ DB_WORKLOAD_OLTP = 'OLTP'.freeze, DB_WORKLOAD_DW = 'DW'.freeze, DB_WORKLOAD_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
-
#connection_strings ⇒ OCI::Database::Models::AutonomousDatabaseConnectionStrings
The connection string used to connect to the Autonomous Database.
-
#cpu_core_count ⇒ Integer
[Required] The number of CPU cores to be made available to the database.
-
#data_storage_size_in_tbs ⇒ Integer
[Required] The quantity of data in the database, in terabytes.
-
#db_name ⇒ String
[Required] The database name.
-
#db_version ⇒ String
A valid Oracle Database version for Autonomous Database.
-
#db_workload ⇒ String
The Autonomous Database workload type.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
The user-friendly name for the Autonomous Database.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Autonomous Database.
-
#license_model ⇒ String
The Oracle license model that applies to the Oracle Autonomous Database.
-
#lifecycle_details ⇒ String
Information about the current lifecycle state.
-
#lifecycle_state ⇒ String
[Required] The current state of the database.
-
#service_console_url ⇒ String
The URL of the Service Console for the Autonomous Database.
-
#time_created ⇒ DateTime
The date and time the database was created.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AutonomousDatabase
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ AutonomousDatabase
Initializes the object
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/oci/database/models/autonomous_database.rb', line 183 def initialize(attributes = {}) return unless attributes.is_a?(Hash) self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.db_name = attributes[:'dbName'] if attributes[:'dbName'] raise 'You cannot provide both :dbName and :db_name' if attributes.key?(:'dbName') && attributes.key?(:'db_name') self.db_name = attributes[:'db_name'] if attributes[:'db_name'] self.cpu_core_count = attributes[:'cpuCoreCount'] if attributes[:'cpuCoreCount'] raise 'You cannot provide both :cpuCoreCount and :cpu_core_count' if attributes.key?(:'cpuCoreCount') && attributes.key?(:'cpu_core_count') self.cpu_core_count = attributes[:'cpu_core_count'] if attributes[:'cpu_core_count'] self.data_storage_size_in_tbs = attributes[:'dataStorageSizeInTBs'] if attributes[:'dataStorageSizeInTBs'] raise 'You cannot provide both :dataStorageSizeInTBs and :data_storage_size_in_tbs' if attributes.key?(:'dataStorageSizeInTBs') && attributes.key?(:'data_storage_size_in_tbs') self.data_storage_size_in_tbs = attributes[:'data_storage_size_in_tbs'] if attributes[:'data_storage_size_in_tbs'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.service_console_url = attributes[:'serviceConsoleUrl'] if attributes[:'serviceConsoleUrl'] raise 'You cannot provide both :serviceConsoleUrl and :service_console_url' if attributes.key?(:'serviceConsoleUrl') && attributes.key?(:'service_console_url') self.service_console_url = attributes[:'service_console_url'] if attributes[:'service_console_url'] self.connection_strings = attributes[:'connectionStrings'] if attributes[:'connectionStrings'] raise 'You cannot provide both :connectionStrings and :connection_strings' if attributes.key?(:'connectionStrings') && attributes.key?(:'connection_strings') self.connection_strings = attributes[:'connection_strings'] if attributes[:'connection_strings'] self.license_model = attributes[:'licenseModel'] if attributes[:'licenseModel'] raise 'You cannot provide both :licenseModel and :license_model' if attributes.key?(:'licenseModel') && attributes.key?(:'license_model') self.license_model = attributes[:'license_model'] if attributes[:'license_model'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.db_version = attributes[:'dbVersion'] if attributes[:'dbVersion'] raise 'You cannot provide both :dbVersion and :db_version' if attributes.key?(:'dbVersion') && attributes.key?(:'db_version') self.db_version = attributes[:'db_version'] if attributes[:'db_version'] self.db_workload = attributes[:'dbWorkload'] if attributes[:'dbWorkload'] raise 'You cannot provide both :dbWorkload and :db_workload' if attributes.key?(:'dbWorkload') && attributes.key?(:'db_workload') self.db_workload = attributes[:'db_workload'] if attributes[:'db_workload'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
46 47 48 |
# File 'lib/oci/database/models/autonomous_database.rb', line 46 def compartment_id @compartment_id end |
#connection_strings ⇒ OCI::Database::Models::AutonomousDatabaseConnectionStrings
The connection string used to connect to the Autonomous Database. The username for the Service Console is ADMIN. Use the password you entered when creating the Autonomous Database for the password value.
82 83 84 |
# File 'lib/oci/database/models/autonomous_database.rb', line 82 def connection_strings @connection_strings end |
#cpu_core_count ⇒ Integer
[Required] The number of CPU cores to be made available to the database.
62 63 64 |
# File 'lib/oci/database/models/autonomous_database.rb', line 62 def cpu_core_count @cpu_core_count end |
#data_storage_size_in_tbs ⇒ Integer
[Required] The quantity of data in the database, in terabytes.
66 67 68 |
# File 'lib/oci/database/models/autonomous_database.rb', line 66 def data_storage_size_in_tbs @data_storage_size_in_tbs end |
#db_name ⇒ String
[Required] The database name.
58 59 60 |
# File 'lib/oci/database/models/autonomous_database.rb', line 58 def db_name @db_name end |
#db_version ⇒ String
A valid Oracle Database version for Autonomous Database.
107 108 109 |
# File 'lib/oci/database/models/autonomous_database.rb', line 107 def db_version @db_version end |
#db_workload ⇒ String
The Autonomous Database workload type.
111 112 113 |
# File 'lib/oci/database/models/autonomous_database.rb', line 111 def db_workload @db_workload end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
103 104 105 |
# File 'lib/oci/database/models/autonomous_database.rb', line 103 def @defined_tags end |
#display_name ⇒ String
The user-friendly name for the Autonomous Database. The name does not have to be unique.
74 75 76 |
# File 'lib/oci/database/models/autonomous_database.rb', line 74 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
95 96 97 |
# File 'lib/oci/database/models/autonomous_database.rb', line 95 def @freeform_tags end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Autonomous Database.
42 43 44 |
# File 'lib/oci/database/models/autonomous_database.rb', line 42 def id @id end |
#license_model ⇒ String
The Oracle license model that applies to the Oracle Autonomous Database. The default is BRING_YOUR_OWN_LICENSE.
87 88 89 |
# File 'lib/oci/database/models/autonomous_database.rb', line 87 def license_model @license_model end |
#lifecycle_details ⇒ String
Information about the current lifecycle state.
54 55 56 |
# File 'lib/oci/database/models/autonomous_database.rb', line 54 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
[Required] The current state of the database.
50 51 52 |
# File 'lib/oci/database/models/autonomous_database.rb', line 50 def lifecycle_state @lifecycle_state end |
#service_console_url ⇒ String
The URL of the Service Console for the Autonomous Database.
78 79 80 |
# File 'lib/oci/database/models/autonomous_database.rb', line 78 def service_console_url @service_console_url end |
#time_created ⇒ DateTime
The date and time the database was created.
70 71 72 |
# File 'lib/oci/database/models/autonomous_database.rb', line 70 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/oci/database/models/autonomous_database.rb', line 114 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'db_name': :'dbName', 'cpu_core_count': :'cpuCoreCount', 'data_storage_size_in_tbs': :'dataStorageSizeInTBs', 'time_created': :'timeCreated', 'display_name': :'displayName', 'service_console_url': :'serviceConsoleUrl', 'connection_strings': :'connectionStrings', 'license_model': :'licenseModel', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'db_version': :'dbVersion', 'db_workload': :'dbWorkload' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/oci/database/models/autonomous_database.rb', line 138 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'db_name': :'String', 'cpu_core_count': :'Integer', 'data_storage_size_in_tbs': :'Integer', 'time_created': :'DateTime', 'display_name': :'String', 'service_console_url': :'String', 'connection_strings': :'OCI::Database::Models::AutonomousDatabaseConnectionStrings', 'license_model': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'db_version': :'String', 'db_workload': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 |
# File 'lib/oci/database/models/autonomous_database.rb', line 331 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && db_name == other.db_name && cpu_core_count == other.cpu_core_count && data_storage_size_in_tbs == other.data_storage_size_in_tbs && time_created == other.time_created && display_name == other.display_name && service_console_url == other.service_console_url && connection_strings == other.connection_strings && license_model == other.license_model && == other. && == other. && db_version == other.db_version && db_workload == other.db_workload end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 |
# File 'lib/oci/database/models/autonomous_database.rb', line 376 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
356 357 358 |
# File 'lib/oci/database/models/autonomous_database.rb', line 356 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
365 366 367 |
# File 'lib/oci/database/models/autonomous_database.rb', line 365 def hash [id, compartment_id, lifecycle_state, lifecycle_details, db_name, cpu_core_count, data_storage_size_in_tbs, time_created, display_name, service_console_url, connection_strings, license_model, , , db_version, db_workload].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
409 410 411 412 413 414 415 416 417 418 |
# File 'lib/oci/database/models/autonomous_database.rb', line 409 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
403 404 405 |
# File 'lib/oci/database/models/autonomous_database.rb', line 403 def to_s to_hash.to_s end |