Class: OCI::Database::Models::AutonomousDbPreviewVersionSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database/models/autonomous_db_preview_version_summary.rb

Overview

The Autonomous Database preview version. Note that preview version software is only available for databases on [shared Exadata infrastructure](docs.cloud.oracle.com/Content/Database/Concepts/adboverview.htm#AEI).

Constant Summary collapse

DB_WORKLOAD_ENUM =
[
  DB_WORKLOAD_OLTP = 'OLTP'.freeze,
  DB_WORKLOAD_DW = 'DW'.freeze,
  DB_WORKLOAD_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ AutonomousDbPreviewVersionSummary

Initializes the object

Options Hash (attributes):

  • :version (String)

    The value to assign to the #version property

  • :time_preview_begin (DateTime)

    The value to assign to the #time_preview_begin property

  • :time_preview_end (DateTime)

    The value to assign to the #time_preview_end property

  • :db_workload (String)

    The value to assign to the #db_workload property

  • :details (String)

    The value to assign to the #details property

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/oci/database/models/autonomous_db_preview_version_summary.rb', line 79

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.version = attributes[:'version'] if attributes[:'version']

  self.time_preview_begin = attributes[:'timePreviewBegin'] if attributes[:'timePreviewBegin']

  raise 'You cannot provide both :timePreviewBegin and :time_preview_begin' if attributes.key?(:'timePreviewBegin') && attributes.key?(:'time_preview_begin')

  self.time_preview_begin = attributes[:'time_preview_begin'] if attributes[:'time_preview_begin']

  self.time_preview_end = attributes[:'timePreviewEnd'] if attributes[:'timePreviewEnd']

  raise 'You cannot provide both :timePreviewEnd and :time_preview_end' if attributes.key?(:'timePreviewEnd') && attributes.key?(:'time_preview_end')

  self.time_preview_end = attributes[:'time_preview_end'] if attributes[:'time_preview_end']

  self.db_workload = attributes[:'dbWorkload'] if attributes[:'dbWorkload']

  raise 'You cannot provide both :dbWorkload and :db_workload' if attributes.key?(:'dbWorkload') && attributes.key?(:'db_workload')

  self.db_workload = attributes[:'db_workload'] if attributes[:'db_workload']

  self.details = attributes[:'details'] if attributes[:'details']
end

Instance Attribute Details

#db_workloadString

The Autonomous Database workload type. The following values are valid:

  • OLTP - indicates an Autonomous Transaction Processing database

  • DW - indicates an Autonomous Data Warehouse database

Returns:



36
37
38
# File 'lib/oci/database/models/autonomous_db_preview_version_summary.rb', line 36

def db_workload
  @db_workload
end

#detailsString

A URL that points to a detailed description of the preview version.

Returns:



40
41
42
# File 'lib/oci/database/models/autonomous_db_preview_version_summary.rb', line 40

def details
  @details
end

#time_preview_beginDateTime

The date and time when the preview version availability begins.

Returns:



24
25
26
# File 'lib/oci/database/models/autonomous_db_preview_version_summary.rb', line 24

def time_preview_begin
  @time_preview_begin
end

#time_preview_endDateTime

The date and time when the preview version availability ends.

Returns:



28
29
30
# File 'lib/oci/database/models/autonomous_db_preview_version_summary.rb', line 28

def time_preview_end
  @time_preview_end
end

#versionString

[Required] A valid Autonomous Database preview version.

Returns:



20
21
22
# File 'lib/oci/database/models/autonomous_db_preview_version_summary.rb', line 20

def version
  @version
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
# File 'lib/oci/database/models/autonomous_db_preview_version_summary.rb', line 43

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'version': :'version',
    'time_preview_begin': :'timePreviewBegin',
    'time_preview_end': :'timePreviewEnd',
    'db_workload': :'dbWorkload',
    'details': :'details'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



56
57
58
59
60
61
62
63
64
65
66
# File 'lib/oci/database/models/autonomous_db_preview_version_summary.rb', line 56

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'version': :'String',
    'time_preview_begin': :'DateTime',
    'time_preview_end': :'DateTime',
    'db_workload': :'String',
    'details': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • the other object to be compared



128
129
130
131
132
133
134
135
136
137
# File 'lib/oci/database/models/autonomous_db_preview_version_summary.rb', line 128

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    version == other.version &&
    time_preview_begin == other.time_preview_begin &&
    time_preview_end == other.time_preview_end &&
    db_workload == other.db_workload &&
    details == other.details
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/oci/database/models/autonomous_db_preview_version_summary.rb', line 162

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method

Parameters:

  • the other object to be compared

Returns:



142
143
144
# File 'lib/oci/database/models/autonomous_db_preview_version_summary.rb', line 142

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • Hash code



151
152
153
# File 'lib/oci/database/models/autonomous_db_preview_version_summary.rb', line 151

def hash
  [version, time_preview_begin, time_preview_end, db_workload, details].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



195
196
197
198
199
200
201
202
203
204
# File 'lib/oci/database/models/autonomous_db_preview_version_summary.rb', line 195

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



189
190
191
# File 'lib/oci/database/models/autonomous_db_preview_version_summary.rb', line 189

def to_s
  to_hash.to_s
end