Class: OCI::Database::Models::AutonomousVmCluster
- Inherits:
-
Object
- Object
- OCI::Database::Models::AutonomousVmCluster
- Defined in:
- lib/oci/database/models/autonomous_vm_cluster.rb
Overview
Details of the Autonomous VM cluster.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze, LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze, LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_MAINTENANCE_IN_PROGRESS = 'MAINTENANCE_IN_PROGRESS'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LICENSE_MODEL_ENUM =
[ LICENSE_MODEL_LICENSE_INCLUDED = 'LICENSE_INCLUDED'.freeze, LICENSE_MODEL_BRING_YOUR_OWN_LICENSE = 'BRING_YOUR_OWN_LICENSE'.freeze, LICENSE_MODEL_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#available_cpus ⇒ Integer
The numnber of CPU cores available.
-
#available_data_storage_size_in_tbs ⇒ Float
The data storage available in TBs.
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
-
#cpus_enabled ⇒ Integer
The number of enabled CPU cores.
-
#data_storage_size_in_gbs ⇒ Float
The total data storage allocated in GBs.
-
#data_storage_size_in_tbs ⇒ Float
The total data storage allocated in TBs.
-
#db_node_storage_size_in_gbs ⇒ Integer
The local node storage allocated in GBs.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
[Required] The user-friendly name for the Autonomous VM cluster.
-
#exadata_infrastructure_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Exadata infrastructure.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Autonomous VM cluster.
-
#is_local_backup_enabled ⇒ BOOLEAN
If true, database backup on local Exadata storage is configured for the Autonomous VM cluster.
-
#license_model ⇒ String
The Oracle license model that applies to the Autonomous VM cluster.
-
#lifecycle_details ⇒ String
Additional information about the current lifecycle state.
-
#lifecycle_state ⇒ String
[Required] The current state of the Autonomous VM cluster.
-
#memory_size_in_gbs ⇒ Integer
The memory allocated in GBs.
-
#ocpus_enabled ⇒ Float
The number of enabled OCPU cores.
-
#time_created ⇒ DateTime
The date and time that the Autonomous VM cluster was created.
-
#time_zone ⇒ String
The time zone to use for the Autonomous VM cluster.
-
#vm_cluster_network_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VM cluster network.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AutonomousVmCluster
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ AutonomousVmCluster
Initializes the object
206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 |
# File 'lib/oci/database/models/autonomous_vm_cluster.rb', line 206 def initialize(attributes = {}) return unless attributes.is_a?(Hash) self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.time_zone = attributes[:'timeZone'] if attributes[:'timeZone'] raise 'You cannot provide both :timeZone and :time_zone' if attributes.key?(:'timeZone') && attributes.key?(:'time_zone') self.time_zone = attributes[:'time_zone'] if attributes[:'time_zone'] self.exadata_infrastructure_id = attributes[:'exadataInfrastructureId'] if attributes[:'exadataInfrastructureId'] raise 'You cannot provide both :exadataInfrastructureId and :exadata_infrastructure_id' if attributes.key?(:'exadataInfrastructureId') && attributes.key?(:'exadata_infrastructure_id') self.exadata_infrastructure_id = attributes[:'exadata_infrastructure_id'] if attributes[:'exadata_infrastructure_id'] self.vm_cluster_network_id = attributes[:'vmClusterNetworkId'] if attributes[:'vmClusterNetworkId'] raise 'You cannot provide both :vmClusterNetworkId and :vm_cluster_network_id' if attributes.key?(:'vmClusterNetworkId') && attributes.key?(:'vm_cluster_network_id') self.vm_cluster_network_id = attributes[:'vm_cluster_network_id'] if attributes[:'vm_cluster_network_id'] self.is_local_backup_enabled = attributes[:'isLocalBackupEnabled'] unless attributes[:'isLocalBackupEnabled'].nil? raise 'You cannot provide both :isLocalBackupEnabled and :is_local_backup_enabled' if attributes.key?(:'isLocalBackupEnabled') && attributes.key?(:'is_local_backup_enabled') self.is_local_backup_enabled = attributes[:'is_local_backup_enabled'] unless attributes[:'is_local_backup_enabled'].nil? self.cpus_enabled = attributes[:'cpusEnabled'] if attributes[:'cpusEnabled'] raise 'You cannot provide both :cpusEnabled and :cpus_enabled' if attributes.key?(:'cpusEnabled') && attributes.key?(:'cpus_enabled') self.cpus_enabled = attributes[:'cpus_enabled'] if attributes[:'cpus_enabled'] self.ocpus_enabled = attributes[:'ocpusEnabled'] if attributes[:'ocpusEnabled'] raise 'You cannot provide both :ocpusEnabled and :ocpus_enabled' if attributes.key?(:'ocpusEnabled') && attributes.key?(:'ocpus_enabled') self.ocpus_enabled = attributes[:'ocpus_enabled'] if attributes[:'ocpus_enabled'] self.available_cpus = attributes[:'availableCpus'] if attributes[:'availableCpus'] raise 'You cannot provide both :availableCpus and :available_cpus' if attributes.key?(:'availableCpus') && attributes.key?(:'available_cpus') self.available_cpus = attributes[:'available_cpus'] if attributes[:'available_cpus'] self.memory_size_in_gbs = attributes[:'memorySizeInGBs'] if attributes[:'memorySizeInGBs'] raise 'You cannot provide both :memorySizeInGBs and :memory_size_in_gbs' if attributes.key?(:'memorySizeInGBs') && attributes.key?(:'memory_size_in_gbs') self.memory_size_in_gbs = attributes[:'memory_size_in_gbs'] if attributes[:'memory_size_in_gbs'] self.db_node_storage_size_in_gbs = attributes[:'dbNodeStorageSizeInGBs'] if attributes[:'dbNodeStorageSizeInGBs'] raise 'You cannot provide both :dbNodeStorageSizeInGBs and :db_node_storage_size_in_gbs' if attributes.key?(:'dbNodeStorageSizeInGBs') && attributes.key?(:'db_node_storage_size_in_gbs') self.db_node_storage_size_in_gbs = attributes[:'db_node_storage_size_in_gbs'] if attributes[:'db_node_storage_size_in_gbs'] self.data_storage_size_in_tbs = attributes[:'dataStorageSizeInTBs'] if attributes[:'dataStorageSizeInTBs'] raise 'You cannot provide both :dataStorageSizeInTBs and :data_storage_size_in_tbs' if attributes.key?(:'dataStorageSizeInTBs') && attributes.key?(:'data_storage_size_in_tbs') self.data_storage_size_in_tbs = attributes[:'data_storage_size_in_tbs'] if attributes[:'data_storage_size_in_tbs'] self.data_storage_size_in_gbs = attributes[:'dataStorageSizeInGBs'] if attributes[:'dataStorageSizeInGBs'] raise 'You cannot provide both :dataStorageSizeInGBs and :data_storage_size_in_gbs' if attributes.key?(:'dataStorageSizeInGBs') && attributes.key?(:'data_storage_size_in_gbs') self.data_storage_size_in_gbs = attributes[:'data_storage_size_in_gbs'] if attributes[:'data_storage_size_in_gbs'] self.available_data_storage_size_in_tbs = attributes[:'availableDataStorageSizeInTBs'] if attributes[:'availableDataStorageSizeInTBs'] raise 'You cannot provide both :availableDataStorageSizeInTBs and :available_data_storage_size_in_tbs' if attributes.key?(:'availableDataStorageSizeInTBs') && attributes.key?(:'available_data_storage_size_in_tbs') self.available_data_storage_size_in_tbs = attributes[:'available_data_storage_size_in_tbs'] if attributes[:'available_data_storage_size_in_tbs'] self.license_model = attributes[:'licenseModel'] if attributes[:'licenseModel'] raise 'You cannot provide both :licenseModel and :license_model' if attributes.key?(:'licenseModel') && attributes.key?(:'license_model') self.license_model = attributes[:'license_model'] if attributes[:'license_model'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#available_cpus ⇒ Integer
The numnber of CPU cores available.
80 81 82 |
# File 'lib/oci/database/models/autonomous_vm_cluster.rb', line 80 def available_cpus @available_cpus end |
#available_data_storage_size_in_tbs ⇒ Float
The data storage available in TBs
100 101 102 |
# File 'lib/oci/database/models/autonomous_vm_cluster.rb', line 100 def available_data_storage_size_in_tbs @available_data_storage_size_in_tbs end |
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
35 36 37 |
# File 'lib/oci/database/models/autonomous_vm_cluster.rb', line 35 def compartment_id @compartment_id end |
#cpus_enabled ⇒ Integer
The number of enabled CPU cores.
72 73 74 |
# File 'lib/oci/database/models/autonomous_vm_cluster.rb', line 72 def cpus_enabled @cpus_enabled end |
#data_storage_size_in_gbs ⇒ Float
The total data storage allocated in GBs.
96 97 98 |
# File 'lib/oci/database/models/autonomous_vm_cluster.rb', line 96 def data_storage_size_in_gbs @data_storage_size_in_gbs end |
#data_storage_size_in_tbs ⇒ Float
The total data storage allocated in TBs
92 93 94 |
# File 'lib/oci/database/models/autonomous_vm_cluster.rb', line 92 def data_storage_size_in_tbs @data_storage_size_in_tbs end |
#db_node_storage_size_in_gbs ⇒ Integer
The local node storage allocated in GBs.
88 89 90 |
# File 'lib/oci/database/models/autonomous_vm_cluster.rb', line 88 def db_node_storage_size_in_gbs @db_node_storage_size_in_gbs end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
119 120 121 |
# File 'lib/oci/database/models/autonomous_vm_cluster.rb', line 119 def @defined_tags end |
#display_name ⇒ String
[Required] The user-friendly name for the Autonomous VM cluster. The name does not need to be unique.
39 40 41 |
# File 'lib/oci/database/models/autonomous_vm_cluster.rb', line 39 def display_name @display_name end |
#exadata_infrastructure_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Exadata infrastructure.
59 60 61 |
# File 'lib/oci/database/models/autonomous_vm_cluster.rb', line 59 def exadata_infrastructure_id @exadata_infrastructure_id end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
113 114 115 |
# File 'lib/oci/database/models/autonomous_vm_cluster.rb', line 113 def @freeform_tags end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Autonomous VM cluster.
31 32 33 |
# File 'lib/oci/database/models/autonomous_vm_cluster.rb', line 31 def id @id end |
#is_local_backup_enabled ⇒ BOOLEAN
If true, database backup on local Exadata storage is configured for the Autonomous VM cluster. If false, database backup on local Exadata storage is not available in the Autonomous VM cluster.
68 69 70 |
# File 'lib/oci/database/models/autonomous_vm_cluster.rb', line 68 def is_local_backup_enabled @is_local_backup_enabled end |
#license_model ⇒ String
The Oracle license model that applies to the Autonomous VM cluster. The default is LICENSE_INCLUDED.
105 106 107 |
# File 'lib/oci/database/models/autonomous_vm_cluster.rb', line 105 def license_model @license_model end |
#lifecycle_details ⇒ String
Additional information about the current lifecycle state.
51 52 53 |
# File 'lib/oci/database/models/autonomous_vm_cluster.rb', line 51 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
[Required] The current state of the Autonomous VM cluster.
47 48 49 |
# File 'lib/oci/database/models/autonomous_vm_cluster.rb', line 47 def lifecycle_state @lifecycle_state end |
#memory_size_in_gbs ⇒ Integer
The memory allocated in GBs.
84 85 86 |
# File 'lib/oci/database/models/autonomous_vm_cluster.rb', line 84 def memory_size_in_gbs @memory_size_in_gbs end |
#ocpus_enabled ⇒ Float
The number of enabled OCPU cores.
76 77 78 |
# File 'lib/oci/database/models/autonomous_vm_cluster.rb', line 76 def ocpus_enabled @ocpus_enabled end |
#time_created ⇒ DateTime
The date and time that the Autonomous VM cluster was created.
43 44 45 |
# File 'lib/oci/database/models/autonomous_vm_cluster.rb', line 43 def time_created @time_created end |
#time_zone ⇒ String
The time zone to use for the Autonomous VM cluster. For details, see [DB System Time Zones](docs.cloud.oracle.com/Content/Database/References/timezones.htm).
55 56 57 |
# File 'lib/oci/database/models/autonomous_vm_cluster.rb', line 55 def time_zone @time_zone end |
#vm_cluster_network_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VM cluster network.
63 64 65 |
# File 'lib/oci/database/models/autonomous_vm_cluster.rb', line 63 def vm_cluster_network_id @vm_cluster_network_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/oci/database/models/autonomous_vm_cluster.rb', line 122 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'time_created': :'timeCreated', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'time_zone': :'timeZone', 'exadata_infrastructure_id': :'exadataInfrastructureId', 'vm_cluster_network_id': :'vmClusterNetworkId', 'is_local_backup_enabled': :'isLocalBackupEnabled', 'cpus_enabled': :'cpusEnabled', 'ocpus_enabled': :'ocpusEnabled', 'available_cpus': :'availableCpus', 'memory_size_in_gbs': :'memorySizeInGBs', 'db_node_storage_size_in_gbs': :'dbNodeStorageSizeInGBs', 'data_storage_size_in_tbs': :'dataStorageSizeInTBs', 'data_storage_size_in_gbs': :'dataStorageSizeInGBs', 'available_data_storage_size_in_tbs': :'availableDataStorageSizeInTBs', 'license_model': :'licenseModel', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/oci/database/models/autonomous_vm_cluster.rb', line 151 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'display_name': :'String', 'time_created': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'time_zone': :'String', 'exadata_infrastructure_id': :'String', 'vm_cluster_network_id': :'String', 'is_local_backup_enabled': :'BOOLEAN', 'cpus_enabled': :'Integer', 'ocpus_enabled': :'Float', 'available_cpus': :'Integer', 'memory_size_in_gbs': :'Integer', 'db_node_storage_size_in_gbs': :'Integer', 'data_storage_size_in_tbs': :'Float', 'data_storage_size_in_gbs': :'Float', 'available_data_storage_size_in_tbs': :'Float', 'license_model': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 |
# File 'lib/oci/database/models/autonomous_vm_cluster.rb', line 365 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && display_name == other.display_name && time_created == other.time_created && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && time_zone == other.time_zone && exadata_infrastructure_id == other.exadata_infrastructure_id && vm_cluster_network_id == other.vm_cluster_network_id && is_local_backup_enabled == other.is_local_backup_enabled && cpus_enabled == other.cpus_enabled && ocpus_enabled == other.ocpus_enabled && available_cpus == other.available_cpus && memory_size_in_gbs == other.memory_size_in_gbs && db_node_storage_size_in_gbs == other.db_node_storage_size_in_gbs && data_storage_size_in_tbs == other.data_storage_size_in_tbs && data_storage_size_in_gbs == other.data_storage_size_in_gbs && available_data_storage_size_in_tbs == other.available_data_storage_size_in_tbs && license_model == other.license_model && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 |
# File 'lib/oci/database/models/autonomous_vm_cluster.rb', line 415 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
395 396 397 |
# File 'lib/oci/database/models/autonomous_vm_cluster.rb', line 395 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
404 405 406 |
# File 'lib/oci/database/models/autonomous_vm_cluster.rb', line 404 def hash [id, compartment_id, display_name, time_created, lifecycle_state, lifecycle_details, time_zone, exadata_infrastructure_id, vm_cluster_network_id, is_local_backup_enabled, cpus_enabled, ocpus_enabled, available_cpus, memory_size_in_gbs, db_node_storage_size_in_gbs, data_storage_size_in_tbs, data_storage_size_in_gbs, available_data_storage_size_in_tbs, license_model, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
448 449 450 451 452 453 454 455 456 457 |
# File 'lib/oci/database/models/autonomous_vm_cluster.rb', line 448 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
442 443 444 |
# File 'lib/oci/database/models/autonomous_vm_cluster.rb', line 442 def to_s to_hash.to_s end |