Class: OCI::Database::Models::BackupSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database/models/backup_summary.rb

Overview

A database backup. To use any of the API operations, you must be authorized in an IAM policy. If you're not authorized, talk to an administrator. If you're an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm).

*Warning:* Oracle recommends that you avoid using any confidential information when you supply string values using the API.

Constant Summary collapse

TYPE_ENUM =
[
  TYPE_INCREMENTAL = 'INCREMENTAL'.freeze,
  TYPE_FULL = 'FULL'.freeze,
  TYPE_VIRTUAL_FULL = 'VIRTUAL_FULL'.freeze,
  TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_RESTORING = 'RESTORING'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
DATABASE_EDITION_ENUM =
[
  DATABASE_EDITION_STANDARD_EDITION = 'STANDARD_EDITION'.freeze,
  DATABASE_EDITION_ENTERPRISE_EDITION = 'ENTERPRISE_EDITION'.freeze,
  DATABASE_EDITION_ENTERPRISE_EDITION_HIGH_PERFORMANCE = 'ENTERPRISE_EDITION_HIGH_PERFORMANCE'.freeze,
  DATABASE_EDITION_ENTERPRISE_EDITION_EXTREME_PERFORMANCE = 'ENTERPRISE_EDITION_EXTREME_PERFORMANCE'.freeze,
  DATABASE_EDITION_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ BackupSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :database_id (String)

    The value to assign to the #database_id property

  • :display_name (String)

    The value to assign to the #display_name property

  • :type (String)

    The value to assign to the #type property

  • :time_started (DateTime)

    The value to assign to the #time_started property

  • :time_ended (DateTime)

    The value to assign to the #time_ended property

  • :lifecycle_details (String)

    The value to assign to the #lifecycle_details property

  • :availability_domain (String)

    The value to assign to the #availability_domain property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :database_edition (String)

    The value to assign to the #database_edition property

  • :database_size_in_gbs (Float)

    The value to assign to the #database_size_in_gbs property

  • :shape (String)

    The value to assign to the #shape property

  • :version (String)

    The value to assign to the #version property

  • :kms_key_id (String)

    The value to assign to the #kms_key_id property

  • :kms_key_version_id (String)

    The value to assign to the #kms_key_version_id property

  • :vault_id (String)

    The value to assign to the #vault_id property



184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/oci/database/models/backup_summary.rb', line 184

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.database_id = attributes[:'databaseId'] if attributes[:'databaseId']

  raise 'You cannot provide both :databaseId and :database_id' if attributes.key?(:'databaseId') && attributes.key?(:'database_id')

  self.database_id = attributes[:'database_id'] if attributes[:'database_id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.type = attributes[:'type'] if attributes[:'type']

  self.time_started = attributes[:'timeStarted'] if attributes[:'timeStarted']

  raise 'You cannot provide both :timeStarted and :time_started' if attributes.key?(:'timeStarted') && attributes.key?(:'time_started')

  self.time_started = attributes[:'time_started'] if attributes[:'time_started']

  self.time_ended = attributes[:'timeEnded'] if attributes[:'timeEnded']

  raise 'You cannot provide both :timeEnded and :time_ended' if attributes.key?(:'timeEnded') && attributes.key?(:'time_ended')

  self.time_ended = attributes[:'time_ended'] if attributes[:'time_ended']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain']

  raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain')

  self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.database_edition = attributes[:'databaseEdition'] if attributes[:'databaseEdition']

  raise 'You cannot provide both :databaseEdition and :database_edition' if attributes.key?(:'databaseEdition') && attributes.key?(:'database_edition')

  self.database_edition = attributes[:'database_edition'] if attributes[:'database_edition']

  self.database_size_in_gbs = attributes[:'databaseSizeInGBs'] if attributes[:'databaseSizeInGBs']

  raise 'You cannot provide both :databaseSizeInGBs and :database_size_in_gbs' if attributes.key?(:'databaseSizeInGBs') && attributes.key?(:'database_size_in_gbs')

  self.database_size_in_gbs = attributes[:'database_size_in_gbs'] if attributes[:'database_size_in_gbs']

  self.shape = attributes[:'shape'] if attributes[:'shape']

  self.version = attributes[:'version'] if attributes[:'version']

  self.kms_key_id = attributes[:'kmsKeyId'] if attributes[:'kmsKeyId']

  raise 'You cannot provide both :kmsKeyId and :kms_key_id' if attributes.key?(:'kmsKeyId') && attributes.key?(:'kms_key_id')

  self.kms_key_id = attributes[:'kms_key_id'] if attributes[:'kms_key_id']

  self.kms_key_version_id = attributes[:'kmsKeyVersionId'] if attributes[:'kmsKeyVersionId']

  raise 'You cannot provide both :kmsKeyVersionId and :kms_key_version_id' if attributes.key?(:'kmsKeyVersionId') && attributes.key?(:'kms_key_version_id')

  self.kms_key_version_id = attributes[:'kms_key_version_id'] if attributes[:'kms_key_version_id']

  self.vault_id = attributes[:'vaultId'] if attributes[:'vaultId']

  raise 'You cannot provide both :vaultId and :vault_id' if attributes.key?(:'vaultId') && attributes.key?(:'vault_id')

  self.vault_id = attributes[:'vault_id'] if attributes[:'vault_id']
end

Instance Attribute Details

#availability_domainString

The name of the availability domain where the database backup is stored.

Returns:

  • (String)


74
75
76
# File 'lib/oci/database/models/backup_summary.rb', line 74

def availability_domain
  @availability_domain
end

#compartment_idString

Returns:

  • (String)


46
47
48
# File 'lib/oci/database/models/backup_summary.rb', line 46

def compartment_id
  @compartment_id
end

#database_editionString

The Oracle Database edition of the DB system from which the database backup was taken.

Returns:

  • (String)


83
84
85
# File 'lib/oci/database/models/backup_summary.rb', line 83

def database_edition
  @database_edition
end

#database_idString

Returns:

  • (String)


50
51
52
# File 'lib/oci/database/models/backup_summary.rb', line 50

def database_id
  @database_id
end

#database_size_in_gbsFloat

The size of the database in gigabytes at the time the backup was taken.

Returns:

  • (Float)


88
89
90
# File 'lib/oci/database/models/backup_summary.rb', line 88

def database_size_in_gbs
  @database_size_in_gbs
end

#display_nameString

The user-friendly name for the backup. The name does not have to be unique.

Returns:

  • (String)


54
55
56
# File 'lib/oci/database/models/backup_summary.rb', line 54

def display_name
  @display_name
end

#idString

Returns:

  • (String)


42
43
44
# File 'lib/oci/database/models/backup_summary.rb', line 42

def id
  @id
end

#kms_key_idString

The OCID of the key container that is used as the master encryption key in database transparent data encryption (TDE) operations.

Returns:

  • (String)


100
101
102
# File 'lib/oci/database/models/backup_summary.rb', line 100

def kms_key_id
  @kms_key_id
end

#kms_key_version_idString

The OCID of the key container version that is used in database transparent data encryption (TDE) operations KMS Key can have multiple key versions. If none is specified, the current key version (latest) of the Key Id is used for the operation.

Returns:

  • (String)


105
106
107
# File 'lib/oci/database/models/backup_summary.rb', line 105

def kms_key_version_id
  @kms_key_version_id
end

#lifecycle_detailsString

Additional information about the current lifecycle state.

Returns:

  • (String)


70
71
72
# File 'lib/oci/database/models/backup_summary.rb', line 70

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

The current state of the backup.

Returns:

  • (String)


78
79
80
# File 'lib/oci/database/models/backup_summary.rb', line 78

def lifecycle_state
  @lifecycle_state
end

#shapeString

Shape of the backup's source database.

Returns:

  • (String)


92
93
94
# File 'lib/oci/database/models/backup_summary.rb', line 92

def shape
  @shape
end

#time_endedDateTime

The date and time the backup was completed.

Returns:

  • (DateTime)


66
67
68
# File 'lib/oci/database/models/backup_summary.rb', line 66

def time_ended
  @time_ended
end

#time_startedDateTime

The date and time the backup started.

Returns:

  • (DateTime)


62
63
64
# File 'lib/oci/database/models/backup_summary.rb', line 62

def time_started
  @time_started
end

#typeString

The type of backup.

Returns:

  • (String)


58
59
60
# File 'lib/oci/database/models/backup_summary.rb', line 58

def type
  @type
end

#vault_idString

Returns:

  • (String)


109
110
111
# File 'lib/oci/database/models/backup_summary.rb', line 109

def vault_id
  @vault_id
end

#versionString

Version of the backup's source database

Returns:

  • (String)


96
97
98
# File 'lib/oci/database/models/backup_summary.rb', line 96

def version
  @version
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/oci/database/models/backup_summary.rb', line 112

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'compartment_id': :'compartmentId',
    'database_id': :'databaseId',
    'display_name': :'displayName',
    'type': :'type',
    'time_started': :'timeStarted',
    'time_ended': :'timeEnded',
    'lifecycle_details': :'lifecycleDetails',
    'availability_domain': :'availabilityDomain',
    'lifecycle_state': :'lifecycleState',
    'database_edition': :'databaseEdition',
    'database_size_in_gbs': :'databaseSizeInGBs',
    'shape': :'shape',
    'version': :'version',
    'kms_key_id': :'kmsKeyId',
    'kms_key_version_id': :'kmsKeyVersionId',
    'vault_id': :'vaultId'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/oci/database/models/backup_summary.rb', line 137

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'compartment_id': :'String',
    'database_id': :'String',
    'display_name': :'String',
    'type': :'String',
    'time_started': :'DateTime',
    'time_ended': :'DateTime',
    'lifecycle_details': :'String',
    'availability_domain': :'String',
    'lifecycle_state': :'String',
    'database_edition': :'String',
    'database_size_in_gbs': :'Float',
    'shape': :'String',
    'version': :'String',
    'kms_key_id': :'String',
    'kms_key_version_id': :'String',
    'vault_id': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/oci/database/models/backup_summary.rb', line 323

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    database_id == other.database_id &&
    display_name == other.display_name &&
    type == other.type &&
    time_started == other.time_started &&
    time_ended == other.time_ended &&
    lifecycle_details == other.lifecycle_details &&
    availability_domain == other.availability_domain &&
    lifecycle_state == other.lifecycle_state &&
    database_edition == other.database_edition &&
    database_size_in_gbs == other.database_size_in_gbs &&
    shape == other.shape &&
    version == other.version &&
    kms_key_id == other.kms_key_id &&
    kms_key_version_id == other.kms_key_version_id &&
    vault_id == other.vault_id
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/oci/database/models/backup_summary.rb', line 369

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


349
350
351
# File 'lib/oci/database/models/backup_summary.rb', line 349

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



358
359
360
# File 'lib/oci/database/models/backup_summary.rb', line 358

def hash
  [id, compartment_id, database_id, display_name, type, time_started, time_ended, lifecycle_details, availability_domain, lifecycle_state, database_edition, database_size_in_gbs, shape, version, kms_key_id, kms_key_version_id, vault_id].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



402
403
404
405
406
407
408
409
410
411
# File 'lib/oci/database/models/backup_summary.rb', line 402

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



396
397
398
# File 'lib/oci/database/models/backup_summary.rb', line 396

def to_s
  to_hash.to_s
end