Class: OCI::Database::Models::CreateAutonomousDatabaseBase

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database/models/create_autonomous_database_base.rb

Overview

Details to create an Oracle Autonomous Database.

Notes:

  • To specify OCPU core count, you must use either ocpuCount or cpuCoreCount. You cannot use both parameters at the same time.
  • To specify a storage allocation, you must use either dataStorageSizeInGBs or dataStorageSizeInTBs.
  • See the individual parameter discriptions for more information on the OCPU and storage value parameters.

Warning: Oracle recommends that you avoid using any confidential information when you supply string values using the API.

This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class

Constant Summary collapse

DB_WORKLOAD_ENUM =
[
  DB_WORKLOAD_OLTP = 'OLTP'.freeze,
  DB_WORKLOAD_DW = 'DW'.freeze,
  DB_WORKLOAD_AJD = 'AJD'.freeze,
  DB_WORKLOAD_APEX = 'APEX'.freeze
].freeze
LICENSE_MODEL_ENUM =
[
  LICENSE_MODEL_LICENSE_INCLUDED = 'LICENSE_INCLUDED'.freeze,
  LICENSE_MODEL_BRING_YOUR_OWN_LICENSE = 'BRING_YOUR_OWN_LICENSE'.freeze
].freeze
SOURCE_ENUM =
[
  SOURCE_NONE = 'NONE'.freeze,
  SOURCE_DATABASE = 'DATABASE'.freeze,
  SOURCE_BACKUP_FROM_ID = 'BACKUP_FROM_ID'.freeze,
  SOURCE_BACKUP_FROM_TIMESTAMP = 'BACKUP_FROM_TIMESTAMP'.freeze,
  SOURCE_CLONE_TO_REFRESHABLE = 'CLONE_TO_REFRESHABLE'.freeze,
  SOURCE_CROSS_REGION_DATAGUARD = 'CROSS_REGION_DATAGUARD'.freeze
].freeze
AUTONOMOUS_MAINTENANCE_SCHEDULE_TYPE_ENUM =
[
  AUTONOMOUS_MAINTENANCE_SCHEDULE_TYPE_EARLY = 'EARLY'.freeze,
  AUTONOMOUS_MAINTENANCE_SCHEDULE_TYPE_REGULAR = 'REGULAR'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateAutonomousDatabaseBase

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 461

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.character_set = attributes[:'characterSet'] if attributes[:'characterSet']

  raise 'You cannot provide both :characterSet and :character_set' if attributes.key?(:'characterSet') && attributes.key?(:'character_set')

  self.character_set = attributes[:'character_set'] if attributes[:'character_set']

  self.ncharacter_set = attributes[:'ncharacterSet'] if attributes[:'ncharacterSet']

  raise 'You cannot provide both :ncharacterSet and :ncharacter_set' if attributes.key?(:'ncharacterSet') && attributes.key?(:'ncharacter_set')

  self.ncharacter_set = attributes[:'ncharacter_set'] if attributes[:'ncharacter_set']

  self.db_name = attributes[:'dbName'] if attributes[:'dbName']

  raise 'You cannot provide both :dbName and :db_name' if attributes.key?(:'dbName') && attributes.key?(:'db_name')

  self.db_name = attributes[:'db_name'] if attributes[:'db_name']

  self.cpu_core_count = attributes[:'cpuCoreCount'] if attributes[:'cpuCoreCount']

  raise 'You cannot provide both :cpuCoreCount and :cpu_core_count' if attributes.key?(:'cpuCoreCount') && attributes.key?(:'cpu_core_count')

  self.cpu_core_count = attributes[:'cpu_core_count'] if attributes[:'cpu_core_count']

  self.ocpu_count = attributes[:'ocpuCount'] if attributes[:'ocpuCount']

  raise 'You cannot provide both :ocpuCount and :ocpu_count' if attributes.key?(:'ocpuCount') && attributes.key?(:'ocpu_count')

  self.ocpu_count = attributes[:'ocpu_count'] if attributes[:'ocpu_count']

  self.db_workload = attributes[:'dbWorkload'] if attributes[:'dbWorkload']

  raise 'You cannot provide both :dbWorkload and :db_workload' if attributes.key?(:'dbWorkload') && attributes.key?(:'db_workload')

  self.db_workload = attributes[:'db_workload'] if attributes[:'db_workload']

  self.data_storage_size_in_tbs = attributes[:'dataStorageSizeInTBs'] if attributes[:'dataStorageSizeInTBs']

  raise 'You cannot provide both :dataStorageSizeInTBs and :data_storage_size_in_tbs' if attributes.key?(:'dataStorageSizeInTBs') && attributes.key?(:'data_storage_size_in_tbs')

  self.data_storage_size_in_tbs = attributes[:'data_storage_size_in_tbs'] if attributes[:'data_storage_size_in_tbs']

  self.data_storage_size_in_gbs = attributes[:'dataStorageSizeInGBs'] if attributes[:'dataStorageSizeInGBs']

  raise 'You cannot provide both :dataStorageSizeInGBs and :data_storage_size_in_gbs' if attributes.key?(:'dataStorageSizeInGBs') && attributes.key?(:'data_storage_size_in_gbs')

  self.data_storage_size_in_gbs = attributes[:'data_storage_size_in_gbs'] if attributes[:'data_storage_size_in_gbs']

  self.is_free_tier = attributes[:'isFreeTier'] unless attributes[:'isFreeTier'].nil?
  self.is_free_tier = false if is_free_tier.nil? && !attributes.key?(:'isFreeTier') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isFreeTier and :is_free_tier' if attributes.key?(:'isFreeTier') && attributes.key?(:'is_free_tier')

  self.is_free_tier = attributes[:'is_free_tier'] unless attributes[:'is_free_tier'].nil?
  self.is_free_tier = false if is_free_tier.nil? && !attributes.key?(:'isFreeTier') && !attributes.key?(:'is_free_tier') # rubocop:disable Style/StringLiterals

  self.kms_key_id = attributes[:'kmsKeyId'] if attributes[:'kmsKeyId']

  raise 'You cannot provide both :kmsKeyId and :kms_key_id' if attributes.key?(:'kmsKeyId') && attributes.key?(:'kms_key_id')

  self.kms_key_id = attributes[:'kms_key_id'] if attributes[:'kms_key_id']

  self.vault_id = attributes[:'vaultId'] if attributes[:'vaultId']

  raise 'You cannot provide both :vaultId and :vault_id' if attributes.key?(:'vaultId') && attributes.key?(:'vault_id')

  self.vault_id = attributes[:'vault_id'] if attributes[:'vault_id']

  self.admin_password = attributes[:'adminPassword'] if attributes[:'adminPassword']

  raise 'You cannot provide both :adminPassword and :admin_password' if attributes.key?(:'adminPassword') && attributes.key?(:'admin_password')

  self.admin_password = attributes[:'admin_password'] if attributes[:'admin_password']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.license_model = attributes[:'licenseModel'] if attributes[:'licenseModel']

  raise 'You cannot provide both :licenseModel and :license_model' if attributes.key?(:'licenseModel') && attributes.key?(:'license_model')

  self.license_model = attributes[:'license_model'] if attributes[:'license_model']

  self.is_preview_version_with_service_terms_accepted = attributes[:'isPreviewVersionWithServiceTermsAccepted'] unless attributes[:'isPreviewVersionWithServiceTermsAccepted'].nil?
  self.is_preview_version_with_service_terms_accepted = false if is_preview_version_with_service_terms_accepted.nil? && !attributes.key?(:'isPreviewVersionWithServiceTermsAccepted') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isPreviewVersionWithServiceTermsAccepted and :is_preview_version_with_service_terms_accepted' if attributes.key?(:'isPreviewVersionWithServiceTermsAccepted') && attributes.key?(:'is_preview_version_with_service_terms_accepted')

  self.is_preview_version_with_service_terms_accepted = attributes[:'is_preview_version_with_service_terms_accepted'] unless attributes[:'is_preview_version_with_service_terms_accepted'].nil?
  self.is_preview_version_with_service_terms_accepted = false if is_preview_version_with_service_terms_accepted.nil? && !attributes.key?(:'isPreviewVersionWithServiceTermsAccepted') && !attributes.key?(:'is_preview_version_with_service_terms_accepted') # rubocop:disable Style/StringLiterals

  self.is_auto_scaling_enabled = attributes[:'isAutoScalingEnabled'] unless attributes[:'isAutoScalingEnabled'].nil?
  self.is_auto_scaling_enabled = false if is_auto_scaling_enabled.nil? && !attributes.key?(:'isAutoScalingEnabled') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isAutoScalingEnabled and :is_auto_scaling_enabled' if attributes.key?(:'isAutoScalingEnabled') && attributes.key?(:'is_auto_scaling_enabled')

  self.is_auto_scaling_enabled = attributes[:'is_auto_scaling_enabled'] unless attributes[:'is_auto_scaling_enabled'].nil?
  self.is_auto_scaling_enabled = false if is_auto_scaling_enabled.nil? && !attributes.key?(:'isAutoScalingEnabled') && !attributes.key?(:'is_auto_scaling_enabled') # rubocop:disable Style/StringLiterals

  self.is_dedicated = attributes[:'isDedicated'] unless attributes[:'isDedicated'].nil?

  raise 'You cannot provide both :isDedicated and :is_dedicated' if attributes.key?(:'isDedicated') && attributes.key?(:'is_dedicated')

  self.is_dedicated = attributes[:'is_dedicated'] unless attributes[:'is_dedicated'].nil?

  self.autonomous_container_database_id = attributes[:'autonomousContainerDatabaseId'] if attributes[:'autonomousContainerDatabaseId']

  raise 'You cannot provide both :autonomousContainerDatabaseId and :autonomous_container_database_id' if attributes.key?(:'autonomousContainerDatabaseId') && attributes.key?(:'autonomous_container_database_id')

  self.autonomous_container_database_id = attributes[:'autonomous_container_database_id'] if attributes[:'autonomous_container_database_id']

  self.is_access_control_enabled = attributes[:'isAccessControlEnabled'] unless attributes[:'isAccessControlEnabled'].nil?

  raise 'You cannot provide both :isAccessControlEnabled and :is_access_control_enabled' if attributes.key?(:'isAccessControlEnabled') && attributes.key?(:'is_access_control_enabled')

  self.is_access_control_enabled = attributes[:'is_access_control_enabled'] unless attributes[:'is_access_control_enabled'].nil?

  self.whitelisted_ips = attributes[:'whitelistedIps'] if attributes[:'whitelistedIps']

  raise 'You cannot provide both :whitelistedIps and :whitelisted_ips' if attributes.key?(:'whitelistedIps') && attributes.key?(:'whitelisted_ips')

  self.whitelisted_ips = attributes[:'whitelisted_ips'] if attributes[:'whitelisted_ips']

  self.are_primary_whitelisted_ips_used = attributes[:'arePrimaryWhitelistedIpsUsed'] unless attributes[:'arePrimaryWhitelistedIpsUsed'].nil?

  raise 'You cannot provide both :arePrimaryWhitelistedIpsUsed and :are_primary_whitelisted_ips_used' if attributes.key?(:'arePrimaryWhitelistedIpsUsed') && attributes.key?(:'are_primary_whitelisted_ips_used')

  self.are_primary_whitelisted_ips_used = attributes[:'are_primary_whitelisted_ips_used'] unless attributes[:'are_primary_whitelisted_ips_used'].nil?

  self.standby_whitelisted_ips = attributes[:'standbyWhitelistedIps'] if attributes[:'standbyWhitelistedIps']

  raise 'You cannot provide both :standbyWhitelistedIps and :standby_whitelisted_ips' if attributes.key?(:'standbyWhitelistedIps') && attributes.key?(:'standby_whitelisted_ips')

  self.standby_whitelisted_ips = attributes[:'standby_whitelisted_ips'] if attributes[:'standby_whitelisted_ips']

  self.is_data_guard_enabled = attributes[:'isDataGuardEnabled'] unless attributes[:'isDataGuardEnabled'].nil?

  raise 'You cannot provide both :isDataGuardEnabled and :is_data_guard_enabled' if attributes.key?(:'isDataGuardEnabled') && attributes.key?(:'is_data_guard_enabled')

  self.is_data_guard_enabled = attributes[:'is_data_guard_enabled'] unless attributes[:'is_data_guard_enabled'].nil?

  self.is_local_data_guard_enabled = attributes[:'isLocalDataGuardEnabled'] unless attributes[:'isLocalDataGuardEnabled'].nil?

  raise 'You cannot provide both :isLocalDataGuardEnabled and :is_local_data_guard_enabled' if attributes.key?(:'isLocalDataGuardEnabled') && attributes.key?(:'is_local_data_guard_enabled')

  self.is_local_data_guard_enabled = attributes[:'is_local_data_guard_enabled'] unless attributes[:'is_local_data_guard_enabled'].nil?

  self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId']

  raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id')

  self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id']

  self.nsg_ids = attributes[:'nsgIds'] if attributes[:'nsgIds']

  raise 'You cannot provide both :nsgIds and :nsg_ids' if attributes.key?(:'nsgIds') && attributes.key?(:'nsg_ids')

  self.nsg_ids = attributes[:'nsg_ids'] if attributes[:'nsg_ids']

  self.private_endpoint_label = attributes[:'privateEndpointLabel'] if attributes[:'privateEndpointLabel']

  raise 'You cannot provide both :privateEndpointLabel and :private_endpoint_label' if attributes.key?(:'privateEndpointLabel') && attributes.key?(:'private_endpoint_label')

  self.private_endpoint_label = attributes[:'private_endpoint_label'] if attributes[:'private_endpoint_label']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.db_version = attributes[:'dbVersion'] if attributes[:'dbVersion']

  raise 'You cannot provide both :dbVersion and :db_version' if attributes.key?(:'dbVersion') && attributes.key?(:'db_version')

  self.db_version = attributes[:'db_version'] if attributes[:'db_version']

  self.source = attributes[:'source'] if attributes[:'source']
  self.source = "NONE" if source.nil? && !attributes.key?(:'source') # rubocop:disable Style/StringLiterals

  self.customer_contacts = attributes[:'customerContacts'] if attributes[:'customerContacts']

  raise 'You cannot provide both :customerContacts and :customer_contacts' if attributes.key?(:'customerContacts') && attributes.key?(:'customer_contacts')

  self.customer_contacts = attributes[:'customer_contacts'] if attributes[:'customer_contacts']

  self.is_mtls_connection_required = attributes[:'isMtlsConnectionRequired'] unless attributes[:'isMtlsConnectionRequired'].nil?
  self.is_mtls_connection_required = true if is_mtls_connection_required.nil? && !attributes.key?(:'isMtlsConnectionRequired') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isMtlsConnectionRequired and :is_mtls_connection_required' if attributes.key?(:'isMtlsConnectionRequired') && attributes.key?(:'is_mtls_connection_required')

  self.is_mtls_connection_required = attributes[:'is_mtls_connection_required'] unless attributes[:'is_mtls_connection_required'].nil?
  self.is_mtls_connection_required = true if is_mtls_connection_required.nil? && !attributes.key?(:'isMtlsConnectionRequired') && !attributes.key?(:'is_mtls_connection_required') # rubocop:disable Style/StringLiterals

  self.autonomous_maintenance_schedule_type = attributes[:'autonomousMaintenanceScheduleType'] if attributes[:'autonomousMaintenanceScheduleType']

  raise 'You cannot provide both :autonomousMaintenanceScheduleType and :autonomous_maintenance_schedule_type' if attributes.key?(:'autonomousMaintenanceScheduleType') && attributes.key?(:'autonomous_maintenance_schedule_type')

  self.autonomous_maintenance_schedule_type = attributes[:'autonomous_maintenance_schedule_type'] if attributes[:'autonomous_maintenance_schedule_type']

  self.scheduled_operations = attributes[:'scheduledOperations'] if attributes[:'scheduledOperations']

  raise 'You cannot provide both :scheduledOperations and :scheduled_operations' if attributes.key?(:'scheduledOperations') && attributes.key?(:'scheduled_operations')

  self.scheduled_operations = attributes[:'scheduled_operations'] if attributes[:'scheduled_operations']

  self.is_auto_scaling_for_storage_enabled = attributes[:'isAutoScalingForStorageEnabled'] unless attributes[:'isAutoScalingForStorageEnabled'].nil?

  raise 'You cannot provide both :isAutoScalingForStorageEnabled and :is_auto_scaling_for_storage_enabled' if attributes.key?(:'isAutoScalingForStorageEnabled') && attributes.key?(:'is_auto_scaling_for_storage_enabled')

  self.is_auto_scaling_for_storage_enabled = attributes[:'is_auto_scaling_for_storage_enabled'] unless attributes[:'is_auto_scaling_for_storage_enabled'].nil?

  self.max_cpu_core_count = attributes[:'maxCpuCoreCount'] if attributes[:'maxCpuCoreCount']

  raise 'You cannot provide both :maxCpuCoreCount and :max_cpu_core_count' if attributes.key?(:'maxCpuCoreCount') && attributes.key?(:'max_cpu_core_count')

  self.max_cpu_core_count = attributes[:'max_cpu_core_count'] if attributes[:'max_cpu_core_count']

  self.database_edition = attributes[:'databaseEdition'] if attributes[:'databaseEdition']

  raise 'You cannot provide both :databaseEdition and :database_edition' if attributes.key?(:'databaseEdition') && attributes.key?(:'database_edition')

  self.database_edition = attributes[:'database_edition'] if attributes[:'database_edition']
end

Instance Attribute Details

#admin_passwordString

Important The adminPassword must be specified for all Autonomous Databases except for refreshable clones. The password must be between 12 and 30 characters long, and must contain at least 1 uppercase, 1 lowercase, and 1 numeric character. It cannot contain the double quote symbol (") or the username "admin", regardless of casing.

Returns:

  • (String)


131
132
133
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 131

def admin_password
  @admin_password
end

#are_primary_whitelisted_ips_usedBOOLEAN

This field will be null if the Autonomous Database is not Data Guard enabled or Access Control is disabled. It's value would be TRUE if Autonomous Database is Data Guard enabled and Access Control is enabled and if the Autonomous Database uses primary IP access control list (ACL) for standby. It's value would be FALSE if Autonomous Database is Data Guard enabled and Access Control is enabled and if the Autonomous Database uses different IP access control list (ACL) for standby compared to primary.

Returns:

  • (BOOLEAN)


194
195
196
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 194

def are_primary_whitelisted_ips_used
  @are_primary_whitelisted_ips_used
end

#autonomous_container_database_idString

The Autonomous Container Database OCID.

Returns:

  • (String)


162
163
164
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 162

def autonomous_container_database_id
  @autonomous_container_database_id
end

#autonomous_maintenance_schedule_typeString

The maintenance schedule type of the Autonomous Database on shared Exadata infrastructure. The EARLY maintenance schedule of this Autonomous Database follows a schedule that applies patches prior to the REGULAR schedule.The REGULAR maintenance schedule of this Autonomous Database follows the normal cycle.

Returns:

  • (String)


281
282
283
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 281

def autonomous_maintenance_schedule_type
  @autonomous_maintenance_schedule_type
end

#character_setString

The character set for the autonomous database. The default is AL32UTF8. Allowed values for an Autonomous Database on shared infrastructure as as returned by List Autonomous Database Character Sets

For an Autonomous Database on dedicated infrastructure, the allowed values are:

AL32UTF8, AR8ADOS710, AR8ADOS720, AR8APTEC715, AR8ARABICMACS, AR8ASMO8X, AR8ISO8859P6, AR8MSWIN1256, AR8MUSSAD768, AR8NAFITHA711, AR8NAFITHA721, AR8SAKHR706, AR8SAKHR707, AZ8ISO8859P9E, BG8MSWIN, BG8PC437S, BLT8CP921, BLT8ISO8859P13, BLT8MSWIN1257, BLT8PC775, BN8BSCII, CDN8PC863, CEL8ISO8859P14, CL8ISO8859P5, CL8ISOIR111, CL8KOI8R, CL8KOI8U, CL8MACCYRILLICS, CL8MSWIN1251, EE8ISO8859P2, EE8MACCES, EE8MACCROATIANS, EE8MSWIN1250, EE8PC852, EL8DEC, EL8ISO8859P7, EL8MACGREEKS, EL8MSWIN1253, EL8PC437S, EL8PC851, EL8PC869, ET8MSWIN923, HU8ABMOD, HU8CWI2, IN8ISCII, IS8PC861, IW8ISO8859P8, IW8MACHEBREWS, IW8MSWIN1255, IW8PC1507, JA16EUC, JA16EUCTILDE, JA16SJIS, JA16SJISTILDE, JA16VMS, KO16KSC5601, KO16KSCCS, KO16MSWIN949, LA8ISO6937, LA8PASSPORT, LT8MSWIN921, LT8PC772, LT8PC774, LV8PC1117, LV8PC8LR, LV8RST104090, N8PC865, NE8ISO8859P10, NEE8ISO8859P4, RU8BESTA, RU8PC855, RU8PC866, SE8ISO8859P3, TH8MACTHAIS, TH8TISASCII, TR8DEC, TR8MACTURKISHS, TR8MSWIN1254, TR8PC857, US7ASCII, US8PC437, UTF8, VN8MSWIN1258, VN8VN3, WE8DEC, WE8DG, WE8ISO8859P1, WE8ISO8859P15, WE8ISO8859P9, WE8MACROMAN8S, WE8MSWIN1252, WE8NCR4970, WE8NEXTSTEP, WE8PC850, WE8PC858, WE8PC860, WE8ROMAN8, ZHS16CGB231280, ZHS16GBK, ZHT16BIG5, ZHT16CCDC, ZHT16DBT, ZHT16HKSCS, ZHT16MSWIN950, ZHT32EUC, ZHT32SOPS, ZHT32TRIS

Returns:

  • (String)


56
57
58
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 56

def character_set
  @character_set
end

#compartment_idString

[Required] The OCID of the compartment of the Autonomous Database.

Returns:

  • (String)


47
48
49
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 47

def compartment_id
  @compartment_id
end

#cpu_core_countInteger

The number of OCPU cores to be made available to the database. For Autonomous Databases on dedicated Exadata infrastructure, the maximum number of cores is determined by the infrastructure shape. See Characteristics of Infrastructure Shapes for shape details.

Note: This parameter cannot be used with the ocpuCount parameter.

Returns:

  • (Integer)


74
75
76
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 74

def cpu_core_count
  @cpu_core_count
end

#customer_contactsArray<OCI::Database::Models::CustomerContact>

Customer Contacts.



271
272
273
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 271

def customer_contacts
  @customer_contacts
end

#data_storage_size_in_gbsInteger

The size, in gigabytes, of the data volume that will be created and attached to the database. This storage can later be scaled up if needed. The maximum storage value is determined by the infrastructure shape. See Characteristics of Infrastructure Shapes for shape details.

Notes

  • This parameter is only supported for dedicated Exadata infrastructure.
  • This parameter cannot be used with the dataStorageSizeInTBs parameter.

Returns:

  • (Integer)


113
114
115
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 113

def data_storage_size_in_gbs
  @data_storage_size_in_gbs
end

#data_storage_size_in_tbsInteger

The size, in terabytes, of the data volume that will be created and attached to the database. This storage can later be scaled up if needed. For Autonomous Databases on dedicated Exadata infrastructure, the maximum storage value is determined by the infrastructure shape. See Characteristics of Infrastructure Shapes for shape details.

Note: This parameter cannot be used with the dataStorageSizeInGBs parameter.

Returns:

  • (Integer)


104
105
106
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 104

def data_storage_size_in_tbs
  @data_storage_size_in_tbs
end

#database_editionString

The Oracle Database Edition that applies to the Autonomous databases.

Returns:

  • (String)


300
301
302
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 300

def database_edition
  @database_edition
end

#db_nameString

The database name. The name must begin with an alphabetic character and can contain a maximum of 14 alphanumeric characters. Special characters are not permitted. The database name must be unique in the tenancy.

Returns:

  • (String)


67
68
69
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 67

def db_name
  @db_name
end

#db_versionString

A valid Oracle Database version for Autonomous Database.

Returns:

  • (String)


260
261
262
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 260

def db_version
  @db_version
end

#db_workloadString

The Autonomous Database workload type. The following values are valid:

  • OLTP - indicates an Autonomous Transaction Processing database
  • DW - indicates an Autonomous Data Warehouse database
  • AJD - indicates an Autonomous JSON Database
  • APEX - indicates an Autonomous Database with the Oracle APEX Application Development workload type.

Returns:

  • (String)


97
98
99
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 97

def db_workload
  @db_workload
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see Resource Tags.

Returns:

  • (Hash<String, Hash<String, Object>>)


256
257
258
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 256

def defined_tags
  @defined_tags
end

#display_nameString

The user-friendly name for the Autonomous Database. The name does not have to be unique.

Returns:

  • (String)


135
136
137
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 135

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see Resource Tags.

Example: {\"Department\": \"Finance\"}

Returns:

  • (Hash<String, String>)


250
251
252
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 250

def freeform_tags
  @freeform_tags
end

#is_access_control_enabledBOOLEAN

Indicates if the database-level access control is enabled. If disabled, database access is defined by the network security rules. If enabled, database access is restricted to the IP addresses defined by the rules specified with the whitelistedIps property. While specifying whitelistedIps rules is optional, if database-level access control is enabled and no rules are specified, the database will become inaccessible. The rules can be added later using the UpdateAutonomousDatabase API operation or edit option in console. When creating a database clone, the desired access control setting should be specified. By default, database-level access control will be disabled for the clone.

This property is applicable only to Autonomous Databases on the Exadata Cloud@Customer platform.

Returns:

  • (BOOLEAN)


173
174
175
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 173

def is_access_control_enabled
  @is_access_control_enabled
end

#is_auto_scaling_enabledBOOLEAN

Indicates if auto scaling is enabled for the Autonomous Database OCPU core count. The default value is FALSE.

Returns:

  • (BOOLEAN)


153
154
155
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 153

def is_auto_scaling_enabled
  @is_auto_scaling_enabled
end

#is_auto_scaling_for_storage_enabledBOOLEAN

Indicates if auto scaling is enabled for the Autonomous Database storage. The default value is FALSE.

Returns:

  • (BOOLEAN)


290
291
292
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 290

def is_auto_scaling_for_storage_enabled
  @is_auto_scaling_for_storage_enabled
end

#is_data_guard_enabledBOOLEAN

Deprecated. Indicates whether the Autonomous Database has local (in-region) Data Guard enabled. Not applicable to cross-region Autonomous Data Guard associations, or to Autonomous Databases using dedicated Exadata infrastructure or Exadata Cloud@Customer infrastructure.

Returns:

  • (BOOLEAN)


213
214
215
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 213

def is_data_guard_enabled
  @is_data_guard_enabled
end

#is_dedicatedBOOLEAN

True if the database is on dedicated Exadata infrastructure.

Returns:

  • (BOOLEAN)


158
159
160
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 158

def is_dedicated
  @is_dedicated
end

#is_free_tierBOOLEAN

Indicates if this is an Always Free resource. The default value is false. Note that Always Free Autonomous Databases have 1 CPU and 20GB of memory. For Always Free databases, memory and CPU cannot be scaled.

Returns:

  • (BOOLEAN)


118
119
120
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 118

def is_free_tier
  @is_free_tier
end

#is_local_data_guard_enabledBOOLEAN

Indicates whether the Autonomous Database has local (in-region) Data Guard enabled. Not applicable to cross-region Autonomous Data Guard associations, or to Autonomous Databases using dedicated Exadata infrastructure or Exadata Cloud@Customer infrastructure.

Returns:

  • (BOOLEAN)


217
218
219
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 217

def is_local_data_guard_enabled
  @is_local_data_guard_enabled
end

#is_mtls_connection_requiredBOOLEAN

Indicates whether the Autonomous Database requires mTLS connections.

Returns:

  • (BOOLEAN)


275
276
277
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 275

def is_mtls_connection_required
  @is_mtls_connection_required
end

#is_preview_version_with_service_terms_acceptedBOOLEAN

If set to TRUE, indicates that an Autonomous Database preview version is being provisioned, and that the preview version's terms of service have been accepted. Note that preview version software is only available for databases on shared Exadata infrastructure.

Returns:

  • (BOOLEAN)


148
149
150
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 148

def is_preview_version_with_service_terms_accepted
  @is_preview_version_with_service_terms_accepted
end

#kms_key_idString

The OCID of the key container that is used as the master encryption key in database transparent data encryption (TDE) operations.

Returns:

  • (String)


122
123
124
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 122

def kms_key_id
  @kms_key_id
end

#license_modelString

The Oracle license model that applies to the Oracle Autonomous Database. Bring your own license (BYOL) allows you to apply your current on-premises Oracle software licenses to equivalent, highly automated Oracle PaaS and IaaS services in the cloud. License Included allows you to subscribe to new Oracle Database software licenses and the Database service. Note that when provisioning an Autonomous Database on dedicated Exadata infrastructure, this attribute must be null because the attribute is already set at the Autonomous Exadata Infrastructure level. When using shared Exadata infrastructure, if a value is not specified, the system will supply the value of BRING_YOUR_OWN_LICENSE.

Returns:

  • (String)


143
144
145
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 143

def license_model
  @license_model
end

#max_cpu_core_countInteger

The number of Max OCPU cores to be made available to the autonomous database with auto scaling of cpu enabled.

Returns:

  • (Integer)


295
296
297
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 295

def max_cpu_core_count
  @max_cpu_core_count
end

#ncharacter_setString

The character set for the Autonomous Database. The default is AL32UTF8. Use List Autonomous Database Character Sets to list the allowed values for an Autonomous Database on shared Exadata infrastructure. For an Autonomous Database on dedicated Exadata infrastructure, the allowed values are: AL16UTF16 or UTF8.

Returns:

  • (String)


63
64
65
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 63

def ncharacter_set
  @ncharacter_set
end

#nsg_idsArray<String>

The list of OCIDs for the network security groups (NSGs) to which this resource belongs. Setting this to an empty list removes all resources from all NSGs. For more information about NSGs, see Security Rules. NsgIds restrictions:

  • A network security group (NSG) is optional for Autonomous Databases with private access. The nsgIds list can be empty.

Returns:

  • (Array<String>)


238
239
240
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 238

def nsg_ids
  @nsg_ids
end

#ocpu_countFloat

The number of OCPU cores to be made available to the database.

The following points apply:

  • For Autonomous Databases on dedicated Exadata infrastructure, to provision less than 1 core, enter a fractional value in an increment of 0.1. For example, you can provision 0.3 or 0.4 cores, but not 0.35 cores. (Note that fractional OCPU values are not supported for Autonomous Databasese on shared Exadata infrastructure.)
  • To provision 1 or more cores, you must enter an integer between 1 and the maximum number of cores available for the infrastructure shape. For example, you can provision 2 cores or 3 cores, but not 2.5 cores. This applies to Autonomous Databases on both shared and dedicated Exadata infrastructure.

For Autonomous Databases on dedicated Exadata infrastructure, the maximum number of cores is determined by the infrastructure shape. See Characteristics of Infrastructure Shapes for shape details.

Note: This parameter cannot be used with the cpuCoreCount parameter.

Returns:

  • (Float)


87
88
89
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 87

def ocpu_count
  @ocpu_count
end

#private_endpoint_labelString

The private endpoint label for the resource. Setting this to an empty string, after the private endpoint database gets created, will change the same private endpoint database to the public endpoint database.

Returns:

  • (String)


242
243
244
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 242

def private_endpoint_label
  @private_endpoint_label
end

#scheduled_operationsArray<OCI::Database::Models::ScheduledOperationDetails>

list of scheduled operations



285
286
287
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 285

def scheduled_operations
  @scheduled_operations
end

#sourceString

The source of the database: Use NONE for creating a new Autonomous Database. Use DATABASE for creating a new Autonomous Database by cloning an existing Autonomous Database. Use CROSS_REGION_DATAGUARD to create a standby Data Guard database in another region.

For Autonomous Databases on shared Exadata infrastructure, the following cloning options are available: Use BACKUP_FROM_ID for creating a new Autonomous Database from a specified backup. Use BACKUP_FROM_TIMESTAMP for creating a point-in-time Autonomous Database clone using backups. For more information, see Cloning and Moving an Autonomous Database.

Returns:

  • (String)


267
268
269
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 267

def source
  @source
end

#standby_whitelisted_ipsArray<String>

The client IP access control list (ACL). This feature is available for autonomous databases on shared Exadata infrastructure and on Exadata Cloud@Customer. Only clients connecting from an IP address included in the ACL may access the Autonomous Database instance.

For shared Exadata infrastructure, this is an array of CIDR (Classless Inter-Domain Routing) notations for a subnet or VCN OCID. Use a semicolon (;) as a deliminator between the VCN-specific subnets or IPs. Example: [\"1.1.1.1\",\"1.1.1.0/24\",\"ocid1.vcn.oc1.sea.<unique_id>\",\"ocid1.vcn.oc1.sea.<unique_id1>;1.1.1.1\",\"ocid1.vcn.oc1.sea.<unique_id2>;1.1.0.0/16\"] For Exadata Cloud@Customer, this is an array of IP addresses or CIDR (Classless Inter-Domain Routing) notations. Example: [\"1.1.1.1\",\"1.1.1.0/24\",\"1.1.2.25\"]

For an update operation, if you want to delete all the IPs in the ACL, use an array with a single empty string entry.

Returns:

  • (Array<String>)


208
209
210
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 208

def standby_whitelisted_ips
  @standby_whitelisted_ips
end

#subnet_idString

The OCID of the subnet the resource is associated with.

Subnet Restrictions:

  • For bare metal DB systems and for single node virtual machine DB systems, do not use a subnet that overlaps with 192.168.16.16/28.
  • For Exadata and virtual machine 2-node RAC systems, do not use a subnet that overlaps with 192.168.128.0/20.
  • For Autonomous Database, setting this will disable public secure access to the database.

These subnets are used by the Oracle Clusterware private interconnect on the database instance. Specifying an overlapping subnet will cause the private interconnect to malfunction. This restriction applies to both the client subnet and the backup subnet.

Returns:

  • (String)


231
232
233
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 231

def subnet_id
  @subnet_id
end

#vault_idString

The OCID of the Oracle Cloud Infrastructure vault.

Returns:

  • (String)


126
127
128
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 126

def vault_id
  @vault_id
end

#whitelisted_ipsArray<String>

The client IP access control list (ACL). This feature is available for autonomous databases on shared Exadata infrastructure and on Exadata Cloud@Customer. Only clients connecting from an IP address included in the ACL may access the Autonomous Database instance.

For shared Exadata infrastructure, this is an array of CIDR (Classless Inter-Domain Routing) notations for a subnet or VCN OCID. Use a semicolon (;) as a deliminator between the VCN-specific subnets or IPs. Example: [\"1.1.1.1\",\"1.1.1.0/24\",\"ocid1.vcn.oc1.sea.<unique_id>\",\"ocid1.vcn.oc1.sea.<unique_id1>;1.1.1.1\",\"ocid1.vcn.oc1.sea.<unique_id2>;1.1.0.0/16\"] For Exadata Cloud@Customer, this is an array of IP addresses or CIDR (Classless Inter-Domain Routing) notations. Example: [\"1.1.1.1\",\"1.1.1.0/24\",\"1.1.2.25\"]

For an update operation, if you want to delete all the IPs in the ACL, use an array with a single empty string entry.

Returns:

  • (Array<String>)


187
188
189
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 187

def whitelisted_ips
  @whitelisted_ips
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 303

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'compartmentId',
    'character_set': :'characterSet',
    'ncharacter_set': :'ncharacterSet',
    'db_name': :'dbName',
    'cpu_core_count': :'cpuCoreCount',
    'ocpu_count': :'ocpuCount',
    'db_workload': :'dbWorkload',
    'data_storage_size_in_tbs': :'dataStorageSizeInTBs',
    'data_storage_size_in_gbs': :'dataStorageSizeInGBs',
    'is_free_tier': :'isFreeTier',
    'kms_key_id': :'kmsKeyId',
    'vault_id': :'vaultId',
    'admin_password': :'adminPassword',
    'display_name': :'displayName',
    'license_model': :'licenseModel',
    'is_preview_version_with_service_terms_accepted': :'isPreviewVersionWithServiceTermsAccepted',
    'is_auto_scaling_enabled': :'isAutoScalingEnabled',
    'is_dedicated': :'isDedicated',
    'autonomous_container_database_id': :'autonomousContainerDatabaseId',
    'is_access_control_enabled': :'isAccessControlEnabled',
    'whitelisted_ips': :'whitelistedIps',
    'are_primary_whitelisted_ips_used': :'arePrimaryWhitelistedIpsUsed',
    'standby_whitelisted_ips': :'standbyWhitelistedIps',
    'is_data_guard_enabled': :'isDataGuardEnabled',
    'is_local_data_guard_enabled': :'isLocalDataGuardEnabled',
    'subnet_id': :'subnetId',
    'nsg_ids': :'nsgIds',
    'private_endpoint_label': :'privateEndpointLabel',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'db_version': :'dbVersion',
    'source': :'source',
    'customer_contacts': :'customerContacts',
    'is_mtls_connection_required': :'isMtlsConnectionRequired',
    'autonomous_maintenance_schedule_type': :'autonomousMaintenanceScheduleType',
    'scheduled_operations': :'scheduledOperations',
    'is_auto_scaling_for_storage_enabled': :'isAutoScalingForStorageEnabled',
    'max_cpu_core_count': :'maxCpuCoreCount',
    'database_edition': :'databaseEdition'
    # rubocop:enable Style/SymbolLiteral
  }
end

.get_subtype(object_hash) ⇒ Object

Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.



401
402
403
404
405
406
407
408
409
410
411
412
413
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 401

def self.get_subtype(object_hash)
  type = object_hash[:'source'] # rubocop:disable Style/SymbolLiteral

  return 'OCI::Database::Models::CreateAutonomousDatabaseCloneDetails' if type == 'DATABASE'
  return 'OCI::Database::Models::CreateRefreshableAutonomousDatabaseCloneDetails' if type == 'CLONE_TO_REFRESHABLE'
  return 'OCI::Database::Models::CreateAutonomousDatabaseFromBackupDetails' if type == 'BACKUP_FROM_ID'
  return 'OCI::Database::Models::CreateAutonomousDatabaseFromBackupTimestampDetails' if type == 'BACKUP_FROM_TIMESTAMP'
  return 'OCI::Database::Models::CreateCrossRegionAutonomousDatabaseDataGuardDetails' if type == 'CROSS_REGION_DATAGUARD'
  return 'OCI::Database::Models::CreateAutonomousDatabaseDetails' if type == 'NONE'

  # TODO: Log a warning when the subtype is not found.
  'OCI::Database::Models::CreateAutonomousDatabaseBase'
end

.swagger_typesObject

Attribute type mapping.



350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 350

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'String',
    'character_set': :'String',
    'ncharacter_set': :'String',
    'db_name': :'String',
    'cpu_core_count': :'Integer',
    'ocpu_count': :'Float',
    'db_workload': :'String',
    'data_storage_size_in_tbs': :'Integer',
    'data_storage_size_in_gbs': :'Integer',
    'is_free_tier': :'BOOLEAN',
    'kms_key_id': :'String',
    'vault_id': :'String',
    'admin_password': :'String',
    'display_name': :'String',
    'license_model': :'String',
    'is_preview_version_with_service_terms_accepted': :'BOOLEAN',
    'is_auto_scaling_enabled': :'BOOLEAN',
    'is_dedicated': :'BOOLEAN',
    'autonomous_container_database_id': :'String',
    'is_access_control_enabled': :'BOOLEAN',
    'whitelisted_ips': :'Array<String>',
    'are_primary_whitelisted_ips_used': :'BOOLEAN',
    'standby_whitelisted_ips': :'Array<String>',
    'is_data_guard_enabled': :'BOOLEAN',
    'is_local_data_guard_enabled': :'BOOLEAN',
    'subnet_id': :'String',
    'nsg_ids': :'Array<String>',
    'private_endpoint_label': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'db_version': :'String',
    'source': :'String',
    'customer_contacts': :'Array<OCI::Database::Models::CustomerContact>',
    'is_mtls_connection_required': :'BOOLEAN',
    'autonomous_maintenance_schedule_type': :'String',
    'scheduled_operations': :'Array<OCI::Database::Models::ScheduledOperationDetails>',
    'is_auto_scaling_for_storage_enabled': :'BOOLEAN',
    'max_cpu_core_count': :'Integer',
    'database_edition': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 746

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    compartment_id == other.compartment_id &&
    character_set == other.character_set &&
    ncharacter_set == other.ncharacter_set &&
    db_name == other.db_name &&
    cpu_core_count == other.cpu_core_count &&
    ocpu_count == other.ocpu_count &&
    db_workload == other.db_workload &&
    data_storage_size_in_tbs == other.data_storage_size_in_tbs &&
    data_storage_size_in_gbs == other.data_storage_size_in_gbs &&
    is_free_tier == other.is_free_tier &&
    kms_key_id == other.kms_key_id &&
    vault_id == other.vault_id &&
    admin_password == other.admin_password &&
    display_name == other.display_name &&
    license_model == other.license_model &&
    is_preview_version_with_service_terms_accepted == other.is_preview_version_with_service_terms_accepted &&
    is_auto_scaling_enabled == other.is_auto_scaling_enabled &&
    is_dedicated == other.is_dedicated &&
    autonomous_container_database_id == other.autonomous_container_database_id &&
    is_access_control_enabled == other.is_access_control_enabled &&
    whitelisted_ips == other.whitelisted_ips &&
    are_primary_whitelisted_ips_used == other.are_primary_whitelisted_ips_used &&
    standby_whitelisted_ips == other.standby_whitelisted_ips &&
    is_data_guard_enabled == other.is_data_guard_enabled &&
    is_local_data_guard_enabled == other.is_local_data_guard_enabled &&
    subnet_id == other.subnet_id &&
    nsg_ids == other.nsg_ids &&
    private_endpoint_label == other.private_endpoint_label &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    db_version == other.db_version &&
    source == other.source &&
    customer_contacts == other.customer_contacts &&
    is_mtls_connection_required == other.is_mtls_connection_required &&
    autonomous_maintenance_schedule_type == other.autonomous_maintenance_schedule_type &&
    scheduled_operations == other.scheduled_operations &&
    is_auto_scaling_for_storage_enabled == other.is_auto_scaling_for_storage_enabled &&
    max_cpu_core_count == other.max_cpu_core_count &&
    database_edition == other.database_edition
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 814

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


794
795
796
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 794

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



803
804
805
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 803

def hash
  [compartment_id, character_set, ncharacter_set, db_name, cpu_core_count, ocpu_count, db_workload, data_storage_size_in_tbs, data_storage_size_in_gbs, is_free_tier, kms_key_id, vault_id, admin_password, display_name, license_model, is_preview_version_with_service_terms_accepted, is_auto_scaling_enabled, is_dedicated, autonomous_container_database_id, is_access_control_enabled, whitelisted_ips, are_primary_whitelisted_ips_used, standby_whitelisted_ips, is_data_guard_enabled, is_local_data_guard_enabled, subnet_id, nsg_ids, private_endpoint_label, freeform_tags, defined_tags, db_version, source, customer_contacts, is_mtls_connection_required, autonomous_maintenance_schedule_type, scheduled_operations, is_auto_scaling_for_storage_enabled, max_cpu_core_count, database_edition].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



847
848
849
850
851
852
853
854
855
856
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 847

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



841
842
843
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 841

def to_s
  to_hash.to_s
end