Class: OCI::Database::Models::CreateAutonomousDatabaseCloneDetails
- Inherits:
-
CreateAutonomousDatabaseBase
- Object
- CreateAutonomousDatabaseBase
- OCI::Database::Models::CreateAutonomousDatabaseCloneDetails
- Defined in:
- lib/oci/database/models/create_autonomous_database_clone_details.rb
Overview
Details to create an Oracle Autonomous Database by cloning an existing Autonomous Database.
Constant Summary collapse
- CLONE_TYPE_ENUM =
[ CLONE_TYPE_FULL = 'FULL'.freeze, CLONE_TYPE_METADATA = 'METADATA'.freeze ].freeze
Constants inherited from CreateAutonomousDatabaseBase
OCI::Database::Models::CreateAutonomousDatabaseBase::AUTONOMOUS_MAINTENANCE_SCHEDULE_TYPE_ENUM, OCI::Database::Models::CreateAutonomousDatabaseBase::DB_WORKLOAD_ENUM, OCI::Database::Models::CreateAutonomousDatabaseBase::LICENSE_MODEL_ENUM, OCI::Database::Models::CreateAutonomousDatabaseBase::SOURCE_ENUM
Instance Attribute Summary collapse
-
#clone_type ⇒ String
[Required] The Autonomous Database clone type.
-
#source_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the source Autonomous Database that you will clone to create a new Autonomous Database.
Attributes inherited from CreateAutonomousDatabaseBase
#admin_password, #are_primary_whitelisted_ips_used, #autonomous_container_database_id, #autonomous_maintenance_schedule_type, #compartment_id, #cpu_core_count, #customer_contacts, #data_storage_size_in_gbs, #data_storage_size_in_tbs, #db_name, #db_version, #db_workload, #defined_tags, #display_name, #freeform_tags, #is_access_control_enabled, #is_auto_scaling_enabled, #is_data_guard_enabled, #is_dedicated, #is_free_tier, #is_mtls_connection_required, #is_preview_version_with_service_terms_accepted, #kms_key_id, #license_model, #nsg_ids, #ocpu_count, #private_endpoint_label, #scheduled_operations, #source, #standby_whitelisted_ips, #subnet_id, #vault_id, #whitelisted_ips
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateAutonomousDatabaseCloneDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from CreateAutonomousDatabaseBase
Constructor Details
#initialize(attributes = {}) ⇒ CreateAutonomousDatabaseCloneDetails
Initializes the object
151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/oci/database/models/create_autonomous_database_clone_details.rb', line 151 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['source'] = 'DATABASE' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.source_id = attributes[:'sourceId'] if attributes[:'sourceId'] raise 'You cannot provide both :sourceId and :source_id' if attributes.key?(:'sourceId') && attributes.key?(:'source_id') self.source_id = attributes[:'source_id'] if attributes[:'source_id'] self.clone_type = attributes[:'cloneType'] if attributes[:'cloneType'] raise 'You cannot provide both :cloneType and :clone_type' if attributes.key?(:'cloneType') && attributes.key?(:'clone_type') self.clone_type = attributes[:'clone_type'] if attributes[:'clone_type'] end |
Instance Attribute Details
#clone_type ⇒ String
[Required] The Autonomous Database clone type.
23 24 25 |
# File 'lib/oci/database/models/create_autonomous_database_clone_details.rb', line 23 def clone_type @clone_type end |
#source_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the source Autonomous Database that you will clone to create a new Autonomous Database.
19 20 21 |
# File 'lib/oci/database/models/create_autonomous_database_clone_details.rb', line 19 def source_id @source_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/oci/database/models/create_autonomous_database_clone_details.rb', line 26 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'db_name': :'dbName', 'cpu_core_count': :'cpuCoreCount', 'ocpu_count': :'ocpuCount', 'db_workload': :'dbWorkload', 'data_storage_size_in_tbs': :'dataStorageSizeInTBs', 'data_storage_size_in_gbs': :'dataStorageSizeInGBs', 'is_free_tier': :'isFreeTier', 'kms_key_id': :'kmsKeyId', 'vault_id': :'vaultId', 'admin_password': :'adminPassword', 'display_name': :'displayName', 'license_model': :'licenseModel', 'is_preview_version_with_service_terms_accepted': :'isPreviewVersionWithServiceTermsAccepted', 'is_auto_scaling_enabled': :'isAutoScalingEnabled', 'is_dedicated': :'isDedicated', 'autonomous_container_database_id': :'autonomousContainerDatabaseId', 'is_access_control_enabled': :'isAccessControlEnabled', 'whitelisted_ips': :'whitelistedIps', 'are_primary_whitelisted_ips_used': :'arePrimaryWhitelistedIpsUsed', 'standby_whitelisted_ips': :'standbyWhitelistedIps', 'is_data_guard_enabled': :'isDataGuardEnabled', 'subnet_id': :'subnetId', 'nsg_ids': :'nsgIds', 'private_endpoint_label': :'privateEndpointLabel', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'db_version': :'dbVersion', 'source': :'source', 'customer_contacts': :'customerContacts', 'is_mtls_connection_required': :'isMtlsConnectionRequired', 'autonomous_maintenance_schedule_type': :'autonomousMaintenanceScheduleType', 'scheduled_operations': :'scheduledOperations', 'source_id': :'sourceId', 'clone_type': :'cloneType' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/oci/database/models/create_autonomous_database_clone_details.rb', line 69 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'db_name': :'String', 'cpu_core_count': :'Integer', 'ocpu_count': :'Float', 'db_workload': :'String', 'data_storage_size_in_tbs': :'Integer', 'data_storage_size_in_gbs': :'Integer', 'is_free_tier': :'BOOLEAN', 'kms_key_id': :'String', 'vault_id': :'String', 'admin_password': :'String', 'display_name': :'String', 'license_model': :'String', 'is_preview_version_with_service_terms_accepted': :'BOOLEAN', 'is_auto_scaling_enabled': :'BOOLEAN', 'is_dedicated': :'BOOLEAN', 'autonomous_container_database_id': :'String', 'is_access_control_enabled': :'BOOLEAN', 'whitelisted_ips': :'Array<String>', 'are_primary_whitelisted_ips_used': :'BOOLEAN', 'standby_whitelisted_ips': :'Array<String>', 'is_data_guard_enabled': :'BOOLEAN', 'subnet_id': :'String', 'nsg_ids': :'Array<String>', 'private_endpoint_label': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'db_version': :'String', 'source': :'String', 'customer_contacts': :'Array<OCI::Database::Models::CustomerContact>', 'is_mtls_connection_required': :'BOOLEAN', 'autonomous_maintenance_schedule_type': :'String', 'scheduled_operations': :'Array<OCI::Database::Models::ScheduledOperationDetails>', 'source_id': :'String', 'clone_type': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/oci/database/models/create_autonomous_database_clone_details.rb', line 189 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && db_name == other.db_name && cpu_core_count == other.cpu_core_count && ocpu_count == other.ocpu_count && db_workload == other.db_workload && data_storage_size_in_tbs == other.data_storage_size_in_tbs && data_storage_size_in_gbs == other.data_storage_size_in_gbs && is_free_tier == other.is_free_tier && kms_key_id == other.kms_key_id && vault_id == other.vault_id && admin_password == other.admin_password && display_name == other.display_name && license_model == other.license_model && is_preview_version_with_service_terms_accepted == other.is_preview_version_with_service_terms_accepted && is_auto_scaling_enabled == other.is_auto_scaling_enabled && is_dedicated == other.is_dedicated && autonomous_container_database_id == other.autonomous_container_database_id && is_access_control_enabled == other.is_access_control_enabled && whitelisted_ips == other.whitelisted_ips && are_primary_whitelisted_ips_used == other.are_primary_whitelisted_ips_used && standby_whitelisted_ips == other.standby_whitelisted_ips && is_data_guard_enabled == other.is_data_guard_enabled && subnet_id == other.subnet_id && nsg_ids == other.nsg_ids && private_endpoint_label == other.private_endpoint_label && == other. && == other. && db_version == other.db_version && source == other.source && customer_contacts == other.customer_contacts && is_mtls_connection_required == other.is_mtls_connection_required && autonomous_maintenance_schedule_type == other.autonomous_maintenance_schedule_type && scheduled_operations == other.scheduled_operations && source_id == other.source_id && clone_type == other.clone_type end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/oci/database/models/create_autonomous_database_clone_details.rb', line 253 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
233 234 235 |
# File 'lib/oci/database/models/create_autonomous_database_clone_details.rb', line 233 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
242 243 244 |
# File 'lib/oci/database/models/create_autonomous_database_clone_details.rb', line 242 def hash [compartment_id, db_name, cpu_core_count, ocpu_count, db_workload, data_storage_size_in_tbs, data_storage_size_in_gbs, is_free_tier, kms_key_id, vault_id, admin_password, display_name, license_model, is_preview_version_with_service_terms_accepted, is_auto_scaling_enabled, is_dedicated, autonomous_container_database_id, is_access_control_enabled, whitelisted_ips, are_primary_whitelisted_ips_used, standby_whitelisted_ips, is_data_guard_enabled, subnet_id, nsg_ids, private_endpoint_label, , , db_version, source, customer_contacts, is_mtls_connection_required, autonomous_maintenance_schedule_type, scheduled_operations, source_id, clone_type].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
286 287 288 289 290 291 292 293 294 295 |
# File 'lib/oci/database/models/create_autonomous_database_clone_details.rb', line 286 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
280 281 282 |
# File 'lib/oci/database/models/create_autonomous_database_clone_details.rb', line 280 def to_s to_hash.to_s end |