Class: OCI::Database::Models::CreateAutonomousDatabaseFromBackupTimestampDetails
- Inherits:
-
CreateAutonomousDatabaseBase
- Object
- CreateAutonomousDatabaseBase
- OCI::Database::Models::CreateAutonomousDatabaseFromBackupTimestampDetails
- Defined in:
- lib/oci/database/models/create_autonomous_database_from_backup_timestamp_details.rb
Overview
Details to create a point-in-time clone of an Oracle Autonomous Database by specifying a timestamp. Point-in-time clones use backups as the source of the data for the clone.
Constant Summary collapse
- CLONE_TYPE_ENUM =
[ CLONE_TYPE_FULL = 'FULL'.freeze, CLONE_TYPE_METADATA = 'METADATA'.freeze ].freeze
Constants inherited from CreateAutonomousDatabaseBase
OCI::Database::Models::CreateAutonomousDatabaseBase::AUTONOMOUS_MAINTENANCE_SCHEDULE_TYPE_ENUM, OCI::Database::Models::CreateAutonomousDatabaseBase::DB_WORKLOAD_ENUM, OCI::Database::Models::CreateAutonomousDatabaseBase::LICENSE_MODEL_ENUM, OCI::Database::Models::CreateAutonomousDatabaseBase::SOURCE_ENUM
Instance Attribute Summary collapse
-
#autonomous_database_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the source Autonomous Database that you will clone to create a new Autonomous Database.
-
#clone_type ⇒ String
**[Required]** The Autonomous Database clone type.
-
#timestamp ⇒ DateTime
**[Required]** The timestamp specified for the point-in-time clone of the source Autonomous Database.
Attributes inherited from CreateAutonomousDatabaseBase
#admin_password, #are_primary_whitelisted_ips_used, #autonomous_container_database_id, #autonomous_maintenance_schedule_type, #character_set, #compartment_id, #cpu_core_count, #customer_contacts, #data_storage_size_in_gbs, #data_storage_size_in_tbs, #database_edition, #db_name, #db_version, #db_workload, #defined_tags, #display_name, #freeform_tags, #is_access_control_enabled, #is_auto_scaling_enabled, #is_auto_scaling_for_storage_enabled, #is_data_guard_enabled, #is_dedicated, #is_free_tier, #is_local_data_guard_enabled, #is_mtls_connection_required, #is_preview_version_with_service_terms_accepted, #kms_key_id, #license_model, #max_cpu_core_count, #ncharacter_set, #nsg_ids, #ocpu_count, #private_endpoint_label, #scheduled_operations, #source, #standby_whitelisted_ips, #subnet_id, #vault_id, #whitelisted_ips
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateAutonomousDatabaseFromBackupTimestampDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from CreateAutonomousDatabaseBase
Constructor Details
#initialize(attributes = {}) ⇒ CreateAutonomousDatabaseFromBackupTimestampDetails
Initializes the object
176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/oci/database/models/create_autonomous_database_from_backup_timestamp_details.rb', line 176 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['source'] = 'BACKUP_FROM_TIMESTAMP' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.autonomous_database_id = attributes[:'autonomousDatabaseId'] if attributes[:'autonomousDatabaseId'] raise 'You cannot provide both :autonomousDatabaseId and :autonomous_database_id' if attributes.key?(:'autonomousDatabaseId') && attributes.key?(:'autonomous_database_id') self.autonomous_database_id = attributes[:'autonomous_database_id'] if attributes[:'autonomous_database_id'] self. = attributes[:'timestamp'] if attributes[:'timestamp'] self.clone_type = attributes[:'cloneType'] if attributes[:'cloneType'] raise 'You cannot provide both :cloneType and :clone_type' if attributes.key?(:'cloneType') && attributes.key?(:'clone_type') self.clone_type = attributes[:'clone_type'] if attributes[:'clone_type'] end |
Instance Attribute Details
#autonomous_database_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the source Autonomous Database that you will clone to create a new Autonomous Database.
19 20 21 |
# File 'lib/oci/database/models/create_autonomous_database_from_backup_timestamp_details.rb', line 19 def autonomous_database_id @autonomous_database_id end |
#clone_type ⇒ String
**[Required]** The Autonomous Database clone type.
27 28 29 |
# File 'lib/oci/database/models/create_autonomous_database_from_backup_timestamp_details.rb', line 27 def clone_type @clone_type end |
#timestamp ⇒ DateTime
**[Required]** The timestamp specified for the point-in-time clone of the source Autonomous Database. The timestamp must be in the past.
23 24 25 |
# File 'lib/oci/database/models/create_autonomous_database_from_backup_timestamp_details.rb', line 23 def @timestamp end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/oci/database/models/create_autonomous_database_from_backup_timestamp_details.rb', line 30 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'character_set': :'characterSet', 'ncharacter_set': :'ncharacterSet', 'db_name': :'dbName', 'cpu_core_count': :'cpuCoreCount', 'ocpu_count': :'ocpuCount', 'db_workload': :'dbWorkload', 'data_storage_size_in_tbs': :'dataStorageSizeInTBs', 'data_storage_size_in_gbs': :'dataStorageSizeInGBs', 'is_free_tier': :'isFreeTier', 'kms_key_id': :'kmsKeyId', 'vault_id': :'vaultId', 'admin_password': :'adminPassword', 'display_name': :'displayName', 'license_model': :'licenseModel', 'is_preview_version_with_service_terms_accepted': :'isPreviewVersionWithServiceTermsAccepted', 'is_auto_scaling_enabled': :'isAutoScalingEnabled', 'is_dedicated': :'isDedicated', 'autonomous_container_database_id': :'autonomousContainerDatabaseId', 'is_access_control_enabled': :'isAccessControlEnabled', 'whitelisted_ips': :'whitelistedIps', 'are_primary_whitelisted_ips_used': :'arePrimaryWhitelistedIpsUsed', 'standby_whitelisted_ips': :'standbyWhitelistedIps', 'is_data_guard_enabled': :'isDataGuardEnabled', 'is_local_data_guard_enabled': :'isLocalDataGuardEnabled', 'subnet_id': :'subnetId', 'nsg_ids': :'nsgIds', 'private_endpoint_label': :'privateEndpointLabel', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'db_version': :'dbVersion', 'source': :'source', 'customer_contacts': :'customerContacts', 'is_mtls_connection_required': :'isMtlsConnectionRequired', 'autonomous_maintenance_schedule_type': :'autonomousMaintenanceScheduleType', 'scheduled_operations': :'scheduledOperations', 'is_auto_scaling_for_storage_enabled': :'isAutoScalingForStorageEnabled', 'max_cpu_core_count': :'maxCpuCoreCount', 'database_edition': :'databaseEdition', 'autonomous_database_id': :'autonomousDatabaseId', 'timestamp': :'timestamp', 'clone_type': :'cloneType' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/oci/database/models/create_autonomous_database_from_backup_timestamp_details.rb', line 80 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'character_set': :'String', 'ncharacter_set': :'String', 'db_name': :'String', 'cpu_core_count': :'Integer', 'ocpu_count': :'Float', 'db_workload': :'String', 'data_storage_size_in_tbs': :'Integer', 'data_storage_size_in_gbs': :'Integer', 'is_free_tier': :'BOOLEAN', 'kms_key_id': :'String', 'vault_id': :'String', 'admin_password': :'String', 'display_name': :'String', 'license_model': :'String', 'is_preview_version_with_service_terms_accepted': :'BOOLEAN', 'is_auto_scaling_enabled': :'BOOLEAN', 'is_dedicated': :'BOOLEAN', 'autonomous_container_database_id': :'String', 'is_access_control_enabled': :'BOOLEAN', 'whitelisted_ips': :'Array<String>', 'are_primary_whitelisted_ips_used': :'BOOLEAN', 'standby_whitelisted_ips': :'Array<String>', 'is_data_guard_enabled': :'BOOLEAN', 'is_local_data_guard_enabled': :'BOOLEAN', 'subnet_id': :'String', 'nsg_ids': :'Array<String>', 'private_endpoint_label': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'db_version': :'String', 'source': :'String', 'customer_contacts': :'Array<OCI::Database::Models::CustomerContact>', 'is_mtls_connection_required': :'BOOLEAN', 'autonomous_maintenance_schedule_type': :'String', 'scheduled_operations': :'Array<OCI::Database::Models::ScheduledOperationDetails>', 'is_auto_scaling_for_storage_enabled': :'BOOLEAN', 'max_cpu_core_count': :'Integer', 'database_edition': :'String', 'autonomous_database_id': :'String', 'timestamp': :'DateTime', 'clone_type': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 |
# File 'lib/oci/database/models/create_autonomous_database_from_backup_timestamp_details.rb', line 216 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && character_set == other.character_set && ncharacter_set == other.ncharacter_set && db_name == other.db_name && cpu_core_count == other.cpu_core_count && ocpu_count == other.ocpu_count && db_workload == other.db_workload && data_storage_size_in_tbs == other.data_storage_size_in_tbs && data_storage_size_in_gbs == other.data_storage_size_in_gbs && is_free_tier == other.is_free_tier && kms_key_id == other.kms_key_id && vault_id == other.vault_id && admin_password == other.admin_password && display_name == other.display_name && license_model == other.license_model && is_preview_version_with_service_terms_accepted == other.is_preview_version_with_service_terms_accepted && is_auto_scaling_enabled == other.is_auto_scaling_enabled && is_dedicated == other.is_dedicated && autonomous_container_database_id == other.autonomous_container_database_id && is_access_control_enabled == other.is_access_control_enabled && whitelisted_ips == other.whitelisted_ips && are_primary_whitelisted_ips_used == other.are_primary_whitelisted_ips_used && standby_whitelisted_ips == other.standby_whitelisted_ips && is_data_guard_enabled == other.is_data_guard_enabled && is_local_data_guard_enabled == other.is_local_data_guard_enabled && subnet_id == other.subnet_id && nsg_ids == other.nsg_ids && private_endpoint_label == other.private_endpoint_label && == other. && == other. && db_version == other.db_version && source == other.source && customer_contacts == other.customer_contacts && is_mtls_connection_required == other.is_mtls_connection_required && autonomous_maintenance_schedule_type == other.autonomous_maintenance_schedule_type && scheduled_operations == other.scheduled_operations && is_auto_scaling_for_storage_enabled == other.is_auto_scaling_for_storage_enabled && max_cpu_core_count == other.max_cpu_core_count && database_edition == other.database_edition && autonomous_database_id == other.autonomous_database_id && == other. && clone_type == other.clone_type end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 |
# File 'lib/oci/database/models/create_autonomous_database_from_backup_timestamp_details.rb', line 287 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
267 268 269 |
# File 'lib/oci/database/models/create_autonomous_database_from_backup_timestamp_details.rb', line 267 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
276 277 278 |
# File 'lib/oci/database/models/create_autonomous_database_from_backup_timestamp_details.rb', line 276 def hash [compartment_id, character_set, ncharacter_set, db_name, cpu_core_count, ocpu_count, db_workload, data_storage_size_in_tbs, data_storage_size_in_gbs, is_free_tier, kms_key_id, vault_id, admin_password, display_name, license_model, is_preview_version_with_service_terms_accepted, is_auto_scaling_enabled, is_dedicated, autonomous_container_database_id, is_access_control_enabled, whitelisted_ips, are_primary_whitelisted_ips_used, standby_whitelisted_ips, is_data_guard_enabled, is_local_data_guard_enabled, subnet_id, nsg_ids, private_endpoint_label, , , db_version, source, customer_contacts, is_mtls_connection_required, autonomous_maintenance_schedule_type, scheduled_operations, is_auto_scaling_for_storage_enabled, max_cpu_core_count, database_edition, autonomous_database_id, , clone_type].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
320 321 322 323 324 325 326 327 328 329 |
# File 'lib/oci/database/models/create_autonomous_database_from_backup_timestamp_details.rb', line 320 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
314 315 316 |
# File 'lib/oci/database/models/create_autonomous_database_from_backup_timestamp_details.rb', line 314 def to_s to_hash.to_s end |