Class: OCI::Database::Models::CreateAutonomousVmClusterDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database/models/create_autonomous_vm_cluster_details.rb

Overview

Details for the create Autonomous VM cluster operation.

Constant Summary collapse

LICENSE_MODEL_ENUM =
[
  LICENSE_MODEL_LICENSE_INCLUDED = 'LICENSE_INCLUDED'.freeze,
  LICENSE_MODEL_BRING_YOUR_OWN_LICENSE = 'BRING_YOUR_OWN_LICENSE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateAutonomousVmClusterDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/oci/database/models/create_autonomous_vm_cluster_details.rb', line 143

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.exadata_infrastructure_id = attributes[:'exadataInfrastructureId'] if attributes[:'exadataInfrastructureId']

  raise 'You cannot provide both :exadataInfrastructureId and :exadata_infrastructure_id' if attributes.key?(:'exadataInfrastructureId') && attributes.key?(:'exadata_infrastructure_id')

  self.exadata_infrastructure_id = attributes[:'exadata_infrastructure_id'] if attributes[:'exadata_infrastructure_id']

  self.vm_cluster_network_id = attributes[:'vmClusterNetworkId'] if attributes[:'vmClusterNetworkId']

  raise 'You cannot provide both :vmClusterNetworkId and :vm_cluster_network_id' if attributes.key?(:'vmClusterNetworkId') && attributes.key?(:'vm_cluster_network_id')

  self.vm_cluster_network_id = attributes[:'vm_cluster_network_id'] if attributes[:'vm_cluster_network_id']

  self.time_zone = attributes[:'timeZone'] if attributes[:'timeZone']

  raise 'You cannot provide both :timeZone and :time_zone' if attributes.key?(:'timeZone') && attributes.key?(:'time_zone')

  self.time_zone = attributes[:'time_zone'] if attributes[:'time_zone']

  self.is_local_backup_enabled = attributes[:'isLocalBackupEnabled'] unless attributes[:'isLocalBackupEnabled'].nil?

  raise 'You cannot provide both :isLocalBackupEnabled and :is_local_backup_enabled' if attributes.key?(:'isLocalBackupEnabled') && attributes.key?(:'is_local_backup_enabled')

  self.is_local_backup_enabled = attributes[:'is_local_backup_enabled'] unless attributes[:'is_local_backup_enabled'].nil?

  self.license_model = attributes[:'licenseModel'] if attributes[:'licenseModel']

  raise 'You cannot provide both :licenseModel and :license_model' if attributes.key?(:'licenseModel') && attributes.key?(:'license_model')

  self.license_model = attributes[:'license_model'] if attributes[:'license_model']

  self.total_container_databases = attributes[:'totalContainerDatabases'] if attributes[:'totalContainerDatabases']

  raise 'You cannot provide both :totalContainerDatabases and :total_container_databases' if attributes.key?(:'totalContainerDatabases') && attributes.key?(:'total_container_databases')

  self.total_container_databases = attributes[:'total_container_databases'] if attributes[:'total_container_databases']

  self.cpu_core_count_per_node = attributes[:'cpuCoreCountPerNode'] if attributes[:'cpuCoreCountPerNode']

  raise 'You cannot provide both :cpuCoreCountPerNode and :cpu_core_count_per_node' if attributes.key?(:'cpuCoreCountPerNode') && attributes.key?(:'cpu_core_count_per_node')

  self.cpu_core_count_per_node = attributes[:'cpu_core_count_per_node'] if attributes[:'cpu_core_count_per_node']

  self.memory_per_oracle_compute_unit_in_gbs = attributes[:'memoryPerOracleComputeUnitInGBs'] if attributes[:'memoryPerOracleComputeUnitInGBs']

  raise 'You cannot provide both :memoryPerOracleComputeUnitInGBs and :memory_per_oracle_compute_unit_in_gbs' if attributes.key?(:'memoryPerOracleComputeUnitInGBs') && attributes.key?(:'memory_per_oracle_compute_unit_in_gbs')

  self.memory_per_oracle_compute_unit_in_gbs = attributes[:'memory_per_oracle_compute_unit_in_gbs'] if attributes[:'memory_per_oracle_compute_unit_in_gbs']

  self.autonomous_data_storage_size_in_tbs = attributes[:'autonomousDataStorageSizeInTBs'] if attributes[:'autonomousDataStorageSizeInTBs']

  raise 'You cannot provide both :autonomousDataStorageSizeInTBs and :autonomous_data_storage_size_in_tbs' if attributes.key?(:'autonomousDataStorageSizeInTBs') && attributes.key?(:'autonomous_data_storage_size_in_tbs')

  self.autonomous_data_storage_size_in_tbs = attributes[:'autonomous_data_storage_size_in_tbs'] if attributes[:'autonomous_data_storage_size_in_tbs']

  self.maintenance_window_details = attributes[:'maintenanceWindowDetails'] if attributes[:'maintenanceWindowDetails']

  raise 'You cannot provide both :maintenanceWindowDetails and :maintenance_window_details' if attributes.key?(:'maintenanceWindowDetails') && attributes.key?(:'maintenance_window_details')

  self.maintenance_window_details = attributes[:'maintenance_window_details'] if attributes[:'maintenance_window_details']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#autonomous_data_storage_size_in_tbsFloat

The data disk group size to be allocated for Autonomous Databases, in TBs.

Returns:

  • (Float)


60
61
62
# File 'lib/oci/database/models/create_autonomous_vm_cluster_details.rb', line 60

def autonomous_data_storage_size_in_tbs
  @autonomous_data_storage_size_in_tbs
end

#compartment_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.

Returns:

  • (String)


18
19
20
# File 'lib/oci/database/models/create_autonomous_vm_cluster_details.rb', line 18

def compartment_id
  @compartment_id
end

#cpu_core_count_per_nodeInteger

The number of OCPU cores to enable per VM cluster node.

Returns:

  • (Integer)


52
53
54
# File 'lib/oci/database/models/create_autonomous_vm_cluster_details.rb', line 52

def cpu_core_count_per_node
  @cpu_core_count_per_node
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Returns:

  • (Hash<String, Hash<String, Object>>)


77
78
79
# File 'lib/oci/database/models/create_autonomous_vm_cluster_details.rb', line 77

def defined_tags
  @defined_tags
end

#display_nameString

**[Required]** The user-friendly name for the Autonomous VM cluster. The name does not need to be unique.

Returns:

  • (String)


22
23
24
# File 'lib/oci/database/models/create_autonomous_vm_cluster_details.rb', line 22

def display_name
  @display_name
end

#exadata_infrastructure_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Exadata infrastructure.

Returns:

  • (String)


26
27
28
# File 'lib/oci/database/models/create_autonomous_vm_cluster_details.rb', line 26

def exadata_infrastructure_id
  @exadata_infrastructure_id
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: `"Finance"`

Returns:

  • (Hash<String, String>)


71
72
73
# File 'lib/oci/database/models/create_autonomous_vm_cluster_details.rb', line 71

def freeform_tags
  @freeform_tags
end

#is_local_backup_enabledBOOLEAN

If true, database backup on local Exadata storage is configured for the Autonomous VM cluster. If false, database backup on local Exadata storage is not available in the Autonomous VM cluster.

Returns:

  • (BOOLEAN)


39
40
41
# File 'lib/oci/database/models/create_autonomous_vm_cluster_details.rb', line 39

def is_local_backup_enabled
  @is_local_backup_enabled
end

#license_modelString

The Oracle license model that applies to the Autonomous VM cluster. The default is BRING_YOUR_OWN_LICENSE.

Returns:

  • (String)


44
45
46
# File 'lib/oci/database/models/create_autonomous_vm_cluster_details.rb', line 44

def license_model
  @license_model
end

#maintenance_window_detailsOCI::Database::Models::MaintenanceWindow



63
64
65
# File 'lib/oci/database/models/create_autonomous_vm_cluster_details.rb', line 63

def maintenance_window_details
  @maintenance_window_details
end

#memory_per_oracle_compute_unit_in_gbsInteger

The amount of memory (in GBs) to be enabled per each OCPU core.

Returns:

  • (Integer)


56
57
58
# File 'lib/oci/database/models/create_autonomous_vm_cluster_details.rb', line 56

def memory_per_oracle_compute_unit_in_gbs
  @memory_per_oracle_compute_unit_in_gbs
end

#time_zoneString

The time zone to use for the Autonomous VM cluster. For details, see [DB System Time Zones](docs.cloud.oracle.com/Content/Database/References/timezones.htm).

Returns:

  • (String)


34
35
36
# File 'lib/oci/database/models/create_autonomous_vm_cluster_details.rb', line 34

def time_zone
  @time_zone
end

#total_container_databasesInteger

The total number of Autonomous Container Databases that can be created.

Returns:

  • (Integer)


48
49
50
# File 'lib/oci/database/models/create_autonomous_vm_cluster_details.rb', line 48

def total_container_databases
  @total_container_databases
end

#vm_cluster_network_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VM cluster network.

Returns:

  • (String)


30
31
32
# File 'lib/oci/database/models/create_autonomous_vm_cluster_details.rb', line 30

def vm_cluster_network_id
  @vm_cluster_network_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/oci/database/models/create_autonomous_vm_cluster_details.rb', line 80

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'compartmentId',
    'display_name': :'displayName',
    'exadata_infrastructure_id': :'exadataInfrastructureId',
    'vm_cluster_network_id': :'vmClusterNetworkId',
    'time_zone': :'timeZone',
    'is_local_backup_enabled': :'isLocalBackupEnabled',
    'license_model': :'licenseModel',
    'total_container_databases': :'totalContainerDatabases',
    'cpu_core_count_per_node': :'cpuCoreCountPerNode',
    'memory_per_oracle_compute_unit_in_gbs': :'memoryPerOracleComputeUnitInGBs',
    'autonomous_data_storage_size_in_tbs': :'autonomousDataStorageSizeInTBs',
    'maintenance_window_details': :'maintenanceWindowDetails',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/oci/database/models/create_autonomous_vm_cluster_details.rb', line 102

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'String',
    'display_name': :'String',
    'exadata_infrastructure_id': :'String',
    'vm_cluster_network_id': :'String',
    'time_zone': :'String',
    'is_local_backup_enabled': :'BOOLEAN',
    'license_model': :'String',
    'total_container_databases': :'Integer',
    'cpu_core_count_per_node': :'Integer',
    'memory_per_oracle_compute_unit_in_gbs': :'Integer',
    'autonomous_data_storage_size_in_tbs': :'Float',
    'maintenance_window_details': :'OCI::Database::Models::MaintenanceWindow',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
# File 'lib/oci/database/models/create_autonomous_vm_cluster_details.rb', line 249

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    compartment_id == other.compartment_id &&
    display_name == other.display_name &&
    exadata_infrastructure_id == other.exadata_infrastructure_id &&
    vm_cluster_network_id == other.vm_cluster_network_id &&
    time_zone == other.time_zone &&
    is_local_backup_enabled == other.is_local_backup_enabled &&
    license_model == other.license_model &&
    total_container_databases == other.total_container_databases &&
    cpu_core_count_per_node == other.cpu_core_count_per_node &&
    memory_per_oracle_compute_unit_in_gbs == other.memory_per_oracle_compute_unit_in_gbs &&
    autonomous_data_storage_size_in_tbs == other.autonomous_data_storage_size_in_tbs &&
    maintenance_window_details == other.maintenance_window_details &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/oci/database/models/create_autonomous_vm_cluster_details.rb', line 292

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


272
273
274
# File 'lib/oci/database/models/create_autonomous_vm_cluster_details.rb', line 272

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



281
282
283
# File 'lib/oci/database/models/create_autonomous_vm_cluster_details.rb', line 281

def hash
  [compartment_id, display_name, exadata_infrastructure_id, vm_cluster_network_id, time_zone, is_local_backup_enabled, license_model, total_container_databases, cpu_core_count_per_node, memory_per_oracle_compute_unit_in_gbs, autonomous_data_storage_size_in_tbs, maintenance_window_details, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



325
326
327
328
329
330
331
332
333
334
# File 'lib/oci/database/models/create_autonomous_vm_cluster_details.rb', line 325

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



319
320
321
# File 'lib/oci/database/models/create_autonomous_vm_cluster_details.rb', line 319

def to_s
  to_hash.to_s
end