Class: OCI::Database::Models::CreateCloudAutonomousVmClusterDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database/models/create_cloud_autonomous_vm_cluster_details.rb

Overview

Details for the create cloud Autonomous VM cluster operation.

Constant Summary collapse

LICENSE_MODEL_ENUM =
[
  LICENSE_MODEL_LICENSE_INCLUDED = 'LICENSE_INCLUDED'.freeze,
  LICENSE_MODEL_BRING_YOUR_OWN_LICENSE = 'BRING_YOUR_OWN_LICENSE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateCloudAutonomousVmClusterDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :description (String)

    The value to assign to the #description property

  • :subnet_id (String)

    The value to assign to the #subnet_id property

  • :display_name (String)

    The value to assign to the #display_name property

  • :cloud_exadata_infrastructure_id (String)

    The value to assign to the #cloud_exadata_infrastructure_id property

  • :cluster_time_zone (String)

    The value to assign to the #cluster_time_zone property

  • :license_model (String)

    The value to assign to the #license_model property

  • :nsg_ids (Array<String>)

    The value to assign to the #nsg_ids property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'lib/oci/database/models/create_cloud_autonomous_vm_cluster_details.rb', line 122

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.description = attributes[:'description'] if attributes[:'description']

  self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId']

  raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id')

  self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.cloud_exadata_infrastructure_id = attributes[:'cloudExadataInfrastructureId'] if attributes[:'cloudExadataInfrastructureId']

  raise 'You cannot provide both :cloudExadataInfrastructureId and :cloud_exadata_infrastructure_id' if attributes.key?(:'cloudExadataInfrastructureId') && attributes.key?(:'cloud_exadata_infrastructure_id')

  self.cloud_exadata_infrastructure_id = attributes[:'cloud_exadata_infrastructure_id'] if attributes[:'cloud_exadata_infrastructure_id']

  self.cluster_time_zone = attributes[:'clusterTimeZone'] if attributes[:'clusterTimeZone']
  self.cluster_time_zone = "Etc/UTC" if cluster_time_zone.nil? && !attributes.key?(:'clusterTimeZone') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :clusterTimeZone and :cluster_time_zone' if attributes.key?(:'clusterTimeZone') && attributes.key?(:'cluster_time_zone')

  self.cluster_time_zone = attributes[:'cluster_time_zone'] if attributes[:'cluster_time_zone']
  self.cluster_time_zone = "Etc/UTC" if cluster_time_zone.nil? && !attributes.key?(:'clusterTimeZone') && !attributes.key?(:'cluster_time_zone') # rubocop:disable Style/StringLiterals

  self.license_model = attributes[:'licenseModel'] if attributes[:'licenseModel']

  raise 'You cannot provide both :licenseModel and :license_model' if attributes.key?(:'licenseModel') && attributes.key?(:'license_model')

  self.license_model = attributes[:'license_model'] if attributes[:'license_model']

  self.nsg_ids = attributes[:'nsgIds'] if attributes[:'nsgIds']

  raise 'You cannot provide both :nsgIds and :nsg_ids' if attributes.key?(:'nsgIds') && attributes.key?(:'nsg_ids')

  self.nsg_ids = attributes[:'nsg_ids'] if attributes[:'nsg_ids']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#cloud_exadata_infrastructure_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the cloud Exadata infrastructure.

Returns:

  • (String)


35
36
37
# File 'lib/oci/database/models/create_cloud_autonomous_vm_cluster_details.rb', line 35

def cloud_exadata_infrastructure_id
  @cloud_exadata_infrastructure_id
end

#cluster_time_zoneString

The time zone to use for the Cloud Autonomous VM cluster. For details, see [DB System Time Zones](docs.cloud.oracle.com/Content/Database/References/timezones.htm).

Returns:

  • (String)


39
40
41
# File 'lib/oci/database/models/create_cloud_autonomous_vm_cluster_details.rb', line 39

def cluster_time_zone
  @cluster_time_zone
end

#compartment_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.

Returns:

  • (String)


18
19
20
# File 'lib/oci/database/models/create_cloud_autonomous_vm_cluster_details.rb', line 18

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Returns:

  • (Hash<String, Hash<String, Object>>)


68
69
70
# File 'lib/oci/database/models/create_cloud_autonomous_vm_cluster_details.rb', line 68

def defined_tags
  @defined_tags
end

#descriptionString

User defined description of the cloud Autonomous VM cluster.

Returns:

  • (String)


22
23
24
# File 'lib/oci/database/models/create_cloud_autonomous_vm_cluster_details.rb', line 22

def description
  @description
end

#display_nameString

**[Required]** The user-friendly name for the cloud Autonomous VM cluster. The name does not need to be unique.

Returns:

  • (String)


31
32
33
# File 'lib/oci/database/models/create_cloud_autonomous_vm_cluster_details.rb', line 31

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: `"Finance"`

Returns:

  • (Hash<String, String>)


62
63
64
# File 'lib/oci/database/models/create_cloud_autonomous_vm_cluster_details.rb', line 62

def freeform_tags
  @freeform_tags
end

#license_modelString

The Oracle license model that applies to the Oracle Autonomous Database. Bring your own license (BYOL) allows you to apply your current on-premises Oracle software licenses to equivalent, highly automated Oracle PaaS and IaaS services in the cloud. License Included allows you to subscribe to new Oracle Database software licenses and the Database service. Note that when provisioning an Autonomous Database on [dedicated Exadata infrastructure](docs.oracle.com/en/cloud/paas/autonomous-database/index.html), this attribute must be null because the attribute is already set at the Autonomous Exadata Infrastructure level. When using [shared Exadata infrastructure](docs.oracle.com/en/cloud/paas/autonomous-database/index.html), if a value is not specified, the system will supply the value of `BRING_YOUR_OWN_LICENSE`.

Returns:

  • (String)


47
48
49
# File 'lib/oci/database/models/create_cloud_autonomous_vm_cluster_details.rb', line 47

def license_model
  @license_model
end

#nsg_idsArray<String>

The list of [OCIDs](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) for the network security groups (NSGs) to which this resource belongs. Setting this to an empty list removes all resources from all NSGs. For more information about NSGs, see [Security Rules](docs.cloud.oracle.com/Content/Network/Concepts/securityrules.htm). **NsgIds restrictions:**

  • A network security group (NSG) is optional for Autonomous Databases with private access. The nsgIds list can be empty.

Returns:

  • (Array<String>)


54
55
56
# File 'lib/oci/database/models/create_cloud_autonomous_vm_cluster_details.rb', line 54

def nsg_ids
  @nsg_ids
end

#subnet_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the subnet the cloud Autonomous VM Cluster is associated with.

Returns:

  • (String)


27
28
29
# File 'lib/oci/database/models/create_cloud_autonomous_vm_cluster_details.rb', line 27

def subnet_id
  @subnet_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/oci/database/models/create_cloud_autonomous_vm_cluster_details.rb', line 71

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'compartmentId',
    'description': :'description',
    'subnet_id': :'subnetId',
    'display_name': :'displayName',
    'cloud_exadata_infrastructure_id': :'cloudExadataInfrastructureId',
    'cluster_time_zone': :'clusterTimeZone',
    'license_model': :'licenseModel',
    'nsg_ids': :'nsgIds',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/oci/database/models/create_cloud_autonomous_vm_cluster_details.rb', line 89

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'String',
    'description': :'String',
    'subnet_id': :'String',
    'display_name': :'String',
    'cloud_exadata_infrastructure_id': :'String',
    'cluster_time_zone': :'String',
    'license_model': :'String',
    'nsg_ids': :'Array<String>',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/oci/database/models/create_cloud_autonomous_vm_cluster_details.rb', line 202

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    compartment_id == other.compartment_id &&
    description == other.description &&
    subnet_id == other.subnet_id &&
    display_name == other.display_name &&
    cloud_exadata_infrastructure_id == other.cloud_exadata_infrastructure_id &&
    cluster_time_zone == other.cluster_time_zone &&
    license_model == other.license_model &&
    nsg_ids == other.nsg_ids &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/oci/database/models/create_cloud_autonomous_vm_cluster_details.rb', line 241

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


221
222
223
# File 'lib/oci/database/models/create_cloud_autonomous_vm_cluster_details.rb', line 221

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



230
231
232
# File 'lib/oci/database/models/create_cloud_autonomous_vm_cluster_details.rb', line 230

def hash
  [compartment_id, description, subnet_id, display_name, cloud_exadata_infrastructure_id, cluster_time_zone, license_model, nsg_ids, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



274
275
276
277
278
279
280
281
282
283
# File 'lib/oci/database/models/create_cloud_autonomous_vm_cluster_details.rb', line 274

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



268
269
270
# File 'lib/oci/database/models/create_cloud_autonomous_vm_cluster_details.rb', line 268

def to_s
  to_hash.to_s
end