Class: OCI::Database::Models::CreateCloudExadataInfrastructureDetails
- Inherits:
-
Object
- Object
- OCI::Database::Models::CreateCloudExadataInfrastructureDetails
- Defined in:
- lib/oci/database/models/create_cloud_exadata_infrastructure_details.rb
Overview
Request to create cloud Exadata infrastructure. Applies to Exadata Cloud Service instances only.
Instance Attribute Summary collapse
-
#availability_domain ⇒ String
[Required] The availability domain where the cloud Exadata infrastructure is located.
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
-
#compute_count ⇒ Integer
The number of compute servers for the cloud Exadata infrastructure.
-
#customer_contacts ⇒ Array<OCI::Database::Models::CustomerContact>
Customer contacts.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
[Required] The user-friendly name for the cloud Exadata infrastructure resource.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
- #maintenance_window ⇒ OCI::Database::Models::MaintenanceWindow
-
#shape ⇒ String
[Required] The shape of the cloud Exadata infrastructure resource.
-
#storage_count ⇒ Integer
The number of storage servers for the cloud Exadata infrastructure.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateCloudExadataInfrastructureDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateCloudExadataInfrastructureDetails
Initializes the object
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/oci/database/models/create_cloud_exadata_infrastructure_details.rb', line 110 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain'] raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain') self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.shape = attributes[:'shape'] if attributes[:'shape'] self.compute_count = attributes[:'computeCount'] if attributes[:'computeCount'] raise 'You cannot provide both :computeCount and :compute_count' if attributes.key?(:'computeCount') && attributes.key?(:'compute_count') self.compute_count = attributes[:'compute_count'] if attributes[:'compute_count'] self.storage_count = attributes[:'storageCount'] if attributes[:'storageCount'] raise 'You cannot provide both :storageCount and :storage_count' if attributes.key?(:'storageCount') && attributes.key?(:'storage_count') self.storage_count = attributes[:'storage_count'] if attributes[:'storage_count'] self.maintenance_window = attributes[:'maintenanceWindow'] if attributes[:'maintenanceWindow'] raise 'You cannot provide both :maintenanceWindow and :maintenance_window' if attributes.key?(:'maintenanceWindow') && attributes.key?(:'maintenance_window') self.maintenance_window = attributes[:'maintenance_window'] if attributes[:'maintenance_window'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.customer_contacts = attributes[:'customerContacts'] if attributes[:'customerContacts'] raise 'You cannot provide both :customerContacts and :customer_contacts' if attributes.key?(:'customerContacts') && attributes.key?(:'customer_contacts') self.customer_contacts = attributes[:'customer_contacts'] if attributes[:'customer_contacts'] end |
Instance Attribute Details
#availability_domain ⇒ String
[Required] The availability domain where the cloud Exadata infrastructure is located.
13 14 15 |
# File 'lib/oci/database/models/create_cloud_exadata_infrastructure_details.rb', line 13 def availability_domain @availability_domain end |
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
17 18 19 |
# File 'lib/oci/database/models/create_cloud_exadata_infrastructure_details.rb', line 17 def compartment_id @compartment_id end |
#compute_count ⇒ Integer
The number of compute servers for the cloud Exadata infrastructure.
31 32 33 |
# File 'lib/oci/database/models/create_cloud_exadata_infrastructure_details.rb', line 31 def compute_count @compute_count end |
#customer_contacts ⇒ Array<OCI::Database::Models::CustomerContact>
Customer contacts.
56 57 58 |
# File 'lib/oci/database/models/create_cloud_exadata_infrastructure_details.rb', line 56 def customer_contacts @customer_contacts end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
52 53 54 |
# File 'lib/oci/database/models/create_cloud_exadata_infrastructure_details.rb', line 52 def end |
#display_name ⇒ String
[Required] The user-friendly name for the cloud Exadata infrastructure resource. The name does not need to be unique.
22 23 24 |
# File 'lib/oci/database/models/create_cloud_exadata_infrastructure_details.rb', line 22 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
46 47 48 |
# File 'lib/oci/database/models/create_cloud_exadata_infrastructure_details.rb', line 46 def end |
#maintenance_window ⇒ OCI::Database::Models::MaintenanceWindow
38 39 40 |
# File 'lib/oci/database/models/create_cloud_exadata_infrastructure_details.rb', line 38 def maintenance_window @maintenance_window end |
#shape ⇒ String
[Required] The shape of the cloud Exadata infrastructure resource.
27 28 29 |
# File 'lib/oci/database/models/create_cloud_exadata_infrastructure_details.rb', line 27 def shape @shape end |
#storage_count ⇒ Integer
The number of storage servers for the cloud Exadata infrastructure.
35 36 37 |
# File 'lib/oci/database/models/create_cloud_exadata_infrastructure_details.rb', line 35 def storage_count @storage_count end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/oci/database/models/create_cloud_exadata_infrastructure_details.rb', line 59 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'availability_domain': :'availabilityDomain', 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'shape': :'shape', 'compute_count': :'computeCount', 'storage_count': :'storageCount', 'maintenance_window': :'maintenanceWindow', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'customer_contacts': :'customerContacts' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/oci/database/models/create_cloud_exadata_infrastructure_details.rb', line 77 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'availability_domain': :'String', 'compartment_id': :'String', 'display_name': :'String', 'shape': :'String', 'compute_count': :'Integer', 'storage_count': :'Integer', 'maintenance_window': :'OCI::Database::Models::MaintenanceWindow', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'customer_contacts': :'Array<OCI::Database::Models::CustomerContact>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/oci/database/models/create_cloud_exadata_infrastructure_details.rb', line 180 def ==(other) return true if equal?(other) self.class == other.class && availability_domain == other.availability_domain && compartment_id == other.compartment_id && display_name == other.display_name && shape == other.shape && compute_count == other.compute_count && storage_count == other.storage_count && maintenance_window == other.maintenance_window && == other. && == other. && customer_contacts == other.customer_contacts end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/oci/database/models/create_cloud_exadata_infrastructure_details.rb', line 219 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
199 200 201 |
# File 'lib/oci/database/models/create_cloud_exadata_infrastructure_details.rb', line 199 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
208 209 210 |
# File 'lib/oci/database/models/create_cloud_exadata_infrastructure_details.rb', line 208 def hash [availability_domain, compartment_id, display_name, shape, compute_count, storage_count, maintenance_window, , , customer_contacts].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
252 253 254 255 256 257 258 259 260 261 |
# File 'lib/oci/database/models/create_cloud_exadata_infrastructure_details.rb', line 252 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
246 247 248 |
# File 'lib/oci/database/models/create_cloud_exadata_infrastructure_details.rb', line 246 def to_s to_hash.to_s end |