Class: OCI::Database::Models::CreateCloudVmClusterDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database/models/create_cloud_vm_cluster_details.rb

Overview

Details for the create cloud VM cluster operation. Applies to Exadata Cloud Service instances only.

Constant Summary collapse

LICENSE_MODEL_ENUM =
[
  LICENSE_MODEL_LICENSE_INCLUDED = 'LICENSE_INCLUDED'.freeze,
  LICENSE_MODEL_BRING_YOUR_OWN_LICENSE = 'BRING_YOUR_OWN_LICENSE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateCloudVmClusterDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :subnet_id (String)

    The value to assign to the #subnet_id property

  • :backup_subnet_id (String)

    The value to assign to the #backup_subnet_id property

  • :cpu_core_count (Integer)

    The value to assign to the #cpu_core_count property

  • :ocpu_count (Float)

    The value to assign to the #ocpu_count property

  • :cluster_name (String)

    The value to assign to the #cluster_name property

  • :data_storage_percentage (Integer)

    The value to assign to the #data_storage_percentage property

  • :display_name (String)

    The value to assign to the #display_name property

  • :cloud_exadata_infrastructure_id (String)

    The value to assign to the #cloud_exadata_infrastructure_id property

  • :hostname (String)

    The value to assign to the #hostname property

  • :domain (String)

    The value to assign to the #domain property

  • :ssh_public_keys (Array<String>)

    The value to assign to the #ssh_public_keys property

  • :license_model (String)

    The value to assign to the #license_model property

  • :is_sparse_diskgroup_enabled (BOOLEAN)

    The value to assign to the #is_sparse_diskgroup_enabled property

  • :is_local_backup_enabled (BOOLEAN)

    The value to assign to the #is_local_backup_enabled property

  • :time_zone (String)

    The value to assign to the #time_zone property

  • :scan_listener_port_tcp (Integer)

    The value to assign to the #scan_listener_port_tcp property

  • :scan_listener_port_tcp_ssl (Integer)

    The value to assign to the #scan_listener_port_tcp_ssl property

  • :nsg_ids (Array<String>)

    The value to assign to the #nsg_ids property

  • :backup_network_nsg_ids (Array<String>)

    The value to assign to the #backup_network_nsg_ids property

  • :gi_version (String)

    The value to assign to the #gi_version property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property



238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 238

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId']

  raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id')

  self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id']

  self.backup_subnet_id = attributes[:'backupSubnetId'] if attributes[:'backupSubnetId']

  raise 'You cannot provide both :backupSubnetId and :backup_subnet_id' if attributes.key?(:'backupSubnetId') && attributes.key?(:'backup_subnet_id')

  self.backup_subnet_id = attributes[:'backup_subnet_id'] if attributes[:'backup_subnet_id']

  self.cpu_core_count = attributes[:'cpuCoreCount'] if attributes[:'cpuCoreCount']

  raise 'You cannot provide both :cpuCoreCount and :cpu_core_count' if attributes.key?(:'cpuCoreCount') && attributes.key?(:'cpu_core_count')

  self.cpu_core_count = attributes[:'cpu_core_count'] if attributes[:'cpu_core_count']

  self.ocpu_count = attributes[:'ocpuCount'] if attributes[:'ocpuCount']

  raise 'You cannot provide both :ocpuCount and :ocpu_count' if attributes.key?(:'ocpuCount') && attributes.key?(:'ocpu_count')

  self.ocpu_count = attributes[:'ocpu_count'] if attributes[:'ocpu_count']

  self.cluster_name = attributes[:'clusterName'] if attributes[:'clusterName']

  raise 'You cannot provide both :clusterName and :cluster_name' if attributes.key?(:'clusterName') && attributes.key?(:'cluster_name')

  self.cluster_name = attributes[:'cluster_name'] if attributes[:'cluster_name']

  self.data_storage_percentage = attributes[:'dataStoragePercentage'] if attributes[:'dataStoragePercentage']

  raise 'You cannot provide both :dataStoragePercentage and :data_storage_percentage' if attributes.key?(:'dataStoragePercentage') && attributes.key?(:'data_storage_percentage')

  self.data_storage_percentage = attributes[:'data_storage_percentage'] if attributes[:'data_storage_percentage']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.cloud_exadata_infrastructure_id = attributes[:'cloudExadataInfrastructureId'] if attributes[:'cloudExadataInfrastructureId']

  raise 'You cannot provide both :cloudExadataInfrastructureId and :cloud_exadata_infrastructure_id' if attributes.key?(:'cloudExadataInfrastructureId') && attributes.key?(:'cloud_exadata_infrastructure_id')

  self.cloud_exadata_infrastructure_id = attributes[:'cloud_exadata_infrastructure_id'] if attributes[:'cloud_exadata_infrastructure_id']

  self.hostname = attributes[:'hostname'] if attributes[:'hostname']

  self.domain = attributes[:'domain'] if attributes[:'domain']

  self.ssh_public_keys = attributes[:'sshPublicKeys'] if attributes[:'sshPublicKeys']

  raise 'You cannot provide both :sshPublicKeys and :ssh_public_keys' if attributes.key?(:'sshPublicKeys') && attributes.key?(:'ssh_public_keys')

  self.ssh_public_keys = attributes[:'ssh_public_keys'] if attributes[:'ssh_public_keys']

  self.license_model = attributes[:'licenseModel'] if attributes[:'licenseModel']

  raise 'You cannot provide both :licenseModel and :license_model' if attributes.key?(:'licenseModel') && attributes.key?(:'license_model')

  self.license_model = attributes[:'license_model'] if attributes[:'license_model']

  self.is_sparse_diskgroup_enabled = attributes[:'isSparseDiskgroupEnabled'] unless attributes[:'isSparseDiskgroupEnabled'].nil?

  raise 'You cannot provide both :isSparseDiskgroupEnabled and :is_sparse_diskgroup_enabled' if attributes.key?(:'isSparseDiskgroupEnabled') && attributes.key?(:'is_sparse_diskgroup_enabled')

  self.is_sparse_diskgroup_enabled = attributes[:'is_sparse_diskgroup_enabled'] unless attributes[:'is_sparse_diskgroup_enabled'].nil?

  self.is_local_backup_enabled = attributes[:'isLocalBackupEnabled'] unless attributes[:'isLocalBackupEnabled'].nil?

  raise 'You cannot provide both :isLocalBackupEnabled and :is_local_backup_enabled' if attributes.key?(:'isLocalBackupEnabled') && attributes.key?(:'is_local_backup_enabled')

  self.is_local_backup_enabled = attributes[:'is_local_backup_enabled'] unless attributes[:'is_local_backup_enabled'].nil?

  self.time_zone = attributes[:'timeZone'] if attributes[:'timeZone']

  raise 'You cannot provide both :timeZone and :time_zone' if attributes.key?(:'timeZone') && attributes.key?(:'time_zone')

  self.time_zone = attributes[:'time_zone'] if attributes[:'time_zone']

  self.scan_listener_port_tcp = attributes[:'scanListenerPortTcp'] if attributes[:'scanListenerPortTcp']

  raise 'You cannot provide both :scanListenerPortTcp and :scan_listener_port_tcp' if attributes.key?(:'scanListenerPortTcp') && attributes.key?(:'scan_listener_port_tcp')

  self.scan_listener_port_tcp = attributes[:'scan_listener_port_tcp'] if attributes[:'scan_listener_port_tcp']

  self.scan_listener_port_tcp_ssl = attributes[:'scanListenerPortTcpSsl'] if attributes[:'scanListenerPortTcpSsl']

  raise 'You cannot provide both :scanListenerPortTcpSsl and :scan_listener_port_tcp_ssl' if attributes.key?(:'scanListenerPortTcpSsl') && attributes.key?(:'scan_listener_port_tcp_ssl')

  self.scan_listener_port_tcp_ssl = attributes[:'scan_listener_port_tcp_ssl'] if attributes[:'scan_listener_port_tcp_ssl']

  self.nsg_ids = attributes[:'nsgIds'] if attributes[:'nsgIds']

  raise 'You cannot provide both :nsgIds and :nsg_ids' if attributes.key?(:'nsgIds') && attributes.key?(:'nsg_ids')

  self.nsg_ids = attributes[:'nsg_ids'] if attributes[:'nsg_ids']

  self.backup_network_nsg_ids = attributes[:'backupNetworkNsgIds'] if attributes[:'backupNetworkNsgIds']

  raise 'You cannot provide both :backupNetworkNsgIds and :backup_network_nsg_ids' if attributes.key?(:'backupNetworkNsgIds') && attributes.key?(:'backup_network_nsg_ids')

  self.backup_network_nsg_ids = attributes[:'backup_network_nsg_ids'] if attributes[:'backup_network_nsg_ids']

  self.gi_version = attributes[:'giVersion'] if attributes[:'giVersion']

  raise 'You cannot provide both :giVersion and :gi_version' if attributes.key?(:'giVersion') && attributes.key?(:'gi_version')

  self.gi_version = attributes[:'gi_version'] if attributes[:'gi_version']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#backup_network_nsg_idsArray<String>

A list of the [OCIDs](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the network security groups (NSGs) that the backup network of this DB system belongs to. Setting this to an empty array after the list is created removes the resource from all NSGs. For more information about NSGs, see [Security Rules](docs.cloud.oracle.com/Content/Network/Concepts/securityrules.htm). Applicable only to Exadata systems.

Returns:

  • (Array<String>)


127
128
129
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 127

def backup_network_nsg_ids
  @backup_network_nsg_ids
end

#backup_subnet_idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the backup network subnet associated with the cloud VM cluster.

Returns:

  • (String)


28
29
30
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 28

def backup_subnet_id
  @backup_subnet_id
end

#cloud_exadata_infrastructure_idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the cloud Exadata infrastructure resource.

Returns:

  • (String)


64
65
66
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 64

def cloud_exadata_infrastructure_id
  @cloud_exadata_infrastructure_id
end

#cluster_nameString

The cluster name for cloud VM cluster. The cluster name must begin with an alphabetic character, and may contain hyphens (-). Underscores (_) are not permitted. The cluster name can be no longer than 11 characters and is not case sensitive.

Returns:

  • (String)


50
51
52
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 50

def cluster_name
  @cluster_name
end

#compartment_idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.

Returns:

  • (String)


18
19
20
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 18

def compartment_id
  @compartment_id
end

#cpu_core_countInteger

[Required] The number of CPU cores to enable for a cloud VM cluster. Valid values depend on the specified shape:

  • Exadata.Base.48 - Specify a multiple of 2, from 0 to 48.

  • Exadata.Quarter1.84 - Specify a multiple of 2, from 22 to 84.

  • Exadata.Half1.168 - Specify a multiple of 4, from 44 to 168.

  • Exadata.Full1.336 - Specify a multiple of 8, from 88 to 336.

  • Exadata.Quarter2.92 - Specify a multiple of 2, from 0 to 92.

  • Exadata.Half2.184 - Specify a multiple of 4, from 0 to 184.

  • Exadata.Full2.368 - Specify a multiple of 8, from 0 to 368.

Returns:

  • (Integer)


41
42
43
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 41

def cpu_core_count
  @cpu_core_count
end

#data_storage_percentageInteger

The percentage assigned to DATA storage (user data and database files). The remaining percentage is assigned to RECO storage (database redo logs, archive logs, and recovery manager backups). Accepted values are 35, 40, 60 and 80. The default is 80 percent assigned to DATA storage. See [Storage Configuration](docs.cloud.oracle.com/Content/Database/Concepts/exaoverview.htm#Exadata) in the Exadata documentation for details on the impact of the configuration settings on storage.

Returns:

  • (Integer)


56
57
58
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 56

def data_storage_percentage
  @data_storage_percentage
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Returns:

  • (Hash<String, Hash<String, Object>>)


145
146
147
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 145

def defined_tags
  @defined_tags
end

#display_nameString

[Required] The user-friendly name for the cloud VM cluster. The name does not need to be unique.

Returns:

  • (String)


60
61
62
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 60

def display_name
  @display_name
end

#domainString

A domain name used for the cloud VM cluster. If the Oracle-provided internet and VCN resolver is enabled for the specified subnet, the domain name for the subnet is used (do not provide one). Otherwise, provide a valid DNS domain name. Hyphens (-) are not permitted. Applies to Exadata Cloud Service instances only.

Returns:

  • (String)


83
84
85
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 83

def domain
  @domain
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: ‘"Finance"`

Returns:

  • (Hash<String, String>)


139
140
141
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 139

def freeform_tags
  @freeform_tags
end

#gi_versionString

[Required] A valid Oracle Grid Infrastructure (GI) software version.

Returns:

  • (String)


131
132
133
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 131

def gi_version
  @gi_version
end

#hostnameString

[Required] The hostname for the cloud VM cluster. The hostname must begin with an alphabetic character, and can contain alphanumeric characters and hyphens (-). The maximum length of the hostname is 16 characters for bare metal and virtual machine DB systems, and 12 characters for Exadata systems.

The maximum length of the combined hostname and domain is 63 characters.

Note: The hostname must be unique within the subnet. If it is not unique, the cloud VM Cluster will fail to provision.

Returns:

  • (String)


75
76
77
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 75

def hostname
  @hostname
end

#is_local_backup_enabledBOOLEAN

If true, database backup on local Exadata storage is configured for the cloud VM cluster. If false, database backup on local Exadata storage is not available in the cloud VM cluster.

Returns:

  • (BOOLEAN)


102
103
104
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 102

def is_local_backup_enabled
  @is_local_backup_enabled
end

#is_sparse_diskgroup_enabledBOOLEAN

If true, the sparse disk group is configured for the cloud VM cluster. If false, the sparse disk group is not created.

Returns:

  • (BOOLEAN)


97
98
99
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 97

def is_sparse_diskgroup_enabled
  @is_sparse_diskgroup_enabled
end

#license_modelString

The Oracle license model that applies to the cloud VM cluster. The default is BRING_YOUR_OWN_LICENSE.

Returns:

  • (String)


92
93
94
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 92

def license_model
  @license_model
end

#nsg_idsArray<String>

A list of the [OCIDs](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the network security groups (NSGs) that this resource belongs to. Setting this to an empty array after the list is created removes the resource from all NSGs. For more information about NSGs, see [Security Rules](docs.cloud.oracle.com/Content/Network/Concepts/securityrules.htm). **NsgIds restrictions:**

  • Autonomous Databases with private access require at least 1 Network Security Group (NSG). The nsgIds array cannot be empty.

Returns:

  • (Array<String>)


122
123
124
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 122

def nsg_ids
  @nsg_ids
end

#ocpu_countFloat

The number of OCPU cores to enable for a cloud VM cluster. Only 1 decimal place is allowed for the fractional part.

Returns:

  • (Float)


45
46
47
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 45

def ocpu_count
  @ocpu_count
end

#scan_listener_port_tcpInteger

The TCP Single Client Access Name (SCAN) port. The default port is 1521.

Returns:

  • (Integer)


111
112
113
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 111

def scan_listener_port_tcp
  @scan_listener_port_tcp
end

#scan_listener_port_tcp_sslInteger

The TCPS Single Client Access Name (SCAN) port. The default port is 2484.

Returns:

  • (Integer)


115
116
117
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 115

def scan_listener_port_tcp_ssl
  @scan_listener_port_tcp_ssl
end

#ssh_public_keysArray<String>

[Required] The public key portion of one or more key pairs used for SSH access to the cloud VM cluster.

Returns:

  • (Array<String>)


87
88
89
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 87

def ssh_public_keys
  @ssh_public_keys
end

#subnet_idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the subnet associated with the cloud VM cluster.

Returns:

  • (String)


23
24
25
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 23

def subnet_id
  @subnet_id
end

#time_zoneString

The time zone to use for the cloud VM cluster. For details, see [Time Zones](docs.cloud.oracle.com/Content/Database/References/timezones.htm).

Returns:

  • (String)


107
108
109
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 107

def time_zone
  @time_zone
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 148

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'compartmentId',
    'subnet_id': :'subnetId',
    'backup_subnet_id': :'backupSubnetId',
    'cpu_core_count': :'cpuCoreCount',
    'ocpu_count': :'ocpuCount',
    'cluster_name': :'clusterName',
    'data_storage_percentage': :'dataStoragePercentage',
    'display_name': :'displayName',
    'cloud_exadata_infrastructure_id': :'cloudExadataInfrastructureId',
    'hostname': :'hostname',
    'domain': :'domain',
    'ssh_public_keys': :'sshPublicKeys',
    'license_model': :'licenseModel',
    'is_sparse_diskgroup_enabled': :'isSparseDiskgroupEnabled',
    'is_local_backup_enabled': :'isLocalBackupEnabled',
    'time_zone': :'timeZone',
    'scan_listener_port_tcp': :'scanListenerPortTcp',
    'scan_listener_port_tcp_ssl': :'scanListenerPortTcpSsl',
    'nsg_ids': :'nsgIds',
    'backup_network_nsg_ids': :'backupNetworkNsgIds',
    'gi_version': :'giVersion',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 179

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'String',
    'subnet_id': :'String',
    'backup_subnet_id': :'String',
    'cpu_core_count': :'Integer',
    'ocpu_count': :'Float',
    'cluster_name': :'String',
    'data_storage_percentage': :'Integer',
    'display_name': :'String',
    'cloud_exadata_infrastructure_id': :'String',
    'hostname': :'String',
    'domain': :'String',
    'ssh_public_keys': :'Array<String>',
    'license_model': :'String',
    'is_sparse_diskgroup_enabled': :'BOOLEAN',
    'is_local_backup_enabled': :'BOOLEAN',
    'time_zone': :'String',
    'scan_listener_port_tcp': :'Integer',
    'scan_listener_port_tcp_ssl': :'Integer',
    'nsg_ids': :'Array<String>',
    'backup_network_nsg_ids': :'Array<String>',
    'gi_version': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 390

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    compartment_id == other.compartment_id &&
    subnet_id == other.subnet_id &&
    backup_subnet_id == other.backup_subnet_id &&
    cpu_core_count == other.cpu_core_count &&
    ocpu_count == other.ocpu_count &&
    cluster_name == other.cluster_name &&
    data_storage_percentage == other.data_storage_percentage &&
    display_name == other.display_name &&
    cloud_exadata_infrastructure_id == other.cloud_exadata_infrastructure_id &&
    hostname == other.hostname &&
    domain == other.domain &&
    ssh_public_keys == other.ssh_public_keys &&
    license_model == other.license_model &&
    is_sparse_diskgroup_enabled == other.is_sparse_diskgroup_enabled &&
    is_local_backup_enabled == other.is_local_backup_enabled &&
    time_zone == other.time_zone &&
    scan_listener_port_tcp == other.scan_listener_port_tcp &&
    scan_listener_port_tcp_ssl == other.scan_listener_port_tcp_ssl &&
    nsg_ids == other.nsg_ids &&
    backup_network_nsg_ids == other.backup_network_nsg_ids &&
    gi_version == other.gi_version &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 442

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


422
423
424
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 422

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



431
432
433
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 431

def hash
  [compartment_id, subnet_id, backup_subnet_id, cpu_core_count, ocpu_count, cluster_name, data_storage_percentage, display_name, cloud_exadata_infrastructure_id, hostname, domain, ssh_public_keys, license_model, is_sparse_diskgroup_enabled, is_local_backup_enabled, time_zone, scan_listener_port_tcp, scan_listener_port_tcp_ssl, nsg_ids, backup_network_nsg_ids, gi_version, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



475
476
477
478
479
480
481
482
483
484
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 475

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



469
470
471
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 469

def to_s
  to_hash.to_s
end