Class: OCI::Database::Models::CreateDataGuardAssociationDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database/models/create_data_guard_association_details.rb

Overview

The configuration details for creating a Data Guard association between databases.

Warning: Oracle recommends that you avoid using any confidential information when you supply string values using the API.

This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class

Constant Summary collapse

PROTECTION_MODE_ENUM =
[
  PROTECTION_MODE_MAXIMUM_AVAILABILITY = 'MAXIMUM_AVAILABILITY'.freeze,
  PROTECTION_MODE_MAXIMUM_PERFORMANCE = 'MAXIMUM_PERFORMANCE'.freeze,
  PROTECTION_MODE_MAXIMUM_PROTECTION = 'MAXIMUM_PROTECTION'.freeze
].freeze
TRANSPORT_TYPE_ENUM =
[
  TRANSPORT_TYPE_SYNC = 'SYNC'.freeze,
  TRANSPORT_TYPE_ASYNC = 'ASYNC'.freeze,
  TRANSPORT_TYPE_FASTSYNC = 'FASTSYNC'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateDataGuardAssociationDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/oci/database/models/create_data_guard_association_details.rb', line 153

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.database_software_image_id = attributes[:'databaseSoftwareImageId'] if attributes[:'databaseSoftwareImageId']

  raise 'You cannot provide both :databaseSoftwareImageId and :database_software_image_id' if attributes.key?(:'databaseSoftwareImageId') && attributes.key?(:'database_software_image_id')

  self.database_software_image_id = attributes[:'database_software_image_id'] if attributes[:'database_software_image_id']

  self.database_admin_password = attributes[:'databaseAdminPassword'] if attributes[:'databaseAdminPassword']

  raise 'You cannot provide both :databaseAdminPassword and :database_admin_password' if attributes.key?(:'databaseAdminPassword') && attributes.key?(:'database_admin_password')

  self.database_admin_password = attributes[:'database_admin_password'] if attributes[:'database_admin_password']

  self.protection_mode = attributes[:'protectionMode'] if attributes[:'protectionMode']

  raise 'You cannot provide both :protectionMode and :protection_mode' if attributes.key?(:'protectionMode') && attributes.key?(:'protection_mode')

  self.protection_mode = attributes[:'protection_mode'] if attributes[:'protection_mode']

  self.transport_type = attributes[:'transportType'] if attributes[:'transportType']

  raise 'You cannot provide both :transportType and :transport_type' if attributes.key?(:'transportType') && attributes.key?(:'transport_type')

  self.transport_type = attributes[:'transport_type'] if attributes[:'transport_type']

  self.creation_type = attributes[:'creationType'] if attributes[:'creationType']

  raise 'You cannot provide both :creationType and :creation_type' if attributes.key?(:'creationType') && attributes.key?(:'creation_type')

  self.creation_type = attributes[:'creation_type'] if attributes[:'creation_type']

  self.is_active_data_guard_enabled = attributes[:'isActiveDataGuardEnabled'] unless attributes[:'isActiveDataGuardEnabled'].nil?

  raise 'You cannot provide both :isActiveDataGuardEnabled and :is_active_data_guard_enabled' if attributes.key?(:'isActiveDataGuardEnabled') && attributes.key?(:'is_active_data_guard_enabled')

  self.is_active_data_guard_enabled = attributes[:'is_active_data_guard_enabled'] unless attributes[:'is_active_data_guard_enabled'].nil?

  self.peer_db_unique_name = attributes[:'peerDbUniqueName'] if attributes[:'peerDbUniqueName']

  raise 'You cannot provide both :peerDbUniqueName and :peer_db_unique_name' if attributes.key?(:'peerDbUniqueName') && attributes.key?(:'peer_db_unique_name')

  self.peer_db_unique_name = attributes[:'peer_db_unique_name'] if attributes[:'peer_db_unique_name']

  self.peer_sid_prefix = attributes[:'peerSidPrefix'] if attributes[:'peerSidPrefix']

  raise 'You cannot provide both :peerSidPrefix and :peer_sid_prefix' if attributes.key?(:'peerSidPrefix') && attributes.key?(:'peer_sid_prefix')

  self.peer_sid_prefix = attributes[:'peer_sid_prefix'] if attributes[:'peer_sid_prefix']
end

Instance Attribute Details

#creation_typeString

[Required] Specifies whether to create the peer database in an existing DB system or in a new DB system.

Returns:

  • (String)


74
75
76
# File 'lib/oci/database/models/create_data_guard_association_details.rb', line 74

def creation_type
  @creation_type
end

#database_admin_passwordString

[Required] A strong password for the SYS, SYSTEM, and ‘PDB Admin` users to apply during standby creation.

The password must contain no fewer than nine characters and include:

  • At least two uppercase characters.

  • At least two lowercase characters.

  • At least two numeric characters.

  • At least two special characters. Valid special characters include "_", "#", and "-" only.

**The password MUST be the same as the primary admin password.**

Returns:

  • (String)


45
46
47
# File 'lib/oci/database/models/create_data_guard_association_details.rb', line 45

def database_admin_password
  @database_admin_password
end

#database_software_image_idString

Returns:

  • (String)


28
29
30
# File 'lib/oci/database/models/create_data_guard_association_details.rb', line 28

def database_software_image_id
  @database_software_image_id
end

#is_active_data_guard_enabledBOOLEAN

True if active Data Guard is enabled.

Returns:

  • (BOOLEAN)


78
79
80
# File 'lib/oci/database/models/create_data_guard_association_details.rb', line 78

def is_active_data_guard_enabled
  @is_active_data_guard_enabled
end

#peer_db_unique_nameString

Specifies the DB_UNIQUE_NAME of the peer database to be created.

Returns:

  • (String)


83
84
85
# File 'lib/oci/database/models/create_data_guard_association_details.rb', line 83

def peer_db_unique_name
  @peer_db_unique_name
end

#peer_sid_prefixString

Specifies a prefix for the ‘Oracle SID` of the database to be created.

Returns:

  • (String)


88
89
90
# File 'lib/oci/database/models/create_data_guard_association_details.rb', line 88

def peer_sid_prefix
  @peer_sid_prefix
end

#protection_modeString

[Required] The protection mode to set up between the primary and standby databases. For more information, see [Oracle Data Guard Protection Modes](docs.oracle.com/database/122/SBYDB/oracle-data-guard-protection-modes.htm#SBYDB02000) in the Oracle Data Guard documentation.

IMPORTANT - The only protection mode currently supported by the Database service is MAXIMUM_PERFORMANCE.

Returns:

  • (String)


54
55
56
# File 'lib/oci/database/models/create_data_guard_association_details.rb', line 54

def protection_mode
  @protection_mode
end

#transport_typeString

[Required] The redo transport type to use for this Data Guard association. Valid values depend on the specified protectionMode:

  • MAXIMUM_AVAILABILITY - SYNC or FASTSYNC

  • MAXIMUM_PERFORMANCE - ASYNC

  • MAXIMUM_PROTECTION - SYNC

For more information, see [Redo Transport Services](docs.oracle.com/database/122/SBYDB/oracle-data-guard-redo-transport-services.htm#SBYDB00400) in the Oracle Data Guard documentation.

IMPORTANT - The only transport type currently supported by the Database service is ASYNC.

Returns:

  • (String)


69
70
71
# File 'lib/oci/database/models/create_data_guard_association_details.rb', line 69

def transport_type
  @transport_type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/oci/database/models/create_data_guard_association_details.rb', line 91

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'database_software_image_id': :'databaseSoftwareImageId',
    'database_admin_password': :'databaseAdminPassword',
    'protection_mode': :'protectionMode',
    'transport_type': :'transportType',
    'creation_type': :'creationType',
    'is_active_data_guard_enabled': :'isActiveDataGuardEnabled',
    'peer_db_unique_name': :'peerDbUniqueName',
    'peer_sid_prefix': :'peerSidPrefix'
    # rubocop:enable Style/SymbolLiteral
  }
end

.get_subtype(object_hash) ⇒ Object

Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.



127
128
129
130
131
132
133
134
135
136
# File 'lib/oci/database/models/create_data_guard_association_details.rb', line 127

def self.get_subtype(object_hash)
  type = object_hash[:'creationType'] # rubocop:disable Style/SymbolLiteral

  return 'OCI::Database::Models::CreateDataGuardAssociationWithNewDbSystemDetails' if type == 'NewDbSystem'
  return 'OCI::Database::Models::CreateDataGuardAssociationToExistingVmClusterDetails' if type == 'ExistingVmCluster'
  return 'OCI::Database::Models::CreateDataGuardAssociationToExistingDbSystemDetails' if type == 'ExistingDbSystem'

  # TODO: Log a warning when the subtype is not found.
  'OCI::Database::Models::CreateDataGuardAssociationDetails'
end

.swagger_typesObject

Attribute type mapping.



107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/oci/database/models/create_data_guard_association_details.rb', line 107

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'database_software_image_id': :'String',
    'database_admin_password': :'String',
    'protection_mode': :'String',
    'transport_type': :'String',
    'creation_type': :'String',
    'is_active_data_guard_enabled': :'BOOLEAN',
    'peer_db_unique_name': :'String',
    'peer_sid_prefix': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/oci/database/models/create_data_guard_association_details.rb', line 231

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    database_software_image_id == other.database_software_image_id &&
    database_admin_password == other.database_admin_password &&
    protection_mode == other.protection_mode &&
    transport_type == other.transport_type &&
    creation_type == other.creation_type &&
    is_active_data_guard_enabled == other.is_active_data_guard_enabled &&
    peer_db_unique_name == other.peer_db_unique_name &&
    peer_sid_prefix == other.peer_sid_prefix
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
# File 'lib/oci/database/models/create_data_guard_association_details.rb', line 268

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


248
249
250
# File 'lib/oci/database/models/create_data_guard_association_details.rb', line 248

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



257
258
259
# File 'lib/oci/database/models/create_data_guard_association_details.rb', line 257

def hash
  [database_software_image_id, database_admin_password, protection_mode, transport_type, creation_type, is_active_data_guard_enabled, peer_db_unique_name, peer_sid_prefix].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



301
302
303
304
305
306
307
308
309
310
# File 'lib/oci/database/models/create_data_guard_association_details.rb', line 301

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



295
296
297
# File 'lib/oci/database/models/create_data_guard_association_details.rb', line 295

def to_s
  to_hash.to_s
end