Class: OCI::Database::Models::CreateDatabaseFromBackupDetails
- Inherits:
-
Object
- Object
- OCI::Database::Models::CreateDatabaseFromBackupDetails
- Defined in:
- lib/oci/database/models/create_database_from_backup_details.rb
Overview
CreateDatabaseFromBackupDetails model.
Instance Attribute Summary collapse
-
#admin_password ⇒ String
[Required] A strong password for SYS, SYSTEM, PDB Admin and TDE Wallet.
-
#backup_id ⇒ String
[Required] The backup [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm).
-
#backup_tde_password ⇒ String
The password to open the TDE wallet.
-
#db_name ⇒ String
The display name of the database to be created from the backup.
-
#db_unique_name ⇒ String
The
DB_UNIQUE_NAMEof the Oracle Database being backed up. -
#sid_prefix ⇒ String
Specifies a prefix for the ‘Oracle SID` of the database to be created.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateDatabaseFromBackupDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateDatabaseFromBackupDetails
Initializes the object
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/oci/database/models/create_database_from_backup_details.rb', line 75 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.backup_id = attributes[:'backupId'] if attributes[:'backupId'] raise 'You cannot provide both :backupId and :backup_id' if attributes.key?(:'backupId') && attributes.key?(:'backup_id') self.backup_id = attributes[:'backup_id'] if attributes[:'backup_id'] self.backup_tde_password = attributes[:'backupTDEPassword'] if attributes[:'backupTDEPassword'] raise 'You cannot provide both :backupTDEPassword and :backup_tde_password' if attributes.key?(:'backupTDEPassword') && attributes.key?(:'backup_tde_password') self.backup_tde_password = attributes[:'backup_tde_password'] if attributes[:'backup_tde_password'] self.admin_password = attributes[:'adminPassword'] if attributes[:'adminPassword'] raise 'You cannot provide both :adminPassword and :admin_password' if attributes.key?(:'adminPassword') && attributes.key?(:'admin_password') self.admin_password = attributes[:'admin_password'] if attributes[:'admin_password'] self.db_unique_name = attributes[:'dbUniqueName'] if attributes[:'dbUniqueName'] raise 'You cannot provide both :dbUniqueName and :db_unique_name' if attributes.key?(:'dbUniqueName') && attributes.key?(:'db_unique_name') self.db_unique_name = attributes[:'db_unique_name'] if attributes[:'db_unique_name'] self.db_name = attributes[:'dbName'] if attributes[:'dbName'] raise 'You cannot provide both :dbName and :db_name' if attributes.key?(:'dbName') && attributes.key?(:'db_name') self.db_name = attributes[:'db_name'] if attributes[:'db_name'] self.sid_prefix = attributes[:'sidPrefix'] if attributes[:'sidPrefix'] raise 'You cannot provide both :sidPrefix and :sid_prefix' if attributes.key?(:'sidPrefix') && attributes.key?(:'sid_prefix') self.sid_prefix = attributes[:'sid_prefix'] if attributes[:'sid_prefix'] end |
Instance Attribute Details
#admin_password ⇒ String
[Required] A strong password for SYS, SYSTEM, PDB Admin and TDE Wallet. The password must be at least nine characters and contain at least two uppercase, two lowercase, two numbers, and two special characters. The special characters must be _, \#, or -.
20 21 22 |
# File 'lib/oci/database/models/create_database_from_backup_details.rb', line 20 def admin_password @admin_password end |
#backup_id ⇒ String
[Required] The backup [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm).
12 13 14 |
# File 'lib/oci/database/models/create_database_from_backup_details.rb', line 12 def backup_id @backup_id end |
#backup_tde_password ⇒ String
The password to open the TDE wallet.
16 17 18 |
# File 'lib/oci/database/models/create_database_from_backup_details.rb', line 16 def backup_tde_password @backup_tde_password end |
#db_name ⇒ String
The display name of the database to be created from the backup. It must begin with an alphabetic character and can contain a maximum of eight alphanumeric characters. Special characters are not permitted.
28 29 30 |
# File 'lib/oci/database/models/create_database_from_backup_details.rb', line 28 def db_name @db_name end |
#db_unique_name ⇒ String
The DB_UNIQUE_NAME of the Oracle Database being backed up.
24 25 26 |
# File 'lib/oci/database/models/create_database_from_backup_details.rb', line 24 def db_unique_name @db_unique_name end |
#sid_prefix ⇒ String
Specifies a prefix for the ‘Oracle SID` of the database to be created.
33 34 35 |
# File 'lib/oci/database/models/create_database_from_backup_details.rb', line 33 def sid_prefix @sid_prefix end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
36 37 38 39 40 41 42 43 44 45 46 47 |
# File 'lib/oci/database/models/create_database_from_backup_details.rb', line 36 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'backup_id': :'backupId', 'backup_tde_password': :'backupTDEPassword', 'admin_password': :'adminPassword', 'db_unique_name': :'dbUniqueName', 'db_name': :'dbName', 'sid_prefix': :'sidPrefix' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/oci/database/models/create_database_from_backup_details.rb', line 50 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'backup_id': :'String', 'backup_tde_password': :'String', 'admin_password': :'String', 'db_unique_name': :'String', 'db_name': :'String', 'sid_prefix': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/oci/database/models/create_database_from_backup_details.rb', line 125 def ==(other) return true if equal?(other) self.class == other.class && backup_id == other.backup_id && backup_tde_password == other.backup_tde_password && admin_password == other.admin_password && db_unique_name == other.db_unique_name && db_name == other.db_name && sid_prefix == other.sid_prefix end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/oci/database/models/create_database_from_backup_details.rb', line 160 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
140 141 142 |
# File 'lib/oci/database/models/create_database_from_backup_details.rb', line 140 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
149 150 151 |
# File 'lib/oci/database/models/create_database_from_backup_details.rb', line 149 def hash [backup_id, backup_tde_password, admin_password, db_unique_name, db_name, sid_prefix].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
193 194 195 196 197 198 199 200 201 202 |
# File 'lib/oci/database/models/create_database_from_backup_details.rb', line 193 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
187 188 189 |
# File 'lib/oci/database/models/create_database_from_backup_details.rb', line 187 def to_s to_hash.to_s end |