Class: OCI::Database::Models::CreateDatabaseSoftwareImageDetails
- Inherits:
-
Object
- Object
- OCI::Database::Models::CreateDatabaseSoftwareImageDetails
- Defined in:
- lib/oci/database/models/create_database_software_image_details.rb
Overview
Parameters for creating a database software image in the specified compartment.
Warning: Oracle recommends that you avoid using any confidential information when you supply string values using the API.
Constant Summary collapse
- IMAGE_SHAPE_FAMILY_ENUM =
[ IMAGE_SHAPE_FAMILY_VM_BM_SHAPE = 'VM_BM_SHAPE'.freeze, IMAGE_SHAPE_FAMILY_EXADATA_SHAPE = 'EXADATA_SHAPE'.freeze, IMAGE_SHAPE_FAMILY_EXACC_SHAPE = 'EXACC_SHAPE'.freeze ].freeze
- IMAGE_TYPE_ENUM =
[ IMAGE_TYPE_GRID_IMAGE = 'GRID_IMAGE'.freeze, IMAGE_TYPE_DATABASE_IMAGE = 'DATABASE_IMAGE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment the database software image belongs in.
-
#database_software_image_one_off_patches ⇒ Array<String>
List of one-off patches for Database Homes.
-
#database_version ⇒ String
The database version with which the database software image is to be built.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
[Required] The user-friendly name for the database software image.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#image_shape_family ⇒ String
To what shape the image is meant for.
-
#image_type ⇒ String
The type of software image.
-
#ls_inventory ⇒ String
output from lsinventory which will get passed as a string.
-
#patch_set ⇒ String
The PSU or PBP or Release Updates.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateDatabaseSoftwareImageDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateDatabaseSoftwareImageDetails
Initializes the object
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/oci/database/models/create_database_software_image_details.rb', line 122 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.database_version = attributes[:'databaseVersion'] if attributes[:'databaseVersion'] raise 'You cannot provide both :databaseVersion and :database_version' if attributes.key?(:'databaseVersion') && attributes.key?(:'database_version') self.database_version = attributes[:'database_version'] if attributes[:'database_version'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.image_shape_family = attributes[:'imageShapeFamily'] if attributes[:'imageShapeFamily'] self.image_shape_family = "VM_BM_SHAPE" if image_shape_family.nil? && !attributes.key?(:'imageShapeFamily') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :imageShapeFamily and :image_shape_family' if attributes.key?(:'imageShapeFamily') && attributes.key?(:'image_shape_family') self.image_shape_family = attributes[:'image_shape_family'] if attributes[:'image_shape_family'] self.image_shape_family = "VM_BM_SHAPE" if image_shape_family.nil? && !attributes.key?(:'imageShapeFamily') && !attributes.key?(:'image_shape_family') # rubocop:disable Style/StringLiterals self.image_type = attributes[:'imageType'] if attributes[:'imageType'] self.image_type = "DATABASE_IMAGE" if image_type.nil? && !attributes.key?(:'imageType') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :imageType and :image_type' if attributes.key?(:'imageType') && attributes.key?(:'image_type') self.image_type = attributes[:'image_type'] if attributes[:'image_type'] self.image_type = "DATABASE_IMAGE" if image_type.nil? && !attributes.key?(:'imageType') && !attributes.key?(:'image_type') # rubocop:disable Style/StringLiterals self.patch_set = attributes[:'patchSet'] if attributes[:'patchSet'] raise 'You cannot provide both :patchSet and :patch_set' if attributes.key?(:'patchSet') && attributes.key?(:'patch_set') self.patch_set = attributes[:'patch_set'] if attributes[:'patch_set'] self.database_software_image_one_off_patches = attributes[:'databaseSoftwareImageOneOffPatches'] if attributes[:'databaseSoftwareImageOneOffPatches'] raise 'You cannot provide both :databaseSoftwareImageOneOffPatches and :database_software_image_one_off_patches' if attributes.key?(:'databaseSoftwareImageOneOffPatches') && attributes.key?(:'database_software_image_one_off_patches') self.database_software_image_one_off_patches = attributes[:'database_software_image_one_off_patches'] if attributes[:'database_software_image_one_off_patches'] self.ls_inventory = attributes[:'lsInventory'] if attributes[:'lsInventory'] raise 'You cannot provide both :lsInventory and :ls_inventory' if attributes.key?(:'lsInventory') && attributes.key?(:'ls_inventory') self.ls_inventory = attributes[:'ls_inventory'] if attributes[:'ls_inventory'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment the database software image belongs in.
26 27 28 |
# File 'lib/oci/database/models/create_database_software_image_details.rb', line 26 def compartment_id @compartment_id end |
#database_software_image_one_off_patches ⇒ Array<String>
List of one-off patches for Database Homes.
50 51 52 |
# File 'lib/oci/database/models/create_database_software_image_details.rb', line 50 def database_software_image_one_off_patches @database_software_image_one_off_patches end |
#database_version ⇒ String
The database version with which the database software image is to be built.
30 31 32 |
# File 'lib/oci/database/models/create_database_software_image_details.rb', line 30 def database_version @database_version end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
68 69 70 |
# File 'lib/oci/database/models/create_database_software_image_details.rb', line 68 def @defined_tags end |
#display_name ⇒ String
[Required] The user-friendly name for the database software image. The name does not have to be unique.
34 35 36 |
# File 'lib/oci/database/models/create_database_software_image_details.rb', line 34 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
62 63 64 |
# File 'lib/oci/database/models/create_database_software_image_details.rb', line 62 def @freeform_tags end |
#image_shape_family ⇒ String
To what shape the image is meant for.
38 39 40 |
# File 'lib/oci/database/models/create_database_software_image_details.rb', line 38 def image_shape_family @image_shape_family end |
#image_type ⇒ String
The type of software image. Can be grid or database.
42 43 44 |
# File 'lib/oci/database/models/create_database_software_image_details.rb', line 42 def image_type @image_type end |
#ls_inventory ⇒ String
output from lsinventory which will get passed as a string
54 55 56 |
# File 'lib/oci/database/models/create_database_software_image_details.rb', line 54 def ls_inventory @ls_inventory end |
#patch_set ⇒ String
The PSU or PBP or Release Updates. To get a list of supported versions, use the list_db_versions operation.
46 47 48 |
# File 'lib/oci/database/models/create_database_software_image_details.rb', line 46 def patch_set @patch_set end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/oci/database/models/create_database_software_image_details.rb', line 71 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'database_version': :'databaseVersion', 'display_name': :'displayName', 'image_shape_family': :'imageShapeFamily', 'image_type': :'imageType', 'patch_set': :'patchSet', 'database_software_image_one_off_patches': :'databaseSoftwareImageOneOffPatches', 'ls_inventory': :'lsInventory', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/oci/database/models/create_database_software_image_details.rb', line 89 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'database_version': :'String', 'display_name': :'String', 'image_shape_family': :'String', 'image_type': :'String', 'patch_set': :'String', 'database_software_image_one_off_patches': :'Array<String>', 'ls_inventory': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/oci/database/models/create_database_software_image_details.rb', line 216 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && database_version == other.database_version && display_name == other.display_name && image_shape_family == other.image_shape_family && image_type == other.image_type && patch_set == other.patch_set && database_software_image_one_off_patches == other.database_software_image_one_off_patches && ls_inventory == other.ls_inventory && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/oci/database/models/create_database_software_image_details.rb', line 255 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
235 236 237 |
# File 'lib/oci/database/models/create_database_software_image_details.rb', line 235 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
244 245 246 |
# File 'lib/oci/database/models/create_database_software_image_details.rb', line 244 def hash [compartment_id, database_version, display_name, image_shape_family, image_type, patch_set, database_software_image_one_off_patches, ls_inventory, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
288 289 290 291 292 293 294 295 296 297 |
# File 'lib/oci/database/models/create_database_software_image_details.rb', line 288 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
282 283 284 |
# File 'lib/oci/database/models/create_database_software_image_details.rb', line 282 def to_s to_hash.to_s end |