Class: OCI::Database::Models::CreateDbHomeBase
- Inherits:
-
Object
- Object
- OCI::Database::Models::CreateDbHomeBase
- Defined in:
- lib/oci/database/models/create_db_home_base.rb
Overview
Details for creating a Database Home.
Warning: Oracle recommends that you avoid using any confidential information when you supply string values using the API.
This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
CreateDbHomeWithDbSystemIdDetails, CreateDbHomeWithDbSystemIdFromBackupDetails, CreateDbHomeWithDbSystemIdFromDatabaseDetails, CreateDbHomeWithVmClusterIdDetails, CreateDbHomeWithVmClusterIdFromBackupDetails
Constant Summary collapse
- SOURCE_ENUM =
[ SOURCE_NONE = 'NONE'.freeze, SOURCE_DB_BACKUP = 'DB_BACKUP'.freeze, SOURCE_DATABASE = 'DATABASE'.freeze, SOURCE_VM_CLUSTER_BACKUP = 'VM_CLUSTER_BACKUP'.freeze, SOURCE_VM_CLUSTER_NEW = 'VM_CLUSTER_NEW'.freeze ].freeze
Instance Attribute Summary collapse
-
#database_software_image_id ⇒ String
The database software image [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm).
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
The user-provided name of the Database Home.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#is_desupported_version ⇒ BOOLEAN
If true, the customer acknowledges that the specified Oracle Database software is an older release that is not currently supported by OCI.
-
#kms_key_id ⇒ String
The OCID of the key container that is used as the master encryption key in database transparent data encryption (TDE) operations.
-
#kms_key_version_id ⇒ String
The OCID of the key container version that is used in database transparent data encryption (TDE) operations KMS Key can have multiple key versions.
-
#source ⇒ String
The source of database: NONE for creating a new database.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateDbHomeBase
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateDbHomeBase
Initializes the object
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/oci/database/models/create_db_home_base.rb', line 127 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.kms_key_id = attributes[:'kmsKeyId'] if attributes[:'kmsKeyId'] raise 'You cannot provide both :kmsKeyId and :kms_key_id' if attributes.key?(:'kmsKeyId') && attributes.key?(:'kms_key_id') self.kms_key_id = attributes[:'kms_key_id'] if attributes[:'kms_key_id'] self.kms_key_version_id = attributes[:'kmsKeyVersionId'] if attributes[:'kmsKeyVersionId'] raise 'You cannot provide both :kmsKeyVersionId and :kms_key_version_id' if attributes.key?(:'kmsKeyVersionId') && attributes.key?(:'kms_key_version_id') self.kms_key_version_id = attributes[:'kms_key_version_id'] if attributes[:'kms_key_version_id'] self.database_software_image_id = attributes[:'databaseSoftwareImageId'] if attributes[:'databaseSoftwareImageId'] raise 'You cannot provide both :databaseSoftwareImageId and :database_software_image_id' if attributes.key?(:'databaseSoftwareImageId') && attributes.key?(:'database_software_image_id') self.database_software_image_id = attributes[:'database_software_image_id'] if attributes[:'database_software_image_id'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.source = attributes[:'source'] if attributes[:'source'] self.source = "NONE" if source.nil? && !attributes.key?(:'source') # rubocop:disable Style/StringLiterals self.is_desupported_version = attributes[:'isDesupportedVersion'] unless attributes[:'isDesupportedVersion'].nil? raise 'You cannot provide both :isDesupportedVersion and :is_desupported_version' if attributes.key?(:'isDesupportedVersion') && attributes.key?(:'is_desupported_version') self.is_desupported_version = attributes[:'is_desupported_version'] unless attributes[:'is_desupported_version'].nil? end |
Instance Attribute Details
#database_software_image_id ⇒ String
The database software image [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)
37 38 39 |
# File 'lib/oci/database/models/create_db_home_base.rb', line 37 def database_software_image_id @database_software_image_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
51 52 53 |
# File 'lib/oci/database/models/create_db_home_base.rb', line 51 def end |
#display_name ⇒ String
The user-provided name of the Database Home.
24 25 26 |
# File 'lib/oci/database/models/create_db_home_base.rb', line 24 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
45 46 47 |
# File 'lib/oci/database/models/create_db_home_base.rb', line 45 def end |
#is_desupported_version ⇒ BOOLEAN
If true, the customer acknowledges that the specified Oracle Database software is an older release that is not currently supported by OCI.
60 61 62 |
# File 'lib/oci/database/models/create_db_home_base.rb', line 60 def is_desupported_version @is_desupported_version end |
#kms_key_id ⇒ String
The OCID of the key container that is used as the master encryption key in database transparent data encryption (TDE) operations.
28 29 30 |
# File 'lib/oci/database/models/create_db_home_base.rb', line 28 def kms_key_id @kms_key_id end |
#kms_key_version_id ⇒ String
The OCID of the key container version that is used in database transparent data encryption (TDE) operations KMS Key can have multiple key versions. If none is specified, the current key version (latest) of the Key Id is used for the operation.
33 34 35 |
# File 'lib/oci/database/models/create_db_home_base.rb', line 33 def kms_key_version_id @kms_key_version_id end |
#source ⇒ String
The source of database: NONE for creating a new database. DB_BACKUP for creating a new database by restoring from a database backup.
56 57 58 |
# File 'lib/oci/database/models/create_db_home_base.rb', line 56 def source @source end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/oci/database/models/create_db_home_base.rb', line 63 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'kms_key_id': :'kmsKeyId', 'kms_key_version_id': :'kmsKeyVersionId', 'database_software_image_id': :'databaseSoftwareImageId', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'source': :'source', 'is_desupported_version': :'isDesupportedVersion' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/oci/database/models/create_db_home_base.rb', line 99 def self.get_subtype(object_hash) type = object_hash[:'source'] # rubocop:disable Style/SymbolLiteral return 'OCI::Database::Models::CreateDbHomeWithDbSystemIdFromDatabaseDetails' if type == 'DATABASE' return 'OCI::Database::Models::CreateDbHomeWithDbSystemIdFromBackupDetails' if type == 'DB_BACKUP' return 'OCI::Database::Models::CreateDbHomeWithVmClusterIdFromBackupDetails' if type == 'VM_CLUSTER_BACKUP' return 'OCI::Database::Models::CreateDbHomeWithDbSystemIdDetails' if type == 'NONE' return 'OCI::Database::Models::CreateDbHomeWithVmClusterIdDetails' if type == 'VM_CLUSTER_NEW' # TODO: Log a warning when the subtype is not found. 'OCI::Database::Models::CreateDbHomeBase' end |
.swagger_types ⇒ Object
Attribute type mapping.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/oci/database/models/create_db_home_base.rb', line 79 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'kms_key_id': :'String', 'kms_key_version_id': :'String', 'database_software_image_id': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'source': :'String', 'is_desupported_version': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/oci/database/models/create_db_home_base.rb', line 194 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && kms_key_id == other.kms_key_id && kms_key_version_id == other.kms_key_version_id && database_software_image_id == other.database_software_image_id && == other. && == other. && source == other.source && is_desupported_version == other.is_desupported_version end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/oci/database/models/create_db_home_base.rb', line 231 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
211 212 213 |
# File 'lib/oci/database/models/create_db_home_base.rb', line 211 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
220 221 222 |
# File 'lib/oci/database/models/create_db_home_base.rb', line 220 def hash [display_name, kms_key_id, kms_key_version_id, database_software_image_id, , , source, is_desupported_version].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
264 265 266 267 268 269 270 271 272 273 |
# File 'lib/oci/database/models/create_db_home_base.rb', line 264 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
258 259 260 |
# File 'lib/oci/database/models/create_db_home_base.rb', line 258 def to_s to_hash.to_s end |