Class: OCI::Database::Models::CreateExternalDatabaseConnectorDetails
- Inherits:
-
Object
- Object
- OCI::Database::Models::CreateExternalDatabaseConnectorDetails
- Defined in:
- lib/oci/database/models/create_external_database_connector_details.rb
Overview
Details for creating an external database connector resource.
This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
Constant Summary collapse
- CONNECTOR_TYPE_ENUM =
[ CONNECTOR_TYPE_MACS = 'MACS'.freeze ].freeze
Instance Attribute Summary collapse
-
#connector_type ⇒ String
The type of connector used by the external database resource.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
[Required] The user-friendly name for the create_external_database_connector_details.
-
#external_database_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the external database resource.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateExternalDatabaseConnectorDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateExternalDatabaseConnectorDetails
Initializes the object
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/oci/database/models/create_external_database_connector_details.rb', line 97 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.connector_type = attributes[:'connectorType'] if attributes[:'connectorType'] self.connector_type = "MACS" if connector_type.nil? && !attributes.key?(:'connectorType') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :connectorType and :connector_type' if attributes.key?(:'connectorType') && attributes.key?(:'connector_type') self.connector_type = attributes[:'connector_type'] if attributes[:'connector_type'] self.connector_type = "MACS" if connector_type.nil? && !attributes.key?(:'connectorType') && !attributes.key?(:'connector_type') # rubocop:disable Style/StringLiterals self.external_database_id = attributes[:'externalDatabaseId'] if attributes[:'externalDatabaseId'] raise 'You cannot provide both :externalDatabaseId and :external_database_id' if attributes.key?(:'externalDatabaseId') && attributes.key?(:'external_database_id') self.external_database_id = attributes[:'external_database_id'] if attributes[:'external_database_id'] end |
Instance Attribute Details
#connector_type ⇒ String
The type of connector used by the external database resource.
39 40 41 |
# File 'lib/oci/database/models/create_external_database_connector_details.rb', line 39 def connector_type @connector_type end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
28 29 30 |
# File 'lib/oci/database/models/create_external_database_connector_details.rb', line 28 def end |
#display_name ⇒ String
[Required] The user-friendly name for the create_external_database_connector_details. The name does not have to be unique.
35 36 37 |
# File 'lib/oci/database/models/create_external_database_connector_details.rb', line 35 def display_name @display_name end |
#external_database_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the external database resource.
43 44 45 |
# File 'lib/oci/database/models/create_external_database_connector_details.rb', line 43 def external_database_id @external_database_id end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
22 23 24 |
# File 'lib/oci/database/models/create_external_database_connector_details.rb', line 22 def end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/oci/database/models/create_external_database_connector_details.rb', line 46 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'display_name': :'displayName', 'connector_type': :'connectorType', 'external_database_id': :'externalDatabaseId' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
76 77 78 79 80 81 82 83 |
# File 'lib/oci/database/models/create_external_database_connector_details.rb', line 76 def self.get_subtype(object_hash) type = object_hash[:'connectorType'] # rubocop:disable Style/SymbolLiteral return 'OCI::Database::Models::CreateExternalMacsConnectorDetails' if type == 'MACS' # TODO: Log a warning when the subtype is not found. 'OCI::Database::Models::CreateExternalDatabaseConnectorDetails' end |
.swagger_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/oci/database/models/create_external_database_connector_details.rb', line 59 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'connector_type': :'String', 'external_database_id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
151 152 153 154 155 156 157 158 159 160 |
# File 'lib/oci/database/models/create_external_database_connector_details.rb', line 151 def ==(other) return true if equal?(other) self.class == other.class && == other. && == other. && display_name == other.display_name && connector_type == other.connector_type && external_database_id == other.external_database_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/oci/database/models/create_external_database_connector_details.rb', line 185 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
165 166 167 |
# File 'lib/oci/database/models/create_external_database_connector_details.rb', line 165 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
174 175 176 |
# File 'lib/oci/database/models/create_external_database_connector_details.rb', line 174 def hash [, , display_name, connector_type, external_database_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
218 219 220 221 222 223 224 225 226 227 |
# File 'lib/oci/database/models/create_external_database_connector_details.rb', line 218 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
212 213 214 |
# File 'lib/oci/database/models/create_external_database_connector_details.rb', line 212 def to_s to_hash.to_s end |