Class: OCI::Database::Models::CreateExternalMacsConnectorDetails

Inherits:
CreateExternalDatabaseConnectorDetails show all
Defined in:
lib/oci/database/models/create_external_macs_connector_details.rb

Overview

Details for creating a resource used to connect to an external Oracle Database using the [Management Agent cloud service (MACS)](docs.cloud.oracle.com/iaas/management-agents/index.html).

Constant Summary

Constants inherited from CreateExternalDatabaseConnectorDetails

OCI::Database::Models::CreateExternalDatabaseConnectorDetails::CONNECTOR_TYPE_ENUM

Instance Attribute Summary collapse

Attributes inherited from CreateExternalDatabaseConnectorDetails

#connector_type, #defined_tags, #display_name, #external_database_id, #freeform_tags

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from CreateExternalDatabaseConnectorDetails

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ CreateExternalMacsConnectorDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/oci/database/models/create_external_macs_connector_details.rb', line 72

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['connectorType'] = 'MACS'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.connection_string = attributes[:'connectionString'] if attributes[:'connectionString']

  raise 'You cannot provide both :connectionString and :connection_string' if attributes.key?(:'connectionString') && attributes.key?(:'connection_string')

  self.connection_string = attributes[:'connection_string'] if attributes[:'connection_string']

  self.connection_credentials = attributes[:'connectionCredentials'] if attributes[:'connectionCredentials']

  raise 'You cannot provide both :connectionCredentials and :connection_credentials' if attributes.key?(:'connectionCredentials') && attributes.key?(:'connection_credentials')

  self.connection_credentials = attributes[:'connection_credentials'] if attributes[:'connection_credentials']

  self.connector_agent_id = attributes[:'connectorAgentId'] if attributes[:'connectorAgentId']

  raise 'You cannot provide both :connectorAgentId and :connector_agent_id' if attributes.key?(:'connectorAgentId') && attributes.key?(:'connector_agent_id')

  self.connector_agent_id = attributes[:'connector_agent_id'] if attributes[:'connector_agent_id']
end

Instance Attribute Details

#connection_credentialsOCI::Database::Models::DatabaseConnectionCredentials

This attribute is required.



19
20
21
# File 'lib/oci/database/models/create_external_macs_connector_details.rb', line 19

def connection_credentials
  @connection_credentials
end

#connection_stringOCI::Database::Models::DatabaseConnectionString

This attribute is required.



15
16
17
# File 'lib/oci/database/models/create_external_macs_connector_details.rb', line 15

def connection_string
  @connection_string
end

#connector_agent_idString

[Required] The ID of the agent used for the create_external_database_connector_details.

Returns:

  • (String)


25
26
27
# File 'lib/oci/database/models/create_external_macs_connector_details.rb', line 25

def connector_agent_id
  @connector_agent_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



28
29
30
31
32
33
34
35
36
37
38
39
40
41
# File 'lib/oci/database/models/create_external_macs_connector_details.rb', line 28

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'display_name': :'displayName',
    'connector_type': :'connectorType',
    'external_database_id': :'externalDatabaseId',
    'connection_string': :'connectionString',
    'connection_credentials': :'connectionCredentials',
    'connector_agent_id': :'connectorAgentId'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



44
45
46
47
48
49
50
51
52
53
54
55
56
57
# File 'lib/oci/database/models/create_external_macs_connector_details.rb', line 44

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'display_name': :'String',
    'connector_type': :'String',
    'external_database_id': :'String',
    'connection_string': :'OCI::Database::Models::DatabaseConnectionString',
    'connection_credentials': :'OCI::Database::Models::DatabaseConnectionCredentials',
    'connector_agent_id': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/oci/database/models/create_external_macs_connector_details.rb', line 108

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    display_name == other.display_name &&
    connector_type == other.connector_type &&
    external_database_id == other.external_database_id &&
    connection_string == other.connection_string &&
    connection_credentials == other.connection_credentials &&
    connector_agent_id == other.connector_agent_id
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/oci/database/models/create_external_macs_connector_details.rb', line 145

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


125
126
127
# File 'lib/oci/database/models/create_external_macs_connector_details.rb', line 125

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



134
135
136
# File 'lib/oci/database/models/create_external_macs_connector_details.rb', line 134

def hash
  [freeform_tags, defined_tags, display_name, connector_type, external_database_id, connection_string, connection_credentials, connector_agent_id].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



178
179
180
181
182
183
184
185
186
187
# File 'lib/oci/database/models/create_external_macs_connector_details.rb', line 178

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



172
173
174
# File 'lib/oci/database/models/create_external_macs_connector_details.rb', line 172

def to_s
  to_hash.to_s
end