Class: OCI::Database::Models::CreateVmClusterDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database/models/create_vm_cluster_details.rb

Overview

Details for the create Exadata VM cluster operation. Applies to Exadata Cloud@Customer instances only. For details on the create cloud Exadata VM cluster operation used with Exadata Cloud Service instances, see create_cloud_vm_cluster_details

Constant Summary collapse

LICENSE_MODEL_ENUM =
[
  LICENSE_MODEL_LICENSE_INCLUDED = 'LICENSE_INCLUDED'.freeze,
  LICENSE_MODEL_BRING_YOUR_OWN_LICENSE = 'BRING_YOUR_OWN_LICENSE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateVmClusterDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 187

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.exadata_infrastructure_id = attributes[:'exadataInfrastructureId'] if attributes[:'exadataInfrastructureId']

  raise 'You cannot provide both :exadataInfrastructureId and :exadata_infrastructure_id' if attributes.key?(:'exadataInfrastructureId') && attributes.key?(:'exadata_infrastructure_id')

  self.exadata_infrastructure_id = attributes[:'exadata_infrastructure_id'] if attributes[:'exadata_infrastructure_id']

  self.cpu_core_count = attributes[:'cpuCoreCount'] if attributes[:'cpuCoreCount']

  raise 'You cannot provide both :cpuCoreCount and :cpu_core_count' if attributes.key?(:'cpuCoreCount') && attributes.key?(:'cpu_core_count')

  self.cpu_core_count = attributes[:'cpu_core_count'] if attributes[:'cpu_core_count']

  self.ocpu_count = attributes[:'ocpuCount'] if attributes[:'ocpuCount']

  raise 'You cannot provide both :ocpuCount and :ocpu_count' if attributes.key?(:'ocpuCount') && attributes.key?(:'ocpu_count')

  self.ocpu_count = attributes[:'ocpu_count'] if attributes[:'ocpu_count']

  self.memory_size_in_gbs = attributes[:'memorySizeInGBs'] if attributes[:'memorySizeInGBs']

  raise 'You cannot provide both :memorySizeInGBs and :memory_size_in_gbs' if attributes.key?(:'memorySizeInGBs') && attributes.key?(:'memory_size_in_gbs')

  self.memory_size_in_gbs = attributes[:'memory_size_in_gbs'] if attributes[:'memory_size_in_gbs']

  self.db_node_storage_size_in_gbs = attributes[:'dbNodeStorageSizeInGBs'] if attributes[:'dbNodeStorageSizeInGBs']

  raise 'You cannot provide both :dbNodeStorageSizeInGBs and :db_node_storage_size_in_gbs' if attributes.key?(:'dbNodeStorageSizeInGBs') && attributes.key?(:'db_node_storage_size_in_gbs')

  self.db_node_storage_size_in_gbs = attributes[:'db_node_storage_size_in_gbs'] if attributes[:'db_node_storage_size_in_gbs']

  self.data_storage_size_in_tbs = attributes[:'dataStorageSizeInTBs'] if attributes[:'dataStorageSizeInTBs']

  raise 'You cannot provide both :dataStorageSizeInTBs and :data_storage_size_in_tbs' if attributes.key?(:'dataStorageSizeInTBs') && attributes.key?(:'data_storage_size_in_tbs')

  self.data_storage_size_in_tbs = attributes[:'data_storage_size_in_tbs'] if attributes[:'data_storage_size_in_tbs']

  self.data_storage_size_in_gbs = attributes[:'dataStorageSizeInGBs'] if attributes[:'dataStorageSizeInGBs']

  raise 'You cannot provide both :dataStorageSizeInGBs and :data_storage_size_in_gbs' if attributes.key?(:'dataStorageSizeInGBs') && attributes.key?(:'data_storage_size_in_gbs')

  self.data_storage_size_in_gbs = attributes[:'data_storage_size_in_gbs'] if attributes[:'data_storage_size_in_gbs']

  self.ssh_public_keys = attributes[:'sshPublicKeys'] if attributes[:'sshPublicKeys']

  raise 'You cannot provide both :sshPublicKeys and :ssh_public_keys' if attributes.key?(:'sshPublicKeys') && attributes.key?(:'ssh_public_keys')

  self.ssh_public_keys = attributes[:'ssh_public_keys'] if attributes[:'ssh_public_keys']

  self.vm_cluster_network_id = attributes[:'vmClusterNetworkId'] if attributes[:'vmClusterNetworkId']

  raise 'You cannot provide both :vmClusterNetworkId and :vm_cluster_network_id' if attributes.key?(:'vmClusterNetworkId') && attributes.key?(:'vm_cluster_network_id')

  self.vm_cluster_network_id = attributes[:'vm_cluster_network_id'] if attributes[:'vm_cluster_network_id']

  self.license_model = attributes[:'licenseModel'] if attributes[:'licenseModel']

  raise 'You cannot provide both :licenseModel and :license_model' if attributes.key?(:'licenseModel') && attributes.key?(:'license_model')

  self.license_model = attributes[:'license_model'] if attributes[:'license_model']

  self.is_sparse_diskgroup_enabled = attributes[:'isSparseDiskgroupEnabled'] unless attributes[:'isSparseDiskgroupEnabled'].nil?

  raise 'You cannot provide both :isSparseDiskgroupEnabled and :is_sparse_diskgroup_enabled' if attributes.key?(:'isSparseDiskgroupEnabled') && attributes.key?(:'is_sparse_diskgroup_enabled')

  self.is_sparse_diskgroup_enabled = attributes[:'is_sparse_diskgroup_enabled'] unless attributes[:'is_sparse_diskgroup_enabled'].nil?

  self.is_local_backup_enabled = attributes[:'isLocalBackupEnabled'] unless attributes[:'isLocalBackupEnabled'].nil?

  raise 'You cannot provide both :isLocalBackupEnabled and :is_local_backup_enabled' if attributes.key?(:'isLocalBackupEnabled') && attributes.key?(:'is_local_backup_enabled')

  self.is_local_backup_enabled = attributes[:'is_local_backup_enabled'] unless attributes[:'is_local_backup_enabled'].nil?

  self.time_zone = attributes[:'timeZone'] if attributes[:'timeZone']

  raise 'You cannot provide both :timeZone and :time_zone' if attributes.key?(:'timeZone') && attributes.key?(:'time_zone')

  self.time_zone = attributes[:'time_zone'] if attributes[:'time_zone']

  self.gi_version = attributes[:'giVersion'] if attributes[:'giVersion']

  raise 'You cannot provide both :giVersion and :gi_version' if attributes.key?(:'giVersion') && attributes.key?(:'gi_version')

  self.gi_version = attributes[:'gi_version'] if attributes[:'gi_version']

  self.db_servers = attributes[:'dbServers'] if attributes[:'dbServers']

  raise 'You cannot provide both :dbServers and :db_servers' if attributes.key?(:'dbServers') && attributes.key?(:'db_servers')

  self.db_servers = attributes[:'db_servers'] if attributes[:'db_servers']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.data_collection_options = attributes[:'dataCollectionOptions'] if attributes[:'dataCollectionOptions']

  raise 'You cannot provide both :dataCollectionOptions and :data_collection_options' if attributes.key?(:'dataCollectionOptions') && attributes.key?(:'data_collection_options')

  self.data_collection_options = attributes[:'data_collection_options'] if attributes[:'data_collection_options']
end

Instance Attribute Details

#compartment_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.

Returns:

  • (String)


19
20
21
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 19

def compartment_id
  @compartment_id
end

#cpu_core_countInteger

**[Required]** The number of CPU cores to enable for the VM cluster.

Returns:

  • (Integer)


31
32
33
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 31

def cpu_core_count
  @cpu_core_count
end

#data_collection_optionsOCI::Database::Models::DataCollectionOptions



103
104
105
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 103

def data_collection_options
  @data_collection_options
end

#data_storage_size_in_gbsFloat

The data disk group size to be allocated in GBs.

Returns:

  • (Float)


51
52
53
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 51

def data_storage_size_in_gbs
  @data_storage_size_in_gbs
end

#data_storage_size_in_tbsFloat

The data disk group size to be allocated in TBs.

Returns:

  • (Float)


47
48
49
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 47

def data_storage_size_in_tbs
  @data_storage_size_in_tbs
end

#db_node_storage_size_in_gbsInteger

The local node storage to be allocated in GBs.

Returns:

  • (Integer)


43
44
45
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 43

def db_node_storage_size_in_gbs
  @db_node_storage_size_in_gbs
end

#db_serversArray<String>

The list of Db server.

Returns:

  • (Array<String>)


86
87
88
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 86

def db_servers
  @db_servers
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Returns:

  • (Hash<String, Hash<String, Object>>)


100
101
102
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 100

def defined_tags
  @defined_tags
end

#display_nameString

**[Required]** The user-friendly name for the VM cluster. The name does not need to be unique.

Returns:

  • (String)


23
24
25
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 23

def display_name
  @display_name
end

#exadata_infrastructure_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Exadata infrastructure.

Returns:

  • (String)


27
28
29
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 27

def exadata_infrastructure_id
  @exadata_infrastructure_id
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: `"Finance"`

Returns:

  • (Hash<String, String>)


94
95
96
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 94

def freeform_tags
  @freeform_tags
end

#gi_versionString

**[Required]** The Oracle Grid Infrastructure software version for the VM cluster.

Returns:

  • (String)


82
83
84
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 82

def gi_version
  @gi_version
end

#is_local_backup_enabledBOOLEAN

If true, database backup on local Exadata storage is configured for the VM cluster. If false, database backup on local Exadata storage is not available in the VM cluster.

Returns:

  • (BOOLEAN)


74
75
76
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 74

def is_local_backup_enabled
  @is_local_backup_enabled
end

#is_sparse_diskgroup_enabledBOOLEAN

If true, the sparse disk group is configured for the VM cluster. If false, the sparse disk group is not created.

Returns:

  • (BOOLEAN)


69
70
71
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 69

def is_sparse_diskgroup_enabled
  @is_sparse_diskgroup_enabled
end

#license_modelString

The Oracle license model that applies to the VM cluster. The default is BRING_YOUR_OWN_LICENSE.

Returns:

  • (String)


64
65
66
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 64

def license_model
  @license_model
end

#memory_size_in_gbsInteger

The memory to be allocated in GBs.

Returns:

  • (Integer)


39
40
41
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 39

def memory_size_in_gbs
  @memory_size_in_gbs
end

#ocpu_countFloat

The number of OCPU cores to enable for the VM cluster. Only one decimal place is allowed for the fractional part.

Returns:

  • (Float)


35
36
37
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 35

def ocpu_count
  @ocpu_count
end

#ssh_public_keysArray<String>

**[Required]** The public key portion of one or more key pairs used for SSH access to the VM cluster.

Returns:

  • (Array<String>)


55
56
57
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 55

def ssh_public_keys
  @ssh_public_keys
end

#time_zoneString

The time zone to use for the VM cluster. For details, see [DB System Time Zones](docs.cloud.oracle.com/Content/Database/References/timezones.htm).

Returns:

  • (String)


78
79
80
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 78

def time_zone
  @time_zone
end

#vm_cluster_network_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VM cluster network.

Returns:

  • (String)


59
60
61
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 59

def vm_cluster_network_id
  @vm_cluster_network_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 106

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'compartmentId',
    'display_name': :'displayName',
    'exadata_infrastructure_id': :'exadataInfrastructureId',
    'cpu_core_count': :'cpuCoreCount',
    'ocpu_count': :'ocpuCount',
    'memory_size_in_gbs': :'memorySizeInGBs',
    'db_node_storage_size_in_gbs': :'dbNodeStorageSizeInGBs',
    'data_storage_size_in_tbs': :'dataStorageSizeInTBs',
    'data_storage_size_in_gbs': :'dataStorageSizeInGBs',
    'ssh_public_keys': :'sshPublicKeys',
    'vm_cluster_network_id': :'vmClusterNetworkId',
    'license_model': :'licenseModel',
    'is_sparse_diskgroup_enabled': :'isSparseDiskgroupEnabled',
    'is_local_backup_enabled': :'isLocalBackupEnabled',
    'time_zone': :'timeZone',
    'gi_version': :'giVersion',
    'db_servers': :'dbServers',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'data_collection_options': :'dataCollectionOptions'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 134

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'String',
    'display_name': :'String',
    'exadata_infrastructure_id': :'String',
    'cpu_core_count': :'Integer',
    'ocpu_count': :'Float',
    'memory_size_in_gbs': :'Integer',
    'db_node_storage_size_in_gbs': :'Integer',
    'data_storage_size_in_tbs': :'Float',
    'data_storage_size_in_gbs': :'Float',
    'ssh_public_keys': :'Array<String>',
    'vm_cluster_network_id': :'String',
    'license_model': :'String',
    'is_sparse_diskgroup_enabled': :'BOOLEAN',
    'is_local_backup_enabled': :'BOOLEAN',
    'time_zone': :'String',
    'gi_version': :'String',
    'db_servers': :'Array<String>',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'data_collection_options': :'OCI::Database::Models::DataCollectionOptions'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 329

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    compartment_id == other.compartment_id &&
    display_name == other.display_name &&
    exadata_infrastructure_id == other.exadata_infrastructure_id &&
    cpu_core_count == other.cpu_core_count &&
    ocpu_count == other.ocpu_count &&
    memory_size_in_gbs == other.memory_size_in_gbs &&
    db_node_storage_size_in_gbs == other.db_node_storage_size_in_gbs &&
    data_storage_size_in_tbs == other.data_storage_size_in_tbs &&
    data_storage_size_in_gbs == other.data_storage_size_in_gbs &&
    ssh_public_keys == other.ssh_public_keys &&
    vm_cluster_network_id == other.vm_cluster_network_id &&
    license_model == other.license_model &&
    is_sparse_diskgroup_enabled == other.is_sparse_diskgroup_enabled &&
    is_local_backup_enabled == other.is_local_backup_enabled &&
    time_zone == other.time_zone &&
    gi_version == other.gi_version &&
    db_servers == other.db_servers &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    data_collection_options == other.data_collection_options
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 378

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


358
359
360
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 358

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



367
368
369
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 367

def hash
  [compartment_id, display_name, exadata_infrastructure_id, cpu_core_count, ocpu_count, memory_size_in_gbs, db_node_storage_size_in_gbs, data_storage_size_in_tbs, data_storage_size_in_gbs, ssh_public_keys, vm_cluster_network_id, license_model, is_sparse_diskgroup_enabled, is_local_backup_enabled, time_zone, gi_version, db_servers, freeform_tags, defined_tags, data_collection_options].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



411
412
413
414
415
416
417
418
419
420
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 411

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



405
406
407
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 405

def to_s
  to_hash.to_s
end