Class: OCI::Database::Models::DataCollectionOptions
- Inherits:
-
Object
- Object
- OCI::Database::Models::DataCollectionOptions
- Defined in:
- lib/oci/database/models/data_collection_options.rb
Overview
Indicates user preferences for the various diagnostic collection options for the VM cluster/Cloud VM cluster/VMBM DBCS.
Instance Attribute Summary collapse
-
#is_diagnostics_events_enabled ⇒ BOOLEAN
Indicates whether diagnostic collection is enabled for the VM cluster/Cloud VM cluster/VMBM DBCS.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DataCollectionOptions
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DataCollectionOptions
Initializes the object
41 42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/oci/database/models/data_collection_options.rb', line 41 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.is_diagnostics_events_enabled = attributes[:'isDiagnosticsEventsEnabled'] unless attributes[:'isDiagnosticsEventsEnabled'].nil? raise 'You cannot provide both :isDiagnosticsEventsEnabled and :is_diagnostics_events_enabled' if attributes.key?(:'isDiagnosticsEventsEnabled') && attributes.key?(:'is_diagnostics_events_enabled') self.is_diagnostics_events_enabled = attributes[:'is_diagnostics_events_enabled'] unless attributes[:'is_diagnostics_events_enabled'].nil? end |
Instance Attribute Details
#is_diagnostics_events_enabled ⇒ BOOLEAN
Indicates whether diagnostic collection is enabled for the VM cluster/Cloud VM cluster/VMBM DBCS. Enabling diagnostic collection allows you to receive Events service notifications for guest VM issues. Diagnostic collection also allows Oracle to provide enhanced service and proactive support for your Exadata system. You can enable diagnostic collection during VM cluster/Cloud VM cluster provisioning. You can also disable or enable it at any time using the `UpdateVmCluster` or `updateCloudVmCluster` API.
14 15 16 |
# File 'lib/oci/database/models/data_collection_options.rb', line 14 def is_diagnostics_events_enabled @is_diagnostics_events_enabled end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
17 18 19 20 21 22 23 |
# File 'lib/oci/database/models/data_collection_options.rb', line 17 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'is_diagnostics_events_enabled': :'isDiagnosticsEventsEnabled' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
26 27 28 29 30 31 32 |
# File 'lib/oci/database/models/data_collection_options.rb', line 26 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'is_diagnostics_events_enabled': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
61 62 63 64 65 66 |
# File 'lib/oci/database/models/data_collection_options.rb', line 61 def ==(other) return true if equal?(other) self.class == other.class && is_diagnostics_events_enabled == other.is_diagnostics_events_enabled end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/oci/database/models/data_collection_options.rb', line 91 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
71 72 73 |
# File 'lib/oci/database/models/data_collection_options.rb', line 71 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
80 81 82 |
# File 'lib/oci/database/models/data_collection_options.rb', line 80 def hash [is_diagnostics_events_enabled].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
124 125 126 127 128 129 130 131 132 133 |
# File 'lib/oci/database/models/data_collection_options.rb', line 124 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
118 119 120 |
# File 'lib/oci/database/models/data_collection_options.rb', line 118 def to_s to_hash.to_s end |