Class: OCI::Database::Models::DataGuardAssociation
- Inherits:
-
Object
- Object
- OCI::Database::Models::DataGuardAssociation
- Defined in:
- lib/oci/database/models/data_guard_association.rb
Overview
DataGuardAssociation model.
Constant Summary collapse
- ROLE_ENUM =
[ ROLE_PRIMARY = 'PRIMARY'.freeze, ROLE_STANDBY = 'STANDBY'.freeze, ROLE_DISABLED_STANDBY = 'DISABLED_STANDBY'.freeze, ROLE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze, LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze, LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UPGRADING = 'UPGRADING'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- PEER_ROLE_ENUM =
[ PEER_ROLE_PRIMARY = 'PRIMARY'.freeze, PEER_ROLE_STANDBY = 'STANDBY'.freeze, PEER_ROLE_DISABLED_STANDBY = 'DISABLED_STANDBY'.freeze, PEER_ROLE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- PROTECTION_MODE_ENUM =
[ PROTECTION_MODE_MAXIMUM_AVAILABILITY = 'MAXIMUM_AVAILABILITY'.freeze, PROTECTION_MODE_MAXIMUM_PERFORMANCE = 'MAXIMUM_PERFORMANCE'.freeze, PROTECTION_MODE_MAXIMUM_PROTECTION = 'MAXIMUM_PROTECTION'.freeze, PROTECTION_MODE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- TRANSPORT_TYPE_ENUM =
[ TRANSPORT_TYPE_SYNC = 'SYNC'.freeze, TRANSPORT_TYPE_ASYNC = 'ASYNC'.freeze, TRANSPORT_TYPE_FASTSYNC = 'FASTSYNC'.freeze, TRANSPORT_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#apply_lag ⇒ String
The lag time between updates to the primary database and application of the redo data on the standby database, as computed by the reporting database.
-
#apply_rate ⇒ String
The rate at which redo logs are synced between the associated databases.
-
#database_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the reporting database.
-
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Data Guard association.
-
#is_active_data_guard_enabled ⇒ BOOLEAN
True if active Data Guard is enabled.
-
#lifecycle_details ⇒ String
Additional information about the current lifecycleState, if available.
-
#lifecycle_state ⇒ String
**[Required]** The current state of the Data Guard association.
-
#peer_data_guard_association_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the peer database's Data Guard association.
-
#peer_database_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the associated peer database.
-
#peer_db_home_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Database Home containing the associated peer database.
-
#peer_db_system_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the DB system containing the associated peer database.
-
#peer_role ⇒ String
**[Required]** The role of the peer database in this Data Guard association.
-
#protection_mode ⇒ String
**[Required]** The protection mode of this Data Guard association.
-
#role ⇒ String
**[Required]** The role of the reporting database in this Data Guard association.
-
#time_created ⇒ DateTime
The date and time the Data Guard association was created.
-
#transport_type ⇒ String
The redo transport type used by this Data Guard association.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DataGuardAssociation
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DataGuardAssociation
Initializes the object
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'lib/oci/database/models/data_guard_association.rb', line 201 def initialize(attributes = {}) return unless attributes.is_a?(Hash) self.id = attributes[:'id'] if attributes[:'id'] self.database_id = attributes[:'databaseId'] if attributes[:'databaseId'] raise 'You cannot provide both :databaseId and :database_id' if attributes.key?(:'databaseId') && attributes.key?(:'database_id') self.database_id = attributes[:'database_id'] if attributes[:'database_id'] self.role = attributes[:'role'] if attributes[:'role'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.peer_db_system_id = attributes[:'peerDbSystemId'] if attributes[:'peerDbSystemId'] raise 'You cannot provide both :peerDbSystemId and :peer_db_system_id' if attributes.key?(:'peerDbSystemId') && attributes.key?(:'peer_db_system_id') self.peer_db_system_id = attributes[:'peer_db_system_id'] if attributes[:'peer_db_system_id'] self.peer_db_home_id = attributes[:'peerDbHomeId'] if attributes[:'peerDbHomeId'] raise 'You cannot provide both :peerDbHomeId and :peer_db_home_id' if attributes.key?(:'peerDbHomeId') && attributes.key?(:'peer_db_home_id') self.peer_db_home_id = attributes[:'peer_db_home_id'] if attributes[:'peer_db_home_id'] self.peer_database_id = attributes[:'peerDatabaseId'] if attributes[:'peerDatabaseId'] raise 'You cannot provide both :peerDatabaseId and :peer_database_id' if attributes.key?(:'peerDatabaseId') && attributes.key?(:'peer_database_id') self.peer_database_id = attributes[:'peer_database_id'] if attributes[:'peer_database_id'] self.peer_data_guard_association_id = attributes[:'peerDataGuardAssociationId'] if attributes[:'peerDataGuardAssociationId'] raise 'You cannot provide both :peerDataGuardAssociationId and :peer_data_guard_association_id' if attributes.key?(:'peerDataGuardAssociationId') && attributes.key?(:'peer_data_guard_association_id') self.peer_data_guard_association_id = attributes[:'peer_data_guard_association_id'] if attributes[:'peer_data_guard_association_id'] self.peer_role = attributes[:'peerRole'] if attributes[:'peerRole'] raise 'You cannot provide both :peerRole and :peer_role' if attributes.key?(:'peerRole') && attributes.key?(:'peer_role') self.peer_role = attributes[:'peer_role'] if attributes[:'peer_role'] self.apply_lag = attributes[:'applyLag'] if attributes[:'applyLag'] raise 'You cannot provide both :applyLag and :apply_lag' if attributes.key?(:'applyLag') && attributes.key?(:'apply_lag') self.apply_lag = attributes[:'apply_lag'] if attributes[:'apply_lag'] self.apply_rate = attributes[:'applyRate'] if attributes[:'applyRate'] raise 'You cannot provide both :applyRate and :apply_rate' if attributes.key?(:'applyRate') && attributes.key?(:'apply_rate') self.apply_rate = attributes[:'apply_rate'] if attributes[:'apply_rate'] self.protection_mode = attributes[:'protectionMode'] if attributes[:'protectionMode'] raise 'You cannot provide both :protectionMode and :protection_mode' if attributes.key?(:'protectionMode') && attributes.key?(:'protection_mode') self.protection_mode = attributes[:'protection_mode'] if attributes[:'protection_mode'] self.transport_type = attributes[:'transportType'] if attributes[:'transportType'] raise 'You cannot provide both :transportType and :transport_type' if attributes.key?(:'transportType') && attributes.key?(:'transport_type') self.transport_type = attributes[:'transport_type'] if attributes[:'transport_type'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.is_active_data_guard_enabled = attributes[:'isActiveDataGuardEnabled'] unless attributes[:'isActiveDataGuardEnabled'].nil? raise 'You cannot provide both :isActiveDataGuardEnabled and :is_active_data_guard_enabled' if attributes.key?(:'isActiveDataGuardEnabled') && attributes.key?(:'is_active_data_guard_enabled') self.is_active_data_guard_enabled = attributes[:'is_active_data_guard_enabled'] unless attributes[:'is_active_data_guard_enabled'].nil? end |
Instance Attribute Details
#apply_lag ⇒ String
The lag time between updates to the primary database and application of the redo data on the standby database, as computed by the reporting database.
Example: `9 seconds`
100 101 102 |
# File 'lib/oci/database/models/data_guard_association.rb', line 100 def apply_lag @apply_lag end |
#apply_rate ⇒ String
The rate at which redo logs are synced between the associated databases.
Example: `180 Mb per second`
107 108 109 |
# File 'lib/oci/database/models/data_guard_association.rb', line 107 def apply_rate @apply_rate end |
#database_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the reporting database.
56 57 58 |
# File 'lib/oci/database/models/data_guard_association.rb', line 56 def database_id @database_id end |
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Data Guard association.
52 53 54 |
# File 'lib/oci/database/models/data_guard_association.rb', line 52 def id @id end |
#is_active_data_guard_enabled ⇒ BOOLEAN
True if active Data Guard is enabled.
129 130 131 |
# File 'lib/oci/database/models/data_guard_association.rb', line 129 def is_active_data_guard_enabled @is_active_data_guard_enabled end |
#lifecycle_details ⇒ String
Additional information about the current lifecycleState, if available.
69 70 71 |
# File 'lib/oci/database/models/data_guard_association.rb', line 69 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
**[Required]** The current state of the Data Guard association.
64 65 66 |
# File 'lib/oci/database/models/data_guard_association.rb', line 64 def lifecycle_state @lifecycle_state end |
#peer_data_guard_association_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the peer database's Data Guard association.
88 89 90 |
# File 'lib/oci/database/models/data_guard_association.rb', line 88 def peer_data_guard_association_id @peer_data_guard_association_id end |
#peer_database_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the associated peer database.
84 85 86 |
# File 'lib/oci/database/models/data_guard_association.rb', line 84 def peer_database_id @peer_database_id end |
#peer_db_home_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Database Home containing the associated peer database.
80 81 82 |
# File 'lib/oci/database/models/data_guard_association.rb', line 80 def peer_db_home_id @peer_db_home_id end |
#peer_db_system_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the DB system containing the associated peer database.
75 76 77 |
# File 'lib/oci/database/models/data_guard_association.rb', line 75 def peer_db_system_id @peer_db_system_id end |
#peer_role ⇒ String
**[Required]** The role of the peer database in this Data Guard association.
92 93 94 |
# File 'lib/oci/database/models/data_guard_association.rb', line 92 def peer_role @peer_role end |
#protection_mode ⇒ String
**[Required]** The protection mode of this Data Guard association. For more information, see [Oracle Data Guard Protection Modes](docs.oracle.com/database/122/SBYDB/oracle-data-guard-protection-modes.htm#SBYDB02000) in the Oracle Data Guard documentation.
114 115 116 |
# File 'lib/oci/database/models/data_guard_association.rb', line 114 def protection_mode @protection_mode end |
#role ⇒ String
**[Required]** The role of the reporting database in this Data Guard association.
60 61 62 |
# File 'lib/oci/database/models/data_guard_association.rb', line 60 def role @role end |
#time_created ⇒ DateTime
The date and time the Data Guard association was created.
125 126 127 |
# File 'lib/oci/database/models/data_guard_association.rb', line 125 def time_created @time_created end |
#transport_type ⇒ String
The redo transport type used by this Data Guard association. For more information, see [Redo Transport Services](docs.oracle.com/database/122/SBYDB/oracle-data-guard-redo-transport-services.htm#SBYDB00400) in the Oracle Data Guard documentation.
121 122 123 |
# File 'lib/oci/database/models/data_guard_association.rb', line 121 def transport_type @transport_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/oci/database/models/data_guard_association.rb', line 132 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'database_id': :'databaseId', 'role': :'role', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'peer_db_system_id': :'peerDbSystemId', 'peer_db_home_id': :'peerDbHomeId', 'peer_database_id': :'peerDatabaseId', 'peer_data_guard_association_id': :'peerDataGuardAssociationId', 'peer_role': :'peerRole', 'apply_lag': :'applyLag', 'apply_rate': :'applyRate', 'protection_mode': :'protectionMode', 'transport_type': :'transportType', 'time_created': :'timeCreated', 'is_active_data_guard_enabled': :'isActiveDataGuardEnabled' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/oci/database/models/data_guard_association.rb', line 156 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'database_id': :'String', 'role': :'String', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'peer_db_system_id': :'String', 'peer_db_home_id': :'String', 'peer_database_id': :'String', 'peer_data_guard_association_id': :'String', 'peer_role': :'String', 'apply_lag': :'String', 'apply_rate': :'String', 'protection_mode': :'String', 'transport_type': :'String', 'time_created': :'DateTime', 'is_active_data_guard_enabled': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 |
# File 'lib/oci/database/models/data_guard_association.rb', line 365 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && database_id == other.database_id && role == other.role && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && peer_db_system_id == other.peer_db_system_id && peer_db_home_id == other.peer_db_home_id && peer_database_id == other.peer_database_id && peer_data_guard_association_id == other.peer_data_guard_association_id && peer_role == other.peer_role && apply_lag == other.apply_lag && apply_rate == other.apply_rate && protection_mode == other.protection_mode && transport_type == other.transport_type && time_created == other.time_created && is_active_data_guard_enabled == other.is_active_data_guard_enabled end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 |
# File 'lib/oci/database/models/data_guard_association.rb', line 410 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
390 391 392 |
# File 'lib/oci/database/models/data_guard_association.rb', line 390 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
399 400 401 |
# File 'lib/oci/database/models/data_guard_association.rb', line 399 def hash [id, database_id, role, lifecycle_state, lifecycle_details, peer_db_system_id, peer_db_home_id, peer_database_id, peer_data_guard_association_id, peer_role, apply_lag, apply_rate, protection_mode, transport_type, time_created, is_active_data_guard_enabled].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
443 444 445 446 447 448 449 450 451 452 |
# File 'lib/oci/database/models/data_guard_association.rb', line 443 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
437 438 439 |
# File 'lib/oci/database/models/data_guard_association.rb', line 437 def to_s to_hash.to_s end |