Class: OCI::Database::Models::DatabaseSoftwareImage
- Inherits:
-
Object
- Object
- OCI::Database::Models::DatabaseSoftwareImage
- Defined in:
- lib/oci/database/models/database_software_image.rb
Overview
Database software images are created by specifying a patch set, one-off patches and patches for the database home (listed by ‘ls inventory`).
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze, LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze, LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- IMAGE_TYPE_ENUM =
[ IMAGE_TYPE_GRID_IMAGE = 'GRID_IMAGE'.freeze, IMAGE_TYPE_DATABASE_IMAGE = 'DATABASE_IMAGE'.freeze, IMAGE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- IMAGE_SHAPE_FAMILY_ENUM =
[ IMAGE_SHAPE_FAMILY_VM_BM_SHAPE = 'VM_BM_SHAPE'.freeze, IMAGE_SHAPE_FAMILY_EXADATA_SHAPE = 'EXADATA_SHAPE'.freeze, IMAGE_SHAPE_FAMILY_EXACC_SHAPE = 'EXACC_SHAPE'.freeze, IMAGE_SHAPE_FAMILY_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
-
#database_software_image_included_patches ⇒ Array<String>
List of one-off patches for Database Homes.
-
#database_software_image_one_off_patches ⇒ Array<String>
List of one-off patches for Database Homes.
-
#database_version ⇒ String
[Required] The database version with which the database software image is to be built.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
[Required] The user-friendly name for the database software image.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the database software image.
-
#image_shape_family ⇒ String
[Required] To what shape the image is meant for.
-
#image_type ⇒ String
[Required] The type of software image.
-
#included_patches_summary ⇒ String
The patches included in the image and the version of the image.
-
#is_upgrade_supported ⇒ BOOLEAN
True if this Database software image is supported for Upgrade.
-
#lifecycle_details ⇒ String
Detailed message for the lifecycle state.
-
#lifecycle_state ⇒ String
[Required] The current state of the database software image.
-
#ls_inventory ⇒ String
output from lsinventory which will get passed as a string.
-
#patch_set ⇒ String
[Required] The PSU or PBP or Release Updates.
-
#time_created ⇒ DateTime
[Required] The date and time the database software image was created.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DatabaseSoftwareImage
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DatabaseSoftwareImage
Initializes the object
184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/oci/database/models/database_software_image.rb', line 184 def initialize(attributes = {}) return unless attributes.is_a?(Hash) self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.database_version = attributes[:'databaseVersion'] if attributes[:'databaseVersion'] raise 'You cannot provide both :databaseVersion and :database_version' if attributes.key?(:'databaseVersion') && attributes.key?(:'database_version') self.database_version = attributes[:'database_version'] if attributes[:'database_version'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.image_type = attributes[:'imageType'] if attributes[:'imageType'] raise 'You cannot provide both :imageType and :image_type' if attributes.key?(:'imageType') && attributes.key?(:'image_type') self.image_type = attributes[:'image_type'] if attributes[:'image_type'] self.image_shape_family = attributes[:'imageShapeFamily'] if attributes[:'imageShapeFamily'] raise 'You cannot provide both :imageShapeFamily and :image_shape_family' if attributes.key?(:'imageShapeFamily') && attributes.key?(:'image_shape_family') self.image_shape_family = attributes[:'image_shape_family'] if attributes[:'image_shape_family'] self.patch_set = attributes[:'patchSet'] if attributes[:'patchSet'] raise 'You cannot provide both :patchSet and :patch_set' if attributes.key?(:'patchSet') && attributes.key?(:'patch_set') self.patch_set = attributes[:'patch_set'] if attributes[:'patch_set'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.database_software_image_included_patches = attributes[:'databaseSoftwareImageIncludedPatches'] if attributes[:'databaseSoftwareImageIncludedPatches'] raise 'You cannot provide both :databaseSoftwareImageIncludedPatches and :database_software_image_included_patches' if attributes.key?(:'databaseSoftwareImageIncludedPatches') && attributes.key?(:'database_software_image_included_patches') self.database_software_image_included_patches = attributes[:'database_software_image_included_patches'] if attributes[:'database_software_image_included_patches'] self.included_patches_summary = attributes[:'includedPatchesSummary'] if attributes[:'includedPatchesSummary'] raise 'You cannot provide both :includedPatchesSummary and :included_patches_summary' if attributes.key?(:'includedPatchesSummary') && attributes.key?(:'included_patches_summary') self.included_patches_summary = attributes[:'included_patches_summary'] if attributes[:'included_patches_summary'] self.database_software_image_one_off_patches = attributes[:'databaseSoftwareImageOneOffPatches'] if attributes[:'databaseSoftwareImageOneOffPatches'] raise 'You cannot provide both :databaseSoftwareImageOneOffPatches and :database_software_image_one_off_patches' if attributes.key?(:'databaseSoftwareImageOneOffPatches') && attributes.key?(:'database_software_image_one_off_patches') self.database_software_image_one_off_patches = attributes[:'database_software_image_one_off_patches'] if attributes[:'database_software_image_one_off_patches'] self.ls_inventory = attributes[:'lsInventory'] if attributes[:'lsInventory'] raise 'You cannot provide both :lsInventory and :ls_inventory' if attributes.key?(:'lsInventory') && attributes.key?(:'ls_inventory') self.ls_inventory = attributes[:'ls_inventory'] if attributes[:'ls_inventory'] self.is_upgrade_supported = attributes[:'isUpgradeSupported'] unless attributes[:'isUpgradeSupported'].nil? raise 'You cannot provide both :isUpgradeSupported and :is_upgrade_supported' if attributes.key?(:'isUpgradeSupported') && attributes.key?(:'is_upgrade_supported') self.is_upgrade_supported = attributes[:'is_upgrade_supported'] unless attributes[:'is_upgrade_supported'].nil? end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
43 44 45 |
# File 'lib/oci/database/models/database_software_image.rb', line 43 def compartment_id @compartment_id end |
#database_software_image_included_patches ⇒ Array<String>
List of one-off patches for Database Homes.
93 94 95 |
# File 'lib/oci/database/models/database_software_image.rb', line 93 def database_software_image_included_patches @database_software_image_included_patches end |
#database_software_image_one_off_patches ⇒ Array<String>
List of one-off patches for Database Homes.
101 102 103 |
# File 'lib/oci/database/models/database_software_image.rb', line 101 def database_software_image_one_off_patches @database_software_image_one_off_patches end |
#database_version ⇒ String
[Required] The database version with which the database software image is to be built.
47 48 49 |
# File 'lib/oci/database/models/database_software_image.rb', line 47 def database_version @database_version end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
89 90 91 |
# File 'lib/oci/database/models/database_software_image.rb', line 89 def end |
#display_name ⇒ String
[Required] The user-friendly name for the database software image. The name does not have to be unique.
51 52 53 |
# File 'lib/oci/database/models/database_software_image.rb', line 51 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
83 84 85 |
# File 'lib/oci/database/models/database_software_image.rb', line 83 def end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the database software image.
39 40 41 |
# File 'lib/oci/database/models/database_software_image.rb', line 39 def id @id end |
#image_shape_family ⇒ String
[Required] To what shape the image is meant for.
71 72 73 |
# File 'lib/oci/database/models/database_software_image.rb', line 71 def image_shape_family @image_shape_family end |
#image_type ⇒ String
[Required] The type of software image. Can be grid or database.
67 68 69 |
# File 'lib/oci/database/models/database_software_image.rb', line 67 def image_type @image_type end |
#included_patches_summary ⇒ String
The patches included in the image and the version of the image
97 98 99 |
# File 'lib/oci/database/models/database_software_image.rb', line 97 def included_patches_summary @included_patches_summary end |
#is_upgrade_supported ⇒ BOOLEAN
True if this Database software image is supported for Upgrade.
109 110 111 |
# File 'lib/oci/database/models/database_software_image.rb', line 109 def is_upgrade_supported @is_upgrade_supported end |
#lifecycle_details ⇒ String
Detailed message for the lifecycle state.
59 60 61 |
# File 'lib/oci/database/models/database_software_image.rb', line 59 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
[Required] The current state of the database software image.
55 56 57 |
# File 'lib/oci/database/models/database_software_image.rb', line 55 def lifecycle_state @lifecycle_state end |
#ls_inventory ⇒ String
output from lsinventory which will get passed as a string
105 106 107 |
# File 'lib/oci/database/models/database_software_image.rb', line 105 def ls_inventory @ls_inventory end |
#patch_set ⇒ String
[Required] The PSU or PBP or Release Updates. To get a list of supported versions, use the list_db_versions operation.
75 76 77 |
# File 'lib/oci/database/models/database_software_image.rb', line 75 def patch_set @patch_set end |
#time_created ⇒ DateTime
[Required] The date and time the database software image was created.
63 64 65 |
# File 'lib/oci/database/models/database_software_image.rb', line 63 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/oci/database/models/database_software_image.rb', line 112 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'database_version': :'databaseVersion', 'display_name': :'displayName', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'time_created': :'timeCreated', 'image_type': :'imageType', 'image_shape_family': :'imageShapeFamily', 'patch_set': :'patchSet', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'database_software_image_included_patches': :'databaseSoftwareImageIncludedPatches', 'included_patches_summary': :'includedPatchesSummary', 'database_software_image_one_off_patches': :'databaseSoftwareImageOneOffPatches', 'ls_inventory': :'lsInventory', 'is_upgrade_supported': :'isUpgradeSupported' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/oci/database/models/database_software_image.rb', line 137 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'database_version': :'String', 'display_name': :'String', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'time_created': :'DateTime', 'image_type': :'String', 'image_shape_family': :'String', 'patch_set': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'database_software_image_included_patches': :'Array<String>', 'included_patches_summary': :'String', 'database_software_image_one_off_patches': :'Array<String>', 'ls_inventory': :'String', 'is_upgrade_supported': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 |
# File 'lib/oci/database/models/database_software_image.rb', line 332 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && database_version == other.database_version && display_name == other.display_name && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && time_created == other.time_created && image_type == other.image_type && image_shape_family == other.image_shape_family && patch_set == other.patch_set && == other. && == other. && database_software_image_included_patches == other.database_software_image_included_patches && included_patches_summary == other.included_patches_summary && database_software_image_one_off_patches == other.database_software_image_one_off_patches && ls_inventory == other.ls_inventory && is_upgrade_supported == other.is_upgrade_supported end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 |
# File 'lib/oci/database/models/database_software_image.rb', line 378 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
358 359 360 |
# File 'lib/oci/database/models/database_software_image.rb', line 358 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
367 368 369 |
# File 'lib/oci/database/models/database_software_image.rb', line 367 def hash [id, compartment_id, database_version, display_name, lifecycle_state, lifecycle_details, time_created, image_type, image_shape_family, patch_set, , , database_software_image_included_patches, included_patches_summary, database_software_image_one_off_patches, ls_inventory, is_upgrade_supported].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
411 412 413 414 415 416 417 418 419 420 |
# File 'lib/oci/database/models/database_software_image.rb', line 411 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
405 406 407 |
# File 'lib/oci/database/models/database_software_image.rb', line 405 def to_s to_hash.to_s end |