Class: OCI::Database::Models::DatabaseUpgradeWithDbVersionDetails
- Inherits:
-
DatabaseUpgradeSourceBase
- Object
- DatabaseUpgradeSourceBase
- OCI::Database::Models::DatabaseUpgradeWithDbVersionDetails
- Defined in:
- lib/oci/database/models/database_upgrade_with_db_version_details.rb
Overview
Details of the Oracle Database software version number for upgrading a database.
Constant Summary
Constants inherited from DatabaseUpgradeSourceBase
OCI::Database::Models::DatabaseUpgradeSourceBase::SOURCE_ENUM
Instance Attribute Summary collapse
-
#db_version ⇒ String
[Required] A valid Oracle Database version.
Attributes inherited from DatabaseUpgradeSourceBase
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DatabaseUpgradeWithDbVersionDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from DatabaseUpgradeSourceBase
Constructor Details
#initialize(attributes = {}) ⇒ DatabaseUpgradeWithDbVersionDetails
Initializes the object
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/oci/database/models/database_upgrade_with_db_version_details.rb', line 46 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['source'] = 'DB_VERSION' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.db_version = attributes[:'dbVersion'] if attributes[:'dbVersion'] raise 'You cannot provide both :dbVersion and :db_version' if attributes.key?(:'dbVersion') && attributes.key?(:'db_version') self.db_version = attributes[:'db_version'] if attributes[:'db_version'] end |
Instance Attribute Details
#db_version ⇒ String
[Required] A valid Oracle Database version. To get a list of supported versions, use the list_db_versions operation.
14 15 16 |
# File 'lib/oci/database/models/database_upgrade_with_db_version_details.rb', line 14 def db_version @db_version end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
17 18 19 20 21 22 23 24 25 |
# File 'lib/oci/database/models/database_upgrade_with_db_version_details.rb', line 17 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'source': :'source', 'options': :'options', 'db_version': :'dbVersion' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
28 29 30 31 32 33 34 35 36 |
# File 'lib/oci/database/models/database_upgrade_with_db_version_details.rb', line 28 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'source': :'String', 'options': :'String', 'db_version': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
70 71 72 73 74 75 76 77 |
# File 'lib/oci/database/models/database_upgrade_with_db_version_details.rb', line 70 def ==(other) return true if equal?(other) self.class == other.class && source == other.source && == other. && db_version == other.db_version end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/oci/database/models/database_upgrade_with_db_version_details.rb', line 102 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
82 83 84 |
# File 'lib/oci/database/models/database_upgrade_with_db_version_details.rb', line 82 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
91 92 93 |
# File 'lib/oci/database/models/database_upgrade_with_db_version_details.rb', line 91 def hash [source, , db_version].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
135 136 137 138 139 140 141 142 143 144 |
# File 'lib/oci/database/models/database_upgrade_with_db_version_details.rb', line 135 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
129 130 131 |
# File 'lib/oci/database/models/database_upgrade_with_db_version_details.rb', line 129 def to_s to_hash.to_s end |