Class: OCI::Database::Models::DbSystemShapeSummary
- Inherits:
-
Object
- Object
- OCI::Database::Models::DbSystemShapeSummary
- Defined in:
- lib/oci/database/models/db_system_shape_summary.rb
Overview
The shape of the DB system. The shape determines resources to allocate to the DB system - CPU cores and memory for VM shapes; CPU cores, memory and storage for non-VM (or bare metal) shapes.
To use any of the API operations, you must be authorized in an IAM policy. If you're not authorized, talk to an administrator. If you're an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm).
Constant Summary collapse
- SHAPE_TYPE_ENUM =
[ SHAPE_TYPE_AMD = 'AMD'.freeze, SHAPE_TYPE_INTEL = 'INTEL'.freeze, SHAPE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#available_core_count ⇒ Integer
**[Required]** The maximum number of CPU cores that can be enabled on the DB system for this shape.
-
#available_core_count_per_node ⇒ Integer
The maximum number of CPU cores per database node that can be enabled for this shape.
-
#available_data_storage_in_t_bs ⇒ Integer
The maximum DATA storage that can be enabled for this shape.
-
#available_data_storage_per_server_in_tbs ⇒ Float
The maximum data storage available per storage server for this shape.
-
#available_db_node_per_node_in_gbs ⇒ Integer
The maximum Db Node storage available per database node for this shape.
-
#available_db_node_storage_in_g_bs ⇒ Integer
The maximum Db Node storage that can be enabled for this shape.
-
#available_memory_in_gbs ⇒ Integer
The maximum memory that can be enabled for this shape.
-
#available_memory_per_node_in_gbs ⇒ Integer
The maximum memory available per database node for this shape.
-
#core_count_increment ⇒ Integer
The discrete number by which the CPU core count for this shape can be increased or decreased.
-
#max_storage_count ⇒ Integer
The maximum number of Exadata storage servers available for the Exadata infrastructure.
-
#maximum_node_count ⇒ Integer
The maximum number of database nodes available for this shape.
-
#min_core_count_per_node ⇒ Integer
The minimum number of CPU cores that can be enabled per node for this shape.
-
#min_data_storage_in_t_bs ⇒ Integer
The minimum data storage that need be allocated for this shape.
-
#min_db_node_storage_per_node_in_g_bs ⇒ Integer
The minimum Db Node storage that need be allocated per node for this shape.
-
#min_memory_per_node_in_g_bs ⇒ Integer
The minimum memory that need be allocated per node for this shape.
-
#min_storage_count ⇒ Integer
The minimum number of Exadata storage servers available for the Exadata infrastructure.
-
#minimum_core_count ⇒ Integer
The minimum number of CPU cores that can be enabled on the DB system for this shape.
-
#minimum_node_count ⇒ Integer
The minimum number of database nodes available for this shape.
-
#name ⇒ String
**[Required]** The name of the shape used for the DB system.
-
#shape ⇒ String
Deprecated.
-
#shape_family ⇒ String
The family of the shape used for the DB system.
-
#shape_type ⇒ String
The shape type for the virtual machine DB system.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DbSystemShapeSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DbSystemShapeSummary
Initializes the object
198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'lib/oci/database/models/db_system_shape_summary.rb', line 198 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.shape_family = attributes[:'shapeFamily'] if attributes[:'shapeFamily'] raise 'You cannot provide both :shapeFamily and :shape_family' if attributes.key?(:'shapeFamily') && attributes.key?(:'shape_family') self.shape_family = attributes[:'shape_family'] if attributes[:'shape_family'] self.shape_type = attributes[:'shapeType'] if attributes[:'shapeType'] raise 'You cannot provide both :shapeType and :shape_type' if attributes.key?(:'shapeType') && attributes.key?(:'shape_type') self.shape_type = attributes[:'shape_type'] if attributes[:'shape_type'] self.shape = attributes[:'shape'] if attributes[:'shape'] self.available_core_count = attributes[:'availableCoreCount'] if attributes[:'availableCoreCount'] raise 'You cannot provide both :availableCoreCount and :available_core_count' if attributes.key?(:'availableCoreCount') && attributes.key?(:'available_core_count') self.available_core_count = attributes[:'available_core_count'] if attributes[:'available_core_count'] self.minimum_core_count = attributes[:'minimumCoreCount'] if attributes[:'minimumCoreCount'] raise 'You cannot provide both :minimumCoreCount and :minimum_core_count' if attributes.key?(:'minimumCoreCount') && attributes.key?(:'minimum_core_count') self.minimum_core_count = attributes[:'minimum_core_count'] if attributes[:'minimum_core_count'] self.core_count_increment = attributes[:'coreCountIncrement'] if attributes[:'coreCountIncrement'] raise 'You cannot provide both :coreCountIncrement and :core_count_increment' if attributes.key?(:'coreCountIncrement') && attributes.key?(:'core_count_increment') self.core_count_increment = attributes[:'core_count_increment'] if attributes[:'core_count_increment'] self.min_storage_count = attributes[:'minStorageCount'] if attributes[:'minStorageCount'] raise 'You cannot provide both :minStorageCount and :min_storage_count' if attributes.key?(:'minStorageCount') && attributes.key?(:'min_storage_count') self.min_storage_count = attributes[:'min_storage_count'] if attributes[:'min_storage_count'] self.max_storage_count = attributes[:'maxStorageCount'] if attributes[:'maxStorageCount'] raise 'You cannot provide both :maxStorageCount and :max_storage_count' if attributes.key?(:'maxStorageCount') && attributes.key?(:'max_storage_count') self.max_storage_count = attributes[:'max_storage_count'] if attributes[:'max_storage_count'] self.available_data_storage_per_server_in_tbs = attributes[:'availableDataStoragePerServerInTBs'] if attributes[:'availableDataStoragePerServerInTBs'] raise 'You cannot provide both :availableDataStoragePerServerInTBs and :available_data_storage_per_server_in_tbs' if attributes.key?(:'availableDataStoragePerServerInTBs') && attributes.key?(:'available_data_storage_per_server_in_tbs') self.available_data_storage_per_server_in_tbs = attributes[:'available_data_storage_per_server_in_tbs'] if attributes[:'available_data_storage_per_server_in_tbs'] self.available_memory_per_node_in_gbs = attributes[:'availableMemoryPerNodeInGBs'] if attributes[:'availableMemoryPerNodeInGBs'] raise 'You cannot provide both :availableMemoryPerNodeInGBs and :available_memory_per_node_in_gbs' if attributes.key?(:'availableMemoryPerNodeInGBs') && attributes.key?(:'available_memory_per_node_in_gbs') self.available_memory_per_node_in_gbs = attributes[:'available_memory_per_node_in_gbs'] if attributes[:'available_memory_per_node_in_gbs'] self.available_db_node_per_node_in_gbs = attributes[:'availableDbNodePerNodeInGBs'] if attributes[:'availableDbNodePerNodeInGBs'] raise 'You cannot provide both :availableDbNodePerNodeInGBs and :available_db_node_per_node_in_gbs' if attributes.key?(:'availableDbNodePerNodeInGBs') && attributes.key?(:'available_db_node_per_node_in_gbs') self.available_db_node_per_node_in_gbs = attributes[:'available_db_node_per_node_in_gbs'] if attributes[:'available_db_node_per_node_in_gbs'] self.min_core_count_per_node = attributes[:'minCoreCountPerNode'] if attributes[:'minCoreCountPerNode'] raise 'You cannot provide both :minCoreCountPerNode and :min_core_count_per_node' if attributes.key?(:'minCoreCountPerNode') && attributes.key?(:'min_core_count_per_node') self.min_core_count_per_node = attributes[:'min_core_count_per_node'] if attributes[:'min_core_count_per_node'] self.available_memory_in_gbs = attributes[:'availableMemoryInGBs'] if attributes[:'availableMemoryInGBs'] raise 'You cannot provide both :availableMemoryInGBs and :available_memory_in_gbs' if attributes.key?(:'availableMemoryInGBs') && attributes.key?(:'available_memory_in_gbs') self.available_memory_in_gbs = attributes[:'available_memory_in_gbs'] if attributes[:'available_memory_in_gbs'] self.min_memory_per_node_in_g_bs = attributes[:'minMemoryPerNodeInGBs'] if attributes[:'minMemoryPerNodeInGBs'] raise 'You cannot provide both :minMemoryPerNodeInGBs and :min_memory_per_node_in_g_bs' if attributes.key?(:'minMemoryPerNodeInGBs') && attributes.key?(:'min_memory_per_node_in_g_bs') self.min_memory_per_node_in_g_bs = attributes[:'min_memory_per_node_in_g_bs'] if attributes[:'min_memory_per_node_in_g_bs'] self.available_db_node_storage_in_g_bs = attributes[:'availableDbNodeStorageInGBs'] if attributes[:'availableDbNodeStorageInGBs'] raise 'You cannot provide both :availableDbNodeStorageInGBs and :available_db_node_storage_in_g_bs' if attributes.key?(:'availableDbNodeStorageInGBs') && attributes.key?(:'available_db_node_storage_in_g_bs') self.available_db_node_storage_in_g_bs = attributes[:'available_db_node_storage_in_g_bs'] if attributes[:'available_db_node_storage_in_g_bs'] self.min_db_node_storage_per_node_in_g_bs = attributes[:'minDbNodeStoragePerNodeInGBs'] if attributes[:'minDbNodeStoragePerNodeInGBs'] raise 'You cannot provide both :minDbNodeStoragePerNodeInGBs and :min_db_node_storage_per_node_in_g_bs' if attributes.key?(:'minDbNodeStoragePerNodeInGBs') && attributes.key?(:'min_db_node_storage_per_node_in_g_bs') self.min_db_node_storage_per_node_in_g_bs = attributes[:'min_db_node_storage_per_node_in_g_bs'] if attributes[:'min_db_node_storage_per_node_in_g_bs'] self.available_data_storage_in_t_bs = attributes[:'availableDataStorageInTBs'] if attributes[:'availableDataStorageInTBs'] raise 'You cannot provide both :availableDataStorageInTBs and :available_data_storage_in_t_bs' if attributes.key?(:'availableDataStorageInTBs') && attributes.key?(:'available_data_storage_in_t_bs') self.available_data_storage_in_t_bs = attributes[:'available_data_storage_in_t_bs'] if attributes[:'available_data_storage_in_t_bs'] self.min_data_storage_in_t_bs = attributes[:'minDataStorageInTBs'] if attributes[:'minDataStorageInTBs'] raise 'You cannot provide both :minDataStorageInTBs and :min_data_storage_in_t_bs' if attributes.key?(:'minDataStorageInTBs') && attributes.key?(:'min_data_storage_in_t_bs') self.min_data_storage_in_t_bs = attributes[:'min_data_storage_in_t_bs'] if attributes[:'min_data_storage_in_t_bs'] self.minimum_node_count = attributes[:'minimumNodeCount'] if attributes[:'minimumNodeCount'] raise 'You cannot provide both :minimumNodeCount and :minimum_node_count' if attributes.key?(:'minimumNodeCount') && attributes.key?(:'minimum_node_count') self.minimum_node_count = attributes[:'minimum_node_count'] if attributes[:'minimum_node_count'] self.maximum_node_count = attributes[:'maximumNodeCount'] if attributes[:'maximumNodeCount'] raise 'You cannot provide both :maximumNodeCount and :maximum_node_count' if attributes.key?(:'maximumNodeCount') && attributes.key?(:'maximum_node_count') self.maximum_node_count = attributes[:'maximum_node_count'] if attributes[:'maximum_node_count'] self.available_core_count_per_node = attributes[:'availableCoreCountPerNode'] if attributes[:'availableCoreCountPerNode'] raise 'You cannot provide both :availableCoreCountPerNode and :available_core_count_per_node' if attributes.key?(:'availableCoreCountPerNode') && attributes.key?(:'available_core_count_per_node') self.available_core_count_per_node = attributes[:'available_core_count_per_node'] if attributes[:'available_core_count_per_node'] end |
Instance Attribute Details
#available_core_count ⇒ Integer
**[Required]** The maximum number of CPU cores that can be enabled on the DB system for this shape.
40 41 42 |
# File 'lib/oci/database/models/db_system_shape_summary.rb', line 40 def available_core_count @available_core_count end |
#available_core_count_per_node ⇒ Integer
The maximum number of CPU cores per database node that can be enabled for this shape. Only applicable to the flex Exadata shape and ExaCC Elastic shapes.
108 109 110 |
# File 'lib/oci/database/models/db_system_shape_summary.rb', line 108 def available_core_count_per_node @available_core_count_per_node end |
#available_data_storage_in_t_bs ⇒ Integer
The maximum DATA storage that can be enabled for this shape.
92 93 94 |
# File 'lib/oci/database/models/db_system_shape_summary.rb', line 92 def available_data_storage_in_t_bs @available_data_storage_in_t_bs end |
#available_data_storage_per_server_in_tbs ⇒ Float
The maximum data storage available per storage server for this shape. Only applicable to ExaCC Elastic shapes.
60 61 62 |
# File 'lib/oci/database/models/db_system_shape_summary.rb', line 60 def available_data_storage_per_server_in_tbs @available_data_storage_per_server_in_tbs end |
#available_db_node_per_node_in_gbs ⇒ Integer
The maximum Db Node storage available per database node for this shape. Only applicable to ExaCC Elastic shapes.
68 69 70 |
# File 'lib/oci/database/models/db_system_shape_summary.rb', line 68 def available_db_node_per_node_in_gbs @available_db_node_per_node_in_gbs end |
#available_db_node_storage_in_g_bs ⇒ Integer
The maximum Db Node storage that can be enabled for this shape.
84 85 86 |
# File 'lib/oci/database/models/db_system_shape_summary.rb', line 84 def available_db_node_storage_in_g_bs @available_db_node_storage_in_g_bs end |
#available_memory_in_gbs ⇒ Integer
The maximum memory that can be enabled for this shape.
76 77 78 |
# File 'lib/oci/database/models/db_system_shape_summary.rb', line 76 def available_memory_in_gbs @available_memory_in_gbs end |
#available_memory_per_node_in_gbs ⇒ Integer
The maximum memory available per database node for this shape. Only applicable to ExaCC Elastic shapes.
64 65 66 |
# File 'lib/oci/database/models/db_system_shape_summary.rb', line 64 def available_memory_per_node_in_gbs @available_memory_per_node_in_gbs end |
#core_count_increment ⇒ Integer
The discrete number by which the CPU core count for this shape can be increased or decreased.
48 49 50 |
# File 'lib/oci/database/models/db_system_shape_summary.rb', line 48 def core_count_increment @core_count_increment end |
#max_storage_count ⇒ Integer
The maximum number of Exadata storage servers available for the Exadata infrastructure.
56 57 58 |
# File 'lib/oci/database/models/db_system_shape_summary.rb', line 56 def max_storage_count @max_storage_count end |
#maximum_node_count ⇒ Integer
The maximum number of database nodes available for this shape.
104 105 106 |
# File 'lib/oci/database/models/db_system_shape_summary.rb', line 104 def maximum_node_count @maximum_node_count end |
#min_core_count_per_node ⇒ Integer
The minimum number of CPU cores that can be enabled per node for this shape.
72 73 74 |
# File 'lib/oci/database/models/db_system_shape_summary.rb', line 72 def min_core_count_per_node @min_core_count_per_node end |
#min_data_storage_in_t_bs ⇒ Integer
The minimum data storage that need be allocated for this shape.
96 97 98 |
# File 'lib/oci/database/models/db_system_shape_summary.rb', line 96 def min_data_storage_in_t_bs @min_data_storage_in_t_bs end |
#min_db_node_storage_per_node_in_g_bs ⇒ Integer
The minimum Db Node storage that need be allocated per node for this shape.
88 89 90 |
# File 'lib/oci/database/models/db_system_shape_summary.rb', line 88 def min_db_node_storage_per_node_in_g_bs @min_db_node_storage_per_node_in_g_bs end |
#min_memory_per_node_in_g_bs ⇒ Integer
The minimum memory that need be allocated per node for this shape.
80 81 82 |
# File 'lib/oci/database/models/db_system_shape_summary.rb', line 80 def min_memory_per_node_in_g_bs @min_memory_per_node_in_g_bs end |
#min_storage_count ⇒ Integer
The minimum number of Exadata storage servers available for the Exadata infrastructure.
52 53 54 |
# File 'lib/oci/database/models/db_system_shape_summary.rb', line 52 def min_storage_count @min_storage_count end |
#minimum_core_count ⇒ Integer
The minimum number of CPU cores that can be enabled on the DB system for this shape.
44 45 46 |
# File 'lib/oci/database/models/db_system_shape_summary.rb', line 44 def minimum_core_count @minimum_core_count end |
#minimum_node_count ⇒ Integer
The minimum number of database nodes available for this shape.
100 101 102 |
# File 'lib/oci/database/models/db_system_shape_summary.rb', line 100 def minimum_node_count @minimum_node_count end |
#name ⇒ String
**[Required]** The name of the shape used for the DB system.
24 25 26 |
# File 'lib/oci/database/models/db_system_shape_summary.rb', line 24 def name @name end |
#shape ⇒ String
Deprecated. Use `name` instead of `shape`.
36 37 38 |
# File 'lib/oci/database/models/db_system_shape_summary.rb', line 36 def shape @shape end |
#shape_family ⇒ String
The family of the shape used for the DB system.
28 29 30 |
# File 'lib/oci/database/models/db_system_shape_summary.rb', line 28 def shape_family @shape_family end |
#shape_type ⇒ String
The shape type for the virtual machine DB system. Shape type is determined by CPU hardware. Valid values are `AMD` and `INTEL`.
32 33 34 |
# File 'lib/oci/database/models/db_system_shape_summary.rb', line 32 def shape_type @shape_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/oci/database/models/db_system_shape_summary.rb', line 111 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'shape_family': :'shapeFamily', 'shape_type': :'shapeType', 'shape': :'shape', 'available_core_count': :'availableCoreCount', 'minimum_core_count': :'minimumCoreCount', 'core_count_increment': :'coreCountIncrement', 'min_storage_count': :'minStorageCount', 'max_storage_count': :'maxStorageCount', 'available_data_storage_per_server_in_tbs': :'availableDataStoragePerServerInTBs', 'available_memory_per_node_in_gbs': :'availableMemoryPerNodeInGBs', 'available_db_node_per_node_in_gbs': :'availableDbNodePerNodeInGBs', 'min_core_count_per_node': :'minCoreCountPerNode', 'available_memory_in_gbs': :'availableMemoryInGBs', 'min_memory_per_node_in_g_bs': :'minMemoryPerNodeInGBs', 'available_db_node_storage_in_g_bs': :'availableDbNodeStorageInGBs', 'min_db_node_storage_per_node_in_g_bs': :'minDbNodeStoragePerNodeInGBs', 'available_data_storage_in_t_bs': :'availableDataStorageInTBs', 'min_data_storage_in_t_bs': :'minDataStorageInTBs', 'minimum_node_count': :'minimumNodeCount', 'maximum_node_count': :'maximumNodeCount', 'available_core_count_per_node': :'availableCoreCountPerNode' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/oci/database/models/db_system_shape_summary.rb', line 141 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'shape_family': :'String', 'shape_type': :'String', 'shape': :'String', 'available_core_count': :'Integer', 'minimum_core_count': :'Integer', 'core_count_increment': :'Integer', 'min_storage_count': :'Integer', 'max_storage_count': :'Integer', 'available_data_storage_per_server_in_tbs': :'Float', 'available_memory_per_node_in_gbs': :'Integer', 'available_db_node_per_node_in_gbs': :'Integer', 'min_core_count_per_node': :'Integer', 'available_memory_in_gbs': :'Integer', 'min_memory_per_node_in_g_bs': :'Integer', 'available_db_node_storage_in_g_bs': :'Integer', 'min_db_node_storage_per_node_in_g_bs': :'Integer', 'available_data_storage_in_t_bs': :'Integer', 'min_data_storage_in_t_bs': :'Integer', 'minimum_node_count': :'Integer', 'maximum_node_count': :'Integer', 'available_core_count_per_node': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 |
# File 'lib/oci/database/models/db_system_shape_summary.rb', line 349 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && shape_family == other.shape_family && shape_type == other.shape_type && shape == other.shape && available_core_count == other.available_core_count && minimum_core_count == other.minimum_core_count && core_count_increment == other.core_count_increment && min_storage_count == other.min_storage_count && max_storage_count == other.max_storage_count && available_data_storage_per_server_in_tbs == other.available_data_storage_per_server_in_tbs && available_memory_per_node_in_gbs == other.available_memory_per_node_in_gbs && available_db_node_per_node_in_gbs == other.available_db_node_per_node_in_gbs && min_core_count_per_node == other.min_core_count_per_node && available_memory_in_gbs == other.available_memory_in_gbs && min_memory_per_node_in_g_bs == other.min_memory_per_node_in_g_bs && available_db_node_storage_in_g_bs == other.available_db_node_storage_in_g_bs && min_db_node_storage_per_node_in_g_bs == other.min_db_node_storage_per_node_in_g_bs && available_data_storage_in_t_bs == other.available_data_storage_in_t_bs && min_data_storage_in_t_bs == other.min_data_storage_in_t_bs && minimum_node_count == other.minimum_node_count && maximum_node_count == other.maximum_node_count && available_core_count_per_node == other.available_core_count_per_node end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 |
# File 'lib/oci/database/models/db_system_shape_summary.rb', line 400 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
380 381 382 |
# File 'lib/oci/database/models/db_system_shape_summary.rb', line 380 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
389 390 391 |
# File 'lib/oci/database/models/db_system_shape_summary.rb', line 389 def hash [name, shape_family, shape_type, shape, available_core_count, minimum_core_count, core_count_increment, min_storage_count, max_storage_count, available_data_storage_per_server_in_tbs, available_memory_per_node_in_gbs, available_db_node_per_node_in_gbs, min_core_count_per_node, available_memory_in_gbs, min_memory_per_node_in_g_bs, available_db_node_storage_in_g_bs, min_db_node_storage_per_node_in_g_bs, available_data_storage_in_t_bs, min_data_storage_in_t_bs, minimum_node_count, maximum_node_count, available_core_count_per_node].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
433 434 435 436 437 438 439 440 441 442 |
# File 'lib/oci/database/models/db_system_shape_summary.rb', line 433 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
427 428 429 |
# File 'lib/oci/database/models/db_system_shape_summary.rb', line 427 def to_s to_hash.to_s end |