Class: OCI::Database::Models::DbSystemStoragePerformanceSummary
- Inherits:
-
Object
- Object
- OCI::Database::Models::DbSystemStoragePerformanceSummary
- Defined in:
- lib/oci/database/models/db_system_storage_performance_summary.rb
Overview
Representation of storage performance summary per shapeType .
Constant Summary collapse
- SHAPE_TYPE_ENUM =
[ SHAPE_TYPE_AMD = 'AMD'.freeze, SHAPE_TYPE_INTEL = 'INTEL'.freeze, SHAPE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#data_storage_performance_list ⇒ Array<OCI::Database::Models::StoragePerformanceDetails>
**[Required]** List of storage performance for the DATA disks.
-
#reco_storage_performance_list ⇒ Array<OCI::Database::Models::StoragePerformanceDetails>
**[Required]** List of storage performance for the RECO disks.
-
#shape_type ⇒ String
**[Required]** ShapeType of the DbSystems,INTEL or AMD.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DbSystemStoragePerformanceSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DbSystemStoragePerformanceSummary
Initializes the object
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/oci/database/models/db_system_storage_performance_summary.rb', line 61 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.shape_type = attributes[:'shapeType'] if attributes[:'shapeType'] raise 'You cannot provide both :shapeType and :shape_type' if attributes.key?(:'shapeType') && attributes.key?(:'shape_type') self.shape_type = attributes[:'shape_type'] if attributes[:'shape_type'] self.data_storage_performance_list = attributes[:'dataStoragePerformanceList'] if attributes[:'dataStoragePerformanceList'] raise 'You cannot provide both :dataStoragePerformanceList and :data_storage_performance_list' if attributes.key?(:'dataStoragePerformanceList') && attributes.key?(:'data_storage_performance_list') self.data_storage_performance_list = attributes[:'data_storage_performance_list'] if attributes[:'data_storage_performance_list'] self.reco_storage_performance_list = attributes[:'recoStoragePerformanceList'] if attributes[:'recoStoragePerformanceList'] raise 'You cannot provide both :recoStoragePerformanceList and :reco_storage_performance_list' if attributes.key?(:'recoStoragePerformanceList') && attributes.key?(:'reco_storage_performance_list') self.reco_storage_performance_list = attributes[:'reco_storage_performance_list'] if attributes[:'reco_storage_performance_list'] end |
Instance Attribute Details
#data_storage_performance_list ⇒ Array<OCI::Database::Models::StoragePerformanceDetails>
**[Required]** List of storage performance for the DATA disks
24 25 26 |
# File 'lib/oci/database/models/db_system_storage_performance_summary.rb', line 24 def data_storage_performance_list @data_storage_performance_list end |
#reco_storage_performance_list ⇒ Array<OCI::Database::Models::StoragePerformanceDetails>
**[Required]** List of storage performance for the RECO disks
28 29 30 |
# File 'lib/oci/database/models/db_system_storage_performance_summary.rb', line 28 def reco_storage_performance_list @reco_storage_performance_list end |
#shape_type ⇒ String
**[Required]** ShapeType of the DbSystems,INTEL or AMD
20 21 22 |
# File 'lib/oci/database/models/db_system_storage_performance_summary.rb', line 20 def shape_type @shape_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 |
# File 'lib/oci/database/models/db_system_storage_performance_summary.rb', line 31 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'shape_type': :'shapeType', 'data_storage_performance_list': :'dataStoragePerformanceList', 'reco_storage_performance_list': :'recoStoragePerformanceList' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
42 43 44 45 46 47 48 49 50 |
# File 'lib/oci/database/models/db_system_storage_performance_summary.rb', line 42 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'shape_type': :'String', 'data_storage_performance_list': :'Array<OCI::Database::Models::StoragePerformanceDetails>', 'reco_storage_performance_list': :'Array<OCI::Database::Models::StoragePerformanceDetails>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
106 107 108 109 110 111 112 113 |
# File 'lib/oci/database/models/db_system_storage_performance_summary.rb', line 106 def ==(other) return true if equal?(other) self.class == other.class && shape_type == other.shape_type && data_storage_performance_list == other.data_storage_performance_list && reco_storage_performance_list == other.reco_storage_performance_list end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/oci/database/models/db_system_storage_performance_summary.rb', line 138 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
118 119 120 |
# File 'lib/oci/database/models/db_system_storage_performance_summary.rb', line 118 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
127 128 129 |
# File 'lib/oci/database/models/db_system_storage_performance_summary.rb', line 127 def hash [shape_type, data_storage_performance_list, reco_storage_performance_list].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
171 172 173 174 175 176 177 178 179 180 |
# File 'lib/oci/database/models/db_system_storage_performance_summary.rb', line 171 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
165 166 167 |
# File 'lib/oci/database/models/db_system_storage_performance_summary.rb', line 165 def to_s to_hash.to_s end |