Class: OCI::Database::Models::DbVersionSummary
- Inherits:
-
Object
- Object
- OCI::Database::Models::DbVersionSummary
- Defined in:
- lib/oci/database/models/db_version_summary.rb
Overview
The Oracle database software version.
To use any of the API operations, you must be authorized in an IAM policy. If you’re not authorized, talk to an administrator. If you’re an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.us-phoenix-1.oraclecloud.com/Content/Identity/Concepts/policygetstarted.htm).
Instance Attribute Summary collapse
-
#supports_pdb ⇒ BOOLEAN
True if this version of the Oracle Database software supports pluggable databases.
-
#version ⇒ String
[Required] A valid Oracle Database version.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DbVersionSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DbVersionSummary
Initializes the object
48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/oci/database/models/db_version_summary.rb', line 48 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.supports_pdb = attributes[:'supportsPdb'] unless attributes[:'supportsPdb'].nil? raise 'You cannot provide both :supportsPdb and :supports_pdb' if attributes.key?(:'supportsPdb') && attributes.key?(:'supports_pdb') self.supports_pdb = attributes[:'supports_pdb'] unless attributes[:'supports_pdb'].nil? self.version = attributes[:'version'] if attributes[:'version'] end |
Instance Attribute Details
#supports_pdb ⇒ BOOLEAN
True if this version of the Oracle Database software supports pluggable databases.
14 15 16 |
# File 'lib/oci/database/models/db_version_summary.rb', line 14 def supports_pdb @supports_pdb end |
#version ⇒ String
[Required] A valid Oracle Database version.
18 19 20 |
# File 'lib/oci/database/models/db_version_summary.rb', line 18 def version @version end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
21 22 23 24 25 26 27 28 |
# File 'lib/oci/database/models/db_version_summary.rb', line 21 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'supports_pdb': :'supportsPdb', 'version': :'version' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
31 32 33 34 35 36 37 38 |
# File 'lib/oci/database/models/db_version_summary.rb', line 31 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'supports_pdb': :'BOOLEAN', 'version': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
70 71 72 73 74 75 76 |
# File 'lib/oci/database/models/db_version_summary.rb', line 70 def ==(other) return true if equal?(other) self.class == other.class && supports_pdb == other.supports_pdb && version == other.version end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/oci/database/models/db_version_summary.rb', line 101 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
81 82 83 |
# File 'lib/oci/database/models/db_version_summary.rb', line 81 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
90 91 92 |
# File 'lib/oci/database/models/db_version_summary.rb', line 90 def hash [supports_pdb, version].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
134 135 136 137 138 139 140 141 142 143 |
# File 'lib/oci/database/models/db_version_summary.rb', line 134 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
128 129 130 |
# File 'lib/oci/database/models/db_version_summary.rb', line 128 def to_s to_hash.to_s end |