Class: OCI::Database::Models::ExadataInfrastructure

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database/models/exadata_infrastructure.rb

Overview

ExadataInfrastructure

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_REQUIRES_ACTIVATION = 'REQUIRES_ACTIVATION'.freeze,
  LIFECYCLE_STATE_ACTIVATING = 'ACTIVATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_ACTIVATION_FAILED = 'ACTIVATION_FAILED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_DISCONNECTED = 'DISCONNECTED'.freeze,
  LIFECYCLE_STATE_MAINTENANCE_IN_PROGRESS = 'MAINTENANCE_IN_PROGRESS'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
MAINTENANCE_SLO_STATUS_ENUM =
[
  MAINTENANCE_SLO_STATUS_OK = 'OK'.freeze,
  MAINTENANCE_SLO_STATUS_DEGRADED = 'DEGRADED'.freeze,
  MAINTENANCE_SLO_STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ExadataInfrastructure

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
# File 'lib/oci/database/models/exadata_infrastructure.rb', line 320

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.shape = attributes[:'shape'] if attributes[:'shape']

  self.time_zone = attributes[:'timeZone'] if attributes[:'timeZone']

  raise 'You cannot provide both :timeZone and :time_zone' if attributes.key?(:'timeZone') && attributes.key?(:'time_zone')

  self.time_zone = attributes[:'time_zone'] if attributes[:'time_zone']

  self.cpus_enabled = attributes[:'cpusEnabled'] if attributes[:'cpusEnabled']

  raise 'You cannot provide both :cpusEnabled and :cpus_enabled' if attributes.key?(:'cpusEnabled') && attributes.key?(:'cpus_enabled')

  self.cpus_enabled = attributes[:'cpus_enabled'] if attributes[:'cpus_enabled']

  self.max_cpu_count = attributes[:'maxCpuCount'] if attributes[:'maxCpuCount']

  raise 'You cannot provide both :maxCpuCount and :max_cpu_count' if attributes.key?(:'maxCpuCount') && attributes.key?(:'max_cpu_count')

  self.max_cpu_count = attributes[:'max_cpu_count'] if attributes[:'max_cpu_count']

  self.memory_size_in_gbs = attributes[:'memorySizeInGBs'] if attributes[:'memorySizeInGBs']

  raise 'You cannot provide both :memorySizeInGBs and :memory_size_in_gbs' if attributes.key?(:'memorySizeInGBs') && attributes.key?(:'memory_size_in_gbs')

  self.memory_size_in_gbs = attributes[:'memory_size_in_gbs'] if attributes[:'memory_size_in_gbs']

  self.max_memory_in_gbs = attributes[:'maxMemoryInGBs'] if attributes[:'maxMemoryInGBs']

  raise 'You cannot provide both :maxMemoryInGBs and :max_memory_in_gbs' if attributes.key?(:'maxMemoryInGBs') && attributes.key?(:'max_memory_in_gbs')

  self.max_memory_in_gbs = attributes[:'max_memory_in_gbs'] if attributes[:'max_memory_in_gbs']

  self.db_node_storage_size_in_gbs = attributes[:'dbNodeStorageSizeInGBs'] if attributes[:'dbNodeStorageSizeInGBs']

  raise 'You cannot provide both :dbNodeStorageSizeInGBs and :db_node_storage_size_in_gbs' if attributes.key?(:'dbNodeStorageSizeInGBs') && attributes.key?(:'db_node_storage_size_in_gbs')

  self.db_node_storage_size_in_gbs = attributes[:'db_node_storage_size_in_gbs'] if attributes[:'db_node_storage_size_in_gbs']

  self.max_db_node_storage_in_g_bs = attributes[:'maxDbNodeStorageInGBs'] if attributes[:'maxDbNodeStorageInGBs']

  raise 'You cannot provide both :maxDbNodeStorageInGBs and :max_db_node_storage_in_g_bs' if attributes.key?(:'maxDbNodeStorageInGBs') && attributes.key?(:'max_db_node_storage_in_g_bs')

  self.max_db_node_storage_in_g_bs = attributes[:'max_db_node_storage_in_g_bs'] if attributes[:'max_db_node_storage_in_g_bs']

  self.data_storage_size_in_tbs = attributes[:'dataStorageSizeInTBs'] if attributes[:'dataStorageSizeInTBs']

  raise 'You cannot provide both :dataStorageSizeInTBs and :data_storage_size_in_tbs' if attributes.key?(:'dataStorageSizeInTBs') && attributes.key?(:'data_storage_size_in_tbs')

  self.data_storage_size_in_tbs = attributes[:'data_storage_size_in_tbs'] if attributes[:'data_storage_size_in_tbs']

  self.max_data_storage_in_t_bs = attributes[:'maxDataStorageInTBs'] if attributes[:'maxDataStorageInTBs']

  raise 'You cannot provide both :maxDataStorageInTBs and :max_data_storage_in_t_bs' if attributes.key?(:'maxDataStorageInTBs') && attributes.key?(:'max_data_storage_in_t_bs')

  self.max_data_storage_in_t_bs = attributes[:'max_data_storage_in_t_bs'] if attributes[:'max_data_storage_in_t_bs']

  self.storage_count = attributes[:'storageCount'] if attributes[:'storageCount']

  raise 'You cannot provide both :storageCount and :storage_count' if attributes.key?(:'storageCount') && attributes.key?(:'storage_count')

  self.storage_count = attributes[:'storage_count'] if attributes[:'storage_count']

  self.additional_storage_count = attributes[:'additionalStorageCount'] if attributes[:'additionalStorageCount']

  raise 'You cannot provide both :additionalStorageCount and :additional_storage_count' if attributes.key?(:'additionalStorageCount') && attributes.key?(:'additional_storage_count')

  self.additional_storage_count = attributes[:'additional_storage_count'] if attributes[:'additional_storage_count']

  self.activated_storage_count = attributes[:'activatedStorageCount'] if attributes[:'activatedStorageCount']

  raise 'You cannot provide both :activatedStorageCount and :activated_storage_count' if attributes.key?(:'activatedStorageCount') && attributes.key?(:'activated_storage_count')

  self.activated_storage_count = attributes[:'activated_storage_count'] if attributes[:'activated_storage_count']

  self.compute_count = attributes[:'computeCount'] if attributes[:'computeCount']

  raise 'You cannot provide both :computeCount and :compute_count' if attributes.key?(:'computeCount') && attributes.key?(:'compute_count')

  self.compute_count = attributes[:'compute_count'] if attributes[:'compute_count']

  self.cloud_control_plane_server1 = attributes[:'cloudControlPlaneServer1'] if attributes[:'cloudControlPlaneServer1']

  raise 'You cannot provide both :cloudControlPlaneServer1 and :cloud_control_plane_server1' if attributes.key?(:'cloudControlPlaneServer1') && attributes.key?(:'cloud_control_plane_server1')

  self.cloud_control_plane_server1 = attributes[:'cloud_control_plane_server1'] if attributes[:'cloud_control_plane_server1']

  self.cloud_control_plane_server2 = attributes[:'cloudControlPlaneServer2'] if attributes[:'cloudControlPlaneServer2']

  raise 'You cannot provide both :cloudControlPlaneServer2 and :cloud_control_plane_server2' if attributes.key?(:'cloudControlPlaneServer2') && attributes.key?(:'cloud_control_plane_server2')

  self.cloud_control_plane_server2 = attributes[:'cloud_control_plane_server2'] if attributes[:'cloud_control_plane_server2']

  self.netmask = attributes[:'netmask'] if attributes[:'netmask']

  self.gateway = attributes[:'gateway'] if attributes[:'gateway']

  self.admin_network_cidr = attributes[:'adminNetworkCIDR'] if attributes[:'adminNetworkCIDR']

  raise 'You cannot provide both :adminNetworkCIDR and :admin_network_cidr' if attributes.key?(:'adminNetworkCIDR') && attributes.key?(:'admin_network_cidr')

  self.admin_network_cidr = attributes[:'admin_network_cidr'] if attributes[:'admin_network_cidr']

  self.infini_band_network_cidr = attributes[:'infiniBandNetworkCIDR'] if attributes[:'infiniBandNetworkCIDR']

  raise 'You cannot provide both :infiniBandNetworkCIDR and :infini_band_network_cidr' if attributes.key?(:'infiniBandNetworkCIDR') && attributes.key?(:'infini_band_network_cidr')

  self.infini_band_network_cidr = attributes[:'infini_band_network_cidr'] if attributes[:'infini_band_network_cidr']

  self.corporate_proxy = attributes[:'corporateProxy'] if attributes[:'corporateProxy']

  raise 'You cannot provide both :corporateProxy and :corporate_proxy' if attributes.key?(:'corporateProxy') && attributes.key?(:'corporate_proxy')

  self.corporate_proxy = attributes[:'corporate_proxy'] if attributes[:'corporate_proxy']

  self.dns_server = attributes[:'dnsServer'] if attributes[:'dnsServer']

  raise 'You cannot provide both :dnsServer and :dns_server' if attributes.key?(:'dnsServer') && attributes.key?(:'dns_server')

  self.dns_server = attributes[:'dns_server'] if attributes[:'dns_server']

  self.ntp_server = attributes[:'ntpServer'] if attributes[:'ntpServer']

  raise 'You cannot provide both :ntpServer and :ntp_server' if attributes.key?(:'ntpServer') && attributes.key?(:'ntp_server')

  self.ntp_server = attributes[:'ntp_server'] if attributes[:'ntp_server']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.csi_number = attributes[:'csiNumber'] if attributes[:'csiNumber']

  raise 'You cannot provide both :csiNumber and :csi_number' if attributes.key?(:'csiNumber') && attributes.key?(:'csi_number')

  self.csi_number = attributes[:'csi_number'] if attributes[:'csi_number']

  self.contacts = attributes[:'contacts'] if attributes[:'contacts']

  self.maintenance_slo_status = attributes[:'maintenanceSLOStatus'] if attributes[:'maintenanceSLOStatus']

  raise 'You cannot provide both :maintenanceSLOStatus and :maintenance_slo_status' if attributes.key?(:'maintenanceSLOStatus') && attributes.key?(:'maintenance_slo_status')

  self.maintenance_slo_status = attributes[:'maintenance_slo_status'] if attributes[:'maintenance_slo_status']

  self.maintenance_window = attributes[:'maintenanceWindow'] if attributes[:'maintenanceWindow']

  raise 'You cannot provide both :maintenanceWindow and :maintenance_window' if attributes.key?(:'maintenanceWindow') && attributes.key?(:'maintenance_window')

  self.maintenance_window = attributes[:'maintenance_window'] if attributes[:'maintenance_window']

  self.last_maintenance_run_id = attributes[:'lastMaintenanceRunId'] if attributes[:'lastMaintenanceRunId']

  raise 'You cannot provide both :lastMaintenanceRunId and :last_maintenance_run_id' if attributes.key?(:'lastMaintenanceRunId') && attributes.key?(:'last_maintenance_run_id')

  self.last_maintenance_run_id = attributes[:'last_maintenance_run_id'] if attributes[:'last_maintenance_run_id']

  self.next_maintenance_run_id = attributes[:'nextMaintenanceRunId'] if attributes[:'nextMaintenanceRunId']

  raise 'You cannot provide both :nextMaintenanceRunId and :next_maintenance_run_id' if attributes.key?(:'nextMaintenanceRunId') && attributes.key?(:'next_maintenance_run_id')

  self.next_maintenance_run_id = attributes[:'next_maintenance_run_id'] if attributes[:'next_maintenance_run_id']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#activated_storage_countInteger

The requested number of additional storage servers activated for the Exadata infrastructure.

Returns:

  • (Integer)


100
101
102
# File 'lib/oci/database/models/exadata_infrastructure.rb', line 100

def activated_storage_count
  @activated_storage_count
end

#additional_storage_countInteger

The requested number of additional storage servers for the Exadata infrastructure.

Returns:

  • (Integer)


96
97
98
# File 'lib/oci/database/models/exadata_infrastructure.rb', line 96

def additional_storage_count
  @additional_storage_count
end

#admin_network_cidrString

The CIDR block for the Exadata administration network.

Returns:

  • (String)


124
125
126
# File 'lib/oci/database/models/exadata_infrastructure.rb', line 124

def admin_network_cidr
  @admin_network_cidr
end

#cloud_control_plane_server1String

The IP address for the first control plane server.

Returns:

  • (String)


108
109
110
# File 'lib/oci/database/models/exadata_infrastructure.rb', line 108

def cloud_control_plane_server1
  @cloud_control_plane_server1
end

#cloud_control_plane_server2String

The IP address for the second control plane server.

Returns:

  • (String)


112
113
114
# File 'lib/oci/database/models/exadata_infrastructure.rb', line 112

def cloud_control_plane_server2
  @cloud_control_plane_server2
end

#compartment_idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.

Returns:

  • (String)


38
39
40
# File 'lib/oci/database/models/exadata_infrastructure.rb', line 38

def compartment_id
  @compartment_id
end

#compute_countInteger

The number of compute servers for the Exadata infrastructure.

Returns:

  • (Integer)


104
105
106
# File 'lib/oci/database/models/exadata_infrastructure.rb', line 104

def compute_count
  @compute_count
end

#contactsArray<OCI::Database::Models::ExadataInfrastructureContact>

The list of contacts for the Exadata infrastructure.



156
157
158
# File 'lib/oci/database/models/exadata_infrastructure.rb', line 156

def contacts
  @contacts
end

#corporate_proxyString

The corporate network proxy for access to the control plane network.

Returns:

  • (String)


132
133
134
# File 'lib/oci/database/models/exadata_infrastructure.rb', line 132

def corporate_proxy
  @corporate_proxy
end

#cpus_enabledInteger

The number of enabled CPU cores.

Returns:

  • (Integer)


59
60
61
# File 'lib/oci/database/models/exadata_infrastructure.rb', line 59

def cpus_enabled
  @cpus_enabled
end

#csi_numberString

The CSI Number of the Exadata infrastructure.

Returns:

  • (String)


152
153
154
# File 'lib/oci/database/models/exadata_infrastructure.rb', line 152

def csi_number
  @csi_number
end

#data_storage_size_in_tbsFloat

Size, in terabytes, of the DATA disk group.

Returns:

  • (Float)


84
85
86
# File 'lib/oci/database/models/exadata_infrastructure.rb', line 84

def data_storage_size_in_tbs
  @data_storage_size_in_tbs
end

#db_node_storage_size_in_gbsInteger

The local node storage allocated in GBs.

Returns:

  • (Integer)


75
76
77
# File 'lib/oci/database/models/exadata_infrastructure.rb', line 75

def db_node_storage_size_in_gbs
  @db_node_storage_size_in_gbs
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Returns:

  • (Hash<String, Hash<String, Object>>)


185
186
187
# File 'lib/oci/database/models/exadata_infrastructure.rb', line 185

def defined_tags
  @defined_tags
end

#display_nameString

[Required] The user-friendly name for the Exadata Cloud@Customer infrastructure. The name does not need to be unique.

Returns:

  • (String)


46
47
48
# File 'lib/oci/database/models/exadata_infrastructure.rb', line 46

def display_name
  @display_name
end

#dns_serverArray<String>

The list of DNS server IP addresses. Maximum of 3 allowed.

Returns:

  • (Array<String>)


136
137
138
# File 'lib/oci/database/models/exadata_infrastructure.rb', line 136

def dns_server
  @dns_server
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: ‘"Finance"`

Returns:

  • (Hash<String, String>)


179
180
181
# File 'lib/oci/database/models/exadata_infrastructure.rb', line 179

def freeform_tags
  @freeform_tags
end

#gatewayString

The gateway for the control plane network.

Returns:

  • (String)


120
121
122
# File 'lib/oci/database/models/exadata_infrastructure.rb', line 120

def gateway
  @gateway
end

#idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Exadata infrastructure.

Returns:

  • (String)


34
35
36
# File 'lib/oci/database/models/exadata_infrastructure.rb', line 34

def id
  @id
end

#infini_band_network_cidrString

The CIDR block for the Exadata InfiniBand interconnect.

Returns:

  • (String)


128
129
130
# File 'lib/oci/database/models/exadata_infrastructure.rb', line 128

def infini_band_network_cidr
  @infini_band_network_cidr
end

#last_maintenance_run_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the last maintenance run.

Returns:

  • (String)


167
168
169
# File 'lib/oci/database/models/exadata_infrastructure.rb', line 167

def last_maintenance_run_id
  @last_maintenance_run_id
end

#lifecycle_detailsString

Additional information about the current lifecycle state.

Returns:

  • (String)


148
149
150
# File 'lib/oci/database/models/exadata_infrastructure.rb', line 148

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

[Required] The current lifecycle state of the Exadata infrastructure.

Returns:

  • (String)


42
43
44
# File 'lib/oci/database/models/exadata_infrastructure.rb', line 42

def lifecycle_state
  @lifecycle_state
end

#maintenance_slo_statusString

A field to capture u2018Maintenance SLO Statusu2019 for the Exadata infrastructure with values u2018OKu2019, u2018DEGRADEDu2019. Default is u2018OKu2019 when the infrastructure is provisioned.

Returns:

  • (String)


160
161
162
# File 'lib/oci/database/models/exadata_infrastructure.rb', line 160

def maintenance_slo_status
  @maintenance_slo_status
end

#maintenance_windowOCI::Database::Models::MaintenanceWindow



163
164
165
# File 'lib/oci/database/models/exadata_infrastructure.rb', line 163

def maintenance_window
  @maintenance_window
end

#max_cpu_countInteger

The total number of CPU cores available.

Returns:

  • (Integer)


63
64
65
# File 'lib/oci/database/models/exadata_infrastructure.rb', line 63

def max_cpu_count
  @max_cpu_count
end

#max_data_storage_in_t_bsFloat

The total available DATA disk group size.

Returns:

  • (Float)


88
89
90
# File 'lib/oci/database/models/exadata_infrastructure.rb', line 88

def max_data_storage_in_t_bs
  @max_data_storage_in_t_bs
end

#max_db_node_storage_in_g_bsInteger

The total local node storage available in GBs.

Returns:

  • (Integer)


79
80
81
# File 'lib/oci/database/models/exadata_infrastructure.rb', line 79

def max_db_node_storage_in_g_bs
  @max_db_node_storage_in_g_bs
end

#max_memory_in_gbsInteger

The total memory available in GBs.

Returns:

  • (Integer)


71
72
73
# File 'lib/oci/database/models/exadata_infrastructure.rb', line 71

def max_memory_in_gbs
  @max_memory_in_gbs
end

#memory_size_in_gbsInteger

The memory allocated in GBs.

Returns:

  • (Integer)


67
68
69
# File 'lib/oci/database/models/exadata_infrastructure.rb', line 67

def memory_size_in_gbs
  @memory_size_in_gbs
end

#netmaskString

The netmask for the control plane network.

Returns:

  • (String)


116
117
118
# File 'lib/oci/database/models/exadata_infrastructure.rb', line 116

def netmask
  @netmask
end

#next_maintenance_run_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the next maintenance run.

Returns:

  • (String)


171
172
173
# File 'lib/oci/database/models/exadata_infrastructure.rb', line 171

def next_maintenance_run_id
  @next_maintenance_run_id
end

#ntp_serverArray<String>

The list of NTP server IP addresses. Maximum of 3 allowed.

Returns:

  • (Array<String>)


140
141
142
# File 'lib/oci/database/models/exadata_infrastructure.rb', line 140

def ntp_server
  @ntp_server
end

#shapeString

[Required] The shape of the Exadata infrastructure. The shape determines the amount of CPU, storage, and memory resources allocated to the instance.

Returns:

  • (String)


51
52
53
# File 'lib/oci/database/models/exadata_infrastructure.rb', line 51

def shape
  @shape
end

#storage_countInteger

The number of Exadata storage servers for the Exadata infrastructure.

Returns:

  • (Integer)


92
93
94
# File 'lib/oci/database/models/exadata_infrastructure.rb', line 92

def storage_count
  @storage_count
end

#time_createdDateTime

The date and time the Exadata infrastructure was created.

Returns:

  • (DateTime)


144
145
146
# File 'lib/oci/database/models/exadata_infrastructure.rb', line 144

def time_created
  @time_created
end

#time_zoneString

The time zone of the Exadata infrastructure. For details, see [Exadata Infrastructure Time Zones](docs.cloud.oracle.com/Content/Database/References/timezones.htm).

Returns:

  • (String)


55
56
57
# File 'lib/oci/database/models/exadata_infrastructure.rb', line 55

def time_zone
  @time_zone
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/oci/database/models/exadata_infrastructure.rb', line 188

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'compartment_id': :'compartmentId',
    'lifecycle_state': :'lifecycleState',
    'display_name': :'displayName',
    'shape': :'shape',
    'time_zone': :'timeZone',
    'cpus_enabled': :'cpusEnabled',
    'max_cpu_count': :'maxCpuCount',
    'memory_size_in_gbs': :'memorySizeInGBs',
    'max_memory_in_gbs': :'maxMemoryInGBs',
    'db_node_storage_size_in_gbs': :'dbNodeStorageSizeInGBs',
    'max_db_node_storage_in_g_bs': :'maxDbNodeStorageInGBs',
    'data_storage_size_in_tbs': :'dataStorageSizeInTBs',
    'max_data_storage_in_t_bs': :'maxDataStorageInTBs',
    'storage_count': :'storageCount',
    'additional_storage_count': :'additionalStorageCount',
    'activated_storage_count': :'activatedStorageCount',
    'compute_count': :'computeCount',
    'cloud_control_plane_server1': :'cloudControlPlaneServer1',
    'cloud_control_plane_server2': :'cloudControlPlaneServer2',
    'netmask': :'netmask',
    'gateway': :'gateway',
    'admin_network_cidr': :'adminNetworkCIDR',
    'infini_band_network_cidr': :'infiniBandNetworkCIDR',
    'corporate_proxy': :'corporateProxy',
    'dns_server': :'dnsServer',
    'ntp_server': :'ntpServer',
    'time_created': :'timeCreated',
    'lifecycle_details': :'lifecycleDetails',
    'csi_number': :'csiNumber',
    'contacts': :'contacts',
    'maintenance_slo_status': :'maintenanceSLOStatus',
    'maintenance_window': :'maintenanceWindow',
    'last_maintenance_run_id': :'lastMaintenanceRunId',
    'next_maintenance_run_id': :'nextMaintenanceRunId',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/oci/database/models/exadata_infrastructure.rb', line 233

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'compartment_id': :'String',
    'lifecycle_state': :'String',
    'display_name': :'String',
    'shape': :'String',
    'time_zone': :'String',
    'cpus_enabled': :'Integer',
    'max_cpu_count': :'Integer',
    'memory_size_in_gbs': :'Integer',
    'max_memory_in_gbs': :'Integer',
    'db_node_storage_size_in_gbs': :'Integer',
    'max_db_node_storage_in_g_bs': :'Integer',
    'data_storage_size_in_tbs': :'Float',
    'max_data_storage_in_t_bs': :'Float',
    'storage_count': :'Integer',
    'additional_storage_count': :'Integer',
    'activated_storage_count': :'Integer',
    'compute_count': :'Integer',
    'cloud_control_plane_server1': :'String',
    'cloud_control_plane_server2': :'String',
    'netmask': :'String',
    'gateway': :'String',
    'admin_network_cidr': :'String',
    'infini_band_network_cidr': :'String',
    'corporate_proxy': :'String',
    'dns_server': :'Array<String>',
    'ntp_server': :'Array<String>',
    'time_created': :'DateTime',
    'lifecycle_details': :'String',
    'csi_number': :'String',
    'contacts': :'Array<OCI::Database::Models::ExadataInfrastructureContact>',
    'maintenance_slo_status': :'String',
    'maintenance_window': :'OCI::Database::Models::MaintenanceWindow',
    'last_maintenance_run_id': :'String',
    'next_maintenance_run_id': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
# File 'lib/oci/database/models/exadata_infrastructure.rb', line 559

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    lifecycle_state == other.lifecycle_state &&
    display_name == other.display_name &&
    shape == other.shape &&
    time_zone == other.time_zone &&
    cpus_enabled == other.cpus_enabled &&
    max_cpu_count == other.max_cpu_count &&
    memory_size_in_gbs == other.memory_size_in_gbs &&
    max_memory_in_gbs == other.max_memory_in_gbs &&
    db_node_storage_size_in_gbs == other.db_node_storage_size_in_gbs &&
    max_db_node_storage_in_g_bs == other.max_db_node_storage_in_g_bs &&
    data_storage_size_in_tbs == other.data_storage_size_in_tbs &&
    max_data_storage_in_t_bs == other.max_data_storage_in_t_bs &&
    storage_count == other.storage_count &&
    additional_storage_count == other.additional_storage_count &&
    activated_storage_count == other.activated_storage_count &&
    compute_count == other.compute_count &&
    cloud_control_plane_server1 == other.cloud_control_plane_server1 &&
    cloud_control_plane_server2 == other.cloud_control_plane_server2 &&
    netmask == other.netmask &&
    gateway == other.gateway &&
    admin_network_cidr == other.admin_network_cidr &&
    infini_band_network_cidr == other.infini_band_network_cidr &&
    corporate_proxy == other.corporate_proxy &&
    dns_server == other.dns_server &&
    ntp_server == other.ntp_server &&
    time_created == other.time_created &&
    lifecycle_details == other.lifecycle_details &&
    csi_number == other.csi_number &&
    contacts == other.contacts &&
    maintenance_slo_status == other.maintenance_slo_status &&
    maintenance_window == other.maintenance_window &&
    last_maintenance_run_id == other.last_maintenance_run_id &&
    next_maintenance_run_id == other.next_maintenance_run_id &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
# File 'lib/oci/database/models/exadata_infrastructure.rb', line 625

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


605
606
607
# File 'lib/oci/database/models/exadata_infrastructure.rb', line 605

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



614
615
616
# File 'lib/oci/database/models/exadata_infrastructure.rb', line 614

def hash
  [id, compartment_id, lifecycle_state, display_name, shape, time_zone, cpus_enabled, max_cpu_count, memory_size_in_gbs, max_memory_in_gbs, db_node_storage_size_in_gbs, max_db_node_storage_in_g_bs, data_storage_size_in_tbs, max_data_storage_in_t_bs, storage_count, additional_storage_count, activated_storage_count, compute_count, cloud_control_plane_server1, cloud_control_plane_server2, netmask, gateway, admin_network_cidr, infini_band_network_cidr, corporate_proxy, dns_server, ntp_server, time_created, lifecycle_details, csi_number, contacts, maintenance_slo_status, maintenance_window, last_maintenance_run_id, next_maintenance_run_id, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



658
659
660
661
662
663
664
665
666
667
# File 'lib/oci/database/models/exadata_infrastructure.rb', line 658

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



652
653
654
# File 'lib/oci/database/models/exadata_infrastructure.rb', line 652

def to_s
  to_hash.to_s
end