Class: OCI::Database::Models::ExadataInfrastructureContact
- Inherits:
-
Object
- Object
- OCI::Database::Models::ExadataInfrastructureContact
- Defined in:
- lib/oci/database/models/exadata_infrastructure_contact.rb
Overview
Contact details for Exadata Infrastructure.
Instance Attribute Summary collapse
-
#email ⇒ String
[Required] The email for the Exadata Infrastructure contact.
-
#is_contact_mos_validated ⇒ BOOLEAN
If
true, this Exadata Infrastructure contact is a valid My Oracle Support (MOS) contact. -
#is_primary ⇒ BOOLEAN
[Required] If
true, this Exadata Infrastructure contact is a primary contact. -
#name ⇒ String
[Required] The name of the Exadata Infrastructure contact.
-
#phone_number ⇒ String
The phone number for the Exadata Infrastructure contact.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ExadataInfrastructureContact
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ExadataInfrastructureContact
Initializes the object
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/oci/database/models/exadata_infrastructure_contact.rb', line 67 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.phone_number = attributes[:'phoneNumber'] if attributes[:'phoneNumber'] raise 'You cannot provide both :phoneNumber and :phone_number' if attributes.key?(:'phoneNumber') && attributes.key?(:'phone_number') self.phone_number = attributes[:'phone_number'] if attributes[:'phone_number'] self.email = attributes[:'email'] if attributes[:'email'] self.is_primary = attributes[:'isPrimary'] unless attributes[:'isPrimary'].nil? raise 'You cannot provide both :isPrimary and :is_primary' if attributes.key?(:'isPrimary') && attributes.key?(:'is_primary') self.is_primary = attributes[:'is_primary'] unless attributes[:'is_primary'].nil? self.is_contact_mos_validated = attributes[:'isContactMosValidated'] unless attributes[:'isContactMosValidated'].nil? raise 'You cannot provide both :isContactMosValidated and :is_contact_mos_validated' if attributes.key?(:'isContactMosValidated') && attributes.key?(:'is_contact_mos_validated') self.is_contact_mos_validated = attributes[:'is_contact_mos_validated'] unless attributes[:'is_contact_mos_validated'].nil? end |
Instance Attribute Details
#email ⇒ String
[Required] The email for the Exadata Infrastructure contact.
20 21 22 |
# File 'lib/oci/database/models/exadata_infrastructure_contact.rb', line 20 def email @email end |
#is_contact_mos_validated ⇒ BOOLEAN
If true, this Exadata Infrastructure contact is a valid My Oracle Support (MOS) contact. If false, this Exadata Infrastructure contact is not a valid MOS contact.
28 29 30 |
# File 'lib/oci/database/models/exadata_infrastructure_contact.rb', line 28 def is_contact_mos_validated @is_contact_mos_validated end |
#is_primary ⇒ BOOLEAN
[Required] If true, this Exadata Infrastructure contact is a primary contact. If false, this Exadata Infrastructure is a secondary contact.
24 25 26 |
# File 'lib/oci/database/models/exadata_infrastructure_contact.rb', line 24 def is_primary @is_primary end |
#name ⇒ String
[Required] The name of the Exadata Infrastructure contact.
12 13 14 |
# File 'lib/oci/database/models/exadata_infrastructure_contact.rb', line 12 def name @name end |
#phone_number ⇒ String
The phone number for the Exadata Infrastructure contact.
16 17 18 |
# File 'lib/oci/database/models/exadata_infrastructure_contact.rb', line 16 def phone_number @phone_number end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 40 41 |
# File 'lib/oci/database/models/exadata_infrastructure_contact.rb', line 31 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'phone_number': :'phoneNumber', 'email': :'email', 'is_primary': :'isPrimary', 'is_contact_mos_validated': :'isContactMosValidated' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/oci/database/models/exadata_infrastructure_contact.rb', line 44 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'phone_number': :'String', 'email': :'String', 'is_primary': :'BOOLEAN', 'is_contact_mos_validated': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
103 104 105 106 107 108 109 110 111 112 |
# File 'lib/oci/database/models/exadata_infrastructure_contact.rb', line 103 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && phone_number == other.phone_number && email == other.email && is_primary == other.is_primary && is_contact_mos_validated == other.is_contact_mos_validated end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/oci/database/models/exadata_infrastructure_contact.rb', line 137 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
117 118 119 |
# File 'lib/oci/database/models/exadata_infrastructure_contact.rb', line 117 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
126 127 128 |
# File 'lib/oci/database/models/exadata_infrastructure_contact.rb', line 126 def hash [name, phone_number, email, is_primary, is_contact_mos_validated].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
170 171 172 173 174 175 176 177 178 179 |
# File 'lib/oci/database/models/exadata_infrastructure_contact.rb', line 170 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
164 165 166 |
# File 'lib/oci/database/models/exadata_infrastructure_contact.rb', line 164 def to_s to_hash.to_s end |