Class: OCI::Database::Models::ExadataInfrastructureSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database/models/exadata_infrastructure_summary.rb

Overview

Details of the Exadata Cloud@Customer infrastructure. Applies to Exadata Cloud@Customer instances only. See cloud_exadata_infrastructure_summary for details of the cloud Exadata infrastructure resource used by Exadata Cloud Service instances.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_REQUIRES_ACTIVATION = 'REQUIRES_ACTIVATION'.freeze,
  LIFECYCLE_STATE_ACTIVATING = 'ACTIVATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_ACTIVATION_FAILED = 'ACTIVATION_FAILED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_DISCONNECTED = 'DISCONNECTED'.freeze,
  LIFECYCLE_STATE_MAINTENANCE_IN_PROGRESS = 'MAINTENANCE_IN_PROGRESS'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
MAINTENANCE_SLO_STATUS_ENUM =
[
  MAINTENANCE_SLO_STATUS_OK = 'OK'.freeze,
  MAINTENANCE_SLO_STATUS_DEGRADED = 'DEGRADED'.freeze,
  MAINTENANCE_SLO_STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ExadataInfrastructureSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 346

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.shape = attributes[:'shape'] if attributes[:'shape']

  self.time_zone = attributes[:'timeZone'] if attributes[:'timeZone']

  raise 'You cannot provide both :timeZone and :time_zone' if attributes.key?(:'timeZone') && attributes.key?(:'time_zone')

  self.time_zone = attributes[:'time_zone'] if attributes[:'time_zone']

  self.cpus_enabled = attributes[:'cpusEnabled'] if attributes[:'cpusEnabled']

  raise 'You cannot provide both :cpusEnabled and :cpus_enabled' if attributes.key?(:'cpusEnabled') && attributes.key?(:'cpus_enabled')

  self.cpus_enabled = attributes[:'cpus_enabled'] if attributes[:'cpus_enabled']

  self.max_cpu_count = attributes[:'maxCpuCount'] if attributes[:'maxCpuCount']

  raise 'You cannot provide both :maxCpuCount and :max_cpu_count' if attributes.key?(:'maxCpuCount') && attributes.key?(:'max_cpu_count')

  self.max_cpu_count = attributes[:'max_cpu_count'] if attributes[:'max_cpu_count']

  self.memory_size_in_gbs = attributes[:'memorySizeInGBs'] if attributes[:'memorySizeInGBs']

  raise 'You cannot provide both :memorySizeInGBs and :memory_size_in_gbs' if attributes.key?(:'memorySizeInGBs') && attributes.key?(:'memory_size_in_gbs')

  self.memory_size_in_gbs = attributes[:'memory_size_in_gbs'] if attributes[:'memory_size_in_gbs']

  self.max_memory_in_gbs = attributes[:'maxMemoryInGBs'] if attributes[:'maxMemoryInGBs']

  raise 'You cannot provide both :maxMemoryInGBs and :max_memory_in_gbs' if attributes.key?(:'maxMemoryInGBs') && attributes.key?(:'max_memory_in_gbs')

  self.max_memory_in_gbs = attributes[:'max_memory_in_gbs'] if attributes[:'max_memory_in_gbs']

  self.db_node_storage_size_in_gbs = attributes[:'dbNodeStorageSizeInGBs'] if attributes[:'dbNodeStorageSizeInGBs']

  raise 'You cannot provide both :dbNodeStorageSizeInGBs and :db_node_storage_size_in_gbs' if attributes.key?(:'dbNodeStorageSizeInGBs') && attributes.key?(:'db_node_storage_size_in_gbs')

  self.db_node_storage_size_in_gbs = attributes[:'db_node_storage_size_in_gbs'] if attributes[:'db_node_storage_size_in_gbs']

  self.max_db_node_storage_in_g_bs = attributes[:'maxDbNodeStorageInGBs'] if attributes[:'maxDbNodeStorageInGBs']

  raise 'You cannot provide both :maxDbNodeStorageInGBs and :max_db_node_storage_in_g_bs' if attributes.key?(:'maxDbNodeStorageInGBs') && attributes.key?(:'max_db_node_storage_in_g_bs')

  self.max_db_node_storage_in_g_bs = attributes[:'max_db_node_storage_in_g_bs'] if attributes[:'max_db_node_storage_in_g_bs']

  self.data_storage_size_in_tbs = attributes[:'dataStorageSizeInTBs'] if attributes[:'dataStorageSizeInTBs']

  raise 'You cannot provide both :dataStorageSizeInTBs and :data_storage_size_in_tbs' if attributes.key?(:'dataStorageSizeInTBs') && attributes.key?(:'data_storage_size_in_tbs')

  self.data_storage_size_in_tbs = attributes[:'data_storage_size_in_tbs'] if attributes[:'data_storage_size_in_tbs']

  self.max_data_storage_in_t_bs = attributes[:'maxDataStorageInTBs'] if attributes[:'maxDataStorageInTBs']

  raise 'You cannot provide both :maxDataStorageInTBs and :max_data_storage_in_t_bs' if attributes.key?(:'maxDataStorageInTBs') && attributes.key?(:'max_data_storage_in_t_bs')

  self.max_data_storage_in_t_bs = attributes[:'max_data_storage_in_t_bs'] if attributes[:'max_data_storage_in_t_bs']

  self.storage_count = attributes[:'storageCount'] if attributes[:'storageCount']

  raise 'You cannot provide both :storageCount and :storage_count' if attributes.key?(:'storageCount') && attributes.key?(:'storage_count')

  self.storage_count = attributes[:'storage_count'] if attributes[:'storage_count']

  self.additional_storage_count = attributes[:'additionalStorageCount'] if attributes[:'additionalStorageCount']

  raise 'You cannot provide both :additionalStorageCount and :additional_storage_count' if attributes.key?(:'additionalStorageCount') && attributes.key?(:'additional_storage_count')

  self.additional_storage_count = attributes[:'additional_storage_count'] if attributes[:'additional_storage_count']

  self.activated_storage_count = attributes[:'activatedStorageCount'] if attributes[:'activatedStorageCount']

  raise 'You cannot provide both :activatedStorageCount and :activated_storage_count' if attributes.key?(:'activatedStorageCount') && attributes.key?(:'activated_storage_count')

  self.activated_storage_count = attributes[:'activated_storage_count'] if attributes[:'activated_storage_count']

  self.compute_count = attributes[:'computeCount'] if attributes[:'computeCount']

  raise 'You cannot provide both :computeCount and :compute_count' if attributes.key?(:'computeCount') && attributes.key?(:'compute_count')

  self.compute_count = attributes[:'compute_count'] if attributes[:'compute_count']

  self.cloud_control_plane_server1 = attributes[:'cloudControlPlaneServer1'] if attributes[:'cloudControlPlaneServer1']

  raise 'You cannot provide both :cloudControlPlaneServer1 and :cloud_control_plane_server1' if attributes.key?(:'cloudControlPlaneServer1') && attributes.key?(:'cloud_control_plane_server1')

  self.cloud_control_plane_server1 = attributes[:'cloud_control_plane_server1'] if attributes[:'cloud_control_plane_server1']

  self.cloud_control_plane_server2 = attributes[:'cloudControlPlaneServer2'] if attributes[:'cloudControlPlaneServer2']

  raise 'You cannot provide both :cloudControlPlaneServer2 and :cloud_control_plane_server2' if attributes.key?(:'cloudControlPlaneServer2') && attributes.key?(:'cloud_control_plane_server2')

  self.cloud_control_plane_server2 = attributes[:'cloud_control_plane_server2'] if attributes[:'cloud_control_plane_server2']

  self.netmask = attributes[:'netmask'] if attributes[:'netmask']

  self.gateway = attributes[:'gateway'] if attributes[:'gateway']

  self.admin_network_cidr = attributes[:'adminNetworkCIDR'] if attributes[:'adminNetworkCIDR']

  raise 'You cannot provide both :adminNetworkCIDR and :admin_network_cidr' if attributes.key?(:'adminNetworkCIDR') && attributes.key?(:'admin_network_cidr')

  self.admin_network_cidr = attributes[:'admin_network_cidr'] if attributes[:'admin_network_cidr']

  self.infini_band_network_cidr = attributes[:'infiniBandNetworkCIDR'] if attributes[:'infiniBandNetworkCIDR']

  raise 'You cannot provide both :infiniBandNetworkCIDR and :infini_band_network_cidr' if attributes.key?(:'infiniBandNetworkCIDR') && attributes.key?(:'infini_band_network_cidr')

  self.infini_band_network_cidr = attributes[:'infini_band_network_cidr'] if attributes[:'infini_band_network_cidr']

  self.corporate_proxy = attributes[:'corporateProxy'] if attributes[:'corporateProxy']

  raise 'You cannot provide both :corporateProxy and :corporate_proxy' if attributes.key?(:'corporateProxy') && attributes.key?(:'corporate_proxy')

  self.corporate_proxy = attributes[:'corporate_proxy'] if attributes[:'corporate_proxy']

  self.dns_server = attributes[:'dnsServer'] if attributes[:'dnsServer']

  raise 'You cannot provide both :dnsServer and :dns_server' if attributes.key?(:'dnsServer') && attributes.key?(:'dns_server')

  self.dns_server = attributes[:'dns_server'] if attributes[:'dns_server']

  self.ntp_server = attributes[:'ntpServer'] if attributes[:'ntpServer']

  raise 'You cannot provide both :ntpServer and :ntp_server' if attributes.key?(:'ntpServer') && attributes.key?(:'ntp_server')

  self.ntp_server = attributes[:'ntp_server'] if attributes[:'ntp_server']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.csi_number = attributes[:'csiNumber'] if attributes[:'csiNumber']

  raise 'You cannot provide both :csiNumber and :csi_number' if attributes.key?(:'csiNumber') && attributes.key?(:'csi_number')

  self.csi_number = attributes[:'csi_number'] if attributes[:'csi_number']

  self.contacts = attributes[:'contacts'] if attributes[:'contacts']

  self.maintenance_slo_status = attributes[:'maintenanceSLOStatus'] if attributes[:'maintenanceSLOStatus']

  raise 'You cannot provide both :maintenanceSLOStatus and :maintenance_slo_status' if attributes.key?(:'maintenanceSLOStatus') && attributes.key?(:'maintenance_slo_status')

  self.maintenance_slo_status = attributes[:'maintenance_slo_status'] if attributes[:'maintenance_slo_status']

  self.maintenance_window = attributes[:'maintenanceWindow'] if attributes[:'maintenanceWindow']

  raise 'You cannot provide both :maintenanceWindow and :maintenance_window' if attributes.key?(:'maintenanceWindow') && attributes.key?(:'maintenance_window')

  self.maintenance_window = attributes[:'maintenance_window'] if attributes[:'maintenance_window']

  self.storage_server_version = attributes[:'storageServerVersion'] if attributes[:'storageServerVersion']

  raise 'You cannot provide both :storageServerVersion and :storage_server_version' if attributes.key?(:'storageServerVersion') && attributes.key?(:'storage_server_version')

  self.storage_server_version = attributes[:'storage_server_version'] if attributes[:'storage_server_version']

  self.db_server_version = attributes[:'dbServerVersion'] if attributes[:'dbServerVersion']

  raise 'You cannot provide both :dbServerVersion and :db_server_version' if attributes.key?(:'dbServerVersion') && attributes.key?(:'db_server_version')

  self.db_server_version = attributes[:'db_server_version'] if attributes[:'db_server_version']

  self.last_maintenance_run_id = attributes[:'lastMaintenanceRunId'] if attributes[:'lastMaintenanceRunId']

  raise 'You cannot provide both :lastMaintenanceRunId and :last_maintenance_run_id' if attributes.key?(:'lastMaintenanceRunId') && attributes.key?(:'last_maintenance_run_id')

  self.last_maintenance_run_id = attributes[:'last_maintenance_run_id'] if attributes[:'last_maintenance_run_id']

  self.next_maintenance_run_id = attributes[:'nextMaintenanceRunId'] if attributes[:'nextMaintenanceRunId']

  raise 'You cannot provide both :nextMaintenanceRunId and :next_maintenance_run_id' if attributes.key?(:'nextMaintenanceRunId') && attributes.key?(:'next_maintenance_run_id')

  self.next_maintenance_run_id = attributes[:'next_maintenance_run_id'] if attributes[:'next_maintenance_run_id']

  self.is_cps_offline_report_enabled = attributes[:'isCpsOfflineReportEnabled'] unless attributes[:'isCpsOfflineReportEnabled'].nil?

  raise 'You cannot provide both :isCpsOfflineReportEnabled and :is_cps_offline_report_enabled' if attributes.key?(:'isCpsOfflineReportEnabled') && attributes.key?(:'is_cps_offline_report_enabled')

  self.is_cps_offline_report_enabled = attributes[:'is_cps_offline_report_enabled'] unless attributes[:'is_cps_offline_report_enabled'].nil?

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#activated_storage_countInteger

The requested number of additional storage servers activated for the Exadata infrastructure.

Returns:

  • (Integer)


102
103
104
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 102

def activated_storage_count
  @activated_storage_count
end

#additional_storage_countInteger

The requested number of additional storage servers for the Exadata infrastructure.

Returns:

  • (Integer)


98
99
100
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 98

def additional_storage_count
  @additional_storage_count
end

#admin_network_cidrString

The CIDR block for the Exadata administration network.

Returns:

  • (String)


126
127
128
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 126

def admin_network_cidr
  @admin_network_cidr
end

#cloud_control_plane_server1String

The IP address for the first control plane server.

Returns:

  • (String)


110
111
112
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 110

def cloud_control_plane_server1
  @cloud_control_plane_server1
end

#cloud_control_plane_server2String

The IP address for the second control plane server.

Returns:

  • (String)


114
115
116
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 114

def cloud_control_plane_server2
  @cloud_control_plane_server2
end

#compartment_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.

Returns:

  • (String)


40
41
42
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 40

def compartment_id
  @compartment_id
end

#compute_countInteger

The number of compute servers for the Exadata infrastructure.

Returns:

  • (Integer)


106
107
108
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 106

def compute_count
  @compute_count
end

#contactsArray<OCI::Database::Models::ExadataInfrastructureContact>

The list of contacts for the Exadata infrastructure.



158
159
160
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 158

def contacts
  @contacts
end

#corporate_proxyString

The corporate network proxy for access to the control plane network.

Returns:

  • (String)


134
135
136
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 134

def corporate_proxy
  @corporate_proxy
end

#cpus_enabledInteger

The number of enabled CPU cores.

Returns:

  • (Integer)


61
62
63
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 61

def cpus_enabled
  @cpus_enabled
end

#csi_numberString

The CSI Number of the Exadata infrastructure.

Returns:

  • (String)


154
155
156
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 154

def csi_number
  @csi_number
end

#data_storage_size_in_tbsFloat

Size, in terabytes, of the DATA disk group.

Returns:

  • (Float)


86
87
88
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 86

def data_storage_size_in_tbs
  @data_storage_size_in_tbs
end

#db_node_storage_size_in_gbsInteger

The local node storage allocated in GBs.

Returns:

  • (Integer)


77
78
79
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 77

def db_node_storage_size_in_gbs
  @db_node_storage_size_in_gbs
end

#db_server_versionString

The software version of the database servers (dom0) in the Exadata infrastructure.

Returns:

  • (String)


173
174
175
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 173

def db_server_version
  @db_server_version
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Returns:

  • (Hash<String, Hash<String, Object>>)


202
203
204
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 202

def defined_tags
  @defined_tags
end

#display_nameString

**[Required]** The user-friendly name for the Exadata Cloud@Customer infrastructure. The name does not need to be unique.

Returns:

  • (String)


48
49
50
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 48

def display_name
  @display_name
end

#dns_serverArray<String>

The list of DNS server IP addresses. Maximum of 3 allowed.

Returns:

  • (Array<String>)


138
139
140
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 138

def dns_server
  @dns_server
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: `"Finance"`

Returns:

  • (Hash<String, String>)


196
197
198
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 196

def freeform_tags
  @freeform_tags
end

#gatewayString

The gateway for the control plane network.

Returns:

  • (String)


122
123
124
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 122

def gateway
  @gateway
end

#idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Exadata infrastructure.

Returns:

  • (String)


36
37
38
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 36

def id
  @id
end

#infini_band_network_cidrString

The CIDR block for the Exadata InfiniBand interconnect.

Returns:

  • (String)


130
131
132
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 130

def infini_band_network_cidr
  @infini_band_network_cidr
end

#is_cps_offline_report_enabledBOOLEAN

Indicates whether cps offline diagnostic report is enabled for this Exadata infrastructure. This will allow a customer to quickly check status themselves and fix problems on their end, saving time and frustration for both Oracle and the customer when they find the CPS in a disconnected state.You can enable offline diagnostic report during Exadata infrastructure provisioning. You can also disable or enable it at any time using the UpdateExadatainfrastructure API.

Returns:

  • (BOOLEAN)


188
189
190
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 188

def is_cps_offline_report_enabled
  @is_cps_offline_report_enabled
end

#last_maintenance_run_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the last maintenance run.

Returns:

  • (String)


177
178
179
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 177

def last_maintenance_run_id
  @last_maintenance_run_id
end

#lifecycle_detailsString

Additional information about the current lifecycle state.

Returns:

  • (String)


150
151
152
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 150

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

**[Required]** The current lifecycle state of the Exadata infrastructure.

Returns:

  • (String)


44
45
46
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 44

def lifecycle_state
  @lifecycle_state
end

#maintenance_slo_statusString

A field to capture u2018Maintenance SLO Statusu2019 for the Exadata infrastructure with values u2018OKu2019, u2018DEGRADEDu2019. Default is u2018OKu2019 when the infrastructure is provisioned.

Returns:

  • (String)


162
163
164
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 162

def maintenance_slo_status
  @maintenance_slo_status
end

#maintenance_windowOCI::Database::Models::MaintenanceWindow



165
166
167
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 165

def maintenance_window
  @maintenance_window
end

#max_cpu_countInteger

The total number of CPU cores available.

Returns:

  • (Integer)


65
66
67
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 65

def max_cpu_count
  @max_cpu_count
end

#max_data_storage_in_t_bsFloat

The total available DATA disk group size.

Returns:

  • (Float)


90
91
92
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 90

def max_data_storage_in_t_bs
  @max_data_storage_in_t_bs
end

#max_db_node_storage_in_g_bsInteger

The total local node storage available in GBs.

Returns:

  • (Integer)


81
82
83
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 81

def max_db_node_storage_in_g_bs
  @max_db_node_storage_in_g_bs
end

#max_memory_in_gbsInteger

The total memory available in GBs.

Returns:

  • (Integer)


73
74
75
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 73

def max_memory_in_gbs
  @max_memory_in_gbs
end

#memory_size_in_gbsInteger

The memory allocated in GBs.

Returns:

  • (Integer)


69
70
71
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 69

def memory_size_in_gbs
  @memory_size_in_gbs
end

#netmaskString

The netmask for the control plane network.

Returns:

  • (String)


118
119
120
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 118

def netmask
  @netmask
end

#next_maintenance_run_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the next maintenance run.

Returns:

  • (String)


181
182
183
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 181

def next_maintenance_run_id
  @next_maintenance_run_id
end

#ntp_serverArray<String>

The list of NTP server IP addresses. Maximum of 3 allowed.

Returns:

  • (Array<String>)


142
143
144
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 142

def ntp_server
  @ntp_server
end

#shapeString

**[Required]** The shape of the Exadata infrastructure. The shape determines the amount of CPU, storage, and memory resources allocated to the instance.

Returns:

  • (String)


53
54
55
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 53

def shape
  @shape
end

#storage_countInteger

The number of Exadata storage servers for the Exadata infrastructure.

Returns:

  • (Integer)


94
95
96
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 94

def storage_count
  @storage_count
end

#storage_server_versionString

The software version of the storage servers (cells) in the Exadata infrastructure.

Returns:

  • (String)


169
170
171
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 169

def storage_server_version
  @storage_server_version
end

#time_createdDateTime

The date and time the Exadata infrastructure was created.

Returns:

  • (DateTime)


146
147
148
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 146

def time_created
  @time_created
end

#time_zoneString

The time zone of the Exadata infrastructure. For details, see [Exadata Infrastructure Time Zones](docs.cloud.oracle.com/Content/Database/References/timezones.htm).

Returns:

  • (String)


57
58
59
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 57

def time_zone
  @time_zone
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 205

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'compartment_id': :'compartmentId',
    'lifecycle_state': :'lifecycleState',
    'display_name': :'displayName',
    'shape': :'shape',
    'time_zone': :'timeZone',
    'cpus_enabled': :'cpusEnabled',
    'max_cpu_count': :'maxCpuCount',
    'memory_size_in_gbs': :'memorySizeInGBs',
    'max_memory_in_gbs': :'maxMemoryInGBs',
    'db_node_storage_size_in_gbs': :'dbNodeStorageSizeInGBs',
    'max_db_node_storage_in_g_bs': :'maxDbNodeStorageInGBs',
    'data_storage_size_in_tbs': :'dataStorageSizeInTBs',
    'max_data_storage_in_t_bs': :'maxDataStorageInTBs',
    'storage_count': :'storageCount',
    'additional_storage_count': :'additionalStorageCount',
    'activated_storage_count': :'activatedStorageCount',
    'compute_count': :'computeCount',
    'cloud_control_plane_server1': :'cloudControlPlaneServer1',
    'cloud_control_plane_server2': :'cloudControlPlaneServer2',
    'netmask': :'netmask',
    'gateway': :'gateway',
    'admin_network_cidr': :'adminNetworkCIDR',
    'infini_band_network_cidr': :'infiniBandNetworkCIDR',
    'corporate_proxy': :'corporateProxy',
    'dns_server': :'dnsServer',
    'ntp_server': :'ntpServer',
    'time_created': :'timeCreated',
    'lifecycle_details': :'lifecycleDetails',
    'csi_number': :'csiNumber',
    'contacts': :'contacts',
    'maintenance_slo_status': :'maintenanceSLOStatus',
    'maintenance_window': :'maintenanceWindow',
    'storage_server_version': :'storageServerVersion',
    'db_server_version': :'dbServerVersion',
    'last_maintenance_run_id': :'lastMaintenanceRunId',
    'next_maintenance_run_id': :'nextMaintenanceRunId',
    'is_cps_offline_report_enabled': :'isCpsOfflineReportEnabled',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 253

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'compartment_id': :'String',
    'lifecycle_state': :'String',
    'display_name': :'String',
    'shape': :'String',
    'time_zone': :'String',
    'cpus_enabled': :'Integer',
    'max_cpu_count': :'Integer',
    'memory_size_in_gbs': :'Integer',
    'max_memory_in_gbs': :'Integer',
    'db_node_storage_size_in_gbs': :'Integer',
    'max_db_node_storage_in_g_bs': :'Integer',
    'data_storage_size_in_tbs': :'Float',
    'max_data_storage_in_t_bs': :'Float',
    'storage_count': :'Integer',
    'additional_storage_count': :'Integer',
    'activated_storage_count': :'Integer',
    'compute_count': :'Integer',
    'cloud_control_plane_server1': :'String',
    'cloud_control_plane_server2': :'String',
    'netmask': :'String',
    'gateway': :'String',
    'admin_network_cidr': :'String',
    'infini_band_network_cidr': :'String',
    'corporate_proxy': :'String',
    'dns_server': :'Array<String>',
    'ntp_server': :'Array<String>',
    'time_created': :'DateTime',
    'lifecycle_details': :'String',
    'csi_number': :'String',
    'contacts': :'Array<OCI::Database::Models::ExadataInfrastructureContact>',
    'maintenance_slo_status': :'String',
    'maintenance_window': :'OCI::Database::Models::MaintenanceWindow',
    'storage_server_version': :'String',
    'db_server_version': :'String',
    'last_maintenance_run_id': :'String',
    'next_maintenance_run_id': :'String',
    'is_cps_offline_report_enabled': :'BOOLEAN',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 606

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    lifecycle_state == other.lifecycle_state &&
    display_name == other.display_name &&
    shape == other.shape &&
    time_zone == other.time_zone &&
    cpus_enabled == other.cpus_enabled &&
    max_cpu_count == other.max_cpu_count &&
    memory_size_in_gbs == other.memory_size_in_gbs &&
    max_memory_in_gbs == other.max_memory_in_gbs &&
    db_node_storage_size_in_gbs == other.db_node_storage_size_in_gbs &&
    max_db_node_storage_in_g_bs == other.max_db_node_storage_in_g_bs &&
    data_storage_size_in_tbs == other.data_storage_size_in_tbs &&
    max_data_storage_in_t_bs == other.max_data_storage_in_t_bs &&
    storage_count == other.storage_count &&
    additional_storage_count == other.additional_storage_count &&
    activated_storage_count == other.activated_storage_count &&
    compute_count == other.compute_count &&
    cloud_control_plane_server1 == other.cloud_control_plane_server1 &&
    cloud_control_plane_server2 == other.cloud_control_plane_server2 &&
    netmask == other.netmask &&
    gateway == other.gateway &&
    admin_network_cidr == other.admin_network_cidr &&
    infini_band_network_cidr == other.infini_band_network_cidr &&
    corporate_proxy == other.corporate_proxy &&
    dns_server == other.dns_server &&
    ntp_server == other.ntp_server &&
    time_created == other.time_created &&
    lifecycle_details == other.lifecycle_details &&
    csi_number == other.csi_number &&
    contacts == other.contacts &&
    maintenance_slo_status == other.maintenance_slo_status &&
    maintenance_window == other.maintenance_window &&
    storage_server_version == other.storage_server_version &&
    db_server_version == other.db_server_version &&
    last_maintenance_run_id == other.last_maintenance_run_id &&
    next_maintenance_run_id == other.next_maintenance_run_id &&
    is_cps_offline_report_enabled == other.is_cps_offline_report_enabled &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 675

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


655
656
657
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 655

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



664
665
666
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 664

def hash
  [id, compartment_id, lifecycle_state, display_name, shape, time_zone, cpus_enabled, max_cpu_count, memory_size_in_gbs, max_memory_in_gbs, db_node_storage_size_in_gbs, max_db_node_storage_in_g_bs, data_storage_size_in_tbs, max_data_storage_in_t_bs, storage_count, additional_storage_count, activated_storage_count, compute_count, cloud_control_plane_server1, cloud_control_plane_server2, netmask, gateway, admin_network_cidr, infini_band_network_cidr, corporate_proxy, dns_server, ntp_server, time_created, lifecycle_details, csi_number, contacts, maintenance_slo_status, maintenance_window, storage_server_version, db_server_version, last_maintenance_run_id, next_maintenance_run_id, is_cps_offline_report_enabled, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



708
709
710
711
712
713
714
715
716
717
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 708

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



702
703
704
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 702

def to_s
  to_hash.to_s
end