Class: OCI::Database::Models::ExternalContainerDatabase
- Inherits:
-
Object
- Object
- OCI::Database::Models::ExternalContainerDatabase
- Defined in:
- lib/oci/database/models/external_container_database.rb
Overview
An Oracle Cloud Infrastructure resource that allows you to manage an external container database.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze, LIFECYCLE_STATE_NOT_CONNECTED = 'NOT_CONNECTED'.freeze, LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze, LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- DATABASE_EDITION_ENUM =
[ DATABASE_EDITION_STANDARD_EDITION = 'STANDARD_EDITION'.freeze, DATABASE_EDITION_ENTERPRISE_EDITION = 'ENTERPRISE_EDITION'.freeze, DATABASE_EDITION_ENTERPRISE_EDITION_HIGH_PERFORMANCE = 'ENTERPRISE_EDITION_HIGH_PERFORMANCE'.freeze, DATABASE_EDITION_ENTERPRISE_EDITION_EXTREME_PERFORMANCE = 'ENTERPRISE_EDITION_EXTREME_PERFORMANCE'.freeze, DATABASE_EDITION_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- DATABASE_CONFIGURATION_ENUM =
[ DATABASE_CONFIGURATION_RAC = 'RAC'.freeze, DATABASE_CONFIGURATION_SINGLE_INSTANCE = 'SINGLE_INSTANCE'.freeze, DATABASE_CONFIGURATION_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#character_set ⇒ String
The character set of the external database.
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
-
#database_configuration ⇒ String
The Oracle Database configuration.
-
#database_edition ⇒ String
The Oracle Database edition.
- #database_management_config ⇒ OCI::Database::Models::DatabaseManagementConfig
-
#database_version ⇒ String
The Oracle Database version.
-
#db_id ⇒ String
The Oracle Database ID, which identifies an Oracle Database located outside of Oracle Cloud.
-
#db_packs ⇒ String
The database packs licensed for the external Oracle Database.
-
#db_unique_name ⇒ String
The
DB_UNIQUE_NAMEof the external database. -
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
[Required] The user-friendly name for the external database.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Oracle Cloud Infrastructure external database resource.
-
#lifecycle_details ⇒ String
Additional information about the current lifecycle state.
-
#lifecycle_state ⇒ String
[Required] The current state of the Oracle Cloud Infrastructure external database resource.
-
#ncharacter_set ⇒ String
The national character of the external database.
-
#time_created ⇒ DateTime
[Required] The date and time the database was created.
-
#time_zone ⇒ String
The time zone of the external database.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ExternalContainerDatabase
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ExternalContainerDatabase
Initializes the object
196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/oci/database/models/external_container_database.rb', line 196 def initialize(attributes = {}) return unless attributes.is_a?(Hash) self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.id = attributes[:'id'] if attributes[:'id'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.db_unique_name = attributes[:'dbUniqueName'] if attributes[:'dbUniqueName'] raise 'You cannot provide both :dbUniqueName and :db_unique_name' if attributes.key?(:'dbUniqueName') && attributes.key?(:'db_unique_name') self.db_unique_name = attributes[:'db_unique_name'] if attributes[:'db_unique_name'] self.db_id = attributes[:'dbId'] if attributes[:'dbId'] raise 'You cannot provide both :dbId and :db_id' if attributes.key?(:'dbId') && attributes.key?(:'db_id') self.db_id = attributes[:'db_id'] if attributes[:'db_id'] self.database_version = attributes[:'databaseVersion'] if attributes[:'databaseVersion'] raise 'You cannot provide both :databaseVersion and :database_version' if attributes.key?(:'databaseVersion') && attributes.key?(:'database_version') self.database_version = attributes[:'database_version'] if attributes[:'database_version'] self.database_edition = attributes[:'databaseEdition'] if attributes[:'databaseEdition'] raise 'You cannot provide both :databaseEdition and :database_edition' if attributes.key?(:'databaseEdition') && attributes.key?(:'database_edition') self.database_edition = attributes[:'database_edition'] if attributes[:'database_edition'] self.time_zone = attributes[:'timeZone'] if attributes[:'timeZone'] raise 'You cannot provide both :timeZone and :time_zone' if attributes.key?(:'timeZone') && attributes.key?(:'time_zone') self.time_zone = attributes[:'time_zone'] if attributes[:'time_zone'] self.character_set = attributes[:'characterSet'] if attributes[:'characterSet'] raise 'You cannot provide both :characterSet and :character_set' if attributes.key?(:'characterSet') && attributes.key?(:'character_set') self.character_set = attributes[:'character_set'] if attributes[:'character_set'] self.ncharacter_set = attributes[:'ncharacterSet'] if attributes[:'ncharacterSet'] raise 'You cannot provide both :ncharacterSet and :ncharacter_set' if attributes.key?(:'ncharacterSet') && attributes.key?(:'ncharacter_set') self.ncharacter_set = attributes[:'ncharacter_set'] if attributes[:'ncharacter_set'] self.db_packs = attributes[:'dbPacks'] if attributes[:'dbPacks'] raise 'You cannot provide both :dbPacks and :db_packs' if attributes.key?(:'dbPacks') && attributes.key?(:'db_packs') self.db_packs = attributes[:'db_packs'] if attributes[:'db_packs'] self.database_configuration = attributes[:'databaseConfiguration'] if attributes[:'databaseConfiguration'] raise 'You cannot provide both :databaseConfiguration and :database_configuration' if attributes.key?(:'databaseConfiguration') && attributes.key?(:'database_configuration') self.database_configuration = attributes[:'database_configuration'] if attributes[:'database_configuration'] self.database_management_config = attributes[:'databaseManagementConfig'] if attributes[:'databaseManagementConfig'] raise 'You cannot provide both :databaseManagementConfig and :database_management_config' if attributes.key?(:'databaseManagementConfig') && attributes.key?(:'database_management_config') self.database_management_config = attributes[:'database_management_config'] if attributes[:'database_management_config'] end |
Instance Attribute Details
#character_set ⇒ String
The character set of the external database.
103 104 105 |
# File 'lib/oci/database/models/external_container_database.rb', line 103 def character_set @character_set end |
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
39 40 41 |
# File 'lib/oci/database/models/external_container_database.rb', line 39 def compartment_id @compartment_id end |
#database_configuration ⇒ String
The Oracle Database configuration
115 116 117 |
# File 'lib/oci/database/models/external_container_database.rb', line 115 def database_configuration @database_configuration end |
#database_edition ⇒ String
The Oracle Database edition.
92 93 94 |
# File 'lib/oci/database/models/external_container_database.rb', line 92 def database_edition @database_edition end |
#database_management_config ⇒ OCI::Database::Models::DatabaseManagementConfig
118 119 120 |
# File 'lib/oci/database/models/external_container_database.rb', line 118 def database_management_config @database_management_config end |
#database_version ⇒ String
The Oracle Database version.
87 88 89 |
# File 'lib/oci/database/models/external_container_database.rb', line 87 def database_version @database_version end |
#db_id ⇒ String
The Oracle Database ID, which identifies an Oracle Database located outside of Oracle Cloud.
83 84 85 |
# File 'lib/oci/database/models/external_container_database.rb', line 83 def db_id @db_id end |
#db_packs ⇒ String
The database packs licensed for the external Oracle Database.
111 112 113 |
# File 'lib/oci/database/models/external_container_database.rb', line 111 def db_packs @db_packs end |
#db_unique_name ⇒ String
The DB_UNIQUE_NAME of the external database.
78 79 80 |
# File 'lib/oci/database/models/external_container_database.rb', line 78 def db_unique_name @db_unique_name end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
53 54 55 |
# File 'lib/oci/database/models/external_container_database.rb', line 53 def end |
#display_name ⇒ String
[Required] The user-friendly name for the external database. The name does not have to be unique.
57 58 59 |
# File 'lib/oci/database/models/external_container_database.rb', line 57 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
47 48 49 |
# File 'lib/oci/database/models/external_container_database.rb', line 47 def end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Oracle Cloud Infrastructure external database resource.
62 63 64 |
# File 'lib/oci/database/models/external_container_database.rb', line 62 def id @id end |
#lifecycle_details ⇒ String
Additional information about the current lifecycle state.
66 67 68 |
# File 'lib/oci/database/models/external_container_database.rb', line 66 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
[Required] The current state of the Oracle Cloud Infrastructure external database resource.
70 71 72 |
# File 'lib/oci/database/models/external_container_database.rb', line 70 def lifecycle_state @lifecycle_state end |
#ncharacter_set ⇒ String
The national character of the external database.
107 108 109 |
# File 'lib/oci/database/models/external_container_database.rb', line 107 def ncharacter_set @ncharacter_set end |
#time_created ⇒ DateTime
[Required] The date and time the database was created.
74 75 76 |
# File 'lib/oci/database/models/external_container_database.rb', line 74 def time_created @time_created end |
#time_zone ⇒ String
The time zone of the external database. It is a time zone offset (a character type in the format ‘[+|-]TZH:TZM’) or a time zone region name, depending on how the time zone value was specified when the database was created / last altered.
99 100 101 |
# File 'lib/oci/database/models/external_container_database.rb', line 99 def time_zone @time_zone end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/oci/database/models/external_container_database.rb', line 121 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'display_name': :'displayName', 'id': :'id', 'lifecycle_details': :'lifecycleDetails', 'lifecycle_state': :'lifecycleState', 'time_created': :'timeCreated', 'db_unique_name': :'dbUniqueName', 'db_id': :'dbId', 'database_version': :'databaseVersion', 'database_edition': :'databaseEdition', 'time_zone': :'timeZone', 'character_set': :'characterSet', 'ncharacter_set': :'ncharacterSet', 'db_packs': :'dbPacks', 'database_configuration': :'databaseConfiguration', 'database_management_config': :'databaseManagementConfig' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/oci/database/models/external_container_database.rb', line 147 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'id': :'String', 'lifecycle_details': :'String', 'lifecycle_state': :'String', 'time_created': :'DateTime', 'db_unique_name': :'String', 'db_id': :'String', 'database_version': :'String', 'database_edition': :'String', 'time_zone': :'String', 'character_set': :'String', 'ncharacter_set': :'String', 'db_packs': :'String', 'database_configuration': :'String', 'database_management_config': :'OCI::Database::Models::DatabaseManagementConfig' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 |
# File 'lib/oci/database/models/external_container_database.rb', line 350 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && == other. && == other. && display_name == other.display_name && id == other.id && lifecycle_details == other.lifecycle_details && lifecycle_state == other.lifecycle_state && time_created == other.time_created && db_unique_name == other.db_unique_name && db_id == other.db_id && database_version == other.database_version && database_edition == other.database_edition && time_zone == other.time_zone && character_set == other.character_set && ncharacter_set == other.ncharacter_set && db_packs == other.db_packs && database_configuration == other.database_configuration && database_management_config == other.database_management_config end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 |
# File 'lib/oci/database/models/external_container_database.rb', line 397 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
377 378 379 |
# File 'lib/oci/database/models/external_container_database.rb', line 377 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
386 387 388 |
# File 'lib/oci/database/models/external_container_database.rb', line 386 def hash [compartment_id, , , display_name, id, lifecycle_details, lifecycle_state, time_created, db_unique_name, db_id, database_version, database_edition, time_zone, character_set, ncharacter_set, db_packs, database_configuration, database_management_config].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
430 431 432 433 434 435 436 437 438 439 |
# File 'lib/oci/database/models/external_container_database.rb', line 430 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
424 425 426 |
# File 'lib/oci/database/models/external_container_database.rb', line 424 def to_s to_hash.to_s end |