Class: OCI::Database::Models::ExternalDatabaseConnectorSummary
- Inherits:
-
Object
- Object
- OCI::Database::Models::ExternalDatabaseConnectorSummary
- Defined in:
- lib/oci/database/models/external_database_connector_summary.rb
Overview
An Oracle Cloud Infrastructure resource used to connect to an external Oracle Database. This resource stores the database connection string, user credentials, and related details that allow you to manage your external database using the Oracle Cloud Infrastructure Console and API interfaces.
This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
Constant Summary collapse
- CONNECTOR_TYPE_ENUM =
[ CONNECTOR_TYPE_MACS = 'MACS'.freeze, CONNECTOR_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
-
#connection_status ⇒ String
[Required] The status of connectivity to the external database.
-
#connector_type ⇒ String
[Required] The type of connector used by the external database resource.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
[Required] The user-friendly name for the create_external_database_connector_details.
-
#external_database_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the external database resource.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the create_external_database_connector_details.
-
#lifecycle_details ⇒ String
Additional information about the current lifecycle state.
-
#lifecycle_state ⇒ String
[Required] The current lifecycle state of the external database connector resource.
-
#time_connection_status_last_updated ⇒ DateTime
[Required] The date and time the
connectionStatusof this external connector was last updated. -
#time_created ⇒ DateTime
[Required] The date and time the external connector was created.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ExternalDatabaseConnectorSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ExternalDatabaseConnectorSummary
Initializes the object
152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/oci/database/models/external_database_connector_summary.rb', line 152 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.id = attributes[:'id'] if attributes[:'id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.connector_type = attributes[:'connectorType'] if attributes[:'connectorType'] self.connector_type = "MACS" if connector_type.nil? && !attributes.key?(:'connectorType') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :connectorType and :connector_type' if attributes.key?(:'connectorType') && attributes.key?(:'connector_type') self.connector_type = attributes[:'connector_type'] if attributes[:'connector_type'] self.connector_type = "MACS" if connector_type.nil? && !attributes.key?(:'connectorType') && !attributes.key?(:'connector_type') # rubocop:disable Style/StringLiterals self.external_database_id = attributes[:'externalDatabaseId'] if attributes[:'externalDatabaseId'] raise 'You cannot provide both :externalDatabaseId and :external_database_id' if attributes.key?(:'externalDatabaseId') && attributes.key?(:'external_database_id') self.external_database_id = attributes[:'external_database_id'] if attributes[:'external_database_id'] self.connection_status = attributes[:'connectionStatus'] if attributes[:'connectionStatus'] raise 'You cannot provide both :connectionStatus and :connection_status' if attributes.key?(:'connectionStatus') && attributes.key?(:'connection_status') self.connection_status = attributes[:'connection_status'] if attributes[:'connection_status'] self.time_connection_status_last_updated = attributes[:'timeConnectionStatusLastUpdated'] if attributes[:'timeConnectionStatusLastUpdated'] raise 'You cannot provide both :timeConnectionStatusLastUpdated and :time_connection_status_last_updated' if attributes.key?(:'timeConnectionStatusLastUpdated') && attributes.key?(:'time_connection_status_last_updated') self.time_connection_status_last_updated = attributes[:'time_connection_status_last_updated'] if attributes[:'time_connection_status_last_updated'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
22 23 24 |
# File 'lib/oci/database/models/external_database_connector_summary.rb', line 22 def compartment_id @compartment_id end |
#connection_status ⇒ String
[Required] The status of connectivity to the external database.
73 74 75 |
# File 'lib/oci/database/models/external_database_connector_summary.rb', line 73 def connection_status @connection_status end |
#connector_type ⇒ String
[Required] The type of connector used by the external database resource.
65 66 67 |
# File 'lib/oci/database/models/external_database_connector_summary.rb', line 65 def connector_type @connector_type end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
36 37 38 |
# File 'lib/oci/database/models/external_database_connector_summary.rb', line 36 def end |
#display_name ⇒ String
[Required] The user-friendly name for the create_external_database_connector_details. The name does not have to be unique.
43 44 45 |
# File 'lib/oci/database/models/external_database_connector_summary.rb', line 43 def display_name @display_name end |
#external_database_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the external database resource.
69 70 71 |
# File 'lib/oci/database/models/external_database_connector_summary.rb', line 69 def external_database_id @external_database_id end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
30 31 32 |
# File 'lib/oci/database/models/external_database_connector_summary.rb', line 30 def end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the create_external_database_connector_details.
49 50 51 |
# File 'lib/oci/database/models/external_database_connector_summary.rb', line 49 def id @id end |
#lifecycle_details ⇒ String
Additional information about the current lifecycle state.
57 58 59 |
# File 'lib/oci/database/models/external_database_connector_summary.rb', line 57 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
[Required] The current lifecycle state of the external database connector resource.
53 54 55 |
# File 'lib/oci/database/models/external_database_connector_summary.rb', line 53 def lifecycle_state @lifecycle_state end |
#time_connection_status_last_updated ⇒ DateTime
[Required] The date and time the connectionStatus of this external connector was last updated.
77 78 79 |
# File 'lib/oci/database/models/external_database_connector_summary.rb', line 77 def time_connection_status_last_updated @time_connection_status_last_updated end |
#time_created ⇒ DateTime
[Required] The date and time the external connector was created.
61 62 63 |
# File 'lib/oci/database/models/external_database_connector_summary.rb', line 61 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/oci/database/models/external_database_connector_summary.rb', line 80 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'display_name': :'displayName', 'id': :'id', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'time_created': :'timeCreated', 'connector_type': :'connectorType', 'external_database_id': :'externalDatabaseId', 'connection_status': :'connectionStatus', 'time_connection_status_last_updated': :'timeConnectionStatusLastUpdated' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
124 125 126 127 128 129 130 131 |
# File 'lib/oci/database/models/external_database_connector_summary.rb', line 124 def self.get_subtype(object_hash) type = object_hash[:'connectorType'] # rubocop:disable Style/SymbolLiteral return 'OCI::Database::Models::ExternalMacsConnectorSummary' if type == 'MACS' # TODO: Log a warning when the subtype is not found. 'OCI::Database::Models::ExternalDatabaseConnectorSummary' end |
.swagger_types ⇒ Object
Attribute type mapping.
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/oci/database/models/external_database_connector_summary.rb', line 100 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'id': :'String', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'time_created': :'DateTime', 'connector_type': :'String', 'external_database_id': :'String', 'connection_status': :'String', 'time_connection_status_last_updated': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 |
# File 'lib/oci/database/models/external_database_connector_summary.rb', line 249 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && == other. && == other. && display_name == other.display_name && id == other.id && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && time_created == other.time_created && connector_type == other.connector_type && external_database_id == other.external_database_id && connection_status == other.connection_status && time_connection_status_last_updated == other.time_connection_status_last_updated end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 |
# File 'lib/oci/database/models/external_database_connector_summary.rb', line 290 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
270 271 272 |
# File 'lib/oci/database/models/external_database_connector_summary.rb', line 270 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
279 280 281 |
# File 'lib/oci/database/models/external_database_connector_summary.rb', line 279 def hash [compartment_id, , , display_name, id, lifecycle_state, lifecycle_details, time_created, connector_type, external_database_id, connection_status, time_connection_status_last_updated].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
323 324 325 326 327 328 329 330 331 332 |
# File 'lib/oci/database/models/external_database_connector_summary.rb', line 323 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
317 318 319 |
# File 'lib/oci/database/models/external_database_connector_summary.rb', line 317 def to_s to_hash.to_s end |