Class: OCI::Database::Models::ExternalPluggableDatabase

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database/models/external_pluggable_database.rb

Overview

an external Oracle pluggable database.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze,
  LIFECYCLE_STATE_NOT_CONNECTED = 'NOT_CONNECTED'.freeze,
  LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze,
  LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
DATABASE_EDITION_ENUM =
[
  DATABASE_EDITION_STANDARD_EDITION = 'STANDARD_EDITION'.freeze,
  DATABASE_EDITION_ENTERPRISE_EDITION = 'ENTERPRISE_EDITION'.freeze,
  DATABASE_EDITION_ENTERPRISE_EDITION_HIGH_PERFORMANCE = 'ENTERPRISE_EDITION_HIGH_PERFORMANCE'.freeze,
  DATABASE_EDITION_ENTERPRISE_EDITION_EXTREME_PERFORMANCE = 'ENTERPRISE_EDITION_EXTREME_PERFORMANCE'.freeze,
  DATABASE_EDITION_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
DATABASE_CONFIGURATION_ENUM =
[
  DATABASE_CONFIGURATION_RAC = 'RAC'.freeze,
  DATABASE_CONFIGURATION_SINGLE_INSTANCE = 'SINGLE_INSTANCE'.freeze,
  DATABASE_CONFIGURATION_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ExternalPluggableDatabase

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
# File 'lib/oci/database/models/external_pluggable_database.rb', line 220

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.source_id = attributes[:'sourceId'] if attributes[:'sourceId']

  raise 'You cannot provide both :sourceId and :source_id' if attributes.key?(:'sourceId') && attributes.key?(:'source_id')

  self.source_id = attributes[:'source_id'] if attributes[:'source_id']

  self.external_container_database_id = attributes[:'externalContainerDatabaseId'] if attributes[:'externalContainerDatabaseId']

  raise 'You cannot provide both :externalContainerDatabaseId and :external_container_database_id' if attributes.key?(:'externalContainerDatabaseId') && attributes.key?(:'external_container_database_id')

  self.external_container_database_id = attributes[:'external_container_database_id'] if attributes[:'external_container_database_id']

  self.operations_insights_config = attributes[:'operationsInsightsConfig'] if attributes[:'operationsInsightsConfig']

  raise 'You cannot provide both :operationsInsightsConfig and :operations_insights_config' if attributes.key?(:'operationsInsightsConfig') && attributes.key?(:'operations_insights_config')

  self.operations_insights_config = attributes[:'operations_insights_config'] if attributes[:'operations_insights_config']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.id = attributes[:'id'] if attributes[:'id']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.db_unique_name = attributes[:'dbUniqueName'] if attributes[:'dbUniqueName']

  raise 'You cannot provide both :dbUniqueName and :db_unique_name' if attributes.key?(:'dbUniqueName') && attributes.key?(:'db_unique_name')

  self.db_unique_name = attributes[:'db_unique_name'] if attributes[:'db_unique_name']

  self.db_id = attributes[:'dbId'] if attributes[:'dbId']

  raise 'You cannot provide both :dbId and :db_id' if attributes.key?(:'dbId') && attributes.key?(:'db_id')

  self.db_id = attributes[:'db_id'] if attributes[:'db_id']

  self.database_version = attributes[:'databaseVersion'] if attributes[:'databaseVersion']

  raise 'You cannot provide both :databaseVersion and :database_version' if attributes.key?(:'databaseVersion') && attributes.key?(:'database_version')

  self.database_version = attributes[:'database_version'] if attributes[:'database_version']

  self.database_edition = attributes[:'databaseEdition'] if attributes[:'databaseEdition']

  raise 'You cannot provide both :databaseEdition and :database_edition' if attributes.key?(:'databaseEdition') && attributes.key?(:'database_edition')

  self.database_edition = attributes[:'database_edition'] if attributes[:'database_edition']

  self.time_zone = attributes[:'timeZone'] if attributes[:'timeZone']

  raise 'You cannot provide both :timeZone and :time_zone' if attributes.key?(:'timeZone') && attributes.key?(:'time_zone')

  self.time_zone = attributes[:'time_zone'] if attributes[:'time_zone']

  self.character_set = attributes[:'characterSet'] if attributes[:'characterSet']

  raise 'You cannot provide both :characterSet and :character_set' if attributes.key?(:'characterSet') && attributes.key?(:'character_set')

  self.character_set = attributes[:'character_set'] if attributes[:'character_set']

  self.ncharacter_set = attributes[:'ncharacterSet'] if attributes[:'ncharacterSet']

  raise 'You cannot provide both :ncharacterSet and :ncharacter_set' if attributes.key?(:'ncharacterSet') && attributes.key?(:'ncharacter_set')

  self.ncharacter_set = attributes[:'ncharacter_set'] if attributes[:'ncharacter_set']

  self.db_packs = attributes[:'dbPacks'] if attributes[:'dbPacks']

  raise 'You cannot provide both :dbPacks and :db_packs' if attributes.key?(:'dbPacks') && attributes.key?(:'db_packs')

  self.db_packs = attributes[:'db_packs'] if attributes[:'db_packs']

  self.database_configuration = attributes[:'databaseConfiguration'] if attributes[:'databaseConfiguration']

  raise 'You cannot provide both :databaseConfiguration and :database_configuration' if attributes.key?(:'databaseConfiguration') && attributes.key?(:'database_configuration')

  self.database_configuration = attributes[:'database_configuration'] if attributes[:'database_configuration']

  self.database_management_config = attributes[:'databaseManagementConfig'] if attributes[:'databaseManagementConfig']

  raise 'You cannot provide both :databaseManagementConfig and :database_management_config' if attributes.key?(:'databaseManagementConfig') && attributes.key?(:'database_management_config')

  self.database_management_config = attributes[:'database_management_config'] if attributes[:'database_management_config']
end

Instance Attribute Details

#character_setString

The character set of the external database.

Returns:

  • (String)


118
119
120
# File 'lib/oci/database/models/external_pluggable_database.rb', line 118

def character_set
  @character_set
end

#compartment_idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.

Returns:

  • (String)


54
55
56
# File 'lib/oci/database/models/external_pluggable_database.rb', line 54

def compartment_id
  @compartment_id
end

#database_configurationString

The Oracle Database configuration

Returns:

  • (String)


130
131
132
# File 'lib/oci/database/models/external_pluggable_database.rb', line 130

def database_configuration
  @database_configuration
end

#database_editionString

The Oracle Database edition.

Returns:

  • (String)


107
108
109
# File 'lib/oci/database/models/external_pluggable_database.rb', line 107

def database_edition
  @database_edition
end

#database_management_configOCI::Database::Models::DatabaseManagementConfig



133
134
135
# File 'lib/oci/database/models/external_pluggable_database.rb', line 133

def database_management_config
  @database_management_config
end

#database_versionString

The Oracle Database version.

Returns:

  • (String)


102
103
104
# File 'lib/oci/database/models/external_pluggable_database.rb', line 102

def database_version
  @database_version
end

#db_idString

The Oracle Database ID, which identifies an Oracle Database located outside of Oracle Cloud.

Returns:

  • (String)


98
99
100
# File 'lib/oci/database/models/external_pluggable_database.rb', line 98

def db_id
  @db_id
end

#db_packsString

The database packs licensed for the external Oracle Database.

Returns:

  • (String)


126
127
128
# File 'lib/oci/database/models/external_pluggable_database.rb', line 126

def db_packs
  @db_packs
end

#db_unique_nameString

The DB_UNIQUE_NAME of the external database.

Returns:

  • (String)


93
94
95
# File 'lib/oci/database/models/external_pluggable_database.rb', line 93

def db_unique_name
  @db_unique_name
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Returns:

  • (Hash<String, Hash<String, Object>>)


68
69
70
# File 'lib/oci/database/models/external_pluggable_database.rb', line 68

def defined_tags
  @defined_tags
end

#display_nameString

[Required] The user-friendly name for the external database. The name does not have to be unique.

Returns:

  • (String)


72
73
74
# File 'lib/oci/database/models/external_pluggable_database.rb', line 72

def display_name
  @display_name
end

#external_container_database_idString

[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the create_external_container_database_details that contains the specified create_external_pluggable_database_details resource.

Returns:

  • (String)


47
48
49
# File 'lib/oci/database/models/external_pluggable_database.rb', line 47

def external_container_database_id
  @external_container_database_id
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: ‘"Finance"`

Returns:

  • (Hash<String, String>)


62
63
64
# File 'lib/oci/database/models/external_pluggable_database.rb', line 62

def freeform_tags
  @freeform_tags
end

#idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Oracle Cloud Infrastructure external database resource.

Returns:

  • (String)


77
78
79
# File 'lib/oci/database/models/external_pluggable_database.rb', line 77

def id
  @id
end

#lifecycle_detailsString

Additional information about the current lifecycle state.

Returns:

  • (String)


81
82
83
# File 'lib/oci/database/models/external_pluggable_database.rb', line 81

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

[Required] The current state of the Oracle Cloud Infrastructure external database resource.

Returns:

  • (String)


85
86
87
# File 'lib/oci/database/models/external_pluggable_database.rb', line 85

def lifecycle_state
  @lifecycle_state
end

#ncharacter_setString

The national character of the external database.

Returns:

  • (String)


122
123
124
# File 'lib/oci/database/models/external_pluggable_database.rb', line 122

def ncharacter_set
  @ncharacter_set
end

#operations_insights_configOCI::Database::Models::OperationsInsightsConfig



50
51
52
# File 'lib/oci/database/models/external_pluggable_database.rb', line 50

def operations_insights_config
  @operations_insights_config
end

#source_idString

The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the the non-container database that was converted to a pluggable database to create this resource.

Returns:

  • (String)


40
41
42
# File 'lib/oci/database/models/external_pluggable_database.rb', line 40

def source_id
  @source_id
end

#time_createdDateTime

[Required] The date and time the database was created.

Returns:

  • (DateTime)


89
90
91
# File 'lib/oci/database/models/external_pluggable_database.rb', line 89

def time_created
  @time_created
end

#time_zoneString

The time zone of the external database. It is a time zone offset (a character type in the format ‘[+|-]TZH:TZM’) or a time zone region name, depending on how the time zone value was specified when the database was created / last altered.

Returns:

  • (String)


114
115
116
# File 'lib/oci/database/models/external_pluggable_database.rb', line 114

def time_zone
  @time_zone
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/oci/database/models/external_pluggable_database.rb', line 136

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'source_id': :'sourceId',
    'external_container_database_id': :'externalContainerDatabaseId',
    'operations_insights_config': :'operationsInsightsConfig',
    'compartment_id': :'compartmentId',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'display_name': :'displayName',
    'id': :'id',
    'lifecycle_details': :'lifecycleDetails',
    'lifecycle_state': :'lifecycleState',
    'time_created': :'timeCreated',
    'db_unique_name': :'dbUniqueName',
    'db_id': :'dbId',
    'database_version': :'databaseVersion',
    'database_edition': :'databaseEdition',
    'time_zone': :'timeZone',
    'character_set': :'characterSet',
    'ncharacter_set': :'ncharacterSet',
    'db_packs': :'dbPacks',
    'database_configuration': :'databaseConfiguration',
    'database_management_config': :'databaseManagementConfig'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/oci/database/models/external_pluggable_database.rb', line 165

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'source_id': :'String',
    'external_container_database_id': :'String',
    'operations_insights_config': :'OCI::Database::Models::OperationsInsightsConfig',
    'compartment_id': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'display_name': :'String',
    'id': :'String',
    'lifecycle_details': :'String',
    'lifecycle_state': :'String',
    'time_created': :'DateTime',
    'db_unique_name': :'String',
    'db_id': :'String',
    'database_version': :'String',
    'database_edition': :'String',
    'time_zone': :'String',
    'character_set': :'String',
    'ncharacter_set': :'String',
    'db_packs': :'String',
    'database_configuration': :'String',
    'database_management_config': :'OCI::Database::Models::DatabaseManagementConfig'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
# File 'lib/oci/database/models/external_pluggable_database.rb', line 395

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    source_id == other.source_id &&
    external_container_database_id == other.external_container_database_id &&
    operations_insights_config == other.operations_insights_config &&
    compartment_id == other.compartment_id &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    display_name == other.display_name &&
    id == other.id &&
    lifecycle_details == other.lifecycle_details &&
    lifecycle_state == other.lifecycle_state &&
    time_created == other.time_created &&
    db_unique_name == other.db_unique_name &&
    db_id == other.db_id &&
    database_version == other.database_version &&
    database_edition == other.database_edition &&
    time_zone == other.time_zone &&
    character_set == other.character_set &&
    ncharacter_set == other.ncharacter_set &&
    db_packs == other.db_packs &&
    database_configuration == other.database_configuration &&
    database_management_config == other.database_management_config
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
# File 'lib/oci/database/models/external_pluggable_database.rb', line 445

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


425
426
427
# File 'lib/oci/database/models/external_pluggable_database.rb', line 425

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



434
435
436
# File 'lib/oci/database/models/external_pluggable_database.rb', line 434

def hash
  [source_id, external_container_database_id, operations_insights_config, compartment_id, freeform_tags, defined_tags, display_name, id, lifecycle_details, lifecycle_state, time_created, db_unique_name, db_id, database_version, database_edition, time_zone, character_set, ncharacter_set, db_packs, database_configuration, database_management_config].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



478
479
480
481
482
483
484
485
486
487
# File 'lib/oci/database/models/external_pluggable_database.rb', line 478

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



472
473
474
# File 'lib/oci/database/models/external_pluggable_database.rb', line 472

def to_s
  to_hash.to_s
end