Class: OCI::Database::Models::LaunchDbSystemDetails
- Inherits:
-
LaunchDbSystemBase
- Object
- LaunchDbSystemBase
- OCI::Database::Models::LaunchDbSystemDetails
- Defined in:
- lib/oci/database/models/launch_db_system_details.rb
Overview
LaunchDbSystemDetails model.
Constant Summary collapse
- DATABASE_EDITION_ENUM =
rubocop:disable Metrics/LineLength
[ DATABASE_EDITION_STANDARD_EDITION = 'STANDARD_EDITION'.freeze, DATABASE_EDITION_ENTERPRISE_EDITION = 'ENTERPRISE_EDITION'.freeze, DATABASE_EDITION_ENTERPRISE_EDITION_HIGH_PERFORMANCE = 'ENTERPRISE_EDITION_HIGH_PERFORMANCE'.freeze, DATABASE_EDITION_ENTERPRISE_EDITION_EXTREME_PERFORMANCE = 'ENTERPRISE_EDITION_EXTREME_PERFORMANCE'.freeze ].freeze
- DISK_REDUNDANCY_ENUM =
[ DISK_REDUNDANCY_HIGH = 'HIGH'.freeze, DISK_REDUNDANCY_NORMAL = 'NORMAL'.freeze ].freeze
- LICENSE_MODEL_ENUM =
[ LICENSE_MODEL_LICENSE_INCLUDED = 'LICENSE_INCLUDED'.freeze, LICENSE_MODEL_BRING_YOUR_OWN_LICENSE = 'BRING_YOUR_OWN_LICENSE'.freeze ].freeze
Constants inherited from LaunchDbSystemBase
OCI::Database::Models::LaunchDbSystemBase::SOURCE_ENUM
Instance Attribute Summary collapse
-
#database_edition ⇒ String
[Required] The Oracle Database Edition that applies to all the databases on the DB system.
-
#db_home ⇒ OCI::Database::Models::CreateDbHomeDetails
This attribute is required.
-
#disk_redundancy ⇒ String
The type of redundancy configured for the DB system.
-
#license_model ⇒ String
The Oracle license model that applies to all the databases on the DB system.
Attributes inherited from LaunchDbSystemBase
#availability_domain, #backup_subnet_id, #cluster_name, #compartment_id, #cpu_core_count, #data_storage_percentage, #defined_tags, #display_name, #domain, #freeform_tags, #hostname, #initial_data_storage_size_in_gb, #node_count, #shape, #source, #sparse_diskgroup, #ssh_public_keys, #subnet_id
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LaunchDbSystemDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from LaunchDbSystemBase
Constructor Details
#initialize(attributes = {}) ⇒ LaunchDbSystemDetails
Initializes the object
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/oci/database/models/launch_db_system_details.rb', line 136 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['source'] = 'NONE' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.db_home = attributes[:'dbHome'] if attributes[:'dbHome'] raise 'You cannot provide both :dbHome and :db_home' if attributes.key?(:'dbHome') && attributes.key?(:'db_home') self.db_home = attributes[:'db_home'] if attributes[:'db_home'] self.database_edition = attributes[:'databaseEdition'] if attributes[:'databaseEdition'] raise 'You cannot provide both :databaseEdition and :database_edition' if attributes.key?(:'databaseEdition') && attributes.key?(:'database_edition') self.database_edition = attributes[:'database_edition'] if attributes[:'database_edition'] self.disk_redundancy = attributes[:'diskRedundancy'] if attributes[:'diskRedundancy'] raise 'You cannot provide both :diskRedundancy and :disk_redundancy' if attributes.key?(:'diskRedundancy') && attributes.key?(:'disk_redundancy') self.disk_redundancy = attributes[:'disk_redundancy'] if attributes[:'disk_redundancy'] self.license_model = attributes[:'licenseModel'] if attributes[:'licenseModel'] raise 'You cannot provide both :licenseModel and :license_model' if attributes.key?(:'licenseModel') && attributes.key?(:'license_model') self.license_model = attributes[:'license_model'] if attributes[:'license_model'] end |
Instance Attribute Details
#database_edition ⇒ String
[Required] The Oracle Database Edition that applies to all the databases on the DB system. Exadata DB systems and 2-node RAC DB systems require ENTERPRISE_EDITION_EXTREME_PERFORMANCE.
35 36 37 |
# File 'lib/oci/database/models/launch_db_system_details.rb', line 35 def database_edition @database_edition end |
#db_home ⇒ OCI::Database::Models::CreateDbHomeDetails
This attribute is required.
29 30 31 |
# File 'lib/oci/database/models/launch_db_system_details.rb', line 29 def db_home @db_home end |
#disk_redundancy ⇒ String
The type of redundancy configured for the DB system. Normal is 2-way redundancy, recommended for test and development systems. High is 3-way redundancy, recommended for production systems.
42 43 44 |
# File 'lib/oci/database/models/launch_db_system_details.rb', line 42 def disk_redundancy @disk_redundancy end |
#license_model ⇒ String
The Oracle license model that applies to all the databases on the DB system. The default is LICENSE_INCLUDED.
47 48 49 |
# File 'lib/oci/database/models/launch_db_system_details.rb', line 47 def license_model @license_model end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/oci/database/models/launch_db_system_details.rb', line 50 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'availability_domain': :'availabilityDomain', 'subnet_id': :'subnetId', 'backup_subnet_id': :'backupSubnetId', 'shape': :'shape', 'sparse_diskgroup': :'sparseDiskgroup', 'ssh_public_keys': :'sshPublicKeys', 'hostname': :'hostname', 'domain': :'domain', 'cpu_core_count': :'cpuCoreCount', 'cluster_name': :'clusterName', 'data_storage_percentage': :'dataStoragePercentage', 'initial_data_storage_size_in_gb': :'initialDataStorageSizeInGB', 'node_count': :'nodeCount', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'source': :'source', 'db_home': :'dbHome', 'database_edition': :'databaseEdition', 'disk_redundancy': :'diskRedundancy', 'license_model': :'licenseModel' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/oci/database/models/launch_db_system_details.rb', line 80 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'display_name': :'String', 'availability_domain': :'String', 'subnet_id': :'String', 'backup_subnet_id': :'String', 'shape': :'String', 'sparse_diskgroup': :'BOOLEAN', 'ssh_public_keys': :'Array<String>', 'hostname': :'String', 'domain': :'String', 'cpu_core_count': :'Integer', 'cluster_name': :'String', 'data_storage_percentage': :'Integer', 'initial_data_storage_size_in_gb': :'Integer', 'node_count': :'Integer', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'source': :'String', 'db_home': :'OCI::Database::Models::CreateDbHomeDetails', 'database_edition': :'String', 'disk_redundancy': :'String', 'license_model': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/oci/database/models/launch_db_system_details.rb', line 208 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && display_name == other.display_name && availability_domain == other.availability_domain && subnet_id == other.subnet_id && backup_subnet_id == other.backup_subnet_id && shape == other.shape && sparse_diskgroup == other.sparse_diskgroup && ssh_public_keys == other.ssh_public_keys && hostname == other.hostname && domain == other.domain && cpu_core_count == other.cpu_core_count && cluster_name == other.cluster_name && data_storage_percentage == other.data_storage_percentage && initial_data_storage_size_in_gb == other.initial_data_storage_size_in_gb && node_count == other.node_count && == other. && == other. && source == other.source && db_home == other.db_home && database_edition == other.database_edition && disk_redundancy == other.disk_redundancy && license_model == other.license_model end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/oci/database/models/launch_db_system_details.rb', line 259 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
239 240 241 |
# File 'lib/oci/database/models/launch_db_system_details.rb', line 239 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
248 249 250 |
# File 'lib/oci/database/models/launch_db_system_details.rb', line 248 def hash [compartment_id, display_name, availability_domain, subnet_id, backup_subnet_id, shape, sparse_diskgroup, ssh_public_keys, hostname, domain, cpu_core_count, cluster_name, data_storage_percentage, initial_data_storage_size_in_gb, node_count, , , source, db_home, database_edition, disk_redundancy, license_model].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
292 293 294 295 296 297 298 299 300 301 |
# File 'lib/oci/database/models/launch_db_system_details.rb', line 292 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
286 287 288 |
# File 'lib/oci/database/models/launch_db_system_details.rb', line 286 def to_s to_hash.to_s end |