Class: OCI::Database::Models::LaunchDbSystemFromDbSystemDetails
- Inherits:
-
LaunchDbSystemBase
- Object
- LaunchDbSystemBase
- OCI::Database::Models::LaunchDbSystemFromDbSystemDetails
- Defined in:
- lib/oci/database/models/launch_db_system_from_db_system_details.rb
Overview
Used for creating a new database system by cloning an existing DB system.
Constant Summary collapse
- LICENSE_MODEL_ENUM =
[ LICENSE_MODEL_LICENSE_INCLUDED = 'LICENSE_INCLUDED'.freeze, LICENSE_MODEL_BRING_YOUR_OWN_LICENSE = 'BRING_YOUR_OWN_LICENSE'.freeze ].freeze
Constants inherited from LaunchDbSystemBase
OCI::Database::Models::LaunchDbSystemBase::SOURCE_ENUM, OCI::Database::Models::LaunchDbSystemBase::STORAGE_VOLUME_PERFORMANCE_MODE_ENUM
Instance Attribute Summary collapse
-
#db_home ⇒ OCI::Database::Models::CreateDbHomeFromDbSystemDetails
This attribute is required.
-
#license_model ⇒ String
The Oracle license model that applies to all the databases on the DB system.
-
#source_db_system_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the DB system.
Attributes inherited from LaunchDbSystemBase
#availability_domain, #backup_network_nsg_ids, #backup_subnet_id, #cluster_name, #compartment_id, #cpu_core_count, #data_storage_percentage, #db_system_options, #defined_tags, #display_name, #domain, #fault_domains, #freeform_tags, #hostname, #initial_data_storage_size_in_gb, #kms_key_id, #kms_key_version_id, #node_count, #nsg_ids, #private_ip, #shape, #source, #sparse_diskgroup, #ssh_public_keys, #storage_volume_performance_mode, #subnet_id, #time_zone
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LaunchDbSystemFromDbSystemDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from LaunchDbSystemBase
Constructor Details
#initialize(attributes = {}) ⇒ LaunchDbSystemFromDbSystemDetails
Initializes the object
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/oci/database/models/launch_db_system_from_db_system_details.rb', line 141 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['source'] = 'DB_SYSTEM' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.source_db_system_id = attributes[:'sourceDbSystemId'] if attributes[:'sourceDbSystemId'] raise 'You cannot provide both :sourceDbSystemId and :source_db_system_id' if attributes.key?(:'sourceDbSystemId') && attributes.key?(:'source_db_system_id') self.source_db_system_id = attributes[:'source_db_system_id'] if attributes[:'source_db_system_id'] self.db_home = attributes[:'dbHome'] if attributes[:'dbHome'] raise 'You cannot provide both :dbHome and :db_home' if attributes.key?(:'dbHome') && attributes.key?(:'db_home') self.db_home = attributes[:'db_home'] if attributes[:'db_home'] self.license_model = attributes[:'licenseModel'] if attributes[:'licenseModel'] raise 'You cannot provide both :licenseModel and :license_model' if attributes.key?(:'licenseModel') && attributes.key?(:'license_model') self.license_model = attributes[:'license_model'] if attributes[:'license_model'] end |
Instance Attribute Details
#db_home ⇒ OCI::Database::Models::CreateDbHomeFromDbSystemDetails
This attribute is required.
23 24 25 |
# File 'lib/oci/database/models/launch_db_system_from_db_system_details.rb', line 23 def db_home @db_home end |
#license_model ⇒ String
The Oracle license model that applies to all the databases on the DB system. The default is LICENSE_INCLUDED.
28 29 30 |
# File 'lib/oci/database/models/launch_db_system_from_db_system_details.rb', line 28 def license_model @license_model end |
#source_db_system_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the DB system.
19 20 21 |
# File 'lib/oci/database/models/launch_db_system_from_db_system_details.rb', line 19 def source_db_system_id @source_db_system_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/oci/database/models/launch_db_system_from_db_system_details.rb', line 31 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'fault_domains': :'faultDomains', 'display_name': :'displayName', 'availability_domain': :'availabilityDomain', 'subnet_id': :'subnetId', 'backup_subnet_id': :'backupSubnetId', 'nsg_ids': :'nsgIds', 'backup_network_nsg_ids': :'backupNetworkNsgIds', 'shape': :'shape', 'time_zone': :'timeZone', 'db_system_options': :'dbSystemOptions', 'storage_volume_performance_mode': :'storageVolumePerformanceMode', 'sparse_diskgroup': :'sparseDiskgroup', 'ssh_public_keys': :'sshPublicKeys', 'hostname': :'hostname', 'domain': :'domain', 'cpu_core_count': :'cpuCoreCount', 'cluster_name': :'clusterName', 'data_storage_percentage': :'dataStoragePercentage', 'initial_data_storage_size_in_gb': :'initialDataStorageSizeInGB', 'kms_key_id': :'kmsKeyId', 'kms_key_version_id': :'kmsKeyVersionId', 'node_count': :'nodeCount', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'source': :'source', 'private_ip': :'privateIp', 'source_db_system_id': :'sourceDbSystemId', 'db_home': :'dbHome', 'license_model': :'licenseModel' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/oci/database/models/launch_db_system_from_db_system_details.rb', line 69 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'fault_domains': :'Array<String>', 'display_name': :'String', 'availability_domain': :'String', 'subnet_id': :'String', 'backup_subnet_id': :'String', 'nsg_ids': :'Array<String>', 'backup_network_nsg_ids': :'Array<String>', 'shape': :'String', 'time_zone': :'String', 'db_system_options': :'OCI::Database::Models::DbSystemOptions', 'storage_volume_performance_mode': :'String', 'sparse_diskgroup': :'BOOLEAN', 'ssh_public_keys': :'Array<String>', 'hostname': :'String', 'domain': :'String', 'cpu_core_count': :'Integer', 'cluster_name': :'String', 'data_storage_percentage': :'Integer', 'initial_data_storage_size_in_gb': :'Integer', 'kms_key_id': :'String', 'kms_key_version_id': :'String', 'node_count': :'Integer', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'source': :'String', 'private_ip': :'String', 'source_db_system_id': :'String', 'db_home': :'OCI::Database::Models::CreateDbHomeFromDbSystemDetails', 'license_model': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/oci/database/models/launch_db_system_from_db_system_details.rb', line 185 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && fault_domains == other.fault_domains && display_name == other.display_name && availability_domain == other.availability_domain && subnet_id == other.subnet_id && backup_subnet_id == other.backup_subnet_id && nsg_ids == other.nsg_ids && backup_network_nsg_ids == other.backup_network_nsg_ids && shape == other.shape && time_zone == other.time_zone && == other. && storage_volume_performance_mode == other.storage_volume_performance_mode && sparse_diskgroup == other.sparse_diskgroup && ssh_public_keys == other.ssh_public_keys && hostname == other.hostname && domain == other.domain && cpu_core_count == other.cpu_core_count && cluster_name == other.cluster_name && data_storage_percentage == other.data_storage_percentage && initial_data_storage_size_in_gb == other.initial_data_storage_size_in_gb && kms_key_id == other.kms_key_id && kms_key_version_id == other.kms_key_version_id && node_count == other.node_count && == other. && == other. && source == other.source && private_ip == other.private_ip && source_db_system_id == other.source_db_system_id && db_home == other.db_home && license_model == other.license_model end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/oci/database/models/launch_db_system_from_db_system_details.rb', line 244 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
224 225 226 |
# File 'lib/oci/database/models/launch_db_system_from_db_system_details.rb', line 224 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
233 234 235 |
# File 'lib/oci/database/models/launch_db_system_from_db_system_details.rb', line 233 def hash [compartment_id, fault_domains, display_name, availability_domain, subnet_id, backup_subnet_id, nsg_ids, backup_network_nsg_ids, shape, time_zone, , storage_volume_performance_mode, sparse_diskgroup, ssh_public_keys, hostname, domain, cpu_core_count, cluster_name, data_storage_percentage, initial_data_storage_size_in_gb, kms_key_id, kms_key_version_id, node_count, , , source, private_ip, source_db_system_id, db_home, license_model].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
277 278 279 280 281 282 283 284 285 286 |
# File 'lib/oci/database/models/launch_db_system_from_db_system_details.rb', line 277 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
271 272 273 |
# File 'lib/oci/database/models/launch_db_system_from_db_system_details.rb', line 271 def to_s to_hash.to_s end |