Class: OCI::Database::Models::LocalClonePluggableDatabaseDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database/models/local_clone_pluggable_database_details.rb

Overview

Parameters for cloning a pluggable database (PDB) within the same database (CDB).

Warning: Oracle recommends that you avoid using any confidential information when you supply string values using the API.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ LocalClonePluggableDatabaseDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/oci/database/models/local_clone_pluggable_database_details.rb', line 65

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.cloned_pdb_name = attributes[:'clonedPdbName'] if attributes[:'clonedPdbName']

  raise 'You cannot provide both :clonedPdbName and :cloned_pdb_name' if attributes.key?(:'clonedPdbName') && attributes.key?(:'cloned_pdb_name')

  self.cloned_pdb_name = attributes[:'cloned_pdb_name'] if attributes[:'cloned_pdb_name']

  self.pdb_admin_password = attributes[:'pdbAdminPassword'] if attributes[:'pdbAdminPassword']

  raise 'You cannot provide both :pdbAdminPassword and :pdb_admin_password' if attributes.key?(:'pdbAdminPassword') && attributes.key?(:'pdb_admin_password')

  self.pdb_admin_password = attributes[:'pdb_admin_password'] if attributes[:'pdb_admin_password']

  self.target_tde_wallet_password = attributes[:'targetTdeWalletPassword'] if attributes[:'targetTdeWalletPassword']

  raise 'You cannot provide both :targetTdeWalletPassword and :target_tde_wallet_password' if attributes.key?(:'targetTdeWalletPassword') && attributes.key?(:'target_tde_wallet_password')

  self.target_tde_wallet_password = attributes[:'target_tde_wallet_password'] if attributes[:'target_tde_wallet_password']

  self. = attributes[:'shouldPdbAdminAccountBeLocked'] unless attributes[:'shouldPdbAdminAccountBeLocked'].nil?
  self. = false if .nil? && !attributes.key?(:'shouldPdbAdminAccountBeLocked') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :shouldPdbAdminAccountBeLocked and :should_pdb_admin_account_be_locked' if attributes.key?(:'shouldPdbAdminAccountBeLocked') && attributes.key?(:'should_pdb_admin_account_be_locked')

  self. = attributes[:'should_pdb_admin_account_be_locked'] unless attributes[:'should_pdb_admin_account_be_locked'].nil?
  self. = false if .nil? && !attributes.key?(:'shouldPdbAdminAccountBeLocked') && !attributes.key?(:'should_pdb_admin_account_be_locked') # rubocop:disable Style/StringLiterals
end

Instance Attribute Details

#cloned_pdb_nameString

[Required] The name for the pluggable database (PDB). The name is unique in the context of a Database. The name must begin with an alphabetic character and can contain a maximum of thirty alphanumeric characters. Special characters are not permitted. The pluggable database name should not be same as the container database name.

Returns:

  • (String)


15
16
17
# File 'lib/oci/database/models/local_clone_pluggable_database_details.rb', line 15

def cloned_pdb_name
  @cloned_pdb_name
end

#pdb_admin_passwordString

A strong password for PDB Admin of the newly cloned PDB. The password must be at least nine characters and contain at least two uppercase, two lowercase, two numbers, and two special characters. The special characters must be _, \#, or -.

Returns:

  • (String)


19
20
21
# File 'lib/oci/database/models/local_clone_pluggable_database_details.rb', line 19

def pdb_admin_password
  @pdb_admin_password
end

#should_pdb_admin_account_be_lockedBOOLEAN

The locked mode of the pluggable database admin account. If false, the user needs to provide the PDB Admin Password to connect to it. If true, the pluggable database will be locked and user cannot login to it.

Returns:

  • (BOOLEAN)


29
30
31
# File 'lib/oci/database/models/local_clone_pluggable_database_details.rb', line 29

def 
  
end

#target_tde_wallet_passwordString

The existing TDE wallet password of the target CDB.

Returns:

  • (String)


23
24
25
# File 'lib/oci/database/models/local_clone_pluggable_database_details.rb', line 23

def target_tde_wallet_password
  @target_tde_wallet_password
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



32
33
34
35
36
37
38
39
40
41
# File 'lib/oci/database/models/local_clone_pluggable_database_details.rb', line 32

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'cloned_pdb_name': :'clonedPdbName',
    'pdb_admin_password': :'pdbAdminPassword',
    'target_tde_wallet_password': :'targetTdeWalletPassword',
    'should_pdb_admin_account_be_locked': :'shouldPdbAdminAccountBeLocked'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



44
45
46
47
48
49
50
51
52
53
# File 'lib/oci/database/models/local_clone_pluggable_database_details.rb', line 44

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'cloned_pdb_name': :'String',
    'pdb_admin_password': :'String',
    'target_tde_wallet_password': :'String',
    'should_pdb_admin_account_be_locked': :'BOOLEAN'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



105
106
107
108
109
110
111
112
113
# File 'lib/oci/database/models/local_clone_pluggable_database_details.rb', line 105

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    cloned_pdb_name == other.cloned_pdb_name &&
    pdb_admin_password == other.pdb_admin_password &&
    target_tde_wallet_password == other.target_tde_wallet_password &&
     == other.
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/oci/database/models/local_clone_pluggable_database_details.rb', line 138

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


118
119
120
# File 'lib/oci/database/models/local_clone_pluggable_database_details.rb', line 118

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



127
128
129
# File 'lib/oci/database/models/local_clone_pluggable_database_details.rb', line 127

def hash
  [cloned_pdb_name, pdb_admin_password, target_tde_wallet_password, ].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



171
172
173
174
175
176
177
178
179
180
# File 'lib/oci/database/models/local_clone_pluggable_database_details.rb', line 171

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



165
166
167
# File 'lib/oci/database/models/local_clone_pluggable_database_details.rb', line 165

def to_s
  to_hash.to_s
end