Class: OCI::Database::Models::MaintenanceRun

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database/models/maintenance_run.rb

Overview

Details of a maintenance run.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_SCHEDULED = 'SCHEDULED'.freeze,
  LIFECYCLE_STATE_IN_PROGRESS = 'IN_PROGRESS'.freeze,
  LIFECYCLE_STATE_SUCCEEDED = 'SUCCEEDED'.freeze,
  LIFECYCLE_STATE_SKIPPED = 'SKIPPED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_CANCELED = 'CANCELED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
TARGET_RESOURCE_TYPE_ENUM =
[
  TARGET_RESOURCE_TYPE_AUTONOMOUS_EXADATA_INFRASTRUCTURE = 'AUTONOMOUS_EXADATA_INFRASTRUCTURE'.freeze,
  TARGET_RESOURCE_TYPE_AUTONOMOUS_CONTAINER_DATABASE = 'AUTONOMOUS_CONTAINER_DATABASE'.freeze,
  TARGET_RESOURCE_TYPE_EXADATA_DB_SYSTEM = 'EXADATA_DB_SYSTEM'.freeze,
  TARGET_RESOURCE_TYPE_CLOUD_EXADATA_INFRASTRUCTURE = 'CLOUD_EXADATA_INFRASTRUCTURE'.freeze,
  TARGET_RESOURCE_TYPE_EXACC_INFRASTRUCTURE = 'EXACC_INFRASTRUCTURE'.freeze,
  TARGET_RESOURCE_TYPE_AUTONOMOUS_VM_CLUSTER = 'AUTONOMOUS_VM_CLUSTER'.freeze,
  TARGET_RESOURCE_TYPE_AUTONOMOUS_DATABASE = 'AUTONOMOUS_DATABASE'.freeze,
  TARGET_RESOURCE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
MAINTENANCE_TYPE_ENUM =
[
  MAINTENANCE_TYPE_PLANNED = 'PLANNED'.freeze,
  MAINTENANCE_TYPE_UNPLANNED = 'UNPLANNED'.freeze,
  MAINTENANCE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
MAINTENANCE_SUBTYPE_ENUM =
[
  MAINTENANCE_SUBTYPE_QUARTERLY = 'QUARTERLY'.freeze,
  MAINTENANCE_SUBTYPE_HARDWARE = 'HARDWARE'.freeze,
  MAINTENANCE_SUBTYPE_CRITICAL = 'CRITICAL'.freeze,
  MAINTENANCE_SUBTYPE_INFRASTRUCTURE = 'INFRASTRUCTURE'.freeze,
  MAINTENANCE_SUBTYPE_DATABASE = 'DATABASE'.freeze,
  MAINTENANCE_SUBTYPE_ONEOFF = 'ONEOFF'.freeze,
  MAINTENANCE_SUBTYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
PATCHING_MODE_ENUM =
[
  PATCHING_MODE_ROLLING = 'ROLLING'.freeze,
  PATCHING_MODE_NONROLLING = 'NONROLLING'.freeze,
  PATCHING_MODE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
PATCHING_STATUS_ENUM =
[
  PATCHING_STATUS_PATCHING = 'PATCHING'.freeze,
  PATCHING_STATUS_WAITING = 'WAITING'.freeze,
  PATCHING_STATUS_SCHEDULED = 'SCHEDULED'.freeze,
  PATCHING_STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ MaintenanceRun

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
# File 'lib/oci/database/models/maintenance_run.rb', line 288

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.time_scheduled = attributes[:'timeScheduled'] if attributes[:'timeScheduled']

  raise 'You cannot provide both :timeScheduled and :time_scheduled' if attributes.key?(:'timeScheduled') && attributes.key?(:'time_scheduled')

  self.time_scheduled = attributes[:'time_scheduled'] if attributes[:'time_scheduled']

  self.time_started = attributes[:'timeStarted'] if attributes[:'timeStarted']

  raise 'You cannot provide both :timeStarted and :time_started' if attributes.key?(:'timeStarted') && attributes.key?(:'time_started')

  self.time_started = attributes[:'time_started'] if attributes[:'time_started']

  self.time_ended = attributes[:'timeEnded'] if attributes[:'timeEnded']

  raise 'You cannot provide both :timeEnded and :time_ended' if attributes.key?(:'timeEnded') && attributes.key?(:'time_ended')

  self.time_ended = attributes[:'time_ended'] if attributes[:'time_ended']

  self.target_resource_type = attributes[:'targetResourceType'] if attributes[:'targetResourceType']

  raise 'You cannot provide both :targetResourceType and :target_resource_type' if attributes.key?(:'targetResourceType') && attributes.key?(:'target_resource_type')

  self.target_resource_type = attributes[:'target_resource_type'] if attributes[:'target_resource_type']

  self.target_resource_id = attributes[:'targetResourceId'] if attributes[:'targetResourceId']

  raise 'You cannot provide both :targetResourceId and :target_resource_id' if attributes.key?(:'targetResourceId') && attributes.key?(:'target_resource_id')

  self.target_resource_id = attributes[:'target_resource_id'] if attributes[:'target_resource_id']

  self.maintenance_type = attributes[:'maintenanceType'] if attributes[:'maintenanceType']

  raise 'You cannot provide both :maintenanceType and :maintenance_type' if attributes.key?(:'maintenanceType') && attributes.key?(:'maintenance_type')

  self.maintenance_type = attributes[:'maintenance_type'] if attributes[:'maintenance_type']

  self.patch_id = attributes[:'patchId'] if attributes[:'patchId']

  raise 'You cannot provide both :patchId and :patch_id' if attributes.key?(:'patchId') && attributes.key?(:'patch_id')

  self.patch_id = attributes[:'patch_id'] if attributes[:'patch_id']

  self.maintenance_subtype = attributes[:'maintenanceSubtype'] if attributes[:'maintenanceSubtype']

  raise 'You cannot provide both :maintenanceSubtype and :maintenance_subtype' if attributes.key?(:'maintenanceSubtype') && attributes.key?(:'maintenance_subtype')

  self.maintenance_subtype = attributes[:'maintenance_subtype'] if attributes[:'maintenance_subtype']

  self.peer_maintenance_run_id = attributes[:'peerMaintenanceRunId'] if attributes[:'peerMaintenanceRunId']

  raise 'You cannot provide both :peerMaintenanceRunId and :peer_maintenance_run_id' if attributes.key?(:'peerMaintenanceRunId') && attributes.key?(:'peer_maintenance_run_id')

  self.peer_maintenance_run_id = attributes[:'peer_maintenance_run_id'] if attributes[:'peer_maintenance_run_id']

  self.patching_mode = attributes[:'patchingMode'] if attributes[:'patchingMode']

  raise 'You cannot provide both :patchingMode and :patching_mode' if attributes.key?(:'patchingMode') && attributes.key?(:'patching_mode')

  self.patching_mode = attributes[:'patching_mode'] if attributes[:'patching_mode']

  self.patch_failure_count = attributes[:'patchFailureCount'] if attributes[:'patchFailureCount']

  raise 'You cannot provide both :patchFailureCount and :patch_failure_count' if attributes.key?(:'patchFailureCount') && attributes.key?(:'patch_failure_count')

  self.patch_failure_count = attributes[:'patch_failure_count'] if attributes[:'patch_failure_count']

  self.target_db_server_version = attributes[:'targetDbServerVersion'] if attributes[:'targetDbServerVersion']

  raise 'You cannot provide both :targetDbServerVersion and :target_db_server_version' if attributes.key?(:'targetDbServerVersion') && attributes.key?(:'target_db_server_version')

  self.target_db_server_version = attributes[:'target_db_server_version'] if attributes[:'target_db_server_version']

  self.target_storage_server_version = attributes[:'targetStorageServerVersion'] if attributes[:'targetStorageServerVersion']

  raise 'You cannot provide both :targetStorageServerVersion and :target_storage_server_version' if attributes.key?(:'targetStorageServerVersion') && attributes.key?(:'target_storage_server_version')

  self.target_storage_server_version = attributes[:'target_storage_server_version'] if attributes[:'target_storage_server_version']

  self.is_custom_action_timeout_enabled = attributes[:'isCustomActionTimeoutEnabled'] unless attributes[:'isCustomActionTimeoutEnabled'].nil?

  raise 'You cannot provide both :isCustomActionTimeoutEnabled and :is_custom_action_timeout_enabled' if attributes.key?(:'isCustomActionTimeoutEnabled') && attributes.key?(:'is_custom_action_timeout_enabled')

  self.is_custom_action_timeout_enabled = attributes[:'is_custom_action_timeout_enabled'] unless attributes[:'is_custom_action_timeout_enabled'].nil?

  self.custom_action_timeout_in_mins = attributes[:'customActionTimeoutInMins'] if attributes[:'customActionTimeoutInMins']

  raise 'You cannot provide both :customActionTimeoutInMins and :custom_action_timeout_in_mins' if attributes.key?(:'customActionTimeoutInMins') && attributes.key?(:'custom_action_timeout_in_mins')

  self.custom_action_timeout_in_mins = attributes[:'custom_action_timeout_in_mins'] if attributes[:'custom_action_timeout_in_mins']

  self.current_custom_action_timeout_in_mins = attributes[:'currentCustomActionTimeoutInMins'] if attributes[:'currentCustomActionTimeoutInMins']

  raise 'You cannot provide both :currentCustomActionTimeoutInMins and :current_custom_action_timeout_in_mins' if attributes.key?(:'currentCustomActionTimeoutInMins') && attributes.key?(:'current_custom_action_timeout_in_mins')

  self.current_custom_action_timeout_in_mins = attributes[:'current_custom_action_timeout_in_mins'] if attributes[:'current_custom_action_timeout_in_mins']

  self.patching_status = attributes[:'patchingStatus'] if attributes[:'patchingStatus']

  raise 'You cannot provide both :patchingStatus and :patching_status' if attributes.key?(:'patchingStatus') && attributes.key?(:'patching_status')

  self.patching_status = attributes[:'patching_status'] if attributes[:'patching_status']

  self.patching_start_time = attributes[:'patchingStartTime'] if attributes[:'patchingStartTime']

  raise 'You cannot provide both :patchingStartTime and :patching_start_time' if attributes.key?(:'patchingStartTime') && attributes.key?(:'patching_start_time')

  self.patching_start_time = attributes[:'patching_start_time'] if attributes[:'patching_start_time']

  self.patching_end_time = attributes[:'patchingEndTime'] if attributes[:'patchingEndTime']

  raise 'You cannot provide both :patchingEndTime and :patching_end_time' if attributes.key?(:'patchingEndTime') && attributes.key?(:'patching_end_time')

  self.patching_end_time = attributes[:'patching_end_time'] if attributes[:'patching_end_time']

  self.estimated_patching_time = attributes[:'estimatedPatchingTime'] if attributes[:'estimatedPatchingTime']

  raise 'You cannot provide both :estimatedPatchingTime and :estimated_patching_time' if attributes.key?(:'estimatedPatchingTime') && attributes.key?(:'estimated_patching_time')

  self.estimated_patching_time = attributes[:'estimated_patching_time'] if attributes[:'estimated_patching_time']

  self.current_patching_component = attributes[:'currentPatchingComponent'] if attributes[:'currentPatchingComponent']

  raise 'You cannot provide both :currentPatchingComponent and :current_patching_component' if attributes.key?(:'currentPatchingComponent') && attributes.key?(:'current_patching_component')

  self.current_patching_component = attributes[:'current_patching_component'] if attributes[:'current_patching_component']

  self.estimated_component_patching_start_time = attributes[:'estimatedComponentPatchingStartTime'] if attributes[:'estimatedComponentPatchingStartTime']

  raise 'You cannot provide both :estimatedComponentPatchingStartTime and :estimated_component_patching_start_time' if attributes.key?(:'estimatedComponentPatchingStartTime') && attributes.key?(:'estimated_component_patching_start_time')

  self.estimated_component_patching_start_time = attributes[:'estimated_component_patching_start_time'] if attributes[:'estimated_component_patching_start_time']
end

Instance Attribute Details

#compartment_idString

**[Required]** The OCID of the compartment.

Returns:

  • (String)


71
72
73
# File 'lib/oci/database/models/maintenance_run.rb', line 71

def compartment_id
  @compartment_id
end

#current_custom_action_timeout_in_minsInteger

Extend current custom action timeout between the current database servers during waiting state, from 0 (zero) to 30 minutes.

Returns:

  • (Integer)


157
158
159
# File 'lib/oci/database/models/maintenance_run.rb', line 157

def current_custom_action_timeout_in_mins
  @current_custom_action_timeout_in_mins
end

#current_patching_componentString

The name of the current infrastruture component that is getting patched.

Returns:

  • (String)


176
177
178
# File 'lib/oci/database/models/maintenance_run.rb', line 176

def current_patching_component
  @current_patching_component
end

#custom_action_timeout_in_minsInteger

Determines the amount of time the system will wait before the start of each database server patching operation. Specify a number of minutes, from 15 to 120.

Returns:

  • (Integer)


153
154
155
# File 'lib/oci/database/models/maintenance_run.rb', line 153

def custom_action_timeout_in_mins
  @custom_action_timeout_in_mins
end

#descriptionString

Description of the maintenance run.

Returns:

  • (String)


79
80
81
# File 'lib/oci/database/models/maintenance_run.rb', line 79

def description
  @description
end

#display_nameString

**[Required]** The user-friendly name for the maintenance run.

Returns:

  • (String)


75
76
77
# File 'lib/oci/database/models/maintenance_run.rb', line 75

def display_name
  @display_name
end

#estimated_component_patching_start_timeDateTime

The estimated start time of the next infrastruture component patching operation.

Returns:

  • (DateTime)


180
181
182
# File 'lib/oci/database/models/maintenance_run.rb', line 180

def estimated_component_patching_start_time
  @estimated_component_patching_start_time
end

#estimated_patching_timeOCI::Database::Models::EstimatedPatchingTime



172
173
174
# File 'lib/oci/database/models/maintenance_run.rb', line 172

def estimated_patching_time
  @estimated_patching_time
end

#idString

**[Required]** The OCID of the maintenance run.

Returns:

  • (String)


67
68
69
# File 'lib/oci/database/models/maintenance_run.rb', line 67

def id
  @id
end

#is_custom_action_timeout_enabledBOOLEAN

If true, enables the configuration of a custom action timeout (waiting period) between database servers patching operations.

Returns:

  • (BOOLEAN)


147
148
149
# File 'lib/oci/database/models/maintenance_run.rb', line 147

def is_custom_action_timeout_enabled
  @is_custom_action_timeout_enabled
end

#lifecycle_detailsString

Additional information about the current lifecycle state.

Returns:

  • (String)


88
89
90
# File 'lib/oci/database/models/maintenance_run.rb', line 88

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

**[Required]** The current state of the maintenance run. For Autonomous Database on shared Exadata infrastructure, valid states are IN_PROGRESS, SUCCEEDED and FAILED.

Returns:

  • (String)


84
85
86
# File 'lib/oci/database/models/maintenance_run.rb', line 84

def lifecycle_state
  @lifecycle_state
end

#maintenance_subtypeString

Maintenance sub-type.

Returns:

  • (String)


120
121
122
# File 'lib/oci/database/models/maintenance_run.rb', line 120

def maintenance_subtype
  @maintenance_subtype
end

#maintenance_typeString

Maintenance type.

Returns:

  • (String)


112
113
114
# File 'lib/oci/database/models/maintenance_run.rb', line 112

def maintenance_type
  @maintenance_type
end

#patch_failure_countInteger

Contain the patch failure count.

Returns:

  • (Integer)


135
136
137
# File 'lib/oci/database/models/maintenance_run.rb', line 135

def patch_failure_count
  @patch_failure_count
end

#patch_idString

The unique identifier of the patch. The identifier string includes the patch type, the Oracle Database version, and the patch creation date (using the format YYMMDD). For example, the identifier `ru_patch_19.9.0.0_201030` is used for an RU patch for Oracle Database 19.9.0.0 that was released October 30, 2020.

Returns:

  • (String)


116
117
118
# File 'lib/oci/database/models/maintenance_run.rb', line 116

def patch_id
  @patch_id
end

#patching_end_timeDateTime

The time when the patching operation ended.

Returns:

  • (DateTime)


169
170
171
# File 'lib/oci/database/models/maintenance_run.rb', line 169

def patching_end_time
  @patching_end_time
end

#patching_modeString

Cloud Exadata infrastructure node patching method, either "ROLLING" or "NONROLLING". Default value is ROLLING.

IMPORTANT: Non-rolling infrastructure patching involves system down time. See [Oracle-Managed Infrastructure Maintenance Updates](docs.cloud.oracle.com/iaas/Content/Database/Concepts/examaintenance.htm#Oracle) for more information.

Returns:

  • (String)


131
132
133
# File 'lib/oci/database/models/maintenance_run.rb', line 131

def patching_mode
  @patching_mode
end

#patching_start_timeDateTime

The time when the patching operation started.

Returns:

  • (DateTime)


165
166
167
# File 'lib/oci/database/models/maintenance_run.rb', line 165

def patching_start_time
  @patching_start_time
end

#patching_statusString

The status of the patching operation.

Returns:

  • (String)


161
162
163
# File 'lib/oci/database/models/maintenance_run.rb', line 161

def patching_status
  @patching_status
end

#peer_maintenance_run_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the maintenance run for the Autonomous Data Guard association's peer container database.

Returns:

  • (String)


124
125
126
# File 'lib/oci/database/models/maintenance_run.rb', line 124

def peer_maintenance_run_id
  @peer_maintenance_run_id
end

#target_db_server_versionString

The target software version for the database server patching operation.

Returns:

  • (String)


139
140
141
# File 'lib/oci/database/models/maintenance_run.rb', line 139

def target_db_server_version
  @target_db_server_version
end

#target_resource_idString

The ID of the target resource on which the maintenance run occurs.

Returns:

  • (String)


108
109
110
# File 'lib/oci/database/models/maintenance_run.rb', line 108

def target_resource_id
  @target_resource_id
end

#target_resource_typeString

The type of the target resource on which the maintenance run occurs.

Returns:

  • (String)


104
105
106
# File 'lib/oci/database/models/maintenance_run.rb', line 104

def target_resource_type
  @target_resource_type
end

#target_storage_server_versionString

The target Cell version that is to be patched to.

Returns:

  • (String)


143
144
145
# File 'lib/oci/database/models/maintenance_run.rb', line 143

def target_storage_server_version
  @target_storage_server_version
end

#time_endedDateTime

The date and time the maintenance run was completed.

Returns:

  • (DateTime)


100
101
102
# File 'lib/oci/database/models/maintenance_run.rb', line 100

def time_ended
  @time_ended
end

#time_scheduledDateTime

**[Required]** The date and time the maintenance run is scheduled to occur.

Returns:

  • (DateTime)


92
93
94
# File 'lib/oci/database/models/maintenance_run.rb', line 92

def time_scheduled
  @time_scheduled
end

#time_startedDateTime

The date and time the maintenance run starts.

Returns:

  • (DateTime)


96
97
98
# File 'lib/oci/database/models/maintenance_run.rb', line 96

def time_started
  @time_started
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/oci/database/models/maintenance_run.rb', line 183

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'compartment_id': :'compartmentId',
    'display_name': :'displayName',
    'description': :'description',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'time_scheduled': :'timeScheduled',
    'time_started': :'timeStarted',
    'time_ended': :'timeEnded',
    'target_resource_type': :'targetResourceType',
    'target_resource_id': :'targetResourceId',
    'maintenance_type': :'maintenanceType',
    'patch_id': :'patchId',
    'maintenance_subtype': :'maintenanceSubtype',
    'peer_maintenance_run_id': :'peerMaintenanceRunId',
    'patching_mode': :'patchingMode',
    'patch_failure_count': :'patchFailureCount',
    'target_db_server_version': :'targetDbServerVersion',
    'target_storage_server_version': :'targetStorageServerVersion',
    'is_custom_action_timeout_enabled': :'isCustomActionTimeoutEnabled',
    'custom_action_timeout_in_mins': :'customActionTimeoutInMins',
    'current_custom_action_timeout_in_mins': :'currentCustomActionTimeoutInMins',
    'patching_status': :'patchingStatus',
    'patching_start_time': :'patchingStartTime',
    'patching_end_time': :'patchingEndTime',
    'estimated_patching_time': :'estimatedPatchingTime',
    'current_patching_component': :'currentPatchingComponent',
    'estimated_component_patching_start_time': :'estimatedComponentPatchingStartTime'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
# File 'lib/oci/database/models/maintenance_run.rb', line 219

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'compartment_id': :'String',
    'display_name': :'String',
    'description': :'String',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'time_scheduled': :'DateTime',
    'time_started': :'DateTime',
    'time_ended': :'DateTime',
    'target_resource_type': :'String',
    'target_resource_id': :'String',
    'maintenance_type': :'String',
    'patch_id': :'String',
    'maintenance_subtype': :'String',
    'peer_maintenance_run_id': :'String',
    'patching_mode': :'String',
    'patch_failure_count': :'Integer',
    'target_db_server_version': :'String',
    'target_storage_server_version': :'String',
    'is_custom_action_timeout_enabled': :'BOOLEAN',
    'custom_action_timeout_in_mins': :'Integer',
    'current_custom_action_timeout_in_mins': :'Integer',
    'patching_status': :'String',
    'patching_start_time': :'DateTime',
    'patching_end_time': :'DateTime',
    'estimated_patching_time': :'OCI::Database::Models::EstimatedPatchingTime',
    'current_patching_component': :'String',
    'estimated_component_patching_start_time': :'DateTime'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
# File 'lib/oci/database/models/maintenance_run.rb', line 537

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    display_name == other.display_name &&
    description == other.description &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    time_scheduled == other.time_scheduled &&
    time_started == other.time_started &&
    time_ended == other.time_ended &&
    target_resource_type == other.target_resource_type &&
    target_resource_id == other.target_resource_id &&
    maintenance_type == other.maintenance_type &&
    patch_id == other.patch_id &&
    maintenance_subtype == other.maintenance_subtype &&
    peer_maintenance_run_id == other.peer_maintenance_run_id &&
    patching_mode == other.patching_mode &&
    patch_failure_count == other.patch_failure_count &&
    target_db_server_version == other.target_db_server_version &&
    target_storage_server_version == other.target_storage_server_version &&
    is_custom_action_timeout_enabled == other.is_custom_action_timeout_enabled &&
    custom_action_timeout_in_mins == other.custom_action_timeout_in_mins &&
    current_custom_action_timeout_in_mins == other.current_custom_action_timeout_in_mins &&
    patching_status == other.patching_status &&
    patching_start_time == other.patching_start_time &&
    patching_end_time == other.patching_end_time &&
    estimated_patching_time == other.estimated_patching_time &&
    current_patching_component == other.current_patching_component &&
    estimated_component_patching_start_time == other.estimated_component_patching_start_time
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
# File 'lib/oci/database/models/maintenance_run.rb', line 594

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


574
575
576
# File 'lib/oci/database/models/maintenance_run.rb', line 574

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



583
584
585
# File 'lib/oci/database/models/maintenance_run.rb', line 583

def hash
  [id, compartment_id, display_name, description, lifecycle_state, lifecycle_details, time_scheduled, time_started, time_ended, target_resource_type, target_resource_id, maintenance_type, patch_id, maintenance_subtype, peer_maintenance_run_id, patching_mode, patch_failure_count, target_db_server_version, target_storage_server_version, is_custom_action_timeout_enabled, custom_action_timeout_in_mins, current_custom_action_timeout_in_mins, patching_status, patching_start_time, patching_end_time, estimated_patching_time, current_patching_component, estimated_component_patching_start_time].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



627
628
629
630
631
632
633
634
635
636
# File 'lib/oci/database/models/maintenance_run.rb', line 627

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



621
622
623
# File 'lib/oci/database/models/maintenance_run.rb', line 621

def to_s
  to_hash.to_s
end