Class: OCI::Database::Models::ModifyDatabaseManagementDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database/models/modify_database_management_details.rb

Overview

Data to update one or more attributes of the Database Management configuration for the database.

Constant Summary collapse

MANAGEMENT_TYPE_ENUM =
[
  MANAGEMENT_TYPE_BASIC = 'BASIC'.freeze,
  MANAGEMENT_TYPE_ADVANCED = 'ADVANCED'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ModifyDatabaseManagementDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/oci/database/models/modify_database_management_details.rb', line 66

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.credential_details = attributes[:'credentialDetails'] if attributes[:'credentialDetails']

  raise 'You cannot provide both :credentialDetails and :credential_details' if attributes.key?(:'credentialDetails') && attributes.key?(:'credential_details')

  self.credential_details = attributes[:'credential_details'] if attributes[:'credential_details']

  self.private_end_point_id = attributes[:'privateEndPointId'] if attributes[:'privateEndPointId']

  raise 'You cannot provide both :privateEndPointId and :private_end_point_id' if attributes.key?(:'privateEndPointId') && attributes.key?(:'private_end_point_id')

  self.private_end_point_id = attributes[:'private_end_point_id'] if attributes[:'private_end_point_id']

  self.management_type = attributes[:'managementType'] if attributes[:'managementType']
  self.management_type = "BASIC" if management_type.nil? && !attributes.key?(:'managementType') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :managementType and :management_type' if attributes.key?(:'managementType') && attributes.key?(:'management_type')

  self.management_type = attributes[:'management_type'] if attributes[:'management_type']
  self.management_type = "BASIC" if management_type.nil? && !attributes.key?(:'managementType') && !attributes.key?(:'management_type') # rubocop:disable Style/StringLiterals

  self.service_name = attributes[:'serviceName'] if attributes[:'serviceName']

  raise 'You cannot provide both :serviceName and :service_name' if attributes.key?(:'serviceName') && attributes.key?(:'service_name')

  self.service_name = attributes[:'service_name'] if attributes[:'service_name']
end

Instance Attribute Details

#credential_detailsOCI::Database::Models::DatabaseCredentialDetails



17
18
19
# File 'lib/oci/database/models/modify_database_management_details.rb', line 17

def credential_details
  @credential_details
end

#management_typeString

The Database Management type.

Returns:

  • (String)


26
27
28
# File 'lib/oci/database/models/modify_database_management_details.rb', line 26

def management_type
  @management_type
end

#private_end_point_idString

Returns:

  • (String)


22
23
24
# File 'lib/oci/database/models/modify_database_management_details.rb', line 22

def private_end_point_id
  @private_end_point_id
end

#service_nameString

The name of the Oracle Database service that will be used to connect to the database.

Returns:

  • (String)


30
31
32
# File 'lib/oci/database/models/modify_database_management_details.rb', line 30

def service_name
  @service_name
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



33
34
35
36
37
38
39
40
41
42
# File 'lib/oci/database/models/modify_database_management_details.rb', line 33

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'credential_details': :'credentialDetails',
    'private_end_point_id': :'privateEndPointId',
    'management_type': :'managementType',
    'service_name': :'serviceName'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



45
46
47
48
49
50
51
52
53
54
# File 'lib/oci/database/models/modify_database_management_details.rb', line 45

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'credential_details': :'OCI::Database::Models::DatabaseCredentialDetails',
    'private_end_point_id': :'String',
    'management_type': :'String',
    'service_name': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



114
115
116
117
118
119
120
121
122
# File 'lib/oci/database/models/modify_database_management_details.rb', line 114

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    credential_details == other.credential_details &&
    private_end_point_id == other.private_end_point_id &&
    management_type == other.management_type &&
    service_name == other.service_name
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/oci/database/models/modify_database_management_details.rb', line 147

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


127
128
129
# File 'lib/oci/database/models/modify_database_management_details.rb', line 127

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



136
137
138
# File 'lib/oci/database/models/modify_database_management_details.rb', line 136

def hash
  [credential_details, private_end_point_id, management_type, service_name].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



180
181
182
183
184
185
186
187
188
189
# File 'lib/oci/database/models/modify_database_management_details.rb', line 180

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



174
175
176
# File 'lib/oci/database/models/modify_database_management_details.rb', line 174

def to_s
  to_hash.to_s
end