Class: OCI::Database::Models::PluggableDatabase

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database/models/pluggable_database.rb

Overview

A pluggable database (PDB) is portable collection of schemas, schema objects, and non-schema objects that appears to an Oracle client as a non-container database. To use a PDB, it needs to be plugged into a CDB. To use any of the API operations, you must be authorized in an IAM policy. If you are not authorized, talk to a tenancy administrator. If you are an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm).

Warning: Oracle recommends that you avoid using any confidential information when you supply string values using the API.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze,
  LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze,
  LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze,
  LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
OPEN_MODE_ENUM =
[
  OPEN_MODE_READ_ONLY = 'READ_ONLY'.freeze,
  OPEN_MODE_READ_WRITE = 'READ_WRITE'.freeze,
  OPEN_MODE_MOUNTED = 'MOUNTED'.freeze,
  OPEN_MODE_MIGRATE = 'MIGRATE'.freeze,
  OPEN_MODE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PluggableDatabase

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/oci/database/models/pluggable_database.rb', line 147

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  self.id = attributes[:'id'] if attributes[:'id']

  self.container_database_id = attributes[:'containerDatabaseId'] if attributes[:'containerDatabaseId']

  raise 'You cannot provide both :containerDatabaseId and :container_database_id' if attributes.key?(:'containerDatabaseId') && attributes.key?(:'container_database_id')

  self.container_database_id = attributes[:'container_database_id'] if attributes[:'container_database_id']

  self.pdb_name = attributes[:'pdbName'] if attributes[:'pdbName']

  raise 'You cannot provide both :pdbName and :pdb_name' if attributes.key?(:'pdbName') && attributes.key?(:'pdb_name')

  self.pdb_name = attributes[:'pdb_name'] if attributes[:'pdb_name']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.connection_strings = attributes[:'connectionStrings'] if attributes[:'connectionStrings']

  raise 'You cannot provide both :connectionStrings and :connection_strings' if attributes.key?(:'connectionStrings') && attributes.key?(:'connection_strings')

  self.connection_strings = attributes[:'connection_strings'] if attributes[:'connection_strings']

  self.open_mode = attributes[:'openMode'] if attributes[:'openMode']

  raise 'You cannot provide both :openMode and :open_mode' if attributes.key?(:'openMode') && attributes.key?(:'open_mode')

  self.open_mode = attributes[:'open_mode'] if attributes[:'open_mode']

  self.is_restricted = attributes[:'isRestricted'] unless attributes[:'isRestricted'].nil?

  raise 'You cannot provide both :isRestricted and :is_restricted' if attributes.key?(:'isRestricted') && attributes.key?(:'is_restricted')

  self.is_restricted = attributes[:'is_restricted'] unless attributes[:'is_restricted'].nil?

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#compartment_idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.

Returns:

  • (String)


73
74
75
# File 'lib/oci/database/models/pluggable_database.rb', line 73

def compartment_id
  @compartment_id
end

#connection_stringsOCI::Database::Models::PluggableDatabaseConnectionStrings



58
59
60
# File 'lib/oci/database/models/pluggable_database.rb', line 58

def connection_strings
  @connection_strings
end

#container_database_idString

Returns:

  • (String)


39
40
41
# File 'lib/oci/database/models/pluggable_database.rb', line 39

def container_database_id
  @container_database_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Returns:

  • (Hash<String, Hash<String, Object>>)


87
88
89
# File 'lib/oci/database/models/pluggable_database.rb', line 87

def defined_tags
  @defined_tags
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: ‘"Finance"`

Returns:

  • (Hash<String, String>)


81
82
83
# File 'lib/oci/database/models/pluggable_database.rb', line 81

def freeform_tags
  @freeform_tags
end

#idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the pluggable database.

Returns:

  • (String)


35
36
37
# File 'lib/oci/database/models/pluggable_database.rb', line 35

def id
  @id
end

#is_restrictedBOOLEAN

The restricted mode of the pluggable database. If a pluggable database is opened in restricted mode, the user needs both create a session and have restricted session privileges to connect to it.

Returns:

  • (BOOLEAN)


69
70
71
# File 'lib/oci/database/models/pluggable_database.rb', line 69

def is_restricted
  @is_restricted
end

#lifecycle_detailsString

Detailed message for the lifecycle state.

Returns:

  • (String)


51
52
53
# File 'lib/oci/database/models/pluggable_database.rb', line 51

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

[Required] The current state of the pluggable database.

Returns:

  • (String)


47
48
49
# File 'lib/oci/database/models/pluggable_database.rb', line 47

def lifecycle_state
  @lifecycle_state
end

#open_modeString

[Required] The mode that pluggable database is in. Open mode can only be changed to READ_ONLY or MIGRATE directly from the backend (within the Oracle Database software).

Returns:

  • (String)


63
64
65
# File 'lib/oci/database/models/pluggable_database.rb', line 63

def open_mode
  @open_mode
end

#pdb_nameString

[Required] The name for the pluggable database (PDB). The name is unique in the context of a Database. The name must begin with an alphabetic character and can contain a maximum of thirty alphanumeric characters. Special characters are not permitted. The pluggable database name should not be same as the container database name.

Returns:

  • (String)


43
44
45
# File 'lib/oci/database/models/pluggable_database.rb', line 43

def pdb_name
  @pdb_name
end

#time_createdDateTime

[Required] The date and time the pluggable database was created.

Returns:

  • (DateTime)


55
56
57
# File 'lib/oci/database/models/pluggable_database.rb', line 55

def time_created
  @time_created
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/oci/database/models/pluggable_database.rb', line 90

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'container_database_id': :'containerDatabaseId',
    'pdb_name': :'pdbName',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'time_created': :'timeCreated',
    'connection_strings': :'connectionStrings',
    'open_mode': :'openMode',
    'is_restricted': :'isRestricted',
    'compartment_id': :'compartmentId',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/oci/database/models/pluggable_database.rb', line 110

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'container_database_id': :'String',
    'pdb_name': :'String',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'time_created': :'DateTime',
    'connection_strings': :'OCI::Database::Models::PluggableDatabaseConnectionStrings',
    'open_mode': :'String',
    'is_restricted': :'BOOLEAN',
    'compartment_id': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'lib/oci/database/models/pluggable_database.rb', line 252

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    container_database_id == other.container_database_id &&
    pdb_name == other.pdb_name &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    time_created == other.time_created &&
    connection_strings == other.connection_strings &&
    open_mode == other.open_mode &&
    is_restricted == other.is_restricted &&
    compartment_id == other.compartment_id &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
# File 'lib/oci/database/models/pluggable_database.rb', line 293

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


273
274
275
# File 'lib/oci/database/models/pluggable_database.rb', line 273

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



282
283
284
# File 'lib/oci/database/models/pluggable_database.rb', line 282

def hash
  [id, container_database_id, pdb_name, lifecycle_state, lifecycle_details, time_created, connection_strings, open_mode, is_restricted, compartment_id, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



326
327
328
329
330
331
332
333
334
335
# File 'lib/oci/database/models/pluggable_database.rb', line 326

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



320
321
322
# File 'lib/oci/database/models/pluggable_database.rb', line 320

def to_s
  to_hash.to_s
end