Class: OCI::Database::Models::UpdateAutonomousVmClusterDetails
- Inherits:
-
Object
- Object
- OCI::Database::Models::UpdateAutonomousVmClusterDetails
- Defined in:
- lib/oci/database/models/update_autonomous_vm_cluster_details.rb
Overview
Details for updating the Autonomous VM cluster.
Constant Summary collapse
- LICENSE_MODEL_ENUM =
[ LICENSE_MODEL_LICENSE_INCLUDED = 'LICENSE_INCLUDED'.freeze, LICENSE_MODEL_BRING_YOUR_OWN_LICENSE = 'BRING_YOUR_OWN_LICENSE'.freeze ].freeze
Instance Attribute Summary collapse
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#license_model ⇒ String
The Oracle license model that applies to the Autonomous VM cluster.
- #maintenance_window_details ⇒ OCI::Database::Models::MaintenanceWindow
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateAutonomousVmClusterDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateAutonomousVmClusterDetails
Initializes the object
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/oci/database/models/update_autonomous_vm_cluster_details.rb', line 71 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.maintenance_window_details = attributes[:'maintenanceWindowDetails'] if attributes[:'maintenanceWindowDetails'] raise 'You cannot provide both :maintenanceWindowDetails and :maintenance_window_details' if attributes.key?(:'maintenanceWindowDetails') && attributes.key?(:'maintenance_window_details') self.maintenance_window_details = attributes[:'maintenance_window_details'] if attributes[:'maintenance_window_details'] self.license_model = attributes[:'licenseModel'] if attributes[:'licenseModel'] raise 'You cannot provide both :licenseModel and :license_model' if attributes.key?(:'licenseModel') && attributes.key?(:'license_model') self.license_model = attributes[:'license_model'] if attributes[:'license_model'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
35 36 37 |
# File 'lib/oci/database/models/update_autonomous_vm_cluster_details.rb', line 35 def @defined_tags end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: `"Finance"`
29 30 31 |
# File 'lib/oci/database/models/update_autonomous_vm_cluster_details.rb', line 29 def @freeform_tags end |
#license_model ⇒ String
The Oracle license model that applies to the Autonomous VM cluster. The default is BRING_YOUR_OWN_LICENSE.
21 22 23 |
# File 'lib/oci/database/models/update_autonomous_vm_cluster_details.rb', line 21 def license_model @license_model end |
#maintenance_window_details ⇒ OCI::Database::Models::MaintenanceWindow
16 17 18 |
# File 'lib/oci/database/models/update_autonomous_vm_cluster_details.rb', line 16 def maintenance_window_details @maintenance_window_details end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
38 39 40 41 42 43 44 45 46 47 |
# File 'lib/oci/database/models/update_autonomous_vm_cluster_details.rb', line 38 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'maintenance_window_details': :'maintenanceWindowDetails', 'license_model': :'licenseModel', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
50 51 52 53 54 55 56 57 58 59 |
# File 'lib/oci/database/models/update_autonomous_vm_cluster_details.rb', line 50 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'maintenance_window_details': :'OCI::Database::Models::MaintenanceWindow', 'license_model': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
117 118 119 120 121 122 123 124 125 |
# File 'lib/oci/database/models/update_autonomous_vm_cluster_details.rb', line 117 def ==(other) return true if equal?(other) self.class == other.class && maintenance_window_details == other.maintenance_window_details && license_model == other.license_model && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/oci/database/models/update_autonomous_vm_cluster_details.rb', line 150 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
130 131 132 |
# File 'lib/oci/database/models/update_autonomous_vm_cluster_details.rb', line 130 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
139 140 141 |
# File 'lib/oci/database/models/update_autonomous_vm_cluster_details.rb', line 139 def hash [maintenance_window_details, license_model, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
183 184 185 186 187 188 189 190 191 192 |
# File 'lib/oci/database/models/update_autonomous_vm_cluster_details.rb', line 183 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
177 178 179 |
# File 'lib/oci/database/models/update_autonomous_vm_cluster_details.rb', line 177 def to_s to_hash.to_s end |