Class: OCI::Database::Models::UpdateHistoryEntry

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database/models/update_history_entry.rb

Overview

UpdateHistoryEntry model.

Constant Summary collapse

UPDATE_ACTION_ENUM =
[
  UPDATE_ACTION_ROLLING_APPLY = 'ROLLING_APPLY'.freeze,
  UPDATE_ACTION_NON_ROLLING_APPLY = 'NON_ROLLING_APPLY'.freeze,
  UPDATE_ACTION_PRECHECK = 'PRECHECK'.freeze,
  UPDATE_ACTION_ROLLBACK = 'ROLLBACK'.freeze,
  UPDATE_ACTION_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
UPDATE_TYPE_ENUM =
[
  UPDATE_TYPE_GI_UPGRADE = 'GI_UPGRADE'.freeze,
  UPDATE_TYPE_GI_PATCH = 'GI_PATCH'.freeze,
  UPDATE_TYPE_OS_UPDATE = 'OS_UPDATE'.freeze,
  UPDATE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_IN_PROGRESS = 'IN_PROGRESS'.freeze,
  LIFECYCLE_STATE_SUCCEEDED = 'SUCCEEDED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateHistoryEntry

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :update_id (String)

    The value to assign to the #update_id property

  • :update_action (String)

    The value to assign to the #update_action property

  • :update_type (String)

    The value to assign to the #update_type property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :lifecycle_details (String)

    The value to assign to the #lifecycle_details property

  • :time_started (DateTime)

    The value to assign to the #time_started property

  • :time_completed (DateTime)

    The value to assign to the #time_completed property



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/oci/database/models/update_history_entry.rb', line 112

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  self.id = attributes[:'id'] if attributes[:'id']

  self.update_id = attributes[:'updateId'] if attributes[:'updateId']

  raise 'You cannot provide both :updateId and :update_id' if attributes.key?(:'updateId') && attributes.key?(:'update_id')

  self.update_id = attributes[:'update_id'] if attributes[:'update_id']

  self.update_action = attributes[:'updateAction'] if attributes[:'updateAction']

  raise 'You cannot provide both :updateAction and :update_action' if attributes.key?(:'updateAction') && attributes.key?(:'update_action')

  self.update_action = attributes[:'update_action'] if attributes[:'update_action']

  self.update_type = attributes[:'updateType'] if attributes[:'updateType']

  raise 'You cannot provide both :updateType and :update_type' if attributes.key?(:'updateType') && attributes.key?(:'update_type')

  self.update_type = attributes[:'update_type'] if attributes[:'update_type']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.time_started = attributes[:'timeStarted'] if attributes[:'timeStarted']

  raise 'You cannot provide both :timeStarted and :time_started' if attributes.key?(:'timeStarted') && attributes.key?(:'time_started')

  self.time_started = attributes[:'time_started'] if attributes[:'time_started']

  self.time_completed = attributes[:'timeCompleted'] if attributes[:'timeCompleted']

  raise 'You cannot provide both :timeCompleted and :time_completed' if attributes.key?(:'timeCompleted') && attributes.key?(:'time_completed')

  self.time_completed = attributes[:'time_completed'] if attributes[:'time_completed']
end

Instance Attribute Details

#idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the maintenance update history entry.

Returns:

  • (String)


35
36
37
# File 'lib/oci/database/models/update_history_entry.rb', line 35

def id
  @id
end

#lifecycle_detailsString

Descriptive text providing additional details about the lifecycle state.

Returns:

  • (String)


56
57
58
# File 'lib/oci/database/models/update_history_entry.rb', line 56

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

[Required] The current lifecycle state of the maintenance update operation.

Returns:

  • (String)


51
52
53
# File 'lib/oci/database/models/update_history_entry.rb', line 51

def lifecycle_state
  @lifecycle_state
end

#time_completedDateTime

The date and time when the maintenance update action completed.

Returns:

  • (DateTime)


64
65
66
# File 'lib/oci/database/models/update_history_entry.rb', line 64

def time_completed
  @time_completed
end

#time_startedDateTime

[Required] The date and time when the maintenance update action started.

Returns:

  • (DateTime)


60
61
62
# File 'lib/oci/database/models/update_history_entry.rb', line 60

def time_started
  @time_started
end

#update_actionString

The update action.

Returns:

  • (String)


43
44
45
# File 'lib/oci/database/models/update_history_entry.rb', line 43

def update_action
  @update_action
end

#update_idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the maintenance update.

Returns:

  • (String)


39
40
41
# File 'lib/oci/database/models/update_history_entry.rb', line 39

def update_id
  @update_id
end

#update_typeString

[Required] The type of cloud VM cluster maintenance update.

Returns:

  • (String)


47
48
49
# File 'lib/oci/database/models/update_history_entry.rb', line 47

def update_type
  @update_type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/oci/database/models/update_history_entry.rb', line 67

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'update_id': :'updateId',
    'update_action': :'updateAction',
    'update_type': :'updateType',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'time_started': :'timeStarted',
    'time_completed': :'timeCompleted'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/oci/database/models/update_history_entry.rb', line 83

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'update_id': :'String',
    'update_action': :'String',
    'update_type': :'String',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'time_started': :'DateTime',
    'time_completed': :'DateTime'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/oci/database/models/update_history_entry.rb', line 206

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    update_id == other.update_id &&
    update_action == other.update_action &&
    update_type == other.update_type &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    time_started == other.time_started &&
    time_completed == other.time_completed
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/oci/database/models/update_history_entry.rb', line 243

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


223
224
225
# File 'lib/oci/database/models/update_history_entry.rb', line 223

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



232
233
234
# File 'lib/oci/database/models/update_history_entry.rb', line 232

def hash
  [id, update_id, update_action, update_type, lifecycle_state, lifecycle_details, time_started, time_completed].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



276
277
278
279
280
281
282
283
284
285
# File 'lib/oci/database/models/update_history_entry.rb', line 276

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



270
271
272
# File 'lib/oci/database/models/update_history_entry.rb', line 270

def to_s
  to_hash.to_s
end