Class: OCI::Database::Models::UpgradeDbSystemDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database/models/upgrade_db_system_details.rb

Overview

Details for upgrading the operating system and Oracle Grid Infrastructure (GI) of a DB system.

Constant Summary collapse

ACTION_ENUM =
[
  ACTION_PRECHECK = 'PRECHECK'.freeze,
  ACTION_ROLLBACK = 'ROLLBACK'.freeze,
  ACTION_UPDATE_SNAPSHOT_RETENTION_DAYS = 'UPDATE_SNAPSHOT_RETENTION_DAYS'.freeze,
  ACTION_UPGRADE = 'UPGRADE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpgradeDbSystemDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/oci/database/models/upgrade_db_system_details.rb', line 68

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.action = attributes[:'action'] if attributes[:'action']

  self.snapshot_retention_period_in_days = attributes[:'snapshotRetentionPeriodInDays'] if attributes[:'snapshotRetentionPeriodInDays']

  raise 'You cannot provide both :snapshotRetentionPeriodInDays and :snapshot_retention_period_in_days' if attributes.key?(:'snapshotRetentionPeriodInDays') && attributes.key?(:'snapshot_retention_period_in_days')

  self.snapshot_retention_period_in_days = attributes[:'snapshot_retention_period_in_days'] if attributes[:'snapshot_retention_period_in_days']

  self.new_gi_version = attributes[:'newGiVersion'] if attributes[:'newGiVersion']

  raise 'You cannot provide both :newGiVersion and :new_gi_version' if attributes.key?(:'newGiVersion') && attributes.key?(:'new_gi_version')

  self.new_gi_version = attributes[:'new_gi_version'] if attributes[:'new_gi_version']

  self.is_snapshot_retention_days_force_updated = attributes[:'isSnapshotRetentionDaysForceUpdated'] unless attributes[:'isSnapshotRetentionDaysForceUpdated'].nil?

  raise 'You cannot provide both :isSnapshotRetentionDaysForceUpdated and :is_snapshot_retention_days_force_updated' if attributes.key?(:'isSnapshotRetentionDaysForceUpdated') && attributes.key?(:'is_snapshot_retention_days_force_updated')

  self.is_snapshot_retention_days_force_updated = attributes[:'is_snapshot_retention_days_force_updated'] unless attributes[:'is_snapshot_retention_days_force_updated'].nil?
end

Instance Attribute Details

#actionString

**[Required]** The operating system upgrade action.

Returns:

  • (String)


20
21
22
# File 'lib/oci/database/models/upgrade_db_system_details.rb', line 20

def action
  @action
end

#is_snapshot_retention_days_force_updatedBOOLEAN

If true, rollback time is updated even if operating system upgrade history contains errors.

Returns:

  • (BOOLEAN)


32
33
34
# File 'lib/oci/database/models/upgrade_db_system_details.rb', line 32

def is_snapshot_retention_days_force_updated
  @is_snapshot_retention_days_force_updated
end

#new_gi_versionString

A valid Oracle Grid Infrastructure (GI) software version.

Returns:

  • (String)


28
29
30
# File 'lib/oci/database/models/upgrade_db_system_details.rb', line 28

def new_gi_version
  @new_gi_version
end

#snapshot_retention_period_in_daysInteger

The retention period, in days, for the snapshot that allows you to perform a rollback of the upgrade operation. After this number of days passes, you cannot roll back the upgrade.

Returns:

  • (Integer)


24
25
26
# File 'lib/oci/database/models/upgrade_db_system_details.rb', line 24

def snapshot_retention_period_in_days
  @snapshot_retention_period_in_days
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
44
# File 'lib/oci/database/models/upgrade_db_system_details.rb', line 35

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'action': :'action',
    'snapshot_retention_period_in_days': :'snapshotRetentionPeriodInDays',
    'new_gi_version': :'newGiVersion',
    'is_snapshot_retention_days_force_updated': :'isSnapshotRetentionDaysForceUpdated'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



47
48
49
50
51
52
53
54
55
56
# File 'lib/oci/database/models/upgrade_db_system_details.rb', line 47

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'action': :'String',
    'snapshot_retention_period_in_days': :'Integer',
    'new_gi_version': :'String',
    'is_snapshot_retention_days_force_updated': :'BOOLEAN'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



110
111
112
113
114
115
116
117
118
# File 'lib/oci/database/models/upgrade_db_system_details.rb', line 110

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    action == other.action &&
    snapshot_retention_period_in_days == other.snapshot_retention_period_in_days &&
    new_gi_version == other.new_gi_version &&
    is_snapshot_retention_days_force_updated == other.is_snapshot_retention_days_force_updated
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/oci/database/models/upgrade_db_system_details.rb', line 143

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


123
124
125
# File 'lib/oci/database/models/upgrade_db_system_details.rb', line 123

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



132
133
134
# File 'lib/oci/database/models/upgrade_db_system_details.rb', line 132

def hash
  [action, snapshot_retention_period_in_days, new_gi_version, is_snapshot_retention_days_force_updated].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



176
177
178
179
180
181
182
183
184
185
# File 'lib/oci/database/models/upgrade_db_system_details.rb', line 176

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



170
171
172
# File 'lib/oci/database/models/upgrade_db_system_details.rb', line 170

def to_s
  to_hash.to_s
end