Class: OCI::Database::Models::VmClusterSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database/models/vm_cluster_summary.rb

Overview

Details of the Exadata Cloud@Customer VM cluster.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze,
  LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze,
  LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_MAINTENANCE_IN_PROGRESS = 'MAINTENANCE_IN_PROGRESS'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LICENSE_MODEL_ENUM =
[
  LICENSE_MODEL_LICENSE_INCLUDED = 'LICENSE_INCLUDED'.freeze,
  LICENSE_MODEL_BRING_YOUR_OWN_LICENSE = 'BRING_YOUR_OWN_LICENSE'.freeze,
  LICENSE_MODEL_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ VmClusterSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :last_patch_history_entry_id (String)

    The value to assign to the #last_patch_history_entry_id property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :display_name (String)

    The value to assign to the #display_name property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :lifecycle_details (String)

    The value to assign to the #lifecycle_details property

  • :time_zone (String)

    The value to assign to the #time_zone property

  • :is_local_backup_enabled (BOOLEAN)

    The value to assign to the #is_local_backup_enabled property

  • :exadata_infrastructure_id (String)

    The value to assign to the #exadata_infrastructure_id property

  • :is_sparse_diskgroup_enabled (BOOLEAN)

    The value to assign to the #is_sparse_diskgroup_enabled property

  • :vm_cluster_network_id (String)

    The value to assign to the #vm_cluster_network_id property

  • :cpus_enabled (Integer)

    The value to assign to the #cpus_enabled property

  • :memory_size_in_gbs (Integer)

    The value to assign to the #memory_size_in_gbs property

  • :db_node_storage_size_in_gbs (Integer)

    The value to assign to the #db_node_storage_size_in_gbs property

  • :data_storage_size_in_tbs (Float)

    The value to assign to the #data_storage_size_in_tbs property

  • :shape (String)

    The value to assign to the #shape property

  • :gi_version (String)

    The value to assign to the #gi_version property

  • :system_version (String)

    The value to assign to the #system_version property

  • :ssh_public_keys (Array<String>)

    The value to assign to the #ssh_public_keys property

  • :license_model (String)

    The value to assign to the #license_model property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property



222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
# File 'lib/oci/database/models/vm_cluster_summary.rb', line 222

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.last_patch_history_entry_id = attributes[:'lastPatchHistoryEntryId'] if attributes[:'lastPatchHistoryEntryId']

  raise 'You cannot provide both :lastPatchHistoryEntryId and :last_patch_history_entry_id' if attributes.key?(:'lastPatchHistoryEntryId') && attributes.key?(:'last_patch_history_entry_id')

  self.last_patch_history_entry_id = attributes[:'last_patch_history_entry_id'] if attributes[:'last_patch_history_entry_id']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.time_zone = attributes[:'timeZone'] if attributes[:'timeZone']

  raise 'You cannot provide both :timeZone and :time_zone' if attributes.key?(:'timeZone') && attributes.key?(:'time_zone')

  self.time_zone = attributes[:'time_zone'] if attributes[:'time_zone']

  self.is_local_backup_enabled = attributes[:'isLocalBackupEnabled'] unless attributes[:'isLocalBackupEnabled'].nil?

  raise 'You cannot provide both :isLocalBackupEnabled and :is_local_backup_enabled' if attributes.key?(:'isLocalBackupEnabled') && attributes.key?(:'is_local_backup_enabled')

  self.is_local_backup_enabled = attributes[:'is_local_backup_enabled'] unless attributes[:'is_local_backup_enabled'].nil?

  self.exadata_infrastructure_id = attributes[:'exadataInfrastructureId'] if attributes[:'exadataInfrastructureId']

  raise 'You cannot provide both :exadataInfrastructureId and :exadata_infrastructure_id' if attributes.key?(:'exadataInfrastructureId') && attributes.key?(:'exadata_infrastructure_id')

  self.exadata_infrastructure_id = attributes[:'exadata_infrastructure_id'] if attributes[:'exadata_infrastructure_id']

  self.is_sparse_diskgroup_enabled = attributes[:'isSparseDiskgroupEnabled'] unless attributes[:'isSparseDiskgroupEnabled'].nil?

  raise 'You cannot provide both :isSparseDiskgroupEnabled and :is_sparse_diskgroup_enabled' if attributes.key?(:'isSparseDiskgroupEnabled') && attributes.key?(:'is_sparse_diskgroup_enabled')

  self.is_sparse_diskgroup_enabled = attributes[:'is_sparse_diskgroup_enabled'] unless attributes[:'is_sparse_diskgroup_enabled'].nil?

  self.vm_cluster_network_id = attributes[:'vmClusterNetworkId'] if attributes[:'vmClusterNetworkId']

  raise 'You cannot provide both :vmClusterNetworkId and :vm_cluster_network_id' if attributes.key?(:'vmClusterNetworkId') && attributes.key?(:'vm_cluster_network_id')

  self.vm_cluster_network_id = attributes[:'vm_cluster_network_id'] if attributes[:'vm_cluster_network_id']

  self.cpus_enabled = attributes[:'cpusEnabled'] if attributes[:'cpusEnabled']

  raise 'You cannot provide both :cpusEnabled and :cpus_enabled' if attributes.key?(:'cpusEnabled') && attributes.key?(:'cpus_enabled')

  self.cpus_enabled = attributes[:'cpus_enabled'] if attributes[:'cpus_enabled']

  self.memory_size_in_gbs = attributes[:'memorySizeInGBs'] if attributes[:'memorySizeInGBs']

  raise 'You cannot provide both :memorySizeInGBs and :memory_size_in_gbs' if attributes.key?(:'memorySizeInGBs') && attributes.key?(:'memory_size_in_gbs')

  self.memory_size_in_gbs = attributes[:'memory_size_in_gbs'] if attributes[:'memory_size_in_gbs']

  self.db_node_storage_size_in_gbs = attributes[:'dbNodeStorageSizeInGBs'] if attributes[:'dbNodeStorageSizeInGBs']

  raise 'You cannot provide both :dbNodeStorageSizeInGBs and :db_node_storage_size_in_gbs' if attributes.key?(:'dbNodeStorageSizeInGBs') && attributes.key?(:'db_node_storage_size_in_gbs')

  self.db_node_storage_size_in_gbs = attributes[:'db_node_storage_size_in_gbs'] if attributes[:'db_node_storage_size_in_gbs']

  self.data_storage_size_in_tbs = attributes[:'dataStorageSizeInTBs'] if attributes[:'dataStorageSizeInTBs']

  raise 'You cannot provide both :dataStorageSizeInTBs and :data_storage_size_in_tbs' if attributes.key?(:'dataStorageSizeInTBs') && attributes.key?(:'data_storage_size_in_tbs')

  self.data_storage_size_in_tbs = attributes[:'data_storage_size_in_tbs'] if attributes[:'data_storage_size_in_tbs']

  self.shape = attributes[:'shape'] if attributes[:'shape']

  self.gi_version = attributes[:'giVersion'] if attributes[:'giVersion']

  raise 'You cannot provide both :giVersion and :gi_version' if attributes.key?(:'giVersion') && attributes.key?(:'gi_version')

  self.gi_version = attributes[:'gi_version'] if attributes[:'gi_version']

  self.system_version = attributes[:'systemVersion'] if attributes[:'systemVersion']

  raise 'You cannot provide both :systemVersion and :system_version' if attributes.key?(:'systemVersion') && attributes.key?(:'system_version')

  self.system_version = attributes[:'system_version'] if attributes[:'system_version']

  self.ssh_public_keys = attributes[:'sshPublicKeys'] if attributes[:'sshPublicKeys']

  raise 'You cannot provide both :sshPublicKeys and :ssh_public_keys' if attributes.key?(:'sshPublicKeys') && attributes.key?(:'ssh_public_keys')

  self.ssh_public_keys = attributes[:'ssh_public_keys'] if attributes[:'ssh_public_keys']

  self.license_model = attributes[:'licenseModel'] if attributes[:'licenseModel']

  raise 'You cannot provide both :licenseModel and :license_model' if attributes.key?(:'licenseModel') && attributes.key?(:'license_model')

  self.license_model = attributes[:'license_model'] if attributes[:'license_model']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#compartment_idString

Returns:

  • (String)


35
36
37
# File 'lib/oci/database/models/vm_cluster_summary.rb', line 35

def compartment_id
  @compartment_id
end

#cpus_enabledInteger

The number of enabled CPU cores.

Returns:

  • (Integer)


81
82
83
# File 'lib/oci/database/models/vm_cluster_summary.rb', line 81

def cpus_enabled
  @cpus_enabled
end

#data_storage_size_in_tbsFloat

Size, in terabytes, of the DATA disk group.

Returns:

  • (Float)


93
94
95
# File 'lib/oci/database/models/vm_cluster_summary.rb', line 93

def data_storage_size_in_tbs
  @data_storage_size_in_tbs
end

#db_node_storage_size_in_gbsInteger

The local node storage allocated in GBs.

Returns:

  • (Integer)


89
90
91
# File 'lib/oci/database/models/vm_cluster_summary.rb', line 89

def db_node_storage_size_in_gbs
  @db_node_storage_size_in_gbs
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Returns:

  • (Hash<String, Hash<String, Object>>)


129
130
131
# File 'lib/oci/database/models/vm_cluster_summary.rb', line 129

def defined_tags
  @defined_tags
end

#display_nameString

The user-friendly name for the Exadata Cloud@Customer VM cluster. The name does not need to be unique.

Returns:

  • (String)


47
48
49
# File 'lib/oci/database/models/vm_cluster_summary.rb', line 47

def display_name
  @display_name
end

#exadata_infrastructure_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Exadata infrastructure.

Returns:

  • (String)


68
69
70
# File 'lib/oci/database/models/vm_cluster_summary.rb', line 68

def exadata_infrastructure_id
  @exadata_infrastructure_id
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: ‘"Finance"`

Returns:

  • (Hash<String, String>)


123
124
125
# File 'lib/oci/database/models/vm_cluster_summary.rb', line 123

def freeform_tags
  @freeform_tags
end

#gi_versionString

The Oracle Grid Infrastructure software version for the VM cluster.

Returns:

  • (String)


102
103
104
# File 'lib/oci/database/models/vm_cluster_summary.rb', line 102

def gi_version
  @gi_version
end

#idString

Returns:

  • (String)


31
32
33
# File 'lib/oci/database/models/vm_cluster_summary.rb', line 31

def id
  @id
end

#is_local_backup_enabledBOOLEAN

If true, database backup on local Exadata storage is configured for the VM cluster. If false, database backup on local Exadata storage is not available in the VM cluster.

Returns:

  • (BOOLEAN)


64
65
66
# File 'lib/oci/database/models/vm_cluster_summary.rb', line 64

def is_local_backup_enabled
  @is_local_backup_enabled
end

#is_sparse_diskgroup_enabledBOOLEAN

If true, sparse disk group is configured for the VM cluster. If false, sparse disk group is not created.

Returns:

  • (BOOLEAN)


73
74
75
# File 'lib/oci/database/models/vm_cluster_summary.rb', line 73

def is_sparse_diskgroup_enabled
  @is_sparse_diskgroup_enabled
end

#last_patch_history_entry_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the last patch history. This value is updated as soon as a patch operation starts.

Returns:

  • (String)


39
40
41
# File 'lib/oci/database/models/vm_cluster_summary.rb', line 39

def last_patch_history_entry_id
  @last_patch_history_entry_id
end

#license_modelString

The Oracle license model that applies to the VM cluster. The default is LICENSE_INCLUDED.

Returns:

  • (String)


115
116
117
# File 'lib/oci/database/models/vm_cluster_summary.rb', line 115

def license_model
  @license_model
end

#lifecycle_detailsString

Additional information about the current lifecycle state.

Returns:

  • (String)


55
56
57
# File 'lib/oci/database/models/vm_cluster_summary.rb', line 55

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

The current state of the VM cluster.

Returns:

  • (String)


43
44
45
# File 'lib/oci/database/models/vm_cluster_summary.rb', line 43

def lifecycle_state
  @lifecycle_state
end

#memory_size_in_gbsInteger

The memory allocated in GBs.

Returns:

  • (Integer)


85
86
87
# File 'lib/oci/database/models/vm_cluster_summary.rb', line 85

def memory_size_in_gbs
  @memory_size_in_gbs
end

#shapeString

The shape of the Exadata infrastructure. The shape determines the amount of CPU, storage, and memory resources allocated to the instance.

Returns:

  • (String)


98
99
100
# File 'lib/oci/database/models/vm_cluster_summary.rb', line 98

def shape
  @shape
end

#ssh_public_keysArray<String>

The public key portion of one or more key pairs used for SSH access to the VM cluster.

Returns:

  • (Array<String>)


110
111
112
# File 'lib/oci/database/models/vm_cluster_summary.rb', line 110

def ssh_public_keys
  @ssh_public_keys
end

#system_versionString

Operating system version of the image.

Returns:

  • (String)


106
107
108
# File 'lib/oci/database/models/vm_cluster_summary.rb', line 106

def system_version
  @system_version
end

#time_createdDateTime

The date and time that the VM cluster was created.

Returns:

  • (DateTime)


51
52
53
# File 'lib/oci/database/models/vm_cluster_summary.rb', line 51

def time_created
  @time_created
end

#time_zoneString

The time zone of the Exadata infrastructure. For details, see [Exadata Infrastructure Time Zones](docs.cloud.oracle.com/Content/Database/References/timezones.htm).

Returns:

  • (String)


59
60
61
# File 'lib/oci/database/models/vm_cluster_summary.rb', line 59

def time_zone
  @time_zone
end

#vm_cluster_network_idString

Returns:

  • (String)


77
78
79
# File 'lib/oci/database/models/vm_cluster_summary.rb', line 77

def vm_cluster_network_id
  @vm_cluster_network_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/oci/database/models/vm_cluster_summary.rb', line 132

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'compartment_id': :'compartmentId',
    'last_patch_history_entry_id': :'lastPatchHistoryEntryId',
    'lifecycle_state': :'lifecycleState',
    'display_name': :'displayName',
    'time_created': :'timeCreated',
    'lifecycle_details': :'lifecycleDetails',
    'time_zone': :'timeZone',
    'is_local_backup_enabled': :'isLocalBackupEnabled',
    'exadata_infrastructure_id': :'exadataInfrastructureId',
    'is_sparse_diskgroup_enabled': :'isSparseDiskgroupEnabled',
    'vm_cluster_network_id': :'vmClusterNetworkId',
    'cpus_enabled': :'cpusEnabled',
    'memory_size_in_gbs': :'memorySizeInGBs',
    'db_node_storage_size_in_gbs': :'dbNodeStorageSizeInGBs',
    'data_storage_size_in_tbs': :'dataStorageSizeInTBs',
    'shape': :'shape',
    'gi_version': :'giVersion',
    'system_version': :'systemVersion',
    'ssh_public_keys': :'sshPublicKeys',
    'license_model': :'licenseModel',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/oci/database/models/vm_cluster_summary.rb', line 163

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'compartment_id': :'String',
    'last_patch_history_entry_id': :'String',
    'lifecycle_state': :'String',
    'display_name': :'String',
    'time_created': :'DateTime',
    'lifecycle_details': :'String',
    'time_zone': :'String',
    'is_local_backup_enabled': :'BOOLEAN',
    'exadata_infrastructure_id': :'String',
    'is_sparse_diskgroup_enabled': :'BOOLEAN',
    'vm_cluster_network_id': :'String',
    'cpus_enabled': :'Integer',
    'memory_size_in_gbs': :'Integer',
    'db_node_storage_size_in_gbs': :'Integer',
    'data_storage_size_in_tbs': :'Float',
    'shape': :'String',
    'gi_version': :'String',
    'system_version': :'String',
    'ssh_public_keys': :'Array<String>',
    'license_model': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
# File 'lib/oci/database/models/vm_cluster_summary.rb', line 392

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    last_patch_history_entry_id == other.last_patch_history_entry_id &&
    lifecycle_state == other.lifecycle_state &&
    display_name == other.display_name &&
    time_created == other.time_created &&
    lifecycle_details == other.lifecycle_details &&
    time_zone == other.time_zone &&
    is_local_backup_enabled == other.is_local_backup_enabled &&
    exadata_infrastructure_id == other.exadata_infrastructure_id &&
    is_sparse_diskgroup_enabled == other.is_sparse_diskgroup_enabled &&
    vm_cluster_network_id == other.vm_cluster_network_id &&
    cpus_enabled == other.cpus_enabled &&
    memory_size_in_gbs == other.memory_size_in_gbs &&
    db_node_storage_size_in_gbs == other.db_node_storage_size_in_gbs &&
    data_storage_size_in_tbs == other.data_storage_size_in_tbs &&
    shape == other.shape &&
    gi_version == other.gi_version &&
    system_version == other.system_version &&
    ssh_public_keys == other.ssh_public_keys &&
    license_model == other.license_model &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
# File 'lib/oci/database/models/vm_cluster_summary.rb', line 444

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


424
425
426
# File 'lib/oci/database/models/vm_cluster_summary.rb', line 424

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



433
434
435
# File 'lib/oci/database/models/vm_cluster_summary.rb', line 433

def hash
  [id, compartment_id, last_patch_history_entry_id, lifecycle_state, display_name, time_created, lifecycle_details, time_zone, is_local_backup_enabled, exadata_infrastructure_id, is_sparse_diskgroup_enabled, vm_cluster_network_id, cpus_enabled, memory_size_in_gbs, db_node_storage_size_in_gbs, data_storage_size_in_tbs, shape, gi_version, system_version, ssh_public_keys, license_model, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



477
478
479
480
481
482
483
484
485
486
# File 'lib/oci/database/models/vm_cluster_summary.rb', line 477

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



471
472
473
# File 'lib/oci/database/models/vm_cluster_summary.rb', line 471

def to_s
  to_hash.to_s
end