Class: OCI::Database::Models::VmClusterUpdateHistoryEntrySummary
- Inherits:
-
Object
- Object
- OCI::Database::Models::VmClusterUpdateHistoryEntrySummary
- Defined in:
- lib/oci/database/models/vm_cluster_update_history_entry_summary.rb
Overview
The record of a maintenance update action performed on a specified VM cluster. Applies to Exadata Cloud@Customer instances only.
Constant Summary collapse
- UPDATE_ACTION_ENUM =
[ UPDATE_ACTION_ROLLING_APPLY = 'ROLLING_APPLY'.freeze, UPDATE_ACTION_PRECHECK = 'PRECHECK'.freeze, UPDATE_ACTION_ROLLBACK = 'ROLLBACK'.freeze, UPDATE_ACTION_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- UPDATE_TYPE_ENUM =
[ UPDATE_TYPE_GI_UPGRADE = 'GI_UPGRADE'.freeze, UPDATE_TYPE_GI_PATCH = 'GI_PATCH'.freeze, UPDATE_TYPE_OS_UPDATE = 'OS_UPDATE'.freeze, UPDATE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_IN_PROGRESS = 'IN_PROGRESS'.freeze, LIFECYCLE_STATE_SUCCEEDED = 'SUCCEEDED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the maintenance update history entry.
-
#lifecycle_details ⇒ String
Descriptive text providing additional details about the lifecycle state.
-
#lifecycle_state ⇒ String
[Required] The current lifecycle state of the maintenance update operation.
-
#time_completed ⇒ DateTime
The date and time when the maintenance update action completed.
-
#time_started ⇒ DateTime
[Required] The date and time when the maintenance update action started.
-
#update_action ⇒ String
The update action performed using this maintenance update.
-
#update_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the maintenance update.
-
#update_type ⇒ String
[Required] The type of VM cluster maintenance update.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VmClusterUpdateHistoryEntrySummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ VmClusterUpdateHistoryEntrySummary
Initializes the object
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/oci/database/models/vm_cluster_update_history_entry_summary.rb', line 112 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.update_id = attributes[:'updateId'] if attributes[:'updateId'] raise 'You cannot provide both :updateId and :update_id' if attributes.key?(:'updateId') && attributes.key?(:'update_id') self.update_id = attributes[:'update_id'] if attributes[:'update_id'] self.update_action = attributes[:'updateAction'] if attributes[:'updateAction'] raise 'You cannot provide both :updateAction and :update_action' if attributes.key?(:'updateAction') && attributes.key?(:'update_action') self.update_action = attributes[:'update_action'] if attributes[:'update_action'] self.update_type = attributes[:'updateType'] if attributes[:'updateType'] raise 'You cannot provide both :updateType and :update_type' if attributes.key?(:'updateType') && attributes.key?(:'update_type') self.update_type = attributes[:'update_type'] if attributes[:'update_type'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.time_started = attributes[:'timeStarted'] if attributes[:'timeStarted'] raise 'You cannot provide both :timeStarted and :time_started' if attributes.key?(:'timeStarted') && attributes.key?(:'time_started') self.time_started = attributes[:'time_started'] if attributes[:'time_started'] self.time_completed = attributes[:'timeCompleted'] if attributes[:'timeCompleted'] raise 'You cannot provide both :timeCompleted and :time_completed' if attributes.key?(:'timeCompleted') && attributes.key?(:'time_completed') self.time_completed = attributes[:'time_completed'] if attributes[:'time_completed'] end |
Instance Attribute Details
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the maintenance update history entry.
35 36 37 |
# File 'lib/oci/database/models/vm_cluster_update_history_entry_summary.rb', line 35 def id @id end |
#lifecycle_details ⇒ String
Descriptive text providing additional details about the lifecycle state.
56 57 58 |
# File 'lib/oci/database/models/vm_cluster_update_history_entry_summary.rb', line 56 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
[Required] The current lifecycle state of the maintenance update operation.
51 52 53 |
# File 'lib/oci/database/models/vm_cluster_update_history_entry_summary.rb', line 51 def lifecycle_state @lifecycle_state end |
#time_completed ⇒ DateTime
The date and time when the maintenance update action completed.
64 65 66 |
# File 'lib/oci/database/models/vm_cluster_update_history_entry_summary.rb', line 64 def time_completed @time_completed end |
#time_started ⇒ DateTime
[Required] The date and time when the maintenance update action started.
60 61 62 |
# File 'lib/oci/database/models/vm_cluster_update_history_entry_summary.rb', line 60 def time_started @time_started end |
#update_action ⇒ String
The update action performed using this maintenance update.
43 44 45 |
# File 'lib/oci/database/models/vm_cluster_update_history_entry_summary.rb', line 43 def update_action @update_action end |
#update_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the maintenance update.
39 40 41 |
# File 'lib/oci/database/models/vm_cluster_update_history_entry_summary.rb', line 39 def update_id @update_id end |
#update_type ⇒ String
[Required] The type of VM cluster maintenance update.
47 48 49 |
# File 'lib/oci/database/models/vm_cluster_update_history_entry_summary.rb', line 47 def update_type @update_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/oci/database/models/vm_cluster_update_history_entry_summary.rb', line 67 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'update_id': :'updateId', 'update_action': :'updateAction', 'update_type': :'updateType', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'time_started': :'timeStarted', 'time_completed': :'timeCompleted' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/oci/database/models/vm_cluster_update_history_entry_summary.rb', line 83 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'update_id': :'String', 'update_action': :'String', 'update_type': :'String', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'time_started': :'DateTime', 'time_completed': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
209 210 211 212 213 214 215 216 217 218 219 220 221 |
# File 'lib/oci/database/models/vm_cluster_update_history_entry_summary.rb', line 209 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && update_id == other.update_id && update_action == other.update_action && update_type == other.update_type && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && time_started == other.time_started && time_completed == other.time_completed end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 |
# File 'lib/oci/database/models/vm_cluster_update_history_entry_summary.rb', line 246 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
226 227 228 |
# File 'lib/oci/database/models/vm_cluster_update_history_entry_summary.rb', line 226 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
235 236 237 |
# File 'lib/oci/database/models/vm_cluster_update_history_entry_summary.rb', line 235 def hash [id, update_id, update_action, update_type, lifecycle_state, lifecycle_details, time_started, time_completed].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
279 280 281 282 283 284 285 286 287 288 |
# File 'lib/oci/database/models/vm_cluster_update_history_entry_summary.rb', line 279 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
273 274 275 |
# File 'lib/oci/database/models/vm_cluster_update_history_entry_summary.rb', line 273 def to_s to_hash.to_s end |