Class: OCI::Database::Models::VmClusterUpdateSummary
- Inherits:
-
Object
- Object
- OCI::Database::Models::VmClusterUpdateSummary
- Defined in:
- lib/oci/database/models/vm_cluster_update_summary.rb
Overview
A maintenance update for a VM cluster. Applies to Exadata Cloud@Customer instances only.
To use any of the API operations, you must be authorized in an IAM policy. If you’re not authorized, talk to an administrator. If you’re an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm).
Constant Summary collapse
- LAST_ACTION_ENUM =
[ LAST_ACTION_ROLLING_APPLY = 'ROLLING_APPLY'.freeze, LAST_ACTION_PRECHECK = 'PRECHECK'.freeze, LAST_ACTION_ROLLBACK = 'ROLLBACK'.freeze, LAST_ACTION_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- AVAILABLE_ACTIONS_ENUM =
[ AVAILABLE_ACTIONS_ROLLING_APPLY = 'ROLLING_APPLY'.freeze, AVAILABLE_ACTIONS_PRECHECK = 'PRECHECK'.freeze, AVAILABLE_ACTIONS_ROLLBACK = 'ROLLBACK'.freeze, AVAILABLE_ACTIONS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- UPDATE_TYPE_ENUM =
[ UPDATE_TYPE_GI_UPGRADE = 'GI_UPGRADE'.freeze, UPDATE_TYPE_GI_PATCH = 'GI_PATCH'.freeze, UPDATE_TYPE_OS_UPDATE = 'OS_UPDATE'.freeze, UPDATE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze, LIFECYCLE_STATE_SUCCESS = 'SUCCESS'.freeze, LIFECYCLE_STATE_IN_PROGRESS = 'IN_PROGRESS'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#available_actions ⇒ Array<String>
The possible actions that can be performed using this maintenance update.
-
#description ⇒ String
[Required] Details of the maintenance update package.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the maintenance update.
-
#last_action ⇒ String
The update action performed most recently using this maintenance update.
-
#lifecycle_details ⇒ String
Descriptive text providing additional details about the lifecycle state.
-
#lifecycle_state ⇒ String
The current state of the maintenance update.
-
#time_released ⇒ DateTime
[Required] The date and time the maintenance update was released.
-
#update_type ⇒ String
[Required] The type of VM cluster maintenance update.
-
#version ⇒ String
[Required] The version of the maintenance update package.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VmClusterUpdateSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ VmClusterUpdateSummary
Initializes the object
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/oci/database/models/vm_cluster_update_summary.rb', line 131 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.description = attributes[:'description'] if attributes[:'description'] self.last_action = attributes[:'lastAction'] if attributes[:'lastAction'] raise 'You cannot provide both :lastAction and :last_action' if attributes.key?(:'lastAction') && attributes.key?(:'last_action') self.last_action = attributes[:'last_action'] if attributes[:'last_action'] self.available_actions = attributes[:'availableActions'] if attributes[:'availableActions'] raise 'You cannot provide both :availableActions and :available_actions' if attributes.key?(:'availableActions') && attributes.key?(:'available_actions') self.available_actions = attributes[:'available_actions'] if attributes[:'available_actions'] self.update_type = attributes[:'updateType'] if attributes[:'updateType'] raise 'You cannot provide both :updateType and :update_type' if attributes.key?(:'updateType') && attributes.key?(:'update_type') self.update_type = attributes[:'update_type'] if attributes[:'update_type'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_released = attributes[:'timeReleased'] if attributes[:'timeReleased'] raise 'You cannot provide both :timeReleased and :time_released' if attributes.key?(:'timeReleased') && attributes.key?(:'time_released') self.time_released = attributes[:'time_released'] if attributes[:'time_released'] self.version = attributes[:'version'] if attributes[:'version'] end |
Instance Attribute Details
#available_actions ⇒ Array<String>
The possible actions that can be performed using this maintenance update.
59 60 61 |
# File 'lib/oci/database/models/vm_cluster_update_summary.rb', line 59 def available_actions @available_actions end |
#description ⇒ String
[Required] Details of the maintenance update package.
51 52 53 |
# File 'lib/oci/database/models/vm_cluster_update_summary.rb', line 51 def description @description end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the maintenance update.
47 48 49 |
# File 'lib/oci/database/models/vm_cluster_update_summary.rb', line 47 def id @id end |
#last_action ⇒ String
The update action performed most recently using this maintenance update.
55 56 57 |
# File 'lib/oci/database/models/vm_cluster_update_summary.rb', line 55 def last_action @last_action end |
#lifecycle_details ⇒ String
Descriptive text providing additional details about the lifecycle state.
68 69 70 |
# File 'lib/oci/database/models/vm_cluster_update_summary.rb', line 68 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
The current state of the maintenance update. Dependent on value of lastAction.
72 73 74 |
# File 'lib/oci/database/models/vm_cluster_update_summary.rb', line 72 def lifecycle_state @lifecycle_state end |
#time_released ⇒ DateTime
[Required] The date and time the maintenance update was released.
76 77 78 |
# File 'lib/oci/database/models/vm_cluster_update_summary.rb', line 76 def time_released @time_released end |
#update_type ⇒ String
[Required] The type of VM cluster maintenance update.
63 64 65 |
# File 'lib/oci/database/models/vm_cluster_update_summary.rb', line 63 def update_type @update_type end |
#version ⇒ String
[Required] The version of the maintenance update package.
80 81 82 |
# File 'lib/oci/database/models/vm_cluster_update_summary.rb', line 80 def version @version end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/oci/database/models/vm_cluster_update_summary.rb', line 83 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'description': :'description', 'last_action': :'lastAction', 'available_actions': :'availableActions', 'update_type': :'updateType', 'lifecycle_details': :'lifecycleDetails', 'lifecycle_state': :'lifecycleState', 'time_released': :'timeReleased', 'version': :'version' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/oci/database/models/vm_cluster_update_summary.rb', line 100 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'description': :'String', 'last_action': :'String', 'available_actions': :'Array<String>', 'update_type': :'String', 'lifecycle_details': :'String', 'lifecycle_state': :'String', 'time_released': :'DateTime', 'version': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
246 247 248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/oci/database/models/vm_cluster_update_summary.rb', line 246 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && description == other.description && last_action == other.last_action && available_actions == other.available_actions && update_type == other.update_type && lifecycle_details == other.lifecycle_details && lifecycle_state == other.lifecycle_state && time_released == other.time_released && version == other.version end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 |
# File 'lib/oci/database/models/vm_cluster_update_summary.rb', line 284 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
264 265 266 |
# File 'lib/oci/database/models/vm_cluster_update_summary.rb', line 264 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
273 274 275 |
# File 'lib/oci/database/models/vm_cluster_update_summary.rb', line 273 def hash [id, description, last_action, available_actions, update_type, lifecycle_details, lifecycle_state, time_released, version].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
317 318 319 320 321 322 323 324 325 326 |
# File 'lib/oci/database/models/vm_cluster_update_summary.rb', line 317 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
311 312 313 |
# File 'lib/oci/database/models/vm_cluster_update_summary.rb', line 311 def to_s to_hash.to_s end |