Class: OCI::Database::Models::VmNetworkDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database/models/vm_network_details.rb

Overview

Details of the client or backup networks in an Exadata VM cluster network. Applies to Exadata Cloud@Customer instances only.

Constant Summary collapse

NETWORK_TYPE_ENUM =
[
  NETWORK_TYPE_CLIENT = 'CLIENT'.freeze,
  NETWORK_TYPE_BACKUP = 'BACKUP'.freeze,
  NETWORK_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ VmNetworkDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :vlan_id (String)

    The value to assign to the #vlan_id property

  • :network_type (String)

    The value to assign to the #network_type property

  • :netmask (String)

    The value to assign to the #netmask property

  • :gateway (String)

    The value to assign to the #gateway property

  • :domain_name (String)

    The value to assign to the #domain_name property

  • :nodes (Array<OCI::Database::Models::NodeDetails>)

    The value to assign to the #nodes property



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/oci/database/models/vm_network_details.rb', line 82

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.vlan_id = attributes[:'vlanId'] if attributes[:'vlanId']

  raise 'You cannot provide both :vlanId and :vlan_id' if attributes.key?(:'vlanId') && attributes.key?(:'vlan_id')

  self.vlan_id = attributes[:'vlan_id'] if attributes[:'vlan_id']

  self.network_type = attributes[:'networkType'] if attributes[:'networkType']

  raise 'You cannot provide both :networkType and :network_type' if attributes.key?(:'networkType') && attributes.key?(:'network_type')

  self.network_type = attributes[:'network_type'] if attributes[:'network_type']

  self.netmask = attributes[:'netmask'] if attributes[:'netmask']

  self.gateway = attributes[:'gateway'] if attributes[:'gateway']

  self.domain_name = attributes[:'domainName'] if attributes[:'domainName']

  raise 'You cannot provide both :domainName and :domain_name' if attributes.key?(:'domainName') && attributes.key?(:'domain_name')

  self.domain_name = attributes[:'domain_name'] if attributes[:'domain_name']

  self.nodes = attributes[:'nodes'] if attributes[:'nodes']
end

Instance Attribute Details

#domain_nameString

[Required] The network domain name.

Returns:

  • (String)


36
37
38
# File 'lib/oci/database/models/vm_network_details.rb', line 36

def domain_name
  @domain_name
end

#gatewayString

[Required] The network gateway.

Returns:

  • (String)


32
33
34
# File 'lib/oci/database/models/vm_network_details.rb', line 32

def gateway
  @gateway
end

#netmaskString

[Required] The network netmask.

Returns:

  • (String)


28
29
30
# File 'lib/oci/database/models/vm_network_details.rb', line 28

def netmask
  @netmask
end

#network_typeString

[Required] The network type.

Returns:

  • (String)


24
25
26
# File 'lib/oci/database/models/vm_network_details.rb', line 24

def network_type
  @network_type
end

#nodesArray<OCI::Database::Models::NodeDetails>

[Required] The list of node details.



40
41
42
# File 'lib/oci/database/models/vm_network_details.rb', line 40

def nodes
  @nodes
end

#vlan_idString

[Required] The network VLAN ID.

Returns:

  • (String)


20
21
22
# File 'lib/oci/database/models/vm_network_details.rb', line 20

def vlan_id
  @vlan_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/oci/database/models/vm_network_details.rb', line 43

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'vlan_id': :'vlanId',
    'network_type': :'networkType',
    'netmask': :'netmask',
    'gateway': :'gateway',
    'domain_name': :'domainName',
    'nodes': :'nodes'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/oci/database/models/vm_network_details.rb', line 57

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'vlan_id': :'String',
    'network_type': :'String',
    'netmask': :'String',
    'gateway': :'String',
    'domain_name': :'String',
    'nodes': :'Array<OCI::Database::Models::NodeDetails>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



133
134
135
136
137
138
139
140
141
142
143
# File 'lib/oci/database/models/vm_network_details.rb', line 133

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    vlan_id == other.vlan_id &&
    network_type == other.network_type &&
    netmask == other.netmask &&
    gateway == other.gateway &&
    domain_name == other.domain_name &&
    nodes == other.nodes
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/oci/database/models/vm_network_details.rb', line 168

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


148
149
150
# File 'lib/oci/database/models/vm_network_details.rb', line 148

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



157
158
159
# File 'lib/oci/database/models/vm_network_details.rb', line 157

def hash
  [vlan_id, network_type, netmask, gateway, domain_name, nodes].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



201
202
203
204
205
206
207
208
209
210
# File 'lib/oci/database/models/vm_network_details.rb', line 201

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



195
196
197
# File 'lib/oci/database/models/vm_network_details.rb', line 195

def to_s
  to_hash.to_s
end