Class: OCI::DatabaseManagement::Models::AlertLogCountSummary
- Inherits:
-
Object
- Object
- OCI::DatabaseManagement::Models::AlertLogCountSummary
- Defined in:
- lib/oci/database_management/models/alert_log_count_summary.rb
Overview
The details for one alert log count entry.
Constant Summary collapse
- CATEGORY_ENUM =
[ CATEGORY_UNKNOWN = 'UNKNOWN'.freeze, CATEGORY_INCIDENT_ERROR = 'INCIDENT_ERROR'.freeze, CATEGORY_ERROR = 'ERROR'.freeze, CATEGORY_WARNING = 'WARNING'.freeze, CATEGORY_NOTIFICATION = 'NOTIFICATION'.freeze, CATEGORY_TRACE = 'TRACE'.freeze, CATEGORY_CRITICAL = 'CRITICAL'.freeze, CATEGORY_SEVERE = 'SEVERE'.freeze, CATEGORY_IMPORTANT = 'IMPORTANT'.freeze, CATEGORY_NORMAL = 'NORMAL'.freeze, CATEGORY_OTHER = 'OTHER'.freeze, CATEGORY_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#category ⇒ String
**[Required]** The category of different alert logs.
-
#count ⇒ Integer
**[Required]** The count of alert logs with specific category.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AlertLogCountSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ AlertLogCountSummary
Initializes the object
63 64 65 66 67 68 69 70 71 72 |
# File 'lib/oci/database_management/models/alert_log_count_summary.rb', line 63 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.category = attributes[:'category'] if attributes[:'category'] self.count = attributes[:'count'] if attributes[:'count'] end |
Instance Attribute Details
#category ⇒ String
**[Required]** The category of different alert logs.
29 30 31 |
# File 'lib/oci/database_management/models/alert_log_count_summary.rb', line 29 def category @category end |
#count ⇒ Integer
**[Required]** The count of alert logs with specific category.
33 34 35 |
# File 'lib/oci/database_management/models/alert_log_count_summary.rb', line 33 def count @count end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
36 37 38 39 40 41 42 43 |
# File 'lib/oci/database_management/models/alert_log_count_summary.rb', line 36 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'category': :'category', 'count': :'count' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
46 47 48 49 50 51 52 53 |
# File 'lib/oci/database_management/models/alert_log_count_summary.rb', line 46 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'category': :'String', 'count': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
94 95 96 97 98 99 100 |
# File 'lib/oci/database_management/models/alert_log_count_summary.rb', line 94 def ==(other) return true if equal?(other) self.class == other.class && category == other.category && count == other.count end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/oci/database_management/models/alert_log_count_summary.rb', line 125 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
105 106 107 |
# File 'lib/oci/database_management/models/alert_log_count_summary.rb', line 105 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
114 115 116 |
# File 'lib/oci/database_management/models/alert_log_count_summary.rb', line 114 def hash [category, count].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
158 159 160 161 162 163 164 165 166 167 |
# File 'lib/oci/database_management/models/alert_log_count_summary.rb', line 158 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
152 153 154 |
# File 'lib/oci/database_management/models/alert_log_count_summary.rb', line 152 def to_s to_hash.to_s end |