Class: OCI::DatabaseManagement::Models::AwrDbParameterChangeSummary
- Inherits:
-
Object
- Object
- OCI::DatabaseManagement::Models::AwrDbParameterChangeSummary
- Defined in:
- lib/oci/database_management/models/awr_db_parameter_change_summary.rb
Overview
A summary of the changes made to a single AWR database parameter.
Instance Attribute Summary collapse
-
#instance_number ⇒ Integer
The database instance number.
-
#is_default ⇒ BOOLEAN
Indicates whether the parameter value in the end snapshot is the default.
-
#previous_value ⇒ String
The previous value of the database parameter.
-
#snapshot_id ⇒ Integer
[Required] The ID of the snapshot with the parameter value changed.
-
#time_begin ⇒ DateTime
The start time of the interval.
-
#time_end ⇒ DateTime
The end time of the interval.
-
#value ⇒ String
The current value of the database parameter.
-
#value_modified ⇒ String
Indicates whether the parameter has been modified after instance startup: - MODIFIED - Parameter has been modified with ALTER SESSION - SYSTEM_MOD - Parameter has been modified with ALTER SYSTEM (which causes all the currently logged in sessionsu2019 values to be modified) - FALSE - Parameter has not been modified after instance startup.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AwrDbParameterChangeSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ AwrDbParameterChangeSummary
Initializes the object
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/oci/database_management/models/awr_db_parameter_change_summary.rb', line 95 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.time_begin = attributes[:'timeBegin'] if attributes[:'timeBegin'] raise 'You cannot provide both :timeBegin and :time_begin' if attributes.key?(:'timeBegin') && attributes.key?(:'time_begin') self.time_begin = attributes[:'time_begin'] if attributes[:'time_begin'] self.time_end = attributes[:'timeEnd'] if attributes[:'timeEnd'] raise 'You cannot provide both :timeEnd and :time_end' if attributes.key?(:'timeEnd') && attributes.key?(:'time_end') self.time_end = attributes[:'time_end'] if attributes[:'time_end'] self.instance_number = attributes[:'instanceNumber'] if attributes[:'instanceNumber'] raise 'You cannot provide both :instanceNumber and :instance_number' if attributes.key?(:'instanceNumber') && attributes.key?(:'instance_number') self.instance_number = attributes[:'instance_number'] if attributes[:'instance_number'] self.previous_value = attributes[:'previousValue'] if attributes[:'previousValue'] raise 'You cannot provide both :previousValue and :previous_value' if attributes.key?(:'previousValue') && attributes.key?(:'previous_value') self.previous_value = attributes[:'previous_value'] if attributes[:'previous_value'] self.value = attributes[:'value'] if attributes[:'value'] self.snapshot_id = attributes[:'snapshotId'] if attributes[:'snapshotId'] raise 'You cannot provide both :snapshotId and :snapshot_id' if attributes.key?(:'snapshotId') && attributes.key?(:'snapshot_id') self.snapshot_id = attributes[:'snapshot_id'] if attributes[:'snapshot_id'] self.value_modified = attributes[:'valueModified'] if attributes[:'valueModified'] raise 'You cannot provide both :valueModified and :value_modified' if attributes.key?(:'valueModified') && attributes.key?(:'value_modified') self.value_modified = attributes[:'value_modified'] if attributes[:'value_modified'] self.is_default = attributes[:'isDefault'] unless attributes[:'isDefault'].nil? raise 'You cannot provide both :isDefault and :is_default' if attributes.key?(:'isDefault') && attributes.key?(:'is_default') self.is_default = attributes[:'is_default'] unless attributes[:'is_default'].nil? end |
Instance Attribute Details
#instance_number ⇒ Integer
The database instance number.
20 21 22 |
# File 'lib/oci/database_management/models/awr_db_parameter_change_summary.rb', line 20 def instance_number @instance_number end |
#is_default ⇒ BOOLEAN
Indicates whether the parameter value in the end snapshot is the default.
47 48 49 |
# File 'lib/oci/database_management/models/awr_db_parameter_change_summary.rb', line 47 def is_default @is_default end |
#previous_value ⇒ String
The previous value of the database parameter.
24 25 26 |
# File 'lib/oci/database_management/models/awr_db_parameter_change_summary.rb', line 24 def previous_value @previous_value end |
#snapshot_id ⇒ Integer
[Required] The ID of the snapshot with the parameter value changed. The snapshot ID is not the [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm). It can be retrieved from the following endpoint: /managedDatabases/managedDatabaseId/awrDbs/awrDbId/awrDbSnapshots
35 36 37 |
# File 'lib/oci/database_management/models/awr_db_parameter_change_summary.rb', line 35 def snapshot_id @snapshot_id end |
#time_begin ⇒ DateTime
The start time of the interval.
12 13 14 |
# File 'lib/oci/database_management/models/awr_db_parameter_change_summary.rb', line 12 def time_begin @time_begin end |
#time_end ⇒ DateTime
The end time of the interval.
16 17 18 |
# File 'lib/oci/database_management/models/awr_db_parameter_change_summary.rb', line 16 def time_end @time_end end |
#value ⇒ String
The current value of the database parameter.
28 29 30 |
# File 'lib/oci/database_management/models/awr_db_parameter_change_summary.rb', line 28 def value @value end |
#value_modified ⇒ String
Indicates whether the parameter has been modified after instance startup:
- MODIFIED - Parameter has been modified with ALTER SESSION
- SYSTEM_MOD - Parameter has been modified with ALTER SYSTEM (which causes all the currently logged in sessions\u2019 values to be modified)
- FALSE - Parameter has not been modified after instance startup
43 44 45 |
# File 'lib/oci/database_management/models/awr_db_parameter_change_summary.rb', line 43 def value_modified @value_modified end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/oci/database_management/models/awr_db_parameter_change_summary.rb', line 50 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'time_begin': :'timeBegin', 'time_end': :'timeEnd', 'instance_number': :'instanceNumber', 'previous_value': :'previousValue', 'value': :'value', 'snapshot_id': :'snapshotId', 'value_modified': :'valueModified', 'is_default': :'isDefault' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/oci/database_management/models/awr_db_parameter_change_summary.rb', line 66 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'time_begin': :'DateTime', 'time_end': :'DateTime', 'instance_number': :'Integer', 'previous_value': :'String', 'value': :'String', 'snapshot_id': :'Integer', 'value_modified': :'String', 'is_default': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/oci/database_management/models/awr_db_parameter_change_summary.rb', line 153 def ==(other) return true if equal?(other) self.class == other.class && time_begin == other.time_begin && time_end == other.time_end && instance_number == other.instance_number && previous_value == other.previous_value && value == other.value && snapshot_id == other.snapshot_id && value_modified == other.value_modified && is_default == other.is_default end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/oci/database_management/models/awr_db_parameter_change_summary.rb', line 190 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
170 171 172 |
# File 'lib/oci/database_management/models/awr_db_parameter_change_summary.rb', line 170 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
179 180 181 |
# File 'lib/oci/database_management/models/awr_db_parameter_change_summary.rb', line 179 def hash [time_begin, time_end, instance_number, previous_value, value, snapshot_id, value_modified, is_default].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
223 224 225 226 227 228 229 230 231 232 |
# File 'lib/oci/database_management/models/awr_db_parameter_change_summary.rb', line 223 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
217 218 219 |
# File 'lib/oci/database_management/models/awr_db_parameter_change_summary.rb', line 217 def to_s to_hash.to_s end |