Class: OCI::DatabaseManagement::Models::AwrDbParameterSummary
- Inherits:
-
Object
- Object
- OCI::DatabaseManagement::Models::AwrDbParameterSummary
- Defined in:
- lib/oci/database_management/models/awr_db_parameter_summary.rb
Overview
The summary of the AWR change history data for a single database parameter.
Instance Attribute Summary collapse
-
#begin_value ⇒ String
The parameter value when the period began.
-
#end_value ⇒ String
The parameter value when the period ended.
-
#instance_number ⇒ Integer
The database instance number.
-
#is_changed ⇒ BOOLEAN
Indicates whether the parameter value changed within the period.
-
#is_default ⇒ BOOLEAN
Indicates whether the parameter value in the end snapshot is the default.
-
#name ⇒ String
[Required] The name of the parameter.
-
#value_modified ⇒ String
Indicates whether the parameter has been modified after instance startup: - MODIFIED - Parameter has been modified with ALTER SESSION - SYSTEM_MOD - Parameter has been modified with ALTER SYSTEM (which causes all the currently logged in sessionsu2019 values to be modified) - FALSE - Parameter has not been modified after instance startup.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AwrDbParameterSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ AwrDbParameterSummary
Initializes the object
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/oci/database_management/models/awr_db_parameter_summary.rb', line 85 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.instance_number = attributes[:'instanceNumber'] if attributes[:'instanceNumber'] raise 'You cannot provide both :instanceNumber and :instance_number' if attributes.key?(:'instanceNumber') && attributes.key?(:'instance_number') self.instance_number = attributes[:'instance_number'] if attributes[:'instance_number'] self.begin_value = attributes[:'beginValue'] if attributes[:'beginValue'] raise 'You cannot provide both :beginValue and :begin_value' if attributes.key?(:'beginValue') && attributes.key?(:'begin_value') self.begin_value = attributes[:'begin_value'] if attributes[:'begin_value'] self.end_value = attributes[:'endValue'] if attributes[:'endValue'] raise 'You cannot provide both :endValue and :end_value' if attributes.key?(:'endValue') && attributes.key?(:'end_value') self.end_value = attributes[:'end_value'] if attributes[:'end_value'] self.is_changed = attributes[:'isChanged'] unless attributes[:'isChanged'].nil? raise 'You cannot provide both :isChanged and :is_changed' if attributes.key?(:'isChanged') && attributes.key?(:'is_changed') self.is_changed = attributes[:'is_changed'] unless attributes[:'is_changed'].nil? self.value_modified = attributes[:'valueModified'] if attributes[:'valueModified'] raise 'You cannot provide both :valueModified and :value_modified' if attributes.key?(:'valueModified') && attributes.key?(:'value_modified') self.value_modified = attributes[:'value_modified'] if attributes[:'value_modified'] self.is_default = attributes[:'isDefault'] unless attributes[:'isDefault'].nil? raise 'You cannot provide both :isDefault and :is_default' if attributes.key?(:'isDefault') && attributes.key?(:'is_default') self.is_default = attributes[:'is_default'] unless attributes[:'is_default'].nil? end |
Instance Attribute Details
#begin_value ⇒ String
The parameter value when the period began.
20 21 22 |
# File 'lib/oci/database_management/models/awr_db_parameter_summary.rb', line 20 def begin_value @begin_value end |
#end_value ⇒ String
The parameter value when the period ended.
24 25 26 |
# File 'lib/oci/database_management/models/awr_db_parameter_summary.rb', line 24 def end_value @end_value end |
#instance_number ⇒ Integer
The database instance number.
16 17 18 |
# File 'lib/oci/database_management/models/awr_db_parameter_summary.rb', line 16 def instance_number @instance_number end |
#is_changed ⇒ BOOLEAN
Indicates whether the parameter value changed within the period.
28 29 30 |
# File 'lib/oci/database_management/models/awr_db_parameter_summary.rb', line 28 def is_changed @is_changed end |
#is_default ⇒ BOOLEAN
Indicates whether the parameter value in the end snapshot is the default.
40 41 42 |
# File 'lib/oci/database_management/models/awr_db_parameter_summary.rb', line 40 def is_default @is_default end |
#name ⇒ String
[Required] The name of the parameter.
12 13 14 |
# File 'lib/oci/database_management/models/awr_db_parameter_summary.rb', line 12 def name @name end |
#value_modified ⇒ String
Indicates whether the parameter has been modified after instance startup:
- MODIFIED - Parameter has been modified with ALTER SESSION
- SYSTEM_MOD - Parameter has been modified with ALTER SYSTEM (which causes all the currently logged in sessions\u2019 values to be modified)
- FALSE - Parameter has not been modified after instance startup
36 37 38 |
# File 'lib/oci/database_management/models/awr_db_parameter_summary.rb', line 36 def value_modified @value_modified end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/oci/database_management/models/awr_db_parameter_summary.rb', line 43 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'instance_number': :'instanceNumber', 'begin_value': :'beginValue', 'end_value': :'endValue', 'is_changed': :'isChanged', 'value_modified': :'valueModified', 'is_default': :'isDefault' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/oci/database_management/models/awr_db_parameter_summary.rb', line 58 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'instance_number': :'Integer', 'begin_value': :'String', 'end_value': :'String', 'is_changed': :'BOOLEAN', 'value_modified': :'String', 'is_default': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/oci/database_management/models/awr_db_parameter_summary.rb', line 137 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && instance_number == other.instance_number && begin_value == other.begin_value && end_value == other.end_value && is_changed == other.is_changed && value_modified == other.value_modified && is_default == other.is_default end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/oci/database_management/models/awr_db_parameter_summary.rb', line 173 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
153 154 155 |
# File 'lib/oci/database_management/models/awr_db_parameter_summary.rb', line 153 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
162 163 164 |
# File 'lib/oci/database_management/models/awr_db_parameter_summary.rb', line 162 def hash [name, instance_number, begin_value, end_value, is_changed, value_modified, is_default].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
206 207 208 209 210 211 212 213 214 215 |
# File 'lib/oci/database_management/models/awr_db_parameter_summary.rb', line 206 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
200 201 202 |
# File 'lib/oci/database_management/models/awr_db_parameter_summary.rb', line 200 def to_s to_hash.to_s end |