Class: OCI::DatabaseManagement::Models::AwrDbSnapshotSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database_management/models/awr_db_snapshot_summary.rb

Overview

The AWR snapshot summary of one snapshot.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ AwrDbSnapshotSummary

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :awr_db_id (String)

    The value to assign to the #awr_db_id property

  • :instance_number (Integer)

    The value to assign to the #instance_number property

  • :time_db_startup (DateTime)

    The value to assign to the #time_db_startup property

  • :time_begin (DateTime)

    The value to assign to the #time_begin property

  • :time_end (DateTime)

    The value to assign to the #time_end property

  • :snapshot_id (Integer)

    The value to assign to the #snapshot_id property

  • :error_count (Integer)

    The value to assign to the #error_count property



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/oci/database_management/models/awr_db_snapshot_summary.rb', line 87

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.awr_db_id = attributes[:'awrDbId'] if attributes[:'awrDbId']

  raise 'You cannot provide both :awrDbId and :awr_db_id' if attributes.key?(:'awrDbId') && attributes.key?(:'awr_db_id')

  self.awr_db_id = attributes[:'awr_db_id'] if attributes[:'awr_db_id']

  self.instance_number = attributes[:'instanceNumber'] if attributes[:'instanceNumber']

  raise 'You cannot provide both :instanceNumber and :instance_number' if attributes.key?(:'instanceNumber') && attributes.key?(:'instance_number')

  self.instance_number = attributes[:'instance_number'] if attributes[:'instance_number']

  self.time_db_startup = attributes[:'timeDbStartup'] if attributes[:'timeDbStartup']

  raise 'You cannot provide both :timeDbStartup and :time_db_startup' if attributes.key?(:'timeDbStartup') && attributes.key?(:'time_db_startup')

  self.time_db_startup = attributes[:'time_db_startup'] if attributes[:'time_db_startup']

  self.time_begin = attributes[:'timeBegin'] if attributes[:'timeBegin']

  raise 'You cannot provide both :timeBegin and :time_begin' if attributes.key?(:'timeBegin') && attributes.key?(:'time_begin')

  self.time_begin = attributes[:'time_begin'] if attributes[:'time_begin']

  self.time_end = attributes[:'timeEnd'] if attributes[:'timeEnd']

  raise 'You cannot provide both :timeEnd and :time_end' if attributes.key?(:'timeEnd') && attributes.key?(:'time_end')

  self.time_end = attributes[:'time_end'] if attributes[:'time_end']

  self.snapshot_id = attributes[:'snapshotId'] if attributes[:'snapshotId']

  raise 'You cannot provide both :snapshotId and :snapshot_id' if attributes.key?(:'snapshotId') && attributes.key?(:'snapshot_id')

  self.snapshot_id = attributes[:'snapshot_id'] if attributes[:'snapshot_id']

  self.error_count = attributes[:'errorCount'] if attributes[:'errorCount']

  raise 'You cannot provide both :errorCount and :error_count' if attributes.key?(:'errorCount') && attributes.key?(:'error_count')

  self.error_count = attributes[:'error_count'] if attributes[:'error_count']
end

Instance Attribute Details

#awr_db_idString

[Required] Internal ID of the database. The internal ID of the database is not the [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm). It can be retrieved from the following endpoint: /managedDatabases/managedDatabaseId/awrDbs

Returns:



15
16
17
# File 'lib/oci/database_management/models/awr_db_snapshot_summary.rb', line 15

def awr_db_id
  @awr_db_id
end

#error_countInteger

The total number of errors.

Returns:



42
43
44
# File 'lib/oci/database_management/models/awr_db_snapshot_summary.rb', line 42

def error_count
  @error_count
end

#instance_numberInteger

The database instance number.

Returns:



19
20
21
# File 'lib/oci/database_management/models/awr_db_snapshot_summary.rb', line 19

def instance_number
  @instance_number
end

#snapshot_idInteger

[Required] The ID of the snapshot. The snapshot ID is not the [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm). It can be retrieved from the following endpoint: /managedDatabases/managedDatabaseId/awrDbs/awrDbId/awrDbSnapshots

Returns:



38
39
40
# File 'lib/oci/database_management/models/awr_db_snapshot_summary.rb', line 38

def snapshot_id
  @snapshot_id
end

#time_beginDateTime

The start time of the snapshot.

Returns:



27
28
29
# File 'lib/oci/database_management/models/awr_db_snapshot_summary.rb', line 27

def time_begin
  @time_begin
end

#time_db_startupDateTime

The timestamp of the database startup.

Returns:



23
24
25
# File 'lib/oci/database_management/models/awr_db_snapshot_summary.rb', line 23

def time_db_startup
  @time_db_startup
end

#time_endDateTime

The end time of the snapshot.

Returns:



31
32
33
# File 'lib/oci/database_management/models/awr_db_snapshot_summary.rb', line 31

def time_end
  @time_end
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



45
46
47
48
49
50
51
52
53
54
55
56
57
# File 'lib/oci/database_management/models/awr_db_snapshot_summary.rb', line 45

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'awr_db_id': :'awrDbId',
    'instance_number': :'instanceNumber',
    'time_db_startup': :'timeDbStartup',
    'time_begin': :'timeBegin',
    'time_end': :'timeEnd',
    'snapshot_id': :'snapshotId',
    'error_count': :'errorCount'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/oci/database_management/models/awr_db_snapshot_summary.rb', line 60

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'awr_db_id': :'String',
    'instance_number': :'Integer',
    'time_db_startup': :'DateTime',
    'time_begin': :'DateTime',
    'time_end': :'DateTime',
    'snapshot_id': :'Integer',
    'error_count': :'Integer'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • the other object to be compared



143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/oci/database_management/models/awr_db_snapshot_summary.rb', line 143

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    awr_db_id == other.awr_db_id &&
    instance_number == other.instance_number &&
    time_db_startup == other.time_db_startup &&
    time_begin == other.time_begin &&
    time_end == other.time_end &&
    snapshot_id == other.snapshot_id &&
    error_count == other.error_count
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/oci/database_management/models/awr_db_snapshot_summary.rb', line 179

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • the other object to be compared

Returns:

See Also:

  • `==` method


159
160
161
# File 'lib/oci/database_management/models/awr_db_snapshot_summary.rb', line 159

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • Hash code



168
169
170
# File 'lib/oci/database_management/models/awr_db_snapshot_summary.rb', line 168

def hash
  [awr_db_id, instance_number, time_db_startup, time_begin, time_end, snapshot_id, error_count].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



212
213
214
215
216
217
218
219
220
221
# File 'lib/oci/database_management/models/awr_db_snapshot_summary.rb', line 212

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



206
207
208
# File 'lib/oci/database_management/models/awr_db_snapshot_summary.rb', line 206

def to_s
  to_hash.to_s
end