Class: OCI::DatabaseManagement::Models::ChildDatabase

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database_management/models/child_database.rb

Overview

The child Managed Database of a Managed Database Group.

Constant Summary collapse

DEPLOYMENT_TYPE_ENUM =
[
  DEPLOYMENT_TYPE_ONPREMISE = 'ONPREMISE'.freeze,
  DEPLOYMENT_TYPE_BM = 'BM'.freeze,
  DEPLOYMENT_TYPE_VM = 'VM'.freeze,
  DEPLOYMENT_TYPE_EXADATA = 'EXADATA'.freeze,
  DEPLOYMENT_TYPE_EXADATA_CC = 'EXADATA_CC'.freeze,
  DEPLOYMENT_TYPE_AUTONOMOUS = 'AUTONOMOUS'.freeze,
  DEPLOYMENT_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
WORKLOAD_TYPE_ENUM =
[
  WORKLOAD_TYPE_OLTP = 'OLTP'.freeze,
  WORKLOAD_TYPE_DW = 'DW'.freeze,
  WORKLOAD_TYPE_AJD = 'AJD'.freeze,
  WORKLOAD_TYPE_APEX = 'APEX'.freeze,
  WORKLOAD_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
DATABASE_TYPE_ENUM =
[
  DATABASE_TYPE_EXTERNAL_SIDB = 'EXTERNAL_SIDB'.freeze,
  DATABASE_TYPE_EXTERNAL_RAC = 'EXTERNAL_RAC'.freeze,
  DATABASE_TYPE_CLOUD_SIDB = 'CLOUD_SIDB'.freeze,
  DATABASE_TYPE_CLOUD_RAC = 'CLOUD_RAC'.freeze,
  DATABASE_TYPE_SHARED = 'SHARED'.freeze,
  DATABASE_TYPE_DEDICATED = 'DEDICATED'.freeze,
  DATABASE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
DATABASE_SUB_TYPE_ENUM =
[
  DATABASE_SUB_TYPE_CDB = 'CDB'.freeze,
  DATABASE_SUB_TYPE_PDB = 'PDB'.freeze,
  DATABASE_SUB_TYPE_NON_CDB = 'NON_CDB'.freeze,
  DATABASE_SUB_TYPE_ACD = 'ACD'.freeze,
  DATABASE_SUB_TYPE_ADB = 'ADB'.freeze,
  DATABASE_SUB_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ChildDatabase

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :name (String)

    The value to assign to the #name property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :deployment_type (String)

    The value to assign to the #deployment_type property

  • :workload_type (String)

    The value to assign to the #workload_type property

  • :database_type (String)

    The value to assign to the #database_type property

  • :database_sub_type (String)

    The value to assign to the #database_sub_type property

  • :time_added (DateTime)

    The value to assign to the #time_added property



128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/oci/database_management/models/child_database.rb', line 128

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.name = attributes[:'name'] if attributes[:'name']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.deployment_type = attributes[:'deploymentType'] if attributes[:'deploymentType']

  raise 'You cannot provide both :deploymentType and :deployment_type' if attributes.key?(:'deploymentType') && attributes.key?(:'deployment_type')

  self.deployment_type = attributes[:'deployment_type'] if attributes[:'deployment_type']

  self.workload_type = attributes[:'workloadType'] if attributes[:'workloadType']

  raise 'You cannot provide both :workloadType and :workload_type' if attributes.key?(:'workloadType') && attributes.key?(:'workload_type')

  self.workload_type = attributes[:'workload_type'] if attributes[:'workload_type']

  self.database_type = attributes[:'databaseType'] if attributes[:'databaseType']

  raise 'You cannot provide both :databaseType and :database_type' if attributes.key?(:'databaseType') && attributes.key?(:'database_type')

  self.database_type = attributes[:'database_type'] if attributes[:'database_type']

  self.database_sub_type = attributes[:'databaseSubType'] if attributes[:'databaseSubType']

  raise 'You cannot provide both :databaseSubType and :database_sub_type' if attributes.key?(:'databaseSubType') && attributes.key?(:'database_sub_type')

  self.database_sub_type = attributes[:'database_sub_type'] if attributes[:'database_sub_type']

  self.time_added = attributes[:'timeAdded'] if attributes[:'timeAdded']

  raise 'You cannot provide both :timeAdded and :time_added' if attributes.key?(:'timeAdded') && attributes.key?(:'time_added')

  self.time_added = attributes[:'time_added'] if attributes[:'time_added']
end

Instance Attribute Details

#compartment_idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment in which the Managed Database resides.

Returns:

  • (String)


58
59
60
# File 'lib/oci/database_management/models/child_database.rb', line 58

def compartment_id
  @compartment_id
end

#database_sub_typeString

The subtype of the Oracle Database. Indicates whether the database is a Container Database, Pluggable Database, Non-container Database, Autonomous Database, or Autonomous Container Database.

Returns:

  • (String)


76
77
78
# File 'lib/oci/database_management/models/child_database.rb', line 76

def database_sub_type
  @database_sub_type
end

#database_typeString

The type of Oracle Database installation.

Returns:

  • (String)


70
71
72
# File 'lib/oci/database_management/models/child_database.rb', line 70

def database_type
  @database_type
end

#deployment_typeString

The infrastructure used to deploy the Oracle Database.

Returns:

  • (String)


62
63
64
# File 'lib/oci/database_management/models/child_database.rb', line 62

def deployment_type
  @deployment_type
end

#idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Managed Database.

Returns:

  • (String)


50
51
52
# File 'lib/oci/database_management/models/child_database.rb', line 50

def id
  @id
end

#nameString

[Required] The name of the Managed Database.

Returns:

  • (String)


54
55
56
# File 'lib/oci/database_management/models/child_database.rb', line 54

def name
  @name
end

#time_addedDateTime

[Required] The date and time the Managed Database was added to the group.

Returns:

  • (DateTime)


80
81
82
# File 'lib/oci/database_management/models/child_database.rb', line 80

def time_added
  @time_added
end

#workload_typeString

The workload type of the Autonomous Database.

Returns:

  • (String)


66
67
68
# File 'lib/oci/database_management/models/child_database.rb', line 66

def workload_type
  @workload_type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/oci/database_management/models/child_database.rb', line 83

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'name': :'name',
    'compartment_id': :'compartmentId',
    'deployment_type': :'deploymentType',
    'workload_type': :'workloadType',
    'database_type': :'databaseType',
    'database_sub_type': :'databaseSubType',
    'time_added': :'timeAdded'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/oci/database_management/models/child_database.rb', line 99

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'name': :'String',
    'compartment_id': :'String',
    'deployment_type': :'String',
    'workload_type': :'String',
    'database_type': :'String',
    'database_sub_type': :'String',
    'time_added': :'DateTime'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



234
235
236
237
238
239
240
241
242
243
244
245
246
# File 'lib/oci/database_management/models/child_database.rb', line 234

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    name == other.name &&
    compartment_id == other.compartment_id &&
    deployment_type == other.deployment_type &&
    workload_type == other.workload_type &&
    database_type == other.database_type &&
    database_sub_type == other.database_sub_type &&
    time_added == other.time_added
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'lib/oci/database_management/models/child_database.rb', line 271

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


251
252
253
# File 'lib/oci/database_management/models/child_database.rb', line 251

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



260
261
262
# File 'lib/oci/database_management/models/child_database.rb', line 260

def hash
  [id, name, compartment_id, deployment_type, workload_type, database_type, database_sub_type, time_added].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



304
305
306
307
308
309
310
311
312
313
# File 'lib/oci/database_management/models/child_database.rb', line 304

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



298
299
300
# File 'lib/oci/database_management/models/child_database.rb', line 298

def to_s
  to_hash.to_s
end