Class: OCI::DatabaseManagement::Models::CreateDbManagementPrivateEndpointDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database_management/models/create_db_management_private_endpoint_details.rb

Overview

The details used to create a new Database Management private endpoint.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateDbManagementPrivateEndpointDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :name (String)

    The value to assign to the #name property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :is_cluster (BOOLEAN)

    The value to assign to the #is_cluster property

  • :subnet_id (String)

    The value to assign to the #subnet_id property

  • :description (String)

    The value to assign to the #description property

  • :nsg_ids (Array<String>)

    The value to assign to the #nsg_ids property



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/oci/database_management/models/create_db_management_private_endpoint_details.rb', line 75

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.name = attributes[:'name'] if attributes[:'name']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.is_cluster = attributes[:'isCluster'] unless attributes[:'isCluster'].nil?

  raise 'You cannot provide both :isCluster and :is_cluster' if attributes.key?(:'isCluster') && attributes.key?(:'is_cluster')

  self.is_cluster = attributes[:'is_cluster'] unless attributes[:'is_cluster'].nil?

  self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId']

  raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id')

  self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id']

  self.description = attributes[:'description'] if attributes[:'description']

  self.nsg_ids = attributes[:'nsgIds'] if attributes[:'nsgIds']

  raise 'You cannot provide both :nsgIds and :nsg_ids' if attributes.key?(:'nsgIds') && attributes.key?(:'nsg_ids')

  self.nsg_ids = attributes[:'nsg_ids'] if attributes[:'nsg_ids']
end

Instance Attribute Details

#compartment_idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.

Returns:

  • (String)


16
17
18
# File 'lib/oci/database_management/models/create_db_management_private_endpoint_details.rb', line 16

def compartment_id
  @compartment_id
end

#descriptionString

The description of the private endpoint.

Returns:

  • (String)


28
29
30
# File 'lib/oci/database_management/models/create_db_management_private_endpoint_details.rb', line 28

def description
  @description
end

#is_clusterBOOLEAN

Specifies whether the Database Management private endpoint will be used for Oracle Databases in a cluster.

Returns:

  • (BOOLEAN)


20
21
22
# File 'lib/oci/database_management/models/create_db_management_private_endpoint_details.rb', line 20

def is_cluster
  @is_cluster
end

#nameString

[Required] The display name of the Database Management private endpoint.

Returns:

  • (String)


12
13
14
# File 'lib/oci/database_management/models/create_db_management_private_endpoint_details.rb', line 12

def name
  @name
end

#nsg_idsArray<String>

The OCIDs of the Network Security Groups to which the Database Management private endpoint belongs.

Returns:

  • (Array<String>)


33
34
35
# File 'lib/oci/database_management/models/create_db_management_private_endpoint_details.rb', line 33

def nsg_ids
  @nsg_ids
end

#subnet_idString

Returns:

  • (String)


24
25
26
# File 'lib/oci/database_management/models/create_db_management_private_endpoint_details.rb', line 24

def subnet_id
  @subnet_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



36
37
38
39
40
41
42
43
44
45
46
47
# File 'lib/oci/database_management/models/create_db_management_private_endpoint_details.rb', line 36

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'name': :'name',
    'compartment_id': :'compartmentId',
    'is_cluster': :'isCluster',
    'subnet_id': :'subnetId',
    'description': :'description',
    'nsg_ids': :'nsgIds'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/oci/database_management/models/create_db_management_private_endpoint_details.rb', line 50

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'name': :'String',
    'compartment_id': :'String',
    'is_cluster': :'BOOLEAN',
    'subnet_id': :'String',
    'description': :'String',
    'nsg_ids': :'Array<String>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



117
118
119
120
121
122
123
124
125
126
127
# File 'lib/oci/database_management/models/create_db_management_private_endpoint_details.rb', line 117

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    name == other.name &&
    compartment_id == other.compartment_id &&
    is_cluster == other.is_cluster &&
    subnet_id == other.subnet_id &&
    description == other.description &&
    nsg_ids == other.nsg_ids
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/oci/database_management/models/create_db_management_private_endpoint_details.rb', line 152

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


132
133
134
# File 'lib/oci/database_management/models/create_db_management_private_endpoint_details.rb', line 132

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



141
142
143
# File 'lib/oci/database_management/models/create_db_management_private_endpoint_details.rb', line 141

def hash
  [name, compartment_id, is_cluster, subnet_id, description, nsg_ids].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



185
186
187
188
189
190
191
192
193
194
# File 'lib/oci/database_management/models/create_db_management_private_endpoint_details.rb', line 185

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



179
180
181
# File 'lib/oci/database_management/models/create_db_management_private_endpoint_details.rb', line 179

def to_s
  to_hash.to_s
end