Class: OCI::DatabaseManagement::Models::CreateSqlJobDetails
- Inherits:
-
CreateJobDetails
- Object
- CreateJobDetails
- OCI::DatabaseManagement::Models::CreateSqlJobDetails
- Defined in:
- lib/oci/database_management/models/create_sql_job_details.rb
Overview
The details specific to the SQL job request.
Constant Summary
Constants inherited from CreateJobDetails
OCI::DatabaseManagement::Models::CreateJobDetails::DATABASE_SUB_TYPE_ENUM, OCI::DatabaseManagement::Models::CreateJobDetails::JOB_TYPE_ENUM
Instance Attribute Summary collapse
-
#operation_type ⇒ String
[Required] The SQL operation type.
-
#password ⇒ String
The password for the database user name used to execute the SQL job.
-
#role ⇒ String
The role of the database user.
-
#secret_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the secret containing the user password.
-
#sql_text ⇒ String
The SQL text to be executed as part of the job.
- #sql_type ⇒ String
-
#user_name ⇒ String
The database user name used to execute the SQL job.
Attributes inherited from CreateJobDetails
#compartment_id, #database_sub_type, #description, #job_type, #managed_database_group_id, #managed_database_id, #name, #result_location, #schedule_details, #schedule_type, #timeout
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateSqlJobDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from CreateJobDetails
Constructor Details
#initialize(attributes = {}) ⇒ CreateSqlJobDetails
Initializes the object
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/oci/database_management/models/create_sql_job_details.rb', line 116 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['jobType'] = 'SQL' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.sql_text = attributes[:'sqlText'] if attributes[:'sqlText'] raise 'You cannot provide both :sqlText and :sql_text' if attributes.key?(:'sqlText') && attributes.key?(:'sql_text') self.sql_text = attributes[:'sql_text'] if attributes[:'sql_text'] self.sql_type = attributes[:'sqlType'] if attributes[:'sqlType'] raise 'You cannot provide both :sqlType and :sql_type' if attributes.key?(:'sqlType') && attributes.key?(:'sql_type') self.sql_type = attributes[:'sql_type'] if attributes[:'sql_type'] self.operation_type = attributes[:'operationType'] if attributes[:'operationType'] raise 'You cannot provide both :operationType and :operation_type' if attributes.key?(:'operationType') && attributes.key?(:'operation_type') self.operation_type = attributes[:'operation_type'] if attributes[:'operation_type'] self.user_name = attributes[:'userName'] if attributes[:'userName'] raise 'You cannot provide both :userName and :user_name' if attributes.key?(:'userName') && attributes.key?(:'user_name') self.user_name = attributes[:'user_name'] if attributes[:'user_name'] self.password = attributes[:'password'] if attributes[:'password'] self.secret_id = attributes[:'secretId'] if attributes[:'secretId'] raise 'You cannot provide both :secretId and :secret_id' if attributes.key?(:'secretId') && attributes.key?(:'secret_id') self.secret_id = attributes[:'secret_id'] if attributes[:'secret_id'] self.role = attributes[:'role'] if attributes[:'role'] end |
Instance Attribute Details
#operation_type ⇒ String
[Required] The SQL operation type.
20 21 22 |
# File 'lib/oci/database_management/models/create_sql_job_details.rb', line 20 def operation_type @operation_type end |
#password ⇒ String
The password for the database user name used to execute the SQL job.
31 32 33 |
# File 'lib/oci/database_management/models/create_sql_job_details.rb', line 31 def password @password end |
#role ⇒ String
The role of the database user. Indicates whether the database user is a normal user or sysdba.
39 40 41 |
# File 'lib/oci/database_management/models/create_sql_job_details.rb', line 39 def role @role end |
#secret_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the secret containing the user password.
35 36 37 |
# File 'lib/oci/database_management/models/create_sql_job_details.rb', line 35 def secret_id @secret_id end |
#sql_text ⇒ String
The SQL text to be executed as part of the job.
13 14 15 |
# File 'lib/oci/database_management/models/create_sql_job_details.rb', line 13 def sql_text @sql_text end |
#sql_type ⇒ String
16 17 18 |
# File 'lib/oci/database_management/models/create_sql_job_details.rb', line 16 def sql_type @sql_type end |
#user_name ⇒ String
The database user name used to execute the SQL job. If the job is being executed on a Managed Database Group, then the user name should exist on all the databases in the group with the same password.
27 28 29 |
# File 'lib/oci/database_management/models/create_sql_job_details.rb', line 27 def user_name @user_name end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/oci/database_management/models/create_sql_job_details.rb', line 42 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'description': :'description', 'compartment_id': :'compartmentId', 'managed_database_group_id': :'managedDatabaseGroupId', 'managed_database_id': :'managedDatabaseId', 'database_sub_type': :'databaseSubType', 'schedule_type': :'scheduleType', 'job_type': :'jobType', 'timeout': :'timeout', 'result_location': :'resultLocation', 'schedule_details': :'scheduleDetails', 'sql_text': :'sqlText', 'sql_type': :'sqlType', 'operation_type': :'operationType', 'user_name': :'userName', 'password': :'password', 'secret_id': :'secretId', 'role': :'role' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/oci/database_management/models/create_sql_job_details.rb', line 68 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'description': :'String', 'compartment_id': :'String', 'managed_database_group_id': :'String', 'managed_database_id': :'String', 'database_sub_type': :'String', 'schedule_type': :'String', 'job_type': :'String', 'timeout': :'String', 'result_location': :'OCI::DatabaseManagement::Models::JobExecutionResultLocation', 'schedule_details': :'OCI::DatabaseManagement::Models::JobScheduleDetails', 'sql_text': :'String', 'sql_type': :'String', 'operation_type': :'String', 'user_name': :'String', 'password': :'String', 'secret_id': :'String', 'role': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/oci/database_management/models/create_sql_job_details.rb', line 168 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && description == other.description && compartment_id == other.compartment_id && managed_database_group_id == other.managed_database_group_id && managed_database_id == other.managed_database_id && database_sub_type == other.database_sub_type && schedule_type == other.schedule_type && job_type == other.job_type && timeout == other.timeout && result_location == other.result_location && schedule_details == other.schedule_details && sql_text == other.sql_text && sql_type == other.sql_type && operation_type == other.operation_type && user_name == other.user_name && password == other.password && secret_id == other.secret_id && role == other.role end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/oci/database_management/models/create_sql_job_details.rb', line 215 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
195 196 197 |
# File 'lib/oci/database_management/models/create_sql_job_details.rb', line 195 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
204 205 206 |
# File 'lib/oci/database_management/models/create_sql_job_details.rb', line 204 def hash [name, description, compartment_id, managed_database_group_id, managed_database_id, database_sub_type, schedule_type, job_type, timeout, result_location, schedule_details, sql_text, sql_type, operation_type, user_name, password, secret_id, role].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
248 249 250 251 252 253 254 255 256 257 |
# File 'lib/oci/database_management/models/create_sql_job_details.rb', line 248 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
242 243 244 |
# File 'lib/oci/database_management/models/create_sql_job_details.rb', line 242 def to_s to_hash.to_s end |