Class: OCI::DatabaseManagement::Models::DatabaseFleetHealthMetrics

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database_management/models/database_fleet_health_metrics.rb

Overview

The details of the fleet health metrics.

Constant Summary collapse

COMPARE_TYPE_ENUM =
[
  COMPARE_TYPE_HOUR = 'HOUR'.freeze,
  COMPARE_TYPE_DAY = 'DAY'.freeze,
  COMPARE_TYPE_WEEK = 'WEEK'.freeze,
  COMPARE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DatabaseFleetHealthMetrics

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/oci/database_management/models/database_fleet_health_metrics.rb', line 79

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.compare_baseline_time = attributes[:'compareBaselineTime'] if attributes[:'compareBaselineTime']

  raise 'You cannot provide both :compareBaselineTime and :compare_baseline_time' if attributes.key?(:'compareBaselineTime') && attributes.key?(:'compare_baseline_time')

  self.compare_baseline_time = attributes[:'compare_baseline_time'] if attributes[:'compare_baseline_time']

  self.compare_target_time = attributes[:'compareTargetTime'] if attributes[:'compareTargetTime']

  raise 'You cannot provide both :compareTargetTime and :compare_target_time' if attributes.key?(:'compareTargetTime') && attributes.key?(:'compare_target_time')

  self.compare_target_time = attributes[:'compare_target_time'] if attributes[:'compare_target_time']

  self.compare_type = attributes[:'compareType'] if attributes[:'compareType']

  raise 'You cannot provide both :compareType and :compare_type' if attributes.key?(:'compareType') && attributes.key?(:'compare_type')

  self.compare_type = attributes[:'compare_type'] if attributes[:'compare_type']

  self.fleet_summary = attributes[:'fleetSummary'] if attributes[:'fleetSummary']

  raise 'You cannot provide both :fleetSummary and :fleet_summary' if attributes.key?(:'fleetSummary') && attributes.key?(:'fleet_summary')

  self.fleet_summary = attributes[:'fleet_summary'] if attributes[:'fleet_summary']

  self.fleet_databases = attributes[:'fleetDatabases'] if attributes[:'fleetDatabases']

  raise 'You cannot provide both :fleetDatabases and :fleet_databases' if attributes.key?(:'fleetDatabases') && attributes.key?(:'fleet_databases')

  self.fleet_databases = attributes[:'fleet_databases'] if attributes[:'fleet_databases']
end

Instance Attribute Details

#compare_baseline_timeString

**[Required]** The baseline date and time in UTC in ISO-8601 format, which is "yyyy-MM-dd'T'hh:mm:ss.sss'Z'". This is the date and time against which percentage change is calculated.

Returns:

  • (String)


22
23
24
# File 'lib/oci/database_management/models/database_fleet_health_metrics.rb', line 22

def compare_baseline_time
  @compare_baseline_time
end

#compare_target_timeString

**[Required]** The target date and time in UTC in ISO-8601 format, which is "yyyy-MM-dd'T'hh:mm:ss.sss'Z'". All the metrics are returned for the target date and time and the percentage change is calculated against the baseline date and time.

Returns:

  • (String)


29
30
31
# File 'lib/oci/database_management/models/database_fleet_health_metrics.rb', line 29

def compare_target_time
  @compare_target_time
end

#compare_typeString

The time window used for metrics comparison.

Returns:

  • (String)


33
34
35
# File 'lib/oci/database_management/models/database_fleet_health_metrics.rb', line 33

def compare_type
  @compare_type
end

#fleet_databasesArray<OCI::DatabaseManagement::Models::DatabaseUsageMetrics>

**[Required]** A list of the databases present in the fleet and their usage metrics.



40
41
42
# File 'lib/oci/database_management/models/database_fleet_health_metrics.rb', line 40

def fleet_databases
  @fleet_databases
end

#fleet_summaryOCI::DatabaseManagement::Models::FleetSummary



36
37
38
# File 'lib/oci/database_management/models/database_fleet_health_metrics.rb', line 36

def fleet_summary
  @fleet_summary
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
# File 'lib/oci/database_management/models/database_fleet_health_metrics.rb', line 43

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'compare_baseline_time': :'compareBaselineTime',
    'compare_target_time': :'compareTargetTime',
    'compare_type': :'compareType',
    'fleet_summary': :'fleetSummary',
    'fleet_databases': :'fleetDatabases'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



56
57
58
59
60
61
62
63
64
65
66
# File 'lib/oci/database_management/models/database_fleet_health_metrics.rb', line 56

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'compare_baseline_time': :'String',
    'compare_target_time': :'String',
    'compare_type': :'String',
    'fleet_summary': :'OCI::DatabaseManagement::Models::FleetSummary',
    'fleet_databases': :'Array<OCI::DatabaseManagement::Models::DatabaseUsageMetrics>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



136
137
138
139
140
141
142
143
144
145
# File 'lib/oci/database_management/models/database_fleet_health_metrics.rb', line 136

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    compare_baseline_time == other.compare_baseline_time &&
    compare_target_time == other.compare_target_time &&
    compare_type == other.compare_type &&
    fleet_summary == other.fleet_summary &&
    fleet_databases == other.fleet_databases
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/oci/database_management/models/database_fleet_health_metrics.rb', line 170

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


150
151
152
# File 'lib/oci/database_management/models/database_fleet_health_metrics.rb', line 150

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



159
160
161
# File 'lib/oci/database_management/models/database_fleet_health_metrics.rb', line 159

def hash
  [compare_baseline_time, compare_target_time, compare_type, fleet_summary, fleet_databases].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



203
204
205
206
207
208
209
210
211
212
# File 'lib/oci/database_management/models/database_fleet_health_metrics.rb', line 203

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



197
198
199
# File 'lib/oci/database_management/models/database_fleet_health_metrics.rb', line 197

def to_s
  to_hash.to_s
end