Class: OCI::DatabaseManagement::Models::DatabaseHomeMetricDefinition

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database_management/models/database_home_metric_definition.rb

Overview

The response containing the CPU, Storage, Wait, DB Time, and Memory metrics for a specific database.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DatabaseHomeMetricDefinition

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/oci/database_management/models/database_home_metric_definition.rb', line 67

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.activity_time_series_metrics = attributes[:'activityTimeSeriesMetrics'] if attributes[:'activityTimeSeriesMetrics']

  raise 'You cannot provide both :activityTimeSeriesMetrics and :activity_time_series_metrics' if attributes.key?(:'activityTimeSeriesMetrics') && attributes.key?(:'activity_time_series_metrics')

  self.activity_time_series_metrics = attributes[:'activity_time_series_metrics'] if attributes[:'activity_time_series_metrics']

  self.db_time_aggregate_metrics = attributes[:'dbTimeAggregateMetrics'] if attributes[:'dbTimeAggregateMetrics']

  raise 'You cannot provide both :dbTimeAggregateMetrics and :db_time_aggregate_metrics' if attributes.key?(:'dbTimeAggregateMetrics') && attributes.key?(:'db_time_aggregate_metrics')

  self.db_time_aggregate_metrics = attributes[:'db_time_aggregate_metrics'] if attributes[:'db_time_aggregate_metrics']

  self.io_aggregate_metrics = attributes[:'ioAggregateMetrics'] if attributes[:'ioAggregateMetrics']

  raise 'You cannot provide both :ioAggregateMetrics and :io_aggregate_metrics' if attributes.key?(:'ioAggregateMetrics') && attributes.key?(:'io_aggregate_metrics')

  self.io_aggregate_metrics = attributes[:'io_aggregate_metrics'] if attributes[:'io_aggregate_metrics']

  self.memory_aggregate_metrics = attributes[:'memoryAggregateMetrics'] if attributes[:'memoryAggregateMetrics']

  raise 'You cannot provide both :memoryAggregateMetrics and :memory_aggregate_metrics' if attributes.key?(:'memoryAggregateMetrics') && attributes.key?(:'memory_aggregate_metrics')

  self.memory_aggregate_metrics = attributes[:'memory_aggregate_metrics'] if attributes[:'memory_aggregate_metrics']

  self.db_storage_aggregate_metrics = attributes[:'dbStorageAggregateMetrics'] if attributes[:'dbStorageAggregateMetrics']

  raise 'You cannot provide both :dbStorageAggregateMetrics and :db_storage_aggregate_metrics' if attributes.key?(:'dbStorageAggregateMetrics') && attributes.key?(:'db_storage_aggregate_metrics')

  self.db_storage_aggregate_metrics = attributes[:'db_storage_aggregate_metrics'] if attributes[:'db_storage_aggregate_metrics']
end

Instance Attribute Details

#activity_time_series_metricsArray<OCI::DatabaseManagement::Models::ActivityTimeSeriesMetrics>

[Required] A list of the active session metrics for CPU and Wait time for a specific database.



12
13
14
# File 'lib/oci/database_management/models/database_home_metric_definition.rb', line 12

def activity_time_series_metrics
  @activity_time_series_metrics
end

#db_storage_aggregate_metricsOCI::DatabaseManagement::Models::DatabaseStorageAggregateMetrics

This attribute is required.



28
29
30
# File 'lib/oci/database_management/models/database_home_metric_definition.rb', line 28

def db_storage_aggregate_metrics
  @db_storage_aggregate_metrics
end

#db_time_aggregate_metricsOCI::DatabaseManagement::Models::DatabaseTimeAggregateMetrics

This attribute is required.



16
17
18
# File 'lib/oci/database_management/models/database_home_metric_definition.rb', line 16

def db_time_aggregate_metrics
  @db_time_aggregate_metrics
end

#io_aggregate_metricsOCI::DatabaseManagement::Models::DatabaseIOAggregateMetrics

This attribute is required.



20
21
22
# File 'lib/oci/database_management/models/database_home_metric_definition.rb', line 20

def io_aggregate_metrics
  @io_aggregate_metrics
end

#memory_aggregate_metricsOCI::DatabaseManagement::Models::MemoryAggregateMetrics

This attribute is required.



24
25
26
# File 'lib/oci/database_management/models/database_home_metric_definition.rb', line 24

def memory_aggregate_metrics
  @memory_aggregate_metrics
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
40
41
# File 'lib/oci/database_management/models/database_home_metric_definition.rb', line 31

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'activity_time_series_metrics': :'activityTimeSeriesMetrics',
    'db_time_aggregate_metrics': :'dbTimeAggregateMetrics',
    'io_aggregate_metrics': :'ioAggregateMetrics',
    'memory_aggregate_metrics': :'memoryAggregateMetrics',
    'db_storage_aggregate_metrics': :'dbStorageAggregateMetrics'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



44
45
46
47
48
49
50
51
52
53
54
# File 'lib/oci/database_management/models/database_home_metric_definition.rb', line 44

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'activity_time_series_metrics': :'Array<OCI::DatabaseManagement::Models::ActivityTimeSeriesMetrics>',
    'db_time_aggregate_metrics': :'OCI::DatabaseManagement::Models::DatabaseTimeAggregateMetrics',
    'io_aggregate_metrics': :'OCI::DatabaseManagement::Models::DatabaseIOAggregateMetrics',
    'memory_aggregate_metrics': :'OCI::DatabaseManagement::Models::MemoryAggregateMetrics',
    'db_storage_aggregate_metrics': :'OCI::DatabaseManagement::Models::DatabaseStorageAggregateMetrics'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



111
112
113
114
115
116
117
118
119
120
# File 'lib/oci/database_management/models/database_home_metric_definition.rb', line 111

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    activity_time_series_metrics == other.activity_time_series_metrics &&
    db_time_aggregate_metrics == other.db_time_aggregate_metrics &&
    io_aggregate_metrics == other.io_aggregate_metrics &&
    memory_aggregate_metrics == other.memory_aggregate_metrics &&
    db_storage_aggregate_metrics == other.db_storage_aggregate_metrics
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/oci/database_management/models/database_home_metric_definition.rb', line 145

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


125
126
127
# File 'lib/oci/database_management/models/database_home_metric_definition.rb', line 125

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



134
135
136
# File 'lib/oci/database_management/models/database_home_metric_definition.rb', line 134

def hash
  [activity_time_series_metrics, db_time_aggregate_metrics, io_aggregate_metrics, memory_aggregate_metrics, db_storage_aggregate_metrics].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



178
179
180
181
182
183
184
185
186
187
# File 'lib/oci/database_management/models/database_home_metric_definition.rb', line 178

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



172
173
174
# File 'lib/oci/database_management/models/database_home_metric_definition.rb', line 172

def to_s
  to_hash.to_s
end