Class: OCI::DatabaseManagement::Models::DatabaseParameterSummary
- Inherits:
-
Object
- Object
- OCI::DatabaseManagement::Models::DatabaseParameterSummary
- Defined in:
- lib/oci/database_management/models/database_parameter_summary.rb
Overview
A summary of the database parameter.
Constant Summary collapse
- TYPE_ENUM =
[ TYPE_BOOLEAN = 'BOOLEAN'.freeze, TYPE_STRING = 'STRING'.freeze, TYPE_INTEGER = 'INTEGER'.freeze, TYPE_FILENAME = 'FILENAME'.freeze, TYPE_BIG_INTEGER = 'BIG_INTEGER'.freeze, TYPE_RESERVED = 'RESERVED'.freeze, TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- IS_SYSTEM_MODIFIABLE_ENUM =
[ IS_SYSTEM_MODIFIABLE_IMMEDIATE = 'IMMEDIATE'.freeze, IS_SYSTEM_MODIFIABLE_DEFERRED = 'DEFERRED'.freeze, IS_SYSTEM_MODIFIABLE_FALSE = 'FALSE'.freeze, IS_SYSTEM_MODIFIABLE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- IS_MODIFIED_ENUM =
[ IS_MODIFIED_MODIFIED = 'MODIFIED'.freeze, IS_MODIFIED_FALSE = 'FALSE'.freeze, IS_MODIFIED_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- CONSTRAINT_ENUM =
[ CONSTRAINT_UNIQUE = 'UNIQUE'.freeze, CONSTRAINT_IDENTICAL = 'IDENTICAL'.freeze, CONSTRAINT_NONE = 'NONE'.freeze, CONSTRAINT_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#allowed_values ⇒ Array<OCI::DatabaseManagement::Models::AllowedParameterValue>
A list of allowed values for this parameter.
-
#category ⇒ String
The parameter category.
-
#constraint ⇒ String
Applicable in case of Oracle Real Application Clusters (Oracle RAC) databases.
-
#container_id ⇒ Float
The ID of the database container to which the data pertains.
-
#description ⇒ String
The description of the parameter.
-
#display_value ⇒ String
[Required] The parameter value in a user-friendly format.
-
#is_adjusted ⇒ BOOLEAN
Indicates whether Oracle adjusted the input value to a more suitable value.
-
#is_basic ⇒ BOOLEAN
Indicates whether the parameter is a basic parameter (
TRUE) or not (FALSE). -
#is_default ⇒ BOOLEAN
Indicates whether the parameter is set to the default value (
TRUE) or the parameter value was specified in the parameter file (FALSE). -
#is_deprecated ⇒ BOOLEAN
Indicates whether the parameter has been deprecated (
TRUE) or not (FALSE). -
#is_instance_modifiable ⇒ BOOLEAN
For parameters that can be changed with ‘ALTER SYSTEM`, indicates whether the value of the parameter can be different for every instance (
TRUE) or whether the parameter must have the same value for all Real Application Clusters instances (FALSE). -
#is_modified ⇒ String
Indicates how the parameter was modified.
-
#is_pdb_modifiable ⇒ BOOLEAN
Indicates whether the parameter can be modified on a per-PDB basis (
TRUE) or not (FALSE). -
#is_session_modifiable ⇒ BOOLEAN
Indicates whether the parameter can be changed with ‘ALTER SESSION` (
TRUE) or not (FALSE). -
#is_specified ⇒ BOOLEAN
Indicates whether the parameter was specified in the server parameter file (
TRUE) or not (FALSE). -
#is_system_modifiable ⇒ String
Indicates whether the parameter can be changed with ‘ALTER SYSTEM` and when the change takes effect: - IMMEDIATE: Parameter can be changed with `ALTER SYSTEM` regardless of the type of parameter file used to start the instance.
-
#name ⇒ String
[Required] The parameter name.
-
#number ⇒ Float
The parameter number.
-
#ordinal ⇒ Float
The position (ordinal number) of the parameter value.
-
#sid ⇒ String
The database instance SID for which the parameter is defined.
-
#type ⇒ String
[Required] The parameter type.
-
#update_comment ⇒ String
The comments associated with the most recent update.
-
#value ⇒ String
[Required] The parameter value.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DatabaseParameterSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DatabaseParameterSummary
Initializes the object
247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 |
# File 'lib/oci/database_management/models/database_parameter_summary.rb', line 247 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.type = attributes[:'type'] if attributes[:'type'] self.value = attributes[:'value'] if attributes[:'value'] self.display_value = attributes[:'displayValue'] if attributes[:'displayValue'] raise 'You cannot provide both :displayValue and :display_value' if attributes.key?(:'displayValue') && attributes.key?(:'display_value') self.display_value = attributes[:'display_value'] if attributes[:'display_value'] self.number = attributes[:'number'] if attributes[:'number'] self.is_default = attributes[:'isDefault'] unless attributes[:'isDefault'].nil? raise 'You cannot provide both :isDefault and :is_default' if attributes.key?(:'isDefault') && attributes.key?(:'is_default') self.is_default = attributes[:'is_default'] unless attributes[:'is_default'].nil? self.is_session_modifiable = attributes[:'isSessionModifiable'] unless attributes[:'isSessionModifiable'].nil? raise 'You cannot provide both :isSessionModifiable and :is_session_modifiable' if attributes.key?(:'isSessionModifiable') && attributes.key?(:'is_session_modifiable') self.is_session_modifiable = attributes[:'is_session_modifiable'] unless attributes[:'is_session_modifiable'].nil? self.is_system_modifiable = attributes[:'isSystemModifiable'] if attributes[:'isSystemModifiable'] raise 'You cannot provide both :isSystemModifiable and :is_system_modifiable' if attributes.key?(:'isSystemModifiable') && attributes.key?(:'is_system_modifiable') self.is_system_modifiable = attributes[:'is_system_modifiable'] if attributes[:'is_system_modifiable'] self.is_pdb_modifiable = attributes[:'isPdbModifiable'] unless attributes[:'isPdbModifiable'].nil? raise 'You cannot provide both :isPdbModifiable and :is_pdb_modifiable' if attributes.key?(:'isPdbModifiable') && attributes.key?(:'is_pdb_modifiable') self.is_pdb_modifiable = attributes[:'is_pdb_modifiable'] unless attributes[:'is_pdb_modifiable'].nil? self.is_instance_modifiable = attributes[:'isInstanceModifiable'] unless attributes[:'isInstanceModifiable'].nil? raise 'You cannot provide both :isInstanceModifiable and :is_instance_modifiable' if attributes.key?(:'isInstanceModifiable') && attributes.key?(:'is_instance_modifiable') self.is_instance_modifiable = attributes[:'is_instance_modifiable'] unless attributes[:'is_instance_modifiable'].nil? self.is_modified = attributes[:'isModified'] if attributes[:'isModified'] raise 'You cannot provide both :isModified and :is_modified' if attributes.key?(:'isModified') && attributes.key?(:'is_modified') self.is_modified = attributes[:'is_modified'] if attributes[:'is_modified'] self.is_adjusted = attributes[:'isAdjusted'] unless attributes[:'isAdjusted'].nil? raise 'You cannot provide both :isAdjusted and :is_adjusted' if attributes.key?(:'isAdjusted') && attributes.key?(:'is_adjusted') self.is_adjusted = attributes[:'is_adjusted'] unless attributes[:'is_adjusted'].nil? self.is_deprecated = attributes[:'isDeprecated'] unless attributes[:'isDeprecated'].nil? raise 'You cannot provide both :isDeprecated and :is_deprecated' if attributes.key?(:'isDeprecated') && attributes.key?(:'is_deprecated') self.is_deprecated = attributes[:'is_deprecated'] unless attributes[:'is_deprecated'].nil? self.is_basic = attributes[:'isBasic'] unless attributes[:'isBasic'].nil? raise 'You cannot provide both :isBasic and :is_basic' if attributes.key?(:'isBasic') && attributes.key?(:'is_basic') self.is_basic = attributes[:'is_basic'] unless attributes[:'is_basic'].nil? self.description = attributes[:'description'] if attributes[:'description'] self.ordinal = attributes[:'ordinal'] if attributes[:'ordinal'] self.update_comment = attributes[:'updateComment'] if attributes[:'updateComment'] raise 'You cannot provide both :updateComment and :update_comment' if attributes.key?(:'updateComment') && attributes.key?(:'update_comment') self.update_comment = attributes[:'update_comment'] if attributes[:'update_comment'] self.container_id = attributes[:'containerId'] if attributes[:'containerId'] raise 'You cannot provide both :containerId and :container_id' if attributes.key?(:'containerId') && attributes.key?(:'container_id') self.container_id = attributes[:'container_id'] if attributes[:'container_id'] self.category = attributes[:'category'] if attributes[:'category'] self.constraint = attributes[:'constraint'] if attributes[:'constraint'] self.sid = attributes[:'sid'] if attributes[:'sid'] self.is_specified = attributes[:'isSpecified'] unless attributes[:'isSpecified'].nil? raise 'You cannot provide both :isSpecified and :is_specified' if attributes.key?(:'isSpecified') && attributes.key?(:'is_specified') self.is_specified = attributes[:'is_specified'] unless attributes[:'is_specified'].nil? self.allowed_values = attributes[:'allowedValues'] if attributes[:'allowedValues'] raise 'You cannot provide both :allowedValues and :allowed_values' if attributes.key?(:'allowedValues') && attributes.key?(:'allowed_values') self.allowed_values = attributes[:'allowed_values'] if attributes[:'allowed_values'] end |
Instance Attribute Details
#allowed_values ⇒ Array<OCI::DatabaseManagement::Models::AllowedParameterValue>
A list of allowed values for this parameter.
154 155 156 |
# File 'lib/oci/database_management/models/database_parameter_summary.rb', line 154 def allowed_values @allowed_values end |
#category ⇒ String
The parameter category.
131 132 133 |
# File 'lib/oci/database_management/models/database_parameter_summary.rb', line 131 def category @category end |
#constraint ⇒ String
Applicable in case of Oracle Real Application Clusters (Oracle RAC) databases. A UNIQUE parameter is one which is unique to each Oracle Real Application Clusters (Oracle RAC) instance. For example, the parameter INSTANCE_NUMBER must have different values in each instance. An IDENTICAL parameter must have the same value for every instance. For example, the parameter DB_BLOCK_SIZE must have the same value in all instances.
141 142 143 |
# File 'lib/oci/database_management/models/database_parameter_summary.rb', line 141 def constraint @constraint end |
#container_id ⇒ Float
The ID of the database container to which the data pertains. Possible values include:
-
0: This value is used for data that pertain to the entire CDB. This value is also used for data in non-CDBs. -
1: This value is used for data that pertain to only the root container. -
n: Where n is the applicable container ID for the data.
127 128 129 |
# File 'lib/oci/database_management/models/database_parameter_summary.rb', line 127 def container_id @container_id end |
#description ⇒ String
The description of the parameter.
109 110 111 |
# File 'lib/oci/database_management/models/database_parameter_summary.rb', line 109 def description @description end |
#display_value ⇒ String
[Required] The parameter value in a user-friendly format. For example, if the value property shows the value 262144 for a big integer parameter, then the displayValue property will show the value 256K.
56 57 58 |
# File 'lib/oci/database_management/models/database_parameter_summary.rb', line 56 def display_value @display_value end |
#is_adjusted ⇒ BOOLEAN
Indicates whether Oracle adjusted the input value to a more suitable value.
97 98 99 |
# File 'lib/oci/database_management/models/database_parameter_summary.rb', line 97 def is_adjusted @is_adjusted end |
#is_basic ⇒ BOOLEAN
Indicates whether the parameter is a basic parameter (TRUE) or not (FALSE).
105 106 107 |
# File 'lib/oci/database_management/models/database_parameter_summary.rb', line 105 def is_basic @is_basic end |
#is_default ⇒ BOOLEAN
Indicates whether the parameter is set to the default value (TRUE) or the parameter value was specified in the parameter file (FALSE).
65 66 67 |
# File 'lib/oci/database_management/models/database_parameter_summary.rb', line 65 def is_default @is_default end |
#is_deprecated ⇒ BOOLEAN
Indicates whether the parameter has been deprecated (TRUE) or not (FALSE).
101 102 103 |
# File 'lib/oci/database_management/models/database_parameter_summary.rb', line 101 def is_deprecated @is_deprecated end |
#is_instance_modifiable ⇒ BOOLEAN
For parameters that can be changed with ‘ALTER SYSTEM`, indicates whether the value of the parameter can be different for every instance (TRUE) or whether the parameter must have the same value for all Real Application Clusters instances (FALSE). For other parameters, this is always FALSE.
88 89 90 |
# File 'lib/oci/database_management/models/database_parameter_summary.rb', line 88 def is_instance_modifiable @is_instance_modifiable end |
#is_modified ⇒ String
Indicates how the parameter was modified. If an ‘ALTER SYSTEM` was performed, the value will be MODIFIED.
93 94 95 |
# File 'lib/oci/database_management/models/database_parameter_summary.rb', line 93 def is_modified @is_modified end |
#is_pdb_modifiable ⇒ BOOLEAN
Indicates whether the parameter can be modified on a per-PDB basis (TRUE) or not (FALSE). In a non-CDB, the value of this property is null.
83 84 85 |
# File 'lib/oci/database_management/models/database_parameter_summary.rb', line 83 def is_pdb_modifiable @is_pdb_modifiable end |
#is_session_modifiable ⇒ BOOLEAN
Indicates whether the parameter can be changed with ‘ALTER SESSION` (TRUE) or not (FALSE)
70 71 72 |
# File 'lib/oci/database_management/models/database_parameter_summary.rb', line 70 def is_session_modifiable @is_session_modifiable end |
#is_specified ⇒ BOOLEAN
Indicates whether the parameter was specified in the server parameter file (TRUE) or not (FALSE). Applicable only when the parameter source is SPFILE.
150 151 152 |
# File 'lib/oci/database_management/models/database_parameter_summary.rb', line 150 def is_specified @is_specified end |
#is_system_modifiable ⇒ String
Indicates whether the parameter can be changed with ‘ALTER SYSTEM` and when the change takes effect:
-
IMMEDIATE: Parameter can be changed with ‘ALTER SYSTEM` regardless of the type of parameter file used to start the instance. The change takes effect immediately.
-
DEFERRED: Parameter can be changed with ‘ALTER SYSTEM` regardless of the type of parameter file used to start the instance. The change takes effect in subsequent sessions.
-
FALSE: Parameter cannot be changed with ‘ALTER SYSTEM` unless a server parameter file was used to start the instance. The change takes effect in subsequent instances.
78 79 80 |
# File 'lib/oci/database_management/models/database_parameter_summary.rb', line 78 def is_system_modifiable @is_system_modifiable end |
#name ⇒ String
[Required] The parameter name.
43 44 45 |
# File 'lib/oci/database_management/models/database_parameter_summary.rb', line 43 def name @name end |
#number ⇒ Float
The parameter number.
60 61 62 |
# File 'lib/oci/database_management/models/database_parameter_summary.rb', line 60 def number @number end |
#ordinal ⇒ Float
The position (ordinal number) of the parameter value. Useful only for parameters whose values are lists of strings.
114 115 116 |
# File 'lib/oci/database_management/models/database_parameter_summary.rb', line 114 def ordinal @ordinal end |
#sid ⇒ String
The database instance SID for which the parameter is defined.
145 146 147 |
# File 'lib/oci/database_management/models/database_parameter_summary.rb', line 145 def sid @sid end |
#type ⇒ String
[Required] The parameter type.
47 48 49 |
# File 'lib/oci/database_management/models/database_parameter_summary.rb', line 47 def type @type end |
#update_comment ⇒ String
The comments associated with the most recent update.
118 119 120 |
# File 'lib/oci/database_management/models/database_parameter_summary.rb', line 118 def update_comment @update_comment end |
#value ⇒ String
[Required] The parameter value.
51 52 53 |
# File 'lib/oci/database_management/models/database_parameter_summary.rb', line 51 def value @value end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/oci/database_management/models/database_parameter_summary.rb', line 157 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'type': :'type', 'value': :'value', 'display_value': :'displayValue', 'number': :'number', 'is_default': :'isDefault', 'is_session_modifiable': :'isSessionModifiable', 'is_system_modifiable': :'isSystemModifiable', 'is_pdb_modifiable': :'isPdbModifiable', 'is_instance_modifiable': :'isInstanceModifiable', 'is_modified': :'isModified', 'is_adjusted': :'isAdjusted', 'is_deprecated': :'isDeprecated', 'is_basic': :'isBasic', 'description': :'description', 'ordinal': :'ordinal', 'update_comment': :'updateComment', 'container_id': :'containerId', 'category': :'category', 'constraint': :'constraint', 'sid': :'sid', 'is_specified': :'isSpecified', 'allowed_values': :'allowedValues' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/oci/database_management/models/database_parameter_summary.rb', line 188 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'type': :'String', 'value': :'String', 'display_value': :'String', 'number': :'Float', 'is_default': :'BOOLEAN', 'is_session_modifiable': :'BOOLEAN', 'is_system_modifiable': :'String', 'is_pdb_modifiable': :'BOOLEAN', 'is_instance_modifiable': :'BOOLEAN', 'is_modified': :'String', 'is_adjusted': :'BOOLEAN', 'is_deprecated': :'BOOLEAN', 'is_basic': :'BOOLEAN', 'description': :'String', 'ordinal': :'Float', 'update_comment': :'String', 'container_id': :'Float', 'category': :'String', 'constraint': :'String', 'sid': :'String', 'is_specified': :'BOOLEAN', 'allowed_values': :'Array<OCI::DatabaseManagement::Models::AllowedParameterValue>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 |
# File 'lib/oci/database_management/models/database_parameter_summary.rb', line 415 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && type == other.type && value == other.value && display_value == other.display_value && number == other.number && is_default == other.is_default && is_session_modifiable == other.is_session_modifiable && is_system_modifiable == other.is_system_modifiable && is_pdb_modifiable == other.is_pdb_modifiable && is_instance_modifiable == other.is_instance_modifiable && is_modified == other.is_modified && is_adjusted == other.is_adjusted && is_deprecated == other.is_deprecated && is_basic == other.is_basic && description == other.description && ordinal == other.ordinal && update_comment == other.update_comment && container_id == other.container_id && category == other.category && constraint == other.constraint && sid == other.sid && is_specified == other.is_specified && allowed_values == other.allowed_values end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 |
# File 'lib/oci/database_management/models/database_parameter_summary.rb', line 467 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
447 448 449 |
# File 'lib/oci/database_management/models/database_parameter_summary.rb', line 447 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
456 457 458 |
# File 'lib/oci/database_management/models/database_parameter_summary.rb', line 456 def hash [name, type, value, display_value, number, is_default, is_session_modifiable, is_system_modifiable, is_pdb_modifiable, is_instance_modifiable, is_modified, is_adjusted, is_deprecated, is_basic, description, ordinal, update_comment, container_id, category, constraint, sid, is_specified, allowed_values].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
500 501 502 503 504 505 506 507 508 509 |
# File 'lib/oci/database_management/models/database_parameter_summary.rb', line 500 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
494 495 496 |
# File 'lib/oci/database_management/models/database_parameter_summary.rb', line 494 def to_s to_hash.to_s end |