Class: OCI::DatabaseManagement::Models::DatabaseParameterUpdateStatus
- Inherits:
-
Object
- Object
- OCI::DatabaseManagement::Models::DatabaseParameterUpdateStatus
- Defined in:
- lib/oci/database_management/models/database_parameter_update_status.rb
Overview
The result of database parameter update.
Constant Summary collapse
- STATUS_ENUM =
[ STATUS_SUCCEEDED = 'SUCCEEDED'.freeze, STATUS_FAILED = 'FAILED'.freeze, STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#error_code ⇒ String
An error code that defines the failure or
nullif the parameter was updated successfully. -
#error_message ⇒ String
The error message indicating the reason for failure or
nullif the parameter was updated successfully. -
#status ⇒ String
The status of the parameter update.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DatabaseParameterUpdateStatus
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DatabaseParameterUpdateStatus
Initializes the object
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/oci/database_management/models/database_parameter_update_status.rb', line 64 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.status = attributes[:'status'] if attributes[:'status'] self.error_code = attributes[:'errorCode'] if attributes[:'errorCode'] raise 'You cannot provide both :errorCode and :error_code' if attributes.key?(:'errorCode') && attributes.key?(:'error_code') self.error_code = attributes[:'error_code'] if attributes[:'error_code'] self. = attributes[:'errorMessage'] if attributes[:'errorMessage'] raise 'You cannot provide both :errorMessage and :error_message' if attributes.key?(:'errorMessage') && attributes.key?(:'error_message') self. = attributes[:'error_message'] if attributes[:'error_message'] end |
Instance Attribute Details
#error_code ⇒ String
An error code that defines the failure or null if the parameter was updated successfully.
25 26 27 |
# File 'lib/oci/database_management/models/database_parameter_update_status.rb', line 25 def error_code @error_code end |
#error_message ⇒ String
The error message indicating the reason for failure or null if the parameter was updated successfully.
31 32 33 |
# File 'lib/oci/database_management/models/database_parameter_update_status.rb', line 31 def end |
#status ⇒ String
The status of the parameter update.
19 20 21 |
# File 'lib/oci/database_management/models/database_parameter_update_status.rb', line 19 def status @status end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 |
# File 'lib/oci/database_management/models/database_parameter_update_status.rb', line 34 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'status': :'status', 'error_code': :'errorCode', 'error_message': :'errorMessage' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
45 46 47 48 49 50 51 52 53 |
# File 'lib/oci/database_management/models/database_parameter_update_status.rb', line 45 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'status': :'String', 'error_code': :'String', 'error_message': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
105 106 107 108 109 110 111 112 |
# File 'lib/oci/database_management/models/database_parameter_update_status.rb', line 105 def ==(other) return true if equal?(other) self.class == other.class && status == other.status && error_code == other.error_code && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/oci/database_management/models/database_parameter_update_status.rb', line 137 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
117 118 119 |
# File 'lib/oci/database_management/models/database_parameter_update_status.rb', line 117 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
126 127 128 |
# File 'lib/oci/database_management/models/database_parameter_update_status.rb', line 126 def hash [status, error_code, ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
170 171 172 173 174 175 176 177 178 179 |
# File 'lib/oci/database_management/models/database_parameter_update_status.rb', line 170 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
164 165 166 |
# File 'lib/oci/database_management/models/database_parameter_update_status.rb', line 164 def to_s to_hash.to_s end |