Class: OCI::DatabaseManagement::Models::DatabaseParametersCollection

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database_management/models/database_parameters_collection.rb

Overview

A collection of database parameters.

Constant Summary collapse

DATABASE_TYPE_ENUM =
[
  DATABASE_TYPE_EXTERNAL_SIDB = 'EXTERNAL_SIDB'.freeze,
  DATABASE_TYPE_EXTERNAL_RAC = 'EXTERNAL_RAC'.freeze,
  DATABASE_TYPE_CLOUD_SIDB = 'CLOUD_SIDB'.freeze,
  DATABASE_TYPE_CLOUD_RAC = 'CLOUD_RAC'.freeze,
  DATABASE_TYPE_SHARED = 'SHARED'.freeze,
  DATABASE_TYPE_DEDICATED = 'DEDICATED'.freeze,
  DATABASE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
DATABASE_SUB_TYPE_ENUM =
[
  DATABASE_SUB_TYPE_CDB = 'CDB'.freeze,
  DATABASE_SUB_TYPE_PDB = 'PDB'.freeze,
  DATABASE_SUB_TYPE_NON_CDB = 'NON_CDB'.freeze,
  DATABASE_SUB_TYPE_ACD = 'ACD'.freeze,
  DATABASE_SUB_TYPE_ADB = 'ADB'.freeze,
  DATABASE_SUB_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DatabaseParametersCollection

Initializes the object

Options Hash (attributes):

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/oci/database_management/models/database_parameters_collection.rb', line 89

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.database_name = attributes[:'databaseName'] if attributes[:'databaseName']

  raise 'You cannot provide both :databaseName and :database_name' if attributes.key?(:'databaseName') && attributes.key?(:'database_name')

  self.database_name = attributes[:'database_name'] if attributes[:'database_name']

  self.database_type = attributes[:'databaseType'] if attributes[:'databaseType']

  raise 'You cannot provide both :databaseType and :database_type' if attributes.key?(:'databaseType') && attributes.key?(:'database_type')

  self.database_type = attributes[:'database_type'] if attributes[:'database_type']

  self.database_sub_type = attributes[:'databaseSubType'] if attributes[:'databaseSubType']

  raise 'You cannot provide both :databaseSubType and :database_sub_type' if attributes.key?(:'databaseSubType') && attributes.key?(:'database_sub_type')

  self.database_sub_type = attributes[:'database_sub_type'] if attributes[:'database_sub_type']

  self.database_version = attributes[:'databaseVersion'] if attributes[:'databaseVersion']

  raise 'You cannot provide both :databaseVersion and :database_version' if attributes.key?(:'databaseVersion') && attributes.key?(:'database_version')

  self.database_version = attributes[:'database_version'] if attributes[:'database_version']

  self.items = attributes[:'items'] if attributes[:'items']
end

Instance Attribute Details

#database_nameString

[Required] The name of the Managed Database.

Returns:



32
33
34
# File 'lib/oci/database_management/models/database_parameters_collection.rb', line 32

def database_name
  @database_name
end

#database_sub_typeString

[Required] The subtype of the Oracle Database. Indicates whether the database is a Container Database, Pluggable Database, or a Non-container Database.

Returns:



42
43
44
# File 'lib/oci/database_management/models/database_parameters_collection.rb', line 42

def database_sub_type
  @database_sub_type
end

#database_typeString

[Required] The type of Oracle Database installation.

Returns:



36
37
38
# File 'lib/oci/database_management/models/database_parameters_collection.rb', line 36

def database_type
  @database_type
end

#database_versionString

[Required] The Oracle Database version.

Returns:



46
47
48
# File 'lib/oci/database_management/models/database_parameters_collection.rb', line 46

def database_version
  @database_version
end

#itemsArray<OCI::DatabaseManagement::Models::DatabaseParameterSummary>

[Required] An array of DatabaseParameterSummary objects.

Returns:



50
51
52
# File 'lib/oci/database_management/models/database_parameters_collection.rb', line 50

def items
  @items
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



53
54
55
56
57
58
59
60
61
62
63
# File 'lib/oci/database_management/models/database_parameters_collection.rb', line 53

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'database_name': :'databaseName',
    'database_type': :'databaseType',
    'database_sub_type': :'databaseSubType',
    'database_version': :'databaseVersion',
    'items': :'items'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



66
67
68
69
70
71
72
73
74
75
76
# File 'lib/oci/database_management/models/database_parameters_collection.rb', line 66

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'database_name': :'String',
    'database_type': :'String',
    'database_sub_type': :'String',
    'database_version': :'String',
    'items': :'Array<OCI::DatabaseManagement::Models::DatabaseParameterSummary>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • the other object to be compared



155
156
157
158
159
160
161
162
163
164
# File 'lib/oci/database_management/models/database_parameters_collection.rb', line 155

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    database_name == other.database_name &&
    database_type == other.database_type &&
    database_sub_type == other.database_sub_type &&
    database_version == other.database_version &&
    items == other.items
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/oci/database_management/models/database_parameters_collection.rb', line 189

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method

Parameters:

  • the other object to be compared

Returns:



169
170
171
# File 'lib/oci/database_management/models/database_parameters_collection.rb', line 169

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • Hash code



178
179
180
# File 'lib/oci/database_management/models/database_parameters_collection.rb', line 178

def hash
  [database_name, database_type, database_sub_type, database_version, items].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



222
223
224
225
226
227
228
229
230
231
# File 'lib/oci/database_management/models/database_parameters_collection.rb', line 222

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



216
217
218
# File 'lib/oci/database_management/models/database_parameters_collection.rb', line 216

def to_s
  to_hash.to_s
end