Class: OCI::DatabaseManagement::Models::DatabaseStorageAggregateMetrics
- Inherits:
-
Object
- Object
- OCI::DatabaseManagement::Models::DatabaseStorageAggregateMetrics
- Defined in:
- lib/oci/database_management/models/database_storage_aggregate_metrics.rb
Overview
The database storage metric values.
Instance Attribute Summary collapse
- #storage_allocated ⇒ OCI::DatabaseManagement::Models::MetricDataPoint
- #storage_used ⇒ OCI::DatabaseManagement::Models::MetricDataPoint
-
#storage_used_by_table_space ⇒ Array<OCI::DatabaseManagement::Models::MetricDataPoint>
A list of the storage metrics grouped by TableSpace for a specific database.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DatabaseStorageAggregateMetrics
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DatabaseStorageAggregateMetrics
Initializes the object
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/oci/database_management/models/database_storage_aggregate_metrics.rb', line 51 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.storage_allocated = attributes[:'storageAllocated'] if attributes[:'storageAllocated'] raise 'You cannot provide both :storageAllocated and :storage_allocated' if attributes.key?(:'storageAllocated') && attributes.key?(:'storage_allocated') self.storage_allocated = attributes[:'storage_allocated'] if attributes[:'storage_allocated'] self.storage_used = attributes[:'storageUsed'] if attributes[:'storageUsed'] raise 'You cannot provide both :storageUsed and :storage_used' if attributes.key?(:'storageUsed') && attributes.key?(:'storage_used') self.storage_used = attributes[:'storage_used'] if attributes[:'storage_used'] self.storage_used_by_table_space = attributes[:'storageUsedByTableSpace'] if attributes[:'storageUsedByTableSpace'] raise 'You cannot provide both :storageUsedByTableSpace and :storage_used_by_table_space' if attributes.key?(:'storageUsedByTableSpace') && attributes.key?(:'storage_used_by_table_space') self.storage_used_by_table_space = attributes[:'storage_used_by_table_space'] if attributes[:'storage_used_by_table_space'] end |
Instance Attribute Details
#storage_allocated ⇒ OCI::DatabaseManagement::Models::MetricDataPoint
11 12 13 |
# File 'lib/oci/database_management/models/database_storage_aggregate_metrics.rb', line 11 def storage_allocated @storage_allocated end |
#storage_used ⇒ OCI::DatabaseManagement::Models::MetricDataPoint
14 15 16 |
# File 'lib/oci/database_management/models/database_storage_aggregate_metrics.rb', line 14 def storage_used @storage_used end |
#storage_used_by_table_space ⇒ Array<OCI::DatabaseManagement::Models::MetricDataPoint>
A list of the storage metrics grouped by TableSpace for a specific database.
18 19 20 |
# File 'lib/oci/database_management/models/database_storage_aggregate_metrics.rb', line 18 def storage_used_by_table_space @storage_used_by_table_space end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
21 22 23 24 25 26 27 28 29 |
# File 'lib/oci/database_management/models/database_storage_aggregate_metrics.rb', line 21 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'storage_allocated': :'storageAllocated', 'storage_used': :'storageUsed', 'storage_used_by_table_space': :'storageUsedByTableSpace' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
32 33 34 35 36 37 38 39 40 |
# File 'lib/oci/database_management/models/database_storage_aggregate_metrics.rb', line 32 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'storage_allocated': :'OCI::DatabaseManagement::Models::MetricDataPoint', 'storage_used': :'OCI::DatabaseManagement::Models::MetricDataPoint', 'storage_used_by_table_space': :'Array<OCI::DatabaseManagement::Models::MetricDataPoint>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
83 84 85 86 87 88 89 90 |
# File 'lib/oci/database_management/models/database_storage_aggregate_metrics.rb', line 83 def ==(other) return true if equal?(other) self.class == other.class && storage_allocated == other.storage_allocated && storage_used == other.storage_used && storage_used_by_table_space == other.storage_used_by_table_space end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/oci/database_management/models/database_storage_aggregate_metrics.rb', line 115 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
95 96 97 |
# File 'lib/oci/database_management/models/database_storage_aggregate_metrics.rb', line 95 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
104 105 106 |
# File 'lib/oci/database_management/models/database_storage_aggregate_metrics.rb', line 104 def hash [storage_allocated, storage_used, storage_used_by_table_space].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
148 149 150 151 152 153 154 155 156 157 |
# File 'lib/oci/database_management/models/database_storage_aggregate_metrics.rb', line 148 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
142 143 144 |
# File 'lib/oci/database_management/models/database_storage_aggregate_metrics.rb', line 142 def to_s to_hash.to_s end |