Class: OCI::DatabaseManagement::Models::DatabaseTimeAggregateMetrics
- Inherits:
-
Object
- Object
- OCI::DatabaseManagement::Models::DatabaseTimeAggregateMetrics
- Defined in:
- lib/oci/database_management/models/database_time_aggregate_metrics.rb
Overview
The database time metric details.
Instance Attribute Summary collapse
- #cluster ⇒ OCI::DatabaseManagement::Models::MetricDataPoint
- #cpu_count ⇒ OCI::DatabaseManagement::Models::MetricDataPoint
- #cpu_time ⇒ OCI::DatabaseManagement::Models::MetricDataPoint
- #user_io_time ⇒ OCI::DatabaseManagement::Models::MetricDataPoint
- #wait_time ⇒ OCI::DatabaseManagement::Models::MetricDataPoint
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DatabaseTimeAggregateMetrics
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DatabaseTimeAggregateMetrics
Initializes the object
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/oci/database_management/models/database_time_aggregate_metrics.rb', line 62 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.cpu_count = attributes[:'cpuCount'] if attributes[:'cpuCount'] raise 'You cannot provide both :cpuCount and :cpu_count' if attributes.key?(:'cpuCount') && attributes.key?(:'cpu_count') self.cpu_count = attributes[:'cpu_count'] if attributes[:'cpu_count'] self.cpu_time = attributes[:'cpuTime'] if attributes[:'cpuTime'] raise 'You cannot provide both :cpuTime and :cpu_time' if attributes.key?(:'cpuTime') && attributes.key?(:'cpu_time') self.cpu_time = attributes[:'cpu_time'] if attributes[:'cpu_time'] self.wait_time = attributes[:'waitTime'] if attributes[:'waitTime'] raise 'You cannot provide both :waitTime and :wait_time' if attributes.key?(:'waitTime') && attributes.key?(:'wait_time') self.wait_time = attributes[:'wait_time'] if attributes[:'wait_time'] self.user_io_time = attributes[:'userIoTime'] if attributes[:'userIoTime'] raise 'You cannot provide both :userIoTime and :user_io_time' if attributes.key?(:'userIoTime') && attributes.key?(:'user_io_time') self.user_io_time = attributes[:'user_io_time'] if attributes[:'user_io_time'] self.cluster = attributes[:'cluster'] if attributes[:'cluster'] end |
Instance Attribute Details
#cluster ⇒ OCI::DatabaseManagement::Models::MetricDataPoint
23 24 25 |
# File 'lib/oci/database_management/models/database_time_aggregate_metrics.rb', line 23 def cluster @cluster end |
#cpu_count ⇒ OCI::DatabaseManagement::Models::MetricDataPoint
11 12 13 |
# File 'lib/oci/database_management/models/database_time_aggregate_metrics.rb', line 11 def cpu_count @cpu_count end |
#cpu_time ⇒ OCI::DatabaseManagement::Models::MetricDataPoint
14 15 16 |
# File 'lib/oci/database_management/models/database_time_aggregate_metrics.rb', line 14 def cpu_time @cpu_time end |
#user_io_time ⇒ OCI::DatabaseManagement::Models::MetricDataPoint
20 21 22 |
# File 'lib/oci/database_management/models/database_time_aggregate_metrics.rb', line 20 def user_io_time @user_io_time end |
#wait_time ⇒ OCI::DatabaseManagement::Models::MetricDataPoint
17 18 19 |
# File 'lib/oci/database_management/models/database_time_aggregate_metrics.rb', line 17 def wait_time @wait_time end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
26 27 28 29 30 31 32 33 34 35 36 |
# File 'lib/oci/database_management/models/database_time_aggregate_metrics.rb', line 26 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'cpu_count': :'cpuCount', 'cpu_time': :'cpuTime', 'wait_time': :'waitTime', 'user_io_time': :'userIoTime', 'cluster': :'cluster' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
39 40 41 42 43 44 45 46 47 48 49 |
# File 'lib/oci/database_management/models/database_time_aggregate_metrics.rb', line 39 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'cpu_count': :'OCI::DatabaseManagement::Models::MetricDataPoint', 'cpu_time': :'OCI::DatabaseManagement::Models::MetricDataPoint', 'wait_time': :'OCI::DatabaseManagement::Models::MetricDataPoint', 'user_io_time': :'OCI::DatabaseManagement::Models::MetricDataPoint', 'cluster': :'OCI::DatabaseManagement::Models::MetricDataPoint' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
102 103 104 105 106 107 108 109 110 111 |
# File 'lib/oci/database_management/models/database_time_aggregate_metrics.rb', line 102 def ==(other) return true if equal?(other) self.class == other.class && cpu_count == other.cpu_count && cpu_time == other.cpu_time && wait_time == other.wait_time && user_io_time == other.user_io_time && cluster == other.cluster end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/oci/database_management/models/database_time_aggregate_metrics.rb', line 136 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
116 117 118 |
# File 'lib/oci/database_management/models/database_time_aggregate_metrics.rb', line 116 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
125 126 127 |
# File 'lib/oci/database_management/models/database_time_aggregate_metrics.rb', line 125 def hash [cpu_count, cpu_time, wait_time, user_io_time, cluster].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
169 170 171 172 173 174 175 176 177 178 |
# File 'lib/oci/database_management/models/database_time_aggregate_metrics.rb', line 169 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
163 164 165 |
# File 'lib/oci/database_management/models/database_time_aggregate_metrics.rb', line 163 def to_s to_hash.to_s end |