Class: OCI::DatabaseManagement::Models::DbManagementPrivateEndpointSummary
- Inherits:
-
Object
- Object
- OCI::DatabaseManagement::Models::DbManagementPrivateEndpointSummary
- Defined in:
- lib/oci/database_management/models/db_management_private_endpoint_summary.rb
Overview
The summary of a Database Management private endpoint.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
-
#description ⇒ String
The description of the private endpoint.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Database Management private endpoint.
-
#lifecycle_state ⇒ String
The current lifecycle state of the private endpoint.
-
#name ⇒ String
[Required] The display name of the Database Management private endpoint.
-
#subnet_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the subnet.
-
#time_created ⇒ DateTime
The date and time the private endpoint was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#vcn_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VCN.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DbManagementPrivateEndpointSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DbManagementPrivateEndpointSummary
Initializes the object
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/oci/database_management/models/db_management_private_endpoint_summary.rb', line 99 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.name = attributes[:'name'] if attributes[:'name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.vcn_id = attributes[:'vcnId'] if attributes[:'vcnId'] raise 'You cannot provide both :vcnId and :vcn_id' if attributes.key?(:'vcnId') && attributes.key?(:'vcn_id') self.vcn_id = attributes[:'vcn_id'] if attributes[:'vcn_id'] self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId'] raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id') self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id'] self.description = attributes[:'description'] if attributes[:'description'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
31 32 33 |
# File 'lib/oci/database_management/models/db_management_private_endpoint_summary.rb', line 31 def compartment_id @compartment_id end |
#description ⇒ String
The description of the private endpoint.
43 44 45 |
# File 'lib/oci/database_management/models/db_management_private_endpoint_summary.rb', line 43 def description @description end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Database Management private endpoint.
23 24 25 |
# File 'lib/oci/database_management/models/db_management_private_endpoint_summary.rb', line 23 def id @id end |
#lifecycle_state ⇒ String
The current lifecycle state of the private endpoint.
51 52 53 |
# File 'lib/oci/database_management/models/db_management_private_endpoint_summary.rb', line 51 def lifecycle_state @lifecycle_state end |
#name ⇒ String
[Required] The display name of the Database Management private endpoint.
27 28 29 |
# File 'lib/oci/database_management/models/db_management_private_endpoint_summary.rb', line 27 def name @name end |
#subnet_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the subnet.
39 40 41 |
# File 'lib/oci/database_management/models/db_management_private_endpoint_summary.rb', line 39 def subnet_id @subnet_id end |
#time_created ⇒ DateTime
The date and time the private endpoint was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
47 48 49 |
# File 'lib/oci/database_management/models/db_management_private_endpoint_summary.rb', line 47 def time_created @time_created end |
#vcn_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VCN.
35 36 37 |
# File 'lib/oci/database_management/models/db_management_private_endpoint_summary.rb', line 35 def vcn_id @vcn_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/oci/database_management/models/db_management_private_endpoint_summary.rb', line 54 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'name': :'name', 'compartment_id': :'compartmentId', 'vcn_id': :'vcnId', 'subnet_id': :'subnetId', 'description': :'description', 'time_created': :'timeCreated', 'lifecycle_state': :'lifecycleState' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/oci/database_management/models/db_management_private_endpoint_summary.rb', line 70 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'name': :'String', 'compartment_id': :'String', 'vcn_id': :'String', 'subnet_id': :'String', 'description': :'String', 'time_created': :'DateTime', 'lifecycle_state': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/oci/database_management/models/db_management_private_endpoint_summary.rb', line 162 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && name == other.name && compartment_id == other.compartment_id && vcn_id == other.vcn_id && subnet_id == other.subnet_id && description == other.description && time_created == other.time_created && lifecycle_state == other.lifecycle_state end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 |
# File 'lib/oci/database_management/models/db_management_private_endpoint_summary.rb', line 199 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
179 180 181 |
# File 'lib/oci/database_management/models/db_management_private_endpoint_summary.rb', line 179 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
188 189 190 |
# File 'lib/oci/database_management/models/db_management_private_endpoint_summary.rb', line 188 def hash [id, name, compartment_id, vcn_id, subnet_id, description, time_created, lifecycle_state].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
232 233 234 235 236 237 238 239 240 241 |
# File 'lib/oci/database_management/models/db_management_private_endpoint_summary.rb', line 232 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
226 227 228 |
# File 'lib/oci/database_management/models/db_management_private_endpoint_summary.rb', line 226 def to_s to_hash.to_s end |