Class: DatabaseManagement::Models::Job

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database_management/models/job.rb

Overview

The details of the job. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class

Direct Known Subclasses

SqlJob

Constant Summary collapse

DATABASE_SUB_TYPE_ENUM =
[
  DATABASE_SUB_TYPE_CDB = 'CDB'.freeze,
  DATABASE_SUB_TYPE_PDB = 'PDB'.freeze,
  DATABASE_SUB_TYPE_NON_CDB = 'NON_CDB'.freeze,
  DATABASE_SUB_TYPE_ACD = 'ACD'.freeze,
  DATABASE_SUB_TYPE_ADB = 'ADB'.freeze,
  DATABASE_SUB_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
SCHEDULE_TYPE_ENUM =
[
  SCHEDULE_TYPE_IMMEDIATE = 'IMMEDIATE'.freeze,
  SCHEDULE_TYPE_LATER = 'LATER'.freeze,
  SCHEDULE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
JOB_TYPE_ENUM =
[
  JOB_TYPE_SQL = 'SQL'.freeze,
  JOB_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Job

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/oci/database_management/models/job.rb', line 192

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.name = attributes[:'name'] if attributes[:'name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.managed_database_group_id = attributes[:'managedDatabaseGroupId'] if attributes[:'managedDatabaseGroupId']

  raise 'You cannot provide both :managedDatabaseGroupId and :managed_database_group_id' if attributes.key?(:'managedDatabaseGroupId') && attributes.key?(:'managed_database_group_id')

  self.managed_database_group_id = attributes[:'managed_database_group_id'] if attributes[:'managed_database_group_id']

  self.managed_database_id = attributes[:'managedDatabaseId'] if attributes[:'managedDatabaseId']

  raise 'You cannot provide both :managedDatabaseId and :managed_database_id' if attributes.key?(:'managedDatabaseId') && attributes.key?(:'managed_database_id')

  self.managed_database_id = attributes[:'managed_database_id'] if attributes[:'managed_database_id']

  self.managed_databases_details = attributes[:'managedDatabasesDetails'] if attributes[:'managedDatabasesDetails']

  raise 'You cannot provide both :managedDatabasesDetails and :managed_databases_details' if attributes.key?(:'managedDatabasesDetails') && attributes.key?(:'managed_databases_details')

  self.managed_databases_details = attributes[:'managed_databases_details'] if attributes[:'managed_databases_details']

  self.database_sub_type = attributes[:'databaseSubType'] if attributes[:'databaseSubType']

  raise 'You cannot provide both :databaseSubType and :database_sub_type' if attributes.key?(:'databaseSubType') && attributes.key?(:'database_sub_type')

  self.database_sub_type = attributes[:'database_sub_type'] if attributes[:'database_sub_type']

  self.schedule_type = attributes[:'scheduleType'] if attributes[:'scheduleType']

  raise 'You cannot provide both :scheduleType and :schedule_type' if attributes.key?(:'scheduleType') && attributes.key?(:'schedule_type')

  self.schedule_type = attributes[:'schedule_type'] if attributes[:'schedule_type']

  self.job_type = attributes[:'jobType'] if attributes[:'jobType']

  raise 'You cannot provide both :jobType and :job_type' if attributes.key?(:'jobType') && attributes.key?(:'job_type')

  self.job_type = attributes[:'job_type'] if attributes[:'job_type']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.timeout = attributes[:'timeout'] if attributes[:'timeout']

  self.result_location = attributes[:'resultLocation'] if attributes[:'resultLocation']

  raise 'You cannot provide both :resultLocation and :result_location' if attributes.key?(:'resultLocation') && attributes.key?(:'result_location')

  self.result_location = attributes[:'result_location'] if attributes[:'result_location']

  self.schedule_details = attributes[:'scheduleDetails'] if attributes[:'scheduleDetails']

  raise 'You cannot provide both :scheduleDetails and :schedule_details' if attributes.key?(:'scheduleDetails') && attributes.key?(:'schedule_details')

  self.schedule_details = attributes[:'schedule_details'] if attributes[:'schedule_details']

  self.submission_error_message = attributes[:'submissionErrorMessage'] if attributes[:'submissionErrorMessage']

  raise 'You cannot provide both :submissionErrorMessage and :submission_error_message' if attributes.key?(:'submissionErrorMessage') && attributes.key?(:'submission_error_message')

  self.submission_error_message = attributes[:'submission_error_message'] if attributes[:'submission_error_message']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']
end

Instance Attribute Details

#compartment_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment in which the job resides.

Returns:

  • (String)


44
45
46
# File 'lib/oci/database_management/models/job.rb', line 44

def compartment_id
  @compartment_id
end

#database_sub_typeString

The subtype of the Oracle Database where the job has to be executed. Applicable only when managedDatabaseGroupId is provided.

Returns:

  • (String)


68
69
70
# File 'lib/oci/database_management/models/job.rb', line 68

def database_sub_type
  @database_sub_type
end

#descriptionString

The description of the job.

Returns:

  • (String)


52
53
54
# File 'lib/oci/database_management/models/job.rb', line 52

def description
  @description
end

#idString

Returns:

  • (String)


40
41
42
# File 'lib/oci/database_management/models/job.rb', line 40

def id
  @id
end

#job_typeString

**[Required]** The type of job.

Returns:

  • (String)


76
77
78
# File 'lib/oci/database_management/models/job.rb', line 76

def job_type
  @job_type
end

#lifecycle_stateString

**[Required]** The lifecycle state of the job.

Returns:

  • (String)


80
81
82
# File 'lib/oci/database_management/models/job.rb', line 80

def lifecycle_state
  @lifecycle_state
end

#managed_database_group_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Managed Database Group where the job has to be executed.

Returns:

  • (String)


56
57
58
# File 'lib/oci/database_management/models/job.rb', line 56

def managed_database_group_id
  @managed_database_group_id
end

#managed_database_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Managed Database where the job has to be executed.

Returns:

  • (String)


60
61
62
# File 'lib/oci/database_management/models/job.rb', line 60

def managed_database_id
  @managed_database_id
end

#managed_databases_detailsArray<OCI::DatabaseManagement::Models::JobDatabase>

The details of the Managed Databases where the job has to be executed.



64
65
66
# File 'lib/oci/database_management/models/job.rb', line 64

def managed_databases_details
  @managed_databases_details
end

#nameString

**[Required]** The display name of the job.

Returns:

  • (String)


48
49
50
# File 'lib/oci/database_management/models/job.rb', line 48

def name
  @name
end

#result_locationOCI::DatabaseManagement::Models::JobExecutionResultLocation



87
88
89
# File 'lib/oci/database_management/models/job.rb', line 87

def result_location
  @result_location
end

#schedule_detailsOCI::DatabaseManagement::Models::JobScheduleDetails



90
91
92
# File 'lib/oci/database_management/models/job.rb', line 90

def schedule_details
  @schedule_details
end

#schedule_typeString

**[Required]** The schedule type of the job.

Returns:

  • (String)


72
73
74
# File 'lib/oci/database_management/models/job.rb', line 72

def schedule_type
  @schedule_type
end

#submission_error_messageString

The error message that is returned if the job submission fails. Null is returned in all other scenarios.

Returns:

  • (String)


94
95
96
# File 'lib/oci/database_management/models/job.rb', line 94

def submission_error_message
  @submission_error_message
end

#time_createdDateTime

**[Required]** The date and time when the job was created.

Returns:

  • (DateTime)


98
99
100
# File 'lib/oci/database_management/models/job.rb', line 98

def time_created
  @time_created
end

#time_updatedDateTime

**[Required]** The date and time when the job was last updated.

Returns:

  • (DateTime)


102
103
104
# File 'lib/oci/database_management/models/job.rb', line 102

def time_updated
  @time_updated
end

#timeoutString

The job timeout duration, which is expressed like "1h 10m 15s".

Returns:

  • (String)


84
85
86
# File 'lib/oci/database_management/models/job.rb', line 84

def timeout
  @timeout
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/oci/database_management/models/job.rb', line 105

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'compartment_id': :'compartmentId',
    'name': :'name',
    'description': :'description',
    'managed_database_group_id': :'managedDatabaseGroupId',
    'managed_database_id': :'managedDatabaseId',
    'managed_databases_details': :'managedDatabasesDetails',
    'database_sub_type': :'databaseSubType',
    'schedule_type': :'scheduleType',
    'job_type': :'jobType',
    'lifecycle_state': :'lifecycleState',
    'timeout': :'timeout',
    'result_location': :'resultLocation',
    'schedule_details': :'scheduleDetails',
    'submission_error_message': :'submissionErrorMessage',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated'
    # rubocop:enable Style/SymbolLiteral
  }
end

.get_subtype(object_hash) ⇒ Object

Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.



159
160
161
162
163
164
165
166
# File 'lib/oci/database_management/models/job.rb', line 159

def self.get_subtype(object_hash)
  type = object_hash[:'jobType'] # rubocop:disable Style/SymbolLiteral

  return 'OCI::DatabaseManagement::Models::SqlJob' if type == 'SQL'

  # TODO: Log a warning when the subtype is not found.
  'OCI::DatabaseManagement::Models::Job'
end

.swagger_typesObject

Attribute type mapping.



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/oci/database_management/models/job.rb', line 130

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'compartment_id': :'String',
    'name': :'String',
    'description': :'String',
    'managed_database_group_id': :'String',
    'managed_database_id': :'String',
    'managed_databases_details': :'Array<OCI::DatabaseManagement::Models::JobDatabase>',
    'database_sub_type': :'String',
    'schedule_type': :'String',
    'job_type': :'String',
    'lifecycle_state': :'String',
    'timeout': :'String',
    'result_location': :'OCI::DatabaseManagement::Models::JobExecutionResultLocation',
    'schedule_details': :'OCI::DatabaseManagement::Models::JobScheduleDetails',
    'submission_error_message': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
# File 'lib/oci/database_management/models/job.rb', line 344

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    name == other.name &&
    description == other.description &&
    managed_database_group_id == other.managed_database_group_id &&
    managed_database_id == other.managed_database_id &&
    managed_databases_details == other.managed_databases_details &&
    database_sub_type == other.database_sub_type &&
    schedule_type == other.schedule_type &&
    job_type == other.job_type &&
    lifecycle_state == other.lifecycle_state &&
    timeout == other.timeout &&
    result_location == other.result_location &&
    schedule_details == other.schedule_details &&
    submission_error_message == other.submission_error_message &&
    time_created == other.time_created &&
    time_updated == other.time_updated
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
# File 'lib/oci/database_management/models/job.rb', line 390

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


370
371
372
# File 'lib/oci/database_management/models/job.rb', line 370

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



379
380
381
# File 'lib/oci/database_management/models/job.rb', line 379

def hash
  [id, compartment_id, name, description, managed_database_group_id, managed_database_id, managed_databases_details, database_sub_type, schedule_type, job_type, lifecycle_state, timeout, result_location, schedule_details, submission_error_message, time_created, time_updated].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



423
424
425
426
427
428
429
430
431
432
# File 'lib/oci/database_management/models/job.rb', line 423

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



417
418
419
# File 'lib/oci/database_management/models/job.rb', line 417

def to_s
  to_hash.to_s
end