Class: OCI::DatabaseManagement::Models::JobDatabase

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database_management/models/job_database.rb

Overview

The Managed Database on which the job is executed.

Constant Summary collapse

DATABASE_TYPE_ENUM =
[
  DATABASE_TYPE_EXTERNAL_SIDB = 'EXTERNAL_SIDB'.freeze,
  DATABASE_TYPE_EXTERNAL_RAC = 'EXTERNAL_RAC'.freeze,
  DATABASE_TYPE_CLOUD_SIDB = 'CLOUD_SIDB'.freeze,
  DATABASE_TYPE_CLOUD_RAC = 'CLOUD_RAC'.freeze,
  DATABASE_TYPE_SHARED = 'SHARED'.freeze,
  DATABASE_TYPE_DEDICATED = 'DEDICATED'.freeze,
  DATABASE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
DATABASE_SUB_TYPE_ENUM =
[
  DATABASE_SUB_TYPE_CDB = 'CDB'.freeze,
  DATABASE_SUB_TYPE_PDB = 'PDB'.freeze,
  DATABASE_SUB_TYPE_NON_CDB = 'NON_CDB'.freeze,
  DATABASE_SUB_TYPE_ACD = 'ACD'.freeze,
  DATABASE_SUB_TYPE_ADB = 'ADB'.freeze,
  DATABASE_SUB_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
DEPLOYMENT_TYPE_ENUM =
[
  DEPLOYMENT_TYPE_ONPREMISE = 'ONPREMISE'.freeze,
  DEPLOYMENT_TYPE_BM = 'BM'.freeze,
  DEPLOYMENT_TYPE_VM = 'VM'.freeze,
  DEPLOYMENT_TYPE_EXADATA = 'EXADATA'.freeze,
  DEPLOYMENT_TYPE_EXADATA_CC = 'EXADATA_CC'.freeze,
  DEPLOYMENT_TYPE_AUTONOMOUS = 'AUTONOMOUS'.freeze,
  DEPLOYMENT_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
WORKLOAD_TYPE_ENUM =
[
  WORKLOAD_TYPE_OLTP = 'OLTP'.freeze,
  WORKLOAD_TYPE_DW = 'DW'.freeze,
  WORKLOAD_TYPE_AJD = 'AJD'.freeze,
  WORKLOAD_TYPE_APEX = 'APEX'.freeze,
  WORKLOAD_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ JobDatabase

Initializes the object

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :name (String)

    The value to assign to the #name property

  • :database_type (String)

    The value to assign to the #database_type property

  • :database_sub_type (String)

    The value to assign to the #database_sub_type property

  • :deployment_type (String)

    The value to assign to the #deployment_type property

  • :is_cluster (BOOLEAN)

    The value to assign to the #is_cluster property

  • :workload_type (String)

    The value to assign to the #workload_type property



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/oci/database_management/models/job_database.rb', line 119

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.name = attributes[:'name'] if attributes[:'name']

  self.database_type = attributes[:'databaseType'] if attributes[:'databaseType']

  raise 'You cannot provide both :databaseType and :database_type' if attributes.key?(:'databaseType') && attributes.key?(:'database_type')

  self.database_type = attributes[:'database_type'] if attributes[:'database_type']

  self.database_sub_type = attributes[:'databaseSubType'] if attributes[:'databaseSubType']

  raise 'You cannot provide both :databaseSubType and :database_sub_type' if attributes.key?(:'databaseSubType') && attributes.key?(:'database_sub_type')

  self.database_sub_type = attributes[:'database_sub_type'] if attributes[:'database_sub_type']

  self.deployment_type = attributes[:'deploymentType'] if attributes[:'deploymentType']

  raise 'You cannot provide both :deploymentType and :deployment_type' if attributes.key?(:'deploymentType') && attributes.key?(:'deployment_type')

  self.deployment_type = attributes[:'deployment_type'] if attributes[:'deployment_type']

  self.is_cluster = attributes[:'isCluster'] unless attributes[:'isCluster'].nil?

  raise 'You cannot provide both :isCluster and :is_cluster' if attributes.key?(:'isCluster') && attributes.key?(:'is_cluster')

  self.is_cluster = attributes[:'is_cluster'] unless attributes[:'is_cluster'].nil?

  self.workload_type = attributes[:'workloadType'] if attributes[:'workloadType']

  raise 'You cannot provide both :workloadType and :workload_type' if attributes.key?(:'workloadType') && attributes.key?(:'workload_type')

  self.workload_type = attributes[:'workload_type'] if attributes[:'workload_type']
end

Instance Attribute Details

#database_sub_typeString

The subtype of the Oracle Database. Indicates whether the database is a Container Database, Pluggable Database, or a Non-container Database.



62
63
64
# File 'lib/oci/database_management/models/job_database.rb', line 62

def database_sub_type
  @database_sub_type
end

#database_typeString

The type of Oracle Database installation.



58
59
60
# File 'lib/oci/database_management/models/job_database.rb', line 58

def database_type
  @database_type
end

#deployment_typeString

A list of the supported infrastructure that can be used to deploy the database.



66
67
68
# File 'lib/oci/database_management/models/job_database.rb', line 66

def deployment_type
  @deployment_type
end

#idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Managed Database.



50
51
52
# File 'lib/oci/database_management/models/job_database.rb', line 50

def id
  @id
end

#is_clusterBOOLEAN

Indicates whether the Oracle Database is part of a cluster.



70
71
72
# File 'lib/oci/database_management/models/job_database.rb', line 70

def is_cluster
  @is_cluster
end

#nameString

[Required] The name of the Managed Database.



54
55
56
# File 'lib/oci/database_management/models/job_database.rb', line 54

def name
  @name
end

#workload_typeString

The workload type of the Autonomous Database.



74
75
76
# File 'lib/oci/database_management/models/job_database.rb', line 74

def workload_type
  @workload_type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/oci/database_management/models/job_database.rb', line 77

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'name': :'name',
    'database_type': :'databaseType',
    'database_sub_type': :'databaseSubType',
    'deployment_type': :'deploymentType',
    'is_cluster': :'isCluster',
    'workload_type': :'workloadType'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/oci/database_management/models/job_database.rb', line 92

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'name': :'String',
    'database_type': :'String',
    'database_sub_type': :'String',
    'deployment_type': :'String',
    'is_cluster': :'BOOLEAN',
    'workload_type': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.



219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/oci/database_management/models/job_database.rb', line 219

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    name == other.name &&
    database_type == other.database_type &&
    database_sub_type == other.database_sub_type &&
    deployment_type == other.deployment_type &&
    is_cluster == other.is_cluster &&
    workload_type == other.workload_type
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/oci/database_management/models/job_database.rb', line 255

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method


235
236
237
# File 'lib/oci/database_management/models/job_database.rb', line 235

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.



244
245
246
# File 'lib/oci/database_management/models/job_database.rb', line 244

def hash
  [id, name, database_type, database_sub_type, deployment_type, is_cluster, workload_type].hash
end

#to_hashHash

Returns the object in the form of hash



288
289
290
291
292
293
294
295
296
297
# File 'lib/oci/database_management/models/job_database.rb', line 288

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



282
283
284
# File 'lib/oci/database_management/models/job_database.rb', line 282

def to_s
  to_hash.to_s
end