Class: OCI::DatabaseManagement::Models::JobExecution

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database_management/models/job_execution.rb

Overview

The details of a job execution.

Constant Summary collapse

DATABASE_TYPE_ENUM =
[
  DATABASE_TYPE_EXTERNAL_SIDB = 'EXTERNAL_SIDB'.freeze,
  DATABASE_TYPE_EXTERNAL_RAC = 'EXTERNAL_RAC'.freeze,
  DATABASE_TYPE_CLOUD_SIDB = 'CLOUD_SIDB'.freeze,
  DATABASE_TYPE_CLOUD_RAC = 'CLOUD_RAC'.freeze,
  DATABASE_TYPE_SHARED = 'SHARED'.freeze,
  DATABASE_TYPE_DEDICATED = 'DEDICATED'.freeze,
  DATABASE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
DATABASE_SUB_TYPE_ENUM =
[
  DATABASE_SUB_TYPE_CDB = 'CDB'.freeze,
  DATABASE_SUB_TYPE_PDB = 'PDB'.freeze,
  DATABASE_SUB_TYPE_NON_CDB = 'NON_CDB'.freeze,
  DATABASE_SUB_TYPE_ACD = 'ACD'.freeze,
  DATABASE_SUB_TYPE_ADB = 'ADB'.freeze,
  DATABASE_SUB_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
DEPLOYMENT_TYPE_ENUM =
[
  DEPLOYMENT_TYPE_ONPREMISE = 'ONPREMISE'.freeze,
  DEPLOYMENT_TYPE_BM = 'BM'.freeze,
  DEPLOYMENT_TYPE_VM = 'VM'.freeze,
  DEPLOYMENT_TYPE_EXADATA = 'EXADATA'.freeze,
  DEPLOYMENT_TYPE_EXADATA_CC = 'EXADATA_CC'.freeze,
  DEPLOYMENT_TYPE_AUTONOMOUS = 'AUTONOMOUS'.freeze,
  DEPLOYMENT_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
WORKLOAD_TYPE_ENUM =
[
  WORKLOAD_TYPE_OLTP = 'OLTP'.freeze,
  WORKLOAD_TYPE_DW = 'DW'.freeze,
  WORKLOAD_TYPE_AJD = 'AJD'.freeze,
  WORKLOAD_TYPE_APEX = 'APEX'.freeze,
  WORKLOAD_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
STATUS_ENUM =
[
  STATUS_SUCCEEDED = 'SUCCEEDED'.freeze,
  STATUS_FAILED = 'FAILED'.freeze,
  STATUS_IN_PROGRESS = 'IN_PROGRESS'.freeze,
  STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ JobExecution

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'lib/oci/database_management/models/job_execution.rb', line 231

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.name = attributes[:'name'] if attributes[:'name']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.managed_database_group_id = attributes[:'managedDatabaseGroupId'] if attributes[:'managedDatabaseGroupId']

  raise 'You cannot provide both :managedDatabaseGroupId and :managed_database_group_id' if attributes.key?(:'managedDatabaseGroupId') && attributes.key?(:'managed_database_group_id')

  self.managed_database_group_id = attributes[:'managed_database_group_id'] if attributes[:'managed_database_group_id']

  self.managed_database_id = attributes[:'managedDatabaseId'] if attributes[:'managedDatabaseId']

  raise 'You cannot provide both :managedDatabaseId and :managed_database_id' if attributes.key?(:'managedDatabaseId') && attributes.key?(:'managed_database_id')

  self.managed_database_id = attributes[:'managed_database_id'] if attributes[:'managed_database_id']

  self.managed_database_name = attributes[:'managedDatabaseName'] if attributes[:'managedDatabaseName']

  raise 'You cannot provide both :managedDatabaseName and :managed_database_name' if attributes.key?(:'managedDatabaseName') && attributes.key?(:'managed_database_name')

  self.managed_database_name = attributes[:'managed_database_name'] if attributes[:'managed_database_name']

  self.database_type = attributes[:'databaseType'] if attributes[:'databaseType']

  raise 'You cannot provide both :databaseType and :database_type' if attributes.key?(:'databaseType') && attributes.key?(:'database_type')

  self.database_type = attributes[:'database_type'] if attributes[:'database_type']

  self.database_sub_type = attributes[:'databaseSubType'] if attributes[:'databaseSubType']

  raise 'You cannot provide both :databaseSubType and :database_sub_type' if attributes.key?(:'databaseSubType') && attributes.key?(:'database_sub_type')

  self.database_sub_type = attributes[:'database_sub_type'] if attributes[:'database_sub_type']

  self.deployment_type = attributes[:'deploymentType'] if attributes[:'deploymentType']

  raise 'You cannot provide both :deploymentType and :deployment_type' if attributes.key?(:'deploymentType') && attributes.key?(:'deployment_type')

  self.deployment_type = attributes[:'deployment_type'] if attributes[:'deployment_type']

  self.is_cluster = attributes[:'isCluster'] unless attributes[:'isCluster'].nil?

  raise 'You cannot provide both :isCluster and :is_cluster' if attributes.key?(:'isCluster') && attributes.key?(:'is_cluster')

  self.is_cluster = attributes[:'is_cluster'] unless attributes[:'is_cluster'].nil?

  self.workload_type = attributes[:'workloadType'] if attributes[:'workloadType']

  raise 'You cannot provide both :workloadType and :workload_type' if attributes.key?(:'workloadType') && attributes.key?(:'workload_type')

  self.workload_type = attributes[:'workload_type'] if attributes[:'workload_type']

  self.job_id = attributes[:'jobId'] if attributes[:'jobId']

  raise 'You cannot provide both :jobId and :job_id' if attributes.key?(:'jobId') && attributes.key?(:'job_id')

  self.job_id = attributes[:'job_id'] if attributes[:'job_id']

  self.job_name = attributes[:'jobName'] if attributes[:'jobName']

  raise 'You cannot provide both :jobName and :job_name' if attributes.key?(:'jobName') && attributes.key?(:'job_name')

  self.job_name = attributes[:'job_name'] if attributes[:'job_name']

  self.job_run_id = attributes[:'jobRunId'] if attributes[:'jobRunId']

  raise 'You cannot provide both :jobRunId and :job_run_id' if attributes.key?(:'jobRunId') && attributes.key?(:'job_run_id')

  self.job_run_id = attributes[:'job_run_id'] if attributes[:'job_run_id']

  self.status = attributes[:'status'] if attributes[:'status']

  self.error_message = attributes[:'errorMessage'] if attributes[:'errorMessage']

  raise 'You cannot provide both :errorMessage and :error_message' if attributes.key?(:'errorMessage') && attributes.key?(:'error_message')

  self.error_message = attributes[:'error_message'] if attributes[:'error_message']

  self.result_details = attributes[:'resultDetails'] if attributes[:'resultDetails']

  raise 'You cannot provide both :resultDetails and :result_details' if attributes.key?(:'resultDetails') && attributes.key?(:'result_details')

  self.result_details = attributes[:'result_details'] if attributes[:'result_details']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_completed = attributes[:'timeCompleted'] if attributes[:'timeCompleted']

  raise 'You cannot provide both :timeCompleted and :time_completed' if attributes.key?(:'timeCompleted') && attributes.key?(:'time_completed')

  self.time_completed = attributes[:'time_completed'] if attributes[:'time_completed']

  self.user_name = attributes[:'userName'] if attributes[:'userName']

  raise 'You cannot provide both :userName and :user_name' if attributes.key?(:'userName') && attributes.key?(:'user_name')

  self.user_name = attributes[:'user_name'] if attributes[:'user_name']

  self.sql_text = attributes[:'sqlText'] if attributes[:'sqlText']

  raise 'You cannot provide both :sqlText and :sql_text' if attributes.key?(:'sqlText') && attributes.key?(:'sql_text')

  self.sql_text = attributes[:'sql_text'] if attributes[:'sql_text']

  self.schedule_details = attributes[:'scheduleDetails'] if attributes[:'scheduleDetails']

  raise 'You cannot provide both :scheduleDetails and :schedule_details' if attributes.key?(:'scheduleDetails') && attributes.key?(:'schedule_details')

  self.schedule_details = attributes[:'schedule_details'] if attributes[:'schedule_details']
end

Instance Attribute Details

#compartment_idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment in which the parent job resides.

Returns:

  • (String)


65
66
67
# File 'lib/oci/database_management/models/job_execution.rb', line 65

def compartment_id
  @compartment_id
end

#database_sub_typeString

The subtype of the Oracle Database. Indicates whether the database is a Container Database, Pluggable Database, or a Non-container Database.

Returns:

  • (String)


85
86
87
# File 'lib/oci/database_management/models/job_execution.rb', line 85

def database_sub_type
  @database_sub_type
end

#database_typeString

The type of Oracle Database installation.

Returns:

  • (String)


81
82
83
# File 'lib/oci/database_management/models/job_execution.rb', line 81

def database_type
  @database_type
end

#deployment_typeString

A list of the supported infrastructure that can be used to deploy the database.

Returns:

  • (String)


89
90
91
# File 'lib/oci/database_management/models/job_execution.rb', line 89

def deployment_type
  @deployment_type
end

#error_messageString

The error message that is returned if the job execution fails. Null is returned if the job is still running or if the job execution is successful.

Returns:

  • (String)


119
120
121
# File 'lib/oci/database_management/models/job_execution.rb', line 119

def error_message
  @error_message
end

#idString

[Required] The identifier of the job execution.

Returns:

  • (String)


57
58
59
# File 'lib/oci/database_management/models/job_execution.rb', line 57

def id
  @id
end

#is_clusterBOOLEAN

Indicates whether the Oracle Database is part of a cluster.

Returns:

  • (BOOLEAN)


93
94
95
# File 'lib/oci/database_management/models/job_execution.rb', line 93

def is_cluster
  @is_cluster
end

#job_idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the parent job.

Returns:

  • (String)


101
102
103
# File 'lib/oci/database_management/models/job_execution.rb', line 101

def job_id
  @job_id
end

#job_nameString

[Required] The name of the parent job.

Returns:

  • (String)


105
106
107
# File 'lib/oci/database_management/models/job_execution.rb', line 105

def job_name
  @job_name
end

#job_run_idString

[Required] The identifier of the associated job run.

Returns:

  • (String)


109
110
111
# File 'lib/oci/database_management/models/job_execution.rb', line 109

def job_run_id
  @job_run_id
end

#managed_database_group_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Managed Database Group where the parent job has to be executed.

Returns:

  • (String)


69
70
71
# File 'lib/oci/database_management/models/job_execution.rb', line 69

def managed_database_group_id
  @managed_database_group_id
end

#managed_database_idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Managed Database associated with the job execution.

Returns:

  • (String)


73
74
75
# File 'lib/oci/database_management/models/job_execution.rb', line 73

def managed_database_id
  @managed_database_id
end

#managed_database_nameString

[Required] The name of the Managed Database associated with the job execution.

Returns:

  • (String)


77
78
79
# File 'lib/oci/database_management/models/job_execution.rb', line 77

def managed_database_name
  @managed_database_name
end

#nameString

[Required] The name of the job execution.

Returns:

  • (String)


61
62
63
# File 'lib/oci/database_management/models/job_execution.rb', line 61

def name
  @name
end

#result_detailsOCI::DatabaseManagement::Models::JobExecutionResultDetails



122
123
124
# File 'lib/oci/database_management/models/job_execution.rb', line 122

def result_details
  @result_details
end

#schedule_detailsOCI::DatabaseManagement::Models::JobScheduleDetails



141
142
143
# File 'lib/oci/database_management/models/job_execution.rb', line 141

def schedule_details
  @schedule_details
end

#sql_textString

The SQL text executed as part of the job.

Returns:

  • (String)


138
139
140
# File 'lib/oci/database_management/models/job_execution.rb', line 138

def sql_text
  @sql_text
end

#statusString

[Required] The status of the job execution.

Returns:

  • (String)


113
114
115
# File 'lib/oci/database_management/models/job_execution.rb', line 113

def status
  @status
end

#time_completedDateTime

The date and time when the job execution completed.

Returns:

  • (DateTime)


130
131
132
# File 'lib/oci/database_management/models/job_execution.rb', line 130

def time_completed
  @time_completed
end

#time_createdDateTime

[Required] The date and time when the job execution was created.

Returns:

  • (DateTime)


126
127
128
# File 'lib/oci/database_management/models/job_execution.rb', line 126

def time_created
  @time_created
end

#user_nameString

The database user name used to execute the SQL job.

Returns:

  • (String)


134
135
136
# File 'lib/oci/database_management/models/job_execution.rb', line 134

def user_name
  @user_name
end

#workload_typeString

The workload type of the Autonomous Database.

Returns:

  • (String)


97
98
99
# File 'lib/oci/database_management/models/job_execution.rb', line 97

def workload_type
  @workload_type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/oci/database_management/models/job_execution.rb', line 144

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'name': :'name',
    'compartment_id': :'compartmentId',
    'managed_database_group_id': :'managedDatabaseGroupId',
    'managed_database_id': :'managedDatabaseId',
    'managed_database_name': :'managedDatabaseName',
    'database_type': :'databaseType',
    'database_sub_type': :'databaseSubType',
    'deployment_type': :'deploymentType',
    'is_cluster': :'isCluster',
    'workload_type': :'workloadType',
    'job_id': :'jobId',
    'job_name': :'jobName',
    'job_run_id': :'jobRunId',
    'status': :'status',
    'error_message': :'errorMessage',
    'result_details': :'resultDetails',
    'time_created': :'timeCreated',
    'time_completed': :'timeCompleted',
    'user_name': :'userName',
    'sql_text': :'sqlText',
    'schedule_details': :'scheduleDetails'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/oci/database_management/models/job_execution.rb', line 174

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'name': :'String',
    'compartment_id': :'String',
    'managed_database_group_id': :'String',
    'managed_database_id': :'String',
    'managed_database_name': :'String',
    'database_type': :'String',
    'database_sub_type': :'String',
    'deployment_type': :'String',
    'is_cluster': :'BOOLEAN',
    'workload_type': :'String',
    'job_id': :'String',
    'job_name': :'String',
    'job_run_id': :'String',
    'status': :'String',
    'error_message': :'String',
    'result_details': :'OCI::DatabaseManagement::Models::JobExecutionResultDetails',
    'time_created': :'DateTime',
    'time_completed': :'DateTime',
    'user_name': :'String',
    'sql_text': :'String',
    'schedule_details': :'OCI::DatabaseManagement::Models::JobScheduleDetails'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
# File 'lib/oci/database_management/models/job_execution.rb', line 430

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    name == other.name &&
    compartment_id == other.compartment_id &&
    managed_database_group_id == other.managed_database_group_id &&
    managed_database_id == other.managed_database_id &&
    managed_database_name == other.managed_database_name &&
    database_type == other.database_type &&
    database_sub_type == other.database_sub_type &&
    deployment_type == other.deployment_type &&
    is_cluster == other.is_cluster &&
    workload_type == other.workload_type &&
    job_id == other.job_id &&
    job_name == other.job_name &&
    job_run_id == other.job_run_id &&
    status == other.status &&
    error_message == other.error_message &&
    result_details == other.result_details &&
    time_created == other.time_created &&
    time_completed == other.time_completed &&
    user_name == other.user_name &&
    sql_text == other.sql_text &&
    schedule_details == other.schedule_details
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
# File 'lib/oci/database_management/models/job_execution.rb', line 481

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


461
462
463
# File 'lib/oci/database_management/models/job_execution.rb', line 461

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



470
471
472
# File 'lib/oci/database_management/models/job_execution.rb', line 470

def hash
  [id, name, compartment_id, managed_database_group_id, managed_database_id, managed_database_name, database_type, database_sub_type, deployment_type, is_cluster, workload_type, job_id, job_name, job_run_id, status, error_message, result_details, time_created, time_completed, user_name, sql_text, schedule_details].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



514
515
516
517
518
519
520
521
522
523
# File 'lib/oci/database_management/models/job_execution.rb', line 514

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



508
509
510
# File 'lib/oci/database_management/models/job_execution.rb', line 508

def to_s
  to_hash.to_s
end