Class: DatabaseManagement::Models::JobSummary
- Inherits:
-
Object
- Object
- DatabaseManagement::Models::JobSummary
- Defined in:
- lib/oci/database_management/models/job_summary.rb
Overview
A summary of the job.
Constant Summary collapse
- DATABASE_SUB_TYPE_ENUM =
[ DATABASE_SUB_TYPE_CDB = 'CDB'.freeze, DATABASE_SUB_TYPE_PDB = 'PDB'.freeze, DATABASE_SUB_TYPE_NON_CDB = 'NON_CDB'.freeze, DATABASE_SUB_TYPE_ACD = 'ACD'.freeze, DATABASE_SUB_TYPE_ADB = 'ADB'.freeze, DATABASE_SUB_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- JOB_TYPE_ENUM =
[ JOB_TYPE_SQL = 'SQL'.freeze, JOB_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment in which the job resides.
-
#database_sub_type ⇒ String
The subtype of the Oracle Database where the job has to be executed.
-
#description ⇒ String
The description of the job.
-
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the job.
-
#job_type ⇒ String
**[Required]** The type of job.
-
#lifecycle_state ⇒ String
**[Required]** The lifecycle state of the job.
-
#managed_database_group_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Managed Database Group where the job has to be executed.
-
#managed_database_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Managed Database where the job has to be executed.
-
#name ⇒ String
**[Required]** The display name of the job.
- #schedule_details ⇒ OCI::DatabaseManagement::Models::JobScheduleDetails
-
#schedule_type ⇒ String
**[Required]** The schedule type of the job.
-
#submission_error_message ⇒ String
The error message that is returned if the job submission fails.
-
#time_created ⇒ DateTime
**[Required]** The date and time when the job was created.
-
#time_updated ⇒ DateTime
**[Required]** The date and time when the job was last updated.
-
#timeout ⇒ String
The job timeout duration, which is expressed like "1h 10m 15s".
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ JobSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ JobSummary
Initializes the object
151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/oci/database_management/models/job_summary.rb', line 151 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.managed_database_group_id = attributes[:'managedDatabaseGroupId'] if attributes[:'managedDatabaseGroupId'] raise 'You cannot provide both :managedDatabaseGroupId and :managed_database_group_id' if attributes.key?(:'managedDatabaseGroupId') && attributes.key?(:'managed_database_group_id') self.managed_database_group_id = attributes[:'managed_database_group_id'] if attributes[:'managed_database_group_id'] self.managed_database_id = attributes[:'managedDatabaseId'] if attributes[:'managedDatabaseId'] raise 'You cannot provide both :managedDatabaseId and :managed_database_id' if attributes.key?(:'managedDatabaseId') && attributes.key?(:'managed_database_id') self.managed_database_id = attributes[:'managed_database_id'] if attributes[:'managed_database_id'] self.database_sub_type = attributes[:'databaseSubType'] if attributes[:'databaseSubType'] raise 'You cannot provide both :databaseSubType and :database_sub_type' if attributes.key?(:'databaseSubType') && attributes.key?(:'database_sub_type') self.database_sub_type = attributes[:'database_sub_type'] if attributes[:'database_sub_type'] self.schedule_type = attributes[:'scheduleType'] if attributes[:'scheduleType'] raise 'You cannot provide both :scheduleType and :schedule_type' if attributes.key?(:'scheduleType') && attributes.key?(:'schedule_type') self.schedule_type = attributes[:'schedule_type'] if attributes[:'schedule_type'] self.schedule_details = attributes[:'scheduleDetails'] if attributes[:'scheduleDetails'] raise 'You cannot provide both :scheduleDetails and :schedule_details' if attributes.key?(:'scheduleDetails') && attributes.key?(:'schedule_details') self.schedule_details = attributes[:'schedule_details'] if attributes[:'schedule_details'] self.job_type = attributes[:'jobType'] if attributes[:'jobType'] raise 'You cannot provide both :jobType and :job_type' if attributes.key?(:'jobType') && attributes.key?(:'job_type') self.job_type = attributes[:'job_type'] if attributes[:'job_type'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.timeout = attributes[:'timeout'] if attributes[:'timeout'] self. = attributes[:'submissionErrorMessage'] if attributes[:'submissionErrorMessage'] raise 'You cannot provide both :submissionErrorMessage and :submission_error_message' if attributes.key?(:'submissionErrorMessage') && attributes.key?(:'submission_error_message') self. = attributes[:'submission_error_message'] if attributes[:'submission_error_message'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment in which the job resides.
31 32 33 |
# File 'lib/oci/database_management/models/job_summary.rb', line 31 def compartment_id @compartment_id end |
#database_sub_type ⇒ String
The subtype of the Oracle Database where the job has to be executed. Only applicable when managedDatabaseGroupId is provided.
51 52 53 |
# File 'lib/oci/database_management/models/job_summary.rb', line 51 def database_sub_type @database_sub_type end |
#description ⇒ String
The description of the job.
39 40 41 |
# File 'lib/oci/database_management/models/job_summary.rb', line 39 def description @description end |
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the job.
27 28 29 |
# File 'lib/oci/database_management/models/job_summary.rb', line 27 def id @id end |
#job_type ⇒ String
**[Required]** The type of job.
62 63 64 |
# File 'lib/oci/database_management/models/job_summary.rb', line 62 def job_type @job_type end |
#lifecycle_state ⇒ String
**[Required]** The lifecycle state of the job.
66 67 68 |
# File 'lib/oci/database_management/models/job_summary.rb', line 66 def lifecycle_state @lifecycle_state end |
#managed_database_group_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Managed Database Group where the job has to be executed.
43 44 45 |
# File 'lib/oci/database_management/models/job_summary.rb', line 43 def managed_database_group_id @managed_database_group_id end |
#managed_database_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Managed Database where the job has to be executed.
47 48 49 |
# File 'lib/oci/database_management/models/job_summary.rb', line 47 def managed_database_id @managed_database_id end |
#name ⇒ String
**[Required]** The display name of the job.
35 36 37 |
# File 'lib/oci/database_management/models/job_summary.rb', line 35 def name @name end |
#schedule_details ⇒ OCI::DatabaseManagement::Models::JobScheduleDetails
58 59 60 |
# File 'lib/oci/database_management/models/job_summary.rb', line 58 def schedule_details @schedule_details end |
#schedule_type ⇒ String
**[Required]** The schedule type of the job.
55 56 57 |
# File 'lib/oci/database_management/models/job_summary.rb', line 55 def schedule_type @schedule_type end |
#submission_error_message ⇒ String
The error message that is returned if the job submission fails. Null is returned in all other scenarios.
74 75 76 |
# File 'lib/oci/database_management/models/job_summary.rb', line 74 def @submission_error_message end |
#time_created ⇒ DateTime
**[Required]** The date and time when the job was created.
78 79 80 |
# File 'lib/oci/database_management/models/job_summary.rb', line 78 def time_created @time_created end |
#time_updated ⇒ DateTime
**[Required]** The date and time when the job was last updated.
82 83 84 |
# File 'lib/oci/database_management/models/job_summary.rb', line 82 def time_updated @time_updated end |
#timeout ⇒ String
The job timeout duration, which is expressed like "1h 10m 15s".
70 71 72 |
# File 'lib/oci/database_management/models/job_summary.rb', line 70 def timeout @timeout end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/oci/database_management/models/job_summary.rb', line 85 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'name': :'name', 'description': :'description', 'managed_database_group_id': :'managedDatabaseGroupId', 'managed_database_id': :'managedDatabaseId', 'database_sub_type': :'databaseSubType', 'schedule_type': :'scheduleType', 'schedule_details': :'scheduleDetails', 'job_type': :'jobType', 'lifecycle_state': :'lifecycleState', 'timeout': :'timeout', 'submission_error_message': :'submissionErrorMessage', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/oci/database_management/models/job_summary.rb', line 108 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'name': :'String', 'description': :'String', 'managed_database_group_id': :'String', 'managed_database_id': :'String', 'database_sub_type': :'String', 'schedule_type': :'String', 'schedule_details': :'OCI::DatabaseManagement::Models::JobScheduleDetails', 'job_type': :'String', 'lifecycle_state': :'String', 'timeout': :'String', 'submission_error_message': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/oci/database_management/models/job_summary.rb', line 265 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && name == other.name && description == other.description && managed_database_group_id == other.managed_database_group_id && managed_database_id == other.managed_database_id && database_sub_type == other.database_sub_type && schedule_type == other.schedule_type && schedule_details == other.schedule_details && job_type == other.job_type && lifecycle_state == other.lifecycle_state && timeout == other.timeout && == other. && time_created == other.time_created && time_updated == other.time_updated end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 |
# File 'lib/oci/database_management/models/job_summary.rb', line 309 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
289 290 291 |
# File 'lib/oci/database_management/models/job_summary.rb', line 289 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
298 299 300 |
# File 'lib/oci/database_management/models/job_summary.rb', line 298 def hash [id, compartment_id, name, description, managed_database_group_id, managed_database_id, database_sub_type, schedule_type, schedule_details, job_type, lifecycle_state, timeout, , time_created, time_updated].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
342 343 344 345 346 347 348 349 350 351 |
# File 'lib/oci/database_management/models/job_summary.rb', line 342 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
336 337 338 |
# File 'lib/oci/database_management/models/job_summary.rb', line 336 def to_s to_hash.to_s end |