Class: OCI::DatabaseManagement::Models::ManagedDatabaseCredential
- Inherits:
-
Object
- Object
- OCI::DatabaseManagement::Models::ManagedDatabaseCredential
- Defined in:
- lib/oci/database_management/models/managed_database_credential.rb
Overview
The credential used to connect to the Managed Database and obtain the details of the optimizer statistics tasks. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
ManagedDatabasePasswordCredential, ManagedDatabaseSecretCredential
Constant Summary collapse
- CREDENTIAL_TYPE_ENUM =
[ CREDENTIAL_TYPE_SECRET = 'SECRET'.freeze, CREDENTIAL_TYPE_PASSWORD = 'PASSWORD'.freeze ].freeze
- ROLE_ENUM =
[ ROLE_NORMAL = 'NORMAL'.freeze, ROLE_SYSDBA = 'SYSDBA'.freeze ].freeze
Instance Attribute Summary collapse
-
#credential_type ⇒ String
**[Required]** Indicates the type of credential required to retrieve the details of the optimizer statistics tasks.
-
#role ⇒ String
**[Required]** The role of the database user.
-
#username ⇒ String
**[Required]** The user name used to connect to the database.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ManagedDatabaseCredential
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ManagedDatabaseCredential
Initializes the object
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/oci/database_management/models/managed_database_credential.rb', line 80 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.credential_type = attributes[:'credentialType'] if attributes[:'credentialType'] raise 'You cannot provide both :credentialType and :credential_type' if attributes.key?(:'credentialType') && attributes.key?(:'credential_type') self.credential_type = attributes[:'credential_type'] if attributes[:'credential_type'] self.username = attributes[:'username'] if attributes[:'username'] self.role = attributes[:'role'] if attributes[:'role'] end |
Instance Attribute Details
#credential_type ⇒ String
**[Required]** Indicates the type of credential required to retrieve the details of the optimizer statistics tasks.
23 24 25 |
# File 'lib/oci/database_management/models/managed_database_credential.rb', line 23 def credential_type @credential_type end |
#role ⇒ String
**[Required]** The role of the database user.
31 32 33 |
# File 'lib/oci/database_management/models/managed_database_credential.rb', line 31 def role @role end |
#username ⇒ String
**[Required]** The user name used to connect to the database.
27 28 29 |
# File 'lib/oci/database_management/models/managed_database_credential.rb', line 27 def username @username end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 |
# File 'lib/oci/database_management/models/managed_database_credential.rb', line 34 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'credential_type': :'credentialType', 'username': :'username', 'role': :'role' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
60 61 62 63 64 65 66 67 68 |
# File 'lib/oci/database_management/models/managed_database_credential.rb', line 60 def self.get_subtype(object_hash) type = object_hash[:'credentialType'] # rubocop:disable Style/SymbolLiteral return 'OCI::DatabaseManagement::Models::ManagedDatabasePasswordCredential' if type == 'PASSWORD' return 'OCI::DatabaseManagement::Models::ManagedDatabaseSecretCredential' if type == 'SECRET' # TODO: Log a warning when the subtype is not found. 'OCI::DatabaseManagement::Models::ManagedDatabaseCredential' end |
.swagger_types ⇒ Object
Attribute type mapping.
45 46 47 48 49 50 51 52 53 |
# File 'lib/oci/database_management/models/managed_database_credential.rb', line 45 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'credential_type': :'String', 'username': :'String', 'role': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
120 121 122 123 124 125 126 127 |
# File 'lib/oci/database_management/models/managed_database_credential.rb', line 120 def ==(other) return true if equal?(other) self.class == other.class && credential_type == other.credential_type && username == other.username && role == other.role end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/oci/database_management/models/managed_database_credential.rb', line 152 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
132 133 134 |
# File 'lib/oci/database_management/models/managed_database_credential.rb', line 132 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
141 142 143 |
# File 'lib/oci/database_management/models/managed_database_credential.rb', line 141 def hash [credential_type, username, role].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
185 186 187 188 189 190 191 192 193 194 |
# File 'lib/oci/database_management/models/managed_database_credential.rb', line 185 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
179 180 181 |
# File 'lib/oci/database_management/models/managed_database_credential.rb', line 179 def to_s to_hash.to_s end |