Class: OCI::DatabaseManagement::Models::ManagedDatabaseGroup

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database_management/models/managed_database_group.rb

Overview

The details of a Managed Database Group.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ManagedDatabaseGroup

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/oci/database_management/models/managed_database_group.rb', line 99

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.name = attributes[:'name'] if attributes[:'name']

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.description = attributes[:'description'] if attributes[:'description']

  self.managed_databases = attributes[:'managedDatabases'] if attributes[:'managedDatabases']

  raise 'You cannot provide both :managedDatabases and :managed_databases' if attributes.key?(:'managedDatabases') && attributes.key?(:'managed_databases')

  self.managed_databases = attributes[:'managed_databases'] if attributes[:'managed_databases']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']
end

Instance Attribute Details

#compartment_idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.

Returns:

  • (String)


31
32
33
# File 'lib/oci/database_management/models/managed_database_group.rb', line 31

def compartment_id
  @compartment_id
end

#descriptionString

The information specified by the user about the Managed Database Group.

Returns:

  • (String)


35
36
37
# File 'lib/oci/database_management/models/managed_database_group.rb', line 35

def description
  @description
end

#idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Managed Database Group.

Returns:

  • (String)


27
28
29
# File 'lib/oci/database_management/models/managed_database_group.rb', line 27

def id
  @id
end

#lifecycle_stateString

[Required] The current lifecycle state of the Managed Database Group.

Returns:

  • (String)


43
44
45
# File 'lib/oci/database_management/models/managed_database_group.rb', line 43

def lifecycle_state
  @lifecycle_state
end

#managed_databasesArray<OCI::DatabaseManagement::Models::ChildDatabase>

[Required] A list of Managed Databases in the Managed Database Group.



39
40
41
# File 'lib/oci/database_management/models/managed_database_group.rb', line 39

def managed_databases
  @managed_databases
end

#nameString

[Required] The name of the Managed Database Group.

Returns:

  • (String)


23
24
25
# File 'lib/oci/database_management/models/managed_database_group.rb', line 23

def name
  @name
end

#time_createdDateTime

[Required] The date and time the Managed Database Group was created.

Returns:

  • (DateTime)


47
48
49
# File 'lib/oci/database_management/models/managed_database_group.rb', line 47

def time_created
  @time_created
end

#time_updatedDateTime

The date and time the Managed Database Group was last updated.

Returns:

  • (DateTime)


51
52
53
# File 'lib/oci/database_management/models/managed_database_group.rb', line 51

def time_updated
  @time_updated
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/oci/database_management/models/managed_database_group.rb', line 54

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'name': :'name',
    'id': :'id',
    'compartment_id': :'compartmentId',
    'description': :'description',
    'managed_databases': :'managedDatabases',
    'lifecycle_state': :'lifecycleState',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/oci/database_management/models/managed_database_group.rb', line 70

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'name': :'String',
    'id': :'String',
    'compartment_id': :'String',
    'description': :'String',
    'managed_databases': :'Array<OCI::DatabaseManagement::Models::ChildDatabase>',
    'lifecycle_state': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/oci/database_management/models/managed_database_group.rb', line 162

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    name == other.name &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    description == other.description &&
    managed_databases == other.managed_databases &&
    lifecycle_state == other.lifecycle_state &&
    time_created == other.time_created &&
    time_updated == other.time_updated
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/oci/database_management/models/managed_database_group.rb', line 199

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


179
180
181
# File 'lib/oci/database_management/models/managed_database_group.rb', line 179

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



188
189
190
# File 'lib/oci/database_management/models/managed_database_group.rb', line 188

def hash
  [name, id, compartment_id, description, managed_databases, lifecycle_state, time_created, time_updated].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



232
233
234
235
236
237
238
239
240
241
# File 'lib/oci/database_management/models/managed_database_group.rb', line 232

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



226
227
228
# File 'lib/oci/database_management/models/managed_database_group.rb', line 226

def to_s
  to_hash.to_s
end