Class: OCI::DatabaseManagement::Models::ManagedDatabaseGroupSummary
- Inherits:
-
Object
- Object
- OCI::DatabaseManagement::Models::ManagedDatabaseGroupSummary
- Defined in:
- lib/oci/database_management/models/managed_database_group_summary.rb
Overview
A group of Managed Databases that will be managed together.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
-
#description ⇒ String
The information specified by the user about the Managed Database Group.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Managed Database Group.
-
#lifecycle_state ⇒ String
[Required] The current lifecycle state of the Managed Database Group.
-
#managed_database_count ⇒ Integer
[Required] The number of Managed Databases in the Managed Database Group.
-
#name ⇒ String
[Required] The name of the Managed Database Group.
-
#time_created ⇒ DateTime
[Required] The date and time the Managed Database Group was created.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ManagedDatabaseGroupSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ManagedDatabaseGroupSummary
Initializes the object
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/oci/database_management/models/managed_database_group_summary.rb', line 92 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.description = attributes[:'description'] if attributes[:'description'] self.managed_database_count = attributes[:'managedDatabaseCount'] if attributes[:'managedDatabaseCount'] raise 'You cannot provide both :managedDatabaseCount and :managed_database_count' if attributes.key?(:'managedDatabaseCount') && attributes.key?(:'managed_database_count') self.managed_database_count = attributes[:'managed_database_count'] if attributes[:'managed_database_count'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
31 32 33 |
# File 'lib/oci/database_management/models/managed_database_group_summary.rb', line 31 def compartment_id @compartment_id end |
#description ⇒ String
The information specified by the user about the Managed Database Group.
35 36 37 |
# File 'lib/oci/database_management/models/managed_database_group_summary.rb', line 35 def description @description end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Managed Database Group.
27 28 29 |
# File 'lib/oci/database_management/models/managed_database_group_summary.rb', line 27 def id @id end |
#lifecycle_state ⇒ String
[Required] The current lifecycle state of the Managed Database Group.
43 44 45 |
# File 'lib/oci/database_management/models/managed_database_group_summary.rb', line 43 def lifecycle_state @lifecycle_state end |
#managed_database_count ⇒ Integer
[Required] The number of Managed Databases in the Managed Database Group.
39 40 41 |
# File 'lib/oci/database_management/models/managed_database_group_summary.rb', line 39 def managed_database_count @managed_database_count end |
#name ⇒ String
[Required] The name of the Managed Database Group.
23 24 25 |
# File 'lib/oci/database_management/models/managed_database_group_summary.rb', line 23 def name @name end |
#time_created ⇒ DateTime
[Required] The date and time the Managed Database Group was created.
47 48 49 |
# File 'lib/oci/database_management/models/managed_database_group_summary.rb', line 47 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/oci/database_management/models/managed_database_group_summary.rb', line 50 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'id': :'id', 'compartment_id': :'compartmentId', 'description': :'description', 'managed_database_count': :'managedDatabaseCount', 'lifecycle_state': :'lifecycleState', 'time_created': :'timeCreated' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/oci/database_management/models/managed_database_group_summary.rb', line 65 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'id': :'String', 'compartment_id': :'String', 'description': :'String', 'managed_database_count': :'Integer', 'lifecycle_state': :'String', 'time_created': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/oci/database_management/models/managed_database_group_summary.rb', line 149 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && id == other.id && compartment_id == other.compartment_id && description == other.description && managed_database_count == other.managed_database_count && lifecycle_state == other.lifecycle_state && time_created == other.time_created end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/oci/database_management/models/managed_database_group_summary.rb', line 185 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
165 166 167 |
# File 'lib/oci/database_management/models/managed_database_group_summary.rb', line 165 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
174 175 176 |
# File 'lib/oci/database_management/models/managed_database_group_summary.rb', line 174 def hash [name, id, compartment_id, description, managed_database_count, lifecycle_state, time_created].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
218 219 220 221 222 223 224 225 226 227 |
# File 'lib/oci/database_management/models/managed_database_group_summary.rb', line 218 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
212 213 214 |
# File 'lib/oci/database_management/models/managed_database_group_summary.rb', line 212 def to_s to_hash.to_s end |