Class: OCI::DatabaseManagement::Models::MetricDataPoint
- Inherits:
-
Object
- Object
- OCI::DatabaseManagement::Models::MetricDataPoint
- Defined in:
- lib/oci/database_management/models/metric_data_point.rb
Overview
The metric values with dimension details.
Instance Attribute Summary collapse
-
#dimensions ⇒ Array<OCI::DatabaseManagement::Models::MetricDimensionDefinition>
The dimensions of the metric.
-
#unit ⇒ String
The unit of the metric value.
-
#value ⇒ Float
The value of the metric.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MetricDataPoint
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ MetricDataPoint
Initializes the object
53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/oci/database_management/models/metric_data_point.rb', line 53 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.value = attributes[:'value'] if attributes[:'value'] self.unit = attributes[:'unit'] if attributes[:'unit'] self.dimensions = attributes[:'dimensions'] if attributes[:'dimensions'] end |
Instance Attribute Details
#dimensions ⇒ Array<OCI::DatabaseManagement::Models::MetricDimensionDefinition>
The dimensions of the metric.
20 21 22 |
# File 'lib/oci/database_management/models/metric_data_point.rb', line 20 def dimensions @dimensions end |
#unit ⇒ String
The unit of the metric value.
16 17 18 |
# File 'lib/oci/database_management/models/metric_data_point.rb', line 16 def unit @unit end |
#value ⇒ Float
The value of the metric.
12 13 14 |
# File 'lib/oci/database_management/models/metric_data_point.rb', line 12 def value @value end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
23 24 25 26 27 28 29 30 31 |
# File 'lib/oci/database_management/models/metric_data_point.rb', line 23 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'value': :'value', 'unit': :'unit', 'dimensions': :'dimensions' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
34 35 36 37 38 39 40 41 42 |
# File 'lib/oci/database_management/models/metric_data_point.rb', line 34 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'value': :'Float', 'unit': :'String', 'dimensions': :'Array<OCI::DatabaseManagement::Models::MetricDimensionDefinition>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
73 74 75 76 77 78 79 80 |
# File 'lib/oci/database_management/models/metric_data_point.rb', line 73 def ==(other) return true if equal?(other) self.class == other.class && value == other.value && unit == other.unit && dimensions == other.dimensions end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/oci/database_management/models/metric_data_point.rb', line 105 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
85 86 87 |
# File 'lib/oci/database_management/models/metric_data_point.rb', line 85 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
94 95 96 |
# File 'lib/oci/database_management/models/metric_data_point.rb', line 94 def hash [value, unit, dimensions].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
138 139 140 141 142 143 144 145 146 147 |
# File 'lib/oci/database_management/models/metric_data_point.rb', line 138 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
132 133 134 |
# File 'lib/oci/database_management/models/metric_data_point.rb', line 132 def to_s to_hash.to_s end |