Class: OCI::DatabaseManagement::Models::MetricStatisticsDefinition
- Inherits:
-
Object
- Object
- OCI::DatabaseManagement::Models::MetricStatisticsDefinition
- Defined in:
- lib/oci/database_management/models/metric_statistics_definition.rb
Overview
The metric statistics values with dimension details.
Instance Attribute Summary collapse
-
#dimensions ⇒ Array<OCI::DatabaseManagement::Models::MetricDimensionDefinition>
The dimensions of the metric.
-
#lower_quartile ⇒ Float
The first quartile value of the metric.
-
#max ⇒ Float
The maximum value of the metric.
-
#median ⇒ Float
The median value of the metric.
-
#min ⇒ Float
The minimum value of the metric.
-
#unit ⇒ String
The unit of the metric value.
-
#upper_quartile ⇒ Float
The third quartile value of the metric.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MetricStatisticsDefinition
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ MetricStatisticsDefinition
Initializes the object
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/oci/database_management/models/metric_statistics_definition.rb', line 81 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.min = attributes[:'min'] if attributes[:'min'] self.max = attributes[:'max'] if attributes[:'max'] self.median = attributes[:'median'] if attributes[:'median'] self.lower_quartile = attributes[:'lowerQuartile'] if attributes[:'lowerQuartile'] raise 'You cannot provide both :lowerQuartile and :lower_quartile' if attributes.key?(:'lowerQuartile') && attributes.key?(:'lower_quartile') self.lower_quartile = attributes[:'lower_quartile'] if attributes[:'lower_quartile'] self.upper_quartile = attributes[:'upperQuartile'] if attributes[:'upperQuartile'] raise 'You cannot provide both :upperQuartile and :upper_quartile' if attributes.key?(:'upperQuartile') && attributes.key?(:'upper_quartile') self.upper_quartile = attributes[:'upper_quartile'] if attributes[:'upper_quartile'] self.unit = attributes[:'unit'] if attributes[:'unit'] self.dimensions = attributes[:'dimensions'] if attributes[:'dimensions'] end |
Instance Attribute Details
#dimensions ⇒ Array<OCI::DatabaseManagement::Models::MetricDimensionDefinition>
The dimensions of the metric.
36 37 38 |
# File 'lib/oci/database_management/models/metric_statistics_definition.rb', line 36 def dimensions @dimensions end |
#lower_quartile ⇒ Float
The first quartile value of the metric.
24 25 26 |
# File 'lib/oci/database_management/models/metric_statistics_definition.rb', line 24 def lower_quartile @lower_quartile end |
#max ⇒ Float
The maximum value of the metric.
16 17 18 |
# File 'lib/oci/database_management/models/metric_statistics_definition.rb', line 16 def max @max end |
#median ⇒ Float
The median value of the metric.
20 21 22 |
# File 'lib/oci/database_management/models/metric_statistics_definition.rb', line 20 def median @median end |
#min ⇒ Float
The minimum value of the metric.
12 13 14 |
# File 'lib/oci/database_management/models/metric_statistics_definition.rb', line 12 def min @min end |
#unit ⇒ String
The unit of the metric value.
32 33 34 |
# File 'lib/oci/database_management/models/metric_statistics_definition.rb', line 32 def unit @unit end |
#upper_quartile ⇒ Float
The third quartile value of the metric.
28 29 30 |
# File 'lib/oci/database_management/models/metric_statistics_definition.rb', line 28 def upper_quartile @upper_quartile end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/oci/database_management/models/metric_statistics_definition.rb', line 39 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'min': :'min', 'max': :'max', 'median': :'median', 'lower_quartile': :'lowerQuartile', 'upper_quartile': :'upperQuartile', 'unit': :'unit', 'dimensions': :'dimensions' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/oci/database_management/models/metric_statistics_definition.rb', line 54 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'min': :'Float', 'max': :'Float', 'median': :'Float', 'lower_quartile': :'Float', 'upper_quartile': :'Float', 'unit': :'String', 'dimensions': :'Array<OCI::DatabaseManagement::Models::MetricDimensionDefinition>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/oci/database_management/models/metric_statistics_definition.rb', line 117 def ==(other) return true if equal?(other) self.class == other.class && min == other.min && max == other.max && median == other.median && lower_quartile == other.lower_quartile && upper_quartile == other.upper_quartile && unit == other.unit && dimensions == other.dimensions end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/oci/database_management/models/metric_statistics_definition.rb', line 153 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
133 134 135 |
# File 'lib/oci/database_management/models/metric_statistics_definition.rb', line 133 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
142 143 144 |
# File 'lib/oci/database_management/models/metric_statistics_definition.rb', line 142 def hash [min, max, median, lower_quartile, upper_quartile, unit, dimensions].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
186 187 188 189 190 191 192 193 194 195 |
# File 'lib/oci/database_management/models/metric_statistics_definition.rb', line 186 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
180 181 182 |
# File 'lib/oci/database_management/models/metric_statistics_definition.rb', line 180 def to_s to_hash.to_s end |