Class: OCI::DatabaseManagement::Models::ProxiedForUserSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database_management/models/proxied_for_user_summary.rb

Overview

A collection of Users for which the current user acts as proxy.

Constant Summary collapse

AUTHENTICATION_ENUM =
[
  AUTHENTICATION_YES = 'YES'.freeze,
  AUTHENTICATION_NO = 'NO'.freeze,
  AUTHENTICATION_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
FLAGS_ENUM =
[
  FLAGS_PROXY_MAY_ACTIVATE_ALL_CLIENT_ROLES = 'PROXY_MAY_ACTIVATE_ALL_CLIENT_ROLES'.freeze,
  FLAGS_NO_CLIENT_ROLES_MAY_BE_ACTIVATED = 'NO_CLIENT_ROLES_MAY_BE_ACTIVATED'.freeze,
  FLAGS_PROXY_MAY_ACTIVATE_ROLE = 'PROXY_MAY_ACTIVATE_ROLE'.freeze,
  FLAGS_PROXY_MAY_NOT_ACTIVATE_ROLE = 'PROXY_MAY_NOT_ACTIVATE_ROLE'.freeze,
  FLAGS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ProxiedForUserSummary

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :name (String)

    The value to assign to the #name property

  • :authentication (String)

    The value to assign to the #authentication property

  • :flags (String)

    The value to assign to the #flags property



68
69
70
71
72
73
74
75
76
# File 'lib/oci/database_management/models/proxied_for_user_summary.rb', line 68

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  self.name = attributes[:'name'] if attributes[:'name']

  self.authentication = attributes[:'authentication'] if attributes[:'authentication']

  self.flags = attributes[:'flags'] if attributes[:'flags']
end

Instance Attribute Details

#authenticationString

Indicates whether the proxy is required to supply the client credentials (YES) or not (NO)

Returns:



31
32
33
# File 'lib/oci/database_management/models/proxied_for_user_summary.rb', line 31

def authentication
  @authentication
end

#flagsString

Flags associated with the proxy/client pair

Returns:



35
36
37
# File 'lib/oci/database_management/models/proxied_for_user_summary.rb', line 35

def flags
  @flags
end

#nameString

The name of a proxy user or name of the user who the proxy user can act as

Returns:



27
28
29
# File 'lib/oci/database_management/models/proxied_for_user_summary.rb', line 27

def name
  @name
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
# File 'lib/oci/database_management/models/proxied_for_user_summary.rb', line 38

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'name': :'name',
    'authentication': :'authentication',
    'flags': :'flags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



49
50
51
52
53
54
55
56
57
# File 'lib/oci/database_management/models/proxied_for_user_summary.rb', line 49

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'name': :'String',
    'authentication': :'String',
    'flags': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • the other object to be compared



111
112
113
114
115
116
117
118
# File 'lib/oci/database_management/models/proxied_for_user_summary.rb', line 111

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    name == other.name &&
    authentication == other.authentication &&
    flags == other.flags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/oci/database_management/models/proxied_for_user_summary.rb', line 143

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • the other object to be compared

Returns:

See Also:

  • `==` method


123
124
125
# File 'lib/oci/database_management/models/proxied_for_user_summary.rb', line 123

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • Hash code



132
133
134
# File 'lib/oci/database_management/models/proxied_for_user_summary.rb', line 132

def hash
  [name, authentication, flags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



176
177
178
179
180
181
182
183
184
185
# File 'lib/oci/database_management/models/proxied_for_user_summary.rb', line 176

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



170
171
172
# File 'lib/oci/database_management/models/proxied_for_user_summary.rb', line 170

def to_s
  to_hash.to_s
end