Class: OCI::DatabaseManagement::Models::ResetDatabaseParametersDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database_management/models/reset_database_parameters_details.rb

Overview

The details required to reset database parameter values.

Constant Summary collapse

SCOPE_ENUM =
[
  SCOPE_MEMORY = 'MEMORY'.freeze,
  SCOPE_SPFILE = 'SPFILE'.freeze,
  SCOPE_BOTH = 'BOTH'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ResetDatabaseParametersDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/oci/database_management/models/reset_database_parameters_details.rb', line 68

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.credentials = attributes[:'credentials'] if attributes[:'credentials']

  self.scope = attributes[:'scope'] if attributes[:'scope']

  self.parameters = attributes[:'parameters'] if attributes[:'parameters']
end

Instance Attribute Details

#credentialsOCI::DatabaseManagement::Models::DatabaseCredentials

This attribute is required.



18
19
20
# File 'lib/oci/database_management/models/reset_database_parameters_details.rb', line 18

def credentials
  @credentials
end

#parametersArray<String>

**[Required]** A list of database parameter names.

Returns:

  • (Array<String>)


35
36
37
# File 'lib/oci/database_management/models/reset_database_parameters_details.rb', line 35

def parameters
  @parameters
end

#scopeString

**[Required]** The clause used to specify when the parameter change takes effect.

Use `MEMORY` to make the change in memory and ensure that it takes effect immediately. Use `SPFILE` to make the change in the server parameter file. The change takes effect when the database is next shut down and started up again. Use `BOTH` to make the change in memory and in the server parameter file. The change takes effect immediately and persists after the database is shut down and started up again.

Returns:

  • (String)


31
32
33
# File 'lib/oci/database_management/models/reset_database_parameters_details.rb', line 31

def scope
  @scope
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
# File 'lib/oci/database_management/models/reset_database_parameters_details.rb', line 38

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'credentials': :'credentials',
    'scope': :'scope',
    'parameters': :'parameters'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



49
50
51
52
53
54
55
56
57
# File 'lib/oci/database_management/models/reset_database_parameters_details.rb', line 49

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'credentials': :'OCI::DatabaseManagement::Models::DatabaseCredentials',
    'scope': :'String',
    'parameters': :'Array<String>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



96
97
98
99
100
101
102
103
# File 'lib/oci/database_management/models/reset_database_parameters_details.rb', line 96

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    credentials == other.credentials &&
    scope == other.scope &&
    parameters == other.parameters
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/oci/database_management/models/reset_database_parameters_details.rb', line 128

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


108
109
110
# File 'lib/oci/database_management/models/reset_database_parameters_details.rb', line 108

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



117
118
119
# File 'lib/oci/database_management/models/reset_database_parameters_details.rb', line 117

def hash
  [credentials, scope, parameters].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



161
162
163
164
165
166
167
168
169
170
# File 'lib/oci/database_management/models/reset_database_parameters_details.rb', line 161

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



155
156
157
# File 'lib/oci/database_management/models/reset_database_parameters_details.rb', line 155

def to_s
  to_hash.to_s
end