Class: OCI::DatabaseManagement::Models::SqlTuningAdvisorTaskSummaryFindingCounts
- Inherits:
-
Object
- Object
- OCI::DatabaseManagement::Models::SqlTuningAdvisorTaskSummaryFindingCounts
- Defined in:
- lib/oci/database_management/models/sql_tuning_advisor_task_summary_finding_counts.rb
Overview
The finding counts data for the SQL Tuning Advisor summary report.
Instance Attribute Summary collapse
-
#alternate_plan ⇒ Integer
[Required] The count of distinct SQL statements with alternative plan recommendations.
-
#implemented_sql_profile ⇒ Integer
[Required] The count of distinct SQL statements with implemented SQL profiles.
-
#index ⇒ Integer
[Required] The count of distinct SQL statements with index recommendations.
-
#recommended_sql_profile ⇒ Integer
[Required] The count of distinct SQL statements with recommended SQL profiles.
-
#restructure ⇒ Integer
[Required] The count of distinct SQL statements with restructure SQL recommendations.
-
#statistics ⇒ Integer
[Required] The count of distinct SQL statements with stale/missing optimizer statistics recommendations.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SqlTuningAdvisorTaskSummaryFindingCounts
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ SqlTuningAdvisorTaskSummaryFindingCounts
Initializes the object
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_finding_counts.rb', line 74 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.recommended_sql_profile = attributes[:'recommendedSqlProfile'] if attributes[:'recommendedSqlProfile'] raise 'You cannot provide both :recommendedSqlProfile and :recommended_sql_profile' if attributes.key?(:'recommendedSqlProfile') && attributes.key?(:'recommended_sql_profile') self.recommended_sql_profile = attributes[:'recommended_sql_profile'] if attributes[:'recommended_sql_profile'] self.implemented_sql_profile = attributes[:'implementedSqlProfile'] if attributes[:'implementedSqlProfile'] raise 'You cannot provide both :implementedSqlProfile and :implemented_sql_profile' if attributes.key?(:'implementedSqlProfile') && attributes.key?(:'implemented_sql_profile') self.implemented_sql_profile = attributes[:'implemented_sql_profile'] if attributes[:'implemented_sql_profile'] self.index = attributes[:'index'] if attributes[:'index'] self.restructure = attributes[:'restructure'] if attributes[:'restructure'] self.statistics = attributes[:'statistics'] if attributes[:'statistics'] self.alternate_plan = attributes[:'alternatePlan'] if attributes[:'alternatePlan'] raise 'You cannot provide both :alternatePlan and :alternate_plan' if attributes.key?(:'alternatePlan') && attributes.key?(:'alternate_plan') self.alternate_plan = attributes[:'alternate_plan'] if attributes[:'alternate_plan'] end |
Instance Attribute Details
#alternate_plan ⇒ Integer
[Required] The count of distinct SQL statements with alternative plan recommendations.
32 33 34 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_finding_counts.rb', line 32 def alternate_plan @alternate_plan end |
#implemented_sql_profile ⇒ Integer
[Required] The count of distinct SQL statements with implemented SQL profiles.
16 17 18 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_finding_counts.rb', line 16 def implemented_sql_profile @implemented_sql_profile end |
#index ⇒ Integer
[Required] The count of distinct SQL statements with index recommendations.
20 21 22 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_finding_counts.rb', line 20 def index @index end |
#recommended_sql_profile ⇒ Integer
[Required] The count of distinct SQL statements with recommended SQL profiles.
12 13 14 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_finding_counts.rb', line 12 def recommended_sql_profile @recommended_sql_profile end |
#restructure ⇒ Integer
[Required] The count of distinct SQL statements with restructure SQL recommendations.
24 25 26 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_finding_counts.rb', line 24 def restructure @restructure end |
#statistics ⇒ Integer
[Required] The count of distinct SQL statements with stale/missing optimizer statistics recommendations.
28 29 30 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_finding_counts.rb', line 28 def statistics @statistics end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_finding_counts.rb', line 35 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'recommended_sql_profile': :'recommendedSqlProfile', 'implemented_sql_profile': :'implementedSqlProfile', 'index': :'index', 'restructure': :'restructure', 'statistics': :'statistics', 'alternate_plan': :'alternatePlan' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_finding_counts.rb', line 49 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'recommended_sql_profile': :'Integer', 'implemented_sql_profile': :'Integer', 'index': :'Integer', 'restructure': :'Integer', 'statistics': :'Integer', 'alternate_plan': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_finding_counts.rb', line 112 def ==(other) return true if equal?(other) self.class == other.class && recommended_sql_profile == other.recommended_sql_profile && implemented_sql_profile == other.implemented_sql_profile && index == other.index && restructure == other.restructure && statistics == other.statistics && alternate_plan == other.alternate_plan end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_finding_counts.rb', line 147 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
127 128 129 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_finding_counts.rb', line 127 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
136 137 138 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_finding_counts.rb', line 136 def hash [recommended_sql_profile, implemented_sql_profile, index, restructure, statistics, alternate_plan].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
180 181 182 183 184 185 186 187 188 189 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_finding_counts.rb', line 180 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
174 175 176 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_finding_counts.rb', line 174 def to_s to_hash.to_s end |