Class: OCI::DatabaseManagement::Models::SqlTuningAdvisorTaskSummaryReportObjectStatFindingSummary
- Inherits:
-
Object
- Object
- OCI::DatabaseManagement::Models::SqlTuningAdvisorTaskSummaryReportObjectStatFindingSummary
- Defined in:
- lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_object_stat_finding_summary.rb
Overview
A summary for all the statistic findings of an object in a SQL Tuning Advisor task. Includes the object’s hash, name, type, schema, problem type and the object reference count.
Constant Summary collapse
- PROBLEM_TYPE_ENUM =
[ PROBLEM_TYPE_MISSING = 'MISSING'.freeze, PROBLEM_TYPE_STALE = 'STALE'.freeze, PROBLEM_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#object_hash_value ⇒ Integer
[Required] Numerical representation of the object.
-
#object_name ⇒ String
[Required] Name of the object.
-
#object_type ⇒ String
[Required] Type of the object.
-
#problem_type ⇒ String
[Required] Type of statistics problem related to the object.
-
#reference_count ⇒ Integer
[Required] The number of the times the object is referenced within the SQL Tuning advisor task findings.
-
#schema ⇒ String
[Required] Schema of the object.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SqlTuningAdvisorTaskSummaryReportObjectStatFindingSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ SqlTuningAdvisorTaskSummaryReportObjectStatFindingSummary
Initializes the object
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_object_stat_finding_summary.rb', line 81 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.object_hash_value = attributes[:'objectHashValue'] if attributes[:'objectHashValue'] raise 'You cannot provide both :objectHashValue and :object_hash_value' if attributes.key?(:'objectHashValue') && attributes.key?(:'object_hash_value') self.object_hash_value = attributes[:'object_hash_value'] if attributes[:'object_hash_value'] self.object_name = attributes[:'objectName'] if attributes[:'objectName'] raise 'You cannot provide both :objectName and :object_name' if attributes.key?(:'objectName') && attributes.key?(:'object_name') self.object_name = attributes[:'object_name'] if attributes[:'object_name'] self.object_type = attributes[:'objectType'] if attributes[:'objectType'] raise 'You cannot provide both :objectType and :object_type' if attributes.key?(:'objectType') && attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] if attributes[:'object_type'] self.schema = attributes[:'schema'] if attributes[:'schema'] self.problem_type = attributes[:'problemType'] if attributes[:'problemType'] raise 'You cannot provide both :problemType and :problem_type' if attributes.key?(:'problemType') && attributes.key?(:'problem_type') self.problem_type = attributes[:'problem_type'] if attributes[:'problem_type'] self.reference_count = attributes[:'referenceCount'] if attributes[:'referenceCount'] raise 'You cannot provide both :referenceCount and :reference_count' if attributes.key?(:'referenceCount') && attributes.key?(:'reference_count') self.reference_count = attributes[:'reference_count'] if attributes[:'reference_count'] end |
Instance Attribute Details
#object_hash_value ⇒ Integer
[Required] Numerical representation of the object.
19 20 21 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_object_stat_finding_summary.rb', line 19 def object_hash_value @object_hash_value end |
#object_name ⇒ String
[Required] Name of the object.
23 24 25 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_object_stat_finding_summary.rb', line 23 def object_name @object_name end |
#object_type ⇒ String
[Required] Type of the object.
27 28 29 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_object_stat_finding_summary.rb', line 27 def object_type @object_type end |
#problem_type ⇒ String
[Required] Type of statistics problem related to the object.
35 36 37 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_object_stat_finding_summary.rb', line 35 def problem_type @problem_type end |
#reference_count ⇒ Integer
[Required] The number of the times the object is referenced within the SQL Tuning advisor task findings.
39 40 41 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_object_stat_finding_summary.rb', line 39 def reference_count @reference_count end |
#schema ⇒ String
[Required] Schema of the object.
31 32 33 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_object_stat_finding_summary.rb', line 31 def schema @schema end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_object_stat_finding_summary.rb', line 42 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'object_hash_value': :'objectHashValue', 'object_name': :'objectName', 'object_type': :'objectType', 'schema': :'schema', 'problem_type': :'problemType', 'reference_count': :'referenceCount' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_object_stat_finding_summary.rb', line 56 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'object_hash_value': :'Integer', 'object_name': :'String', 'object_type': :'String', 'schema': :'String', 'problem_type': :'String', 'reference_count': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_object_stat_finding_summary.rb', line 140 def ==(other) return true if equal?(other) self.class == other.class && object_hash_value == other.object_hash_value && object_name == other.object_name && object_type == other.object_type && schema == other.schema && problem_type == other.problem_type && reference_count == other.reference_count end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_object_stat_finding_summary.rb', line 175 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
155 156 157 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_object_stat_finding_summary.rb', line 155 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
164 165 166 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_object_stat_finding_summary.rb', line 164 def hash [object_hash_value, object_name, object_type, schema, problem_type, reference_count].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
208 209 210 211 212 213 214 215 216 217 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_object_stat_finding_summary.rb', line 208 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
202 203 204 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_object_stat_finding_summary.rb', line 202 def to_s to_hash.to_s end |