Class: OCI::DatabaseManagement::Models::SqlTuningAdvisorTaskSummaryReportStatementCounts
- Inherits:
-
Object
- Object
- OCI::DatabaseManagement::Models::SqlTuningAdvisorTaskSummaryReportStatementCounts
- Defined in:
- lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_statement_counts.rb
Overview
The statement counts data for the SQL Tuning Advisor summary report.
Instance Attribute Summary collapse
-
#distinct_sql ⇒ Integer
[Required] The count of distinct SQL statements.
-
#error_count ⇒ Integer
[Required] The count of distinct SQL statements with errors.
-
#finding_count ⇒ Integer
[Required] The count of distinct SQL statements with findings.
-
#total_sql ⇒ Integer
[Required] The total count of SQL statements.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SqlTuningAdvisorTaskSummaryReportStatementCounts
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ SqlTuningAdvisorTaskSummaryReportStatementCounts
Initializes the object
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_statement_counts.rb', line 60 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.distinct_sql = attributes[:'distinctSql'] if attributes[:'distinctSql'] raise 'You cannot provide both :distinctSql and :distinct_sql' if attributes.key?(:'distinctSql') && attributes.key?(:'distinct_sql') self.distinct_sql = attributes[:'distinct_sql'] if attributes[:'distinct_sql'] self.total_sql = attributes[:'totalSql'] if attributes[:'totalSql'] raise 'You cannot provide both :totalSql and :total_sql' if attributes.key?(:'totalSql') && attributes.key?(:'total_sql') self.total_sql = attributes[:'total_sql'] if attributes[:'total_sql'] self.finding_count = attributes[:'findingCount'] if attributes[:'findingCount'] raise 'You cannot provide both :findingCount and :finding_count' if attributes.key?(:'findingCount') && attributes.key?(:'finding_count') self.finding_count = attributes[:'finding_count'] if attributes[:'finding_count'] self.error_count = attributes[:'errorCount'] if attributes[:'errorCount'] raise 'You cannot provide both :errorCount and :error_count' if attributes.key?(:'errorCount') && attributes.key?(:'error_count') self.error_count = attributes[:'error_count'] if attributes[:'error_count'] end |
Instance Attribute Details
#distinct_sql ⇒ Integer
[Required] The count of distinct SQL statements.
12 13 14 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_statement_counts.rb', line 12 def distinct_sql @distinct_sql end |
#error_count ⇒ Integer
[Required] The count of distinct SQL statements with errors.
24 25 26 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_statement_counts.rb', line 24 def error_count @error_count end |
#finding_count ⇒ Integer
[Required] The count of distinct SQL statements with findings.
20 21 22 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_statement_counts.rb', line 20 def finding_count @finding_count end |
#total_sql ⇒ Integer
[Required] The total count of SQL statements.
16 17 18 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_statement_counts.rb', line 16 def total_sql @total_sql end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
27 28 29 30 31 32 33 34 35 36 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_statement_counts.rb', line 27 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'distinct_sql': :'distinctSql', 'total_sql': :'totalSql', 'finding_count': :'findingCount', 'error_count': :'errorCount' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
39 40 41 42 43 44 45 46 47 48 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_statement_counts.rb', line 39 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'distinct_sql': :'Integer', 'total_sql': :'Integer', 'finding_count': :'Integer', 'error_count': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
98 99 100 101 102 103 104 105 106 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_statement_counts.rb', line 98 def ==(other) return true if equal?(other) self.class == other.class && distinct_sql == other.distinct_sql && total_sql == other.total_sql && finding_count == other.finding_count && error_count == other.error_count end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_statement_counts.rb', line 131 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
111 112 113 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_statement_counts.rb', line 111 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
120 121 122 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_statement_counts.rb', line 120 def hash [distinct_sql, total_sql, finding_count, error_count].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
164 165 166 167 168 169 170 171 172 173 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_statement_counts.rb', line 164 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
158 159 160 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_statement_counts.rb', line 158 def to_s to_hash.to_s end |