Class: OCI::DatabaseManagement::Models::UpdateJobDetails
- Inherits:
-
Object
- Object
- OCI::DatabaseManagement::Models::UpdateJobDetails
- Defined in:
- lib/oci/database_management/models/update_job_details.rb
Overview
The details required to update a job. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
Constant Summary collapse
- JOB_TYPE_ENUM =
[ JOB_TYPE_SQL = 'SQL'.freeze ].freeze
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the job.
-
#job_type ⇒ String
The type of job.
- #result_location ⇒ OCI::DatabaseManagement::Models::JobExecutionResultLocation
- #schedule_details ⇒ OCI::DatabaseManagement::Models::JobScheduleDetails
-
#timeout ⇒ String
The job timeout duration, which is expressed like "1h 10m 15s".
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateJobDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateJobDetails
Initializes the object
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/oci/database_management/models/update_job_details.rb', line 85 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.description = attributes[:'description'] if attributes[:'description'] self.job_type = attributes[:'jobType'] if attributes[:'jobType'] raise 'You cannot provide both :jobType and :job_type' if attributes.key?(:'jobType') && attributes.key?(:'job_type') self.job_type = attributes[:'job_type'] if attributes[:'job_type'] self.timeout = attributes[:'timeout'] if attributes[:'timeout'] self.result_location = attributes[:'resultLocation'] if attributes[:'resultLocation'] raise 'You cannot provide both :resultLocation and :result_location' if attributes.key?(:'resultLocation') && attributes.key?(:'result_location') self.result_location = attributes[:'result_location'] if attributes[:'result_location'] self.schedule_details = attributes[:'scheduleDetails'] if attributes[:'scheduleDetails'] raise 'You cannot provide both :scheduleDetails and :schedule_details' if attributes.key?(:'scheduleDetails') && attributes.key?(:'schedule_details') self.schedule_details = attributes[:'schedule_details'] if attributes[:'schedule_details'] end |
Instance Attribute Details
#description ⇒ String
The description of the job.
17 18 19 |
# File 'lib/oci/database_management/models/update_job_details.rb', line 17 def description @description end |
#job_type ⇒ String
The type of job.
21 22 23 |
# File 'lib/oci/database_management/models/update_job_details.rb', line 21 def job_type @job_type end |
#result_location ⇒ OCI::DatabaseManagement::Models::JobExecutionResultLocation
28 29 30 |
# File 'lib/oci/database_management/models/update_job_details.rb', line 28 def result_location @result_location end |
#schedule_details ⇒ OCI::DatabaseManagement::Models::JobScheduleDetails
31 32 33 |
# File 'lib/oci/database_management/models/update_job_details.rb', line 31 def schedule_details @schedule_details end |
#timeout ⇒ String
The job timeout duration, which is expressed like "1h 10m 15s".
25 26 27 |
# File 'lib/oci/database_management/models/update_job_details.rb', line 25 def timeout @timeout end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 43 44 |
# File 'lib/oci/database_management/models/update_job_details.rb', line 34 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'description': :'description', 'job_type': :'jobType', 'timeout': :'timeout', 'result_location': :'resultLocation', 'schedule_details': :'scheduleDetails' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
64 65 66 67 68 69 70 71 |
# File 'lib/oci/database_management/models/update_job_details.rb', line 64 def self.get_subtype(object_hash) type = object_hash[:'jobType'] # rubocop:disable Style/SymbolLiteral return 'OCI::DatabaseManagement::Models::UpdateSqlJobDetails' if type == 'SQL' # TODO: Log a warning when the subtype is not found. 'OCI::DatabaseManagement::Models::UpdateJobDetails' end |
.swagger_types ⇒ Object
Attribute type mapping.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/oci/database_management/models/update_job_details.rb', line 47 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'description': :'String', 'job_type': :'String', 'timeout': :'String', 'result_location': :'OCI::DatabaseManagement::Models::JobExecutionResultLocation', 'schedule_details': :'OCI::DatabaseManagement::Models::JobScheduleDetails' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
129 130 131 132 133 134 135 136 137 138 |
# File 'lib/oci/database_management/models/update_job_details.rb', line 129 def ==(other) return true if equal?(other) self.class == other.class && description == other.description && job_type == other.job_type && timeout == other.timeout && result_location == other.result_location && schedule_details == other.schedule_details end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/oci/database_management/models/update_job_details.rb', line 163 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
143 144 145 |
# File 'lib/oci/database_management/models/update_job_details.rb', line 143 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
152 153 154 |
# File 'lib/oci/database_management/models/update_job_details.rb', line 152 def hash [description, job_type, timeout, result_location, schedule_details].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
196 197 198 199 200 201 202 203 204 205 |
# File 'lib/oci/database_management/models/update_job_details.rb', line 196 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
190 191 192 |
# File 'lib/oci/database_management/models/update_job_details.rb', line 190 def to_s to_hash.to_s end |