Class: OCI::DatabaseManagement::Models::UpdateTablespaceDetails
- Inherits:
-
Object
- Object
- OCI::DatabaseManagement::Models::UpdateTablespaceDetails
- Defined in:
- lib/oci/database_management/models/update_tablespace_details.rb
Overview
The details required to update a tablespace.
Constant Summary collapse
- TYPE_ENUM =
[ TYPE_PERMANENT = 'PERMANENT'.freeze, TYPE_TEMPORARY = 'TEMPORARY'.freeze ].freeze
- STATUS_ENUM =
[ STATUS_READ_ONLY = 'READ_ONLY'.freeze, STATUS_READ_WRITE = 'READ_WRITE'.freeze ].freeze
Instance Attribute Summary collapse
-
#auto_extend_max_size ⇒ OCI::DatabaseManagement::Models::TablespaceStorageSize
The maximum disk space allowed for automatic extension of the data files or temp files.
-
#auto_extend_next_size ⇒ OCI::DatabaseManagement::Models::TablespaceStorageSize
The size of the next increment of disk space to be allocated automatically when more extents are required.
-
#credential_details ⇒ OCI::DatabaseManagement::Models::TablespaceAdminCredentialDetails
This attribute is required.
-
#file_size ⇒ OCI::DatabaseManagement::Models::TablespaceStorageSize
The size of each data file or temp file.
-
#is_auto_extensible ⇒ BOOLEAN
Specifies whether the data file or temp file can be extended automatically.
-
#is_default ⇒ BOOLEAN
Specifies whether the tablespace is the default tablespace.
-
#is_max_size_unlimited ⇒ BOOLEAN
Specifies whether the disk space of the data file or temp file can be limited.
-
#name ⇒ String
The name of the tablespace.
-
#status ⇒ String
The status of the tablespace.
-
#type ⇒ String
The type of tablespace.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateTablespaceDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateTablespaceDetails
Initializes the object
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/oci/database_management/models/update_tablespace_details.rb', line 121 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.credential_details = attributes[:'credentialDetails'] if attributes[:'credentialDetails'] raise 'You cannot provide both :credentialDetails and :credential_details' if attributes.key?(:'credentialDetails') && attributes.key?(:'credential_details') self.credential_details = attributes[:'credential_details'] if attributes[:'credential_details'] self.name = attributes[:'name'] if attributes[:'name'] self.type = attributes[:'type'] if attributes[:'type'] self.file_size = attributes[:'fileSize'] if attributes[:'fileSize'] raise 'You cannot provide both :fileSize and :file_size' if attributes.key?(:'fileSize') && attributes.key?(:'file_size') self.file_size = attributes[:'file_size'] if attributes[:'file_size'] self.status = attributes[:'status'] if attributes[:'status'] self.is_auto_extensible = attributes[:'isAutoExtensible'] unless attributes[:'isAutoExtensible'].nil? raise 'You cannot provide both :isAutoExtensible and :is_auto_extensible' if attributes.key?(:'isAutoExtensible') && attributes.key?(:'is_auto_extensible') self.is_auto_extensible = attributes[:'is_auto_extensible'] unless attributes[:'is_auto_extensible'].nil? self.auto_extend_next_size = attributes[:'autoExtendNextSize'] if attributes[:'autoExtendNextSize'] raise 'You cannot provide both :autoExtendNextSize and :auto_extend_next_size' if attributes.key?(:'autoExtendNextSize') && attributes.key?(:'auto_extend_next_size') self.auto_extend_next_size = attributes[:'auto_extend_next_size'] if attributes[:'auto_extend_next_size'] self.auto_extend_max_size = attributes[:'autoExtendMaxSize'] if attributes[:'autoExtendMaxSize'] raise 'You cannot provide both :autoExtendMaxSize and :auto_extend_max_size' if attributes.key?(:'autoExtendMaxSize') && attributes.key?(:'auto_extend_max_size') self.auto_extend_max_size = attributes[:'auto_extend_max_size'] if attributes[:'auto_extend_max_size'] self.is_max_size_unlimited = attributes[:'isMaxSizeUnlimited'] unless attributes[:'isMaxSizeUnlimited'].nil? raise 'You cannot provide both :isMaxSizeUnlimited and :is_max_size_unlimited' if attributes.key?(:'isMaxSizeUnlimited') && attributes.key?(:'is_max_size_unlimited') self.is_max_size_unlimited = attributes[:'is_max_size_unlimited'] unless attributes[:'is_max_size_unlimited'].nil? self.is_default = attributes[:'isDefault'] unless attributes[:'isDefault'].nil? raise 'You cannot provide both :isDefault and :is_default' if attributes.key?(:'isDefault') && attributes.key?(:'is_default') self.is_default = attributes[:'is_default'] unless attributes[:'is_default'].nil? end |
Instance Attribute Details
#auto_extend_max_size ⇒ OCI::DatabaseManagement::Models::TablespaceStorageSize
The maximum disk space allowed for automatic extension of the data files or temp files.
57 58 59 |
# File 'lib/oci/database_management/models/update_tablespace_details.rb', line 57 def auto_extend_max_size @auto_extend_max_size end |
#auto_extend_next_size ⇒ OCI::DatabaseManagement::Models::TablespaceStorageSize
The size of the next increment of disk space to be allocated automatically when more extents are required.
52 53 54 |
# File 'lib/oci/database_management/models/update_tablespace_details.rb', line 52 def auto_extend_next_size @auto_extend_next_size end |
#credential_details ⇒ OCI::DatabaseManagement::Models::TablespaceAdminCredentialDetails
This attribute is required.
22 23 24 |
# File 'lib/oci/database_management/models/update_tablespace_details.rb', line 22 def credential_details @credential_details end |
#file_size ⇒ OCI::DatabaseManagement::Models::TablespaceStorageSize
The size of each data file or temp file.
37 38 39 |
# File 'lib/oci/database_management/models/update_tablespace_details.rb', line 37 def file_size @file_size end |
#is_auto_extensible ⇒ BOOLEAN
Specifies whether the data file or temp file can be extended automatically.
47 48 49 |
# File 'lib/oci/database_management/models/update_tablespace_details.rb', line 47 def is_auto_extensible @is_auto_extensible end |
#is_default ⇒ BOOLEAN
Specifies whether the tablespace is the default tablespace.
67 68 69 |
# File 'lib/oci/database_management/models/update_tablespace_details.rb', line 67 def is_default @is_default end |
#is_max_size_unlimited ⇒ BOOLEAN
Specifies whether the disk space of the data file or temp file can be limited.
62 63 64 |
# File 'lib/oci/database_management/models/update_tablespace_details.rb', line 62 def is_max_size_unlimited @is_max_size_unlimited end |
#name ⇒ String
The name of the tablespace. It must be unique within a database.
27 28 29 |
# File 'lib/oci/database_management/models/update_tablespace_details.rb', line 27 def name @name end |
#status ⇒ String
The status of the tablespace.
42 43 44 |
# File 'lib/oci/database_management/models/update_tablespace_details.rb', line 42 def status @status end |
#type ⇒ String
The type of tablespace.
32 33 34 |
# File 'lib/oci/database_management/models/update_tablespace_details.rb', line 32 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/oci/database_management/models/update_tablespace_details.rb', line 70 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'credential_details': :'credentialDetails', 'name': :'name', 'type': :'type', 'file_size': :'fileSize', 'status': :'status', 'is_auto_extensible': :'isAutoExtensible', 'auto_extend_next_size': :'autoExtendNextSize', 'auto_extend_max_size': :'autoExtendMaxSize', 'is_max_size_unlimited': :'isMaxSizeUnlimited', 'is_default': :'isDefault' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/oci/database_management/models/update_tablespace_details.rb', line 88 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'credential_details': :'OCI::DatabaseManagement::Models::TablespaceAdminCredentialDetails', 'name': :'String', 'type': :'String', 'file_size': :'OCI::DatabaseManagement::Models::TablespaceStorageSize', 'status': :'String', 'is_auto_extensible': :'BOOLEAN', 'auto_extend_next_size': :'OCI::DatabaseManagement::Models::TablespaceStorageSize', 'auto_extend_max_size': :'OCI::DatabaseManagement::Models::TablespaceStorageSize', 'is_max_size_unlimited': :'BOOLEAN', 'is_default': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/oci/database_management/models/update_tablespace_details.rb', line 199 def ==(other) return true if equal?(other) self.class == other.class && credential_details == other.credential_details && name == other.name && type == other.type && file_size == other.file_size && status == other.status && is_auto_extensible == other.is_auto_extensible && auto_extend_next_size == other.auto_extend_next_size && auto_extend_max_size == other.auto_extend_max_size && is_max_size_unlimited == other.is_max_size_unlimited && is_default == other.is_default end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 |
# File 'lib/oci/database_management/models/update_tablespace_details.rb', line 238 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
218 219 220 |
# File 'lib/oci/database_management/models/update_tablespace_details.rb', line 218 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
227 228 229 |
# File 'lib/oci/database_management/models/update_tablespace_details.rb', line 227 def hash [credential_details, name, type, file_size, status, is_auto_extensible, auto_extend_next_size, auto_extend_max_size, is_max_size_unlimited, is_default].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
271 272 273 274 275 276 277 278 279 280 |
# File 'lib/oci/database_management/models/update_tablespace_details.rb', line 271 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
265 266 267 |
# File 'lib/oci/database_management/models/update_tablespace_details.rb', line 265 def to_s to_hash.to_s end |