Class: OCI::DatabaseManagement::Models::UserSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database_management/models/user_summary.rb

Overview

The summary of a specific User.

Constant Summary collapse

STATUS_ENUM =
[
  STATUS_OPEN = 'OPEN'.freeze,
  STATUS_EXPIRED = 'EXPIRED'.freeze,
  STATUS_EXPIRED_GRACE = 'EXPIRED_GRACE'.freeze,
  STATUS_LOCKED = 'LOCKED'.freeze,
  STATUS_LOCKED_TIMED = 'LOCKED_TIMED'.freeze,
  STATUS_EXPIRED_AND_LOCKED = 'EXPIRED_AND_LOCKED'.freeze,
  STATUS_EXPIRED_GRACE_AND_LOCKED = 'EXPIRED_GRACE_AND_LOCKED'.freeze,
  STATUS_EXPIRED_AND_LOCKED_TIMED = 'EXPIRED_AND_LOCKED_TIMED'.freeze,
  STATUS_EXPIRED_GRACE_AND_LOCKED_TIMED = 'EXPIRED_GRACE_AND_LOCKED_TIMED'.freeze,
  STATUS_OPEN_AND_IN_ROLLOVER = 'OPEN_AND_IN_ROLLOVER'.freeze,
  STATUS_EXPIRED_AND_IN_ROLLOVER = 'EXPIRED_AND_IN_ROLLOVER'.freeze,
  STATUS_LOCKED_AND_IN_ROLLOVER = 'LOCKED_AND_IN_ROLLOVER'.freeze,
  STATUS_EXPIRED_AND_LOCKED_AND_IN_ROLLOVER = 'EXPIRED_AND_LOCKED_AND_IN_ROLLOVER'.freeze,
  STATUS_LOCKED_TIMED_AND_IN_ROLLOVER = 'LOCKED_TIMED_AND_IN_ROLLOVER'.freeze,
  STATUS_EXPIRED_AND_LOCKED_TIMED_AND_IN_ROL = 'EXPIRED_AND_LOCKED_TIMED_AND_IN_ROL'.freeze,
  STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UserSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :name (String)

    The value to assign to the #name property

  • :status (String)

    The value to assign to the #status property

  • :time_expiring (DateTime)

    The value to assign to the #time_expiring property

  • :default_tablespace (String)

    The value to assign to the #default_tablespace property

  • :temp_tablespace (String)

    The value to assign to the #temp_tablespace property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :time_locked (DateTime)

    The value to assign to the #time_locked property

  • :profile (String)

    The value to assign to the #profile property



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/oci/database_management/models/user_summary.rb', line 108

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.name = attributes[:'name'] if attributes[:'name']

  self.status = attributes[:'status'] if attributes[:'status']

  self.time_expiring = attributes[:'timeExpiring'] if attributes[:'timeExpiring']

  raise 'You cannot provide both :timeExpiring and :time_expiring' if attributes.key?(:'timeExpiring') && attributes.key?(:'time_expiring')

  self.time_expiring = attributes[:'time_expiring'] if attributes[:'time_expiring']

  self.default_tablespace = attributes[:'defaultTablespace'] if attributes[:'defaultTablespace']

  raise 'You cannot provide both :defaultTablespace and :default_tablespace' if attributes.key?(:'defaultTablespace') && attributes.key?(:'default_tablespace')

  self.default_tablespace = attributes[:'default_tablespace'] if attributes[:'default_tablespace']

  self.temp_tablespace = attributes[:'tempTablespace'] if attributes[:'tempTablespace']

  raise 'You cannot provide both :tempTablespace and :temp_tablespace' if attributes.key?(:'tempTablespace') && attributes.key?(:'temp_tablespace')

  self.temp_tablespace = attributes[:'temp_tablespace'] if attributes[:'temp_tablespace']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_locked = attributes[:'timeLocked'] if attributes[:'timeLocked']

  raise 'You cannot provide both :timeLocked and :time_locked' if attributes.key?(:'timeLocked') && attributes.key?(:'time_locked')

  self.time_locked = attributes[:'time_locked'] if attributes[:'time_locked']

  self.profile = attributes[:'profile'] if attributes[:'profile']
end

Instance Attribute Details

#default_tablespaceString

**[Required]** The default tablespace for data.

Returns:

  • (String)


44
45
46
# File 'lib/oci/database_management/models/user_summary.rb', line 44

def default_tablespace
  @default_tablespace
end

#nameString

**[Required]** The name of the User.

Returns:

  • (String)


32
33
34
# File 'lib/oci/database_management/models/user_summary.rb', line 32

def name
  @name
end

#profileString

**[Required]** The profile name of the user.

Returns:

  • (String)


60
61
62
# File 'lib/oci/database_management/models/user_summary.rb', line 60

def profile
  @profile
end

#statusString

**[Required]** The status of the user account.

Returns:

  • (String)


36
37
38
# File 'lib/oci/database_management/models/user_summary.rb', line 36

def status
  @status
end

#temp_tablespaceString

**[Required]** The name of the default tablespace for temporary tables or the name of a tablespace group.

Returns:

  • (String)


48
49
50
# File 'lib/oci/database_management/models/user_summary.rb', line 48

def temp_tablespace
  @temp_tablespace
end

#time_createdDateTime

**[Required]** The date and time the user was created.

Returns:

  • (DateTime)


52
53
54
# File 'lib/oci/database_management/models/user_summary.rb', line 52

def time_created
  @time_created
end

#time_expiringDateTime

The date and time of the expiration of the user account.

Returns:

  • (DateTime)


40
41
42
# File 'lib/oci/database_management/models/user_summary.rb', line 40

def time_expiring
  @time_expiring
end

#time_lockedDateTime

The date the account was locked, if the status of the account is LOCKED.

Returns:

  • (DateTime)


56
57
58
# File 'lib/oci/database_management/models/user_summary.rb', line 56

def time_locked
  @time_locked
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/oci/database_management/models/user_summary.rb', line 63

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'name': :'name',
    'status': :'status',
    'time_expiring': :'timeExpiring',
    'default_tablespace': :'defaultTablespace',
    'temp_tablespace': :'tempTablespace',
    'time_created': :'timeCreated',
    'time_locked': :'timeLocked',
    'profile': :'profile'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/oci/database_management/models/user_summary.rb', line 79

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'name': :'String',
    'status': :'String',
    'time_expiring': :'DateTime',
    'default_tablespace': :'String',
    'temp_tablespace': :'String',
    'time_created': :'DateTime',
    'time_locked': :'DateTime',
    'profile': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/oci/database_management/models/user_summary.rb', line 171

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    name == other.name &&
    status == other.status &&
    time_expiring == other.time_expiring &&
    default_tablespace == other.default_tablespace &&
    temp_tablespace == other.temp_tablespace &&
    time_created == other.time_created &&
    time_locked == other.time_locked &&
    profile == other.profile
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/oci/database_management/models/user_summary.rb', line 208

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


188
189
190
# File 'lib/oci/database_management/models/user_summary.rb', line 188

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



197
198
199
# File 'lib/oci/database_management/models/user_summary.rb', line 197

def hash
  [name, status, time_expiring, default_tablespace, temp_tablespace, time_created, time_locked, profile].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



241
242
243
244
245
246
247
248
249
250
# File 'lib/oci/database_management/models/user_summary.rb', line 241

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



235
236
237
# File 'lib/oci/database_management/models/user_summary.rb', line 235

def to_s
  to_hash.to_s
end