Class: OCI::DatabaseManagement::Models::WorkRequestError

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database_management/models/work_request_error.rb

Overview

An error encountered while executing a work request.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ WorkRequestError

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :work_request_id (String)

    The value to assign to the #work_request_id property

  • :code (String)

    The value to assign to the #code property

  • :message (String)

    The value to assign to the #message property

  • :is_retryable (BOOLEAN)

    The value to assign to the #is_retryable property

  • :timestamp (DateTime)

    The value to assign to the #timestamp property



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/oci/database_management/models/work_request_error.rb', line 78

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.work_request_id = attributes[:'workRequestId'] if attributes[:'workRequestId']

  raise 'You cannot provide both :workRequestId and :work_request_id' if attributes.key?(:'workRequestId') && attributes.key?(:'work_request_id')

  self.work_request_id = attributes[:'work_request_id'] if attributes[:'work_request_id']

  self.code = attributes[:'code'] if attributes[:'code']

  self.message = attributes[:'message'] if attributes[:'message']

  self.is_retryable = attributes[:'isRetryable'] unless attributes[:'isRetryable'].nil?

  raise 'You cannot provide both :isRetryable and :is_retryable' if attributes.key?(:'isRetryable') && attributes.key?(:'is_retryable')

  self.is_retryable = attributes[:'is_retryable'] unless attributes[:'is_retryable'].nil?

  self.timestamp = attributes[:'timestamp'] if attributes[:'timestamp']
end

Instance Attribute Details

#codeString

[Required] A machine-usable code for the error that occurred. Error codes are listed on (docs.cloud.oracle.com/Content/API/References/apierrors.htm).

Returns:

  • (String)


23
24
25
# File 'lib/oci/database_management/models/work_request_error.rb', line 23

def code
  @code
end

#idString

[Required] The identifier of the work request error.

Returns:

  • (String)


13
14
15
# File 'lib/oci/database_management/models/work_request_error.rb', line 13

def id
  @id
end

#is_retryableBOOLEAN

Determines if the work request error can be reproduced and tried again.

Returns:

  • (BOOLEAN)


31
32
33
# File 'lib/oci/database_management/models/work_request_error.rb', line 31

def is_retryable
  @is_retryable
end

#messageString

[Required] A human-readable description of the issue that occurred.

Returns:

  • (String)


27
28
29
# File 'lib/oci/database_management/models/work_request_error.rb', line 27

def message
  @message
end

#timestampDateTime

[Required] The date and time the error occurred as described in [RFC 3339](tools.ietf.org/rfc/rfc3339). The precision for the time object is in milliseconds.

Returns:

  • (DateTime)


36
37
38
# File 'lib/oci/database_management/models/work_request_error.rb', line 36

def timestamp
  @timestamp
end

#work_request_idString

[Required] The OCID of the work request.

Returns:

  • (String)


17
18
19
# File 'lib/oci/database_management/models/work_request_error.rb', line 17

def work_request_id
  @work_request_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



39
40
41
42
43
44
45
46
47
48
49
50
# File 'lib/oci/database_management/models/work_request_error.rb', line 39

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'work_request_id': :'workRequestId',
    'code': :'code',
    'message': :'message',
    'is_retryable': :'isRetryable',
    'timestamp': :'timestamp'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/oci/database_management/models/work_request_error.rb', line 53

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'work_request_id': :'String',
    'code': :'String',
    'message': :'String',
    'is_retryable': :'BOOLEAN',
    'timestamp': :'DateTime'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



112
113
114
115
116
117
118
119
120
121
122
# File 'lib/oci/database_management/models/work_request_error.rb', line 112

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    work_request_id == other.work_request_id &&
    code == other.code &&
    message == other.message &&
    is_retryable == other.is_retryable &&
    timestamp == other.timestamp
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/oci/database_management/models/work_request_error.rb', line 147

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


127
128
129
# File 'lib/oci/database_management/models/work_request_error.rb', line 127

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



136
137
138
# File 'lib/oci/database_management/models/work_request_error.rb', line 136

def hash
  [id, work_request_id, code, message, is_retryable, timestamp].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



180
181
182
183
184
185
186
187
188
189
# File 'lib/oci/database_management/models/work_request_error.rb', line 180

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



174
175
176
# File 'lib/oci/database_management/models/work_request_error.rb', line 174

def to_s
  to_hash.to_s
end