Class: OCI::DatabaseManagement::Models::WorkRequestLogEntry
- Inherits:
-
Object
- Object
- OCI::DatabaseManagement::Models::WorkRequestLogEntry
- Defined in:
- lib/oci/database_management/models/work_request_log_entry.rb
Overview
A log message from the execution of a work request.
Instance Attribute Summary collapse
-
#id ⇒ Integer
[Required] The identifier of the work request log.
-
#message ⇒ String
[Required] A human-readable log message.
-
#timestamp ⇒ DateTime
[Required] The date and time the log message was written, described in [RFC 3339](tools.ietf.org/rfc/rfc3339).
-
#work_request_id ⇒ String
[Required] The OCID of the work request.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WorkRequestLogEntry
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ WorkRequestLogEntry
Initializes the object
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/oci/database_management/models/work_request_log_entry.rb', line 61 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.work_request_id = attributes[:'workRequestId'] if attributes[:'workRequestId'] raise 'You cannot provide both :workRequestId and :work_request_id' if attributes.key?(:'workRequestId') && attributes.key?(:'work_request_id') self.work_request_id = attributes[:'work_request_id'] if attributes[:'work_request_id'] self. = attributes[:'message'] if attributes[:'message'] self. = attributes[:'timestamp'] if attributes[:'timestamp'] end |
Instance Attribute Details
#id ⇒ Integer
[Required] The identifier of the work request log.
12 13 14 |
# File 'lib/oci/database_management/models/work_request_log_entry.rb', line 12 def id @id end |
#message ⇒ String
[Required] A human-readable log message.
20 21 22 |
# File 'lib/oci/database_management/models/work_request_log_entry.rb', line 20 def end |
#timestamp ⇒ DateTime
[Required] The date and time the log message was written, described in [RFC 3339](tools.ietf.org/rfc/rfc3339). The precision for the time object is in milliseconds.
25 26 27 |
# File 'lib/oci/database_management/models/work_request_log_entry.rb', line 25 def end |
#work_request_id ⇒ String
[Required] The OCID of the work request.
16 17 18 |
# File 'lib/oci/database_management/models/work_request_log_entry.rb', line 16 def work_request_id @work_request_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 35 36 37 |
# File 'lib/oci/database_management/models/work_request_log_entry.rb', line 28 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'work_request_id': :'workRequestId', 'message': :'message', 'timestamp': :'timestamp' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
40 41 42 43 44 45 46 47 48 49 |
# File 'lib/oci/database_management/models/work_request_log_entry.rb', line 40 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'Integer', 'work_request_id': :'String', 'message': :'String', 'timestamp': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
87 88 89 90 91 92 93 94 95 |
# File 'lib/oci/database_management/models/work_request_log_entry.rb', line 87 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && work_request_id == other.work_request_id && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/oci/database_management/models/work_request_log_entry.rb', line 120 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
100 101 102 |
# File 'lib/oci/database_management/models/work_request_log_entry.rb', line 100 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
109 110 111 |
# File 'lib/oci/database_management/models/work_request_log_entry.rb', line 109 def hash [id, work_request_id, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
153 154 155 156 157 158 159 160 161 162 |
# File 'lib/oci/database_management/models/work_request_log_entry.rb', line 153 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
147 148 149 |
# File 'lib/oci/database_management/models/work_request_log_entry.rb', line 147 def to_s to_hash.to_s end |