Class: OCI::DatabaseManagement::SqlTuningClientCompositeOperations

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database_management/sql_tuning_client_composite_operations.rb

Overview

This class provides a wrapper around SqlTuningClient and offers convenience methods for operations that would otherwise need to be chained together. For example, instead of performing an action on a resource (e.g. launching an instance, creating a load balancer) and then using a waiter to wait for the resource to enter a given state, you can call a single method in this class to accomplish the same functionality

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(service_client = OCI::DatabaseManagement::SqlTuningClient.new) ⇒ SqlTuningClientCompositeOperations

Initializes a new SqlTuningClientCompositeOperations

Parameters:

  • service_client (OCI::DatabaseManagement::SqlTuningClient) (defaults to: OCI::DatabaseManagement::SqlTuningClient.new)

    The client used to communicate with the service. Defaults to a new service client created via OCI::DatabaseManagement::SqlTuningClient#initialize with no arguments



20
21
22
# File 'lib/oci/database_management/sql_tuning_client_composite_operations.rb', line 20

def initialize(service_client = OCI::DatabaseManagement::SqlTuningClient.new)
  @service_client = service_client
end

Instance Attribute Details

#service_clientOCI::DatabaseManagement::SqlTuningClient (readonly)

The OCI::DatabaseManagement::SqlTuningClient used to communicate with the service_client

Returns:

  • (OCI::DatabaseManagement::SqlTuningClient)


14
15
16
# File 'lib/oci/database_management/sql_tuning_client_composite_operations.rb', line 14

def service_client
  @service_client
end