Class: OCI::DatabaseMigration::Models::CloneMigrationDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database_migration/models/clone_migration_details.rb

Overview

Details that will override an existing Migration configuration that will be cloned.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CloneMigrationDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/oci/database_migration/models/clone_migration_details.rb', line 122

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.agent_id = attributes[:'agentId'] if attributes[:'agentId']

  raise 'You cannot provide both :agentId and :agent_id' if attributes.key?(:'agentId') && attributes.key?(:'agent_id')

  self.agent_id = attributes[:'agent_id'] if attributes[:'agent_id']

  self.source_database_connection_id = attributes[:'sourceDatabaseConnectionId'] if attributes[:'sourceDatabaseConnectionId']

  raise 'You cannot provide both :sourceDatabaseConnectionId and :source_database_connection_id' if attributes.key?(:'sourceDatabaseConnectionId') && attributes.key?(:'source_database_connection_id')

  self.source_database_connection_id = attributes[:'source_database_connection_id'] if attributes[:'source_database_connection_id']

  self.source_container_database_connection_id = attributes[:'sourceContainerDatabaseConnectionId'] if attributes[:'sourceContainerDatabaseConnectionId']

  raise 'You cannot provide both :sourceContainerDatabaseConnectionId and :source_container_database_connection_id' if attributes.key?(:'sourceContainerDatabaseConnectionId') && attributes.key?(:'source_container_database_connection_id')

  self.source_container_database_connection_id = attributes[:'source_container_database_connection_id'] if attributes[:'source_container_database_connection_id']

  self.target_database_connection_id = attributes[:'targetDatabaseConnectionId'] if attributes[:'targetDatabaseConnectionId']

  raise 'You cannot provide both :targetDatabaseConnectionId and :target_database_connection_id' if attributes.key?(:'targetDatabaseConnectionId') && attributes.key?(:'target_database_connection_id')

  self.target_database_connection_id = attributes[:'target_database_connection_id'] if attributes[:'target_database_connection_id']

  self.exclude_objects = attributes[:'excludeObjects'] if attributes[:'excludeObjects']

  raise 'You cannot provide both :excludeObjects and :exclude_objects' if attributes.key?(:'excludeObjects') && attributes.key?(:'exclude_objects')

  self.exclude_objects = attributes[:'exclude_objects'] if attributes[:'exclude_objects']

  self.include_objects = attributes[:'includeObjects'] if attributes[:'includeObjects']

  raise 'You cannot provide both :includeObjects and :include_objects' if attributes.key?(:'includeObjects') && attributes.key?(:'include_objects')

  self.include_objects = attributes[:'include_objects'] if attributes[:'include_objects']

  self.vault_details = attributes[:'vaultDetails'] if attributes[:'vaultDetails']

  raise 'You cannot provide both :vaultDetails and :vault_details' if attributes.key?(:'vaultDetails') && attributes.key?(:'vault_details')

  self.vault_details = attributes[:'vault_details'] if attributes[:'vault_details']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#agent_idString

The OCID of the registered on-premises ODMS Agent. Only valid for Offline Logical Migrations.

Returns:

  • (String)


24
25
26
# File 'lib/oci/database_migration/models/clone_migration_details.rb', line 24

def agent_id
  @agent_id
end

#compartment_idString

OCID of the compartment

Returns:

  • (String)


19
20
21
# File 'lib/oci/database_migration/models/clone_migration_details.rb', line 19

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


65
66
67
# File 'lib/oci/database_migration/models/clone_migration_details.rb', line 65

def defined_tags
  @defined_tags
end

#display_nameString

Migration Display Name

Returns:

  • (String)


14
15
16
# File 'lib/oci/database_migration/models/clone_migration_details.rb', line 14

def display_name
  @display_name
end

#exclude_objectsArray<OCI::DatabaseMigration::Models::DatabaseObject>

Database objects to exclude from migration, cannot be specified alongside ‘includeObjects’



45
46
47
# File 'lib/oci/database_migration/models/clone_migration_details.rb', line 45

def exclude_objects
  @exclude_objects
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`

Returns:

  • (Hash<String, String>)


59
60
61
# File 'lib/oci/database_migration/models/clone_migration_details.rb', line 59

def freeform_tags
  @freeform_tags
end

#include_objectsArray<OCI::DatabaseMigration::Models::DatabaseObject>

Database objects to include from migration, cannot be specified alongside ‘excludeObjects’



50
51
52
# File 'lib/oci/database_migration/models/clone_migration_details.rb', line 50

def include_objects
  @include_objects
end

#source_container_database_connection_idString

The OCID of the Source Container Database Connection. Only used for Online migrations. Only Connections of type Non-Autonomous can be used as source container databases.

Returns:

  • (String)


35
36
37
# File 'lib/oci/database_migration/models/clone_migration_details.rb', line 35

def source_container_database_connection_id
  @source_container_database_connection_id
end

#source_database_connection_idString

[Required] The OCID of the Source Database Connection.

Returns:

  • (String)


29
30
31
# File 'lib/oci/database_migration/models/clone_migration_details.rb', line 29

def source_database_connection_id
  @source_database_connection_id
end

#target_database_connection_idString

[Required] The OCID of the Target Database Connection.

Returns:

  • (String)


40
41
42
# File 'lib/oci/database_migration/models/clone_migration_details.rb', line 40

def target_database_connection_id
  @target_database_connection_id
end

#vault_detailsOCI::DatabaseMigration::Models::CreateVaultDetails



53
54
55
# File 'lib/oci/database_migration/models/clone_migration_details.rb', line 53

def vault_details
  @vault_details
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/oci/database_migration/models/clone_migration_details.rb', line 68

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'displayName',
    'compartment_id': :'compartmentId',
    'agent_id': :'agentId',
    'source_database_connection_id': :'sourceDatabaseConnectionId',
    'source_container_database_connection_id': :'sourceContainerDatabaseConnectionId',
    'target_database_connection_id': :'targetDatabaseConnectionId',
    'exclude_objects': :'excludeObjects',
    'include_objects': :'includeObjects',
    'vault_details': :'vaultDetails',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/oci/database_migration/models/clone_migration_details.rb', line 87

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'String',
    'compartment_id': :'String',
    'agent_id': :'String',
    'source_database_connection_id': :'String',
    'source_container_database_connection_id': :'String',
    'target_database_connection_id': :'String',
    'exclude_objects': :'Array<OCI::DatabaseMigration::Models::DatabaseObject>',
    'include_objects': :'Array<OCI::DatabaseMigration::Models::DatabaseObject>',
    'vault_details': :'OCI::DatabaseMigration::Models::CreateVaultDetails',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/oci/database_migration/models/clone_migration_details.rb', line 202

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    display_name == other.display_name &&
    compartment_id == other.compartment_id &&
    agent_id == other.agent_id &&
    source_database_connection_id == other.source_database_connection_id &&
    source_container_database_connection_id == other.source_container_database_connection_id &&
    target_database_connection_id == other.target_database_connection_id &&
    exclude_objects == other.exclude_objects &&
    include_objects == other.include_objects &&
    vault_details == other.vault_details &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/oci/database_migration/models/clone_migration_details.rb', line 242

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


222
223
224
# File 'lib/oci/database_migration/models/clone_migration_details.rb', line 222

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



231
232
233
# File 'lib/oci/database_migration/models/clone_migration_details.rb', line 231

def hash
  [display_name, compartment_id, agent_id, source_database_connection_id, source_container_database_connection_id, target_database_connection_id, exclude_objects, include_objects, vault_details, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



275
276
277
278
279
280
281
282
283
284
# File 'lib/oci/database_migration/models/clone_migration_details.rb', line 275

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



269
270
271
# File 'lib/oci/database_migration/models/clone_migration_details.rb', line 269

def to_s
  to_hash.to_s
end