Class: DatabaseMigration::Models::Connection

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database_migration/models/connection.rb

Overview

Database Connection resource used for migrations.

Constant Summary collapse

DATABASE_TYPE_ENUM =
[
  DATABASE_TYPE_MANUAL = 'MANUAL'.freeze,
  DATABASE_TYPE_AUTONOMOUS = 'AUTONOMOUS'.freeze,
  DATABASE_TYPE_USER_MANAGED_OCI = 'USER_MANAGED_OCI'.freeze,
  DATABASE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
MANUAL_DATABASE_SUB_TYPE_ENUM =
[
  MANUAL_DATABASE_SUB_TYPE_ORACLE = 'ORACLE'.freeze,
  MANUAL_DATABASE_SUB_TYPE_RDS_ORACLE = 'RDS_ORACLE'.freeze,
  MANUAL_DATABASE_SUB_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Connection

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
# File 'lib/oci/database_migration/models/connection.rb', line 220

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.database_type = attributes[:'databaseType'] if attributes[:'databaseType']

  raise 'You cannot provide both :databaseType and :database_type' if attributes.key?(:'databaseType') && attributes.key?(:'database_type')

  self.database_type = attributes[:'database_type'] if attributes[:'database_type']

  self.manual_database_sub_type = attributes[:'manualDatabaseSubType'] if attributes[:'manualDatabaseSubType']
  self.manual_database_sub_type = "ORACLE" if manual_database_sub_type.nil? && !attributes.key?(:'manualDatabaseSubType') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :manualDatabaseSubType and :manual_database_sub_type' if attributes.key?(:'manualDatabaseSubType') && attributes.key?(:'manual_database_sub_type')

  self.manual_database_sub_type = attributes[:'manual_database_sub_type'] if attributes[:'manual_database_sub_type']
  self.manual_database_sub_type = "ORACLE" if manual_database_sub_type.nil? && !attributes.key?(:'manualDatabaseSubType') && !attributes.key?(:'manual_database_sub_type') # rubocop:disable Style/StringLiterals

  self.is_dedicated = attributes[:'isDedicated'] unless attributes[:'isDedicated'].nil?

  raise 'You cannot provide both :isDedicated and :is_dedicated' if attributes.key?(:'isDedicated') && attributes.key?(:'is_dedicated')

  self.is_dedicated = attributes[:'is_dedicated'] unless attributes[:'is_dedicated'].nil?

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.database_id = attributes[:'databaseId'] if attributes[:'databaseId']

  raise 'You cannot provide both :databaseId and :database_id' if attributes.key?(:'databaseId') && attributes.key?(:'database_id')

  self.database_id = attributes[:'database_id'] if attributes[:'database_id']

  self.connect_descriptor = attributes[:'connectDescriptor'] if attributes[:'connectDescriptor']

  raise 'You cannot provide both :connectDescriptor and :connect_descriptor' if attributes.key?(:'connectDescriptor') && attributes.key?(:'connect_descriptor')

  self.connect_descriptor = attributes[:'connect_descriptor'] if attributes[:'connect_descriptor']

  self.credentials_secret_id = attributes[:'credentialsSecretId'] if attributes[:'credentialsSecretId']

  raise 'You cannot provide both :credentialsSecretId and :credentials_secret_id' if attributes.key?(:'credentialsSecretId') && attributes.key?(:'credentials_secret_id')

  self.credentials_secret_id = attributes[:'credentials_secret_id'] if attributes[:'credentials_secret_id']

  self.certificate_tdn = attributes[:'certificateTdn'] if attributes[:'certificateTdn']

  raise 'You cannot provide both :certificateTdn and :certificate_tdn' if attributes.key?(:'certificateTdn') && attributes.key?(:'certificate_tdn')

  self.certificate_tdn = attributes[:'certificate_tdn'] if attributes[:'certificate_tdn']

  self.ssh_details = attributes[:'sshDetails'] if attributes[:'sshDetails']

  raise 'You cannot provide both :sshDetails and :ssh_details' if attributes.key?(:'sshDetails') && attributes.key?(:'ssh_details')

  self.ssh_details = attributes[:'ssh_details'] if attributes[:'ssh_details']

  self.admin_credentials = attributes[:'adminCredentials'] if attributes[:'adminCredentials']

  raise 'You cannot provide both :adminCredentials and :admin_credentials' if attributes.key?(:'adminCredentials') && attributes.key?(:'admin_credentials')

  self.admin_credentials = attributes[:'admin_credentials'] if attributes[:'admin_credentials']

  self.private_endpoint = attributes[:'privateEndpoint'] if attributes[:'privateEndpoint']

  raise 'You cannot provide both :privateEndpoint and :private_endpoint' if attributes.key?(:'privateEndpoint') && attributes.key?(:'private_endpoint')

  self.private_endpoint = attributes[:'private_endpoint'] if attributes[:'private_endpoint']

  self.vault_details = attributes[:'vaultDetails'] if attributes[:'vaultDetails']

  raise 'You cannot provide both :vaultDetails and :vault_details' if attributes.key?(:'vaultDetails') && attributes.key?(:'vault_details')

  self.vault_details = attributes[:'vault_details'] if attributes[:'vault_details']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

  raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

  self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']
end

Instance Attribute Details

#admin_credentialsOCI::DatabaseMigration::Models::AdminCredentials



88
89
90
# File 'lib/oci/database_migration/models/connection.rb', line 88

def admin_credentials
  @admin_credentials
end

#certificate_tdnString

This name is the distinguished name used while creating the certificate on target database.

Returns:

  • (String)


82
83
84
# File 'lib/oci/database_migration/models/connection.rb', line 82

def certificate_tdn
  @certificate_tdn
end

#compartment_idString

**[Required]** OCID of the compartment

Returns:

  • (String)


44
45
46
# File 'lib/oci/database_migration/models/connection.rb', line 44

def compartment_id
  @compartment_id
end

#connect_descriptorOCI::DatabaseMigration::Models::ConnectDescriptor



72
73
74
# File 'lib/oci/database_migration/models/connection.rb', line 72

def connect_descriptor
  @connect_descriptor
end

#credentials_secret_idString

OCID of the Secret in the OCI vault containing the Database Connection credentials.

Returns:

  • (String)


77
78
79
# File 'lib/oci/database_migration/models/connection.rb', line 77

def credentials_secret_id
  @credentials_secret_id
end

#database_idString

The OCID of the cloud database.

Returns:

  • (String)


69
70
71
# File 'lib/oci/database_migration/models/connection.rb', line 69

def database_id
  @database_id
end

#database_typeString

**[Required]** Database connection type.

Returns:

  • (String)


49
50
51
# File 'lib/oci/database_migration/models/connection.rb', line 49

def database_type
  @database_type
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


127
128
129
# File 'lib/oci/database_migration/models/connection.rb', line 127

def defined_tags
  @defined_tags
end

#display_nameString

**[Required]** Database Connection display name identifier.

Returns:

  • (String)


64
65
66
# File 'lib/oci/database_migration/models/connection.rb', line 64

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`

Returns:

  • (Hash<String, String>)


121
122
123
# File 'lib/oci/database_migration/models/connection.rb', line 121

def freeform_tags
  @freeform_tags
end

#idString

**[Required]** The OCID of the resource

Returns:

  • (String)


39
40
41
# File 'lib/oci/database_migration/models/connection.rb', line 39

def id
  @id
end

#is_dedicatedBOOLEAN

True if the Autonomous Connection is dedicated. Not provided for Non-Autonomous Connections.

Returns:

  • (BOOLEAN)


59
60
61
# File 'lib/oci/database_migration/models/connection.rb', line 59

def is_dedicated
  @is_dedicated
end

#lifecycle_detailsString

A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.

Returns:

  • (String)


105
106
107
# File 'lib/oci/database_migration/models/connection.rb', line 105

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

**[Required]** The current state of the Connection resource.

Returns:

  • (String)


99
100
101
# File 'lib/oci/database_migration/models/connection.rb', line 99

def lifecycle_state
  @lifecycle_state
end

#manual_database_sub_typeString

Database manual connection subtype. This value can only be specified for manual connections.

Returns:

  • (String)


54
55
56
# File 'lib/oci/database_migration/models/connection.rb', line 54

def manual_database_sub_type
  @manual_database_sub_type
end

#private_endpointOCI::DatabaseMigration::Models::PrivateEndpointDetails



91
92
93
# File 'lib/oci/database_migration/models/connection.rb', line 91

def private_endpoint
  @private_endpoint
end

#ssh_detailsOCI::DatabaseMigration::Models::SshDetails



85
86
87
# File 'lib/oci/database_migration/models/connection.rb', line 85

def ssh_details
  @ssh_details
end

#system_tagsHash<String, Hash<String, Object>>

Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"free-tier-retained": "true"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


133
134
135
# File 'lib/oci/database_migration/models/connection.rb', line 133

def system_tags
  @system_tags
end

#time_createdDateTime

**[Required]** The time the Connection resource was created. An RFC3339 formatted datetime string.

Returns:

  • (DateTime)


110
111
112
# File 'lib/oci/database_migration/models/connection.rb', line 110

def time_created
  @time_created
end

#time_updatedDateTime

The time of the last Connection resource details update. An RFC3339 formatted datetime string.

Returns:

  • (DateTime)


115
116
117
# File 'lib/oci/database_migration/models/connection.rb', line 115

def time_updated
  @time_updated
end

#vault_detailsOCI::DatabaseMigration::Models::VaultDetails



94
95
96
# File 'lib/oci/database_migration/models/connection.rb', line 94

def vault_details
  @vault_details
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/oci/database_migration/models/connection.rb', line 136

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'compartment_id': :'compartmentId',
    'database_type': :'databaseType',
    'manual_database_sub_type': :'manualDatabaseSubType',
    'is_dedicated': :'isDedicated',
    'display_name': :'displayName',
    'database_id': :'databaseId',
    'connect_descriptor': :'connectDescriptor',
    'credentials_secret_id': :'credentialsSecretId',
    'certificate_tdn': :'certificateTdn',
    'ssh_details': :'sshDetails',
    'admin_credentials': :'adminCredentials',
    'private_endpoint': :'privateEndpoint',
    'vault_details': :'vaultDetails',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/oci/database_migration/models/connection.rb', line 165

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'compartment_id': :'String',
    'database_type': :'String',
    'manual_database_sub_type': :'String',
    'is_dedicated': :'BOOLEAN',
    'display_name': :'String',
    'database_id': :'String',
    'connect_descriptor': :'OCI::DatabaseMigration::Models::ConnectDescriptor',
    'credentials_secret_id': :'String',
    'certificate_tdn': :'String',
    'ssh_details': :'OCI::DatabaseMigration::Models::SshDetails',
    'admin_credentials': :'OCI::DatabaseMigration::Models::AdminCredentials',
    'private_endpoint': :'OCI::DatabaseMigration::Models::PrivateEndpointDetails',
    'vault_details': :'OCI::DatabaseMigration::Models::VaultDetails',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
# File 'lib/oci/database_migration/models/connection.rb', line 397

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    database_type == other.database_type &&
    manual_database_sub_type == other.manual_database_sub_type &&
    is_dedicated == other.is_dedicated &&
    display_name == other.display_name &&
    database_id == other.database_id &&
    connect_descriptor == other.connect_descriptor &&
    credentials_secret_id == other.credentials_secret_id &&
    certificate_tdn == other.certificate_tdn &&
    ssh_details == other.ssh_details &&
    admin_credentials == other.admin_credentials &&
    private_endpoint == other.private_endpoint &&
    vault_details == other.vault_details &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
# File 'lib/oci/database_migration/models/connection.rb', line 447

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


427
428
429
# File 'lib/oci/database_migration/models/connection.rb', line 427

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



436
437
438
# File 'lib/oci/database_migration/models/connection.rb', line 436

def hash
  [id, compartment_id, database_type, manual_database_sub_type, is_dedicated, display_name, database_id, connect_descriptor, credentials_secret_id, certificate_tdn, ssh_details, admin_credentials, private_endpoint, vault_details, lifecycle_state, lifecycle_details, time_created, time_updated, freeform_tags, defined_tags, system_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



480
481
482
483
484
485
486
487
488
489
# File 'lib/oci/database_migration/models/connection.rb', line 480

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



474
475
476
# File 'lib/oci/database_migration/models/connection.rb', line 474

def to_s
  to_hash.to_s
end