Class: OCI::DatabaseMigration::Models::ConnectionSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database_migration/models/connection_summary.rb

Overview

Database Connection Summary.

Constant Summary collapse

DATABASE_TYPE_ENUM =
[
  DATABASE_TYPE_MANUAL = 'MANUAL'.freeze,
  DATABASE_TYPE_AUTONOMOUS = 'AUTONOMOUS'.freeze,
  DATABASE_TYPE_USER_MANAGED_OCI = 'USER_MANAGED_OCI'.freeze,
  DATABASE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
MANUAL_DATABASE_SUB_TYPE_ENUM =
[
  MANUAL_DATABASE_SUB_TYPE_ORACLE = 'ORACLE'.freeze,
  MANUAL_DATABASE_SUB_TYPE_RDS_ORACLE = 'RDS_ORACLE'.freeze,
  MANUAL_DATABASE_SUB_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ConnectionSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :database_type (String)

    The value to assign to the #database_type property

  • :manual_database_sub_type (String)

    The value to assign to the #manual_database_sub_type property

  • :is_dedicated (BOOLEAN)

    The value to assign to the #is_dedicated property

  • :display_name (String)

    The value to assign to the #display_name property

  • :database_id (String)

    The value to assign to the #database_id property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :time_updated (DateTime)

    The value to assign to the #time_updated property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :lifecycle_details (String)

    The value to assign to the #lifecycle_details property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property

  • :system_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #system_tags property



174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/oci/database_migration/models/connection_summary.rb', line 174

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.database_type = attributes[:'databaseType'] if attributes[:'databaseType']

  raise 'You cannot provide both :databaseType and :database_type' if attributes.key?(:'databaseType') && attributes.key?(:'database_type')

  self.database_type = attributes[:'database_type'] if attributes[:'database_type']

  self.manual_database_sub_type = attributes[:'manualDatabaseSubType'] if attributes[:'manualDatabaseSubType']
  self.manual_database_sub_type = "ORACLE" if manual_database_sub_type.nil? && !attributes.key?(:'manualDatabaseSubType') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :manualDatabaseSubType and :manual_database_sub_type' if attributes.key?(:'manualDatabaseSubType') && attributes.key?(:'manual_database_sub_type')

  self.manual_database_sub_type = attributes[:'manual_database_sub_type'] if attributes[:'manual_database_sub_type']
  self.manual_database_sub_type = "ORACLE" if manual_database_sub_type.nil? && !attributes.key?(:'manualDatabaseSubType') && !attributes.key?(:'manual_database_sub_type') # rubocop:disable Style/StringLiterals

  self.is_dedicated = attributes[:'isDedicated'] unless attributes[:'isDedicated'].nil?

  raise 'You cannot provide both :isDedicated and :is_dedicated' if attributes.key?(:'isDedicated') && attributes.key?(:'is_dedicated')

  self.is_dedicated = attributes[:'is_dedicated'] unless attributes[:'is_dedicated'].nil?

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.database_id = attributes[:'databaseId'] if attributes[:'databaseId']

  raise 'You cannot provide both :databaseId and :database_id' if attributes.key?(:'databaseId') && attributes.key?(:'database_id')

  self.database_id = attributes[:'database_id'] if attributes[:'database_id']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

  raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

  self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']
end

Instance Attribute Details

#compartment_idString

**[Required]** OCID of the compartment

Returns:

  • (String)


44
45
46
# File 'lib/oci/database_migration/models/connection_summary.rb', line 44

def compartment_id
  @compartment_id
end

#database_idString

The OCID of the cloud database.

Returns:

  • (String)


69
70
71
# File 'lib/oci/database_migration/models/connection_summary.rb', line 69

def database_id
  @database_id
end

#database_typeString

**[Required]** Database connection type.

Returns:

  • (String)


49
50
51
# File 'lib/oci/database_migration/models/connection_summary.rb', line 49

def database_type
  @database_type
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


102
103
104
# File 'lib/oci/database_migration/models/connection_summary.rb', line 102

def defined_tags
  @defined_tags
end

#display_nameString

**[Required]** Database Connection display name identifier.

Returns:

  • (String)


64
65
66
# File 'lib/oci/database_migration/models/connection_summary.rb', line 64

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`

Returns:

  • (Hash<String, String>)


96
97
98
# File 'lib/oci/database_migration/models/connection_summary.rb', line 96

def freeform_tags
  @freeform_tags
end

#idString

**[Required]** The OCID of the resource

Returns:

  • (String)


39
40
41
# File 'lib/oci/database_migration/models/connection_summary.rb', line 39

def id
  @id
end

#is_dedicatedBOOLEAN

True if the Autonomous Connection is dedicated. Not provided for Non-Autonomous Connections.

Returns:

  • (BOOLEAN)


59
60
61
# File 'lib/oci/database_migration/models/connection_summary.rb', line 59

def is_dedicated
  @is_dedicated
end

#lifecycle_detailsString

A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.

Returns:

  • (String)


90
91
92
# File 'lib/oci/database_migration/models/connection_summary.rb', line 90

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

**[Required]** The current state of the Connection resource.

Returns:

  • (String)


84
85
86
# File 'lib/oci/database_migration/models/connection_summary.rb', line 84

def lifecycle_state
  @lifecycle_state
end

#manual_database_sub_typeString

Database manual connection subtype. This value can only be specified for manual connections.

Returns:

  • (String)


54
55
56
# File 'lib/oci/database_migration/models/connection_summary.rb', line 54

def manual_database_sub_type
  @manual_database_sub_type
end

#system_tagsHash<String, Hash<String, Object>>

Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"free-tier-retained": "true"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


108
109
110
# File 'lib/oci/database_migration/models/connection_summary.rb', line 108

def system_tags
  @system_tags
end

#time_createdDateTime

**[Required]** The time the Connection resource was created. An RFC3339 formatted datetime string.

Returns:

  • (DateTime)


74
75
76
# File 'lib/oci/database_migration/models/connection_summary.rb', line 74

def time_created
  @time_created
end

#time_updatedDateTime

The time of the last Connection resource details update. An RFC3339 formatted datetime string.

Returns:

  • (DateTime)


79
80
81
# File 'lib/oci/database_migration/models/connection_summary.rb', line 79

def time_updated
  @time_updated
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/oci/database_migration/models/connection_summary.rb', line 111

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'compartment_id': :'compartmentId',
    'database_type': :'databaseType',
    'manual_database_sub_type': :'manualDatabaseSubType',
    'is_dedicated': :'isDedicated',
    'display_name': :'displayName',
    'database_id': :'databaseId',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/oci/database_migration/models/connection_summary.rb', line 133

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'compartment_id': :'String',
    'database_type': :'String',
    'manual_database_sub_type': :'String',
    'is_dedicated': :'BOOLEAN',
    'display_name': :'String',
    'database_id': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/oci/database_migration/models/connection_summary.rb', line 309

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    database_type == other.database_type &&
    manual_database_sub_type == other.manual_database_sub_type &&
    is_dedicated == other.is_dedicated &&
    display_name == other.display_name &&
    database_id == other.database_id &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
# File 'lib/oci/database_migration/models/connection_summary.rb', line 352

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


332
333
334
# File 'lib/oci/database_migration/models/connection_summary.rb', line 332

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



341
342
343
# File 'lib/oci/database_migration/models/connection_summary.rb', line 341

def hash
  [id, compartment_id, database_type, manual_database_sub_type, is_dedicated, display_name, database_id, time_created, time_updated, lifecycle_state, lifecycle_details, freeform_tags, defined_tags, system_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



385
386
387
388
389
390
391
392
393
394
# File 'lib/oci/database_migration/models/connection_summary.rb', line 385

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



379
380
381
# File 'lib/oci/database_migration/models/connection_summary.rb', line 379

def to_s
  to_hash.to_s
end