Class: OCI::DatabaseMigration::Models::CreateDataTransferMediumDetails
- Inherits:
-
Object
- Object
- OCI::DatabaseMigration::Models::CreateDataTransferMediumDetails
- Defined in:
- lib/oci/database_migration/models/create_data_transfer_medium_details.rb
Overview
Data Transfer Medium details for the Migration. If not specified, it will default to Database Link. Only one type of data transfer medium can be specified, except for the case of Amazon RDS Oracle as source, where Object Storage Details along with AwsS3Details are required.
Instance Attribute Summary collapse
- #aws_s3_details ⇒ OCI::DatabaseMigration::Models::CreateAwsS3Details
- #database_link_details ⇒ OCI::DatabaseMigration::Models::CreateDatabaseLinkDetails
- #object_storage_details ⇒ OCI::DatabaseMigration::Models::CreateObjectStoreBucket
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateDataTransferMediumDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateDataTransferMediumDetails
Initializes the object
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/oci/database_migration/models/create_data_transfer_medium_details.rb', line 53 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.database_link_details = attributes[:'databaseLinkDetails'] if attributes[:'databaseLinkDetails'] raise 'You cannot provide both :databaseLinkDetails and :database_link_details' if attributes.key?(:'databaseLinkDetails') && attributes.key?(:'database_link_details') self.database_link_details = attributes[:'database_link_details'] if attributes[:'database_link_details'] self.object_storage_details = attributes[:'objectStorageDetails'] if attributes[:'objectStorageDetails'] raise 'You cannot provide both :objectStorageDetails and :object_storage_details' if attributes.key?(:'objectStorageDetails') && attributes.key?(:'object_storage_details') self.object_storage_details = attributes[:'object_storage_details'] if attributes[:'object_storage_details'] self.aws_s3_details = attributes[:'awsS3Details'] if attributes[:'awsS3Details'] raise 'You cannot provide both :awsS3Details and :aws_s3_details' if attributes.key?(:'awsS3Details') && attributes.key?(:'aws_s3_details') self.aws_s3_details = attributes[:'aws_s3_details'] if attributes[:'aws_s3_details'] end |
Instance Attribute Details
#aws_s3_details ⇒ OCI::DatabaseMigration::Models::CreateAwsS3Details
20 21 22 |
# File 'lib/oci/database_migration/models/create_data_transfer_medium_details.rb', line 20 def aws_s3_details @aws_s3_details end |
#database_link_details ⇒ OCI::DatabaseMigration::Models::CreateDatabaseLinkDetails
14 15 16 |
# File 'lib/oci/database_migration/models/create_data_transfer_medium_details.rb', line 14 def database_link_details @database_link_details end |
#object_storage_details ⇒ OCI::DatabaseMigration::Models::CreateObjectStoreBucket
17 18 19 |
# File 'lib/oci/database_migration/models/create_data_transfer_medium_details.rb', line 17 def object_storage_details @object_storage_details end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
23 24 25 26 27 28 29 30 31 |
# File 'lib/oci/database_migration/models/create_data_transfer_medium_details.rb', line 23 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'database_link_details': :'databaseLinkDetails', 'object_storage_details': :'objectStorageDetails', 'aws_s3_details': :'awsS3Details' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
34 35 36 37 38 39 40 41 42 |
# File 'lib/oci/database_migration/models/create_data_transfer_medium_details.rb', line 34 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'database_link_details': :'OCI::DatabaseMigration::Models::CreateDatabaseLinkDetails', 'object_storage_details': :'OCI::DatabaseMigration::Models::CreateObjectStoreBucket', 'aws_s3_details': :'OCI::DatabaseMigration::Models::CreateAwsS3Details' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
85 86 87 88 89 90 91 92 |
# File 'lib/oci/database_migration/models/create_data_transfer_medium_details.rb', line 85 def ==(other) return true if equal?(other) self.class == other.class && database_link_details == other.database_link_details && object_storage_details == other.object_storage_details && aws_s3_details == other.aws_s3_details end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/oci/database_migration/models/create_data_transfer_medium_details.rb', line 117 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
97 98 99 |
# File 'lib/oci/database_migration/models/create_data_transfer_medium_details.rb', line 97 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
106 107 108 |
# File 'lib/oci/database_migration/models/create_data_transfer_medium_details.rb', line 106 def hash [database_link_details, object_storage_details, aws_s3_details].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
150 151 152 153 154 155 156 157 158 159 |
# File 'lib/oci/database_migration/models/create_data_transfer_medium_details.rb', line 150 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
144 145 146 |
# File 'lib/oci/database_migration/models/create_data_transfer_medium_details.rb', line 144 def to_s to_hash.to_s end |