Class: DatabaseMigration::Models::Job

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database_migration/models/job.rb

Overview

Results of a Database Connection search. Contains DatabaseConnectionSummary items.

Constant Summary collapse

TYPE_ENUM =
[
  TYPE_EVALUATION = 'EVALUATION'.freeze,
  TYPE_MIGRATION = 'MIGRATION'.freeze,
  TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_ACCEPTED = 'ACCEPTED'.freeze,
  LIFECYCLE_STATE_IN_PROGRESS = 'IN_PROGRESS'.freeze,
  LIFECYCLE_STATE_UNKNOWN = 'UNKNOWN'.freeze,
  LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_SUCCEEDED = 'SUCCEEDED'.freeze,
  LIFECYCLE_STATE_WAITING = 'WAITING'.freeze,
  LIFECYCLE_STATE_CANCELING = 'CANCELING'.freeze,
  LIFECYCLE_STATE_CANCELED = 'CANCELED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Job

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/oci/database_migration/models/job.rb', line 159

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.migration_id = attributes[:'migrationId'] if attributes[:'migrationId']

  raise 'You cannot provide both :migrationId and :migration_id' if attributes.key?(:'migrationId') && attributes.key?(:'migration_id')

  self.migration_id = attributes[:'migration_id'] if attributes[:'migration_id']

  self.type = attributes[:'type'] if attributes[:'type']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.progress = attributes[:'progress'] if attributes[:'progress']

  self.unsupported_objects = attributes[:'unsupportedObjects'] if attributes[:'unsupportedObjects']

  raise 'You cannot provide both :unsupportedObjects and :unsupported_objects' if attributes.key?(:'unsupportedObjects') && attributes.key?(:'unsupported_objects')

  self.unsupported_objects = attributes[:'unsupported_objects'] if attributes[:'unsupported_objects']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

  raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

  self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']
end

Instance Attribute Details

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


90
91
92
# File 'lib/oci/database_migration/models/job.rb', line 90

def defined_tags
  @defined_tags
end

#display_nameString

**[Required]** Name of the job.

Returns:

  • (String)


39
40
41
# File 'lib/oci/database_migration/models/job.rb', line 39

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`

Returns:

  • (Hash<String, String>)


84
85
86
# File 'lib/oci/database_migration/models/job.rb', line 84

def freeform_tags
  @freeform_tags
end

#idString

**[Required]** The OCID of the Migration Job.

Returns:

  • (String)


34
35
36
# File 'lib/oci/database_migration/models/job.rb', line 34

def id
  @id
end

#lifecycle_detailsString

A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.

Returns:

  • (String)


78
79
80
# File 'lib/oci/database_migration/models/job.rb', line 78

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

**[Required]** The current state of the migration job.

Returns:

  • (String)


72
73
74
# File 'lib/oci/database_migration/models/job.rb', line 72

def lifecycle_state
  @lifecycle_state
end

#migration_idString

**[Required]** The OCID of the Migration that this job belongs to.

Returns:

  • (String)


44
45
46
# File 'lib/oci/database_migration/models/job.rb', line 44

def migration_id
  @migration_id
end

#progressOCI::DatabaseMigration::Models::MigrationJobProgressResource



62
63
64
# File 'lib/oci/database_migration/models/job.rb', line 62

def progress
  @progress
end

#system_tagsHash<String, Hash<String, Object>>

Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"free-tier-retained": "true"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


96
97
98
# File 'lib/oci/database_migration/models/job.rb', line 96

def system_tags
  @system_tags
end

#time_createdDateTime

**[Required]** The time the Migration Job was created. An RFC3339 formatted datetime string

Returns:

  • (DateTime)


54
55
56
# File 'lib/oci/database_migration/models/job.rb', line 54

def time_created
  @time_created
end

#time_updatedDateTime

The time the Migration Job was last updated. An RFC3339 formatted datetime string

Returns:

  • (DateTime)


59
60
61
# File 'lib/oci/database_migration/models/job.rb', line 59

def time_updated
  @time_updated
end

#typeString

**[Required]** The job type.

Returns:

  • (String)


49
50
51
# File 'lib/oci/database_migration/models/job.rb', line 49

def type
  @type
end

#unsupported_objectsArray<OCI::DatabaseMigration::Models::UnsupportedDatabaseObject>

Database objects not supported.



67
68
69
# File 'lib/oci/database_migration/models/job.rb', line 67

def unsupported_objects
  @unsupported_objects
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/oci/database_migration/models/job.rb', line 99

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'display_name': :'displayName',
    'migration_id': :'migrationId',
    'type': :'type',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'progress': :'progress',
    'unsupported_objects': :'unsupportedObjects',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/oci/database_migration/models/job.rb', line 120

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'display_name': :'String',
    'migration_id': :'String',
    'type': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'progress': :'OCI::DatabaseMigration::Models::MigrationJobProgressResource',
    'unsupported_objects': :'Array<OCI::DatabaseMigration::Models::UnsupportedDatabaseObject>',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'lib/oci/database_migration/models/job.rb', line 265

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    display_name == other.display_name &&
    migration_id == other.migration_id &&
    type == other.type &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    progress == other.progress &&
    unsupported_objects == other.unsupported_objects &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/oci/database_migration/models/job.rb', line 307

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


287
288
289
# File 'lib/oci/database_migration/models/job.rb', line 287

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



296
297
298
# File 'lib/oci/database_migration/models/job.rb', line 296

def hash
  [id, display_name, migration_id, type, time_created, time_updated, progress, unsupported_objects, lifecycle_state, lifecycle_details, freeform_tags, defined_tags, system_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



340
341
342
343
344
345
346
347
348
349
# File 'lib/oci/database_migration/models/job.rb', line 340

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



334
335
336
# File 'lib/oci/database_migration/models/job.rb', line 334

def to_s
  to_hash.to_s
end