Class: OCI::DatabaseMigration::Models::JobSummary
- Inherits:
-
Object
- Object
- OCI::DatabaseMigration::Models::JobSummary
- Defined in:
- lib/oci/database_migration/models/job_summary.rb
Overview
Job description
Constant Summary collapse
- TYPE_ENUM =
[ TYPE_EVALUATION = 'EVALUATION'.freeze, TYPE_MIGRATION = 'MIGRATION'.freeze, TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_ACCEPTED = 'ACCEPTED'.freeze, LIFECYCLE_STATE_IN_PROGRESS = 'IN_PROGRESS'.freeze, LIFECYCLE_STATE_UNKNOWN = 'UNKNOWN'.freeze, LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_SUCCEEDED = 'SUCCEEDED'.freeze, LIFECYCLE_STATE_WAITING = 'WAITING'.freeze, LIFECYCLE_STATE_CANCELING = 'CANCELING'.freeze, LIFECYCLE_STATE_CANCELED = 'CANCELED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
[Required] Name of the job.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
[Required] The OCID of the Migration Job.
-
#lifecycle_details ⇒ String
A message describing the current state in more detail.
-
#lifecycle_state ⇒ String
[Required] The current state of the migration Deployment.
-
#migration_id ⇒ String
[Required] The OCID of the Migration that this job belongs to.
- #progress ⇒ OCI::DatabaseMigration::Models::MigrationJobProgressSummary
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys.
-
#time_created ⇒ DateTime
[Required] The time the Migration Job was created.
-
#time_updated ⇒ DateTime
The time the Migration Job was last updated.
-
#type ⇒ String
[Required] The job type.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ JobSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ JobSummary
Initializes the object
151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/oci/database_migration/models/job_summary.rb', line 151 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.migration_id = attributes[:'migrationId'] if attributes[:'migrationId'] raise 'You cannot provide both :migrationId and :migration_id' if attributes.key?(:'migrationId') && attributes.key?(:'migration_id') self.migration_id = attributes[:'migration_id'] if attributes[:'migration_id'] self.type = attributes[:'type'] if attributes[:'type'] self.progress = attributes[:'progress'] if attributes[:'progress'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
85 86 87 |
# File 'lib/oci/database_migration/models/job_summary.rb', line 85 def @defined_tags end |
#display_name ⇒ String
[Required] Name of the job.
39 40 41 |
# File 'lib/oci/database_migration/models/job_summary.rb', line 39 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`
79 80 81 |
# File 'lib/oci/database_migration/models/job_summary.rb', line 79 def @freeform_tags end |
#id ⇒ String
[Required] The OCID of the Migration Job.
34 35 36 |
# File 'lib/oci/database_migration/models/job_summary.rb', line 34 def id @id end |
#lifecycle_details ⇒ String
A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
73 74 75 |
# File 'lib/oci/database_migration/models/job_summary.rb', line 73 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
[Required] The current state of the migration Deployment.
67 68 69 |
# File 'lib/oci/database_migration/models/job_summary.rb', line 67 def lifecycle_state @lifecycle_state end |
#migration_id ⇒ String
[Required] The OCID of the Migration that this job belongs to.
44 45 46 |
# File 'lib/oci/database_migration/models/job_summary.rb', line 44 def migration_id @migration_id end |
#progress ⇒ OCI::DatabaseMigration::Models::MigrationJobProgressSummary
52 53 54 |
# File 'lib/oci/database_migration/models/job_summary.rb', line 52 def progress @progress end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys. These predefined keys are scoped to namespaces. Example: ‘{"free-tier-retained": "true"}`
91 92 93 |
# File 'lib/oci/database_migration/models/job_summary.rb', line 91 def @system_tags end |
#time_created ⇒ DateTime
[Required] The time the Migration Job was created. An RFC3339 formatted datetime string
57 58 59 |
# File 'lib/oci/database_migration/models/job_summary.rb', line 57 def time_created @time_created end |
#time_updated ⇒ DateTime
The time the Migration Job was last updated. An RFC3339 formatted datetime string
62 63 64 |
# File 'lib/oci/database_migration/models/job_summary.rb', line 62 def time_updated @time_updated end |
#type ⇒ String
[Required] The job type.
49 50 51 |
# File 'lib/oci/database_migration/models/job_summary.rb', line 49 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/oci/database_migration/models/job_summary.rb', line 94 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'migration_id': :'migrationId', 'type': :'type', 'progress': :'progress', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/oci/database_migration/models/job_summary.rb', line 114 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'migration_id': :'String', 'type': :'String', 'progress': :'OCI::DatabaseMigration::Models::MigrationJobProgressSummary', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'lib/oci/database_migration/models/job_summary.rb', line 251 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && migration_id == other.migration_id && type == other.type && progress == other.progress && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 |
# File 'lib/oci/database_migration/models/job_summary.rb', line 292 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
272 273 274 |
# File 'lib/oci/database_migration/models/job_summary.rb', line 272 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
281 282 283 |
# File 'lib/oci/database_migration/models/job_summary.rb', line 281 def hash [id, display_name, migration_id, type, progress, time_created, time_updated, lifecycle_state, lifecycle_details, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
325 326 327 328 329 330 331 332 333 334 |
# File 'lib/oci/database_migration/models/job_summary.rb', line 325 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
319 320 321 |
# File 'lib/oci/database_migration/models/job_summary.rb', line 319 def to_s to_hash.to_s end |