Class: DatabaseMigration::Models::Migration

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database_migration/models/migration.rb

Overview

Migration resource

Constant Summary collapse

TYPE_ENUM =
[
  TYPE_ONLINE = 'ONLINE'.freeze,
  TYPE_OFFLINE = 'OFFLINE'.freeze,
  TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
WAIT_AFTER_ENUM =
[
  WAIT_AFTER_ODMS_VALIDATE_TGT = 'ODMS_VALIDATE_TGT'.freeze,
  WAIT_AFTER_ODMS_VALIDATE_SRC = 'ODMS_VALIDATE_SRC'.freeze,
  WAIT_AFTER_ODMS_VALIDATE_PREMIGRATION_ADVISOR = 'ODMS_VALIDATE_PREMIGRATION_ADVISOR'.freeze,
  WAIT_AFTER_ODMS_VALIDATE_GG_HUB = 'ODMS_VALIDATE_GG_HUB'.freeze,
  WAIT_AFTER_ODMS_VALIDATE_DATAPUMP_SETTINGS = 'ODMS_VALIDATE_DATAPUMP_SETTINGS'.freeze,
  WAIT_AFTER_ODMS_VALIDATE_DATAPUMP_SETTINGS_SRC = 'ODMS_VALIDATE_DATAPUMP_SETTINGS_SRC'.freeze,
  WAIT_AFTER_ODMS_VALIDATE_DATAPUMP_SETTINGS_TGT = 'ODMS_VALIDATE_DATAPUMP_SETTINGS_TGT'.freeze,
  WAIT_AFTER_ODMS_VALIDATE_DATAPUMP_SRC = 'ODMS_VALIDATE_DATAPUMP_SRC'.freeze,
  WAIT_AFTER_ODMS_VALIDATE_DATAPUMP_ESTIMATE_SRC = 'ODMS_VALIDATE_DATAPUMP_ESTIMATE_SRC'.freeze,
  WAIT_AFTER_ODMS_VALIDATE = 'ODMS_VALIDATE'.freeze,
  WAIT_AFTER_ODMS_PREPARE = 'ODMS_PREPARE'.freeze,
  WAIT_AFTER_ODMS_INITIAL_LOAD_EXPORT = 'ODMS_INITIAL_LOAD_EXPORT'.freeze,
  WAIT_AFTER_ODMS_DATA_UPLOAD = 'ODMS_DATA_UPLOAD'.freeze,
  WAIT_AFTER_ODMS_INITIAL_LOAD_IMPORT = 'ODMS_INITIAL_LOAD_IMPORT'.freeze,
  WAIT_AFTER_ODMS_POST_INITIAL_LOAD = 'ODMS_POST_INITIAL_LOAD'.freeze,
  WAIT_AFTER_ODMS_PREPARE_REPLICATION_TARGET = 'ODMS_PREPARE_REPLICATION_TARGET'.freeze,
  WAIT_AFTER_ODMS_MONITOR_REPLICATION_LAG = 'ODMS_MONITOR_REPLICATION_LAG'.freeze,
  WAIT_AFTER_ODMS_SWITCHOVER = 'ODMS_SWITCHOVER'.freeze,
  WAIT_AFTER_ODMS_CLEANUP = 'ODMS_CLEANUP'.freeze,
  WAIT_AFTER_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_IN_PROGRESS = 'IN_PROGRESS'.freeze,
  LIFECYCLE_STATE_ACCEPTED = 'ACCEPTED'.freeze,
  LIFECYCLE_STATE_SUCCEEDED = 'SUCCEEDED'.freeze,
  LIFECYCLE_STATE_CANCELED = 'CANCELED'.freeze,
  LIFECYCLE_STATE_WAITING = 'WAITING'.freeze,
  LIFECYCLE_STATE_NEEDS_ATTENTION = 'NEEDS_ATTENTION'.freeze,
  LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_DETAILS_ENUM =
[
  LIFECYCLE_DETAILS_READY = 'READY'.freeze,
  LIFECYCLE_DETAILS_ABORTING = 'ABORTING'.freeze,
  LIFECYCLE_DETAILS_VALIDATING = 'VALIDATING'.freeze,
  LIFECYCLE_DETAILS_VALIDATED = 'VALIDATED'.freeze,
  LIFECYCLE_DETAILS_WAITING = 'WAITING'.freeze,
  LIFECYCLE_DETAILS_MIGRATING = 'MIGRATING'.freeze,
  LIFECYCLE_DETAILS_DONE = 'DONE'.freeze,
  LIFECYCLE_DETAILS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Migration

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
# File 'lib/oci/database_migration/models/migration.rb', line 300

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.type = attributes[:'type'] if attributes[:'type']

  self.wait_after = attributes[:'waitAfter'] if attributes[:'waitAfter']

  raise 'You cannot provide both :waitAfter and :wait_after' if attributes.key?(:'waitAfter') && attributes.key?(:'wait_after')

  self.wait_after = attributes[:'wait_after'] if attributes[:'wait_after']

  self.agent_id = attributes[:'agentId'] if attributes[:'agentId']

  raise 'You cannot provide both :agentId and :agent_id' if attributes.key?(:'agentId') && attributes.key?(:'agent_id')

  self.agent_id = attributes[:'agent_id'] if attributes[:'agent_id']

  self.credentials_secret_id = attributes[:'credentialsSecretId'] if attributes[:'credentialsSecretId']

  raise 'You cannot provide both :credentialsSecretId and :credentials_secret_id' if attributes.key?(:'credentialsSecretId') && attributes.key?(:'credentials_secret_id')

  self.credentials_secret_id = attributes[:'credentials_secret_id'] if attributes[:'credentials_secret_id']

  self.source_database_connection_id = attributes[:'sourceDatabaseConnectionId'] if attributes[:'sourceDatabaseConnectionId']

  raise 'You cannot provide both :sourceDatabaseConnectionId and :source_database_connection_id' if attributes.key?(:'sourceDatabaseConnectionId') && attributes.key?(:'source_database_connection_id')

  self.source_database_connection_id = attributes[:'source_database_connection_id'] if attributes[:'source_database_connection_id']

  self.source_container_database_connection_id = attributes[:'sourceContainerDatabaseConnectionId'] if attributes[:'sourceContainerDatabaseConnectionId']

  raise 'You cannot provide both :sourceContainerDatabaseConnectionId and :source_container_database_connection_id' if attributes.key?(:'sourceContainerDatabaseConnectionId') && attributes.key?(:'source_container_database_connection_id')

  self.source_container_database_connection_id = attributes[:'source_container_database_connection_id'] if attributes[:'source_container_database_connection_id']

  self.target_database_connection_id = attributes[:'targetDatabaseConnectionId'] if attributes[:'targetDatabaseConnectionId']

  raise 'You cannot provide both :targetDatabaseConnectionId and :target_database_connection_id' if attributes.key?(:'targetDatabaseConnectionId') && attributes.key?(:'target_database_connection_id')

  self.target_database_connection_id = attributes[:'target_database_connection_id'] if attributes[:'target_database_connection_id']

  self.executing_job_id = attributes[:'executingJobId'] if attributes[:'executingJobId']

  raise 'You cannot provide both :executingJobId and :executing_job_id' if attributes.key?(:'executingJobId') && attributes.key?(:'executing_job_id')

  self.executing_job_id = attributes[:'executing_job_id'] if attributes[:'executing_job_id']

  self.data_transfer_medium_details = attributes[:'dataTransferMediumDetails'] if attributes[:'dataTransferMediumDetails']

  raise 'You cannot provide both :dataTransferMediumDetails and :data_transfer_medium_details' if attributes.key?(:'dataTransferMediumDetails') && attributes.key?(:'data_transfer_medium_details')

  self.data_transfer_medium_details = attributes[:'data_transfer_medium_details'] if attributes[:'data_transfer_medium_details']

  self.dump_transfer_details = attributes[:'dumpTransferDetails'] if attributes[:'dumpTransferDetails']

  raise 'You cannot provide both :dumpTransferDetails and :dump_transfer_details' if attributes.key?(:'dumpTransferDetails') && attributes.key?(:'dump_transfer_details')

  self.dump_transfer_details = attributes[:'dump_transfer_details'] if attributes[:'dump_transfer_details']

  self.datapump_settings = attributes[:'datapumpSettings'] if attributes[:'datapumpSettings']

  raise 'You cannot provide both :datapumpSettings and :datapump_settings' if attributes.key?(:'datapumpSettings') && attributes.key?(:'datapump_settings')

  self.datapump_settings = attributes[:'datapump_settings'] if attributes[:'datapump_settings']

  self.advisor_settings = attributes[:'advisorSettings'] if attributes[:'advisorSettings']

  raise 'You cannot provide both :advisorSettings and :advisor_settings' if attributes.key?(:'advisorSettings') && attributes.key?(:'advisor_settings')

  self.advisor_settings = attributes[:'advisor_settings'] if attributes[:'advisor_settings']

  self.exclude_objects = attributes[:'excludeObjects'] if attributes[:'excludeObjects']

  raise 'You cannot provide both :excludeObjects and :exclude_objects' if attributes.key?(:'excludeObjects') && attributes.key?(:'exclude_objects')

  self.exclude_objects = attributes[:'exclude_objects'] if attributes[:'exclude_objects']

  self.include_objects = attributes[:'includeObjects'] if attributes[:'includeObjects']

  raise 'You cannot provide both :includeObjects and :include_objects' if attributes.key?(:'includeObjects') && attributes.key?(:'include_objects')

  self.include_objects = attributes[:'include_objects'] if attributes[:'include_objects']

  self.golden_gate_details = attributes[:'goldenGateDetails'] if attributes[:'goldenGateDetails']

  raise 'You cannot provide both :goldenGateDetails and :golden_gate_details' if attributes.key?(:'goldenGateDetails') && attributes.key?(:'golden_gate_details')

  self.golden_gate_details = attributes[:'golden_gate_details'] if attributes[:'golden_gate_details']

  self.vault_details = attributes[:'vaultDetails'] if attributes[:'vaultDetails']

  raise 'You cannot provide both :vaultDetails and :vault_details' if attributes.key?(:'vaultDetails') && attributes.key?(:'vault_details')

  self.vault_details = attributes[:'vault_details'] if attributes[:'vault_details']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.time_last_migration = attributes[:'timeLastMigration'] if attributes[:'timeLastMigration']

  raise 'You cannot provide both :timeLastMigration and :time_last_migration' if attributes.key?(:'timeLastMigration') && attributes.key?(:'time_last_migration')

  self.time_last_migration = attributes[:'time_last_migration'] if attributes[:'time_last_migration']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

  raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

  self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']
end

Instance Attribute Details

#advisor_settingsOCI::DatabaseMigration::Models::AdvisorSettings



135
136
137
# File 'lib/oci/database_migration/models/migration.rb', line 135

def advisor_settings
  @advisor_settings
end

#agent_idString

The OCID of the registered on-premises ODMS Agent. Only valid for Offline Migrations.

Returns:

  • (String)


98
99
100
# File 'lib/oci/database_migration/models/migration.rb', line 98

def agent_id
  @agent_id
end

#compartment_idString

**[Required]** OCID of the compartment

Returns:

  • (String)


82
83
84
# File 'lib/oci/database_migration/models/migration.rb', line 82

def compartment_id
  @compartment_id
end

#credentials_secret_idString

OCID of the Secret in the OCI vault containing the Migration credentials. Used to store GoldenGate administrator user credentials.

Returns:

  • (String)


103
104
105
# File 'lib/oci/database_migration/models/migration.rb', line 103

def credentials_secret_id
  @credentials_secret_id
end

#data_transfer_medium_detailsOCI::DatabaseMigration::Models::DataTransferMediumDetails



126
127
128
# File 'lib/oci/database_migration/models/migration.rb', line 126

def data_transfer_medium_details
  @data_transfer_medium_details
end

#datapump_settingsOCI::DatabaseMigration::Models::DataPumpSettings



132
133
134
# File 'lib/oci/database_migration/models/migration.rb', line 132

def datapump_settings
  @datapump_settings
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


189
190
191
# File 'lib/oci/database_migration/models/migration.rb', line 189

def defined_tags
  @defined_tags
end

#display_nameString

**[Required]** Migration Display Name

Returns:

  • (String)


77
78
79
# File 'lib/oci/database_migration/models/migration.rb', line 77

def display_name
  @display_name
end

#dump_transfer_detailsOCI::DatabaseMigration::Models::DumpTransferDetails



129
130
131
# File 'lib/oci/database_migration/models/migration.rb', line 129

def dump_transfer_details
  @dump_transfer_details
end

#exclude_objectsArray<OCI::DatabaseMigration::Models::DatabaseObject>

Database objects to exclude from migration. If 'includeObjects' are specified, only exclude object types can be specified with general wildcards (.*) for owner and objectName.



141
142
143
# File 'lib/oci/database_migration/models/migration.rb', line 141

def exclude_objects
  @exclude_objects
end

#executing_job_idString

OCID of the current ODMS Job in execution for the Migration, if any.

Returns:

  • (String)


123
124
125
# File 'lib/oci/database_migration/models/migration.rb', line 123

def executing_job_id
  @executing_job_id
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`

Returns:

  • (Hash<String, String>)


183
184
185
# File 'lib/oci/database_migration/models/migration.rb', line 183

def freeform_tags
  @freeform_tags
end

#golden_gate_detailsOCI::DatabaseMigration::Models::GoldenGateDetails



149
150
151
# File 'lib/oci/database_migration/models/migration.rb', line 149

def golden_gate_details
  @golden_gate_details
end

#idString

**[Required]** The OCID of the resource

Returns:

  • (String)


72
73
74
# File 'lib/oci/database_migration/models/migration.rb', line 72

def id
  @id
end

#include_objectsArray<OCI::DatabaseMigration::Models::DatabaseObject>

Database objects to include from migration.



146
147
148
# File 'lib/oci/database_migration/models/migration.rb', line 146

def include_objects
  @include_objects
end

#lifecycle_detailsString

Additional status related to the execution and current state of the Migration.

Returns:

  • (String)


177
178
179
# File 'lib/oci/database_migration/models/migration.rb', line 177

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

**[Required]** The current state of the Migration resource.

Returns:

  • (String)


172
173
174
# File 'lib/oci/database_migration/models/migration.rb', line 172

def lifecycle_state
  @lifecycle_state
end

#source_container_database_connection_idString

The OCID of the Source Container Database Connection.

Returns:

  • (String)


113
114
115
# File 'lib/oci/database_migration/models/migration.rb', line 113

def source_container_database_connection_id
  @source_container_database_connection_id
end

#source_database_connection_idString

**[Required]** The OCID of the Source Database Connection.

Returns:

  • (String)


108
109
110
# File 'lib/oci/database_migration/models/migration.rb', line 108

def source_database_connection_id
  @source_database_connection_id
end

#system_tagsHash<String, Hash<String, Object>>

Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"free-tier-retained": "true"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


195
196
197
# File 'lib/oci/database_migration/models/migration.rb', line 195

def system_tags
  @system_tags
end

#target_database_connection_idString

**[Required]** The OCID of the Target Database Connection.

Returns:

  • (String)


118
119
120
# File 'lib/oci/database_migration/models/migration.rb', line 118

def target_database_connection_id
  @target_database_connection_id
end

#time_createdDateTime

**[Required]** The time the Migration was created. An RFC3339 formatted datetime string.

Returns:

  • (DateTime)


157
158
159
# File 'lib/oci/database_migration/models/migration.rb', line 157

def time_created
  @time_created
end

#time_last_migrationDateTime

The time of last Migration. An RFC3339 formatted datetime string.

Returns:

  • (DateTime)


167
168
169
# File 'lib/oci/database_migration/models/migration.rb', line 167

def time_last_migration
  @time_last_migration
end

#time_updatedDateTime

The time of the last Migration details update. An RFC3339 formatted datetime string.

Returns:

  • (DateTime)


162
163
164
# File 'lib/oci/database_migration/models/migration.rb', line 162

def time_updated
  @time_updated
end

#typeString

**[Required]** Migration type.

Returns:

  • (String)


87
88
89
# File 'lib/oci/database_migration/models/migration.rb', line 87

def type
  @type
end

#vault_detailsOCI::DatabaseMigration::Models::VaultDetails



152
153
154
# File 'lib/oci/database_migration/models/migration.rb', line 152

def vault_details
  @vault_details
end

#wait_afterString

Name of a migration phase. The Job will wait after executing this phase until the Resume Job endpoint is called.

Returns:

  • (String)


93
94
95
# File 'lib/oci/database_migration/models/migration.rb', line 93

def wait_after
  @wait_after
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/oci/database_migration/models/migration.rb', line 198

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'display_name': :'displayName',
    'compartment_id': :'compartmentId',
    'type': :'type',
    'wait_after': :'waitAfter',
    'agent_id': :'agentId',
    'credentials_secret_id': :'credentialsSecretId',
    'source_database_connection_id': :'sourceDatabaseConnectionId',
    'source_container_database_connection_id': :'sourceContainerDatabaseConnectionId',
    'target_database_connection_id': :'targetDatabaseConnectionId',
    'executing_job_id': :'executingJobId',
    'data_transfer_medium_details': :'dataTransferMediumDetails',
    'dump_transfer_details': :'dumpTransferDetails',
    'datapump_settings': :'datapumpSettings',
    'advisor_settings': :'advisorSettings',
    'exclude_objects': :'excludeObjects',
    'include_objects': :'includeObjects',
    'golden_gate_details': :'goldenGateDetails',
    'vault_details': :'vaultDetails',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'time_last_migration': :'timeLastMigration',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/oci/database_migration/models/migration.rb', line 233

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'display_name': :'String',
    'compartment_id': :'String',
    'type': :'String',
    'wait_after': :'String',
    'agent_id': :'String',
    'credentials_secret_id': :'String',
    'source_database_connection_id': :'String',
    'source_container_database_connection_id': :'String',
    'target_database_connection_id': :'String',
    'executing_job_id': :'String',
    'data_transfer_medium_details': :'OCI::DatabaseMigration::Models::DataTransferMediumDetails',
    'dump_transfer_details': :'OCI::DatabaseMigration::Models::DumpTransferDetails',
    'datapump_settings': :'OCI::DatabaseMigration::Models::DataPumpSettings',
    'advisor_settings': :'OCI::DatabaseMigration::Models::AdvisorSettings',
    'exclude_objects': :'Array<OCI::DatabaseMigration::Models::DatabaseObject>',
    'include_objects': :'Array<OCI::DatabaseMigration::Models::DatabaseObject>',
    'golden_gate_details': :'OCI::DatabaseMigration::Models::GoldenGateDetails',
    'vault_details': :'OCI::DatabaseMigration::Models::VaultDetails',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'time_last_migration': :'DateTime',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
# File 'lib/oci/database_migration/models/migration.rb', line 520

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    display_name == other.display_name &&
    compartment_id == other.compartment_id &&
    type == other.type &&
    wait_after == other.wait_after &&
    agent_id == other.agent_id &&
    credentials_secret_id == other.credentials_secret_id &&
    source_database_connection_id == other.source_database_connection_id &&
    source_container_database_connection_id == other.source_container_database_connection_id &&
    target_database_connection_id == other.target_database_connection_id &&
    executing_job_id == other.executing_job_id &&
    data_transfer_medium_details == other.data_transfer_medium_details &&
    dump_transfer_details == other.dump_transfer_details &&
    datapump_settings == other.datapump_settings &&
    advisor_settings == other.advisor_settings &&
    exclude_objects == other.exclude_objects &&
    include_objects == other.include_objects &&
    golden_gate_details == other.golden_gate_details &&
    vault_details == other.vault_details &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    time_last_migration == other.time_last_migration &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
# File 'lib/oci/database_migration/models/migration.rb', line 576

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


556
557
558
# File 'lib/oci/database_migration/models/migration.rb', line 556

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



565
566
567
# File 'lib/oci/database_migration/models/migration.rb', line 565

def hash
  [id, display_name, compartment_id, type, wait_after, agent_id, credentials_secret_id, source_database_connection_id, source_container_database_connection_id, target_database_connection_id, executing_job_id, data_transfer_medium_details, dump_transfer_details, datapump_settings, advisor_settings, exclude_objects, include_objects, golden_gate_details, vault_details, time_created, time_updated, time_last_migration, lifecycle_state, lifecycle_details, freeform_tags, defined_tags, system_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



609
610
611
612
613
614
615
616
617
618
# File 'lib/oci/database_migration/models/migration.rb', line 609

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



603
604
605
# File 'lib/oci/database_migration/models/migration.rb', line 603

def to_s
  to_hash.to_s
end