Class: OCI::DatabaseMigration::Models::MigrationSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database_migration/models/migration_summary.rb

Overview

Migration resource

Constant Summary collapse

TYPE_ENUM =
[
  TYPE_ONLINE = 'ONLINE'.freeze,
  TYPE_OFFLINE = 'OFFLINE'.freeze,
  TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_DETAILS_ENUM =
[
  LIFECYCLE_DETAILS_READY = 'READY'.freeze,
  LIFECYCLE_DETAILS_ABORTING = 'ABORTING'.freeze,
  LIFECYCLE_DETAILS_VALIDATING = 'VALIDATING'.freeze,
  LIFECYCLE_DETAILS_VALIDATED = 'VALIDATED'.freeze,
  LIFECYCLE_DETAILS_WAITING = 'WAITING'.freeze,
  LIFECYCLE_DETAILS_MIGRATING = 'MIGRATING'.freeze,
  LIFECYCLE_DETAILS_DONE = 'DONE'.freeze,
  LIFECYCLE_DETAILS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ MigrationSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'lib/oci/database_migration/models/migration_summary.rb', line 207

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.type = attributes[:'type'] if attributes[:'type']

  self.source_database_connection_id = attributes[:'sourceDatabaseConnectionId'] if attributes[:'sourceDatabaseConnectionId']

  raise 'You cannot provide both :sourceDatabaseConnectionId and :source_database_connection_id' if attributes.key?(:'sourceDatabaseConnectionId') && attributes.key?(:'source_database_connection_id')

  self.source_database_connection_id = attributes[:'source_database_connection_id'] if attributes[:'source_database_connection_id']

  self.source_container_database_connection_id = attributes[:'sourceContainerDatabaseConnectionId'] if attributes[:'sourceContainerDatabaseConnectionId']

  raise 'You cannot provide both :sourceContainerDatabaseConnectionId and :source_container_database_connection_id' if attributes.key?(:'sourceContainerDatabaseConnectionId') && attributes.key?(:'source_container_database_connection_id')

  self.source_container_database_connection_id = attributes[:'source_container_database_connection_id'] if attributes[:'source_container_database_connection_id']

  self.target_database_connection_id = attributes[:'targetDatabaseConnectionId'] if attributes[:'targetDatabaseConnectionId']

  raise 'You cannot provide both :targetDatabaseConnectionId and :target_database_connection_id' if attributes.key?(:'targetDatabaseConnectionId') && attributes.key?(:'target_database_connection_id')

  self.target_database_connection_id = attributes[:'target_database_connection_id'] if attributes[:'target_database_connection_id']

  self.executing_job_id = attributes[:'executingJobId'] if attributes[:'executingJobId']

  raise 'You cannot provide both :executingJobId and :executing_job_id' if attributes.key?(:'executingJobId') && attributes.key?(:'executing_job_id')

  self.executing_job_id = attributes[:'executing_job_id'] if attributes[:'executing_job_id']

  self.agent_id = attributes[:'agentId'] if attributes[:'agentId']

  raise 'You cannot provide both :agentId and :agent_id' if attributes.key?(:'agentId') && attributes.key?(:'agent_id')

  self.agent_id = attributes[:'agent_id'] if attributes[:'agent_id']

  self.vault_details = attributes[:'vaultDetails'] if attributes[:'vaultDetails']

  raise 'You cannot provide both :vaultDetails and :vault_details' if attributes.key?(:'vaultDetails') && attributes.key?(:'vault_details')

  self.vault_details = attributes[:'vault_details'] if attributes[:'vault_details']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.time_last_migration = attributes[:'timeLastMigration'] if attributes[:'timeLastMigration']

  raise 'You cannot provide both :timeLastMigration and :time_last_migration' if attributes.key?(:'timeLastMigration') && attributes.key?(:'time_last_migration')

  self.time_last_migration = attributes[:'time_last_migration'] if attributes[:'time_last_migration']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

  raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

  self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']
end

Instance Attribute Details

#agent_idString

The OCID of the registered on-premises ODMS Agent. Only valid for Offline Migrations.

Returns:

  • (String)


83
84
85
# File 'lib/oci/database_migration/models/migration_summary.rb', line 83

def agent_id
  @agent_id
end

#compartment_idString

[Required] OCID of the compartment

Returns:

  • (String)


53
54
55
# File 'lib/oci/database_migration/models/migration_summary.rb', line 53

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


123
124
125
# File 'lib/oci/database_migration/models/migration_summary.rb', line 123

def defined_tags
  @defined_tags
end

#display_nameString

[Required] Migration Display Name

Returns:

  • (String)


48
49
50
# File 'lib/oci/database_migration/models/migration_summary.rb', line 48

def display_name
  @display_name
end

#executing_job_idString

OCID of the current ODMS Job in execution for the Migration, if any.

Returns:

  • (String)


78
79
80
# File 'lib/oci/database_migration/models/migration_summary.rb', line 78

def executing_job_id
  @executing_job_id
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`

Returns:

  • (Hash<String, String>)


117
118
119
# File 'lib/oci/database_migration/models/migration_summary.rb', line 117

def freeform_tags
  @freeform_tags
end

#idString

[Required] The OCID of the resource

Returns:

  • (String)


43
44
45
# File 'lib/oci/database_migration/models/migration_summary.rb', line 43

def id
  @id
end

#lifecycle_detailsString

Additional status related to the execution and current state of the Migration.

Returns:

  • (String)


111
112
113
# File 'lib/oci/database_migration/models/migration_summary.rb', line 111

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

[Required] The current state of the Migration.

Returns:

  • (String)


106
107
108
# File 'lib/oci/database_migration/models/migration_summary.rb', line 106

def lifecycle_state
  @lifecycle_state
end

#source_container_database_connection_idString

The OCID of the Source Container Database Connection.

Returns:

  • (String)


68
69
70
# File 'lib/oci/database_migration/models/migration_summary.rb', line 68

def source_container_database_connection_id
  @source_container_database_connection_id
end

#source_database_connection_idString

[Required] The OCID of the Source Database Connection.

Returns:

  • (String)


63
64
65
# File 'lib/oci/database_migration/models/migration_summary.rb', line 63

def source_database_connection_id
  @source_database_connection_id
end

#system_tagsHash<String, Hash<String, Object>>

Usage of system tag keys. These predefined keys are scoped to namespaces. Example: ‘{"free-tier-retained": "true"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


129
130
131
# File 'lib/oci/database_migration/models/migration_summary.rb', line 129

def system_tags
  @system_tags
end

#target_database_connection_idString

[Required] The OCID of the Target Database Connection.

Returns:

  • (String)


73
74
75
# File 'lib/oci/database_migration/models/migration_summary.rb', line 73

def target_database_connection_id
  @target_database_connection_id
end

#time_createdDateTime

[Required] The time the Migration was created. An RFC3339 formatted datetime string.

Returns:

  • (DateTime)


91
92
93
# File 'lib/oci/database_migration/models/migration_summary.rb', line 91

def time_created
  @time_created
end

#time_last_migrationDateTime

The time of last Migration. An RFC3339 formatted datetime string.

Returns:

  • (DateTime)


101
102
103
# File 'lib/oci/database_migration/models/migration_summary.rb', line 101

def time_last_migration
  @time_last_migration
end

#time_updatedDateTime

The time of the last Migration details update. An RFC3339 formatted datetime string.

Returns:

  • (DateTime)


96
97
98
# File 'lib/oci/database_migration/models/migration_summary.rb', line 96

def time_updated
  @time_updated
end

#typeString

[Required] Migration type.

Returns:

  • (String)


58
59
60
# File 'lib/oci/database_migration/models/migration_summary.rb', line 58

def type
  @type
end

#vault_detailsOCI::DatabaseMigration::Models::VaultDetails



86
87
88
# File 'lib/oci/database_migration/models/migration_summary.rb', line 86

def vault_details
  @vault_details
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/oci/database_migration/models/migration_summary.rb', line 132

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'display_name': :'displayName',
    'compartment_id': :'compartmentId',
    'type': :'type',
    'source_database_connection_id': :'sourceDatabaseConnectionId',
    'source_container_database_connection_id': :'sourceContainerDatabaseConnectionId',
    'target_database_connection_id': :'targetDatabaseConnectionId',
    'executing_job_id': :'executingJobId',
    'agent_id': :'agentId',
    'vault_details': :'vaultDetails',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'time_last_migration': :'timeLastMigration',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/oci/database_migration/models/migration_summary.rb', line 158

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'display_name': :'String',
    'compartment_id': :'String',
    'type': :'String',
    'source_database_connection_id': :'String',
    'source_container_database_connection_id': :'String',
    'target_database_connection_id': :'String',
    'executing_job_id': :'String',
    'agent_id': :'String',
    'vault_details': :'OCI::DatabaseMigration::Models::VaultDetails',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'time_last_migration': :'DateTime',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
# File 'lib/oci/database_migration/models/migration_summary.rb', line 360

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    display_name == other.display_name &&
    compartment_id == other.compartment_id &&
    type == other.type &&
    source_database_connection_id == other.source_database_connection_id &&
    source_container_database_connection_id == other.source_container_database_connection_id &&
    target_database_connection_id == other.target_database_connection_id &&
    executing_job_id == other.executing_job_id &&
    agent_id == other.agent_id &&
    vault_details == other.vault_details &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    time_last_migration == other.time_last_migration &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
# File 'lib/oci/database_migration/models/migration_summary.rb', line 407

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


387
388
389
# File 'lib/oci/database_migration/models/migration_summary.rb', line 387

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



396
397
398
# File 'lib/oci/database_migration/models/migration_summary.rb', line 396

def hash
  [id, display_name, compartment_id, type, source_database_connection_id, source_container_database_connection_id, target_database_connection_id, executing_job_id, agent_id, vault_details, time_created, time_updated, time_last_migration, lifecycle_state, lifecycle_details, freeform_tags, defined_tags, system_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



440
441
442
443
444
445
446
447
448
449
# File 'lib/oci/database_migration/models/migration_summary.rb', line 440

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



434
435
436
# File 'lib/oci/database_migration/models/migration_summary.rb', line 434

def to_s
  to_hash.to_s
end