Class: OCI::DatabaseMigration::Models::UpdateGoldenGateHub

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database_migration/models/update_golden_gate_hub.rb

Overview

Details about Oracle GoldenGate Microservices.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateGoldenGateHub

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/oci/database_migration/models/update_golden_gate_hub.rb', line 90

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.rest_admin_credentials = attributes[:'restAdminCredentials'] if attributes[:'restAdminCredentials']

  raise 'You cannot provide both :restAdminCredentials and :rest_admin_credentials' if attributes.key?(:'restAdminCredentials') && attributes.key?(:'rest_admin_credentials')

  self.rest_admin_credentials = attributes[:'rest_admin_credentials'] if attributes[:'rest_admin_credentials']

  self.source_db_admin_credentials = attributes[:'sourceDbAdminCredentials'] if attributes[:'sourceDbAdminCredentials']

  raise 'You cannot provide both :sourceDbAdminCredentials and :source_db_admin_credentials' if attributes.key?(:'sourceDbAdminCredentials') && attributes.key?(:'source_db_admin_credentials')

  self.source_db_admin_credentials = attributes[:'source_db_admin_credentials'] if attributes[:'source_db_admin_credentials']

  self.source_container_db_admin_credentials = attributes[:'sourceContainerDbAdminCredentials'] if attributes[:'sourceContainerDbAdminCredentials']

  raise 'You cannot provide both :sourceContainerDbAdminCredentials and :source_container_db_admin_credentials' if attributes.key?(:'sourceContainerDbAdminCredentials') && attributes.key?(:'source_container_db_admin_credentials')

  self.source_container_db_admin_credentials = attributes[:'source_container_db_admin_credentials'] if attributes[:'source_container_db_admin_credentials']

  self.target_db_admin_credentials = attributes[:'targetDbAdminCredentials'] if attributes[:'targetDbAdminCredentials']

  raise 'You cannot provide both :targetDbAdminCredentials and :target_db_admin_credentials' if attributes.key?(:'targetDbAdminCredentials') && attributes.key?(:'target_db_admin_credentials')

  self.target_db_admin_credentials = attributes[:'target_db_admin_credentials'] if attributes[:'target_db_admin_credentials']

  self.url = attributes[:'url'] if attributes[:'url']

  self.source_microservices_deployment_name = attributes[:'sourceMicroservicesDeploymentName'] if attributes[:'sourceMicroservicesDeploymentName']

  raise 'You cannot provide both :sourceMicroservicesDeploymentName and :source_microservices_deployment_name' if attributes.key?(:'sourceMicroservicesDeploymentName') && attributes.key?(:'source_microservices_deployment_name')

  self.source_microservices_deployment_name = attributes[:'source_microservices_deployment_name'] if attributes[:'source_microservices_deployment_name']

  self.target_microservices_deployment_name = attributes[:'targetMicroservicesDeploymentName'] if attributes[:'targetMicroservicesDeploymentName']

  raise 'You cannot provide both :targetMicroservicesDeploymentName and :target_microservices_deployment_name' if attributes.key?(:'targetMicroservicesDeploymentName') && attributes.key?(:'target_microservices_deployment_name')

  self.target_microservices_deployment_name = attributes[:'target_microservices_deployment_name'] if attributes[:'target_microservices_deployment_name']

  self.compute_id = attributes[:'computeId'] if attributes[:'computeId']

  raise 'You cannot provide both :computeId and :compute_id' if attributes.key?(:'computeId') && attributes.key?(:'compute_id')

  self.compute_id = attributes[:'compute_id'] if attributes[:'compute_id']
end

Instance Attribute Details

#compute_idString

OCID of GoldenGate compute instance. An empty value will remove the stored computeId.

Returns:

  • (String)


42
43
44
# File 'lib/oci/database_migration/models/update_golden_gate_hub.rb', line 42

def compute_id
  @compute_id
end

#rest_admin_credentialsOCI::DatabaseMigration::Models::UpdateAdminCredentials



12
13
14
# File 'lib/oci/database_migration/models/update_golden_gate_hub.rb', line 12

def rest_admin_credentials
  @rest_admin_credentials
end

#source_container_db_admin_credentialsOCI::DatabaseMigration::Models::UpdateAdminCredentials



18
19
20
# File 'lib/oci/database_migration/models/update_golden_gate_hub.rb', line 18

def source_container_db_admin_credentials
  @source_container_db_admin_credentials
end

#source_db_admin_credentialsOCI::DatabaseMigration::Models::UpdateAdminCredentials



15
16
17
# File 'lib/oci/database_migration/models/update_golden_gate_hub.rb', line 15

def source_db_admin_credentials
  @source_db_admin_credentials
end

#source_microservices_deployment_nameString

Name of GoldenGate deployment to operate on source database

Returns:

  • (String)


32
33
34
# File 'lib/oci/database_migration/models/update_golden_gate_hub.rb', line 32

def source_microservices_deployment_name
  @source_microservices_deployment_name
end

#target_db_admin_credentialsOCI::DatabaseMigration::Models::UpdateAdminCredentials



21
22
23
# File 'lib/oci/database_migration/models/update_golden_gate_hub.rb', line 21

def target_db_admin_credentials
  @target_db_admin_credentials
end

#target_microservices_deployment_nameString

Name of GoldenGate deployment to operate on target database

Returns:

  • (String)


37
38
39
# File 'lib/oci/database_migration/models/update_golden_gate_hub.rb', line 37

def target_microservices_deployment_name
  @target_microservices_deployment_name
end

#urlString

Returns:

  • (String)


27
28
29
# File 'lib/oci/database_migration/models/update_golden_gate_hub.rb', line 27

def url
  @url
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



45
46
47
48
49
50
51
52
53
54
55
56
57
58
# File 'lib/oci/database_migration/models/update_golden_gate_hub.rb', line 45

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'rest_admin_credentials': :'restAdminCredentials',
    'source_db_admin_credentials': :'sourceDbAdminCredentials',
    'source_container_db_admin_credentials': :'sourceContainerDbAdminCredentials',
    'target_db_admin_credentials': :'targetDbAdminCredentials',
    'url': :'url',
    'source_microservices_deployment_name': :'sourceMicroservicesDeploymentName',
    'target_microservices_deployment_name': :'targetMicroservicesDeploymentName',
    'compute_id': :'computeId'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/oci/database_migration/models/update_golden_gate_hub.rb', line 61

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'rest_admin_credentials': :'OCI::DatabaseMigration::Models::UpdateAdminCredentials',
    'source_db_admin_credentials': :'OCI::DatabaseMigration::Models::UpdateAdminCredentials',
    'source_container_db_admin_credentials': :'OCI::DatabaseMigration::Models::UpdateAdminCredentials',
    'target_db_admin_credentials': :'OCI::DatabaseMigration::Models::UpdateAdminCredentials',
    'url': :'String',
    'source_microservices_deployment_name': :'String',
    'target_microservices_deployment_name': :'String',
    'compute_id': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/oci/database_migration/models/update_golden_gate_hub.rb', line 148

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    rest_admin_credentials == other.rest_admin_credentials &&
    source_db_admin_credentials == other.source_db_admin_credentials &&
    source_container_db_admin_credentials == other.source_container_db_admin_credentials &&
    target_db_admin_credentials == other.target_db_admin_credentials &&
    url == other.url &&
    source_microservices_deployment_name == other.source_microservices_deployment_name &&
    target_microservices_deployment_name == other.target_microservices_deployment_name &&
    compute_id == other.compute_id
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/oci/database_migration/models/update_golden_gate_hub.rb', line 185

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


165
166
167
# File 'lib/oci/database_migration/models/update_golden_gate_hub.rb', line 165

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



174
175
176
# File 'lib/oci/database_migration/models/update_golden_gate_hub.rb', line 174

def hash
  [rest_admin_credentials, source_db_admin_credentials, source_container_db_admin_credentials, target_db_admin_credentials, url, source_microservices_deployment_name, target_microservices_deployment_name, compute_id].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



218
219
220
221
222
223
224
225
226
227
# File 'lib/oci/database_migration/models/update_golden_gate_hub.rb', line 218

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



212
213
214
# File 'lib/oci/database_migration/models/update_golden_gate_hub.rb', line 212

def to_s
  to_hash.to_s
end