Class: OCI::DatabaseMigration::Models::UpdateSshDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database_migration/models/update_ssh_details.rb

Overview

Details of the SSH key that will be used.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateSshDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :host (String)

    The value to assign to the #host property

  • :sshkey (String)

    The value to assign to the #sshkey property

  • :user (String)

    The value to assign to the #user property

  • :sudo_location (String)

    The value to assign to the #sudo_location property



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/oci/database_migration/models/update_ssh_details.rb', line 65

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.host = attributes[:'host'] if attributes[:'host']

  self.sshkey = attributes[:'sshkey'] if attributes[:'sshkey']

  self.user = attributes[:'user'] if attributes[:'user']

  self.sudo_location = attributes[:'sudoLocation'] if attributes[:'sudoLocation']

  raise 'You cannot provide both :sudoLocation and :sudo_location' if attributes.key?(:'sudoLocation') && attributes.key?(:'sudo_location')

  self.sudo_location = attributes[:'sudo_location'] if attributes[:'sudo_location']
end

Instance Attribute Details

#hostString

Name of the host the SSH key is valid for.

Returns:

  • (String)


14
15
16
# File 'lib/oci/database_migration/models/update_ssh_details.rb', line 14

def host
  @host
end

#sshkeyString

Private SSH key string.

Returns:

  • (String)


19
20
21
# File 'lib/oci/database_migration/models/update_ssh_details.rb', line 19

def sshkey
  @sshkey
end

#sudo_locationString

Sudo location

Returns:

  • (String)


29
30
31
# File 'lib/oci/database_migration/models/update_ssh_details.rb', line 29

def sudo_location
  @sudo_location
end

#userString

SSH user

Returns:

  • (String)


24
25
26
# File 'lib/oci/database_migration/models/update_ssh_details.rb', line 24

def user
  @user
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



32
33
34
35
36
37
38
39
40
41
# File 'lib/oci/database_migration/models/update_ssh_details.rb', line 32

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'host': :'host',
    'sshkey': :'sshkey',
    'user': :'user',
    'sudo_location': :'sudoLocation'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



44
45
46
47
48
49
50
51
52
53
# File 'lib/oci/database_migration/models/update_ssh_details.rb', line 44

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'host': :'String',
    'sshkey': :'String',
    'user': :'String',
    'sudo_location': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



91
92
93
94
95
96
97
98
99
# File 'lib/oci/database_migration/models/update_ssh_details.rb', line 91

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    host == other.host &&
    sshkey == other.sshkey &&
    user == other.user &&
    sudo_location == other.sudo_location
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/oci/database_migration/models/update_ssh_details.rb', line 124

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


104
105
106
# File 'lib/oci/database_migration/models/update_ssh_details.rb', line 104

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



113
114
115
# File 'lib/oci/database_migration/models/update_ssh_details.rb', line 113

def hash
  [host, sshkey, user, sudo_location].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



157
158
159
160
161
162
163
164
165
166
# File 'lib/oci/database_migration/models/update_ssh_details.rb', line 157

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



151
152
153
# File 'lib/oci/database_migration/models/update_ssh_details.rb', line 151

def to_s
  to_hash.to_s
end