Class: OCI::DatabaseTools::DatabaseToolsClient
- Inherits:
-
Object
- Object
- OCI::DatabaseTools::DatabaseToolsClient
- Defined in:
- lib/oci/database_tools/database_tools_client.rb
Overview
Database Tools APIs to manage Connections and Private Endpoints.
Instance Attribute Summary collapse
-
#api_client ⇒ OCI::ApiClient
readonly
Client used to make HTTP requests.
-
#endpoint ⇒ String
readonly
Fully qualified endpoint URL.
-
#region ⇒ String
The region, which will usually correspond to a value in Regions::REGION_ENUM.
-
#retry_config ⇒ OCI::Retry::RetryConfig
readonly
The default retry configuration to apply to all operations in this service client.
Instance Method Summary collapse
-
#change_database_tools_connection_compartment(database_tools_connection_id, change_database_tools_connection_compartment_details, opts = {}) ⇒ Response
Moves a DatabaseToolsConnection into a different compartment within the same tenancy.
-
#change_database_tools_private_endpoint_compartment(database_tools_private_endpoint_id, change_database_tools_private_endpoint_compartment_details, opts = {}) ⇒ Response
Moves a DatabaseToolsPrivateEndpoint into a different compartment within the same tenancy.
-
#create_database_tools_connection(create_database_tools_connection_details, opts = {}) ⇒ Response
Creates a new DatabaseToolsConnection.
-
#create_database_tools_private_endpoint(create_database_tools_private_endpoint_details, opts = {}) ⇒ Response
Creates a new DatabaseToolsPrivateEndpoint.
-
#delete_database_tools_connection(database_tools_connection_id, opts = {}) ⇒ Response
Deletes a DatabaseToolsConnection resource by identifier.
-
#delete_database_tools_private_endpoint(database_tools_private_endpoint_id, opts = {}) ⇒ Response
Deletes a DatabaseToolsPrivateEndpoint resource by identifier.
-
#get_database_tools_connection(database_tools_connection_id, opts = {}) ⇒ Response
Gets a DatabaseToolsConnection by identifier.
-
#get_database_tools_endpoint_service(database_tools_endpoint_service_id, opts = {}) ⇒ Response
Gets a DatabaseToolsEndpointService by identifier.
-
#get_database_tools_private_endpoint(database_tools_private_endpoint_id, opts = {}) ⇒ Response
Gets a DatabaseToolsPrivateEndpoint by identifier.
-
#get_work_request(work_request_id, opts = {}) ⇒ Response
Gets the status of the work request with the given ID.
-
#initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) ⇒ DatabaseToolsClient
constructor
Creates a new DatabaseToolsClient.
-
#list_database_tools_connections(compartment_id, opts = {}) ⇒ Response
Returns a list of DatabaseToolsConnections.
-
#list_database_tools_endpoint_services(compartment_id, opts = {}) ⇒ Response
Returns a list of DatabaseToolsEndpointServices.
-
#list_database_tools_private_endpoints(compartment_id, opts = {}) ⇒ Response
Returns a list of DatabaseToolsPrivateEndpoints.
-
#list_work_request_errors(work_request_id, opts = {}) ⇒ Response
Return a (paginated) list of errors for a given work request.
-
#list_work_request_logs(work_request_id, opts = {}) ⇒ Response
Return a (paginated) list of logs for a given work request.
-
#list_work_requests(compartment_id, opts = {}) ⇒ Response
Lists the work requests in a compartment.
-
#logger ⇒ Logger
The logger for this client.
-
#update_database_tools_connection(database_tools_connection_id, update_database_tools_connection_details, opts = {}) ⇒ Response
Updates the DatabaseToolsConnection.
-
#update_database_tools_private_endpoint(database_tools_private_endpoint_id, update_database_tools_private_endpoint_details, opts = {}) ⇒ Response
Updates the DatabaseToolsPrivateEndpoint.
-
#validate_database_tools_connection(database_tools_connection_id, validate_database_tools_connection_details, opts = {}) ⇒ Response
Validate the DatabaseToolsConnection information details by establishing a connection to the database.
Constructor Details
#initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) ⇒ DatabaseToolsClient
Creates a new DatabaseToolsClient. Notes:
If a config is not specified, then the global OCI.config will be used.
This client is not thread-safe
Either a region or an endpoint must be specified. If an endpoint is specified, it will be used instead of the
region. A region may be specified in the config or via or the region parameter. If specified in both, then the
region parameter will be used.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/oci/database_tools/database_tools_client.rb', line 53 def initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) # If the signer is an InstancePrincipalsSecurityTokenSigner or SecurityTokenSigner and no config was supplied (they are self-sufficient signers) # then create a dummy config to pass to the ApiClient constructor. If customers wish to create a client which uses instance principals # and has config (either populated programmatically or loaded from a file), they must construct that config themselves and then # pass it to this constructor. # # If there is no signer (or the signer is not an instance principals signer) and no config was supplied, this is not valid # so try and load the config from the default file. config = OCI::Config.validate_and_build_config_with_signer(config, signer) signer = OCI::Signer.config_file_auth_builder(config) if signer.nil? @api_client = OCI::ApiClient.new(config, signer, proxy_settings: proxy_settings) @retry_config = retry_config if endpoint @endpoint = endpoint + '/20201005' else region ||= config.region region ||= signer.region if signer.respond_to?(:region) self.region = region end logger.info "DatabaseToolsClient endpoint set to '#{@endpoint}'." if logger end |
Instance Attribute Details
#api_client ⇒ OCI::ApiClient (readonly)
Client used to make HTTP requests.
13 14 15 |
# File 'lib/oci/database_tools/database_tools_client.rb', line 13 def api_client @api_client end |
#endpoint ⇒ String (readonly)
Fully qualified endpoint URL
17 18 19 |
# File 'lib/oci/database_tools/database_tools_client.rb', line 17 def endpoint @endpoint end |
#region ⇒ String
The region, which will usually correspond to a value in Regions::REGION_ENUM.
27 28 29 |
# File 'lib/oci/database_tools/database_tools_client.rb', line 27 def region @region end |
#retry_config ⇒ OCI::Retry::RetryConfig (readonly)
The default retry configuration to apply to all operations in this service client. This can be overridden on a per-operation basis. The default retry configuration value is nil, which means that an operation will not perform any retries
23 24 25 |
# File 'lib/oci/database_tools/database_tools_client.rb', line 23 def retry_config @retry_config end |
Instance Method Details
#change_database_tools_connection_compartment(database_tools_connection_id, change_database_tools_connection_compartment_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/databasetools/change_database_tools_connection_compartment.rb.html) to see an example of how to use change_database_tools_connection_compartment API.
Moves a DatabaseToolsConnection into a different compartment within the same tenancy. For information about moving resources between compartments, see [Moving Resources to a Different Compartment](docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/oci/database_tools/database_tools_client.rb', line 125 def change_database_tools_connection_compartment(database_tools_connection_id, change_database_tools_connection_compartment_details, opts = {}) logger.debug 'Calling operation DatabaseToolsClient#change_database_tools_connection_compartment.' if logger raise "Missing the required parameter 'database_tools_connection_id' when calling change_database_tools_connection_compartment." if database_tools_connection_id.nil? raise "Missing the required parameter 'change_database_tools_connection_compartment_details' when calling change_database_tools_connection_compartment." if change_database_tools_connection_compartment_details.nil? raise "Parameter value for 'database_tools_connection_id' must not be blank" if OCI::Internal::Util.blank_string?(database_tools_connection_id) path = '/databaseToolsConnections/{databaseToolsConnectionId}/actions/changeCompartment'.sub('{databaseToolsConnectionId}', database_tools_connection_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = @api_client.object_to_http_body(change_database_tools_connection_compartment_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DatabaseToolsClient#change_database_tools_connection_compartment') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#change_database_tools_private_endpoint_compartment(database_tools_private_endpoint_id, change_database_tools_private_endpoint_compartment_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/databasetools/change_database_tools_private_endpoint_compartment.rb.html) to see an example of how to use change_database_tools_private_endpoint_compartment API.
Moves a DatabaseToolsPrivateEndpoint into a different compartment within the same tenancy. For information about moving resources between compartments, see [Moving Resources to a Different Compartment](docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/oci/database_tools/database_tools_client.rb', line 198 def change_database_tools_private_endpoint_compartment(database_tools_private_endpoint_id, change_database_tools_private_endpoint_compartment_details, opts = {}) logger.debug 'Calling operation DatabaseToolsClient#change_database_tools_private_endpoint_compartment.' if logger raise "Missing the required parameter 'database_tools_private_endpoint_id' when calling change_database_tools_private_endpoint_compartment." if database_tools_private_endpoint_id.nil? raise "Missing the required parameter 'change_database_tools_private_endpoint_compartment_details' when calling change_database_tools_private_endpoint_compartment." if change_database_tools_private_endpoint_compartment_details.nil? raise "Parameter value for 'database_tools_private_endpoint_id' must not be blank" if OCI::Internal::Util.blank_string?(database_tools_private_endpoint_id) path = '/databaseToolsPrivateEndpoints/{databaseToolsPrivateEndpointId}/actions/changeCompartment'.sub('{databaseToolsPrivateEndpointId}', database_tools_private_endpoint_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = @api_client.object_to_http_body(change_database_tools_private_endpoint_compartment_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DatabaseToolsClient#change_database_tools_private_endpoint_compartment') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#create_database_tools_connection(create_database_tools_connection_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/databasetools/create_database_tools_connection.rb.html) to see an example of how to use create_database_tools_connection API.
Creates a new DatabaseToolsConnection.
262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/oci/database_tools/database_tools_client.rb', line 262 def create_database_tools_connection(create_database_tools_connection_details, opts = {}) logger.debug 'Calling operation DatabaseToolsClient#create_database_tools_connection.' if logger raise "Missing the required parameter 'create_database_tools_connection_details' when calling create_database_tools_connection." if create_database_tools_connection_details.nil? path = '/databaseToolsConnections' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = @api_client.object_to_http_body(create_database_tools_connection_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DatabaseToolsClient#create_database_tools_connection') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::DatabaseTools::Models::DatabaseToolsConnection' ) end # rubocop:enable Metrics/BlockLength end |
#create_database_tools_private_endpoint(create_database_tools_private_endpoint_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/databasetools/create_database_tools_private_endpoint.rb.html) to see an example of how to use create_database_tools_private_endpoint API.
Creates a new DatabaseToolsPrivateEndpoint.
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 |
# File 'lib/oci/database_tools/database_tools_client.rb', line 324 def create_database_tools_private_endpoint(create_database_tools_private_endpoint_details, opts = {}) logger.debug 'Calling operation DatabaseToolsClient#create_database_tools_private_endpoint.' if logger raise "Missing the required parameter 'create_database_tools_private_endpoint_details' when calling create_database_tools_private_endpoint." if create_database_tools_private_endpoint_details.nil? path = '/databaseToolsPrivateEndpoints' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = @api_client.object_to_http_body(create_database_tools_private_endpoint_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DatabaseToolsClient#create_database_tools_private_endpoint') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::DatabaseTools::Models::DatabaseToolsPrivateEndpoint' ) end # rubocop:enable Metrics/BlockLength end |
#delete_database_tools_connection(database_tools_connection_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/databasetools/delete_database_tools_connection.rb.html) to see an example of how to use delete_database_tools_connection API.
Deletes a DatabaseToolsConnection resource by identifier
385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 |
# File 'lib/oci/database_tools/database_tools_client.rb', line 385 def delete_database_tools_connection(database_tools_connection_id, opts = {}) logger.debug 'Calling operation DatabaseToolsClient#delete_database_tools_connection.' if logger raise "Missing the required parameter 'database_tools_connection_id' when calling delete_database_tools_connection." if database_tools_connection_id.nil? raise "Parameter value for 'database_tools_connection_id' must not be blank" if OCI::Internal::Util.blank_string?(database_tools_connection_id) path = '/databaseToolsConnections/{databaseToolsConnectionId}'.sub('{databaseToolsConnectionId}', database_tools_connection_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DatabaseToolsClient#delete_database_tools_connection') do @api_client.call_api( :DELETE, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#delete_database_tools_private_endpoint(database_tools_private_endpoint_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/databasetools/delete_database_tools_private_endpoint.rb.html) to see an example of how to use delete_database_tools_private_endpoint API.
Deletes a DatabaseToolsPrivateEndpoint resource by identifier
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 |
# File 'lib/oci/database_tools/database_tools_client.rb', line 445 def delete_database_tools_private_endpoint(database_tools_private_endpoint_id, opts = {}) logger.debug 'Calling operation DatabaseToolsClient#delete_database_tools_private_endpoint.' if logger raise "Missing the required parameter 'database_tools_private_endpoint_id' when calling delete_database_tools_private_endpoint." if database_tools_private_endpoint_id.nil? raise "Parameter value for 'database_tools_private_endpoint_id' must not be blank" if OCI::Internal::Util.blank_string?(database_tools_private_endpoint_id) path = '/databaseToolsPrivateEndpoints/{databaseToolsPrivateEndpointId}'.sub('{databaseToolsPrivateEndpointId}', database_tools_private_endpoint_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DatabaseToolsClient#delete_database_tools_private_endpoint') do @api_client.call_api( :DELETE, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#get_database_tools_connection(database_tools_connection_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/databasetools/get_database_tools_connection.rb.html) to see an example of how to use get_database_tools_connection API.
Gets a DatabaseToolsConnection by identifier
499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 |
# File 'lib/oci/database_tools/database_tools_client.rb', line 499 def get_database_tools_connection(database_tools_connection_id, opts = {}) logger.debug 'Calling operation DatabaseToolsClient#get_database_tools_connection.' if logger raise "Missing the required parameter 'database_tools_connection_id' when calling get_database_tools_connection." if database_tools_connection_id.nil? raise "Parameter value for 'database_tools_connection_id' must not be blank" if OCI::Internal::Util.blank_string?(database_tools_connection_id) path = '/databaseToolsConnections/{databaseToolsConnectionId}'.sub('{databaseToolsConnectionId}', database_tools_connection_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DatabaseToolsClient#get_database_tools_connection') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::DatabaseTools::Models::DatabaseToolsConnection' ) end # rubocop:enable Metrics/BlockLength end |
#get_database_tools_endpoint_service(database_tools_endpoint_service_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/databasetools/get_database_tools_endpoint_service.rb.html) to see an example of how to use get_database_tools_endpoint_service API.
Gets a DatabaseToolsEndpointService by identifier
553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 |
# File 'lib/oci/database_tools/database_tools_client.rb', line 553 def get_database_tools_endpoint_service(database_tools_endpoint_service_id, opts = {}) logger.debug 'Calling operation DatabaseToolsClient#get_database_tools_endpoint_service.' if logger raise "Missing the required parameter 'database_tools_endpoint_service_id' when calling get_database_tools_endpoint_service." if database_tools_endpoint_service_id.nil? raise "Parameter value for 'database_tools_endpoint_service_id' must not be blank" if OCI::Internal::Util.blank_string?(database_tools_endpoint_service_id) path = '/databaseToolsEndpointServices/{databaseToolsEndpointServiceId}'.sub('{databaseToolsEndpointServiceId}', database_tools_endpoint_service_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DatabaseToolsClient#get_database_tools_endpoint_service') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::DatabaseTools::Models::DatabaseToolsEndpointService' ) end # rubocop:enable Metrics/BlockLength end |
#get_database_tools_private_endpoint(database_tools_private_endpoint_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/databasetools/get_database_tools_private_endpoint.rb.html) to see an example of how to use get_database_tools_private_endpoint API.
Gets a DatabaseToolsPrivateEndpoint by identifier
607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 |
# File 'lib/oci/database_tools/database_tools_client.rb', line 607 def get_database_tools_private_endpoint(database_tools_private_endpoint_id, opts = {}) logger.debug 'Calling operation DatabaseToolsClient#get_database_tools_private_endpoint.' if logger raise "Missing the required parameter 'database_tools_private_endpoint_id' when calling get_database_tools_private_endpoint." if database_tools_private_endpoint_id.nil? raise "Parameter value for 'database_tools_private_endpoint_id' must not be blank" if OCI::Internal::Util.blank_string?(database_tools_private_endpoint_id) path = '/databaseToolsPrivateEndpoints/{databaseToolsPrivateEndpointId}'.sub('{databaseToolsPrivateEndpointId}', database_tools_private_endpoint_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DatabaseToolsClient#get_database_tools_private_endpoint') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::DatabaseTools::Models::DatabaseToolsPrivateEndpoint' ) end # rubocop:enable Metrics/BlockLength end |
#get_work_request(work_request_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/databasetools/get_work_request.rb.html) to see an example of how to use get_work_request API.
Gets the status of the work request with the given ID.
661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 |
# File 'lib/oci/database_tools/database_tools_client.rb', line 661 def get_work_request(work_request_id, opts = {}) logger.debug 'Calling operation DatabaseToolsClient#get_work_request.' if logger raise "Missing the required parameter 'work_request_id' when calling get_work_request." if work_request_id.nil? raise "Parameter value for 'work_request_id' must not be blank" if OCI::Internal::Util.blank_string?(work_request_id) path = '/workRequests/{workRequestId}'.sub('{workRequestId}', work_request_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DatabaseToolsClient#get_work_request') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::DatabaseTools::Models::WorkRequest' ) end # rubocop:enable Metrics/BlockLength end |
#list_database_tools_connections(compartment_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/databasetools/list_database_tools_connections.rb.html) to see an example of how to use list_database_tools_connections API.
Returns a list of DatabaseToolsConnections.
Allowed values are: timeCreated, displayName
726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 |
# File 'lib/oci/database_tools/database_tools_client.rb', line 726 def list_database_tools_connections(compartment_id, opts = {}) logger.debug 'Calling operation DatabaseToolsClient#list_database_tools_connections.' if logger raise "Missing the required parameter 'compartment_id' when calling list_database_tools_connections." if compartment_id.nil? if opts[:lifecycle_state] && !OCI::DatabaseTools::Models::LIFECYCLE_STATE_ENUM.include?(opts[:lifecycle_state]) raise 'Invalid value for "lifecycle_state", must be one of the values in OCI::DatabaseTools::Models::LIFECYCLE_STATE_ENUM.' end type_allowable_values = %w[ORACLE_DATABASE] if opts[:type] && !opts[:type].empty? opts[:type].each do |val_to_check| unless type_allowable_values.include?(val_to_check) raise 'Invalid value for "type", must be one of ORACLE_DATABASE.' end end end if opts[:sort_order] && !OCI::DatabaseTools::Models::SORT_ORDER_ENUM.include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of the values in OCI::DatabaseTools::Models::SORT_ORDER_ENUM.' end if opts[:sort_by] && !%w[timeCreated displayName].include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of timeCreated, displayName.' end path = '/databaseToolsConnections' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:compartmentId] = compartment_id query_params[:lifecycleState] = opts[:lifecycle_state] if opts[:lifecycle_state] query_params[:displayName] = opts[:display_name] if opts[:display_name] query_params[:type] = OCI::ApiClient.build_collection_params(opts[:type], :multi) if opts[:type] && !opts[:type].empty? query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DatabaseToolsClient#list_database_tools_connections') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::DatabaseTools::Models::DatabaseToolsConnectionCollection' ) end # rubocop:enable Metrics/BlockLength end |
#list_database_tools_endpoint_services(compartment_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/databasetools/list_database_tools_endpoint_services.rb.html) to see an example of how to use list_database_tools_endpoint_services API.
Returns a list of DatabaseToolsEndpointServices.
Allowed values are: timeCreated, displayName
819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 |
# File 'lib/oci/database_tools/database_tools_client.rb', line 819 def list_database_tools_endpoint_services(compartment_id, opts = {}) logger.debug 'Calling operation DatabaseToolsClient#list_database_tools_endpoint_services.' if logger raise "Missing the required parameter 'compartment_id' when calling list_database_tools_endpoint_services." if compartment_id.nil? if opts[:sort_order] && !OCI::DatabaseTools::Models::SORT_ORDER_ENUM.include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of the values in OCI::DatabaseTools::Models::SORT_ORDER_ENUM.' end if opts[:sort_by] && !%w[timeCreated displayName].include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of timeCreated, displayName.' end if opts[:lifecycle_state] && !OCI::DatabaseTools::Models::LIFECYCLE_STATE_ENUM.include?(opts[:lifecycle_state]) raise 'Invalid value for "lifecycle_state", must be one of the values in OCI::DatabaseTools::Models::LIFECYCLE_STATE_ENUM.' end path = '/databaseToolsEndpointServices' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:compartmentId] = compartment_id query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] query_params[:lifecycleState] = opts[:lifecycle_state] if opts[:lifecycle_state] query_params[:displayName] = opts[:display_name] if opts[:display_name] query_params[:name] = opts[:name] if opts[:name] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DatabaseToolsClient#list_database_tools_endpoint_services') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::DatabaseTools::Models::DatabaseToolsEndpointServiceCollection' ) end # rubocop:enable Metrics/BlockLength end |
#list_database_tools_private_endpoints(compartment_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/databasetools/list_database_tools_private_endpoints.rb.html) to see an example of how to use list_database_tools_private_endpoints API.
Returns a list of DatabaseToolsPrivateEndpoints.
Allowed values are: timeCreated, displayName
903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 |
# File 'lib/oci/database_tools/database_tools_client.rb', line 903 def list_database_tools_private_endpoints(compartment_id, opts = {}) logger.debug 'Calling operation DatabaseToolsClient#list_database_tools_private_endpoints.' if logger raise "Missing the required parameter 'compartment_id' when calling list_database_tools_private_endpoints." if compartment_id.nil? if opts[:sort_order] && !OCI::DatabaseTools::Models::SORT_ORDER_ENUM.include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of the values in OCI::DatabaseTools::Models::SORT_ORDER_ENUM.' end if opts[:sort_by] && !%w[timeCreated displayName].include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of timeCreated, displayName.' end if opts[:lifecycle_state] && !OCI::DatabaseTools::Models::LIFECYCLE_STATE_ENUM.include?(opts[:lifecycle_state]) raise 'Invalid value for "lifecycle_state", must be one of the values in OCI::DatabaseTools::Models::LIFECYCLE_STATE_ENUM.' end path = '/databaseToolsPrivateEndpoints' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:compartmentId] = compartment_id query_params[:subnetId] = opts[:subnet_id] if opts[:subnet_id] query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] query_params[:endpointServiceId] = opts[:endpoint_service_id] if opts[:endpoint_service_id] query_params[:lifecycleState] = opts[:lifecycle_state] if opts[:lifecycle_state] query_params[:displayName] = opts[:display_name] if opts[:display_name] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DatabaseToolsClient#list_database_tools_private_endpoints') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::DatabaseTools::Models::DatabaseToolsPrivateEndpointCollection' ) end # rubocop:enable Metrics/BlockLength end |
#list_work_request_errors(work_request_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/databasetools/list_work_request_errors.rb.html) to see an example of how to use list_work_request_errors API.
Return a (paginated) list of errors for a given work request.
Allowed values are: timeCreated, displayName
984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 |
# File 'lib/oci/database_tools/database_tools_client.rb', line 984 def list_work_request_errors(work_request_id, opts = {}) logger.debug 'Calling operation DatabaseToolsClient#list_work_request_errors.' if logger raise "Missing the required parameter 'work_request_id' when calling list_work_request_errors." if work_request_id.nil? if opts[:sort_order] && !OCI::DatabaseTools::Models::SORT_ORDER_ENUM.include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of the values in OCI::DatabaseTools::Models::SORT_ORDER_ENUM.' end if opts[:sort_by] && !%w[timeCreated displayName].include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of timeCreated, displayName.' end raise "Parameter value for 'work_request_id' must not be blank" if OCI::Internal::Util.blank_string?(work_request_id) path = '/workRequests/{workRequestId}/errors'.sub('{workRequestId}', work_request_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] query_params[:page] = opts[:page] if opts[:page] query_params[:limit] = opts[:limit] if opts[:limit] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DatabaseToolsClient#list_work_request_errors') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::DatabaseTools::Models::WorkRequestErrorCollection' ) end # rubocop:enable Metrics/BlockLength end |
#list_work_request_logs(work_request_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/databasetools/list_work_request_logs.rb.html) to see an example of how to use list_work_request_logs API.
Return a (paginated) list of logs for a given work request.
Allowed values are: timeCreated, displayName
1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 |
# File 'lib/oci/database_tools/database_tools_client.rb', line 1057 def list_work_request_logs(work_request_id, opts = {}) logger.debug 'Calling operation DatabaseToolsClient#list_work_request_logs.' if logger raise "Missing the required parameter 'work_request_id' when calling list_work_request_logs." if work_request_id.nil? if opts[:sort_order] && !OCI::DatabaseTools::Models::SORT_ORDER_ENUM.include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of the values in OCI::DatabaseTools::Models::SORT_ORDER_ENUM.' end if opts[:sort_by] && !%w[timeCreated displayName].include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of timeCreated, displayName.' end raise "Parameter value for 'work_request_id' must not be blank" if OCI::Internal::Util.blank_string?(work_request_id) path = '/workRequests/{workRequestId}/logs'.sub('{workRequestId}', work_request_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] query_params[:page] = opts[:page] if opts[:page] query_params[:limit] = opts[:limit] if opts[:limit] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DatabaseToolsClient#list_work_request_logs') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::DatabaseTools::Models::WorkRequestLogEntryCollection' ) end # rubocop:enable Metrics/BlockLength end |
#list_work_requests(compartment_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/databasetools/list_work_requests.rb.html) to see an example of how to use list_work_requests API.
Lists the work requests in a compartment.
Allowed values are: timeAccepted
1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 |
# File 'lib/oci/database_tools/database_tools_client.rb', line 1131 def list_work_requests(compartment_id, opts = {}) logger.debug 'Calling operation DatabaseToolsClient#list_work_requests.' if logger raise "Missing the required parameter 'compartment_id' when calling list_work_requests." if compartment_id.nil? if opts[:sort_order] && !OCI::DatabaseTools::Models::SORT_ORDER_ENUM.include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of the values in OCI::DatabaseTools::Models::SORT_ORDER_ENUM.' end if opts[:sort_by] && !%w[timeAccepted].include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of timeAccepted.' end path = '/workRequests' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:compartmentId] = compartment_id query_params[:resourceIdentifier] = opts[:resource_identifier] if opts[:resource_identifier] query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] query_params[:page] = opts[:page] if opts[:page] query_params[:limit] = opts[:limit] if opts[:limit] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DatabaseToolsClient#list_work_requests') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::DatabaseTools::Models::WorkRequestCollection' ) end # rubocop:enable Metrics/BlockLength end |
#logger ⇒ Logger
Returns The logger for this client. May be nil.
92 93 94 |
# File 'lib/oci/database_tools/database_tools_client.rb', line 92 def logger @api_client.config.logger end |
#update_database_tools_connection(database_tools_connection_id, update_database_tools_connection_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/databasetools/update_database_tools_connection.rb.html) to see an example of how to use update_database_tools_connection API.
Updates the DatabaseToolsConnection
1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 |
# File 'lib/oci/database_tools/database_tools_client.rb', line 1205 def update_database_tools_connection(database_tools_connection_id, update_database_tools_connection_details, opts = {}) logger.debug 'Calling operation DatabaseToolsClient#update_database_tools_connection.' if logger raise "Missing the required parameter 'database_tools_connection_id' when calling update_database_tools_connection." if database_tools_connection_id.nil? raise "Missing the required parameter 'update_database_tools_connection_details' when calling update_database_tools_connection." if update_database_tools_connection_details.nil? raise "Parameter value for 'database_tools_connection_id' must not be blank" if OCI::Internal::Util.blank_string?(database_tools_connection_id) path = '/databaseToolsConnections/{databaseToolsConnectionId}'.sub('{databaseToolsConnectionId}', database_tools_connection_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(update_database_tools_connection_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DatabaseToolsClient#update_database_tools_connection') do @api_client.call_api( :PUT, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#update_database_tools_private_endpoint(database_tools_private_endpoint_id, update_database_tools_private_endpoint_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/databasetools/update_database_tools_private_endpoint.rb.html) to see an example of how to use update_database_tools_private_endpoint API.
Updates the DatabaseToolsPrivateEndpoint
1267 1268 1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 1294 1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 |
# File 'lib/oci/database_tools/database_tools_client.rb', line 1267 def update_database_tools_private_endpoint(database_tools_private_endpoint_id, update_database_tools_private_endpoint_details, opts = {}) logger.debug 'Calling operation DatabaseToolsClient#update_database_tools_private_endpoint.' if logger raise "Missing the required parameter 'database_tools_private_endpoint_id' when calling update_database_tools_private_endpoint." if database_tools_private_endpoint_id.nil? raise "Missing the required parameter 'update_database_tools_private_endpoint_details' when calling update_database_tools_private_endpoint." if update_database_tools_private_endpoint_details.nil? raise "Parameter value for 'database_tools_private_endpoint_id' must not be blank" if OCI::Internal::Util.blank_string?(database_tools_private_endpoint_id) path = '/databaseToolsPrivateEndpoints/{databaseToolsPrivateEndpointId}'.sub('{databaseToolsPrivateEndpointId}', database_tools_private_endpoint_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(update_database_tools_private_endpoint_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DatabaseToolsClient#update_database_tools_private_endpoint') do @api_client.call_api( :PUT, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#validate_database_tools_connection(database_tools_connection_id, validate_database_tools_connection_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/databasetools/validate_database_tools_connection.rb.html) to see an example of how to use validate_database_tools_connection API.
Validate the DatabaseToolsConnection information details by establishing a connection to the database.
1330 1331 1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 |
# File 'lib/oci/database_tools/database_tools_client.rb', line 1330 def validate_database_tools_connection(database_tools_connection_id, validate_database_tools_connection_details, opts = {}) logger.debug 'Calling operation DatabaseToolsClient#validate_database_tools_connection.' if logger raise "Missing the required parameter 'database_tools_connection_id' when calling validate_database_tools_connection." if database_tools_connection_id.nil? raise "Missing the required parameter 'validate_database_tools_connection_details' when calling validate_database_tools_connection." if validate_database_tools_connection_details.nil? raise "Parameter value for 'database_tools_connection_id' must not be blank" if OCI::Internal::Util.blank_string?(database_tools_connection_id) path = '/databaseToolsConnections/{databaseToolsConnectionId}/actions/validateConnection'.sub('{databaseToolsConnectionId}', database_tools_connection_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(validate_database_tools_connection_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DatabaseToolsClient#validate_database_tools_connection') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::DatabaseTools::Models::ValidateDatabaseToolsConnectionResult' ) end # rubocop:enable Metrics/BlockLength end |