Class: OCI::DatabaseTools::Models::DatabaseToolsConnectionOracleDatabase

Inherits:
DatabaseToolsConnection show all
Defined in:
lib/oci/database_tools/models/database_tools_connection_oracle_database.rb

Overview

DatabaseToolsConnection of an Oracle Database.

Constant Summary

Constants inherited from DatabaseToolsConnection

OCI::DatabaseTools::Models::DatabaseToolsConnection::LIFECYCLE_STATE_ENUM, OCI::DatabaseTools::Models::DatabaseToolsConnection::TYPE_ENUM

Instance Attribute Summary collapse

Attributes inherited from DatabaseToolsConnection

#compartment_id, #defined_tags, #display_name, #freeform_tags, #id, #lifecycle_details, #lifecycle_state, #system_tags, #time_created, #time_updated, #type

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from DatabaseToolsConnection

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ DatabaseToolsConnectionOracleDatabase

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/oci/database_tools/models/database_tools_connection_oracle_database.rb', line 114

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['type'] = 'ORACLE_DATABASE'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.related_resource = attributes[:'relatedResource'] if attributes[:'relatedResource']

  raise 'You cannot provide both :relatedResource and :related_resource' if attributes.key?(:'relatedResource') && attributes.key?(:'related_resource')

  self.related_resource = attributes[:'related_resource'] if attributes[:'related_resource']

  self.connection_string = attributes[:'connectionString'] if attributes[:'connectionString']

  raise 'You cannot provide both :connectionString and :connection_string' if attributes.key?(:'connectionString') && attributes.key?(:'connection_string')

  self.connection_string = attributes[:'connection_string'] if attributes[:'connection_string']

  self.user_name = attributes[:'userName'] if attributes[:'userName']

  raise 'You cannot provide both :userName and :user_name' if attributes.key?(:'userName') && attributes.key?(:'user_name')

  self.user_name = attributes[:'user_name'] if attributes[:'user_name']

  self.user_password = attributes[:'userPassword'] if attributes[:'userPassword']

  raise 'You cannot provide both :userPassword and :user_password' if attributes.key?(:'userPassword') && attributes.key?(:'user_password')

  self.user_password = attributes[:'user_password'] if attributes[:'user_password']

  self.advanced_properties = attributes[:'advancedProperties'] if attributes[:'advancedProperties']

  raise 'You cannot provide both :advancedProperties and :advanced_properties' if attributes.key?(:'advancedProperties') && attributes.key?(:'advanced_properties')

  self.advanced_properties = attributes[:'advanced_properties'] if attributes[:'advanced_properties']

  self.key_stores = attributes[:'keyStores'] if attributes[:'keyStores']

  raise 'You cannot provide both :keyStores and :key_stores' if attributes.key?(:'keyStores') && attributes.key?(:'key_stores')

  self.key_stores = attributes[:'key_stores'] if attributes[:'key_stores']

  self.private_endpoint_id = attributes[:'privateEndpointId'] if attributes[:'privateEndpointId']

  raise 'You cannot provide both :privateEndpointId and :private_endpoint_id' if attributes.key?(:'privateEndpointId') && attributes.key?(:'private_endpoint_id')

  self.private_endpoint_id = attributes[:'private_endpoint_id'] if attributes[:'private_endpoint_id']
end

Instance Attribute Details

#advanced_propertiesHash<String, String>

Advanced connection properties key-value pair (e.g., oracle.net.ssl_server_dn_match).

Returns:

  • (Hash<String, String>)


27
28
29
# File 'lib/oci/database_tools/models/database_tools_connection_oracle_database.rb', line 27

def advanced_properties
  @advanced_properties
end

#connection_stringString

Connect descriptor or Easy Connect Naming method to connect to the database.

Returns:

  • (String)


16
17
18
# File 'lib/oci/database_tools/models/database_tools_connection_oracle_database.rb', line 16

def connection_string
  @connection_string
end

#key_storesArray<OCI::DatabaseTools::Models::DatabaseToolsKeyStore>

Oracle wallet or Java Keystores containing trusted certificates for authenticating the server’s public certificate and the client private key and associated certificates required for client authentication.



33
34
35
# File 'lib/oci/database_tools/models/database_tools_connection_oracle_database.rb', line 33

def key_stores
  @key_stores
end

#private_endpoint_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the DatabaseToolsPrivateEndpoint used to access the database in the Customer VCN.

Returns:

  • (String)


37
38
39
# File 'lib/oci/database_tools/models/database_tools_connection_oracle_database.rb', line 37

def private_endpoint_id
  @private_endpoint_id
end


12
13
14
# File 'lib/oci/database_tools/models/database_tools_connection_oracle_database.rb', line 12

def related_resource
  @related_resource
end

#user_nameString

Database user name.

Returns:

  • (String)


20
21
22
# File 'lib/oci/database_tools/models/database_tools_connection_oracle_database.rb', line 20

def user_name
  @user_name
end

#user_passwordOCI::DatabaseTools::Models::DatabaseToolsUserPassword



23
24
25
# File 'lib/oci/database_tools/models/database_tools_connection_oracle_database.rb', line 23

def user_password
  @user_password
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/oci/database_tools/models/database_tools_connection_oracle_database.rb', line 40

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'display_name': :'displayName',
    'compartment_id': :'compartmentId',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'defined_tags': :'definedTags',
    'freeform_tags': :'freeformTags',
    'system_tags': :'systemTags',
    'type': :'type',
    'related_resource': :'relatedResource',
    'connection_string': :'connectionString',
    'user_name': :'userName',
    'user_password': :'userPassword',
    'advanced_properties': :'advancedProperties',
    'key_stores': :'keyStores',
    'private_endpoint_id': :'privateEndpointId'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/oci/database_tools/models/database_tools_connection_oracle_database.rb', line 66

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'display_name': :'String',
    'compartment_id': :'String',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'freeform_tags': :'Hash<String, String>',
    'system_tags': :'Hash<String, Hash<String, Object>>',
    'type': :'String',
    'related_resource': :'OCI::DatabaseTools::Models::DatabaseToolsRelatedResource',
    'connection_string': :'String',
    'user_name': :'String',
    'user_password': :'OCI::DatabaseTools::Models::DatabaseToolsUserPassword',
    'advanced_properties': :'Hash<String, String>',
    'key_stores': :'Array<OCI::DatabaseTools::Models::DatabaseToolsKeyStore>',
    'private_endpoint_id': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/oci/database_tools/models/database_tools_connection_oracle_database.rb', line 174

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    display_name == other.display_name &&
    compartment_id == other.compartment_id &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    defined_tags == other.defined_tags &&
    freeform_tags == other.freeform_tags &&
    system_tags == other.system_tags &&
    type == other.type &&
    related_resource == other.related_resource &&
    connection_string == other.connection_string &&
    user_name == other.user_name &&
    user_password == other.user_password &&
    advanced_properties == other.advanced_properties &&
    key_stores == other.key_stores &&
    private_endpoint_id == other.private_endpoint_id
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/oci/database_tools/models/database_tools_connection_oracle_database.rb', line 221

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


201
202
203
# File 'lib/oci/database_tools/models/database_tools_connection_oracle_database.rb', line 201

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



210
211
212
# File 'lib/oci/database_tools/models/database_tools_connection_oracle_database.rb', line 210

def hash
  [id, display_name, compartment_id, lifecycle_state, lifecycle_details, time_created, time_updated, defined_tags, freeform_tags, system_tags, type, related_resource, connection_string, user_name, user_password, advanced_properties, key_stores, private_endpoint_id].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



254
255
256
257
258
259
260
261
262
263
# File 'lib/oci/database_tools/models/database_tools_connection_oracle_database.rb', line 254

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



248
249
250
# File 'lib/oci/database_tools/models/database_tools_connection_oracle_database.rb', line 248

def to_s
  to_hash.to_s
end