Class: OCI::DatabaseTools::Models::DatabaseToolsPrivateEndpoint
- Inherits:
-
Object
- Object
- OCI::DatabaseTools::Models::DatabaseToolsPrivateEndpoint
- Defined in:
- lib/oci/database_tools/models/database_tools_private_endpoint.rb
Overview
Description of DatabaseToolsPrivateEndpoint.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#additional_fqdns ⇒ Array<String>
A list of additional FQDNs that can be also be used for the private endpoint.
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the containing Compartment.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
A description of the DatabaseToolsPrivateEndpoint.
-
#display_name ⇒ String
A user-friendly name.
-
#endpoint_fqdn ⇒ String
Then FQDN to use for the private endpoint.
-
#endpoint_service_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the DatabaseToolsEndpointService.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the DatabaseToolsPrivateEndpoint.
-
#lifecycle_details ⇒ String
A message describing the current state in more detail.
-
#lifecycle_state ⇒ String
[Required] The current state of the DatabaseToolsPrivateEndpoint.
-
#nsg_ids ⇒ Array<String>
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the network security groups that the private endpoint’s VNIC belongs to.
-
#private_endpoint_ip ⇒ String
The private IP address that represents the access point for the associated endpoint service.
-
#private_endpoint_vnic_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the private endpoint’s VNIC.
- #reverse_connection_configuration ⇒ OCI::DatabaseTools::Models::DatabaseToolsPrivateEndpointReverseConnectionConfiguration
-
#subnet_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the subnet that the private endpoint belongs to.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys.
-
#time_created ⇒ DateTime
[Required] The time the DatabaseToolsPrivateEndpoint was created.
-
#time_updated ⇒ DateTime
[Required] The time the DatabaseToolsPrivateEndpoint was updated.
-
#vcn_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VCN that the private endpoint belongs to.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DatabaseToolsPrivateEndpoint
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DatabaseToolsPrivateEndpoint
Initializes the object
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 |
# File 'lib/oci/database_tools/models/database_tools_private_endpoint.rb', line 191 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.id = attributes[:'id'] if attributes[:'id'] self.endpoint_service_id = attributes[:'endpointServiceId'] if attributes[:'endpointServiceId'] raise 'You cannot provide both :endpointServiceId and :endpoint_service_id' if attributes.key?(:'endpointServiceId') && attributes.key?(:'endpoint_service_id') self.endpoint_service_id = attributes[:'endpoint_service_id'] if attributes[:'endpoint_service_id'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.vcn_id = attributes[:'vcnId'] if attributes[:'vcnId'] raise 'You cannot provide both :vcnId and :vcn_id' if attributes.key?(:'vcnId') && attributes.key?(:'vcn_id') self.vcn_id = attributes[:'vcn_id'] if attributes[:'vcn_id'] self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId'] raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id') self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id'] self.private_endpoint_vnic_id = attributes[:'privateEndpointVnicId'] if attributes[:'privateEndpointVnicId'] raise 'You cannot provide both :privateEndpointVnicId and :private_endpoint_vnic_id' if attributes.key?(:'privateEndpointVnicId') && attributes.key?(:'private_endpoint_vnic_id') self.private_endpoint_vnic_id = attributes[:'private_endpoint_vnic_id'] if attributes[:'private_endpoint_vnic_id'] self.private_endpoint_ip = attributes[:'privateEndpointIp'] if attributes[:'privateEndpointIp'] raise 'You cannot provide both :privateEndpointIp and :private_endpoint_ip' if attributes.key?(:'privateEndpointIp') && attributes.key?(:'private_endpoint_ip') self.private_endpoint_ip = attributes[:'private_endpoint_ip'] if attributes[:'private_endpoint_ip'] self.endpoint_fqdn = attributes[:'endpointFqdn'] if attributes[:'endpointFqdn'] raise 'You cannot provide both :endpointFqdn and :endpoint_fqdn' if attributes.key?(:'endpointFqdn') && attributes.key?(:'endpoint_fqdn') self.endpoint_fqdn = attributes[:'endpoint_fqdn'] if attributes[:'endpoint_fqdn'] self.additional_fqdns = attributes[:'additionalFqdns'] if attributes[:'additionalFqdns'] raise 'You cannot provide both :additionalFqdns and :additional_fqdns' if attributes.key?(:'additionalFqdns') && attributes.key?(:'additional_fqdns') self.additional_fqdns = attributes[:'additional_fqdns'] if attributes[:'additional_fqdns'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.nsg_ids = attributes[:'nsgIds'] if attributes[:'nsgIds'] raise 'You cannot provide both :nsgIds and :nsg_ids' if attributes.key?(:'nsgIds') && attributes.key?(:'nsg_ids') self.nsg_ids = attributes[:'nsg_ids'] if attributes[:'nsg_ids'] self.reverse_connection_configuration = attributes[:'reverseConnectionConfiguration'] if attributes[:'reverseConnectionConfiguration'] raise 'You cannot provide both :reverseConnectionConfiguration and :reverse_connection_configuration' if attributes.key?(:'reverseConnectionConfiguration') && attributes.key?(:'reverse_connection_configuration') self.reverse_connection_configuration = attributes[:'reverse_connection_configuration'] if attributes[:'reverse_connection_configuration'] end |
Instance Attribute Details
#additional_fqdns ⇒ Array<String>
A list of additional FQDNs that can be also be used for the private endpoint.
89 90 91 |
# File 'lib/oci/database_tools/models/database_tools_private_endpoint.rb', line 89 def additional_fqdns @additional_fqdns end |
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the containing Compartment.
23 24 25 |
# File 'lib/oci/database_tools/models/database_tools_private_endpoint.rb', line 23 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
29 30 31 |
# File 'lib/oci/database_tools/models/database_tools_private_endpoint.rb', line 29 def @defined_tags end |
#description ⇒ String
A description of the DatabaseToolsPrivateEndpoint.
49 50 51 |
# File 'lib/oci/database_tools/models/database_tools_private_endpoint.rb', line 49 def description @description end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
45 46 47 |
# File 'lib/oci/database_tools/models/database_tools_private_endpoint.rb', line 45 def display_name @display_name end |
#endpoint_fqdn ⇒ String
Then FQDN to use for the private endpoint.
85 86 87 |
# File 'lib/oci/database_tools/models/database_tools_private_endpoint.rb', line 85 def endpoint_fqdn @endpoint_fqdn end |
#endpoint_service_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the DatabaseToolsEndpointService.
57 58 59 |
# File 'lib/oci/database_tools/models/database_tools_private_endpoint.rb', line 57 def endpoint_service_id @endpoint_service_id end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`
35 36 37 |
# File 'lib/oci/database_tools/models/database_tools_private_endpoint.rb', line 35 def @freeform_tags end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the DatabaseToolsPrivateEndpoint.
53 54 55 |
# File 'lib/oci/database_tools/models/database_tools_private_endpoint.rb', line 53 def id @id end |
#lifecycle_details ⇒ String
A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
97 98 99 |
# File 'lib/oci/database_tools/models/database_tools_private_endpoint.rb', line 97 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
[Required] The current state of the DatabaseToolsPrivateEndpoint.
93 94 95 |
# File 'lib/oci/database_tools/models/database_tools_private_endpoint.rb', line 93 def lifecycle_state @lifecycle_state end |
#nsg_ids ⇒ Array<String>
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the network security groups that the private endpoint’s VNIC belongs to. For more information about NSGs, see NetworkSecurityGroup.
104 105 106 |
# File 'lib/oci/database_tools/models/database_tools_private_endpoint.rb', line 104 def nsg_ids @nsg_ids end |
#private_endpoint_ip ⇒ String
The private IP address that represents the access point for the associated endpoint service.
81 82 83 |
# File 'lib/oci/database_tools/models/database_tools_private_endpoint.rb', line 81 def private_endpoint_ip @private_endpoint_ip end |
#private_endpoint_vnic_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the private endpoint’s VNIC.
77 78 79 |
# File 'lib/oci/database_tools/models/database_tools_private_endpoint.rb', line 77 def private_endpoint_vnic_id @private_endpoint_vnic_id end |
#reverse_connection_configuration ⇒ OCI::DatabaseTools::Models::DatabaseToolsPrivateEndpointReverseConnectionConfiguration
107 108 109 |
# File 'lib/oci/database_tools/models/database_tools_private_endpoint.rb', line 107 def reverse_connection_configuration @reverse_connection_configuration end |
#subnet_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the subnet that the private endpoint belongs to.
73 74 75 |
# File 'lib/oci/database_tools/models/database_tools_private_endpoint.rb', line 73 def subnet_id @subnet_id end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys. These predefined keys are scoped to namespaces. Example: ‘{"free-tier-retained": "true"}`
41 42 43 |
# File 'lib/oci/database_tools/models/database_tools_private_endpoint.rb', line 41 def @system_tags end |
#time_created ⇒ DateTime
[Required] The time the DatabaseToolsPrivateEndpoint was created. An RFC3339 formatted datetime string
61 62 63 |
# File 'lib/oci/database_tools/models/database_tools_private_endpoint.rb', line 61 def time_created @time_created end |
#time_updated ⇒ DateTime
[Required] The time the DatabaseToolsPrivateEndpoint was updated. An RFC3339 formatted datetime string
65 66 67 |
# File 'lib/oci/database_tools/models/database_tools_private_endpoint.rb', line 65 def time_updated @time_updated end |
#vcn_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VCN that the private endpoint belongs to.
69 70 71 |
# File 'lib/oci/database_tools/models/database_tools_private_endpoint.rb', line 69 def vcn_id @vcn_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/oci/database_tools/models/database_tools_private_endpoint.rb', line 110 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'defined_tags': :'definedTags', 'freeform_tags': :'freeformTags', 'system_tags': :'systemTags', 'display_name': :'displayName', 'description': :'description', 'id': :'id', 'endpoint_service_id': :'endpointServiceId', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'vcn_id': :'vcnId', 'subnet_id': :'subnetId', 'private_endpoint_vnic_id': :'privateEndpointVnicId', 'private_endpoint_ip': :'privateEndpointIp', 'endpoint_fqdn': :'endpointFqdn', 'additional_fqdns': :'additionalFqdns', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'nsg_ids': :'nsgIds', 'reverse_connection_configuration': :'reverseConnectionConfiguration' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/oci/database_tools/models/database_tools_private_endpoint.rb', line 138 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'freeform_tags': :'Hash<String, String>', 'system_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'description': :'String', 'id': :'String', 'endpoint_service_id': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'vcn_id': :'String', 'subnet_id': :'String', 'private_endpoint_vnic_id': :'String', 'private_endpoint_ip': :'String', 'endpoint_fqdn': :'String', 'additional_fqdns': :'Array<String>', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'nsg_ids': :'Array<String>', 'reverse_connection_configuration': :'OCI::DatabaseTools::Models::DatabaseToolsPrivateEndpointReverseConnectionConfiguration' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 |
# File 'lib/oci/database_tools/models/database_tools_private_endpoint.rb', line 330 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && == other. && == other. && == other. && display_name == other.display_name && description == other.description && id == other.id && endpoint_service_id == other.endpoint_service_id && time_created == other.time_created && time_updated == other.time_updated && vcn_id == other.vcn_id && subnet_id == other.subnet_id && private_endpoint_vnic_id == other.private_endpoint_vnic_id && private_endpoint_ip == other.private_endpoint_ip && endpoint_fqdn == other.endpoint_fqdn && additional_fqdns == other.additional_fqdns && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && nsg_ids == other.nsg_ids && reverse_connection_configuration == other.reverse_connection_configuration end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 |
# File 'lib/oci/database_tools/models/database_tools_private_endpoint.rb', line 379 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
359 360 361 |
# File 'lib/oci/database_tools/models/database_tools_private_endpoint.rb', line 359 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
368 369 370 |
# File 'lib/oci/database_tools/models/database_tools_private_endpoint.rb', line 368 def hash [compartment_id, , , , display_name, description, id, endpoint_service_id, time_created, time_updated, vcn_id, subnet_id, private_endpoint_vnic_id, private_endpoint_ip, endpoint_fqdn, additional_fqdns, lifecycle_state, lifecycle_details, nsg_ids, reverse_connection_configuration].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
412 413 414 415 416 417 418 419 420 421 |
# File 'lib/oci/database_tools/models/database_tools_private_endpoint.rb', line 412 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
406 407 408 |
# File 'lib/oci/database_tools/models/database_tools_private_endpoint.rb', line 406 def to_s to_hash.to_s end |