Class: OCI::DatabaseTools::Models::DatabaseToolsRelatedResourceMySql
- Inherits:
-
Object
- Object
- OCI::DatabaseTools::Models::DatabaseToolsRelatedResourceMySql
- Defined in:
- lib/oci/database_tools/models/database_tools_related_resource_my_sql.rb
Overview
A related resource
Constant Summary collapse
- ENTITY_TYPE_ENUM =
[ ENTITY_TYPE_MYSQLDBSYSTEM = 'MYSQLDBSYSTEM'.freeze, ENTITY_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#entity_type ⇒ String
**[Required]** The resource entity type.
-
#identifier ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the related resource.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DatabaseToolsRelatedResourceMySql
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DatabaseToolsRelatedResourceMySql
Initializes the object
52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/oci/database_tools/models/database_tools_related_resource_my_sql.rb', line 52 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.entity_type = attributes[:'entityType'] if attributes[:'entityType'] raise 'You cannot provide both :entityType and :entity_type' if attributes.key?(:'entityType') && attributes.key?(:'entity_type') self.entity_type = attributes[:'entity_type'] if attributes[:'entity_type'] self.identifier = attributes[:'identifier'] if attributes[:'identifier'] end |
Instance Attribute Details
#entity_type ⇒ String
**[Required]** The resource entity type.
18 19 20 |
# File 'lib/oci/database_tools/models/database_tools_related_resource_my_sql.rb', line 18 def entity_type @entity_type end |
#identifier ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the related resource.
22 23 24 |
# File 'lib/oci/database_tools/models/database_tools_related_resource_my_sql.rb', line 22 def identifier @identifier end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
25 26 27 28 29 30 31 32 |
# File 'lib/oci/database_tools/models/database_tools_related_resource_my_sql.rb', line 25 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'entity_type': :'entityType', 'identifier': :'identifier' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
35 36 37 38 39 40 41 42 |
# File 'lib/oci/database_tools/models/database_tools_related_resource_my_sql.rb', line 35 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'entity_type': :'String', 'identifier': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
87 88 89 90 91 92 93 |
# File 'lib/oci/database_tools/models/database_tools_related_resource_my_sql.rb', line 87 def ==(other) return true if equal?(other) self.class == other.class && entity_type == other.entity_type && identifier == other.identifier end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/oci/database_tools/models/database_tools_related_resource_my_sql.rb', line 118 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
98 99 100 |
# File 'lib/oci/database_tools/models/database_tools_related_resource_my_sql.rb', line 98 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
107 108 109 |
# File 'lib/oci/database_tools/models/database_tools_related_resource_my_sql.rb', line 107 def hash [entity_type, identifier].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
151 152 153 154 155 156 157 158 159 160 |
# File 'lib/oci/database_tools/models/database_tools_related_resource_my_sql.rb', line 151 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
145 146 147 |
# File 'lib/oci/database_tools/models/database_tools_related_resource_my_sql.rb', line 145 def to_s to_hash.to_s end |