Class: OCI::DatabaseTools::Models::ValidateDatabaseToolsConnectionResult

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database_tools/models/validate_database_tools_connection_result.rb

Overview

Connection validation result. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class

Constant Summary collapse

TYPE_ENUM =
[
  TYPE_ORACLE_DATABASE = 'ORACLE_DATABASE'.freeze,
  TYPE_MYSQL = 'MYSQL'.freeze,
  TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ValidateDatabaseToolsConnectionResult

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :type (String)

    The value to assign to the #type property

  • :code (String)

    The value to assign to the #code property

  • :message (String)

    The value to assign to the #message property

  • :cause (String)

    The value to assign to the #cause property

  • :action (String)

    The value to assign to the #action property



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/oci/database_tools/models/validate_database_tools_connection_result.rb', line 91

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.type = attributes[:'type'] if attributes[:'type']

  self.code = attributes[:'code'] if attributes[:'code']

  self.message = attributes[:'message'] if attributes[:'message']

  self.cause = attributes[:'cause'] if attributes[:'cause']

  self.action = attributes[:'action'] if attributes[:'action']
end

Instance Attribute Details

#actionString

A human-readable message that suggests a remedial action to resolve the validation error.

Returns:

  • (String)


36
37
38
# File 'lib/oci/database_tools/models/validate_database_tools_connection_result.rb', line 36

def action
  @action
end

#causeString

A human-readable message that describes possible causes for the validation error.

Returns:

  • (String)


32
33
34
# File 'lib/oci/database_tools/models/validate_database_tools_connection_result.rb', line 32

def cause
  @cause
end

#codeString

**[Required]** A short code that defines the result of the validation, meant for programmatic parsing. The value OK indicates that the validation was successful.

Returns:

  • (String)


24
25
26
# File 'lib/oci/database_tools/models/validate_database_tools_connection_result.rb', line 24

def code
  @code
end

#messageString

**[Required]** A human-readable message that describes the result of the validation.

Returns:

  • (String)


28
29
30
# File 'lib/oci/database_tools/models/validate_database_tools_connection_result.rb', line 28

def message
  @message
end

#typeString

**[Required]** The Database Tools connection type.

Returns:

  • (String)


20
21
22
# File 'lib/oci/database_tools/models/validate_database_tools_connection_result.rb', line 20

def type
  @type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



39
40
41
42
43
44
45
46
47
48
49
# File 'lib/oci/database_tools/models/validate_database_tools_connection_result.rb', line 39

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'type': :'type',
    'code': :'code',
    'message': :'message',
    'cause': :'cause',
    'action': :'action'
    # rubocop:enable Style/SymbolLiteral
  }
end

.get_subtype(object_hash) ⇒ Object

Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.



69
70
71
72
73
74
75
76
77
# File 'lib/oci/database_tools/models/validate_database_tools_connection_result.rb', line 69

def self.get_subtype(object_hash)
  type = object_hash[:'type'] # rubocop:disable Style/SymbolLiteral

  return 'OCI::DatabaseTools::Models::ValidateDatabaseToolsConnectionOracleDatabaseResult' if type == 'ORACLE_DATABASE'
  return 'OCI::DatabaseTools::Models::ValidateDatabaseToolsConnectionMySqlResult' if type == 'MYSQL'

  # TODO: Log a warning when the subtype is not found.
  'OCI::DatabaseTools::Models::ValidateDatabaseToolsConnectionResult'
end

.swagger_typesObject

Attribute type mapping.



52
53
54
55
56
57
58
59
60
61
62
# File 'lib/oci/database_tools/models/validate_database_tools_connection_result.rb', line 52

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'type': :'String',
    'code': :'String',
    'message': :'String',
    'cause': :'String',
    'action': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



128
129
130
131
132
133
134
135
136
137
# File 'lib/oci/database_tools/models/validate_database_tools_connection_result.rb', line 128

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    type == other.type &&
    code == other.code &&
    message == other.message &&
    cause == other.cause &&
    action == other.action
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/oci/database_tools/models/validate_database_tools_connection_result.rb', line 162

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


142
143
144
# File 'lib/oci/database_tools/models/validate_database_tools_connection_result.rb', line 142

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



151
152
153
# File 'lib/oci/database_tools/models/validate_database_tools_connection_result.rb', line 151

def hash
  [type, code, message, cause, action].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



195
196
197
198
199
200
201
202
203
204
# File 'lib/oci/database_tools/models/validate_database_tools_connection_result.rb', line 195

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



189
190
191
# File 'lib/oci/database_tools/models/validate_database_tools_connection_result.rb', line 189

def to_s
  to_hash.to_s
end