Class: OCI::Devops::Models::ApprovalAction
- Inherits:
-
Object
- Object
- OCI::Devops::Models::ApprovalAction
- Defined in:
- lib/oci/devops/models/approval_action.rb
Overview
Information about the approval action of DevOps deployment stages.
Constant Summary collapse
- ACTION_ENUM =
[ ACTION_APPROVE = 'APPROVE'.freeze, ACTION_REJECT = 'REJECT'.freeze, ACTION_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#action ⇒ String
**[Required]** The action of the user on the DevOps deployment stage.
-
#reason ⇒ String
The reason for approving or rejecting the deployment.
-
#subject_id ⇒ String
**[Required]** The subject ID of the user who approves or disapproves a DevOps deployment stage.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ApprovalAction
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ApprovalAction
Initializes the object
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/oci/devops/models/approval_action.rb', line 60 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.subject_id = attributes[:'subjectId'] if attributes[:'subjectId'] raise 'You cannot provide both :subjectId and :subject_id' if attributes.key?(:'subjectId') && attributes.key?(:'subject_id') self.subject_id = attributes[:'subject_id'] if attributes[:'subject_id'] self.action = attributes[:'action'] if attributes[:'action'] self.reason = attributes[:'reason'] if attributes[:'reason'] end |
Instance Attribute Details
#action ⇒ String
**[Required]** The action of the user on the DevOps deployment stage.
23 24 25 |
# File 'lib/oci/devops/models/approval_action.rb', line 23 def action @action end |
#reason ⇒ String
The reason for approving or rejecting the deployment.
27 28 29 |
# File 'lib/oci/devops/models/approval_action.rb', line 27 def reason @reason end |
#subject_id ⇒ String
**[Required]** The subject ID of the user who approves or disapproves a DevOps deployment stage.
19 20 21 |
# File 'lib/oci/devops/models/approval_action.rb', line 19 def subject_id @subject_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
30 31 32 33 34 35 36 37 38 |
# File 'lib/oci/devops/models/approval_action.rb', line 30 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'subject_id': :'subjectId', 'action': :'action', 'reason': :'reason' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
41 42 43 44 45 46 47 48 49 |
# File 'lib/oci/devops/models/approval_action.rb', line 41 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'subject_id': :'String', 'action': :'String', 'reason': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
97 98 99 100 101 102 103 104 |
# File 'lib/oci/devops/models/approval_action.rb', line 97 def ==(other) return true if equal?(other) self.class == other.class && subject_id == other.subject_id && action == other.action && reason == other.reason end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/oci/devops/models/approval_action.rb', line 129 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
109 110 111 |
# File 'lib/oci/devops/models/approval_action.rb', line 109 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
118 119 120 |
# File 'lib/oci/devops/models/approval_action.rb', line 118 def hash [subject_id, action, reason].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
162 163 164 165 166 167 168 169 170 171 |
# File 'lib/oci/devops/models/approval_action.rb', line 162 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
156 157 158 |
# File 'lib/oci/devops/models/approval_action.rb', line 156 def to_s to_hash.to_s end |