Class: OCI::Devops::Models::BitbucketCloudFilter
- Defined in:
- lib/oci/devops/models/bitbucket_cloud_filter.rb
Overview
The filter for Bitbucket Cloud events.
Constant Summary collapse
- EVENTS_ENUM =
[ EVENTS_PUSH = 'PUSH'.freeze, EVENTS_PULL_REQUEST_CREATED = 'PULL_REQUEST_CREATED'.freeze, EVENTS_PULL_REQUEST_UPDATED = 'PULL_REQUEST_UPDATED'.freeze, EVENTS_PULL_REQUEST_MERGED = 'PULL_REQUEST_MERGED'.freeze, EVENTS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#events ⇒ Array<String>
The events, for example, PUSH, PULL_REQUEST_MERGE.
- #include ⇒ OCI::Devops::Models::BitbucketCloudFilterAttributes
Attributes inherited from Filter
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BitbucketCloudFilter
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from Filter
Constructor Details
#initialize(attributes = {}) ⇒ BitbucketCloudFilter
Initializes the object
57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/oci/devops/models/bitbucket_cloud_filter.rb', line 57 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['triggerSource'] = 'BITBUCKET_CLOUD' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.events = attributes[:'events'] if attributes[:'events'] self.include = attributes[:'include'] if attributes[:'include'] end |
Instance Attribute Details
#events ⇒ Array<String>
The events, for example, PUSH, PULL_REQUEST_MERGE.
22 23 24 |
# File 'lib/oci/devops/models/bitbucket_cloud_filter.rb', line 22 def events @events end |
#include ⇒ OCI::Devops::Models::BitbucketCloudFilterAttributes
25 26 27 |
# File 'lib/oci/devops/models/bitbucket_cloud_filter.rb', line 25 def include @include end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 35 36 |
# File 'lib/oci/devops/models/bitbucket_cloud_filter.rb', line 28 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'trigger_source': :'triggerSource', 'events': :'events', 'include': :'include' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
39 40 41 42 43 44 45 46 47 |
# File 'lib/oci/devops/models/bitbucket_cloud_filter.rb', line 39 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'trigger_source': :'String', 'events': :'Array<String>', 'include': :'OCI::Devops::Models::BitbucketCloudFilterAttributes' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
99 100 101 102 103 104 105 106 |
# File 'lib/oci/devops/models/bitbucket_cloud_filter.rb', line 99 def ==(other) return true if equal?(other) self.class == other.class && trigger_source == other.trigger_source && events == other.events && include == other.include end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/oci/devops/models/bitbucket_cloud_filter.rb', line 131 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
111 112 113 |
# File 'lib/oci/devops/models/bitbucket_cloud_filter.rb', line 111 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
120 121 122 |
# File 'lib/oci/devops/models/bitbucket_cloud_filter.rb', line 120 def hash [trigger_source, events, include].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
164 165 166 167 168 169 170 171 172 173 |
# File 'lib/oci/devops/models/bitbucket_cloud_filter.rb', line 164 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
158 159 160 |
# File 'lib/oci/devops/models/bitbucket_cloud_filter.rb', line 158 def to_s to_hash.to_s end |