Class: OCI::Devops::Models::BuildPipelineStage
- Inherits:
-
Object
- Object
- OCI::Devops::Models::BuildPipelineStage
- Defined in:
- lib/oci/devops/models/build_pipeline_stage.rb
Overview
A single node in a build pipeline. A stage takes a specific designated action. There are many types of stages such as ‘Build’ and ‘Deliver Artifacts’.
This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
BuildStage, DeliverArtifactStage, TriggerDeploymentStage, WaitStage
Constant Summary collapse
- BUILD_PIPELINE_STAGE_TYPE_ENUM =
[ BUILD_PIPELINE_STAGE_TYPE_WAIT = 'WAIT'.freeze, BUILD_PIPELINE_STAGE_TYPE_BUILD = 'BUILD'.freeze, BUILD_PIPELINE_STAGE_TYPE_DELIVER_ARTIFACT = 'DELIVER_ARTIFACT'.freeze, BUILD_PIPELINE_STAGE_TYPE_TRIGGER_DEPLOYMENT_PIPELINE = 'TRIGGER_DEPLOYMENT_PIPELINE'.freeze, BUILD_PIPELINE_STAGE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#build_pipeline_id ⇒ String
[Required] The OCID of the build pipeline.
- #build_pipeline_stage_predecessor_collection ⇒ OCI::Devops::Models::BuildPipelineStagePredecessorCollection
-
#build_pipeline_stage_type ⇒ String
[Required] Defines the stage type, which is one of the following: Build, Deliver Artifacts, Wait, and Trigger Deployment.
-
#compartment_id ⇒ String
[Required] The OCID of the compartment where the pipeline is created.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
Optional description about the build stage.
-
#display_name ⇒ String
Stage display name, which can be renamed and is not necessarily unique.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
[Required] Unique identifier that is immutable on creation.
-
#lifecycle_details ⇒ String
A message describing the current state in more detail.
-
#lifecycle_state ⇒ String
The current state of the stage.
-
#project_id ⇒ String
[Required] The OCID of the DevOps project.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys.
-
#time_created ⇒ DateTime
The time the stage was created.
-
#time_updated ⇒ DateTime
The time the stage was updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BuildPipelineStage
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ BuildPipelineStage
Initializes the object
178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 |
# File 'lib/oci/devops/models/build_pipeline_stage.rb', line 178 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.project_id = attributes[:'projectId'] if attributes[:'projectId'] raise 'You cannot provide both :projectId and :project_id' if attributes.key?(:'projectId') && attributes.key?(:'project_id') self.project_id = attributes[:'project_id'] if attributes[:'project_id'] self.build_pipeline_id = attributes[:'buildPipelineId'] if attributes[:'buildPipelineId'] raise 'You cannot provide both :buildPipelineId and :build_pipeline_id' if attributes.key?(:'buildPipelineId') && attributes.key?(:'build_pipeline_id') self.build_pipeline_id = attributes[:'build_pipeline_id'] if attributes[:'build_pipeline_id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.build_pipeline_stage_type = attributes[:'buildPipelineStageType'] if attributes[:'buildPipelineStageType'] raise 'You cannot provide both :buildPipelineStageType and :build_pipeline_stage_type' if attributes.key?(:'buildPipelineStageType') && attributes.key?(:'build_pipeline_stage_type') self.build_pipeline_stage_type = attributes[:'build_pipeline_stage_type'] if attributes[:'build_pipeline_stage_type'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.build_pipeline_stage_predecessor_collection = attributes[:'buildPipelineStagePredecessorCollection'] if attributes[:'buildPipelineStagePredecessorCollection'] raise 'You cannot provide both :buildPipelineStagePredecessorCollection and :build_pipeline_stage_predecessor_collection' if attributes.key?(:'buildPipelineStagePredecessorCollection') && attributes.key?(:'build_pipeline_stage_predecessor_collection') self.build_pipeline_stage_predecessor_collection = attributes[:'build_pipeline_stage_predecessor_collection'] if attributes[:'build_pipeline_stage_predecessor_collection'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#build_pipeline_id ⇒ String
[Required] The OCID of the build pipeline.
50 51 52 |
# File 'lib/oci/devops/models/build_pipeline_stage.rb', line 50 def build_pipeline_id @build_pipeline_id end |
#build_pipeline_stage_predecessor_collection ⇒ OCI::Devops::Models::BuildPipelineStagePredecessorCollection
79 80 81 |
# File 'lib/oci/devops/models/build_pipeline_stage.rb', line 79 def build_pipeline_stage_predecessor_collection @build_pipeline_stage_predecessor_collection end |
#build_pipeline_stage_type ⇒ String
[Required] Defines the stage type, which is one of the following: Build, Deliver Artifacts, Wait, and Trigger Deployment.
59 60 61 |
# File 'lib/oci/devops/models/build_pipeline_stage.rb', line 59 def build_pipeline_stage_type @build_pipeline_stage_type end |
#compartment_id ⇒ String
[Required] The OCID of the compartment where the pipeline is created.
54 55 56 |
# File 'lib/oci/devops/models/build_pipeline_stage.rb', line 54 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"bar-key": "value"}`
87 88 89 |
# File 'lib/oci/devops/models/build_pipeline_stage.rb', line 87 def end |
#description ⇒ String
Optional description about the build stage.
42 43 44 |
# File 'lib/oci/devops/models/build_pipeline_stage.rb', line 42 def description @description end |
#display_name ⇒ String
Stage display name, which can be renamed and is not necessarily unique. Avoid entering confidential information.
38 39 40 |
# File 'lib/oci/devops/models/build_pipeline_stage.rb', line 38 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"value"`
83 84 85 |
# File 'lib/oci/devops/models/build_pipeline_stage.rb', line 83 def end |
#id ⇒ String
[Required] Unique identifier that is immutable on creation.
34 35 36 |
# File 'lib/oci/devops/models/build_pipeline_stage.rb', line 34 def id @id end |
#lifecycle_details ⇒ String
A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
76 77 78 |
# File 'lib/oci/devops/models/build_pipeline_stage.rb', line 76 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
The current state of the stage.
72 73 74 |
# File 'lib/oci/devops/models/build_pipeline_stage.rb', line 72 def lifecycle_state @lifecycle_state end |
#project_id ⇒ String
[Required] The OCID of the DevOps project.
46 47 48 |
# File 'lib/oci/devops/models/build_pipeline_stage.rb', line 46 def project_id @project_id end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys. These predefined keys are scoped to namespaces. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"free-tier-retained": "true"}`
91 92 93 |
# File 'lib/oci/devops/models/build_pipeline_stage.rb', line 91 def end |
#time_created ⇒ DateTime
The time the stage was created. Format defined by [RFC3339](datatracker.ietf.org/doc/html/rfc3339).
63 64 65 |
# File 'lib/oci/devops/models/build_pipeline_stage.rb', line 63 def time_created @time_created end |
#time_updated ⇒ DateTime
The time the stage was updated. Format defined by [RFC3339](datatracker.ietf.org/doc/html/rfc3339).
67 68 69 |
# File 'lib/oci/devops/models/build_pipeline_stage.rb', line 67 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/oci/devops/models/build_pipeline_stage.rb', line 94 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'description': :'description', 'project_id': :'projectId', 'build_pipeline_id': :'buildPipelineId', 'compartment_id': :'compartmentId', 'build_pipeline_stage_type': :'buildPipelineStageType', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'build_pipeline_stage_predecessor_collection': :'buildPipelineStagePredecessorCollection', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/oci/devops/models/build_pipeline_stage.rb', line 144 def self.get_subtype(object_hash) type = object_hash[:'buildPipelineStageType'] # rubocop:disable Style/SymbolLiteral return 'OCI::Devops::Models::DeliverArtifactStage' if type == 'DELIVER_ARTIFACT' return 'OCI::Devops::Models::WaitStage' if type == 'WAIT' return 'OCI::Devops::Models::TriggerDeploymentStage' if type == 'TRIGGER_DEPLOYMENT_PIPELINE' return 'OCI::Devops::Models::BuildStage' if type == 'BUILD' # TODO: Log a warning when the subtype is not found. 'OCI::Devops::Models::BuildPipelineStage' end |
.swagger_types ⇒ Object
Attribute type mapping.
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/oci/devops/models/build_pipeline_stage.rb', line 117 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'description': :'String', 'project_id': :'String', 'build_pipeline_id': :'String', 'compartment_id': :'String', 'build_pipeline_stage_type': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'build_pipeline_stage_predecessor_collection': :'OCI::Devops::Models::BuildPipelineStagePredecessorCollection', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 |
# File 'lib/oci/devops/models/build_pipeline_stage.rb', line 300 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && description == other.description && project_id == other.project_id && build_pipeline_id == other.build_pipeline_id && compartment_id == other.compartment_id && build_pipeline_stage_type == other.build_pipeline_stage_type && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && build_pipeline_stage_predecessor_collection == other.build_pipeline_stage_predecessor_collection && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 |
# File 'lib/oci/devops/models/build_pipeline_stage.rb', line 344 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
324 325 326 |
# File 'lib/oci/devops/models/build_pipeline_stage.rb', line 324 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
333 334 335 |
# File 'lib/oci/devops/models/build_pipeline_stage.rb', line 333 def hash [id, display_name, description, project_id, build_pipeline_id, compartment_id, build_pipeline_stage_type, time_created, time_updated, lifecycle_state, lifecycle_details, build_pipeline_stage_predecessor_collection, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
377 378 379 380 381 382 383 384 385 386 |
# File 'lib/oci/devops/models/build_pipeline_stage.rb', line 377 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
371 372 373 |
# File 'lib/oci/devops/models/build_pipeline_stage.rb', line 371 def to_s to_hash.to_s end |