Class: OCI::Devops::Models::BuildPipelineSummary
- Inherits:
-
Object
- Object
- OCI::Devops::Models::BuildPipelineSummary
- Defined in:
- lib/oci/devops/models/build_pipeline_summary.rb
Overview
Summary of the build pipeline.
Instance Attribute Summary collapse
- #build_pipeline_parameters ⇒ OCI::Devops::Models::BuildPipelineParameterCollection
-
#compartment_id ⇒ String
[Required] The OCID of the compartment where the build pipeline is created.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
Optional description about the build pipeline.
-
#display_name ⇒ String
Build pipeline display name, which can be renamed and is not necessarily unique.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
[Required] Unique identifier that is immutable on creation.
-
#lifecycle_state ⇒ String
The current state of the build pipeline.
-
#project_id ⇒ String
[Required] The OCID of the DevOps project.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys.
-
#time_created ⇒ DateTime
The time the build pipeline was created.
-
#time_updated ⇒ DateTime
The time the build pipeline was updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BuildPipelineSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ BuildPipelineSummary
Initializes the object
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/oci/devops/models/build_pipeline_summary.rb', line 115 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.description = attributes[:'description'] if attributes[:'description'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.project_id = attributes[:'projectId'] if attributes[:'projectId'] raise 'You cannot provide both :projectId and :project_id' if attributes.key?(:'projectId') && attributes.key?(:'project_id') self.project_id = attributes[:'project_id'] if attributes[:'project_id'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.build_pipeline_parameters = attributes[:'buildPipelineParameters'] if attributes[:'buildPipelineParameters'] raise 'You cannot provide both :buildPipelineParameters and :build_pipeline_parameters' if attributes.key?(:'buildPipelineParameters') && attributes.key?(:'build_pipeline_parameters') self.build_pipeline_parameters = attributes[:'build_pipeline_parameters'] if attributes[:'build_pipeline_parameters'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#build_pipeline_parameters ⇒ OCI::Devops::Models::BuildPipelineParameterCollection
43 44 45 |
# File 'lib/oci/devops/models/build_pipeline_summary.rb', line 43 def build_pipeline_parameters @build_pipeline_parameters end |
#compartment_id ⇒ String
[Required] The OCID of the compartment where the build pipeline is created.
24 25 26 |
# File 'lib/oci/devops/models/build_pipeline_summary.rb', line 24 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"bar-key": "value"}`
51 52 53 |
# File 'lib/oci/devops/models/build_pipeline_summary.rb', line 51 def end |
#description ⇒ String
Optional description about the build pipeline.
16 17 18 |
# File 'lib/oci/devops/models/build_pipeline_summary.rb', line 16 def description @description end |
#display_name ⇒ String
Build pipeline display name, which can be renamed and is not necessarily unique. Avoid entering confidential information.
20 21 22 |
# File 'lib/oci/devops/models/build_pipeline_summary.rb', line 20 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"value"`
47 48 49 |
# File 'lib/oci/devops/models/build_pipeline_summary.rb', line 47 def end |
#id ⇒ String
[Required] Unique identifier that is immutable on creation.
12 13 14 |
# File 'lib/oci/devops/models/build_pipeline_summary.rb', line 12 def id @id end |
#lifecycle_state ⇒ String
The current state of the build pipeline.
40 41 42 |
# File 'lib/oci/devops/models/build_pipeline_summary.rb', line 40 def lifecycle_state @lifecycle_state end |
#project_id ⇒ String
[Required] The OCID of the DevOps project.
28 29 30 |
# File 'lib/oci/devops/models/build_pipeline_summary.rb', line 28 def project_id @project_id end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys. These predefined keys are scoped to namespaces. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"free-tier-retained": "true"}`
55 56 57 |
# File 'lib/oci/devops/models/build_pipeline_summary.rb', line 55 def end |
#time_created ⇒ DateTime
The time the build pipeline was created. Format defined by [RFC3339](datatracker.ietf.org/doc/html/rfc3339).
32 33 34 |
# File 'lib/oci/devops/models/build_pipeline_summary.rb', line 32 def time_created @time_created end |
#time_updated ⇒ DateTime
The time the build pipeline was updated. Format defined by [RFC3339](datatracker.ietf.org/doc/html/rfc3339).
36 37 38 |
# File 'lib/oci/devops/models/build_pipeline_summary.rb', line 36 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/oci/devops/models/build_pipeline_summary.rb', line 58 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'description': :'description', 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'project_id': :'projectId', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'build_pipeline_parameters': :'buildPipelineParameters', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/oci/devops/models/build_pipeline_summary.rb', line 78 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'description': :'String', 'display_name': :'String', 'compartment_id': :'String', 'project_id': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'build_pipeline_parameters': :'OCI::Devops::Models::BuildPipelineParameterCollection', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/oci/devops/models/build_pipeline_summary.rb', line 193 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && description == other.description && display_name == other.display_name && compartment_id == other.compartment_id && project_id == other.project_id && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && build_pipeline_parameters == other.build_pipeline_parameters && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/oci/devops/models/build_pipeline_summary.rb', line 234 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
214 215 216 |
# File 'lib/oci/devops/models/build_pipeline_summary.rb', line 214 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
223 224 225 |
# File 'lib/oci/devops/models/build_pipeline_summary.rb', line 223 def hash [id, description, display_name, compartment_id, project_id, time_created, time_updated, lifecycle_state, build_pipeline_parameters, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
267 268 269 270 271 272 273 274 275 276 |
# File 'lib/oci/devops/models/build_pipeline_summary.rb', line 267 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
261 262 263 |
# File 'lib/oci/devops/models/build_pipeline_summary.rb', line 261 def to_s to_hash.to_s end |