Class: OCI::Devops::Models::BuildRun
- Inherits:
-
Object
- Object
- OCI::Devops::Models::BuildRun
- Defined in:
- lib/oci/devops/models/build_run.rb
Overview
Each time you attempt to run a build pipeline you create one build run. A build can be running currently, or it can be a record of the run that happened in the past. The set of build runs constitutes a build pipeline’s history.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_ACCEPTED = 'ACCEPTED'.freeze, LIFECYCLE_STATE_IN_PROGRESS = 'IN_PROGRESS'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_SUCCEEDED = 'SUCCEEDED'.freeze, LIFECYCLE_STATE_CANCELING = 'CANCELING'.freeze, LIFECYCLE_STATE_CANCELED = 'CANCELED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
- #build_outputs ⇒ OCI::Devops::Models::BuildOutputs
-
#build_pipeline_id ⇒ String
The OCID of the build pipeline.
- #build_run_arguments ⇒ OCI::Devops::Models::BuildRunArgumentCollection
- #build_run_progress ⇒ OCI::Devops::Models::BuildRunProgress
-
#build_run_source ⇒ OCI::Devops::Models::BuildRunSource
This attribute is required.
- #commit_info ⇒ OCI::Devops::Models::CommitInfo
-
#compartment_id ⇒ String
The OCID of the compartment where the build is running.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
Build run display name, which can be renamed and is not necessarily unique.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
[Required] Unique identifier that is immutable on creation.
-
#lifecycle_details ⇒ String
A message describing the current state in more detail.
-
#lifecycle_state ⇒ String
The current state of the build run.
-
#project_id ⇒ String
The OCID of the DevOps project.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys.
-
#time_created ⇒ DateTime
The time the build run was created.
-
#time_updated ⇒ DateTime
The time the build run was updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BuildRun
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ BuildRun
Initializes the object
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/oci/devops/models/build_run.rb', line 161 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.project_id = attributes[:'projectId'] if attributes[:'projectId'] raise 'You cannot provide both :projectId and :project_id' if attributes.key?(:'projectId') && attributes.key?(:'project_id') self.project_id = attributes[:'project_id'] if attributes[:'project_id'] self.build_pipeline_id = attributes[:'buildPipelineId'] if attributes[:'buildPipelineId'] raise 'You cannot provide both :buildPipelineId and :build_pipeline_id' if attributes.key?(:'buildPipelineId') && attributes.key?(:'build_pipeline_id') self.build_pipeline_id = attributes[:'build_pipeline_id'] if attributes[:'build_pipeline_id'] self.build_run_source = attributes[:'buildRunSource'] if attributes[:'buildRunSource'] raise 'You cannot provide both :buildRunSource and :build_run_source' if attributes.key?(:'buildRunSource') && attributes.key?(:'build_run_source') self.build_run_source = attributes[:'build_run_source'] if attributes[:'build_run_source'] self.build_run_arguments = attributes[:'buildRunArguments'] if attributes[:'buildRunArguments'] raise 'You cannot provide both :buildRunArguments and :build_run_arguments' if attributes.key?(:'buildRunArguments') && attributes.key?(:'build_run_arguments') self.build_run_arguments = attributes[:'build_run_arguments'] if attributes[:'build_run_arguments'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.build_run_progress = attributes[:'buildRunProgress'] if attributes[:'buildRunProgress'] raise 'You cannot provide both :buildRunProgress and :build_run_progress' if attributes.key?(:'buildRunProgress') && attributes.key?(:'build_run_progress') self.build_run_progress = attributes[:'build_run_progress'] if attributes[:'build_run_progress'] self.commit_info = attributes[:'commitInfo'] if attributes[:'commitInfo'] raise 'You cannot provide both :commitInfo and :commit_info' if attributes.key?(:'commitInfo') && attributes.key?(:'commit_info') self.commit_info = attributes[:'commit_info'] if attributes[:'commit_info'] self.build_outputs = attributes[:'buildOutputs'] if attributes[:'buildOutputs'] raise 'You cannot provide both :buildOutputs and :build_outputs' if attributes.key?(:'buildOutputs') && attributes.key?(:'build_outputs') self.build_outputs = attributes[:'build_outputs'] if attributes[:'build_outputs'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#build_outputs ⇒ OCI::Devops::Models::BuildOutputs
74 75 76 |
# File 'lib/oci/devops/models/build_run.rb', line 74 def build_outputs @build_outputs end |
#build_pipeline_id ⇒ String
The OCID of the build pipeline.
42 43 44 |
# File 'lib/oci/devops/models/build_run.rb', line 42 def build_pipeline_id @build_pipeline_id end |
#build_run_arguments ⇒ OCI::Devops::Models::BuildRunArgumentCollection
49 50 51 |
# File 'lib/oci/devops/models/build_run.rb', line 49 def build_run_arguments @build_run_arguments end |
#build_run_progress ⇒ OCI::Devops::Models::BuildRunProgress
68 69 70 |
# File 'lib/oci/devops/models/build_run.rb', line 68 def build_run_progress @build_run_progress end |
#build_run_source ⇒ OCI::Devops::Models::BuildRunSource
This attribute is required.
46 47 48 |
# File 'lib/oci/devops/models/build_run.rb', line 46 def build_run_source @build_run_source end |
#commit_info ⇒ OCI::Devops::Models::CommitInfo
71 72 73 |
# File 'lib/oci/devops/models/build_run.rb', line 71 def commit_info @commit_info end |
#compartment_id ⇒ String
The OCID of the compartment where the build is running.
34 35 36 |
# File 'lib/oci/devops/models/build_run.rb', line 34 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"bar-key": "value"}`
82 83 84 |
# File 'lib/oci/devops/models/build_run.rb', line 82 def end |
#display_name ⇒ String
Build run display name, which can be renamed and is not necessarily unique. Avoid entering confidential information.
30 31 32 |
# File 'lib/oci/devops/models/build_run.rb', line 30 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"value"`
78 79 80 |
# File 'lib/oci/devops/models/build_run.rb', line 78 def end |
#id ⇒ String
[Required] Unique identifier that is immutable on creation.
26 27 28 |
# File 'lib/oci/devops/models/build_run.rb', line 26 def id @id end |
#lifecycle_details ⇒ String
A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
65 66 67 |
# File 'lib/oci/devops/models/build_run.rb', line 65 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
The current state of the build run.
61 62 63 |
# File 'lib/oci/devops/models/build_run.rb', line 61 def lifecycle_state @lifecycle_state end |
#project_id ⇒ String
The OCID of the DevOps project.
38 39 40 |
# File 'lib/oci/devops/models/build_run.rb', line 38 def project_id @project_id end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys. These predefined keys are scoped to namespaces. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"free-tier-retained": "true"}`
86 87 88 |
# File 'lib/oci/devops/models/build_run.rb', line 86 def end |
#time_created ⇒ DateTime
The time the build run was created. Format defined by [RFC3339](datatracker.ietf.org/doc/html/rfc3339).
53 54 55 |
# File 'lib/oci/devops/models/build_run.rb', line 53 def time_created @time_created end |
#time_updated ⇒ DateTime
The time the build run was updated. Format defined by [RFC3339](datatracker.ietf.org/doc/html/rfc3339).
57 58 59 |
# File 'lib/oci/devops/models/build_run.rb', line 57 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/oci/devops/models/build_run.rb', line 89 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'project_id': :'projectId', 'build_pipeline_id': :'buildPipelineId', 'build_run_source': :'buildRunSource', 'build_run_arguments': :'buildRunArguments', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'build_run_progress': :'buildRunProgress', 'commit_info': :'commitInfo', 'build_outputs': :'buildOutputs', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/oci/devops/models/build_run.rb', line 114 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'compartment_id': :'String', 'project_id': :'String', 'build_pipeline_id': :'String', 'build_run_source': :'OCI::Devops::Models::BuildRunSource', 'build_run_arguments': :'OCI::Devops::Models::BuildRunArgumentCollection', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'build_run_progress': :'OCI::Devops::Models::BuildRunProgress', 'commit_info': :'OCI::Devops::Models::CommitInfo', 'build_outputs': :'OCI::Devops::Models::BuildOutputs', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 |
# File 'lib/oci/devops/models/build_run.rb', line 286 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && compartment_id == other.compartment_id && project_id == other.project_id && build_pipeline_id == other.build_pipeline_id && build_run_source == other.build_run_source && build_run_arguments == other.build_run_arguments && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && build_run_progress == other.build_run_progress && commit_info == other.commit_info && build_outputs == other.build_outputs && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 |
# File 'lib/oci/devops/models/build_run.rb', line 332 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
312 313 314 |
# File 'lib/oci/devops/models/build_run.rb', line 312 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
321 322 323 |
# File 'lib/oci/devops/models/build_run.rb', line 321 def hash [id, display_name, compartment_id, project_id, build_pipeline_id, build_run_source, build_run_arguments, time_created, time_updated, lifecycle_state, lifecycle_details, build_run_progress, commit_info, build_outputs, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
365 366 367 368 369 370 371 372 373 374 |
# File 'lib/oci/devops/models/build_run.rb', line 365 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
359 360 361 |
# File 'lib/oci/devops/models/build_run.rb', line 359 def to_s to_hash.to_s end |