Class: OCI::Devops::Models::BuildStageRunProgress

Inherits:
BuildPipelineStageRunProgress show all
Defined in:
lib/oci/devops/models/build_stage_run_progress.rb

Overview

Specifies the run details for Build stage.

Constant Summary collapse

IMAGE_ENUM =
[
  IMAGE_OL7_X86_64_STANDARD_10 = 'OL7_X86_64_STANDARD_10'.freeze,
  IMAGE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Constants inherited from BuildPipelineStageRunProgress

OCI::Devops::Models::BuildPipelineStageRunProgress::STATUS_ENUM

Instance Attribute Summary collapse

Attributes inherited from BuildPipelineStageRunProgress

#build_pipeline_stage_id, #build_pipeline_stage_predecessors, #build_pipeline_stage_type, #stage_display_name, #status, #time_finished, #time_started

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BuildPipelineStageRunProgress

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ BuildStageRunProgress

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/oci/devops/models/build_stage_run_progress.rb', line 120

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['buildPipelineStageType'] = 'BUILD'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.actual_build_runner_shape = attributes[:'actualBuildRunnerShape'] if attributes[:'actualBuildRunnerShape']

  raise 'You cannot provide both :actualBuildRunnerShape and :actual_build_runner_shape' if attributes.key?(:'actualBuildRunnerShape') && attributes.key?(:'actual_build_runner_shape')

  self.actual_build_runner_shape = attributes[:'actual_build_runner_shape'] if attributes[:'actual_build_runner_shape']

  self.actual_build_runner_shape_config = attributes[:'actualBuildRunnerShapeConfig'] if attributes[:'actualBuildRunnerShapeConfig']

  raise 'You cannot provide both :actualBuildRunnerShapeConfig and :actual_build_runner_shape_config' if attributes.key?(:'actualBuildRunnerShapeConfig') && attributes.key?(:'actual_build_runner_shape_config')

  self.actual_build_runner_shape_config = attributes[:'actual_build_runner_shape_config'] if attributes[:'actual_build_runner_shape_config']

  self.image = attributes[:'image'] if attributes[:'image']

  self.build_spec_file = attributes[:'buildSpecFile'] if attributes[:'buildSpecFile']

  raise 'You cannot provide both :buildSpecFile and :build_spec_file' if attributes.key?(:'buildSpecFile') && attributes.key?(:'build_spec_file')

  self.build_spec_file = attributes[:'build_spec_file'] if attributes[:'build_spec_file']

  self.stage_execution_timeout_in_seconds = attributes[:'stageExecutionTimeoutInSeconds'] if attributes[:'stageExecutionTimeoutInSeconds']

  raise 'You cannot provide both :stageExecutionTimeoutInSeconds and :stage_execution_timeout_in_seconds' if attributes.key?(:'stageExecutionTimeoutInSeconds') && attributes.key?(:'stage_execution_timeout_in_seconds')

  self.stage_execution_timeout_in_seconds = attributes[:'stage_execution_timeout_in_seconds'] if attributes[:'stage_execution_timeout_in_seconds']

  self.build_source_collection = attributes[:'buildSourceCollection'] if attributes[:'buildSourceCollection']

  raise 'You cannot provide both :buildSourceCollection and :build_source_collection' if attributes.key?(:'buildSourceCollection') && attributes.key?(:'build_source_collection')

  self.build_source_collection = attributes[:'build_source_collection'] if attributes[:'build_source_collection']

  self.primary_build_source = attributes[:'primaryBuildSource'] if attributes[:'primaryBuildSource']

  raise 'You cannot provide both :primaryBuildSource and :primary_build_source' if attributes.key?(:'primaryBuildSource') && attributes.key?(:'primary_build_source')

  self.primary_build_source = attributes[:'primary_build_source'] if attributes[:'primary_build_source']

  self.steps = attributes[:'steps'] if attributes[:'steps']

  self.exported_variables = attributes[:'exportedVariables'] if attributes[:'exportedVariables']

  raise 'You cannot provide both :exportedVariables and :exported_variables' if attributes.key?(:'exportedVariables') && attributes.key?(:'exported_variables')

  self.exported_variables = attributes[:'exported_variables'] if attributes[:'exported_variables']
end

Instance Attribute Details

#actual_build_runner_shapeString

Name of Build Runner shape where this Build Stage is running.

Returns:

  • (String)


19
20
21
# File 'lib/oci/devops/models/build_stage_run_progress.rb', line 19

def actual_build_runner_shape
  @actual_build_runner_shape
end

#actual_build_runner_shape_configOCI::Devops::Models::ActualBuildRunnerShapeConfig



22
23
24
# File 'lib/oci/devops/models/build_stage_run_progress.rb', line 22

def actual_build_runner_shape_config
  @actual_build_runner_shape_config
end

#build_source_collectionOCI::Devops::Models::BuildSourceCollection

This attribute is required.



38
39
40
# File 'lib/oci/devops/models/build_stage_run_progress.rb', line 38

def build_source_collection
  @build_source_collection
end

#build_spec_fileString

The path to the build specification file for this Environment. The default location if not specified is build_spec.yaml

Returns:

  • (String)


30
31
32
# File 'lib/oci/devops/models/build_stage_run_progress.rb', line 30

def build_spec_file
  @build_spec_file
end

#exported_variablesOCI::Devops::Models::ExportedVariableCollection



49
50
51
# File 'lib/oci/devops/models/build_stage_run_progress.rb', line 49

def exported_variables
  @exported_variables
end

#imageString

[Required] Image name for the Build Environment

Returns:

  • (String)


26
27
28
# File 'lib/oci/devops/models/build_stage_run_progress.rb', line 26

def image
  @image
end

#primary_build_sourceString

Name of the BuildSource in which the build_spec.yml file need to be located. If not specified, the 1st entry in the BuildSource collection will be chosen as Primary.

Returns:

  • (String)


42
43
44
# File 'lib/oci/devops/models/build_stage_run_progress.rb', line 42

def primary_build_source
  @primary_build_source
end

#stage_execution_timeout_in_secondsInteger

Timeout for the Build Stage Execution. Value in seconds.

Returns:

  • (Integer)


34
35
36
# File 'lib/oci/devops/models/build_stage_run_progress.rb', line 34

def stage_execution_timeout_in_seconds
  @stage_execution_timeout_in_seconds
end

#stepsArray<OCI::Devops::Models::BuildStageRunStep>

The details about all the steps in a Build stage



46
47
48
# File 'lib/oci/devops/models/build_stage_run_progress.rb', line 46

def steps
  @steps
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/oci/devops/models/build_stage_run_progress.rb', line 52

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'stage_display_name': :'stageDisplayName',
    'build_pipeline_stage_type': :'buildPipelineStageType',
    'build_pipeline_stage_id': :'buildPipelineStageId',
    'time_started': :'timeStarted',
    'time_finished': :'timeFinished',
    'status': :'status',
    'build_pipeline_stage_predecessors': :'buildPipelineStagePredecessors',
    'actual_build_runner_shape': :'actualBuildRunnerShape',
    'actual_build_runner_shape_config': :'actualBuildRunnerShapeConfig',
    'image': :'image',
    'build_spec_file': :'buildSpecFile',
    'stage_execution_timeout_in_seconds': :'stageExecutionTimeoutInSeconds',
    'build_source_collection': :'buildSourceCollection',
    'primary_build_source': :'primaryBuildSource',
    'steps': :'steps',
    'exported_variables': :'exportedVariables'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/oci/devops/models/build_stage_run_progress.rb', line 76

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'stage_display_name': :'String',
    'build_pipeline_stage_type': :'String',
    'build_pipeline_stage_id': :'String',
    'time_started': :'DateTime',
    'time_finished': :'DateTime',
    'status': :'String',
    'build_pipeline_stage_predecessors': :'OCI::Devops::Models::BuildPipelineStagePredecessorCollection',
    'actual_build_runner_shape': :'String',
    'actual_build_runner_shape_config': :'OCI::Devops::Models::ActualBuildRunnerShapeConfig',
    'image': :'String',
    'build_spec_file': :'String',
    'stage_execution_timeout_in_seconds': :'Integer',
    'build_source_collection': :'OCI::Devops::Models::BuildSourceCollection',
    'primary_build_source': :'String',
    'steps': :'Array<OCI::Devops::Models::BuildStageRunStep>',
    'exported_variables': :'OCI::Devops::Models::ExportedVariableCollection'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/oci/devops/models/build_stage_run_progress.rb', line 197

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    stage_display_name == other.stage_display_name &&
    build_pipeline_stage_type == other.build_pipeline_stage_type &&
    build_pipeline_stage_id == other.build_pipeline_stage_id &&
    time_started == other.time_started &&
    time_finished == other.time_finished &&
    status == other.status &&
    build_pipeline_stage_predecessors == other.build_pipeline_stage_predecessors &&
    actual_build_runner_shape == other.actual_build_runner_shape &&
    actual_build_runner_shape_config == other.actual_build_runner_shape_config &&
    image == other.image &&
    build_spec_file == other.build_spec_file &&
    stage_execution_timeout_in_seconds == other.stage_execution_timeout_in_seconds &&
    build_source_collection == other.build_source_collection &&
    primary_build_source == other.primary_build_source &&
    steps == other.steps &&
    exported_variables == other.exported_variables
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/oci/devops/models/build_stage_run_progress.rb', line 242

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


222
223
224
# File 'lib/oci/devops/models/build_stage_run_progress.rb', line 222

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



231
232
233
# File 'lib/oci/devops/models/build_stage_run_progress.rb', line 231

def hash
  [stage_display_name, build_pipeline_stage_type, build_pipeline_stage_id, time_started, time_finished, status, build_pipeline_stage_predecessors, actual_build_runner_shape, actual_build_runner_shape_config, image, build_spec_file, stage_execution_timeout_in_seconds, build_source_collection, primary_build_source, steps, exported_variables].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



275
276
277
278
279
280
281
282
283
284
# File 'lib/oci/devops/models/build_stage_run_progress.rb', line 275

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



269
270
271
# File 'lib/oci/devops/models/build_stage_run_progress.rb', line 269

def to_s
  to_hash.to_s
end