Class: OCI::Devops::Models::BuildStageSummary

Inherits:
BuildPipelineStageSummary show all
Defined in:
lib/oci/devops/models/build_stage_summary.rb

Overview

Specifies the build stage.

Instance Attribute Summary collapse

Attributes inherited from BuildPipelineStageSummary

#build_pipeline_id, #build_pipeline_stage_predecessor_collection, #build_pipeline_stage_type, #compartment_id, #defined_tags, #description, #display_name, #freeform_tags, #id, #lifecycle_details, #lifecycle_state, #project_id, #system_tags, #time_created, #time_updated

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BuildPipelineStageSummary

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ BuildStageSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/oci/devops/models/build_stage_summary.rb', line 111

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['buildPipelineStageType'] = 'BUILD'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.image = attributes[:'image'] if attributes[:'image']

  self.build_spec_file = attributes[:'buildSpecFile'] if attributes[:'buildSpecFile']

  raise 'You cannot provide both :buildSpecFile and :build_spec_file' if attributes.key?(:'buildSpecFile') && attributes.key?(:'build_spec_file')

  self.build_spec_file = attributes[:'build_spec_file'] if attributes[:'build_spec_file']

  self.stage_execution_timeout_in_seconds = attributes[:'stageExecutionTimeoutInSeconds'] if attributes[:'stageExecutionTimeoutInSeconds']

  raise 'You cannot provide both :stageExecutionTimeoutInSeconds and :stage_execution_timeout_in_seconds' if attributes.key?(:'stageExecutionTimeoutInSeconds') && attributes.key?(:'stage_execution_timeout_in_seconds')

  self.stage_execution_timeout_in_seconds = attributes[:'stage_execution_timeout_in_seconds'] if attributes[:'stage_execution_timeout_in_seconds']

  self.build_source_collection = attributes[:'buildSourceCollection'] if attributes[:'buildSourceCollection']

  raise 'You cannot provide both :buildSourceCollection and :build_source_collection' if attributes.key?(:'buildSourceCollection') && attributes.key?(:'build_source_collection')

  self.build_source_collection = attributes[:'build_source_collection'] if attributes[:'build_source_collection']

  self.primary_build_source = attributes[:'primaryBuildSource'] if attributes[:'primaryBuildSource']

  raise 'You cannot provide both :primaryBuildSource and :primary_build_source' if attributes.key?(:'primaryBuildSource') && attributes.key?(:'primary_build_source')

  self.primary_build_source = attributes[:'primary_build_source'] if attributes[:'primary_build_source']
end

Instance Attribute Details

#build_source_collectionOCI::Devops::Models::BuildSourceCollection



24
25
26
# File 'lib/oci/devops/models/build_stage_summary.rb', line 24

def build_source_collection
  @build_source_collection
end

#build_spec_fileString

The path to the build specification file for this environment. The default location of the file if not specified is build_spec.yaml.

Returns:

  • (String)


17
18
19
# File 'lib/oci/devops/models/build_stage_summary.rb', line 17

def build_spec_file
  @build_spec_file
end

#imageString

[Required] Image for the build environment.

Returns:

  • (String)


13
14
15
# File 'lib/oci/devops/models/build_stage_summary.rb', line 13

def image
  @image
end

#primary_build_sourceString

Name of the build source where the build_spec.yml file is located. If not specified, the first entry in the build source collection is chosen as primary build source.

Returns:

  • (String)


28
29
30
# File 'lib/oci/devops/models/build_stage_summary.rb', line 28

def primary_build_source
  @primary_build_source
end

#stage_execution_timeout_in_secondsInteger

Timeout for the build stage execution. Specify value in seconds.

Returns:

  • (Integer)


21
22
23
# File 'lib/oci/devops/models/build_stage_summary.rb', line 21

def stage_execution_timeout_in_seconds
  @stage_execution_timeout_in_seconds
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
# File 'lib/oci/devops/models/build_stage_summary.rb', line 31

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'display_name': :'displayName',
    'project_id': :'projectId',
    'build_pipeline_id': :'buildPipelineId',
    'compartment_id': :'compartmentId',
    'build_pipeline_stage_type': :'buildPipelineStageType',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'description': :'description',
    'build_pipeline_stage_predecessor_collection': :'buildPipelineStagePredecessorCollection',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags',
    'image': :'image',
    'build_spec_file': :'buildSpecFile',
    'stage_execution_timeout_in_seconds': :'stageExecutionTimeoutInSeconds',
    'build_source_collection': :'buildSourceCollection',
    'primary_build_source': :'primaryBuildSource'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/oci/devops/models/build_stage_summary.rb', line 59

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'display_name': :'String',
    'project_id': :'String',
    'build_pipeline_id': :'String',
    'compartment_id': :'String',
    'build_pipeline_stage_type': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'description': :'String',
    'build_pipeline_stage_predecessor_collection': :'OCI::Devops::Models::BuildPipelineStagePredecessorCollection',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>',
    'image': :'String',
    'build_spec_file': :'String',
    'stage_execution_timeout_in_seconds': :'Integer',
    'build_source_collection': :'OCI::Devops::Models::BuildSourceCollection',
    'primary_build_source': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/oci/devops/models/build_stage_summary.rb', line 155

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    display_name == other.display_name &&
    project_id == other.project_id &&
    build_pipeline_id == other.build_pipeline_id &&
    compartment_id == other.compartment_id &&
    build_pipeline_stage_type == other.build_pipeline_stage_type &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    description == other.description &&
    build_pipeline_stage_predecessor_collection == other.build_pipeline_stage_predecessor_collection &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags &&
    image == other.image &&
    build_spec_file == other.build_spec_file &&
    stage_execution_timeout_in_seconds == other.stage_execution_timeout_in_seconds &&
    build_source_collection == other.build_source_collection &&
    primary_build_source == other.primary_build_source
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/oci/devops/models/build_stage_summary.rb', line 204

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


184
185
186
# File 'lib/oci/devops/models/build_stage_summary.rb', line 184

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



193
194
195
# File 'lib/oci/devops/models/build_stage_summary.rb', line 193

def hash
  [id, display_name, project_id, build_pipeline_id, compartment_id, build_pipeline_stage_type, time_created, time_updated, lifecycle_state, lifecycle_details, description, build_pipeline_stage_predecessor_collection, freeform_tags, defined_tags, system_tags, image, build_spec_file, stage_execution_timeout_in_seconds, build_source_collection, primary_build_source].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



237
238
239
240
241
242
243
244
245
246
# File 'lib/oci/devops/models/build_stage_summary.rb', line 237

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



231
232
233
# File 'lib/oci/devops/models/build_stage_summary.rb', line 231

def to_s
  to_hash.to_s
end