Class: OCI::Devops::Models::CommitInfo
- Inherits:
-
Object
- Object
- OCI::Devops::Models::CommitInfo
- Defined in:
- lib/oci/devops/models/commit_info.rb
Overview
Commit details that need to be used for the build run.
Instance Attribute Summary collapse
-
#commit_hash ⇒ String
[Required] Commit hash pertinent to the repository URL and the specified branch.
-
#repository_branch ⇒ String
[Required] Name of the repository branch.
-
#repository_url ⇒ String
[Required] Repository URL.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CommitInfo
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CommitInfo
Initializes the object
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/oci/devops/models/commit_info.rb', line 53 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.repository_url = attributes[:'repositoryUrl'] if attributes[:'repositoryUrl'] raise 'You cannot provide both :repositoryUrl and :repository_url' if attributes.key?(:'repositoryUrl') && attributes.key?(:'repository_url') self.repository_url = attributes[:'repository_url'] if attributes[:'repository_url'] self.repository_branch = attributes[:'repositoryBranch'] if attributes[:'repositoryBranch'] raise 'You cannot provide both :repositoryBranch and :repository_branch' if attributes.key?(:'repositoryBranch') && attributes.key?(:'repository_branch') self.repository_branch = attributes[:'repository_branch'] if attributes[:'repository_branch'] self.commit_hash = attributes[:'commitHash'] if attributes[:'commitHash'] raise 'You cannot provide both :commitHash and :commit_hash' if attributes.key?(:'commitHash') && attributes.key?(:'commit_hash') self.commit_hash = attributes[:'commit_hash'] if attributes[:'commit_hash'] end |
Instance Attribute Details
#commit_hash ⇒ String
[Required] Commit hash pertinent to the repository URL and the specified branch.
20 21 22 |
# File 'lib/oci/devops/models/commit_info.rb', line 20 def commit_hash @commit_hash end |
#repository_branch ⇒ String
[Required] Name of the repository branch.
16 17 18 |
# File 'lib/oci/devops/models/commit_info.rb', line 16 def repository_branch @repository_branch end |
#repository_url ⇒ String
[Required] Repository URL.
12 13 14 |
# File 'lib/oci/devops/models/commit_info.rb', line 12 def repository_url @repository_url end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
23 24 25 26 27 28 29 30 31 |
# File 'lib/oci/devops/models/commit_info.rb', line 23 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'repository_url': :'repositoryUrl', 'repository_branch': :'repositoryBranch', 'commit_hash': :'commitHash' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
34 35 36 37 38 39 40 41 42 |
# File 'lib/oci/devops/models/commit_info.rb', line 34 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'repository_url': :'String', 'repository_branch': :'String', 'commit_hash': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
85 86 87 88 89 90 91 92 |
# File 'lib/oci/devops/models/commit_info.rb', line 85 def ==(other) return true if equal?(other) self.class == other.class && repository_url == other.repository_url && repository_branch == other.repository_branch && commit_hash == other.commit_hash end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/oci/devops/models/commit_info.rb', line 117 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
97 98 99 |
# File 'lib/oci/devops/models/commit_info.rb', line 97 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
106 107 108 |
# File 'lib/oci/devops/models/commit_info.rb', line 106 def hash [repository_url, repository_branch, commit_hash].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
150 151 152 153 154 155 156 157 158 159 |
# File 'lib/oci/devops/models/commit_info.rb', line 150 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
144 145 146 |
# File 'lib/oci/devops/models/commit_info.rb', line 144 def to_s to_hash.to_s end |