Class: OCI::Devops::Models::ComputeInstanceGroupDeployEnvironment
- Inherits:
-
DeployEnvironment
- Object
- DeployEnvironment
- OCI::Devops::Models::ComputeInstanceGroupDeployEnvironment
- Defined in:
- lib/oci/devops/models/compute_instance_group_deploy_environment.rb
Overview
Specifies the Compute instance group environment. The instances in the group is the combined results of each selectors in the instance group selectors.
Constant Summary
Constants inherited from DeployEnvironment
DeployEnvironment::DEPLOY_ENVIRONMENT_TYPE_ENUM, DeployEnvironment::LIFECYCLE_STATE_ENUM
Instance Attribute Summary collapse
-
#compute_instance_group_selectors ⇒ OCI::Devops::Models::ComputeInstanceGroupSelectorCollection
This attribute is required.
Attributes inherited from DeployEnvironment
#compartment_id, #defined_tags, #deploy_environment_type, #description, #display_name, #freeform_tags, #id, #lifecycle_details, #lifecycle_state, #project_id, #system_tags, #time_created, #time_updated
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ComputeInstanceGroupDeployEnvironment
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from DeployEnvironment
Constructor Details
#initialize(attributes = {}) ⇒ ComputeInstanceGroupDeployEnvironment
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/oci/devops/models/compute_instance_group_deploy_environment.rb', line 78 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['deployEnvironmentType'] = 'COMPUTE_INSTANCE_GROUP' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compute_instance_group_selectors = attributes[:'computeInstanceGroupSelectors'] if attributes[:'computeInstanceGroupSelectors'] raise 'You cannot provide both :computeInstanceGroupSelectors and :compute_instance_group_selectors' if attributes.key?(:'computeInstanceGroupSelectors') && attributes.key?(:'compute_instance_group_selectors') self.compute_instance_group_selectors = attributes[:'compute_instance_group_selectors'] if attributes[:'compute_instance_group_selectors'] end |
Instance Attribute Details
#compute_instance_group_selectors ⇒ OCI::Devops::Models::ComputeInstanceGroupSelectorCollection
This attribute is required.
13 14 15 |
# File 'lib/oci/devops/models/compute_instance_group_deploy_environment.rb', line 13 def compute_instance_group_selectors @compute_instance_group_selectors end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 |
# File 'lib/oci/devops/models/compute_instance_group_deploy_environment.rb', line 16 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'description': :'description', 'display_name': :'displayName', 'project_id': :'projectId', 'compartment_id': :'compartmentId', 'deploy_environment_type': :'deployEnvironmentType', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags', 'compute_instance_group_selectors': :'computeInstanceGroupSelectors' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/oci/devops/models/compute_instance_group_deploy_environment.rb', line 38 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'description': :'String', 'display_name': :'String', 'project_id': :'String', 'compartment_id': :'String', 'deploy_environment_type': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>', 'compute_instance_group_selectors': :'OCI::Devops::Models::ComputeInstanceGroupSelectorCollection' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/oci/devops/models/compute_instance_group_deploy_environment.rb', line 102 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && description == other.description && display_name == other.display_name && project_id == other.project_id && compartment_id == other.compartment_id && deploy_environment_type == other.deploy_environment_type && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && == other. && == other. && == other. && compute_instance_group_selectors == other.compute_instance_group_selectors end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/oci/devops/models/compute_instance_group_deploy_environment.rb', line 145 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
125 126 127 |
# File 'lib/oci/devops/models/compute_instance_group_deploy_environment.rb', line 125 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
134 135 136 |
# File 'lib/oci/devops/models/compute_instance_group_deploy_environment.rb', line 134 def hash [id, description, display_name, project_id, compartment_id, deploy_environment_type, time_created, time_updated, lifecycle_state, lifecycle_details, , , , compute_instance_group_selectors].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
178 179 180 181 182 183 184 185 186 187 |
# File 'lib/oci/devops/models/compute_instance_group_deploy_environment.rb', line 178 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
172 173 174 |
# File 'lib/oci/devops/models/compute_instance_group_deploy_environment.rb', line 172 def to_s to_hash.to_s end |