Class: OCI::Devops::Models::ComputeInstanceGroupDeployStage

Inherits:
DeployStage
  • Object
show all
Defined in:
lib/oci/devops/models/compute_instance_group_deploy_stage.rb

Overview

Specifies the instance group rolling deployment stage.

Constant Summary

Constants inherited from DeployStage

DeployStage::DEPLOY_STAGE_TYPE_ENUM, DeployStage::LIFECYCLE_STATE_ENUM

Instance Attribute Summary collapse

Attributes inherited from DeployStage

#compartment_id, #defined_tags, #deploy_pipeline_id, #deploy_stage_predecessor_collection, #deploy_stage_type, #description, #display_name, #freeform_tags, #id, #lifecycle_details, #lifecycle_state, #project_id, #system_tags, #time_created, #time_updated

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from DeployStage

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ ComputeInstanceGroupDeployStage

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/oci/devops/models/compute_instance_group_deploy_stage.rb', line 123

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['deployStageType'] = 'COMPUTE_INSTANCE_GROUP_ROLLING_DEPLOYMENT'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.compute_instance_group_deploy_environment_id = attributes[:'computeInstanceGroupDeployEnvironmentId'] if attributes[:'computeInstanceGroupDeployEnvironmentId']

  raise 'You cannot provide both :computeInstanceGroupDeployEnvironmentId and :compute_instance_group_deploy_environment_id' if attributes.key?(:'computeInstanceGroupDeployEnvironmentId') && attributes.key?(:'compute_instance_group_deploy_environment_id')

  self.compute_instance_group_deploy_environment_id = attributes[:'compute_instance_group_deploy_environment_id'] if attributes[:'compute_instance_group_deploy_environment_id']

  self.deployment_spec_deploy_artifact_id = attributes[:'deploymentSpecDeployArtifactId'] if attributes[:'deploymentSpecDeployArtifactId']

  raise 'You cannot provide both :deploymentSpecDeployArtifactId and :deployment_spec_deploy_artifact_id' if attributes.key?(:'deploymentSpecDeployArtifactId') && attributes.key?(:'deployment_spec_deploy_artifact_id')

  self.deployment_spec_deploy_artifact_id = attributes[:'deployment_spec_deploy_artifact_id'] if attributes[:'deployment_spec_deploy_artifact_id']

  self.deploy_artifact_ids = attributes[:'deployArtifactIds'] if attributes[:'deployArtifactIds']

  raise 'You cannot provide both :deployArtifactIds and :deploy_artifact_ids' if attributes.key?(:'deployArtifactIds') && attributes.key?(:'deploy_artifact_ids')

  self.deploy_artifact_ids = attributes[:'deploy_artifact_ids'] if attributes[:'deploy_artifact_ids']

  self.rollout_policy = attributes[:'rolloutPolicy'] if attributes[:'rolloutPolicy']

  raise 'You cannot provide both :rolloutPolicy and :rollout_policy' if attributes.key?(:'rolloutPolicy') && attributes.key?(:'rollout_policy')

  self.rollout_policy = attributes[:'rollout_policy'] if attributes[:'rollout_policy']

  self.rollback_policy = attributes[:'rollbackPolicy'] if attributes[:'rollbackPolicy']

  raise 'You cannot provide both :rollbackPolicy and :rollback_policy' if attributes.key?(:'rollbackPolicy') && attributes.key?(:'rollback_policy')

  self.rollback_policy = attributes[:'rollback_policy'] if attributes[:'rollback_policy']

  self.failure_policy = attributes[:'failurePolicy'] if attributes[:'failurePolicy']

  raise 'You cannot provide both :failurePolicy and :failure_policy' if attributes.key?(:'failurePolicy') && attributes.key?(:'failure_policy')

  self.failure_policy = attributes[:'failure_policy'] if attributes[:'failure_policy']

  self.load_balancer_config = attributes[:'loadBalancerConfig'] if attributes[:'loadBalancerConfig']

  raise 'You cannot provide both :loadBalancerConfig and :load_balancer_config' if attributes.key?(:'loadBalancerConfig') && attributes.key?(:'load_balancer_config')

  self.load_balancer_config = attributes[:'load_balancer_config'] if attributes[:'load_balancer_config']
end

Instance Attribute Details

#compute_instance_group_deploy_environment_idString

[Required] A compute instance group environment OCID for rolling deployment.

Returns:

  • (String)


13
14
15
# File 'lib/oci/devops/models/compute_instance_group_deploy_stage.rb', line 13

def compute_instance_group_deploy_environment_id
  @compute_instance_group_deploy_environment_id
end

#deploy_artifact_idsArray<String>

Additional file artifact OCIDs.

Returns:

  • (Array<String>)


21
22
23
# File 'lib/oci/devops/models/compute_instance_group_deploy_stage.rb', line 21

def deploy_artifact_ids
  @deploy_artifact_ids
end

#deployment_spec_deploy_artifact_idString

[Required] The OCID of the artifact that contains the deployment specification.

Returns:

  • (String)


17
18
19
# File 'lib/oci/devops/models/compute_instance_group_deploy_stage.rb', line 17

def deployment_spec_deploy_artifact_id
  @deployment_spec_deploy_artifact_id
end

#failure_policyOCI::Devops::Models::ComputeInstanceGroupFailurePolicy



31
32
33
# File 'lib/oci/devops/models/compute_instance_group_deploy_stage.rb', line 31

def failure_policy
  @failure_policy
end

#load_balancer_configOCI::Devops::Models::LoadBalancerConfig



34
35
36
# File 'lib/oci/devops/models/compute_instance_group_deploy_stage.rb', line 34

def load_balancer_config
  @load_balancer_config
end

#rollback_policyOCI::Devops::Models::DeployStageRollbackPolicy



28
29
30
# File 'lib/oci/devops/models/compute_instance_group_deploy_stage.rb', line 28

def rollback_policy
  @rollback_policy
end

#rollout_policyOCI::Devops::Models::ComputeInstanceGroupRolloutPolicy

This attribute is required.



25
26
27
# File 'lib/oci/devops/models/compute_instance_group_deploy_stage.rb', line 25

def rollout_policy
  @rollout_policy
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/oci/devops/models/compute_instance_group_deploy_stage.rb', line 37

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'description': :'description',
    'display_name': :'displayName',
    'project_id': :'projectId',
    'deploy_pipeline_id': :'deployPipelineId',
    'compartment_id': :'compartmentId',
    'deploy_stage_type': :'deployStageType',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'deploy_stage_predecessor_collection': :'deployStagePredecessorCollection',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags',
    'compute_instance_group_deploy_environment_id': :'computeInstanceGroupDeployEnvironmentId',
    'deployment_spec_deploy_artifact_id': :'deploymentSpecDeployArtifactId',
    'deploy_artifact_ids': :'deployArtifactIds',
    'rollout_policy': :'rolloutPolicy',
    'rollback_policy': :'rollbackPolicy',
    'failure_policy': :'failurePolicy',
    'load_balancer_config': :'loadBalancerConfig'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/oci/devops/models/compute_instance_group_deploy_stage.rb', line 67

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'description': :'String',
    'display_name': :'String',
    'project_id': :'String',
    'deploy_pipeline_id': :'String',
    'compartment_id': :'String',
    'deploy_stage_type': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'deploy_stage_predecessor_collection': :'OCI::Devops::Models::DeployStagePredecessorCollection',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>',
    'compute_instance_group_deploy_environment_id': :'String',
    'deployment_spec_deploy_artifact_id': :'String',
    'deploy_artifact_ids': :'Array<String>',
    'rollout_policy': :'OCI::Devops::Models::ComputeInstanceGroupRolloutPolicy',
    'rollback_policy': :'OCI::Devops::Models::DeployStageRollbackPolicy',
    'failure_policy': :'OCI::Devops::Models::ComputeInstanceGroupFailurePolicy',
    'load_balancer_config': :'OCI::Devops::Models::LoadBalancerConfig'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/oci/devops/models/compute_instance_group_deploy_stage.rb', line 183

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    description == other.description &&
    display_name == other.display_name &&
    project_id == other.project_id &&
    deploy_pipeline_id == other.deploy_pipeline_id &&
    compartment_id == other.compartment_id &&
    deploy_stage_type == other.deploy_stage_type &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    deploy_stage_predecessor_collection == other.deploy_stage_predecessor_collection &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags &&
    compute_instance_group_deploy_environment_id == other.compute_instance_group_deploy_environment_id &&
    deployment_spec_deploy_artifact_id == other.deployment_spec_deploy_artifact_id &&
    deploy_artifact_ids == other.deploy_artifact_ids &&
    rollout_policy == other.rollout_policy &&
    rollback_policy == other.rollback_policy &&
    failure_policy == other.failure_policy &&
    load_balancer_config == other.load_balancer_config
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/oci/devops/models/compute_instance_group_deploy_stage.rb', line 234

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


214
215
216
# File 'lib/oci/devops/models/compute_instance_group_deploy_stage.rb', line 214

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



223
224
225
# File 'lib/oci/devops/models/compute_instance_group_deploy_stage.rb', line 223

def hash
  [id, description, display_name, project_id, deploy_pipeline_id, compartment_id, deploy_stage_type, time_created, time_updated, lifecycle_state, lifecycle_details, deploy_stage_predecessor_collection, freeform_tags, defined_tags, system_tags, compute_instance_group_deploy_environment_id, deployment_spec_deploy_artifact_id, deploy_artifact_ids, rollout_policy, rollback_policy, failure_policy, load_balancer_config].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



267
268
269
270
271
272
273
274
275
276
# File 'lib/oci/devops/models/compute_instance_group_deploy_stage.rb', line 267

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



261
262
263
# File 'lib/oci/devops/models/compute_instance_group_deploy_stage.rb', line 261

def to_s
  to_hash.to_s
end