Class: OCI::Devops::Models::ConnectionSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/devops/models/connection_summary.rb

Overview

Summary information for a connection. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ConnectionSummary

Initializes the object

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :display_name (String)

    The value to assign to the #display_name property

  • :description (String)

    The value to assign to the #description property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :project_id (String)

    The value to assign to the #project_id property

  • :connection_type (String)

    The value to assign to the #connection_type property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :time_updated (DateTime)

    The value to assign to the #time_updated property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property

  • :system_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #system_tags property



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/oci/devops/models/connection_summary.rb', line 135

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.project_id = attributes[:'projectId'] if attributes[:'projectId']

  raise 'You cannot provide both :projectId and :project_id' if attributes.key?(:'projectId') && attributes.key?(:'project_id')

  self.project_id = attributes[:'project_id'] if attributes[:'project_id']

  self.connection_type = attributes[:'connectionType'] if attributes[:'connectionType']

  raise 'You cannot provide both :connectionType and :connection_type' if attributes.key?(:'connectionType') && attributes.key?(:'connection_type')

  self.connection_type = attributes[:'connection_type'] if attributes[:'connection_type']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

  raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

  self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']
end

Instance Attribute Details

#compartment_idString

[Required] The OCID of the compartment containing the connection.



26
27
28
# File 'lib/oci/devops/models/connection_summary.rb', line 26

def compartment_id
  @compartment_id
end

#connection_typeString

[Required] The type of connection.



34
35
36
# File 'lib/oci/devops/models/connection_summary.rb', line 34

def connection_type
  @connection_type
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"bar-key": "value"}`



55
56
57
# File 'lib/oci/devops/models/connection_summary.rb', line 55

def defined_tags
  @defined_tags
end

#descriptionString

Optional description about the connection.



22
23
24
# File 'lib/oci/devops/models/connection_summary.rb', line 22

def description
  @description
end

#display_nameString

Connection display name, which can be renamed and is not necessarily unique. Avoid entering confidential information.



18
19
20
# File 'lib/oci/devops/models/connection_summary.rb', line 18

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"value"`



51
52
53
# File 'lib/oci/devops/models/connection_summary.rb', line 51

def freeform_tags
  @freeform_tags
end

#idString

[Required] Unique identifier that is immutable on creation.



14
15
16
# File 'lib/oci/devops/models/connection_summary.rb', line 14

def id
  @id
end

#lifecycle_stateString

The current state of the connection.



47
48
49
# File 'lib/oci/devops/models/connection_summary.rb', line 47

def lifecycle_state
  @lifecycle_state
end

#project_idString

[Required] The OCID of the DevOps project.



30
31
32
# File 'lib/oci/devops/models/connection_summary.rb', line 30

def project_id
  @project_id
end

#system_tagsHash<String, Hash<String, Object>>

Usage of system tag keys. These predefined keys are scoped to namespaces. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"free-tier-retained": "true"}`



59
60
61
# File 'lib/oci/devops/models/connection_summary.rb', line 59

def system_tags
  @system_tags
end

#time_createdDateTime

The time the connection was created. Format defined by [RFC3339](datatracker.ietf.org/doc/html/rfc3339).



38
39
40
# File 'lib/oci/devops/models/connection_summary.rb', line 38

def time_created
  @time_created
end

#time_updatedDateTime

The time the connection was updated. Format defined by [RFC3339](datatracker.ietf.org/doc/html/rfc3339).



42
43
44
# File 'lib/oci/devops/models/connection_summary.rb', line 42

def time_updated
  @time_updated
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/oci/devops/models/connection_summary.rb', line 62

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'display_name': :'displayName',
    'description': :'description',
    'compartment_id': :'compartmentId',
    'project_id': :'projectId',
    'connection_type': :'connectionType',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'lifecycle_state': :'lifecycleState',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.get_subtype(object_hash) ⇒ Object

Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.



106
107
108
109
110
111
112
113
114
# File 'lib/oci/devops/models/connection_summary.rb', line 106

def self.get_subtype(object_hash)
  type = object_hash[:'connectionType'] # rubocop:disable Style/SymbolLiteral

  return 'OCI::Devops::Models::GithubAccessTokenConnectionSummary' if type == 'GITHUB_ACCESS_TOKEN'
  return 'OCI::Devops::Models::GitlabAccessTokenConnectionSummary' if type == 'GITLAB_ACCESS_TOKEN'

  # TODO: Log a warning when the subtype is not found.
  'OCI::Devops::Models::ConnectionSummary'
end

.swagger_typesObject

Attribute type mapping.



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/oci/devops/models/connection_summary.rb', line 82

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'display_name': :'String',
    'description': :'String',
    'compartment_id': :'String',
    'project_id': :'String',
    'connection_type': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'lifecycle_state': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/oci/devops/models/connection_summary.rb', line 213

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    display_name == other.display_name &&
    description == other.description &&
    compartment_id == other.compartment_id &&
    project_id == other.project_id &&
    connection_type == other.connection_type &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    lifecycle_state == other.lifecycle_state &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/oci/devops/models/connection_summary.rb', line 254

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method


234
235
236
# File 'lib/oci/devops/models/connection_summary.rb', line 234

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.



243
244
245
# File 'lib/oci/devops/models/connection_summary.rb', line 243

def hash
  [id, display_name, description, compartment_id, project_id, connection_type, time_created, time_updated, lifecycle_state, freeform_tags, defined_tags, system_tags].hash
end

#to_hashHash

Returns the object in the form of hash



287
288
289
290
291
292
293
294
295
296
# File 'lib/oci/devops/models/connection_summary.rb', line 287

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



281
282
283
# File 'lib/oci/devops/models/connection_summary.rb', line 281

def to_s
  to_hash.to_s
end