Class: OCI::Devops::Models::CreateBuildPipelineStageDetails
- Inherits:
-
Object
- Object
- OCI::Devops::Models::CreateBuildPipelineStageDetails
- Defined in:
- lib/oci/devops/models/create_build_pipeline_stage_details.rb
Overview
The information about a new stage. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
CreateBuildStageDetails, CreateDeliverArtifactStageDetails, CreateTriggerDeploymentStageDetails, CreateWaitStageDetails
Instance Attribute Summary collapse
-
#build_pipeline_id ⇒ String
[Required] The OCID of the build pipeline.
-
#build_pipeline_stage_predecessor_collection ⇒ OCI::Devops::Models::BuildPipelineStagePredecessorCollection
This attribute is required.
-
#build_pipeline_stage_type ⇒ String
[Required] Defines the stage type, which is one of the following: Build, Deliver Artifacts, Wait, and Trigger Deployment.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
Optional description about the stage.
-
#display_name ⇒ String
Stage display name, which can be renamed and is not necessarily unique.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateBuildPipelineStageDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateBuildPipelineStageDetails
Initializes the object
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/oci/devops/models/create_build_pipeline_stage_details.rb', line 101 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.build_pipeline_stage_type = attributes[:'buildPipelineStageType'] if attributes[:'buildPipelineStageType'] raise 'You cannot provide both :buildPipelineStageType and :build_pipeline_stage_type' if attributes.key?(:'buildPipelineStageType') && attributes.key?(:'build_pipeline_stage_type') self.build_pipeline_stage_type = attributes[:'build_pipeline_stage_type'] if attributes[:'build_pipeline_stage_type'] self.build_pipeline_id = attributes[:'buildPipelineId'] if attributes[:'buildPipelineId'] raise 'You cannot provide both :buildPipelineId and :build_pipeline_id' if attributes.key?(:'buildPipelineId') && attributes.key?(:'build_pipeline_id') self.build_pipeline_id = attributes[:'build_pipeline_id'] if attributes[:'build_pipeline_id'] self.build_pipeline_stage_predecessor_collection = attributes[:'buildPipelineStagePredecessorCollection'] if attributes[:'buildPipelineStagePredecessorCollection'] raise 'You cannot provide both :buildPipelineStagePredecessorCollection and :build_pipeline_stage_predecessor_collection' if attributes.key?(:'buildPipelineStagePredecessorCollection') && attributes.key?(:'build_pipeline_stage_predecessor_collection') self.build_pipeline_stage_predecessor_collection = attributes[:'build_pipeline_stage_predecessor_collection'] if attributes[:'build_pipeline_stage_predecessor_collection'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#build_pipeline_id ⇒ String
[Required] The OCID of the build pipeline.
26 27 28 |
# File 'lib/oci/devops/models/create_build_pipeline_stage_details.rb', line 26 def build_pipeline_id @build_pipeline_id end |
#build_pipeline_stage_predecessor_collection ⇒ OCI::Devops::Models::BuildPipelineStagePredecessorCollection
This attribute is required.
30 31 32 |
# File 'lib/oci/devops/models/create_build_pipeline_stage_details.rb', line 30 def build_pipeline_stage_predecessor_collection @build_pipeline_stage_predecessor_collection end |
#build_pipeline_stage_type ⇒ String
[Required] Defines the stage type, which is one of the following: Build, Deliver Artifacts, Wait, and Trigger Deployment.
22 23 24 |
# File 'lib/oci/devops/models/create_build_pipeline_stage_details.rb', line 22 def build_pipeline_stage_type @build_pipeline_stage_type end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"bar-key": "value"}`
38 39 40 |
# File 'lib/oci/devops/models/create_build_pipeline_stage_details.rb', line 38 def end |
#description ⇒ String
Optional description about the stage.
17 18 19 |
# File 'lib/oci/devops/models/create_build_pipeline_stage_details.rb', line 17 def description @description end |
#display_name ⇒ String
Stage display name, which can be renamed and is not necessarily unique. Avoid entering confidential information.
13 14 15 |
# File 'lib/oci/devops/models/create_build_pipeline_stage_details.rb', line 13 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"value"`
34 35 36 |
# File 'lib/oci/devops/models/create_build_pipeline_stage_details.rb', line 34 def end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/oci/devops/models/create_build_pipeline_stage_details.rb', line 41 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'description': :'description', 'build_pipeline_stage_type': :'buildPipelineStageType', 'build_pipeline_id': :'buildPipelineId', 'build_pipeline_stage_predecessor_collection': :'buildPipelineStagePredecessorCollection', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/oci/devops/models/create_build_pipeline_stage_details.rb', line 75 def self.get_subtype(object_hash) type = object_hash[:'buildPipelineStageType'] # rubocop:disable Style/SymbolLiteral return 'OCI::Devops::Models::CreateDeliverArtifactStageDetails' if type == 'DELIVER_ARTIFACT' return 'OCI::Devops::Models::CreateTriggerDeploymentStageDetails' if type == 'TRIGGER_DEPLOYMENT_PIPELINE' return 'OCI::Devops::Models::CreateWaitStageDetails' if type == 'WAIT' return 'OCI::Devops::Models::CreateBuildStageDetails' if type == 'BUILD' # TODO: Log a warning when the subtype is not found. 'OCI::Devops::Models::CreateBuildPipelineStageDetails' end |
.swagger_types ⇒ Object
Attribute type mapping.
56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/oci/devops/models/create_build_pipeline_stage_details.rb', line 56 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'description': :'String', 'build_pipeline_stage_type': :'String', 'build_pipeline_id': :'String', 'build_pipeline_stage_predecessor_collection': :'OCI::Devops::Models::BuildPipelineStagePredecessorCollection', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/oci/devops/models/create_build_pipeline_stage_details.rb', line 153 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && description == other.description && build_pipeline_stage_type == other.build_pipeline_stage_type && build_pipeline_id == other.build_pipeline_id && build_pipeline_stage_predecessor_collection == other.build_pipeline_stage_predecessor_collection && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/oci/devops/models/create_build_pipeline_stage_details.rb', line 189 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
169 170 171 |
# File 'lib/oci/devops/models/create_build_pipeline_stage_details.rb', line 169 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
178 179 180 |
# File 'lib/oci/devops/models/create_build_pipeline_stage_details.rb', line 178 def hash [display_name, description, build_pipeline_stage_type, build_pipeline_id, build_pipeline_stage_predecessor_collection, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
222 223 224 225 226 227 228 229 230 231 |
# File 'lib/oci/devops/models/create_build_pipeline_stage_details.rb', line 222 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
216 217 218 |
# File 'lib/oci/devops/models/create_build_pipeline_stage_details.rb', line 216 def to_s to_hash.to_s end |