Class: OCI::Devops::Models::CreateBuildRunDetails
- Inherits:
-
Object
- Object
- OCI::Devops::Models::CreateBuildRunDetails
- Defined in:
- lib/oci/devops/models/create_build_run_details.rb
Overview
Information about the new build run.
Instance Attribute Summary collapse
-
#build_pipeline_id ⇒ String
[Required] The OCID of the build pipeline.
- #build_run_arguments ⇒ OCI::Devops::Models::BuildRunArgumentCollection
- #commit_info ⇒ OCI::Devops::Models::CommitInfo
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
Build run display name, which can be renamed and is not necessarily unique.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateBuildRunDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateBuildRunDetails
Initializes the object
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/oci/devops/models/create_build_run_details.rb', line 72 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.build_pipeline_id = attributes[:'buildPipelineId'] if attributes[:'buildPipelineId'] raise 'You cannot provide both :buildPipelineId and :build_pipeline_id' if attributes.key?(:'buildPipelineId') && attributes.key?(:'build_pipeline_id') self.build_pipeline_id = attributes[:'build_pipeline_id'] if attributes[:'build_pipeline_id'] self.commit_info = attributes[:'commitInfo'] if attributes[:'commitInfo'] raise 'You cannot provide both :commitInfo and :commit_info' if attributes.key?(:'commitInfo') && attributes.key?(:'commit_info') self.commit_info = attributes[:'commit_info'] if attributes[:'commit_info'] self.build_run_arguments = attributes[:'buildRunArguments'] if attributes[:'buildRunArguments'] raise 'You cannot provide both :buildRunArguments and :build_run_arguments' if attributes.key?(:'buildRunArguments') && attributes.key?(:'build_run_arguments') self.build_run_arguments = attributes[:'build_run_arguments'] if attributes[:'build_run_arguments'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#build_pipeline_id ⇒ String
[Required] The OCID of the build pipeline.
16 17 18 |
# File 'lib/oci/devops/models/create_build_run_details.rb', line 16 def build_pipeline_id @build_pipeline_id end |
#build_run_arguments ⇒ OCI::Devops::Models::BuildRunArgumentCollection
22 23 24 |
# File 'lib/oci/devops/models/create_build_run_details.rb', line 22 def build_run_arguments @build_run_arguments end |
#commit_info ⇒ OCI::Devops::Models::CommitInfo
19 20 21 |
# File 'lib/oci/devops/models/create_build_run_details.rb', line 19 def commit_info @commit_info end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"bar-key": "value"}`
30 31 32 |
# File 'lib/oci/devops/models/create_build_run_details.rb', line 30 def end |
#display_name ⇒ String
Build run display name, which can be renamed and is not necessarily unique. Avoid entering confidential information.
12 13 14 |
# File 'lib/oci/devops/models/create_build_run_details.rb', line 12 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"value"`
26 27 28 |
# File 'lib/oci/devops/models/create_build_run_details.rb', line 26 def end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 41 42 43 44 |
# File 'lib/oci/devops/models/create_build_run_details.rb', line 33 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'build_pipeline_id': :'buildPipelineId', 'commit_info': :'commitInfo', 'build_run_arguments': :'buildRunArguments', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/oci/devops/models/create_build_run_details.rb', line 47 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'build_pipeline_id': :'String', 'commit_info': :'OCI::Devops::Models::CommitInfo', 'build_run_arguments': :'OCI::Devops::Models::BuildRunArgumentCollection', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/oci/devops/models/create_build_run_details.rb', line 122 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && build_pipeline_id == other.build_pipeline_id && commit_info == other.commit_info && build_run_arguments == other.build_run_arguments && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/oci/devops/models/create_build_run_details.rb', line 157 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
137 138 139 |
# File 'lib/oci/devops/models/create_build_run_details.rb', line 137 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
146 147 148 |
# File 'lib/oci/devops/models/create_build_run_details.rb', line 146 def hash [display_name, build_pipeline_id, commit_info, build_run_arguments, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
190 191 192 193 194 195 196 197 198 199 |
# File 'lib/oci/devops/models/create_build_run_details.rb', line 190 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
184 185 186 |
# File 'lib/oci/devops/models/create_build_run_details.rb', line 184 def to_s to_hash.to_s end |