Class: OCI::Devops::Models::CreateComputeInstanceGroupCanaryDeployStageDetails
- Inherits:
-
CreateDeployStageDetails
- Object
- CreateDeployStageDetails
- OCI::Devops::Models::CreateComputeInstanceGroupCanaryDeployStageDetails
- Defined in:
- lib/oci/devops/models/create_compute_instance_group_canary_deploy_stage_details.rb
Overview
Specifies the Instance Group Canary deployment stage.
Instance Attribute Summary collapse
-
#compute_instance_group_deploy_environment_id ⇒ String
**[Required]** A compute instance group environment OCID for Canary deployment.
-
#deploy_artifact_ids ⇒ Array<String>
The list of file artifact OCIDs to deploy.
-
#deployment_spec_deploy_artifact_id ⇒ String
**[Required]** The OCID of the artifact that contains the deployment specification.
-
#production_load_balancer_config ⇒ OCI::Devops::Models::LoadBalancerConfig
This attribute is required.
-
#rollout_policy ⇒ OCI::Devops::Models::ComputeInstanceGroupRolloutPolicy
This attribute is required.
- #test_load_balancer_config ⇒ OCI::Devops::Models::LoadBalancerConfig
Attributes inherited from CreateDeployStageDetails
#defined_tags, #deploy_pipeline_id, #deploy_stage_predecessor_collection, #deploy_stage_type, #description, #display_name, #freeform_tags
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateComputeInstanceGroupCanaryDeployStageDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from CreateDeployStageDetails
Constructor Details
#initialize(attributes = {}) ⇒ CreateComputeInstanceGroupCanaryDeployStageDetails
Initializes the object
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/oci/devops/models/create_compute_instance_group_canary_deploy_stage_details.rb', line 94 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['deployStageType'] = 'COMPUTE_INSTANCE_GROUP_CANARY_DEPLOYMENT' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compute_instance_group_deploy_environment_id = attributes[:'computeInstanceGroupDeployEnvironmentId'] if attributes[:'computeInstanceGroupDeployEnvironmentId'] raise 'You cannot provide both :computeInstanceGroupDeployEnvironmentId and :compute_instance_group_deploy_environment_id' if attributes.key?(:'computeInstanceGroupDeployEnvironmentId') && attributes.key?(:'compute_instance_group_deploy_environment_id') self.compute_instance_group_deploy_environment_id = attributes[:'compute_instance_group_deploy_environment_id'] if attributes[:'compute_instance_group_deploy_environment_id'] self.deployment_spec_deploy_artifact_id = attributes[:'deploymentSpecDeployArtifactId'] if attributes[:'deploymentSpecDeployArtifactId'] raise 'You cannot provide both :deploymentSpecDeployArtifactId and :deployment_spec_deploy_artifact_id' if attributes.key?(:'deploymentSpecDeployArtifactId') && attributes.key?(:'deployment_spec_deploy_artifact_id') self.deployment_spec_deploy_artifact_id = attributes[:'deployment_spec_deploy_artifact_id'] if attributes[:'deployment_spec_deploy_artifact_id'] self.deploy_artifact_ids = attributes[:'deployArtifactIds'] if attributes[:'deployArtifactIds'] raise 'You cannot provide both :deployArtifactIds and :deploy_artifact_ids' if attributes.key?(:'deployArtifactIds') && attributes.key?(:'deploy_artifact_ids') self.deploy_artifact_ids = attributes[:'deploy_artifact_ids'] if attributes[:'deploy_artifact_ids'] self.rollout_policy = attributes[:'rolloutPolicy'] if attributes[:'rolloutPolicy'] raise 'You cannot provide both :rolloutPolicy and :rollout_policy' if attributes.key?(:'rolloutPolicy') && attributes.key?(:'rollout_policy') self.rollout_policy = attributes[:'rollout_policy'] if attributes[:'rollout_policy'] self.test_load_balancer_config = attributes[:'testLoadBalancerConfig'] if attributes[:'testLoadBalancerConfig'] raise 'You cannot provide both :testLoadBalancerConfig and :test_load_balancer_config' if attributes.key?(:'testLoadBalancerConfig') && attributes.key?(:'test_load_balancer_config') self.test_load_balancer_config = attributes[:'test_load_balancer_config'] if attributes[:'test_load_balancer_config'] self.production_load_balancer_config = attributes[:'productionLoadBalancerConfig'] if attributes[:'productionLoadBalancerConfig'] raise 'You cannot provide both :productionLoadBalancerConfig and :production_load_balancer_config' if attributes.key?(:'productionLoadBalancerConfig') && attributes.key?(:'production_load_balancer_config') self.production_load_balancer_config = attributes[:'production_load_balancer_config'] if attributes[:'production_load_balancer_config'] end |
Instance Attribute Details
#compute_instance_group_deploy_environment_id ⇒ String
**[Required]** A compute instance group environment OCID for Canary deployment.
13 14 15 |
# File 'lib/oci/devops/models/create_compute_instance_group_canary_deploy_stage_details.rb', line 13 def compute_instance_group_deploy_environment_id @compute_instance_group_deploy_environment_id end |
#deploy_artifact_ids ⇒ Array<String>
The list of file artifact OCIDs to deploy.
21 22 23 |
# File 'lib/oci/devops/models/create_compute_instance_group_canary_deploy_stage_details.rb', line 21 def deploy_artifact_ids @deploy_artifact_ids end |
#deployment_spec_deploy_artifact_id ⇒ String
**[Required]** The OCID of the artifact that contains the deployment specification.
17 18 19 |
# File 'lib/oci/devops/models/create_compute_instance_group_canary_deploy_stage_details.rb', line 17 def deployment_spec_deploy_artifact_id @deployment_spec_deploy_artifact_id end |
#production_load_balancer_config ⇒ OCI::Devops::Models::LoadBalancerConfig
This attribute is required.
32 33 34 |
# File 'lib/oci/devops/models/create_compute_instance_group_canary_deploy_stage_details.rb', line 32 def production_load_balancer_config @production_load_balancer_config end |
#rollout_policy ⇒ OCI::Devops::Models::ComputeInstanceGroupRolloutPolicy
This attribute is required.
25 26 27 |
# File 'lib/oci/devops/models/create_compute_instance_group_canary_deploy_stage_details.rb', line 25 def rollout_policy @rollout_policy end |
#test_load_balancer_config ⇒ OCI::Devops::Models::LoadBalancerConfig
28 29 30 |
# File 'lib/oci/devops/models/create_compute_instance_group_canary_deploy_stage_details.rb', line 28 def test_load_balancer_config @test_load_balancer_config end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/oci/devops/models/create_compute_instance_group_canary_deploy_stage_details.rb', line 35 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'description': :'description', 'display_name': :'displayName', 'deploy_stage_type': :'deployStageType', 'deploy_pipeline_id': :'deployPipelineId', 'deploy_stage_predecessor_collection': :'deployStagePredecessorCollection', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'compute_instance_group_deploy_environment_id': :'computeInstanceGroupDeployEnvironmentId', 'deployment_spec_deploy_artifact_id': :'deploymentSpecDeployArtifactId', 'deploy_artifact_ids': :'deployArtifactIds', 'rollout_policy': :'rolloutPolicy', 'test_load_balancer_config': :'testLoadBalancerConfig', 'production_load_balancer_config': :'productionLoadBalancerConfig' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/oci/devops/models/create_compute_instance_group_canary_deploy_stage_details.rb', line 56 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'description': :'String', 'display_name': :'String', 'deploy_stage_type': :'String', 'deploy_pipeline_id': :'String', 'deploy_stage_predecessor_collection': :'OCI::Devops::Models::DeployStagePredecessorCollection', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'compute_instance_group_deploy_environment_id': :'String', 'deployment_spec_deploy_artifact_id': :'String', 'deploy_artifact_ids': :'Array<String>', 'rollout_policy': :'OCI::Devops::Models::ComputeInstanceGroupRolloutPolicy', 'test_load_balancer_config': :'OCI::Devops::Models::LoadBalancerConfig', 'production_load_balancer_config': :'OCI::Devops::Models::LoadBalancerConfig' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/oci/devops/models/create_compute_instance_group_canary_deploy_stage_details.rb', line 148 def ==(other) return true if equal?(other) self.class == other.class && description == other.description && display_name == other.display_name && deploy_stage_type == other.deploy_stage_type && deploy_pipeline_id == other.deploy_pipeline_id && deploy_stage_predecessor_collection == other.deploy_stage_predecessor_collection && == other. && == other. && compute_instance_group_deploy_environment_id == other.compute_instance_group_deploy_environment_id && deployment_spec_deploy_artifact_id == other.deployment_spec_deploy_artifact_id && deploy_artifact_ids == other.deploy_artifact_ids && rollout_policy == other.rollout_policy && test_load_balancer_config == other.test_load_balancer_config && production_load_balancer_config == other.production_load_balancer_config end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/oci/devops/models/create_compute_instance_group_canary_deploy_stage_details.rb', line 190 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
170 171 172 |
# File 'lib/oci/devops/models/create_compute_instance_group_canary_deploy_stage_details.rb', line 170 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
179 180 181 |
# File 'lib/oci/devops/models/create_compute_instance_group_canary_deploy_stage_details.rb', line 179 def hash [description, display_name, deploy_stage_type, deploy_pipeline_id, deploy_stage_predecessor_collection, , , compute_instance_group_deploy_environment_id, deployment_spec_deploy_artifact_id, deploy_artifact_ids, rollout_policy, test_load_balancer_config, production_load_balancer_config].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
223 224 225 226 227 228 229 230 231 232 |
# File 'lib/oci/devops/models/create_compute_instance_group_canary_deploy_stage_details.rb', line 223 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
217 218 219 |
# File 'lib/oci/devops/models/create_compute_instance_group_canary_deploy_stage_details.rb', line 217 def to_s to_hash.to_s end |