Class: OCI::Devops::Models::CreateDeployArtifactDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/devops/models/create_deploy_artifact_details.rb

Overview

Information about a new deployment artifact.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateDeployArtifactDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/oci/devops/models/create_deploy_artifact_details.rb', line 88

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.description = attributes[:'description'] if attributes[:'description']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.deploy_artifact_type = attributes[:'deployArtifactType'] if attributes[:'deployArtifactType']

  raise 'You cannot provide both :deployArtifactType and :deploy_artifact_type' if attributes.key?(:'deployArtifactType') && attributes.key?(:'deploy_artifact_type')

  self.deploy_artifact_type = attributes[:'deploy_artifact_type'] if attributes[:'deploy_artifact_type']

  self.deploy_artifact_source = attributes[:'deployArtifactSource'] if attributes[:'deployArtifactSource']

  raise 'You cannot provide both :deployArtifactSource and :deploy_artifact_source' if attributes.key?(:'deployArtifactSource') && attributes.key?(:'deploy_artifact_source')

  self.deploy_artifact_source = attributes[:'deploy_artifact_source'] if attributes[:'deploy_artifact_source']

  self.argument_substitution_mode = attributes[:'argumentSubstitutionMode'] if attributes[:'argumentSubstitutionMode']

  raise 'You cannot provide both :argumentSubstitutionMode and :argument_substitution_mode' if attributes.key?(:'argumentSubstitutionMode') && attributes.key?(:'argument_substitution_mode')

  self.argument_substitution_mode = attributes[:'argument_substitution_mode'] if attributes[:'argument_substitution_mode']

  self.project_id = attributes[:'projectId'] if attributes[:'projectId']

  raise 'You cannot provide both :projectId and :project_id' if attributes.key?(:'projectId') && attributes.key?(:'project_id')

  self.project_id = attributes[:'project_id'] if attributes[:'project_id']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#argument_substitution_modeString

[Required] Mode for artifact parameter substitution.

Returns:

  • (String)


28
29
30
# File 'lib/oci/devops/models/create_deploy_artifact_details.rb', line 28

def argument_substitution_mode
  @argument_substitution_mode
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


40
41
42
# File 'lib/oci/devops/models/create_deploy_artifact_details.rb', line 40

def defined_tags
  @defined_tags
end

#deploy_artifact_sourceOCI::Devops::Models::DeployArtifactSource

This attribute is required.



24
25
26
# File 'lib/oci/devops/models/create_deploy_artifact_details.rb', line 24

def deploy_artifact_source
  @deploy_artifact_source
end

#deploy_artifact_typeString

[Required] Type of the deployment artifact.

Returns:

  • (String)


20
21
22
# File 'lib/oci/devops/models/create_deploy_artifact_details.rb', line 20

def deploy_artifact_type
  @deploy_artifact_type
end

#descriptionString

Optional description about the deployment artifact.

Returns:

  • (String)


12
13
14
# File 'lib/oci/devops/models/create_deploy_artifact_details.rb', line 12

def description
  @description
end

#display_nameString

Deployment artifact display name. Avoid entering confidential information.

Returns:

  • (String)


16
17
18
# File 'lib/oci/devops/models/create_deploy_artifact_details.rb', line 16

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"value"`

Returns:

  • (Hash<String, String>)


36
37
38
# File 'lib/oci/devops/models/create_deploy_artifact_details.rb', line 36

def freeform_tags
  @freeform_tags
end

#project_idString

[Required] The OCID of a project.

Returns:

  • (String)


32
33
34
# File 'lib/oci/devops/models/create_deploy_artifact_details.rb', line 32

def project_id
  @project_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
54
55
56
# File 'lib/oci/devops/models/create_deploy_artifact_details.rb', line 43

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'description': :'description',
    'display_name': :'displayName',
    'deploy_artifact_type': :'deployArtifactType',
    'deploy_artifact_source': :'deployArtifactSource',
    'argument_substitution_mode': :'argumentSubstitutionMode',
    'project_id': :'projectId',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/oci/devops/models/create_deploy_artifact_details.rb', line 59

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'description': :'String',
    'display_name': :'String',
    'deploy_artifact_type': :'String',
    'deploy_artifact_source': :'OCI::Devops::Models::DeployArtifactSource',
    'argument_substitution_mode': :'String',
    'project_id': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/oci/devops/models/create_deploy_artifact_details.rb', line 146

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    description == other.description &&
    display_name == other.display_name &&
    deploy_artifact_type == other.deploy_artifact_type &&
    deploy_artifact_source == other.deploy_artifact_source &&
    argument_substitution_mode == other.argument_substitution_mode &&
    project_id == other.project_id &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/oci/devops/models/create_deploy_artifact_details.rb', line 183

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


163
164
165
# File 'lib/oci/devops/models/create_deploy_artifact_details.rb', line 163

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



172
173
174
# File 'lib/oci/devops/models/create_deploy_artifact_details.rb', line 172

def hash
  [description, display_name, deploy_artifact_type, deploy_artifact_source, argument_substitution_mode, project_id, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



216
217
218
219
220
221
222
223
224
225
# File 'lib/oci/devops/models/create_deploy_artifact_details.rb', line 216

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



210
211
212
# File 'lib/oci/devops/models/create_deploy_artifact_details.rb', line 210

def to_s
  to_hash.to_s
end