Class: OCI::Devops::Models::CreateDeployEnvironmentDetails
- Inherits:
-
Object
- Object
- OCI::Devops::Models::CreateDeployEnvironmentDetails
- Defined in:
- lib/oci/devops/models/create_deploy_environment_details.rb
Overview
The information about new deployment environment. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
CreateComputeInstanceGroupDeployEnvironmentDetails, CreateFunctionDeployEnvironmentDetails, CreateOkeClusterDeployEnvironmentDetails
Instance Attribute Summary collapse
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#deploy_environment_type ⇒ String
[Required] Deployment environment type.
-
#description ⇒ String
Optional description about the deployment environment.
-
#display_name ⇒ String
Deployment environment display name.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#project_id ⇒ String
[Required] The OCID of a project.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateDeployEnvironmentDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateDeployEnvironmentDetails
Initializes the object
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/oci/devops/models/create_deploy_environment_details.rb', line 92 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.description = attributes[:'description'] if attributes[:'description'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.deploy_environment_type = attributes[:'deployEnvironmentType'] if attributes[:'deployEnvironmentType'] raise 'You cannot provide both :deployEnvironmentType and :deploy_environment_type' if attributes.key?(:'deployEnvironmentType') && attributes.key?(:'deploy_environment_type') self.deploy_environment_type = attributes[:'deploy_environment_type'] if attributes[:'deploy_environment_type'] self.project_id = attributes[:'projectId'] if attributes[:'projectId'] raise 'You cannot provide both :projectId and :project_id' if attributes.key?(:'projectId') && attributes.key?(:'project_id') self.project_id = attributes[:'project_id'] if attributes[:'project_id'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"bar-key": "value"}`
33 34 35 |
# File 'lib/oci/devops/models/create_deploy_environment_details.rb', line 33 def @defined_tags end |
#deploy_environment_type ⇒ String
[Required] Deployment environment type.
21 22 23 |
# File 'lib/oci/devops/models/create_deploy_environment_details.rb', line 21 def deploy_environment_type @deploy_environment_type end |
#description ⇒ String
Optional description about the deployment environment.
13 14 15 |
# File 'lib/oci/devops/models/create_deploy_environment_details.rb', line 13 def description @description end |
#display_name ⇒ String
Deployment environment display name. Avoid entering confidential information.
17 18 19 |
# File 'lib/oci/devops/models/create_deploy_environment_details.rb', line 17 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"value"`
29 30 31 |
# File 'lib/oci/devops/models/create_deploy_environment_details.rb', line 29 def @freeform_tags end |
#project_id ⇒ String
[Required] The OCID of a project.
25 26 27 |
# File 'lib/oci/devops/models/create_deploy_environment_details.rb', line 25 def project_id @project_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
36 37 38 39 40 41 42 43 44 45 46 47 |
# File 'lib/oci/devops/models/create_deploy_environment_details.rb', line 36 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'description': :'description', 'display_name': :'displayName', 'deploy_environment_type': :'deployEnvironmentType', 'project_id': :'projectId', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
68 69 70 71 72 73 74 75 76 77 |
# File 'lib/oci/devops/models/create_deploy_environment_details.rb', line 68 def self.get_subtype(object_hash) type = object_hash[:'deployEnvironmentType'] # rubocop:disable Style/SymbolLiteral return 'OCI::Devops::Models::CreateComputeInstanceGroupDeployEnvironmentDetails' if type == 'COMPUTE_INSTANCE_GROUP' return 'OCI::Devops::Models::CreateOkeClusterDeployEnvironmentDetails' if type == 'OKE_CLUSTER' return 'OCI::Devops::Models::CreateFunctionDeployEnvironmentDetails' if type == 'FUNCTION' # TODO: Log a warning when the subtype is not found. 'OCI::Devops::Models::CreateDeployEnvironmentDetails' end |
.swagger_types ⇒ Object
Attribute type mapping.
50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/oci/devops/models/create_deploy_environment_details.rb', line 50 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'description': :'String', 'display_name': :'String', 'deploy_environment_type': :'String', 'project_id': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/oci/devops/models/create_deploy_environment_details.rb', line 138 def ==(other) return true if equal?(other) self.class == other.class && description == other.description && display_name == other.display_name && deploy_environment_type == other.deploy_environment_type && project_id == other.project_id && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/oci/devops/models/create_deploy_environment_details.rb', line 173 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
153 154 155 |
# File 'lib/oci/devops/models/create_deploy_environment_details.rb', line 153 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
162 163 164 |
# File 'lib/oci/devops/models/create_deploy_environment_details.rb', line 162 def hash [description, display_name, deploy_environment_type, project_id, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
206 207 208 209 210 211 212 213 214 215 |
# File 'lib/oci/devops/models/create_deploy_environment_details.rb', line 206 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
200 201 202 |
# File 'lib/oci/devops/models/create_deploy_environment_details.rb', line 200 def to_s to_hash.to_s end |