Class: OCI::Devops::Models::CreateDeployPipelineDeploymentDetails
- Inherits:
-
CreateDeploymentDetails
- Object
- CreateDeploymentDetails
- OCI::Devops::Models::CreateDeployPipelineDeploymentDetails
- Defined in:
- lib/oci/devops/models/create_deploy_pipeline_deployment_details.rb
Overview
Details of the new deployment to be created that will run all the stages in the pipeline.
Instance Attribute Summary collapse
- #deploy_artifact_override_arguments ⇒ OCI::Devops::Models::DeployArtifactOverrideArgumentCollection
- #deployment_arguments ⇒ OCI::Devops::Models::DeploymentArgumentCollection
Attributes inherited from CreateDeploymentDetails
#defined_tags, #deploy_pipeline_id, #deployment_type, #display_name, #freeform_tags
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateDeployPipelineDeploymentDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from CreateDeploymentDetails
Constructor Details
#initialize(attributes = {}) ⇒ CreateDeployPipelineDeploymentDetails
Initializes the object
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/oci/devops/models/create_deploy_pipeline_deployment_details.rb', line 59 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['deploymentType'] = 'PIPELINE_DEPLOYMENT' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.deployment_arguments = attributes[:'deploymentArguments'] if attributes[:'deploymentArguments'] raise 'You cannot provide both :deploymentArguments and :deployment_arguments' if attributes.key?(:'deploymentArguments') && attributes.key?(:'deployment_arguments') self.deployment_arguments = attributes[:'deployment_arguments'] if attributes[:'deployment_arguments'] self.deploy_artifact_override_arguments = attributes[:'deployArtifactOverrideArguments'] if attributes[:'deployArtifactOverrideArguments'] raise 'You cannot provide both :deployArtifactOverrideArguments and :deploy_artifact_override_arguments' if attributes.key?(:'deployArtifactOverrideArguments') && attributes.key?(:'deploy_artifact_override_arguments') self.deploy_artifact_override_arguments = attributes[:'deploy_artifact_override_arguments'] if attributes[:'deploy_artifact_override_arguments'] end |
Instance Attribute Details
#deploy_artifact_override_arguments ⇒ OCI::Devops::Models::DeployArtifactOverrideArgumentCollection
15 16 17 |
# File 'lib/oci/devops/models/create_deploy_pipeline_deployment_details.rb', line 15 def deploy_artifact_override_arguments @deploy_artifact_override_arguments end |
#deployment_arguments ⇒ OCI::Devops::Models::DeploymentArgumentCollection
12 13 14 |
# File 'lib/oci/devops/models/create_deploy_pipeline_deployment_details.rb', line 12 def deployment_arguments @deployment_arguments end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
18 19 20 21 22 23 24 25 26 27 28 29 30 |
# File 'lib/oci/devops/models/create_deploy_pipeline_deployment_details.rb', line 18 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'deploy_pipeline_id': :'deployPipelineId', 'deployment_type': :'deploymentType', 'display_name': :'displayName', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'deployment_arguments': :'deploymentArguments', 'deploy_artifact_override_arguments': :'deployArtifactOverrideArguments' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
33 34 35 36 37 38 39 40 41 42 43 44 45 |
# File 'lib/oci/devops/models/create_deploy_pipeline_deployment_details.rb', line 33 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'deploy_pipeline_id': :'String', 'deployment_type': :'String', 'display_name': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'deployment_arguments': :'OCI::Devops::Models::DeploymentArgumentCollection', 'deploy_artifact_override_arguments': :'OCI::Devops::Models::DeployArtifactOverrideArgumentCollection' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/oci/devops/models/create_deploy_pipeline_deployment_details.rb', line 89 def ==(other) return true if equal?(other) self.class == other.class && deploy_pipeline_id == other.deploy_pipeline_id && deployment_type == other.deployment_type && display_name == other.display_name && == other. && == other. && deployment_arguments == other.deployment_arguments && deploy_artifact_override_arguments == other.deploy_artifact_override_arguments end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/oci/devops/models/create_deploy_pipeline_deployment_details.rb', line 125 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
105 106 107 |
# File 'lib/oci/devops/models/create_deploy_pipeline_deployment_details.rb', line 105 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
114 115 116 |
# File 'lib/oci/devops/models/create_deploy_pipeline_deployment_details.rb', line 114 def hash [deploy_pipeline_id, deployment_type, display_name, , , deployment_arguments, deploy_artifact_override_arguments].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
158 159 160 161 162 163 164 165 166 167 |
# File 'lib/oci/devops/models/create_deploy_pipeline_deployment_details.rb', line 158 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
152 153 154 |
# File 'lib/oci/devops/models/create_deploy_pipeline_deployment_details.rb', line 152 def to_s to_hash.to_s end |