Class: OCI::Devops::Models::CreateDeployPipelineDetails
- Inherits:
-
Object
- Object
- OCI::Devops::Models::CreateDeployPipelineDetails
- Defined in:
- lib/oci/devops/models/create_deploy_pipeline_details.rb
Overview
The information about new deployment pipeline to be created.
Instance Attribute Summary collapse
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
- #deploy_pipeline_parameters ⇒ OCI::Devops::Models::DeployPipelineParameterCollection
-
#description ⇒ String
Optional description about the deployment pipeline.
-
#display_name ⇒ String
Deployment pipeline display name.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#project_id ⇒ String
[Required] The OCID of a project.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateDeployPipelineDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateDeployPipelineDetails
Initializes the object
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/oci/devops/models/create_deploy_pipeline_details.rb', line 73 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.description = attributes[:'description'] if attributes[:'description'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.project_id = attributes[:'projectId'] if attributes[:'projectId'] raise 'You cannot provide both :projectId and :project_id' if attributes.key?(:'projectId') && attributes.key?(:'project_id') self.project_id = attributes[:'project_id'] if attributes[:'project_id'] self.deploy_pipeline_parameters = attributes[:'deployPipelineParameters'] if attributes[:'deployPipelineParameters'] raise 'You cannot provide both :deployPipelineParameters and :deploy_pipeline_parameters' if attributes.key?(:'deployPipelineParameters') && attributes.key?(:'deploy_pipeline_parameters') self.deploy_pipeline_parameters = attributes[:'deploy_pipeline_parameters'] if attributes[:'deploy_pipeline_parameters'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"bar-key": "value"}`
31 32 33 |
# File 'lib/oci/devops/models/create_deploy_pipeline_details.rb', line 31 def end |
#deploy_pipeline_parameters ⇒ OCI::Devops::Models::DeployPipelineParameterCollection
23 24 25 |
# File 'lib/oci/devops/models/create_deploy_pipeline_details.rb', line 23 def deploy_pipeline_parameters @deploy_pipeline_parameters end |
#description ⇒ String
Optional description about the deployment pipeline.
12 13 14 |
# File 'lib/oci/devops/models/create_deploy_pipeline_details.rb', line 12 def description @description end |
#display_name ⇒ String
Deployment pipeline display name. Avoid entering confidential information.
16 17 18 |
# File 'lib/oci/devops/models/create_deploy_pipeline_details.rb', line 16 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"value"`
27 28 29 |
# File 'lib/oci/devops/models/create_deploy_pipeline_details.rb', line 27 def end |
#project_id ⇒ String
[Required] The OCID of a project.
20 21 22 |
# File 'lib/oci/devops/models/create_deploy_pipeline_details.rb', line 20 def project_id @project_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 43 44 45 |
# File 'lib/oci/devops/models/create_deploy_pipeline_details.rb', line 34 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'description': :'description', 'display_name': :'displayName', 'project_id': :'projectId', 'deploy_pipeline_parameters': :'deployPipelineParameters', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/oci/devops/models/create_deploy_pipeline_details.rb', line 48 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'description': :'String', 'display_name': :'String', 'project_id': :'String', 'deploy_pipeline_parameters': :'OCI::Devops::Models::DeployPipelineParameterCollection', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/oci/devops/models/create_deploy_pipeline_details.rb', line 119 def ==(other) return true if equal?(other) self.class == other.class && description == other.description && display_name == other.display_name && project_id == other.project_id && deploy_pipeline_parameters == other.deploy_pipeline_parameters && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/oci/devops/models/create_deploy_pipeline_details.rb', line 154 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
134 135 136 |
# File 'lib/oci/devops/models/create_deploy_pipeline_details.rb', line 134 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
143 144 145 |
# File 'lib/oci/devops/models/create_deploy_pipeline_details.rb', line 143 def hash [description, display_name, project_id, deploy_pipeline_parameters, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
187 188 189 190 191 192 193 194 195 196 |
# File 'lib/oci/devops/models/create_deploy_pipeline_details.rb', line 187 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
181 182 183 |
# File 'lib/oci/devops/models/create_deploy_pipeline_details.rb', line 181 def to_s to_hash.to_s end |