Class: OCI::Devops::Models::CreateDeployStageDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/devops/models/create_deploy_stage_details.rb

Overview

The information about new deployment stage. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateDeployStageDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/oci/devops/models/create_deploy_stage_details.rb', line 114

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.description = attributes[:'description'] if attributes[:'description']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.deploy_stage_type = attributes[:'deployStageType'] if attributes[:'deployStageType']

  raise 'You cannot provide both :deployStageType and :deploy_stage_type' if attributes.key?(:'deployStageType') && attributes.key?(:'deploy_stage_type')

  self.deploy_stage_type = attributes[:'deploy_stage_type'] if attributes[:'deploy_stage_type']

  self.deploy_pipeline_id = attributes[:'deployPipelineId'] if attributes[:'deployPipelineId']

  raise 'You cannot provide both :deployPipelineId and :deploy_pipeline_id' if attributes.key?(:'deployPipelineId') && attributes.key?(:'deploy_pipeline_id')

  self.deploy_pipeline_id = attributes[:'deploy_pipeline_id'] if attributes[:'deploy_pipeline_id']

  self.deploy_stage_predecessor_collection = attributes[:'deployStagePredecessorCollection'] if attributes[:'deployStagePredecessorCollection']

  raise 'You cannot provide both :deployStagePredecessorCollection and :deploy_stage_predecessor_collection' if attributes.key?(:'deployStagePredecessorCollection') && attributes.key?(:'deploy_stage_predecessor_collection')

  self.deploy_stage_predecessor_collection = attributes[:'deploy_stage_predecessor_collection'] if attributes[:'deploy_stage_predecessor_collection']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


37
38
39
# File 'lib/oci/devops/models/create_deploy_stage_details.rb', line 37

def defined_tags
  @defined_tags
end

#deploy_pipeline_idString

**[Required]** The OCID of a pipeline.

Returns:

  • (String)


25
26
27
# File 'lib/oci/devops/models/create_deploy_stage_details.rb', line 25

def deploy_pipeline_id
  @deploy_pipeline_id
end

#deploy_stage_predecessor_collectionOCI::Devops::Models::DeployStagePredecessorCollection

This attribute is required.



29
30
31
# File 'lib/oci/devops/models/create_deploy_stage_details.rb', line 29

def deploy_stage_predecessor_collection
  @deploy_stage_predecessor_collection
end

#deploy_stage_typeString

**[Required]** Deployment stage type.

Returns:

  • (String)


21
22
23
# File 'lib/oci/devops/models/create_deploy_stage_details.rb', line 21

def deploy_stage_type
  @deploy_stage_type
end

#descriptionString

Optional description about the deployment stage.

Returns:

  • (String)


13
14
15
# File 'lib/oci/devops/models/create_deploy_stage_details.rb', line 13

def description
  @description
end

#display_nameString

Deployment stage display name, which can be renamed and is not necessarily unique. Avoid entering confidential information.

Returns:

  • (String)


17
18
19
# File 'lib/oci/devops/models/create_deploy_stage_details.rb', line 17

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `"value"`

Returns:

  • (Hash<String, String>)


33
34
35
# File 'lib/oci/devops/models/create_deploy_stage_details.rb', line 33

def freeform_tags
  @freeform_tags
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
51
52
# File 'lib/oci/devops/models/create_deploy_stage_details.rb', line 40

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'description': :'description',
    'display_name': :'displayName',
    'deploy_stage_type': :'deployStageType',
    'deploy_pipeline_id': :'deployPipelineId',
    'deploy_stage_predecessor_collection': :'deployStagePredecessorCollection',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.get_subtype(object_hash) ⇒ Object

Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/oci/devops/models/create_deploy_stage_details.rb', line 74

def self.get_subtype(object_hash)
  type = object_hash[:'deployStageType'] # rubocop:disable Style/SymbolLiteral

  return 'OCI::Devops::Models::CreateOkeCanaryTrafficShiftDeployStageDetails' if type == 'OKE_CANARY_TRAFFIC_SHIFT'
  return 'OCI::Devops::Models::CreateOkeBlueGreenTrafficShiftDeployStageDetails' if type == 'OKE_BLUE_GREEN_TRAFFIC_SHIFT'
  return 'OCI::Devops::Models::CreateComputeInstanceGroupCanaryDeployStageDetails' if type == 'COMPUTE_INSTANCE_GROUP_CANARY_DEPLOYMENT'
  return 'OCI::Devops::Models::CreateWaitDeployStageDetails' if type == 'WAIT'
  return 'OCI::Devops::Models::CreateLoadBalancerTrafficShiftDeployStageDetails' if type == 'LOAD_BALANCER_TRAFFIC_SHIFT'
  return 'OCI::Devops::Models::CreateComputeInstanceGroupBlueGreenTrafficShiftDeployStageDetails' if type == 'COMPUTE_INSTANCE_GROUP_BLUE_GREEN_TRAFFIC_SHIFT'
  return 'OCI::Devops::Models::CreateOkeBlueGreenDeployStageDetails' if type == 'OKE_BLUE_GREEN_DEPLOYMENT'
  return 'OCI::Devops::Models::CreateComputeInstanceGroupDeployStageDetails' if type == 'COMPUTE_INSTANCE_GROUP_ROLLING_DEPLOYMENT'
  return 'OCI::Devops::Models::CreateInvokeFunctionDeployStageDetails' if type == 'INVOKE_FUNCTION'
  return 'OCI::Devops::Models::CreateFunctionDeployStageDetails' if type == 'DEPLOY_FUNCTION'
  return 'OCI::Devops::Models::CreateOkeCanaryDeployStageDetails' if type == 'OKE_CANARY_DEPLOYMENT'
  return 'OCI::Devops::Models::CreateComputeInstanceGroupCanaryTrafficShiftDeployStageDetails' if type == 'COMPUTE_INSTANCE_GROUP_CANARY_TRAFFIC_SHIFT'
  return 'OCI::Devops::Models::CreateComputeInstanceGroupCanaryApprovalDeployStageDetails' if type == 'COMPUTE_INSTANCE_GROUP_CANARY_APPROVAL'
  return 'OCI::Devops::Models::CreateOkeHelmChartDeployStageDetails' if type == 'OKE_HELM_CHART_DEPLOYMENT'
  return 'OCI::Devops::Models::CreateManualApprovalDeployStageDetails' if type == 'MANUAL_APPROVAL'
  return 'OCI::Devops::Models::CreateOkeDeployStageDetails' if type == 'OKE_DEPLOYMENT'
  return 'OCI::Devops::Models::CreateComputeInstanceGroupBlueGreenDeployStageDetails' if type == 'COMPUTE_INSTANCE_GROUP_BLUE_GREEN_DEPLOYMENT'
  return 'OCI::Devops::Models::CreateOkeCanaryApprovalDeployStageDetails' if type == 'OKE_CANARY_APPROVAL'

  # TODO: Log a warning when the subtype is not found.
  'OCI::Devops::Models::CreateDeployStageDetails'
end

.swagger_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/oci/devops/models/create_deploy_stage_details.rb', line 55

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'description': :'String',
    'display_name': :'String',
    'deploy_stage_type': :'String',
    'deploy_pipeline_id': :'String',
    'deploy_stage_predecessor_collection': :'OCI::Devops::Models::DeployStagePredecessorCollection',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/oci/devops/models/create_deploy_stage_details.rb', line 166

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    description == other.description &&
    display_name == other.display_name &&
    deploy_stage_type == other.deploy_stage_type &&
    deploy_pipeline_id == other.deploy_pipeline_id &&
    deploy_stage_predecessor_collection == other.deploy_stage_predecessor_collection &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/oci/devops/models/create_deploy_stage_details.rb', line 202

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


182
183
184
# File 'lib/oci/devops/models/create_deploy_stage_details.rb', line 182

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



191
192
193
# File 'lib/oci/devops/models/create_deploy_stage_details.rb', line 191

def hash
  [description, display_name, deploy_stage_type, deploy_pipeline_id, deploy_stage_predecessor_collection, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



235
236
237
238
239
240
241
242
243
244
# File 'lib/oci/devops/models/create_deploy_stage_details.rb', line 235

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



229
230
231
# File 'lib/oci/devops/models/create_deploy_stage_details.rb', line 229

def to_s
  to_hash.to_s
end