Class: OCI::Devops::Models::CreateFunctionDeployStageDetails
- Inherits:
-
CreateDeployStageDetails
- Object
- CreateDeployStageDetails
- OCI::Devops::Models::CreateFunctionDeployStageDetails
- Defined in:
- lib/oci/devops/models/create_function_deploy_stage_details.rb
Overview
Specifies the Function stage.
Instance Attribute Summary collapse
-
#config ⇒ Hash<String, String>
User provided key and value pair configuration, which is assigned through constants or parameter.
-
#docker_image_deploy_artifact_id ⇒ String
[Required] A Docker image artifact OCID.
-
#function_deploy_environment_id ⇒ String
[Required] Function environment OCID.
-
#function_timeout_in_seconds ⇒ Integer
Timeout for execution of the Function.
-
#max_memory_in_mbs ⇒ Integer
Maximum usable memory for the Function (in MB).
Attributes inherited from CreateDeployStageDetails
#defined_tags, #deploy_pipeline_id, #deploy_stage_predecessor_collection, #deploy_stage_type, #description, #display_name, #freeform_tags
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateFunctionDeployStageDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from CreateDeployStageDetails
Constructor Details
#initialize(attributes = {}) ⇒ CreateFunctionDeployStageDetails
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/oci/devops/models/create_function_deploy_stage_details.rb', line 88 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['deployStageType'] = 'DEPLOY_FUNCTION' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.function_deploy_environment_id = attributes[:'functionDeployEnvironmentId'] if attributes[:'functionDeployEnvironmentId'] raise 'You cannot provide both :functionDeployEnvironmentId and :function_deploy_environment_id' if attributes.key?(:'functionDeployEnvironmentId') && attributes.key?(:'function_deploy_environment_id') self.function_deploy_environment_id = attributes[:'function_deploy_environment_id'] if attributes[:'function_deploy_environment_id'] self.docker_image_deploy_artifact_id = attributes[:'dockerImageDeployArtifactId'] if attributes[:'dockerImageDeployArtifactId'] raise 'You cannot provide both :dockerImageDeployArtifactId and :docker_image_deploy_artifact_id' if attributes.key?(:'dockerImageDeployArtifactId') && attributes.key?(:'docker_image_deploy_artifact_id') self.docker_image_deploy_artifact_id = attributes[:'docker_image_deploy_artifact_id'] if attributes[:'docker_image_deploy_artifact_id'] self.config = attributes[:'config'] if attributes[:'config'] self.max_memory_in_mbs = attributes[:'maxMemoryInMBs'] if attributes[:'maxMemoryInMBs'] raise 'You cannot provide both :maxMemoryInMBs and :max_memory_in_mbs' if attributes.key?(:'maxMemoryInMBs') && attributes.key?(:'max_memory_in_mbs') self.max_memory_in_mbs = attributes[:'max_memory_in_mbs'] if attributes[:'max_memory_in_mbs'] self.function_timeout_in_seconds = attributes[:'functionTimeoutInSeconds'] if attributes[:'functionTimeoutInSeconds'] raise 'You cannot provide both :functionTimeoutInSeconds and :function_timeout_in_seconds' if attributes.key?(:'functionTimeoutInSeconds') && attributes.key?(:'function_timeout_in_seconds') self.function_timeout_in_seconds = attributes[:'function_timeout_in_seconds'] if attributes[:'function_timeout_in_seconds'] end |
Instance Attribute Details
#config ⇒ Hash<String, String>
User provided key and value pair configuration, which is assigned through constants or parameter.
21 22 23 |
# File 'lib/oci/devops/models/create_function_deploy_stage_details.rb', line 21 def config @config end |
#docker_image_deploy_artifact_id ⇒ String
[Required] A Docker image artifact OCID.
17 18 19 |
# File 'lib/oci/devops/models/create_function_deploy_stage_details.rb', line 17 def docker_image_deploy_artifact_id @docker_image_deploy_artifact_id end |
#function_deploy_environment_id ⇒ String
[Required] Function environment OCID.
13 14 15 |
# File 'lib/oci/devops/models/create_function_deploy_stage_details.rb', line 13 def function_deploy_environment_id @function_deploy_environment_id end |
#function_timeout_in_seconds ⇒ Integer
Timeout for execution of the Function. Value in seconds.
29 30 31 |
# File 'lib/oci/devops/models/create_function_deploy_stage_details.rb', line 29 def function_timeout_in_seconds @function_timeout_in_seconds end |
#max_memory_in_mbs ⇒ Integer
Maximum usable memory for the Function (in MB).
25 26 27 |
# File 'lib/oci/devops/models/create_function_deploy_stage_details.rb', line 25 def max_memory_in_mbs @max_memory_in_mbs end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 |
# File 'lib/oci/devops/models/create_function_deploy_stage_details.rb', line 32 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'description': :'description', 'display_name': :'displayName', 'deploy_stage_type': :'deployStageType', 'deploy_pipeline_id': :'deployPipelineId', 'deploy_stage_predecessor_collection': :'deployStagePredecessorCollection', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'function_deploy_environment_id': :'functionDeployEnvironmentId', 'docker_image_deploy_artifact_id': :'dockerImageDeployArtifactId', 'config': :'config', 'max_memory_in_mbs': :'maxMemoryInMBs', 'function_timeout_in_seconds': :'functionTimeoutInSeconds' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/oci/devops/models/create_function_deploy_stage_details.rb', line 52 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'description': :'String', 'display_name': :'String', 'deploy_stage_type': :'String', 'deploy_pipeline_id': :'String', 'deploy_stage_predecessor_collection': :'OCI::Devops::Models::DeployStagePredecessorCollection', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'function_deploy_environment_id': :'String', 'docker_image_deploy_artifact_id': :'String', 'config': :'Hash<String, String>', 'max_memory_in_mbs': :'Integer', 'function_timeout_in_seconds': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/oci/devops/models/create_function_deploy_stage_details.rb', line 132 def ==(other) return true if equal?(other) self.class == other.class && description == other.description && display_name == other.display_name && deploy_stage_type == other.deploy_stage_type && deploy_pipeline_id == other.deploy_pipeline_id && deploy_stage_predecessor_collection == other.deploy_stage_predecessor_collection && == other. && == other. && function_deploy_environment_id == other.function_deploy_environment_id && docker_image_deploy_artifact_id == other.docker_image_deploy_artifact_id && config == other.config && max_memory_in_mbs == other.max_memory_in_mbs && function_timeout_in_seconds == other.function_timeout_in_seconds end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/oci/devops/models/create_function_deploy_stage_details.rb', line 173 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
153 154 155 |
# File 'lib/oci/devops/models/create_function_deploy_stage_details.rb', line 153 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
162 163 164 |
# File 'lib/oci/devops/models/create_function_deploy_stage_details.rb', line 162 def hash [description, display_name, deploy_stage_type, deploy_pipeline_id, deploy_stage_predecessor_collection, , , function_deploy_environment_id, docker_image_deploy_artifact_id, config, max_memory_in_mbs, function_timeout_in_seconds].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
206 207 208 209 210 211 212 213 214 215 |
# File 'lib/oci/devops/models/create_function_deploy_stage_details.rb', line 206 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
200 201 202 |
# File 'lib/oci/devops/models/create_function_deploy_stage_details.rb', line 200 def to_s to_hash.to_s end |