Class: OCI::Devops::Models::CreateRepositoryDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/devops/models/create_repository_details.rb

Overview

Information about the new repository.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateRepositoryDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'lib/oci/devops/models/create_repository_details.rb', line 87

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.name = attributes[:'name'] if attributes[:'name']

  self.project_id = attributes[:'projectId'] if attributes[:'projectId']

  raise 'You cannot provide both :projectId and :project_id' if attributes.key?(:'projectId') && attributes.key?(:'project_id')

  self.project_id = attributes[:'project_id'] if attributes[:'project_id']

  self.default_branch = attributes[:'defaultBranch'] if attributes[:'defaultBranch']

  raise 'You cannot provide both :defaultBranch and :default_branch' if attributes.key?(:'defaultBranch') && attributes.key?(:'default_branch')

  self.default_branch = attributes[:'default_branch'] if attributes[:'default_branch']

  self.repository_type = attributes[:'repositoryType'] if attributes[:'repositoryType']

  raise 'You cannot provide both :repositoryType and :repository_type' if attributes.key?(:'repositoryType') && attributes.key?(:'repository_type')

  self.repository_type = attributes[:'repository_type'] if attributes[:'repository_type']

  self.mirror_repository_config = attributes[:'mirrorRepositoryConfig'] if attributes[:'mirrorRepositoryConfig']

  raise 'You cannot provide both :mirrorRepositoryConfig and :mirror_repository_config' if attributes.key?(:'mirrorRepositoryConfig') && attributes.key?(:'mirror_repository_config')

  self.mirror_repository_config = attributes[:'mirror_repository_config'] if attributes[:'mirror_repository_config']

  self.description = attributes[:'description'] if attributes[:'description']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#default_branchString

The default branch of the repository.

Returns:

  • (String)


20
21
22
# File 'lib/oci/devops/models/create_repository_details.rb', line 20

def default_branch
  @default_branch
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


39
40
41
# File 'lib/oci/devops/models/create_repository_details.rb', line 39

def defined_tags
  @defined_tags
end

#descriptionString

Details of the repository. Avoid entering confidential information.

Returns:

  • (String)


31
32
33
# File 'lib/oci/devops/models/create_repository_details.rb', line 31

def description
  @description
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"value"`

Returns:

  • (Hash<String, String>)


35
36
37
# File 'lib/oci/devops/models/create_repository_details.rb', line 35

def freeform_tags
  @freeform_tags
end

#mirror_repository_configOCI::Devops::Models::MirrorRepositoryConfig



27
28
29
# File 'lib/oci/devops/models/create_repository_details.rb', line 27

def mirror_repository_config
  @mirror_repository_config
end

#nameString

[Required] Unique name of a repository.

Returns:

  • (String)


12
13
14
# File 'lib/oci/devops/models/create_repository_details.rb', line 12

def name
  @name
end

#project_idString

[Required] The OCID of the DevOps project containing the repository.

Returns:

  • (String)


16
17
18
# File 'lib/oci/devops/models/create_repository_details.rb', line 16

def project_id
  @project_id
end

#repository_typeString

Type of repository.

Returns:

  • (String)


24
25
26
# File 'lib/oci/devops/models/create_repository_details.rb', line 24

def repository_type
  @repository_type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



42
43
44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/oci/devops/models/create_repository_details.rb', line 42

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'name': :'name',
    'project_id': :'projectId',
    'default_branch': :'defaultBranch',
    'repository_type': :'repositoryType',
    'mirror_repository_config': :'mirrorRepositoryConfig',
    'description': :'description',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/oci/devops/models/create_repository_details.rb', line 58

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'name': :'String',
    'project_id': :'String',
    'default_branch': :'String',
    'repository_type': :'String',
    'mirror_repository_config': :'OCI::Devops::Models::MirrorRepositoryConfig',
    'description': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



141
142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/oci/devops/models/create_repository_details.rb', line 141

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    name == other.name &&
    project_id == other.project_id &&
    default_branch == other.default_branch &&
    repository_type == other.repository_type &&
    mirror_repository_config == other.mirror_repository_config &&
    description == other.description &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/oci/devops/models/create_repository_details.rb', line 178

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


158
159
160
# File 'lib/oci/devops/models/create_repository_details.rb', line 158

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



167
168
169
# File 'lib/oci/devops/models/create_repository_details.rb', line 167

def hash
  [name, project_id, default_branch, repository_type, mirror_repository_config, description, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



211
212
213
214
215
216
217
218
219
220
# File 'lib/oci/devops/models/create_repository_details.rb', line 211

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



205
206
207
# File 'lib/oci/devops/models/create_repository_details.rb', line 205

def to_s
  to_hash.to_s
end