Class: OCI::Devops::Models::DeliverArtifactCollection
- Inherits:
-
Object
- Object
- OCI::Devops::Models::DeliverArtifactCollection
- Defined in:
- lib/oci/devops/models/deliver_artifact_collection.rb
Overview
Specifies an array of artifacts that need to be pushed to the artifactory stores.
Instance Attribute Summary collapse
-
#items ⇒ Array<OCI::Devops::Models::DeliverArtifact>
[Required] Collection of artifacts that were generated in the Build stage and need to be pushed to the artifactory stores.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DeliverArtifactCollection
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DeliverArtifactCollection
Initializes the object
39 40 41 42 43 44 45 46 |
# File 'lib/oci/devops/models/deliver_artifact_collection.rb', line 39 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.items = attributes[:'items'] if attributes[:'items'] end |
Instance Attribute Details
#items ⇒ Array<OCI::Devops::Models::DeliverArtifact>
[Required] Collection of artifacts that were generated in the Build stage and need to be pushed to the artifactory stores. In case of UPDATE operation, replaces existing artifacts list. Merging with existing artifacts is not supported.
12 13 14 |
# File 'lib/oci/devops/models/deliver_artifact_collection.rb', line 12 def items @items end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
15 16 17 18 19 20 21 |
# File 'lib/oci/devops/models/deliver_artifact_collection.rb', line 15 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'items': :'items' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
24 25 26 27 28 29 30 |
# File 'lib/oci/devops/models/deliver_artifact_collection.rb', line 24 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'items': :'Array<OCI::Devops::Models::DeliverArtifact>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
55 56 57 58 59 60 |
# File 'lib/oci/devops/models/deliver_artifact_collection.rb', line 55 def ==(other) return true if equal?(other) self.class == other.class && items == other.items end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/oci/devops/models/deliver_artifact_collection.rb', line 85 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
65 66 67 |
# File 'lib/oci/devops/models/deliver_artifact_collection.rb', line 65 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
74 75 76 |
# File 'lib/oci/devops/models/deliver_artifact_collection.rb', line 74 def hash [items].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
118 119 120 121 122 123 124 125 126 127 |
# File 'lib/oci/devops/models/deliver_artifact_collection.rb', line 118 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
112 113 114 |
# File 'lib/oci/devops/models/deliver_artifact_collection.rb', line 112 def to_s to_hash.to_s end |