Class: OCI::Devops::Models::DeployArtifact
- Inherits:
-
Object
- Object
- OCI::Devops::Models::DeployArtifact
- Defined in:
- lib/oci/devops/models/deploy_artifact.rb
Overview
Artifacts are deployment manifests that are referenced in a pipeline stage for automated deployment to the target environment. DevOps artifacts can be an OCI Container image repository, Kubernetes manifest, an Artifact Registry artifact, or defined inline.
Constant Summary collapse
- DEPLOY_ARTIFACT_TYPE_ENUM =
[ DEPLOY_ARTIFACT_TYPE_DEPLOYMENT_SPEC = 'DEPLOYMENT_SPEC'.freeze, DEPLOY_ARTIFACT_TYPE_JOB_SPEC = 'JOB_SPEC'.freeze, DEPLOY_ARTIFACT_TYPE_KUBERNETES_MANIFEST = 'KUBERNETES_MANIFEST'.freeze, DEPLOY_ARTIFACT_TYPE_GENERIC_FILE = 'GENERIC_FILE'.freeze, DEPLOY_ARTIFACT_TYPE_DOCKER_IMAGE = 'DOCKER_IMAGE'.freeze, DEPLOY_ARTIFACT_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- ARGUMENT_SUBSTITUTION_MODE_ENUM =
[ ARGUMENT_SUBSTITUTION_MODE_NONE = 'NONE'.freeze, ARGUMENT_SUBSTITUTION_MODE_SUBSTITUTE_PLACEHOLDERS = 'SUBSTITUTE_PLACEHOLDERS'.freeze, ARGUMENT_SUBSTITUTION_MODE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#argument_substitution_mode ⇒ String
[Required] Mode for artifact parameter substitution.
-
#compartment_id ⇒ String
[Required] The OCID of a compartment.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#deploy_artifact_source ⇒ OCI::Devops::Models::DeployArtifactSource
This attribute is required.
-
#deploy_artifact_type ⇒ String
[Required] Type of the deployment artifact.
-
#description ⇒ String
Optional description about the artifact to be deployed.
-
#display_name ⇒ String
Deployment artifact identifier, which can be renamed and is not necessarily unique.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
[Required] Unique identifier that is immutable on creation.
-
#lifecycle_details ⇒ String
A detailed message describing the current state.
-
#lifecycle_state ⇒ String
Current state of the deployment artifact.
-
#project_id ⇒ String
[Required] The OCID of a project.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys.
-
#time_created ⇒ DateTime
Time the deployment artifact was created.
-
#time_updated ⇒ DateTime
Time the deployment artifact was updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DeployArtifact
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DeployArtifact
Initializes the object
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/oci/devops/models/deploy_artifact.rb', line 163 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.description = attributes[:'description'] if attributes[:'description'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.project_id = attributes[:'projectId'] if attributes[:'projectId'] raise 'You cannot provide both :projectId and :project_id' if attributes.key?(:'projectId') && attributes.key?(:'project_id') self.project_id = attributes[:'project_id'] if attributes[:'project_id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.deploy_artifact_type = attributes[:'deployArtifactType'] if attributes[:'deployArtifactType'] raise 'You cannot provide both :deployArtifactType and :deploy_artifact_type' if attributes.key?(:'deployArtifactType') && attributes.key?(:'deploy_artifact_type') self.deploy_artifact_type = attributes[:'deploy_artifact_type'] if attributes[:'deploy_artifact_type'] self.argument_substitution_mode = attributes[:'argumentSubstitutionMode'] if attributes[:'argumentSubstitutionMode'] raise 'You cannot provide both :argumentSubstitutionMode and :argument_substitution_mode' if attributes.key?(:'argumentSubstitutionMode') && attributes.key?(:'argument_substitution_mode') self.argument_substitution_mode = attributes[:'argument_substitution_mode'] if attributes[:'argument_substitution_mode'] self.deploy_artifact_source = attributes[:'deployArtifactSource'] if attributes[:'deployArtifactSource'] raise 'You cannot provide both :deployArtifactSource and :deploy_artifact_source' if attributes.key?(:'deployArtifactSource') && attributes.key?(:'deploy_artifact_source') self.deploy_artifact_source = attributes[:'deploy_artifact_source'] if attributes[:'deploy_artifact_source'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#argument_substitution_mode ⇒ String
[Required] Mode for artifact parameter substitution.
62 63 64 |
# File 'lib/oci/devops/models/deploy_artifact.rb', line 62 def argument_substitution_mode @argument_substitution_mode end |
#compartment_id ⇒ String
[Required] The OCID of a compartment.
54 55 56 |
# File 'lib/oci/devops/models/deploy_artifact.rb', line 54 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"bar-key": "value"}`
90 91 92 |
# File 'lib/oci/devops/models/deploy_artifact.rb', line 90 def end |
#deploy_artifact_source ⇒ OCI::Devops::Models::DeployArtifactSource
This attribute is required.
66 67 68 |
# File 'lib/oci/devops/models/deploy_artifact.rb', line 66 def deploy_artifact_source @deploy_artifact_source end |
#deploy_artifact_type ⇒ String
[Required] Type of the deployment artifact.
58 59 60 |
# File 'lib/oci/devops/models/deploy_artifact.rb', line 58 def deploy_artifact_type @deploy_artifact_type end |
#description ⇒ String
Optional description about the artifact to be deployed.
42 43 44 |
# File 'lib/oci/devops/models/deploy_artifact.rb', line 42 def description @description end |
#display_name ⇒ String
Deployment artifact identifier, which can be renamed and is not necessarily unique. Avoid entering confidential information.
46 47 48 |
# File 'lib/oci/devops/models/deploy_artifact.rb', line 46 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"value"`
86 87 88 |
# File 'lib/oci/devops/models/deploy_artifact.rb', line 86 def end |
#id ⇒ String
[Required] Unique identifier that is immutable on creation.
38 39 40 |
# File 'lib/oci/devops/models/deploy_artifact.rb', line 38 def id @id end |
#lifecycle_details ⇒ String
A detailed message describing the current state. For example, can be used to provide actionable information for a resource in Failed state.
82 83 84 |
# File 'lib/oci/devops/models/deploy_artifact.rb', line 82 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
Current state of the deployment artifact.
78 79 80 |
# File 'lib/oci/devops/models/deploy_artifact.rb', line 78 def lifecycle_state @lifecycle_state end |
#project_id ⇒ String
[Required] The OCID of a project.
50 51 52 |
# File 'lib/oci/devops/models/deploy_artifact.rb', line 50 def project_id @project_id end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys. These predefined keys are scoped to namespaces. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"free-tier-retained": "true"}`
94 95 96 |
# File 'lib/oci/devops/models/deploy_artifact.rb', line 94 def end |
#time_created ⇒ DateTime
Time the deployment artifact was created. Format defined by [RFC3339](datatracker.ietf.org/doc/html/rfc3339).
70 71 72 |
# File 'lib/oci/devops/models/deploy_artifact.rb', line 70 def time_created @time_created end |
#time_updated ⇒ DateTime
Time the deployment artifact was updated. Format defined by [RFC3339](datatracker.ietf.org/doc/html/rfc3339).
74 75 76 |
# File 'lib/oci/devops/models/deploy_artifact.rb', line 74 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/oci/devops/models/deploy_artifact.rb', line 97 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'description': :'description', 'display_name': :'displayName', 'project_id': :'projectId', 'compartment_id': :'compartmentId', 'deploy_artifact_type': :'deployArtifactType', 'argument_substitution_mode': :'argumentSubstitutionMode', 'deploy_artifact_source': :'deployArtifactSource', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/oci/devops/models/deploy_artifact.rb', line 120 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'description': :'String', 'display_name': :'String', 'project_id': :'String', 'compartment_id': :'String', 'deploy_artifact_type': :'String', 'argument_substitution_mode': :'String', 'deploy_artifact_source': :'OCI::Devops::Models::DeployArtifactSource', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/oci/devops/models/deploy_artifact.rb', line 298 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && description == other.description && display_name == other.display_name && project_id == other.project_id && compartment_id == other.compartment_id && deploy_artifact_type == other.deploy_artifact_type && argument_substitution_mode == other.argument_substitution_mode && deploy_artifact_source == other.deploy_artifact_source && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 |
# File 'lib/oci/devops/models/deploy_artifact.rb', line 342 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
322 323 324 |
# File 'lib/oci/devops/models/deploy_artifact.rb', line 322 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
331 332 333 |
# File 'lib/oci/devops/models/deploy_artifact.rb', line 331 def hash [id, description, display_name, project_id, compartment_id, deploy_artifact_type, argument_substitution_mode, deploy_artifact_source, time_created, time_updated, lifecycle_state, lifecycle_details, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
375 376 377 378 379 380 381 382 383 384 |
# File 'lib/oci/devops/models/deploy_artifact.rb', line 375 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
369 370 371 |
# File 'lib/oci/devops/models/deploy_artifact.rb', line 369 def to_s to_hash.to_s end |