Class: OCI::Devops::Models::DeployPipeline
- Inherits:
-
Object
- Object
- OCI::Devops::Models::DeployPipeline
- Defined in:
- lib/oci/devops/models/deploy_pipeline.rb
Overview
A set of stages whose predecessor relation forms a directed acyclic graph.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The OCID of the compartment where the pipeline is created.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
- #deploy_pipeline_artifacts ⇒ OCI::Devops::Models::DeployPipelineArtifactCollection
- #deploy_pipeline_environments ⇒ OCI::Devops::Models::DeployPipelineEnvironmentCollection
-
#deploy_pipeline_parameters ⇒ OCI::Devops::Models::DeployPipelineParameterCollection
This attribute is required.
-
#description ⇒ String
Optional description about the deployment pipeline.
-
#display_name ⇒ String
Deployment pipeline display name, which can be renamed and is not necessarily unique.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
[Required] Unique identifier that is immutable on creation.
-
#lifecycle_details ⇒ String
A message describing the current state in more detail.
-
#lifecycle_state ⇒ String
The current state of the deployment pipeline.
-
#project_id ⇒ String
[Required] The OCID of a project.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys.
-
#time_created ⇒ DateTime
Time the deployment pipeline was created.
-
#time_updated ⇒ DateTime
Time the deployment pipeline was updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DeployPipeline
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DeployPipeline
Initializes the object
147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/oci/devops/models/deploy_pipeline.rb', line 147 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.description = attributes[:'description'] if attributes[:'description'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.project_id = attributes[:'projectId'] if attributes[:'projectId'] raise 'You cannot provide both :projectId and :project_id' if attributes.key?(:'projectId') && attributes.key?(:'project_id') self.project_id = attributes[:'project_id'] if attributes[:'project_id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.deploy_pipeline_artifacts = attributes[:'deployPipelineArtifacts'] if attributes[:'deployPipelineArtifacts'] raise 'You cannot provide both :deployPipelineArtifacts and :deploy_pipeline_artifacts' if attributes.key?(:'deployPipelineArtifacts') && attributes.key?(:'deploy_pipeline_artifacts') self.deploy_pipeline_artifacts = attributes[:'deploy_pipeline_artifacts'] if attributes[:'deploy_pipeline_artifacts'] self.deploy_pipeline_environments = attributes[:'deployPipelineEnvironments'] if attributes[:'deployPipelineEnvironments'] raise 'You cannot provide both :deployPipelineEnvironments and :deploy_pipeline_environments' if attributes.key?(:'deployPipelineEnvironments') && attributes.key?(:'deploy_pipeline_environments') self.deploy_pipeline_environments = attributes[:'deploy_pipeline_environments'] if attributes[:'deploy_pipeline_environments'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.deploy_pipeline_parameters = attributes[:'deployPipelineParameters'] if attributes[:'deployPipelineParameters'] raise 'You cannot provide both :deployPipelineParameters and :deploy_pipeline_parameters' if attributes.key?(:'deployPipelineParameters') && attributes.key?(:'deploy_pipeline_parameters') self.deploy_pipeline_parameters = attributes[:'deploy_pipeline_parameters'] if attributes[:'deploy_pipeline_parameters'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The OCID of the compartment where the pipeline is created.
40 41 42 |
# File 'lib/oci/devops/models/deploy_pipeline.rb', line 40 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"bar-key": "value"}`
74 75 76 |
# File 'lib/oci/devops/models/deploy_pipeline.rb', line 74 def end |
#deploy_pipeline_artifacts ⇒ OCI::Devops::Models::DeployPipelineArtifactCollection
43 44 45 |
# File 'lib/oci/devops/models/deploy_pipeline.rb', line 43 def deploy_pipeline_artifacts @deploy_pipeline_artifacts end |
#deploy_pipeline_environments ⇒ OCI::Devops::Models::DeployPipelineEnvironmentCollection
46 47 48 |
# File 'lib/oci/devops/models/deploy_pipeline.rb', line 46 def deploy_pipeline_environments @deploy_pipeline_environments end |
#deploy_pipeline_parameters ⇒ OCI::Devops::Models::DeployPipelineParameterCollection
This attribute is required.
66 67 68 |
# File 'lib/oci/devops/models/deploy_pipeline.rb', line 66 def deploy_pipeline_parameters @deploy_pipeline_parameters end |
#description ⇒ String
Optional description about the deployment pipeline.
28 29 30 |
# File 'lib/oci/devops/models/deploy_pipeline.rb', line 28 def description @description end |
#display_name ⇒ String
Deployment pipeline display name, which can be renamed and is not necessarily unique. Avoid entering confidential information.
32 33 34 |
# File 'lib/oci/devops/models/deploy_pipeline.rb', line 32 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"value"`
70 71 72 |
# File 'lib/oci/devops/models/deploy_pipeline.rb', line 70 def end |
#id ⇒ String
[Required] Unique identifier that is immutable on creation.
24 25 26 |
# File 'lib/oci/devops/models/deploy_pipeline.rb', line 24 def id @id end |
#lifecycle_details ⇒ String
A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
62 63 64 |
# File 'lib/oci/devops/models/deploy_pipeline.rb', line 62 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
The current state of the deployment pipeline.
58 59 60 |
# File 'lib/oci/devops/models/deploy_pipeline.rb', line 58 def lifecycle_state @lifecycle_state end |
#project_id ⇒ String
[Required] The OCID of a project.
36 37 38 |
# File 'lib/oci/devops/models/deploy_pipeline.rb', line 36 def project_id @project_id end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys. These predefined keys are scoped to namespaces. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"free-tier-retained": "true"}`
78 79 80 |
# File 'lib/oci/devops/models/deploy_pipeline.rb', line 78 def end |
#time_created ⇒ DateTime
Time the deployment pipeline was created. Format defined by [RFC3339](datatracker.ietf.org/doc/html/rfc3339).
50 51 52 |
# File 'lib/oci/devops/models/deploy_pipeline.rb', line 50 def time_created @time_created end |
#time_updated ⇒ DateTime
Time the deployment pipeline was updated. Format defined by [RFC3339](datatracker.ietf.org/doc/html/rfc3339).
54 55 56 |
# File 'lib/oci/devops/models/deploy_pipeline.rb', line 54 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/oci/devops/models/deploy_pipeline.rb', line 81 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'description': :'description', 'display_name': :'displayName', 'project_id': :'projectId', 'compartment_id': :'compartmentId', 'deploy_pipeline_artifacts': :'deployPipelineArtifacts', 'deploy_pipeline_environments': :'deployPipelineEnvironments', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'deploy_pipeline_parameters': :'deployPipelineParameters', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/oci/devops/models/deploy_pipeline.rb', line 104 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'description': :'String', 'display_name': :'String', 'project_id': :'String', 'compartment_id': :'String', 'deploy_pipeline_artifacts': :'OCI::Devops::Models::DeployPipelineArtifactCollection', 'deploy_pipeline_environments': :'OCI::Devops::Models::DeployPipelineEnvironmentCollection', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'deploy_pipeline_parameters': :'OCI::Devops::Models::DeployPipelineParameterCollection', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/oci/devops/models/deploy_pipeline.rb', line 256 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && description == other.description && display_name == other.display_name && project_id == other.project_id && compartment_id == other.compartment_id && deploy_pipeline_artifacts == other.deploy_pipeline_artifacts && deploy_pipeline_environments == other.deploy_pipeline_environments && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && deploy_pipeline_parameters == other.deploy_pipeline_parameters && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 |
# File 'lib/oci/devops/models/deploy_pipeline.rb', line 300 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
280 281 282 |
# File 'lib/oci/devops/models/deploy_pipeline.rb', line 280 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
289 290 291 |
# File 'lib/oci/devops/models/deploy_pipeline.rb', line 289 def hash [id, description, display_name, project_id, compartment_id, deploy_pipeline_artifacts, deploy_pipeline_environments, time_created, time_updated, lifecycle_state, lifecycle_details, deploy_pipeline_parameters, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
333 334 335 336 337 338 339 340 341 342 |
# File 'lib/oci/devops/models/deploy_pipeline.rb', line 333 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
327 328 329 |
# File 'lib/oci/devops/models/deploy_pipeline.rb', line 327 def to_s to_hash.to_s end |