Class: OCI::Devops::Models::Deployment

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/devops/models/deployment.rb

Overview

A single execution or run of a pipeline. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class

Constant Summary collapse

DEPLOYMENT_TYPE_ENUM =
[
  DEPLOYMENT_TYPE_PIPELINE_DEPLOYMENT = 'PIPELINE_DEPLOYMENT'.freeze,
  DEPLOYMENT_TYPE_PIPELINE_REDEPLOYMENT = 'PIPELINE_REDEPLOYMENT'.freeze,
  DEPLOYMENT_TYPE_SINGLE_STAGE_DEPLOYMENT = 'SINGLE_STAGE_DEPLOYMENT'.freeze,
  DEPLOYMENT_TYPE_SINGLE_STAGE_REDEPLOYMENT = 'SINGLE_STAGE_REDEPLOYMENT'.freeze,
  DEPLOYMENT_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_ACCEPTED = 'ACCEPTED'.freeze,
  LIFECYCLE_STATE_IN_PROGRESS = 'IN_PROGRESS'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_SUCCEEDED = 'SUCCEEDED'.freeze,
  LIFECYCLE_STATE_CANCELING = 'CANCELING'.freeze,
  LIFECYCLE_STATE_CANCELED = 'CANCELED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Deployment

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
# File 'lib/oci/devops/models/deployment.rb', line 191

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.deploy_pipeline_artifacts = attributes[:'deployPipelineArtifacts'] if attributes[:'deployPipelineArtifacts']

  raise 'You cannot provide both :deployPipelineArtifacts and :deploy_pipeline_artifacts' if attributes.key?(:'deployPipelineArtifacts') && attributes.key?(:'deploy_pipeline_artifacts')

  self.deploy_pipeline_artifacts = attributes[:'deploy_pipeline_artifacts'] if attributes[:'deploy_pipeline_artifacts']

  self.deploy_pipeline_environments = attributes[:'deployPipelineEnvironments'] if attributes[:'deployPipelineEnvironments']

  raise 'You cannot provide both :deployPipelineEnvironments and :deploy_pipeline_environments' if attributes.key?(:'deployPipelineEnvironments') && attributes.key?(:'deploy_pipeline_environments')

  self.deploy_pipeline_environments = attributes[:'deploy_pipeline_environments'] if attributes[:'deploy_pipeline_environments']

  self.deployment_type = attributes[:'deploymentType'] if attributes[:'deploymentType']

  raise 'You cannot provide both :deploymentType and :deployment_type' if attributes.key?(:'deploymentType') && attributes.key?(:'deployment_type')

  self.deployment_type = attributes[:'deployment_type'] if attributes[:'deployment_type']

  self.id = attributes[:'id'] if attributes[:'id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.project_id = attributes[:'projectId'] if attributes[:'projectId']

  raise 'You cannot provide both :projectId and :project_id' if attributes.key?(:'projectId') && attributes.key?(:'project_id')

  self.project_id = attributes[:'project_id'] if attributes[:'project_id']

  self.deploy_pipeline_id = attributes[:'deployPipelineId'] if attributes[:'deployPipelineId']

  raise 'You cannot provide both :deployPipelineId and :deploy_pipeline_id' if attributes.key?(:'deployPipelineId') && attributes.key?(:'deploy_pipeline_id')

  self.deploy_pipeline_id = attributes[:'deploy_pipeline_id'] if attributes[:'deploy_pipeline_id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.deployment_arguments = attributes[:'deploymentArguments'] if attributes[:'deploymentArguments']

  raise 'You cannot provide both :deploymentArguments and :deployment_arguments' if attributes.key?(:'deploymentArguments') && attributes.key?(:'deployment_arguments')

  self.deployment_arguments = attributes[:'deployment_arguments'] if attributes[:'deployment_arguments']

  self.deploy_artifact_override_arguments = attributes[:'deployArtifactOverrideArguments'] if attributes[:'deployArtifactOverrideArguments']

  raise 'You cannot provide both :deployArtifactOverrideArguments and :deploy_artifact_override_arguments' if attributes.key?(:'deployArtifactOverrideArguments') && attributes.key?(:'deploy_artifact_override_arguments')

  self.deploy_artifact_override_arguments = attributes[:'deploy_artifact_override_arguments'] if attributes[:'deploy_artifact_override_arguments']

  self.deployment_execution_progress = attributes[:'deploymentExecutionProgress'] if attributes[:'deploymentExecutionProgress']

  raise 'You cannot provide both :deploymentExecutionProgress and :deployment_execution_progress' if attributes.key?(:'deploymentExecutionProgress') && attributes.key?(:'deployment_execution_progress')

  self.deployment_execution_progress = attributes[:'deployment_execution_progress'] if attributes[:'deployment_execution_progress']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

  raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

  self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']
end

Instance Attribute Details

#compartment_idString

**[Required]** The OCID of a compartment.

Returns:

  • (String)


58
59
60
# File 'lib/oci/devops/models/deployment.rb', line 58

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


91
92
93
# File 'lib/oci/devops/models/deployment.rb', line 91

def defined_tags
  @defined_tags
end

#deploy_artifact_override_argumentsOCI::Devops::Models::DeployArtifactOverrideArgumentCollection



80
81
82
# File 'lib/oci/devops/models/deployment.rb', line 80

def deploy_artifact_override_arguments
  @deploy_artifact_override_arguments
end

#deploy_pipeline_artifactsOCI::Devops::Models::DeployPipelineArtifactCollection



31
32
33
# File 'lib/oci/devops/models/deployment.rb', line 31

def deploy_pipeline_artifacts
  @deploy_pipeline_artifacts
end

#deploy_pipeline_environmentsOCI::Devops::Models::DeployPipelineEnvironmentCollection



34
35
36
# File 'lib/oci/devops/models/deployment.rb', line 34

def deploy_pipeline_environments
  @deploy_pipeline_environments
end

#deploy_pipeline_idString

**[Required]** The OCID of a pipeline.

Returns:

  • (String)


54
55
56
# File 'lib/oci/devops/models/deployment.rb', line 54

def deploy_pipeline_id
  @deploy_pipeline_id
end

#deployment_argumentsOCI::Devops::Models::DeploymentArgumentCollection



77
78
79
# File 'lib/oci/devops/models/deployment.rb', line 77

def deployment_arguments
  @deployment_arguments
end

#deployment_execution_progressOCI::Devops::Models::DeploymentExecutionProgress



83
84
85
# File 'lib/oci/devops/models/deployment.rb', line 83

def deployment_execution_progress
  @deployment_execution_progress
end

#deployment_typeString

**[Required]** Specifies type of deployment.

Returns:

  • (String)


38
39
40
# File 'lib/oci/devops/models/deployment.rb', line 38

def deployment_type
  @deployment_type
end

#display_nameString

Deployment identifier which can be renamed and is not necessarily unique. Avoid entering confidential information.

Returns:

  • (String)


46
47
48
# File 'lib/oci/devops/models/deployment.rb', line 46

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `"value"`

Returns:

  • (Hash<String, String>)


87
88
89
# File 'lib/oci/devops/models/deployment.rb', line 87

def freeform_tags
  @freeform_tags
end

#idString

**[Required]** Unique identifier that is immutable on creation.

Returns:

  • (String)


42
43
44
# File 'lib/oci/devops/models/deployment.rb', line 42

def id
  @id
end

#lifecycle_detailsString

A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.

Returns:

  • (String)


74
75
76
# File 'lib/oci/devops/models/deployment.rb', line 74

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

The current state of the deployment.

Returns:

  • (String)


70
71
72
# File 'lib/oci/devops/models/deployment.rb', line 70

def lifecycle_state
  @lifecycle_state
end

#project_idString

**[Required]** The OCID of a project.

Returns:

  • (String)


50
51
52
# File 'lib/oci/devops/models/deployment.rb', line 50

def project_id
  @project_id
end

#system_tagsHash<String, Hash<String, Object>>

Usage of system tag keys. These predefined keys are scoped to namespaces. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `{"free-tier-retained": "true"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


95
96
97
# File 'lib/oci/devops/models/deployment.rb', line 95

def system_tags
  @system_tags
end

#time_createdDateTime

Time the deployment was created. Format defined by [RFC3339](datatracker.ietf.org/doc/html/rfc3339).

Returns:

  • (DateTime)


62
63
64
# File 'lib/oci/devops/models/deployment.rb', line 62

def time_created
  @time_created
end

#time_updatedDateTime

Time the deployment was updated. Format defined by [RFC3339](datatracker.ietf.org/doc/html/rfc3339).

Returns:

  • (DateTime)


66
67
68
# File 'lib/oci/devops/models/deployment.rb', line 66

def time_updated
  @time_updated
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/oci/devops/models/deployment.rb', line 98

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'deploy_pipeline_artifacts': :'deployPipelineArtifacts',
    'deploy_pipeline_environments': :'deployPipelineEnvironments',
    'deployment_type': :'deploymentType',
    'id': :'id',
    'display_name': :'displayName',
    'project_id': :'projectId',
    'deploy_pipeline_id': :'deployPipelineId',
    'compartment_id': :'compartmentId',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'deployment_arguments': :'deploymentArguments',
    'deploy_artifact_override_arguments': :'deployArtifactOverrideArguments',
    'deployment_execution_progress': :'deploymentExecutionProgress',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.get_subtype(object_hash) ⇒ Object

Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.



154
155
156
157
158
159
160
161
162
163
164
# File 'lib/oci/devops/models/deployment.rb', line 154

def self.get_subtype(object_hash)
  type = object_hash[:'deploymentType'] # rubocop:disable Style/SymbolLiteral

  return 'OCI::Devops::Models::SingleDeployStageRedeployment' if type == 'SINGLE_STAGE_REDEPLOYMENT'
  return 'OCI::Devops::Models::DeployPipelineDeployment' if type == 'PIPELINE_DEPLOYMENT'
  return 'OCI::Devops::Models::DeployPipelineRedeployment' if type == 'PIPELINE_REDEPLOYMENT'
  return 'OCI::Devops::Models::SingleDeployStageDeployment' if type == 'SINGLE_STAGE_DEPLOYMENT'

  # TODO: Log a warning when the subtype is not found.
  'OCI::Devops::Models::Deployment'
end

.swagger_typesObject

Attribute type mapping.



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/oci/devops/models/deployment.rb', line 124

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'deploy_pipeline_artifacts': :'OCI::Devops::Models::DeployPipelineArtifactCollection',
    'deploy_pipeline_environments': :'OCI::Devops::Models::DeployPipelineEnvironmentCollection',
    'deployment_type': :'String',
    'id': :'String',
    'display_name': :'String',
    'project_id': :'String',
    'deploy_pipeline_id': :'String',
    'compartment_id': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'deployment_arguments': :'OCI::Devops::Models::DeploymentArgumentCollection',
    'deploy_artifact_override_arguments': :'OCI::Devops::Models::DeployArtifactOverrideArgumentCollection',
    'deployment_execution_progress': :'OCI::Devops::Models::DeploymentExecutionProgress',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
# File 'lib/oci/devops/models/deployment.rb', line 335

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    deploy_pipeline_artifacts == other.deploy_pipeline_artifacts &&
    deploy_pipeline_environments == other.deploy_pipeline_environments &&
    deployment_type == other.deployment_type &&
    id == other.id &&
    display_name == other.display_name &&
    project_id == other.project_id &&
    deploy_pipeline_id == other.deploy_pipeline_id &&
    compartment_id == other.compartment_id &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    deployment_arguments == other.deployment_arguments &&
    deploy_artifact_override_arguments == other.deploy_artifact_override_arguments &&
    deployment_execution_progress == other.deployment_execution_progress &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
# File 'lib/oci/devops/models/deployment.rb', line 382

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


362
363
364
# File 'lib/oci/devops/models/deployment.rb', line 362

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



371
372
373
# File 'lib/oci/devops/models/deployment.rb', line 371

def hash
  [deploy_pipeline_artifacts, deploy_pipeline_environments, deployment_type, id, display_name, project_id, deploy_pipeline_id, compartment_id, time_created, time_updated, lifecycle_state, lifecycle_details, deployment_arguments, deploy_artifact_override_arguments, deployment_execution_progress, freeform_tags, defined_tags, system_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



415
416
417
418
419
420
421
422
423
424
# File 'lib/oci/devops/models/deployment.rb', line 415

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



409
410
411
# File 'lib/oci/devops/models/deployment.rb', line 409

def to_s
  to_hash.to_s
end