Class: OCI::Devops::Models::DevopsCodeRepositoryFilter
- Defined in:
- lib/oci/devops/models/devops_code_repository_filter.rb
Overview
The filter for GitLab events.
Constant Summary collapse
- EVENTS_ENUM =
[ EVENTS_PUSH = 'PUSH'.freeze, EVENTS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#events ⇒ Array<String>
The events only support PUSH.
- #include ⇒ OCI::Devops::Models::DevopsCodeRepositoryFilterAttributes
Attributes inherited from Filter
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DevopsCodeRepositoryFilter
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from Filter
Constructor Details
#initialize(attributes = {}) ⇒ DevopsCodeRepositoryFilter
Initializes the object
54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/oci/devops/models/devops_code_repository_filter.rb', line 54 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['triggerSource'] = 'DEVOPS_CODE_REPOSITORY' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.events = attributes[:'events'] if attributes[:'events'] self.include = attributes[:'include'] if attributes[:'include'] end |
Instance Attribute Details
#events ⇒ Array<String>
The events only support PUSH.
19 20 21 |
# File 'lib/oci/devops/models/devops_code_repository_filter.rb', line 19 def events @events end |
#include ⇒ OCI::Devops::Models::DevopsCodeRepositoryFilterAttributes
22 23 24 |
# File 'lib/oci/devops/models/devops_code_repository_filter.rb', line 22 def include @include end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
25 26 27 28 29 30 31 32 33 |
# File 'lib/oci/devops/models/devops_code_repository_filter.rb', line 25 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'trigger_source': :'triggerSource', 'events': :'events', 'include': :'include' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
36 37 38 39 40 41 42 43 44 |
# File 'lib/oci/devops/models/devops_code_repository_filter.rb', line 36 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'trigger_source': :'String', 'events': :'Array<String>', 'include': :'OCI::Devops::Models::DevopsCodeRepositoryFilterAttributes' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
96 97 98 99 100 101 102 103 |
# File 'lib/oci/devops/models/devops_code_repository_filter.rb', line 96 def ==(other) return true if equal?(other) self.class == other.class && trigger_source == other.trigger_source && events == other.events && include == other.include end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/oci/devops/models/devops_code_repository_filter.rb', line 128 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
108 109 110 |
# File 'lib/oci/devops/models/devops_code_repository_filter.rb', line 108 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
117 118 119 |
# File 'lib/oci/devops/models/devops_code_repository_filter.rb', line 117 def hash [trigger_source, events, include].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
161 162 163 164 165 166 167 168 169 170 |
# File 'lib/oci/devops/models/devops_code_repository_filter.rb', line 161 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
155 156 157 |
# File 'lib/oci/devops/models/devops_code_repository_filter.rb', line 155 def to_s to_hash.to_s end |