Class: OCI::Devops::Models::DiffChunk

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/devops/models/diff_chunk.rb

Overview

Details about a group of changes.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DiffChunk

Initializes the object

Options Hash (attributes):

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/oci/devops/models/diff_chunk.rb', line 67

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.base_line = attributes[:'baseLine'] if attributes[:'baseLine']

  raise 'You cannot provide both :baseLine and :base_line' if attributes.key?(:'baseLine') && attributes.key?(:'base_line')

  self.base_line = attributes[:'base_line'] if attributes[:'base_line']

  self.base_span = attributes[:'baseSpan'] if attributes[:'baseSpan']

  raise 'You cannot provide both :baseSpan and :base_span' if attributes.key?(:'baseSpan') && attributes.key?(:'base_span')

  self.base_span = attributes[:'base_span'] if attributes[:'base_span']

  self.target_line = attributes[:'targetLine'] if attributes[:'targetLine']

  raise 'You cannot provide both :targetLine and :target_line' if attributes.key?(:'targetLine') && attributes.key?(:'target_line')

  self.target_line = attributes[:'target_line'] if attributes[:'target_line']

  self.target_span = attributes[:'targetSpan'] if attributes[:'targetSpan']

  raise 'You cannot provide both :targetSpan and :target_span' if attributes.key?(:'targetSpan') && attributes.key?(:'target_span')

  self.target_span = attributes[:'target_span'] if attributes[:'target_span']

  self.diff_sections = attributes[:'diffSections'] if attributes[:'diffSections']

  raise 'You cannot provide both :diffSections and :diff_sections' if attributes.key?(:'diffSections') && attributes.key?(:'diff_sections')

  self.diff_sections = attributes[:'diff_sections'] if attributes[:'diff_sections']
end

Instance Attribute Details

#base_lineInteger

Line number in base version where changes begin.

Returns:



12
13
14
# File 'lib/oci/devops/models/diff_chunk.rb', line 12

def base_line
  @base_line
end

#base_spanInteger

Number of lines chunk spans in base version.

Returns:



16
17
18
# File 'lib/oci/devops/models/diff_chunk.rb', line 16

def base_span
  @base_span
end

#diff_sectionsArray<OCI::Devops::Models::DiffSection>

List of difference section.

Returns:



28
29
30
# File 'lib/oci/devops/models/diff_chunk.rb', line 28

def diff_sections
  @diff_sections
end

#target_lineInteger

Line number in target version where changes begin.

Returns:



20
21
22
# File 'lib/oci/devops/models/diff_chunk.rb', line 20

def target_line
  @target_line
end

#target_spanInteger

Number of lines chunk spans in target version.

Returns:



24
25
26
# File 'lib/oci/devops/models/diff_chunk.rb', line 24

def target_span
  @target_span
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
40
41
# File 'lib/oci/devops/models/diff_chunk.rb', line 31

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'base_line': :'baseLine',
    'base_span': :'baseSpan',
    'target_line': :'targetLine',
    'target_span': :'targetSpan',
    'diff_sections': :'diffSections'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



44
45
46
47
48
49
50
51
52
53
54
# File 'lib/oci/devops/models/diff_chunk.rb', line 44

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'base_line': :'Integer',
    'base_span': :'Integer',
    'target_line': :'Integer',
    'target_span': :'Integer',
    'diff_sections': :'Array<OCI::Devops::Models::DiffSection>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • the other object to be compared



111
112
113
114
115
116
117
118
119
120
# File 'lib/oci/devops/models/diff_chunk.rb', line 111

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    base_line == other.base_line &&
    base_span == other.base_span &&
    target_line == other.target_line &&
    target_span == other.target_span &&
    diff_sections == other.diff_sections
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/oci/devops/models/diff_chunk.rb', line 145

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method

Parameters:

  • the other object to be compared

Returns:



125
126
127
# File 'lib/oci/devops/models/diff_chunk.rb', line 125

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • Hash code



134
135
136
# File 'lib/oci/devops/models/diff_chunk.rb', line 134

def hash
  [base_line, base_span, target_line, target_span, diff_sections].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



178
179
180
181
182
183
184
185
186
187
# File 'lib/oci/devops/models/diff_chunk.rb', line 178

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



172
173
174
# File 'lib/oci/devops/models/diff_chunk.rb', line 172

def to_s
  to_hash.to_s
end