Class: OCI::Devops::Models::Filter

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/devops/models/filter.rb

Overview

The filters for the trigger. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Filter

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :trigger_source (String)

    The value to assign to the #trigger_source property



58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/oci/devops/models/filter.rb', line 58

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.trigger_source = attributes[:'triggerSource'] if attributes[:'triggerSource']

  raise 'You cannot provide both :triggerSource and :trigger_source' if attributes.key?(:'triggerSource') && attributes.key?(:'trigger_source')

  self.trigger_source = attributes[:'trigger_source'] if attributes[:'trigger_source']
end

Instance Attribute Details

#trigger_sourceString

[Required] Source of the trigger. Allowed values are, GITHUB and GITLAB.

Returns:

  • (String)


14
15
16
# File 'lib/oci/devops/models/filter.rb', line 14

def trigger_source
  @trigger_source
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



17
18
19
20
21
22
23
# File 'lib/oci/devops/models/filter.rb', line 17

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'trigger_source': :'triggerSource'
    # rubocop:enable Style/SymbolLiteral
  }
end

.get_subtype(object_hash) ⇒ Object

Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.



39
40
41
42
43
44
45
46
47
48
# File 'lib/oci/devops/models/filter.rb', line 39

def self.get_subtype(object_hash)
  type = object_hash[:'triggerSource'] # rubocop:disable Style/SymbolLiteral

  return 'OCI::Devops::Models::DevopsCodeRepositoryFilter' if type == 'DEVOPS_CODE_REPOSITORY'
  return 'OCI::Devops::Models::GitlabFilter' if type == 'GITLAB'
  return 'OCI::Devops::Models::GithubFilter' if type == 'GITHUB'

  # TODO: Log a warning when the subtype is not found.
  'OCI::Devops::Models::Filter'
end

.swagger_typesObject

Attribute type mapping.



26
27
28
29
30
31
32
# File 'lib/oci/devops/models/filter.rb', line 26

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'trigger_source': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



78
79
80
81
82
83
# File 'lib/oci/devops/models/filter.rb', line 78

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    trigger_source == other.trigger_source
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/oci/devops/models/filter.rb', line 108

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


88
89
90
# File 'lib/oci/devops/models/filter.rb', line 88

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



97
98
99
# File 'lib/oci/devops/models/filter.rb', line 97

def hash
  [trigger_source].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



141
142
143
144
145
146
147
148
149
150
# File 'lib/oci/devops/models/filter.rb', line 141

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



135
136
137
# File 'lib/oci/devops/models/filter.rb', line 135

def to_s
  to_hash.to_s
end