Class: OCI::Devops::Models::FunctionDeployStageSummary

Inherits:
DeployStageSummary show all
Defined in:
lib/oci/devops/models/function_deploy_stage_summary.rb

Overview

Specifies the Function stage.

Instance Attribute Summary collapse

Attributes inherited from DeployStageSummary

#compartment_id, #defined_tags, #deploy_pipeline_id, #deploy_stage_predecessor_collection, #deploy_stage_type, #description, #display_name, #freeform_tags, #id, #lifecycle_details, #lifecycle_state, #project_id, #system_tags, #time_created, #time_updated

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from DeployStageSummary

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ FunctionDeployStageSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/oci/devops/models/function_deploy_stage_summary.rb', line 112

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['deployStageType'] = 'DEPLOY_FUNCTION'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.function_deploy_environment_id = attributes[:'functionDeployEnvironmentId'] if attributes[:'functionDeployEnvironmentId']

  raise 'You cannot provide both :functionDeployEnvironmentId and :function_deploy_environment_id' if attributes.key?(:'functionDeployEnvironmentId') && attributes.key?(:'function_deploy_environment_id')

  self.function_deploy_environment_id = attributes[:'function_deploy_environment_id'] if attributes[:'function_deploy_environment_id']

  self.docker_image_deploy_artifact_id = attributes[:'dockerImageDeployArtifactId'] if attributes[:'dockerImageDeployArtifactId']

  raise 'You cannot provide both :dockerImageDeployArtifactId and :docker_image_deploy_artifact_id' if attributes.key?(:'dockerImageDeployArtifactId') && attributes.key?(:'docker_image_deploy_artifact_id')

  self.docker_image_deploy_artifact_id = attributes[:'docker_image_deploy_artifact_id'] if attributes[:'docker_image_deploy_artifact_id']

  self.config = attributes[:'config'] if attributes[:'config']

  self.max_memory_in_mbs = attributes[:'maxMemoryInMBs'] if attributes[:'maxMemoryInMBs']

  raise 'You cannot provide both :maxMemoryInMBs and :max_memory_in_mbs' if attributes.key?(:'maxMemoryInMBs') && attributes.key?(:'max_memory_in_mbs')

  self.max_memory_in_mbs = attributes[:'max_memory_in_mbs'] if attributes[:'max_memory_in_mbs']

  self.function_timeout_in_seconds = attributes[:'functionTimeoutInSeconds'] if attributes[:'functionTimeoutInSeconds']

  raise 'You cannot provide both :functionTimeoutInSeconds and :function_timeout_in_seconds' if attributes.key?(:'functionTimeoutInSeconds') && attributes.key?(:'function_timeout_in_seconds')

  self.function_timeout_in_seconds = attributes[:'function_timeout_in_seconds'] if attributes[:'function_timeout_in_seconds']
end

Instance Attribute Details

#configHash<String, String>

User provided key and value pair configuration, which is assigned through constants or parameter.

Returns:

  • (Hash<String, String>)


21
22
23
# File 'lib/oci/devops/models/function_deploy_stage_summary.rb', line 21

def config
  @config
end

#docker_image_deploy_artifact_idString

[Required] A Docker image artifact OCID.

Returns:

  • (String)


17
18
19
# File 'lib/oci/devops/models/function_deploy_stage_summary.rb', line 17

def docker_image_deploy_artifact_id
  @docker_image_deploy_artifact_id
end

#function_deploy_environment_idString

[Required] Function environment OCID.

Returns:

  • (String)


13
14
15
# File 'lib/oci/devops/models/function_deploy_stage_summary.rb', line 13

def function_deploy_environment_id
  @function_deploy_environment_id
end

#function_timeout_in_secondsInteger

Timeout for execution of the Function. Value in seconds.

Returns:

  • (Integer)


29
30
31
# File 'lib/oci/devops/models/function_deploy_stage_summary.rb', line 29

def function_timeout_in_seconds
  @function_timeout_in_seconds
end

#max_memory_in_mbsInteger

Maximum usable memory for the Function (in MB).

Returns:

  • (Integer)


25
26
27
# File 'lib/oci/devops/models/function_deploy_stage_summary.rb', line 25

def max_memory_in_mbs
  @max_memory_in_mbs
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
# File 'lib/oci/devops/models/function_deploy_stage_summary.rb', line 32

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'description': :'description',
    'display_name': :'displayName',
    'project_id': :'projectId',
    'deploy_pipeline_id': :'deployPipelineId',
    'compartment_id': :'compartmentId',
    'deploy_stage_type': :'deployStageType',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'deploy_stage_predecessor_collection': :'deployStagePredecessorCollection',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags',
    'function_deploy_environment_id': :'functionDeployEnvironmentId',
    'docker_image_deploy_artifact_id': :'dockerImageDeployArtifactId',
    'config': :'config',
    'max_memory_in_mbs': :'maxMemoryInMBs',
    'function_timeout_in_seconds': :'functionTimeoutInSeconds'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/oci/devops/models/function_deploy_stage_summary.rb', line 60

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'description': :'String',
    'display_name': :'String',
    'project_id': :'String',
    'deploy_pipeline_id': :'String',
    'compartment_id': :'String',
    'deploy_stage_type': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'deploy_stage_predecessor_collection': :'OCI::Devops::Models::DeployStagePredecessorCollection',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>',
    'function_deploy_environment_id': :'String',
    'docker_image_deploy_artifact_id': :'String',
    'config': :'Hash<String, String>',
    'max_memory_in_mbs': :'Integer',
    'function_timeout_in_seconds': :'Integer'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/oci/devops/models/function_deploy_stage_summary.rb', line 156

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    description == other.description &&
    display_name == other.display_name &&
    project_id == other.project_id &&
    deploy_pipeline_id == other.deploy_pipeline_id &&
    compartment_id == other.compartment_id &&
    deploy_stage_type == other.deploy_stage_type &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    deploy_stage_predecessor_collection == other.deploy_stage_predecessor_collection &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags &&
    function_deploy_environment_id == other.function_deploy_environment_id &&
    docker_image_deploy_artifact_id == other.docker_image_deploy_artifact_id &&
    config == other.config &&
    max_memory_in_mbs == other.max_memory_in_mbs &&
    function_timeout_in_seconds == other.function_timeout_in_seconds
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/oci/devops/models/function_deploy_stage_summary.rb', line 205

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


185
186
187
# File 'lib/oci/devops/models/function_deploy_stage_summary.rb', line 185

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



194
195
196
# File 'lib/oci/devops/models/function_deploy_stage_summary.rb', line 194

def hash
  [id, description, display_name, project_id, deploy_pipeline_id, compartment_id, deploy_stage_type, time_created, time_updated, lifecycle_state, lifecycle_details, deploy_stage_predecessor_collection, freeform_tags, defined_tags, system_tags, function_deploy_environment_id, docker_image_deploy_artifact_id, config, max_memory_in_mbs, function_timeout_in_seconds].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



238
239
240
241
242
243
244
245
246
247
# File 'lib/oci/devops/models/function_deploy_stage_summary.rb', line 238

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



232
233
234
# File 'lib/oci/devops/models/function_deploy_stage_summary.rb', line 232

def to_s
  to_hash.to_s
end