Class: OCI::Devops::Models::InvokeFunctionDeployStage
- Inherits:
-
DeployStage
- Object
- DeployStage
- OCI::Devops::Models::InvokeFunctionDeployStage
- Defined in:
- lib/oci/devops/models/invoke_function_deploy_stage.rb
Overview
Specifies Invoke Function stage.
Constant Summary
Constants inherited from DeployStage
DeployStage::DEPLOY_STAGE_TYPE_ENUM, DeployStage::LIFECYCLE_STATE_ENUM
Instance Attribute Summary collapse
-
#deploy_artifact_id ⇒ String
Optional binary artifact OCID user may provide to this stage.
-
#function_deploy_environment_id ⇒ String
[Required] Function environment OCID.
-
#is_async ⇒ BOOLEAN
[Required] A boolean flag specifies whether this stage executes asynchronously.
-
#is_validation_enabled ⇒ BOOLEAN
[Required] A boolean flag specifies whether the invoked function must be validated.
Attributes inherited from DeployStage
#compartment_id, #defined_tags, #deploy_pipeline_id, #deploy_stage_predecessor_collection, #deploy_stage_type, #description, #display_name, #freeform_tags, #id, #lifecycle_details, #lifecycle_state, #project_id, #system_tags, #time_created, #time_updated
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ InvokeFunctionDeployStage
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from DeployStage
Constructor Details
#initialize(attributes = {}) ⇒ InvokeFunctionDeployStage
Initializes the object
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/oci/devops/models/invoke_function_deploy_stage.rb', line 105 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['deployStageType'] = 'INVOKE_FUNCTION' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.function_deploy_environment_id = attributes[:'functionDeployEnvironmentId'] if attributes[:'functionDeployEnvironmentId'] raise 'You cannot provide both :functionDeployEnvironmentId and :function_deploy_environment_id' if attributes.key?(:'functionDeployEnvironmentId') && attributes.key?(:'function_deploy_environment_id') self.function_deploy_environment_id = attributes[:'function_deploy_environment_id'] if attributes[:'function_deploy_environment_id'] self.deploy_artifact_id = attributes[:'deployArtifactId'] if attributes[:'deployArtifactId'] raise 'You cannot provide both :deployArtifactId and :deploy_artifact_id' if attributes.key?(:'deployArtifactId') && attributes.key?(:'deploy_artifact_id') self.deploy_artifact_id = attributes[:'deploy_artifact_id'] if attributes[:'deploy_artifact_id'] self.is_async = attributes[:'isAsync'] unless attributes[:'isAsync'].nil? raise 'You cannot provide both :isAsync and :is_async' if attributes.key?(:'isAsync') && attributes.key?(:'is_async') self.is_async = attributes[:'is_async'] unless attributes[:'is_async'].nil? self.is_validation_enabled = attributes[:'isValidationEnabled'] unless attributes[:'isValidationEnabled'].nil? raise 'You cannot provide both :isValidationEnabled and :is_validation_enabled' if attributes.key?(:'isValidationEnabled') && attributes.key?(:'is_validation_enabled') self.is_validation_enabled = attributes[:'is_validation_enabled'] unless attributes[:'is_validation_enabled'].nil? end |
Instance Attribute Details
#deploy_artifact_id ⇒ String
Optional binary artifact OCID user may provide to this stage.
17 18 19 |
# File 'lib/oci/devops/models/invoke_function_deploy_stage.rb', line 17 def deploy_artifact_id @deploy_artifact_id end |
#function_deploy_environment_id ⇒ String
[Required] Function environment OCID.
13 14 15 |
# File 'lib/oci/devops/models/invoke_function_deploy_stage.rb', line 13 def function_deploy_environment_id @function_deploy_environment_id end |
#is_async ⇒ BOOLEAN
[Required] A boolean flag specifies whether this stage executes asynchronously.
21 22 23 |
# File 'lib/oci/devops/models/invoke_function_deploy_stage.rb', line 21 def is_async @is_async end |
#is_validation_enabled ⇒ BOOLEAN
[Required] A boolean flag specifies whether the invoked function must be validated.
25 26 27 |
# File 'lib/oci/devops/models/invoke_function_deploy_stage.rb', line 25 def is_validation_enabled @is_validation_enabled end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/oci/devops/models/invoke_function_deploy_stage.rb', line 28 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'description': :'description', 'display_name': :'displayName', 'project_id': :'projectId', 'deploy_pipeline_id': :'deployPipelineId', 'compartment_id': :'compartmentId', 'deploy_stage_type': :'deployStageType', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'deploy_stage_predecessor_collection': :'deployStagePredecessorCollection', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags', 'function_deploy_environment_id': :'functionDeployEnvironmentId', 'deploy_artifact_id': :'deployArtifactId', 'is_async': :'isAsync', 'is_validation_enabled': :'isValidationEnabled' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/oci/devops/models/invoke_function_deploy_stage.rb', line 55 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'description': :'String', 'display_name': :'String', 'project_id': :'String', 'deploy_pipeline_id': :'String', 'compartment_id': :'String', 'deploy_stage_type': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'deploy_stage_predecessor_collection': :'OCI::Devops::Models::DeployStagePredecessorCollection', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>', 'function_deploy_environment_id': :'String', 'deploy_artifact_id': :'String', 'is_async': :'BOOLEAN', 'is_validation_enabled': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/oci/devops/models/invoke_function_deploy_stage.rb', line 147 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && description == other.description && display_name == other.display_name && project_id == other.project_id && deploy_pipeline_id == other.deploy_pipeline_id && compartment_id == other.compartment_id && deploy_stage_type == other.deploy_stage_type && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && deploy_stage_predecessor_collection == other.deploy_stage_predecessor_collection && == other. && == other. && == other. && function_deploy_environment_id == other.function_deploy_environment_id && deploy_artifact_id == other.deploy_artifact_id && is_async == other.is_async && is_validation_enabled == other.is_validation_enabled end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/oci/devops/models/invoke_function_deploy_stage.rb', line 195 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
175 176 177 |
# File 'lib/oci/devops/models/invoke_function_deploy_stage.rb', line 175 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
184 185 186 |
# File 'lib/oci/devops/models/invoke_function_deploy_stage.rb', line 184 def hash [id, description, display_name, project_id, deploy_pipeline_id, compartment_id, deploy_stage_type, time_created, time_updated, lifecycle_state, lifecycle_details, deploy_stage_predecessor_collection, , , , function_deploy_environment_id, deploy_artifact_id, is_async, is_validation_enabled].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
228 229 230 231 232 233 234 235 236 237 |
# File 'lib/oci/devops/models/invoke_function_deploy_stage.rb', line 228 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
222 223 224 |
# File 'lib/oci/devops/models/invoke_function_deploy_stage.rb', line 222 def to_s to_hash.to_s end |