Class: OCI::Devops::Models::LoadBalancerTrafficShiftDeployStageSummary
- Inherits:
-
DeployStageSummary
- Object
- DeployStageSummary
- OCI::Devops::Models::LoadBalancerTrafficShiftDeployStageSummary
- Defined in:
- lib/oci/devops/models/load_balancer_traffic_shift_deploy_stage_summary.rb
Overview
Specifies load balancer traffic shift stage.
Instance Attribute Summary collapse
-
#blue_backend_ips ⇒ OCI::Devops::Models::BackendSetIpCollection
This attribute is required.
-
#green_backend_ips ⇒ OCI::Devops::Models::BackendSetIpCollection
This attribute is required.
-
#load_balancer_config ⇒ OCI::Devops::Models::LoadBalancerConfig
This attribute is required.
- #rollback_policy ⇒ OCI::Devops::Models::DeployStageRollbackPolicy
-
#rollout_policy ⇒ OCI::Devops::Models::LoadBalancerTrafficShiftRolloutPolicy
This attribute is required.
-
#traffic_shift_target ⇒ String
[Required] Specifies the target or destination backend set.
Attributes inherited from DeployStageSummary
#compartment_id, #defined_tags, #deploy_pipeline_id, #deploy_stage_predecessor_collection, #deploy_stage_type, #description, #display_name, #freeform_tags, #id, #lifecycle_details, #lifecycle_state, #project_id, #system_tags, #time_created, #time_updated
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LoadBalancerTrafficShiftDeployStageSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from DeployStageSummary
Constructor Details
#initialize(attributes = {}) ⇒ LoadBalancerTrafficShiftDeployStageSummary
Initializes the object
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/oci/devops/models/load_balancer_traffic_shift_deploy_stage_summary.rb', line 118 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['deployStageType'] = 'LOAD_BALANCER_TRAFFIC_SHIFT' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.blue_backend_ips = attributes[:'blueBackendIps'] if attributes[:'blueBackendIps'] raise 'You cannot provide both :blueBackendIps and :blue_backend_ips' if attributes.key?(:'blueBackendIps') && attributes.key?(:'blue_backend_ips') self.blue_backend_ips = attributes[:'blue_backend_ips'] if attributes[:'blue_backend_ips'] self.green_backend_ips = attributes[:'greenBackendIps'] if attributes[:'greenBackendIps'] raise 'You cannot provide both :greenBackendIps and :green_backend_ips' if attributes.key?(:'greenBackendIps') && attributes.key?(:'green_backend_ips') self.green_backend_ips = attributes[:'green_backend_ips'] if attributes[:'green_backend_ips'] self.traffic_shift_target = attributes[:'trafficShiftTarget'] if attributes[:'trafficShiftTarget'] raise 'You cannot provide both :trafficShiftTarget and :traffic_shift_target' if attributes.key?(:'trafficShiftTarget') && attributes.key?(:'traffic_shift_target') self.traffic_shift_target = attributes[:'traffic_shift_target'] if attributes[:'traffic_shift_target'] self.rollout_policy = attributes[:'rolloutPolicy'] if attributes[:'rolloutPolicy'] raise 'You cannot provide both :rolloutPolicy and :rollout_policy' if attributes.key?(:'rolloutPolicy') && attributes.key?(:'rollout_policy') self.rollout_policy = attributes[:'rollout_policy'] if attributes[:'rollout_policy'] self.load_balancer_config = attributes[:'loadBalancerConfig'] if attributes[:'loadBalancerConfig'] raise 'You cannot provide both :loadBalancerConfig and :load_balancer_config' if attributes.key?(:'loadBalancerConfig') && attributes.key?(:'load_balancer_config') self.load_balancer_config = attributes[:'load_balancer_config'] if attributes[:'load_balancer_config'] self.rollback_policy = attributes[:'rollbackPolicy'] if attributes[:'rollbackPolicy'] raise 'You cannot provide both :rollbackPolicy and :rollback_policy' if attributes.key?(:'rollbackPolicy') && attributes.key?(:'rollback_policy') self.rollback_policy = attributes[:'rollback_policy'] if attributes[:'rollback_policy'] end |
Instance Attribute Details
#blue_backend_ips ⇒ OCI::Devops::Models::BackendSetIpCollection
This attribute is required.
13 14 15 |
# File 'lib/oci/devops/models/load_balancer_traffic_shift_deploy_stage_summary.rb', line 13 def blue_backend_ips @blue_backend_ips end |
#green_backend_ips ⇒ OCI::Devops::Models::BackendSetIpCollection
This attribute is required.
17 18 19 |
# File 'lib/oci/devops/models/load_balancer_traffic_shift_deploy_stage_summary.rb', line 17 def green_backend_ips @green_backend_ips end |
#load_balancer_config ⇒ OCI::Devops::Models::LoadBalancerConfig
This attribute is required.
29 30 31 |
# File 'lib/oci/devops/models/load_balancer_traffic_shift_deploy_stage_summary.rb', line 29 def load_balancer_config @load_balancer_config end |
#rollback_policy ⇒ OCI::Devops::Models::DeployStageRollbackPolicy
32 33 34 |
# File 'lib/oci/devops/models/load_balancer_traffic_shift_deploy_stage_summary.rb', line 32 def rollback_policy @rollback_policy end |
#rollout_policy ⇒ OCI::Devops::Models::LoadBalancerTrafficShiftRolloutPolicy
This attribute is required.
25 26 27 |
# File 'lib/oci/devops/models/load_balancer_traffic_shift_deploy_stage_summary.rb', line 25 def rollout_policy @rollout_policy end |
#traffic_shift_target ⇒ String
[Required] Specifies the target or destination backend set.
21 22 23 |
# File 'lib/oci/devops/models/load_balancer_traffic_shift_deploy_stage_summary.rb', line 21 def traffic_shift_target @traffic_shift_target end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/oci/devops/models/load_balancer_traffic_shift_deploy_stage_summary.rb', line 35 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'description': :'description', 'display_name': :'displayName', 'project_id': :'projectId', 'deploy_pipeline_id': :'deployPipelineId', 'compartment_id': :'compartmentId', 'deploy_stage_type': :'deployStageType', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'deploy_stage_predecessor_collection': :'deployStagePredecessorCollection', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags', 'blue_backend_ips': :'blueBackendIps', 'green_backend_ips': :'greenBackendIps', 'traffic_shift_target': :'trafficShiftTarget', 'rollout_policy': :'rolloutPolicy', 'load_balancer_config': :'loadBalancerConfig', 'rollback_policy': :'rollbackPolicy' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/oci/devops/models/load_balancer_traffic_shift_deploy_stage_summary.rb', line 64 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'description': :'String', 'display_name': :'String', 'project_id': :'String', 'deploy_pipeline_id': :'String', 'compartment_id': :'String', 'deploy_stage_type': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'deploy_stage_predecessor_collection': :'OCI::Devops::Models::DeployStagePredecessorCollection', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>', 'blue_backend_ips': :'OCI::Devops::Models::BackendSetIpCollection', 'green_backend_ips': :'OCI::Devops::Models::BackendSetIpCollection', 'traffic_shift_target': :'String', 'rollout_policy': :'OCI::Devops::Models::LoadBalancerTrafficShiftRolloutPolicy', 'load_balancer_config': :'OCI::Devops::Models::LoadBalancerConfig', 'rollback_policy': :'OCI::Devops::Models::DeployStageRollbackPolicy' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/oci/devops/models/load_balancer_traffic_shift_deploy_stage_summary.rb', line 172 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && description == other.description && display_name == other.display_name && project_id == other.project_id && deploy_pipeline_id == other.deploy_pipeline_id && compartment_id == other.compartment_id && deploy_stage_type == other.deploy_stage_type && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && deploy_stage_predecessor_collection == other.deploy_stage_predecessor_collection && == other. && == other. && == other. && blue_backend_ips == other.blue_backend_ips && green_backend_ips == other.green_backend_ips && traffic_shift_target == other.traffic_shift_target && rollout_policy == other.rollout_policy && load_balancer_config == other.load_balancer_config && rollback_policy == other.rollback_policy end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/oci/devops/models/load_balancer_traffic_shift_deploy_stage_summary.rb', line 222 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
202 203 204 |
# File 'lib/oci/devops/models/load_balancer_traffic_shift_deploy_stage_summary.rb', line 202 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
211 212 213 |
# File 'lib/oci/devops/models/load_balancer_traffic_shift_deploy_stage_summary.rb', line 211 def hash [id, description, display_name, project_id, deploy_pipeline_id, compartment_id, deploy_stage_type, time_created, time_updated, lifecycle_state, lifecycle_details, deploy_stage_predecessor_collection, , , , blue_backend_ips, green_backend_ips, traffic_shift_target, rollout_policy, load_balancer_config, rollback_policy].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
255 256 257 258 259 260 261 262 263 264 |
# File 'lib/oci/devops/models/load_balancer_traffic_shift_deploy_stage_summary.rb', line 255 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
249 250 251 |
# File 'lib/oci/devops/models/load_balancer_traffic_shift_deploy_stage_summary.rb', line 249 def to_s to_hash.to_s end |