Class: OCI::Devops::Models::ManualApprovalDeployStageExecutionProgress
- Inherits:
-
DeployStageExecutionProgress
- Object
- DeployStageExecutionProgress
- OCI::Devops::Models::ManualApprovalDeployStageExecutionProgress
- Defined in:
- lib/oci/devops/models/manual_approval_deploy_stage_execution_progress.rb
Overview
Specifies the manual approval stage specific execution details.
Constant Summary
Constants inherited from DeployStageExecutionProgress
DeployStageExecutionProgress::STATUS_ENUM
Instance Attribute Summary collapse
Attributes inherited from DeployStageExecutionProgress
#deploy_stage_display_name, #deploy_stage_execution_progress_details, #deploy_stage_id, #deploy_stage_predecessors, #deploy_stage_type, #status, #time_finished, #time_started
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ManualApprovalDeployStageExecutionProgress
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from DeployStageExecutionProgress
Constructor Details
#initialize(attributes = {}) ⇒ ManualApprovalDeployStageExecutionProgress
Initializes the object
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/oci/devops/models/manual_approval_deploy_stage_execution_progress.rb', line 62 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['deployStageType'] = 'MANUAL_APPROVAL' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.approval_actions = attributes[:'approvalActions'] if attributes[:'approvalActions'] raise 'You cannot provide both :approvalActions and :approval_actions' if attributes.key?(:'approvalActions') && attributes.key?(:'approval_actions') self.approval_actions = attributes[:'approval_actions'] if attributes[:'approval_actions'] end |
Instance Attribute Details
#approval_actions ⇒ Array<OCI::Devops::Models::ApprovalAction>
12 13 14 |
# File 'lib/oci/devops/models/manual_approval_deploy_stage_execution_progress.rb', line 12 def approval_actions @approval_actions end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 |
# File 'lib/oci/devops/models/manual_approval_deploy_stage_execution_progress.rb', line 15 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'deploy_stage_display_name': :'deployStageDisplayName', 'deploy_stage_type': :'deployStageType', 'deploy_stage_id': :'deployStageId', 'time_started': :'timeStarted', 'time_finished': :'timeFinished', 'status': :'status', 'deploy_stage_predecessors': :'deployStagePredecessors', 'deploy_stage_execution_progress_details': :'deployStageExecutionProgressDetails', 'approval_actions': :'approvalActions' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/oci/devops/models/manual_approval_deploy_stage_execution_progress.rb', line 32 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'deploy_stage_display_name': :'String', 'deploy_stage_type': :'String', 'deploy_stage_id': :'String', 'time_started': :'DateTime', 'time_finished': :'DateTime', 'status': :'String', 'deploy_stage_predecessors': :'OCI::Devops::Models::DeployStagePredecessorCollection', 'deploy_stage_execution_progress_details': :'Array<OCI::Devops::Models::DeployStageExecutionProgressDetails>', 'approval_actions': :'Array<OCI::Devops::Models::ApprovalAction>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/oci/devops/models/manual_approval_deploy_stage_execution_progress.rb', line 86 def ==(other) return true if equal?(other) self.class == other.class && deploy_stage_display_name == other.deploy_stage_display_name && deploy_stage_type == other.deploy_stage_type && deploy_stage_id == other.deploy_stage_id && time_started == other.time_started && time_finished == other.time_finished && status == other.status && deploy_stage_predecessors == other.deploy_stage_predecessors && deploy_stage_execution_progress_details == other.deploy_stage_execution_progress_details && approval_actions == other.approval_actions end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/oci/devops/models/manual_approval_deploy_stage_execution_progress.rb', line 124 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
104 105 106 |
# File 'lib/oci/devops/models/manual_approval_deploy_stage_execution_progress.rb', line 104 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
113 114 115 |
# File 'lib/oci/devops/models/manual_approval_deploy_stage_execution_progress.rb', line 113 def hash [deploy_stage_display_name, deploy_stage_type, deploy_stage_id, time_started, time_finished, status, deploy_stage_predecessors, deploy_stage_execution_progress_details, approval_actions].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
157 158 159 160 161 162 163 164 165 166 |
# File 'lib/oci/devops/models/manual_approval_deploy_stage_execution_progress.rb', line 157 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
151 152 153 |
# File 'lib/oci/devops/models/manual_approval_deploy_stage_execution_progress.rb', line 151 def to_s to_hash.to_s end |