Class: OCI::Devops::Models::OkeCanaryDeployStageSummary

Inherits:
DeployStageSummary show all
Defined in:
lib/oci/devops/models/oke_canary_deploy_stage_summary.rb

Overview

Specifies the Container Engine for Kubernetes (OKE) cluster Canary deployment stage.

Instance Attribute Summary collapse

Attributes inherited from DeployStageSummary

#compartment_id, #defined_tags, #deploy_pipeline_id, #deploy_stage_predecessor_collection, #deploy_stage_type, #description, #display_name, #freeform_tags, #id, #lifecycle_details, #lifecycle_state, #project_id, #system_tags, #time_created, #time_updated

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from DeployStageSummary

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ OkeCanaryDeployStageSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/oci/devops/models/oke_canary_deploy_stage_summary.rb', line 98

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['deployStageType'] = 'OKE_CANARY_DEPLOYMENT'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.oke_cluster_deploy_environment_id = attributes[:'okeClusterDeployEnvironmentId'] if attributes[:'okeClusterDeployEnvironmentId']

  raise 'You cannot provide both :okeClusterDeployEnvironmentId and :oke_cluster_deploy_environment_id' if attributes.key?(:'okeClusterDeployEnvironmentId') && attributes.key?(:'oke_cluster_deploy_environment_id')

  self.oke_cluster_deploy_environment_id = attributes[:'oke_cluster_deploy_environment_id'] if attributes[:'oke_cluster_deploy_environment_id']

  self.kubernetes_manifest_deploy_artifact_ids = attributes[:'kubernetesManifestDeployArtifactIds'] if attributes[:'kubernetesManifestDeployArtifactIds']

  raise 'You cannot provide both :kubernetesManifestDeployArtifactIds and :kubernetes_manifest_deploy_artifact_ids' if attributes.key?(:'kubernetesManifestDeployArtifactIds') && attributes.key?(:'kubernetes_manifest_deploy_artifact_ids')

  self.kubernetes_manifest_deploy_artifact_ids = attributes[:'kubernetes_manifest_deploy_artifact_ids'] if attributes[:'kubernetes_manifest_deploy_artifact_ids']

  self.canary_strategy = attributes[:'canaryStrategy'] if attributes[:'canaryStrategy']

  raise 'You cannot provide both :canaryStrategy and :canary_strategy' if attributes.key?(:'canaryStrategy') && attributes.key?(:'canary_strategy')

  self.canary_strategy = attributes[:'canary_strategy'] if attributes[:'canary_strategy']
end

Instance Attribute Details

#canary_strategyOCI::Devops::Models::OkeCanaryStrategy

This attribute is required.



21
22
23
# File 'lib/oci/devops/models/oke_canary_deploy_stage_summary.rb', line 21

def canary_strategy
  @canary_strategy
end

#kubernetes_manifest_deploy_artifact_idsArray<String>

**[Required]** List of Kubernetes manifest artifact OCIDs.

Returns:

  • (Array<String>)


17
18
19
# File 'lib/oci/devops/models/oke_canary_deploy_stage_summary.rb', line 17

def kubernetes_manifest_deploy_artifact_ids
  @kubernetes_manifest_deploy_artifact_ids
end

#oke_cluster_deploy_environment_idString

**[Required]** Kubernetes cluster environment OCID for deployment.

Returns:

  • (String)


13
14
15
# File 'lib/oci/devops/models/oke_canary_deploy_stage_summary.rb', line 13

def oke_cluster_deploy_environment_id
  @oke_cluster_deploy_environment_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
# File 'lib/oci/devops/models/oke_canary_deploy_stage_summary.rb', line 24

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'description': :'description',
    'display_name': :'displayName',
    'project_id': :'projectId',
    'deploy_pipeline_id': :'deployPipelineId',
    'compartment_id': :'compartmentId',
    'deploy_stage_type': :'deployStageType',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'deploy_stage_predecessor_collection': :'deployStagePredecessorCollection',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags',
    'oke_cluster_deploy_environment_id': :'okeClusterDeployEnvironmentId',
    'kubernetes_manifest_deploy_artifact_ids': :'kubernetesManifestDeployArtifactIds',
    'canary_strategy': :'canaryStrategy'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/oci/devops/models/oke_canary_deploy_stage_summary.rb', line 50

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'description': :'String',
    'display_name': :'String',
    'project_id': :'String',
    'deploy_pipeline_id': :'String',
    'compartment_id': :'String',
    'deploy_stage_type': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'deploy_stage_predecessor_collection': :'OCI::Devops::Models::DeployStagePredecessorCollection',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>',
    'oke_cluster_deploy_environment_id': :'String',
    'kubernetes_manifest_deploy_artifact_ids': :'Array<String>',
    'canary_strategy': :'OCI::Devops::Models::OkeCanaryStrategy'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/oci/devops/models/oke_canary_deploy_stage_summary.rb', line 134

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    description == other.description &&
    display_name == other.display_name &&
    project_id == other.project_id &&
    deploy_pipeline_id == other.deploy_pipeline_id &&
    compartment_id == other.compartment_id &&
    deploy_stage_type == other.deploy_stage_type &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    deploy_stage_predecessor_collection == other.deploy_stage_predecessor_collection &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags &&
    oke_cluster_deploy_environment_id == other.oke_cluster_deploy_environment_id &&
    kubernetes_manifest_deploy_artifact_ids == other.kubernetes_manifest_deploy_artifact_ids &&
    canary_strategy == other.canary_strategy
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/oci/devops/models/oke_canary_deploy_stage_summary.rb', line 181

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


161
162
163
# File 'lib/oci/devops/models/oke_canary_deploy_stage_summary.rb', line 161

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



170
171
172
# File 'lib/oci/devops/models/oke_canary_deploy_stage_summary.rb', line 170

def hash
  [id, description, display_name, project_id, deploy_pipeline_id, compartment_id, deploy_stage_type, time_created, time_updated, lifecycle_state, lifecycle_details, deploy_stage_predecessor_collection, freeform_tags, defined_tags, system_tags, oke_cluster_deploy_environment_id, kubernetes_manifest_deploy_artifact_ids, canary_strategy].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



214
215
216
217
218
219
220
221
222
223
# File 'lib/oci/devops/models/oke_canary_deploy_stage_summary.rb', line 214

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



208
209
210
# File 'lib/oci/devops/models/oke_canary_deploy_stage_summary.rb', line 208

def to_s
  to_hash.to_s
end