Class: OCI::Devops::Models::OkeHelmChartDeployStageSummary
- Inherits:
-
DeployStageSummary
- Object
- DeployStageSummary
- OCI::Devops::Models::OkeHelmChartDeployStageSummary
- Defined in:
- lib/oci/devops/models/oke_helm_chart_deploy_stage_summary.rb
Overview
Specifies the OKE cluster deployment stage using Helm charts.
Instance Attribute Summary collapse
-
#helm_chart_deploy_artifact_id ⇒ String
**[Required]** Helm chart artifact OCID.
-
#namespace ⇒ String
Default namespace to be used for Kubernetes deployment when not specified in the manifest.
-
#oke_cluster_deploy_environment_id ⇒ String
**[Required]** Kubernetes cluster environment OCID for deployment.
-
#release_name ⇒ String
**[Required]** Release name of the Helm chart.
- #rollback_policy ⇒ OCI::Devops::Models::DeployStageRollbackPolicy
-
#timeout_in_seconds ⇒ Integer
Time to wait for execution of a helm stage.
-
#values_artifact_ids ⇒ Array<String>
List of values.yaml file artifact OCIDs.
Attributes inherited from DeployStageSummary
#compartment_id, #defined_tags, #deploy_pipeline_id, #deploy_stage_predecessor_collection, #deploy_stage_type, #description, #display_name, #freeform_tags, #id, #lifecycle_details, #lifecycle_state, #project_id, #system_tags, #time_created, #time_updated
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OkeHelmChartDeployStageSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from DeployStageSummary
Constructor Details
#initialize(attributes = {}) ⇒ OkeHelmChartDeployStageSummary
Initializes the object
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/oci/devops/models/oke_helm_chart_deploy_stage_summary.rb', line 125 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['deployStageType'] = 'OKE_HELM_CHART_DEPLOYMENT' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.oke_cluster_deploy_environment_id = attributes[:'okeClusterDeployEnvironmentId'] if attributes[:'okeClusterDeployEnvironmentId'] raise 'You cannot provide both :okeClusterDeployEnvironmentId and :oke_cluster_deploy_environment_id' if attributes.key?(:'okeClusterDeployEnvironmentId') && attributes.key?(:'oke_cluster_deploy_environment_id') self.oke_cluster_deploy_environment_id = attributes[:'oke_cluster_deploy_environment_id'] if attributes[:'oke_cluster_deploy_environment_id'] self.helm_chart_deploy_artifact_id = attributes[:'helmChartDeployArtifactId'] if attributes[:'helmChartDeployArtifactId'] raise 'You cannot provide both :helmChartDeployArtifactId and :helm_chart_deploy_artifact_id' if attributes.key?(:'helmChartDeployArtifactId') && attributes.key?(:'helm_chart_deploy_artifact_id') self.helm_chart_deploy_artifact_id = attributes[:'helm_chart_deploy_artifact_id'] if attributes[:'helm_chart_deploy_artifact_id'] self.values_artifact_ids = attributes[:'valuesArtifactIds'] if attributes[:'valuesArtifactIds'] raise 'You cannot provide both :valuesArtifactIds and :values_artifact_ids' if attributes.key?(:'valuesArtifactIds') && attributes.key?(:'values_artifact_ids') self.values_artifact_ids = attributes[:'values_artifact_ids'] if attributes[:'values_artifact_ids'] self.release_name = attributes[:'releaseName'] if attributes[:'releaseName'] raise 'You cannot provide both :releaseName and :release_name' if attributes.key?(:'releaseName') && attributes.key?(:'release_name') self.release_name = attributes[:'release_name'] if attributes[:'release_name'] self.namespace = attributes[:'namespace'] if attributes[:'namespace'] self.namespace = "default" if namespace.nil? && !attributes.key?(:'namespace') # rubocop:disable Style/StringLiterals self.timeout_in_seconds = attributes[:'timeoutInSeconds'] if attributes[:'timeoutInSeconds'] raise 'You cannot provide both :timeoutInSeconds and :timeout_in_seconds' if attributes.key?(:'timeoutInSeconds') && attributes.key?(:'timeout_in_seconds') self.timeout_in_seconds = attributes[:'timeout_in_seconds'] if attributes[:'timeout_in_seconds'] self.rollback_policy = attributes[:'rollbackPolicy'] if attributes[:'rollbackPolicy'] raise 'You cannot provide both :rollbackPolicy and :rollback_policy' if attributes.key?(:'rollbackPolicy') && attributes.key?(:'rollback_policy') self.rollback_policy = attributes[:'rollback_policy'] if attributes[:'rollback_policy'] end |
Instance Attribute Details
#helm_chart_deploy_artifact_id ⇒ String
**[Required]** Helm chart artifact OCID.
17 18 19 |
# File 'lib/oci/devops/models/oke_helm_chart_deploy_stage_summary.rb', line 17 def helm_chart_deploy_artifact_id @helm_chart_deploy_artifact_id end |
#namespace ⇒ String
Default namespace to be used for Kubernetes deployment when not specified in the manifest.
29 30 31 |
# File 'lib/oci/devops/models/oke_helm_chart_deploy_stage_summary.rb', line 29 def namespace @namespace end |
#oke_cluster_deploy_environment_id ⇒ String
**[Required]** Kubernetes cluster environment OCID for deployment.
13 14 15 |
# File 'lib/oci/devops/models/oke_helm_chart_deploy_stage_summary.rb', line 13 def oke_cluster_deploy_environment_id @oke_cluster_deploy_environment_id end |
#release_name ⇒ String
**[Required]** Release name of the Helm chart.
25 26 27 |
# File 'lib/oci/devops/models/oke_helm_chart_deploy_stage_summary.rb', line 25 def release_name @release_name end |
#rollback_policy ⇒ OCI::Devops::Models::DeployStageRollbackPolicy
36 37 38 |
# File 'lib/oci/devops/models/oke_helm_chart_deploy_stage_summary.rb', line 36 def rollback_policy @rollback_policy end |
#timeout_in_seconds ⇒ Integer
Time to wait for execution of a helm stage. Defaults to 300 seconds.
33 34 35 |
# File 'lib/oci/devops/models/oke_helm_chart_deploy_stage_summary.rb', line 33 def timeout_in_seconds @timeout_in_seconds end |
#values_artifact_ids ⇒ Array<String>
List of values.yaml file artifact OCIDs.
21 22 23 |
# File 'lib/oci/devops/models/oke_helm_chart_deploy_stage_summary.rb', line 21 def values_artifact_ids @values_artifact_ids end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/oci/devops/models/oke_helm_chart_deploy_stage_summary.rb', line 39 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'description': :'description', 'display_name': :'displayName', 'project_id': :'projectId', 'deploy_pipeline_id': :'deployPipelineId', 'compartment_id': :'compartmentId', 'deploy_stage_type': :'deployStageType', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'deploy_stage_predecessor_collection': :'deployStagePredecessorCollection', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags', 'oke_cluster_deploy_environment_id': :'okeClusterDeployEnvironmentId', 'helm_chart_deploy_artifact_id': :'helmChartDeployArtifactId', 'values_artifact_ids': :'valuesArtifactIds', 'release_name': :'releaseName', 'namespace': :'namespace', 'timeout_in_seconds': :'timeoutInSeconds', 'rollback_policy': :'rollbackPolicy' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/oci/devops/models/oke_helm_chart_deploy_stage_summary.rb', line 69 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'description': :'String', 'display_name': :'String', 'project_id': :'String', 'deploy_pipeline_id': :'String', 'compartment_id': :'String', 'deploy_stage_type': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'deploy_stage_predecessor_collection': :'OCI::Devops::Models::DeployStagePredecessorCollection', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>', 'oke_cluster_deploy_environment_id': :'String', 'helm_chart_deploy_artifact_id': :'String', 'values_artifact_ids': :'Array<String>', 'release_name': :'String', 'namespace': :'String', 'timeout_in_seconds': :'Integer', 'rollback_policy': :'OCI::Devops::Models::DeployStageRollbackPolicy' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/oci/devops/models/oke_helm_chart_deploy_stage_summary.rb', line 182 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && description == other.description && display_name == other.display_name && project_id == other.project_id && deploy_pipeline_id == other.deploy_pipeline_id && compartment_id == other.compartment_id && deploy_stage_type == other.deploy_stage_type && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && deploy_stage_predecessor_collection == other.deploy_stage_predecessor_collection && == other. && == other. && == other. && oke_cluster_deploy_environment_id == other.oke_cluster_deploy_environment_id && helm_chart_deploy_artifact_id == other.helm_chart_deploy_artifact_id && values_artifact_ids == other.values_artifact_ids && release_name == other.release_name && namespace == other.namespace && timeout_in_seconds == other.timeout_in_seconds && rollback_policy == other.rollback_policy end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/oci/devops/models/oke_helm_chart_deploy_stage_summary.rb', line 233 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
213 214 215 |
# File 'lib/oci/devops/models/oke_helm_chart_deploy_stage_summary.rb', line 213 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
222 223 224 |
# File 'lib/oci/devops/models/oke_helm_chart_deploy_stage_summary.rb', line 222 def hash [id, description, display_name, project_id, deploy_pipeline_id, compartment_id, deploy_stage_type, time_created, time_updated, lifecycle_state, lifecycle_details, deploy_stage_predecessor_collection, , , , oke_cluster_deploy_environment_id, helm_chart_deploy_artifact_id, values_artifact_ids, release_name, namespace, timeout_in_seconds, rollback_policy].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
266 267 268 269 270 271 272 273 274 275 |
# File 'lib/oci/devops/models/oke_helm_chart_deploy_stage_summary.rb', line 266 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
260 261 262 |
# File 'lib/oci/devops/models/oke_helm_chart_deploy_stage_summary.rb', line 260 def to_s to_hash.to_s end |