Class: OCI::Devops::Models::OkeHelmChartDeploymentStageExecutionProgress
- Inherits:
-
DeployStageExecutionProgress
- Object
- DeployStageExecutionProgress
- OCI::Devops::Models::OkeHelmChartDeploymentStageExecutionProgress
- Defined in:
- lib/oci/devops/models/oke_helm_chart_deployment_stage_execution_progress.rb
Overview
Specifies the execution details for Kubernetes (OKE) helm chart deployment stage.
Constant Summary
Constants inherited from DeployStageExecutionProgress
DeployStageExecutionProgress::STATUS_ENUM
Instance Attribute Summary collapse
-
#chart_url ⇒ String
The URL of an OCIR repository.
-
#namespace ⇒ String
Default namespace to be used for Kubernetes deployment when not specified in the manifest.
-
#release_name ⇒ String
Release name of the Helm chart.
-
#version ⇒ String
The version of the helm chart stored in OCIR repository.
Attributes inherited from DeployStageExecutionProgress
#deploy_stage_display_name, #deploy_stage_execution_progress_details, #deploy_stage_id, #deploy_stage_predecessors, #deploy_stage_type, #status, #time_finished, #time_started
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OkeHelmChartDeploymentStageExecutionProgress
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from DeployStageExecutionProgress
Constructor Details
#initialize(attributes = {}) ⇒ OkeHelmChartDeploymentStageExecutionProgress
Initializes the object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/oci/devops/models/oke_helm_chart_deployment_stage_execution_progress.rb', line 84 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['deployStageType'] = 'OKE_HELM_CHART_DEPLOYMENT' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.release_name = attributes[:'releaseName'] if attributes[:'releaseName'] raise 'You cannot provide both :releaseName and :release_name' if attributes.key?(:'releaseName') && attributes.key?(:'release_name') self.release_name = attributes[:'release_name'] if attributes[:'release_name'] self.chart_url = attributes[:'chartUrl'] if attributes[:'chartUrl'] raise 'You cannot provide both :chartUrl and :chart_url' if attributes.key?(:'chartUrl') && attributes.key?(:'chart_url') self.chart_url = attributes[:'chart_url'] if attributes[:'chart_url'] self.version = attributes[:'version'] if attributes[:'version'] self.namespace = attributes[:'namespace'] if attributes[:'namespace'] self.namespace = "default" if namespace.nil? && !attributes.key?(:'namespace') # rubocop:disable Style/StringLiterals end |
Instance Attribute Details
#chart_url ⇒ String
The URL of an OCIR repository.
17 18 19 |
# File 'lib/oci/devops/models/oke_helm_chart_deployment_stage_execution_progress.rb', line 17 def chart_url @chart_url end |
#namespace ⇒ String
Default namespace to be used for Kubernetes deployment when not specified in the manifest.
25 26 27 |
# File 'lib/oci/devops/models/oke_helm_chart_deployment_stage_execution_progress.rb', line 25 def namespace @namespace end |
#release_name ⇒ String
Release name of the Helm chart.
13 14 15 |
# File 'lib/oci/devops/models/oke_helm_chart_deployment_stage_execution_progress.rb', line 13 def release_name @release_name end |
#version ⇒ String
The version of the helm chart stored in OCIR repository.
21 22 23 |
# File 'lib/oci/devops/models/oke_helm_chart_deployment_stage_execution_progress.rb', line 21 def version @version end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 |
# File 'lib/oci/devops/models/oke_helm_chart_deployment_stage_execution_progress.rb', line 28 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'deploy_stage_display_name': :'deployStageDisplayName', 'deploy_stage_type': :'deployStageType', 'deploy_stage_id': :'deployStageId', 'time_started': :'timeStarted', 'time_finished': :'timeFinished', 'status': :'status', 'deploy_stage_predecessors': :'deployStagePredecessors', 'deploy_stage_execution_progress_details': :'deployStageExecutionProgressDetails', 'release_name': :'releaseName', 'chart_url': :'chartUrl', 'version': :'version', 'namespace': :'namespace' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/oci/devops/models/oke_helm_chart_deployment_stage_execution_progress.rb', line 48 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'deploy_stage_display_name': :'String', 'deploy_stage_type': :'String', 'deploy_stage_id': :'String', 'time_started': :'DateTime', 'time_finished': :'DateTime', 'status': :'String', 'deploy_stage_predecessors': :'OCI::Devops::Models::DeployStagePredecessorCollection', 'deploy_stage_execution_progress_details': :'Array<OCI::Devops::Models::DeployStageExecutionProgressDetails>', 'release_name': :'String', 'chart_url': :'String', 'version': :'String', 'namespace': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/oci/devops/models/oke_helm_chart_deployment_stage_execution_progress.rb', line 119 def ==(other) return true if equal?(other) self.class == other.class && deploy_stage_display_name == other.deploy_stage_display_name && deploy_stage_type == other.deploy_stage_type && deploy_stage_id == other.deploy_stage_id && time_started == other.time_started && time_finished == other.time_finished && status == other.status && deploy_stage_predecessors == other.deploy_stage_predecessors && deploy_stage_execution_progress_details == other.deploy_stage_execution_progress_details && release_name == other.release_name && chart_url == other.chart_url && version == other.version && namespace == other.namespace end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/oci/devops/models/oke_helm_chart_deployment_stage_execution_progress.rb', line 160 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
140 141 142 |
# File 'lib/oci/devops/models/oke_helm_chart_deployment_stage_execution_progress.rb', line 140 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
149 150 151 |
# File 'lib/oci/devops/models/oke_helm_chart_deployment_stage_execution_progress.rb', line 149 def hash [deploy_stage_display_name, deploy_stage_type, deploy_stage_id, time_started, time_finished, status, deploy_stage_predecessors, deploy_stage_execution_progress_details, release_name, chart_url, version, namespace].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
193 194 195 196 197 198 199 200 201 202 |
# File 'lib/oci/devops/models/oke_helm_chart_deployment_stage_execution_progress.rb', line 193 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
187 188 189 |
# File 'lib/oci/devops/models/oke_helm_chart_deployment_stage_execution_progress.rb', line 187 def to_s to_hash.to_s end |