Class: OCI::Devops::Models::RepositoryMirrorRecordSummary
- Inherits:
-
Object
- Object
- OCI::Devops::Models::RepositoryMirrorRecordSummary
- Defined in:
- lib/oci/devops/models/repository_mirror_record_summary.rb
Overview
Object containing information about a mirror record.
Constant Summary collapse
- MIRROR_STATUS_ENUM =
[ MIRROR_STATUS_NONE = 'NONE'.freeze, MIRROR_STATUS_QUEUED = 'QUEUED'.freeze, MIRROR_STATUS_RUNNING = 'RUNNING'.freeze, MIRROR_STATUS_PASSED = 'PASSED'.freeze, MIRROR_STATUS_FAILED = 'FAILED'.freeze, MIRROR_STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#mirror_status ⇒ String
[Required] Mirror status of current mirror entry.
-
#time_completed ⇒ DateTime
The time to complete a mirror operation.
-
#time_enqueued ⇒ DateTime
The time to enqueue a mirror operation.
-
#time_started ⇒ DateTime
The time to start a mirror operation.
-
#work_request_id ⇒ String
Workrequest ID to track current mirror operation.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RepositoryMirrorRecordSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ RepositoryMirrorRecordSummary
Initializes the object
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/oci/devops/models/repository_mirror_record_summary.rb', line 96 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.mirror_status = attributes[:'mirrorStatus'] if attributes[:'mirrorStatus'] raise 'You cannot provide both :mirrorStatus and :mirror_status' if attributes.key?(:'mirrorStatus') && attributes.key?(:'mirror_status') self.mirror_status = attributes[:'mirror_status'] if attributes[:'mirror_status'] self.work_request_id = attributes[:'workRequestId'] if attributes[:'workRequestId'] raise 'You cannot provide both :workRequestId and :work_request_id' if attributes.key?(:'workRequestId') && attributes.key?(:'work_request_id') self.work_request_id = attributes[:'work_request_id'] if attributes[:'work_request_id'] self.time_enqueued = attributes[:'timeEnqueued'] if attributes[:'timeEnqueued'] raise 'You cannot provide both :timeEnqueued and :time_enqueued' if attributes.key?(:'timeEnqueued') && attributes.key?(:'time_enqueued') self.time_enqueued = attributes[:'time_enqueued'] if attributes[:'time_enqueued'] self.time_started = attributes[:'timeStarted'] if attributes[:'timeStarted'] raise 'You cannot provide both :timeStarted and :time_started' if attributes.key?(:'timeStarted') && attributes.key?(:'time_started') self.time_started = attributes[:'time_started'] if attributes[:'time_started'] self.time_completed = attributes[:'timeCompleted'] if attributes[:'timeCompleted'] raise 'You cannot provide both :timeCompleted and :time_completed' if attributes.key?(:'timeCompleted') && attributes.key?(:'time_completed') self.time_completed = attributes[:'time_completed'] if attributes[:'time_completed'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"bar-key": "value"}`
51 52 53 |
# File 'lib/oci/devops/models/repository_mirror_record_summary.rb', line 51 def end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"value"`
47 48 49 |
# File 'lib/oci/devops/models/repository_mirror_record_summary.rb', line 47 def end |
#mirror_status ⇒ String
[Required] Mirror status of current mirror entry. QUEUED - Mirroring Queued RUNNING - Mirroring is Running PASSED - Mirroring Passed FAILED - Mirroring Failed
27 28 29 |
# File 'lib/oci/devops/models/repository_mirror_record_summary.rb', line 27 def mirror_status @mirror_status end |
#time_completed ⇒ DateTime
The time to complete a mirror operation.
43 44 45 |
# File 'lib/oci/devops/models/repository_mirror_record_summary.rb', line 43 def time_completed @time_completed end |
#time_enqueued ⇒ DateTime
The time to enqueue a mirror operation.
35 36 37 |
# File 'lib/oci/devops/models/repository_mirror_record_summary.rb', line 35 def time_enqueued @time_enqueued end |
#time_started ⇒ DateTime
The time to start a mirror operation.
39 40 41 |
# File 'lib/oci/devops/models/repository_mirror_record_summary.rb', line 39 def time_started @time_started end |
#work_request_id ⇒ String
Workrequest ID to track current mirror operation.
31 32 33 |
# File 'lib/oci/devops/models/repository_mirror_record_summary.rb', line 31 def work_request_id @work_request_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/oci/devops/models/repository_mirror_record_summary.rb', line 54 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'mirror_status': :'mirrorStatus', 'work_request_id': :'workRequestId', 'time_enqueued': :'timeEnqueued', 'time_started': :'timeStarted', 'time_completed': :'timeCompleted', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/oci/devops/models/repository_mirror_record_summary.rb', line 69 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'mirror_status': :'String', 'work_request_id': :'String', 'time_enqueued': :'DateTime', 'time_started': :'DateTime', 'time_completed': :'DateTime', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/oci/devops/models/repository_mirror_record_summary.rb', line 165 def ==(other) return true if equal?(other) self.class == other.class && mirror_status == other.mirror_status && work_request_id == other.work_request_id && time_enqueued == other.time_enqueued && time_started == other.time_started && time_completed == other.time_completed && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/oci/devops/models/repository_mirror_record_summary.rb', line 201 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
181 182 183 |
# File 'lib/oci/devops/models/repository_mirror_record_summary.rb', line 181 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
190 191 192 |
# File 'lib/oci/devops/models/repository_mirror_record_summary.rb', line 190 def hash [mirror_status, work_request_id, time_enqueued, time_started, time_completed, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
234 235 236 237 238 239 240 241 242 243 |
# File 'lib/oci/devops/models/repository_mirror_record_summary.rb', line 234 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
228 229 230 |
# File 'lib/oci/devops/models/repository_mirror_record_summary.rb', line 228 def to_s to_hash.to_s end |