Class: OCI::Devops::Models::RepositoryPathSummary
- Inherits:
-
Object
- Object
- OCI::Devops::Models::RepositoryPathSummary
- Defined in:
- lib/oci/devops/models/repository_path_summary.rb
Overview
Object containing information about files and directories in a repository.
Instance Attribute Summary collapse
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#name ⇒ String
Name of file or directory.
-
#path ⇒ String
Path to file or directory in a repository.
-
#sha ⇒ String
SHA-1 checksum of blob or tree.
-
#size_in_bytes ⇒ Integer
Size of file or directory.
-
#submodule_git_url ⇒ String
The git URL of the submodule.
-
#type ⇒ String
File or directory.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RepositoryPathSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ RepositoryPathSummary
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/oci/devops/models/repository_path_summary.rb', line 88 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.type = attributes[:'type'] if attributes[:'type'] self.size_in_bytes = attributes[:'sizeInBytes'] if attributes[:'sizeInBytes'] raise 'You cannot provide both :sizeInBytes and :size_in_bytes' if attributes.key?(:'sizeInBytes') && attributes.key?(:'size_in_bytes') self.size_in_bytes = attributes[:'size_in_bytes'] if attributes[:'size_in_bytes'] self.name = attributes[:'name'] if attributes[:'name'] self.path = attributes[:'path'] if attributes[:'path'] self.sha = attributes[:'sha'] if attributes[:'sha'] self.submodule_git_url = attributes[:'submoduleGitUrl'] if attributes[:'submoduleGitUrl'] raise 'You cannot provide both :submoduleGitUrl and :submodule_git_url' if attributes.key?(:'submoduleGitUrl') && attributes.key?(:'submodule_git_url') self.submodule_git_url = attributes[:'submodule_git_url'] if attributes[:'submodule_git_url'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"bar-key": "value"}`
40 41 42 |
# File 'lib/oci/devops/models/repository_path_summary.rb', line 40 def end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"value"`
36 37 38 |
# File 'lib/oci/devops/models/repository_path_summary.rb', line 36 def end |
#name ⇒ String
Name of file or directory.
20 21 22 |
# File 'lib/oci/devops/models/repository_path_summary.rb', line 20 def name @name end |
#path ⇒ String
Path to file or directory in a repository.
24 25 26 |
# File 'lib/oci/devops/models/repository_path_summary.rb', line 24 def path @path end |
#sha ⇒ String
SHA-1 checksum of blob or tree.
28 29 30 |
# File 'lib/oci/devops/models/repository_path_summary.rb', line 28 def sha @sha end |
#size_in_bytes ⇒ Integer
Size of file or directory.
16 17 18 |
# File 'lib/oci/devops/models/repository_path_summary.rb', line 16 def size_in_bytes @size_in_bytes end |
#submodule_git_url ⇒ String
The git URL of the submodule.
32 33 34 |
# File 'lib/oci/devops/models/repository_path_summary.rb', line 32 def submodule_git_url @submodule_git_url end |
#type ⇒ String
File or directory.
12 13 14 |
# File 'lib/oci/devops/models/repository_path_summary.rb', line 12 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/oci/devops/models/repository_path_summary.rb', line 43 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'type': :'type', 'size_in_bytes': :'sizeInBytes', 'name': :'name', 'path': :'path', 'sha': :'sha', 'submodule_git_url': :'submoduleGitUrl', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/oci/devops/models/repository_path_summary.rb', line 59 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'type': :'String', 'size_in_bytes': :'Integer', 'name': :'String', 'path': :'String', 'sha': :'String', 'submodule_git_url': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/oci/devops/models/repository_path_summary.rb', line 134 def ==(other) return true if equal?(other) self.class == other.class && type == other.type && size_in_bytes == other.size_in_bytes && name == other.name && path == other.path && sha == other.sha && submodule_git_url == other.submodule_git_url && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/oci/devops/models/repository_path_summary.rb', line 171 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
151 152 153 |
# File 'lib/oci/devops/models/repository_path_summary.rb', line 151 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
160 161 162 |
# File 'lib/oci/devops/models/repository_path_summary.rb', line 160 def hash [type, size_in_bytes, name, path, sha, submodule_git_url, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
204 205 206 207 208 209 210 211 212 213 |
# File 'lib/oci/devops/models/repository_path_summary.rb', line 204 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
198 199 200 |
# File 'lib/oci/devops/models/repository_path_summary.rb', line 198 def to_s to_hash.to_s end |