Class: OCI::Devops::Models::RepositoryRef
- Inherits:
-
Object
- Object
- OCI::Devops::Models::RepositoryRef
- Defined in:
- lib/oci/devops/models/repository_ref.rb
Overview
Reference object with name and commit ID. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
Constant Summary collapse
- REF_TYPE_ENUM =
[ REF_TYPE_BRANCH = 'BRANCH'.freeze, REF_TYPE_TAG = 'TAG'.freeze, REF_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#full_ref_name ⇒ String
[Required] Unique full reference name inside a repository.
-
#ref_name ⇒ String
[Required] Unique reference name inside a repository.
-
#ref_type ⇒ String
[Required] The type of reference (Branch or Tag).
-
#repository_id ⇒ String
[Required] The OCID of the repository containing the reference.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RepositoryRef
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ RepositoryRef
Initializes the object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/oci/devops/models/repository_ref.rb', line 84 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.ref_name = attributes[:'refName'] if attributes[:'refName'] raise 'You cannot provide both :refName and :ref_name' if attributes.key?(:'refName') && attributes.key?(:'ref_name') self.ref_name = attributes[:'ref_name'] if attributes[:'ref_name'] self.ref_type = attributes[:'refType'] if attributes[:'refType'] raise 'You cannot provide both :refType and :ref_type' if attributes.key?(:'refType') && attributes.key?(:'ref_type') self.ref_type = attributes[:'ref_type'] if attributes[:'ref_type'] self.full_ref_name = attributes[:'fullRefName'] if attributes[:'fullRefName'] raise 'You cannot provide both :fullRefName and :full_ref_name' if attributes.key?(:'fullRefName') && attributes.key?(:'full_ref_name') self.full_ref_name = attributes[:'full_ref_name'] if attributes[:'full_ref_name'] self.repository_id = attributes[:'repositoryId'] if attributes[:'repositoryId'] raise 'You cannot provide both :repositoryId and :repository_id' if attributes.key?(:'repositoryId') && attributes.key?(:'repository_id') self.repository_id = attributes[:'repository_id'] if attributes[:'repository_id'] end |
Instance Attribute Details
#full_ref_name ⇒ String
[Required] Unique full reference name inside a repository.
28 29 30 |
# File 'lib/oci/devops/models/repository_ref.rb', line 28 def full_ref_name @full_ref_name end |
#ref_name ⇒ String
[Required] Unique reference name inside a repository.
20 21 22 |
# File 'lib/oci/devops/models/repository_ref.rb', line 20 def ref_name @ref_name end |
#ref_type ⇒ String
[Required] The type of reference (Branch or Tag).
24 25 26 |
# File 'lib/oci/devops/models/repository_ref.rb', line 24 def ref_type @ref_type end |
#repository_id ⇒ String
[Required] The OCID of the repository containing the reference.
32 33 34 |
# File 'lib/oci/devops/models/repository_ref.rb', line 32 def repository_id @repository_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 |
# File 'lib/oci/devops/models/repository_ref.rb', line 35 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'ref_name': :'refName', 'ref_type': :'refType', 'full_ref_name': :'fullRefName', 'repository_id': :'repositoryId' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
63 64 65 66 67 68 69 70 71 |
# File 'lib/oci/devops/models/repository_ref.rb', line 63 def self.get_subtype(object_hash) type = object_hash[:'refType'] # rubocop:disable Style/SymbolLiteral return 'OCI::Devops::Models::RepositoryBranch' if type == 'BRANCH' return 'OCI::Devops::Models::RepositoryTag' if type == 'TAG' # TODO: Log a warning when the subtype is not found. 'OCI::Devops::Models::RepositoryRef' end |
.swagger_types ⇒ Object
Attribute type mapping.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/oci/devops/models/repository_ref.rb', line 47 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'ref_name': :'String', 'ref_type': :'String', 'full_ref_name': :'String', 'repository_id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
135 136 137 138 139 140 141 142 143 |
# File 'lib/oci/devops/models/repository_ref.rb', line 135 def ==(other) return true if equal?(other) self.class == other.class && ref_name == other.ref_name && ref_type == other.ref_type && full_ref_name == other.full_ref_name && repository_id == other.repository_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/oci/devops/models/repository_ref.rb', line 168 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
148 149 150 |
# File 'lib/oci/devops/models/repository_ref.rb', line 148 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
157 158 159 |
# File 'lib/oci/devops/models/repository_ref.rb', line 157 def hash [ref_name, ref_type, full_ref_name, repository_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
201 202 203 204 205 206 207 208 209 210 |
# File 'lib/oci/devops/models/repository_ref.rb', line 201 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
195 196 197 |
# File 'lib/oci/devops/models/repository_ref.rb', line 195 def to_s to_hash.to_s end |