Class: OCI::Devops::Models::RepositoryRefSummary
- Inherits:
-
Object
- Object
- OCI::Devops::Models::RepositoryRefSummary
- Defined in:
- lib/oci/devops/models/repository_ref_summary.rb
Overview
Summary of a reference. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
Instance Attribute Summary collapse
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#full_ref_name ⇒ String
[Required] Unique full reference name inside a repository.
-
#ref_name ⇒ String
[Required] Reference name inside a repository.
-
#ref_type ⇒ String
[Required] The type of reference (Branch or Tag).
-
#repository_id ⇒ String
[Required] The OCID of the repository containing the reference.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RepositoryRefSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ RepositoryRefSummary
Initializes the object
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/oci/devops/models/repository_ref_summary.rb', line 91 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.ref_name = attributes[:'refName'] if attributes[:'refName'] raise 'You cannot provide both :refName and :ref_name' if attributes.key?(:'refName') && attributes.key?(:'ref_name') self.ref_name = attributes[:'ref_name'] if attributes[:'ref_name'] self.ref_type = attributes[:'refType'] if attributes[:'refType'] raise 'You cannot provide both :refType and :ref_type' if attributes.key?(:'refType') && attributes.key?(:'ref_type') self.ref_type = attributes[:'ref_type'] if attributes[:'ref_type'] self.full_ref_name = attributes[:'fullRefName'] if attributes[:'fullRefName'] raise 'You cannot provide both :fullRefName and :full_ref_name' if attributes.key?(:'fullRefName') && attributes.key?(:'full_ref_name') self.full_ref_name = attributes[:'full_ref_name'] if attributes[:'full_ref_name'] self.repository_id = attributes[:'repositoryId'] if attributes[:'repositoryId'] raise 'You cannot provide both :repositoryId and :repository_id' if attributes.key?(:'repositoryId') && attributes.key?(:'repository_id') self.repository_id = attributes[:'repository_id'] if attributes[:'repository_id'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"bar-key": "value"}`
33 34 35 |
# File 'lib/oci/devops/models/repository_ref_summary.rb', line 33 def end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"value"`
29 30 31 |
# File 'lib/oci/devops/models/repository_ref_summary.rb', line 29 def end |
#full_ref_name ⇒ String
[Required] Unique full reference name inside a repository.
21 22 23 |
# File 'lib/oci/devops/models/repository_ref_summary.rb', line 21 def full_ref_name @full_ref_name end |
#ref_name ⇒ String
[Required] Reference name inside a repository.
13 14 15 |
# File 'lib/oci/devops/models/repository_ref_summary.rb', line 13 def ref_name @ref_name end |
#ref_type ⇒ String
[Required] The type of reference (Branch or Tag).
17 18 19 |
# File 'lib/oci/devops/models/repository_ref_summary.rb', line 17 def ref_type @ref_type end |
#repository_id ⇒ String
[Required] The OCID of the repository containing the reference.
25 26 27 |
# File 'lib/oci/devops/models/repository_ref_summary.rb', line 25 def repository_id @repository_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
36 37 38 39 40 41 42 43 44 45 46 47 |
# File 'lib/oci/devops/models/repository_ref_summary.rb', line 36 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'ref_name': :'refName', 'ref_type': :'refType', 'full_ref_name': :'fullRefName', 'repository_id': :'repositoryId', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
68 69 70 71 72 73 74 75 76 |
# File 'lib/oci/devops/models/repository_ref_summary.rb', line 68 def self.get_subtype(object_hash) type = object_hash[:'refType'] # rubocop:disable Style/SymbolLiteral return 'OCI::Devops::Models::RepositoryBranchSummary' if type == 'BRANCH' return 'OCI::Devops::Models::RepositoryTagSummary' if type == 'TAG' # TODO: Log a warning when the subtype is not found. 'OCI::Devops::Models::RepositoryRefSummary' end |
.swagger_types ⇒ Object
Attribute type mapping.
50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/oci/devops/models/repository_ref_summary.rb', line 50 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'ref_name': :'String', 'ref_type': :'String', 'full_ref_name': :'String', 'repository_id': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/oci/devops/models/repository_ref_summary.rb', line 141 def ==(other) return true if equal?(other) self.class == other.class && ref_name == other.ref_name && ref_type == other.ref_type && full_ref_name == other.full_ref_name && repository_id == other.repository_id && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/oci/devops/models/repository_ref_summary.rb', line 176 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
156 157 158 |
# File 'lib/oci/devops/models/repository_ref_summary.rb', line 156 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
165 166 167 |
# File 'lib/oci/devops/models/repository_ref_summary.rb', line 165 def hash [ref_name, ref_type, full_ref_name, repository_id, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
209 210 211 212 213 214 215 216 217 218 |
# File 'lib/oci/devops/models/repository_ref_summary.rb', line 209 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
203 204 205 |
# File 'lib/oci/devops/models/repository_ref_summary.rb', line 203 def to_s to_hash.to_s end |