Class: OCI::Devops::Models::SingleDeployStageRedeployment
- Inherits:
-
Deployment
- Object
- Deployment
- OCI::Devops::Models::SingleDeployStageRedeployment
- Defined in:
- lib/oci/devops/models/single_deploy_stage_redeployment.rb
Overview
Redeployment of a single stage of a previous deployment.
Constant Summary
Constants inherited from Deployment
Deployment::DEPLOYMENT_TYPE_ENUM, Deployment::LIFECYCLE_STATE_ENUM
Instance Attribute Summary collapse
-
#deploy_stage_id ⇒ String
Specifies the OCID of the stage to be redeployed.
-
#previous_deployment_id ⇒ String
Specifies the OCID of the previous deployment to be redeployed.
Attributes inherited from Deployment
#compartment_id, #defined_tags, #deploy_artifact_override_arguments, #deploy_pipeline_artifacts, #deploy_pipeline_environments, #deploy_pipeline_id, #deployment_arguments, #deployment_execution_progress, #deployment_type, #display_name, #freeform_tags, #id, #lifecycle_details, #lifecycle_state, #project_id, #system_tags, #time_created, #time_updated
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SingleDeployStageRedeployment
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from Deployment
Constructor Details
#initialize(attributes = {}) ⇒ SingleDeployStageRedeployment
Initializes the object
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/oci/devops/models/single_deploy_stage_redeployment.rb', line 100 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['deploymentType'] = 'SINGLE_STAGE_REDEPLOYMENT' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.previous_deployment_id = attributes[:'previousDeploymentId'] if attributes[:'previousDeploymentId'] raise 'You cannot provide both :previousDeploymentId and :previous_deployment_id' if attributes.key?(:'previousDeploymentId') && attributes.key?(:'previous_deployment_id') self.previous_deployment_id = attributes[:'previous_deployment_id'] if attributes[:'previous_deployment_id'] self.deploy_stage_id = attributes[:'deployStageId'] if attributes[:'deployStageId'] raise 'You cannot provide both :deployStageId and :deploy_stage_id' if attributes.key?(:'deployStageId') && attributes.key?(:'deploy_stage_id') self.deploy_stage_id = attributes[:'deploy_stage_id'] if attributes[:'deploy_stage_id'] end |
Instance Attribute Details
#deploy_stage_id ⇒ String
Specifies the OCID of the stage to be redeployed.
17 18 19 |
# File 'lib/oci/devops/models/single_deploy_stage_redeployment.rb', line 17 def deploy_stage_id @deploy_stage_id end |
#previous_deployment_id ⇒ String
Specifies the OCID of the previous deployment to be redeployed.
13 14 15 |
# File 'lib/oci/devops/models/single_deploy_stage_redeployment.rb', line 13 def previous_deployment_id @previous_deployment_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 |
# File 'lib/oci/devops/models/single_deploy_stage_redeployment.rb', line 20 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'deploy_pipeline_artifacts': :'deployPipelineArtifacts', 'deploy_pipeline_environments': :'deployPipelineEnvironments', 'deployment_type': :'deploymentType', 'id': :'id', 'display_name': :'displayName', 'project_id': :'projectId', 'deploy_pipeline_id': :'deployPipelineId', 'compartment_id': :'compartmentId', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'deployment_arguments': :'deploymentArguments', 'deploy_artifact_override_arguments': :'deployArtifactOverrideArguments', 'deployment_execution_progress': :'deploymentExecutionProgress', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags', 'previous_deployment_id': :'previousDeploymentId', 'deploy_stage_id': :'deployStageId' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/oci/devops/models/single_deploy_stage_redeployment.rb', line 48 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'deploy_pipeline_artifacts': :'OCI::Devops::Models::DeployPipelineArtifactCollection', 'deploy_pipeline_environments': :'OCI::Devops::Models::DeployPipelineEnvironmentCollection', 'deployment_type': :'String', 'id': :'String', 'display_name': :'String', 'project_id': :'String', 'deploy_pipeline_id': :'String', 'compartment_id': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'deployment_arguments': :'OCI::Devops::Models::DeploymentArgumentCollection', 'deploy_artifact_override_arguments': :'OCI::Devops::Models::DeployArtifactOverrideArgumentCollection', 'deployment_execution_progress': :'OCI::Devops::Models::DeploymentExecutionProgress', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>', 'previous_deployment_id': :'String', 'deploy_stage_id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/oci/devops/models/single_deploy_stage_redeployment.rb', line 130 def ==(other) return true if equal?(other) self.class == other.class && deploy_pipeline_artifacts == other.deploy_pipeline_artifacts && deploy_pipeline_environments == other.deploy_pipeline_environments && deployment_type == other.deployment_type && id == other.id && display_name == other.display_name && project_id == other.project_id && deploy_pipeline_id == other.deploy_pipeline_id && compartment_id == other.compartment_id && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && deployment_arguments == other.deployment_arguments && deploy_artifact_override_arguments == other.deploy_artifact_override_arguments && deployment_execution_progress == other.deployment_execution_progress && == other. && == other. && == other. && previous_deployment_id == other.previous_deployment_id && deploy_stage_id == other.deploy_stage_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/oci/devops/models/single_deploy_stage_redeployment.rb', line 179 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
159 160 161 |
# File 'lib/oci/devops/models/single_deploy_stage_redeployment.rb', line 159 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
168 169 170 |
# File 'lib/oci/devops/models/single_deploy_stage_redeployment.rb', line 168 def hash [deploy_pipeline_artifacts, deploy_pipeline_environments, deployment_type, id, display_name, project_id, deploy_pipeline_id, compartment_id, time_created, time_updated, lifecycle_state, lifecycle_details, deployment_arguments, deploy_artifact_override_arguments, deployment_execution_progress, , , , previous_deployment_id, deploy_stage_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
212 213 214 215 216 217 218 219 220 221 |
# File 'lib/oci/devops/models/single_deploy_stage_redeployment.rb', line 212 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
206 207 208 |
# File 'lib/oci/devops/models/single_deploy_stage_redeployment.rb', line 206 def to_s to_hash.to_s end |