Class: OCI::Devops::Models::Trigger
- Inherits:
-
Object
- Object
- OCI::Devops::Models::Trigger
- Defined in:
- lib/oci/devops/models/trigger.rb
Overview
Trigger the deployment pipeline to deploy the artifact. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
Constant Summary collapse
- TRIGGER_SOURCE_ENUM =
[ TRIGGER_SOURCE_GITHUB = 'GITHUB'.freeze, TRIGGER_SOURCE_GITLAB = 'GITLAB'.freeze, TRIGGER_SOURCE_DEVOPS_CODE_REPOSITORY = 'DEVOPS_CODE_REPOSITORY'.freeze, TRIGGER_SOURCE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#actions ⇒ Array<OCI::Devops::Models::TriggerAction>
[Required] The list of actions that are to be performed for this trigger.
-
#compartment_id ⇒ String
[Required] The OCID of the compartment that contains the trigger.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
Description about the trigger.
-
#display_name ⇒ String
Trigger display name.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
[Required] Unique identifier that is immutable on creation.
-
#lifecycle_details ⇒ String
A message describing the current state in more detail.
-
#lifecycle_state ⇒ String
The current state of the trigger.
-
#project_id ⇒ String
[Required] The OCID of the DevOps project to which the trigger belongs to.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys.
-
#time_created ⇒ DateTime
The time the trigger was created.
-
#time_updated ⇒ DateTime
The time the trigger was updated.
-
#trigger_source ⇒ String
[Required] Source of the trigger.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Trigger
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Trigger
Initializes the object
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/oci/devops/models/trigger.rb', line 161 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.project_id = attributes[:'projectId'] if attributes[:'projectId'] raise 'You cannot provide both :projectId and :project_id' if attributes.key?(:'projectId') && attributes.key?(:'project_id') self.project_id = attributes[:'project_id'] if attributes[:'project_id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.trigger_source = attributes[:'triggerSource'] if attributes[:'triggerSource'] raise 'You cannot provide both :triggerSource and :trigger_source' if attributes.key?(:'triggerSource') && attributes.key?(:'trigger_source') self.trigger_source = attributes[:'trigger_source'] if attributes[:'trigger_source'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.actions = attributes[:'actions'] if attributes[:'actions'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#actions ⇒ Array<OCI::Devops::Models::TriggerAction>
[Required] The list of actions that are to be performed for this trigger.
66 67 68 |
# File 'lib/oci/devops/models/trigger.rb', line 66 def actions @actions end |
#compartment_id ⇒ String
[Required] The OCID of the compartment that contains the trigger.
42 43 44 |
# File 'lib/oci/devops/models/trigger.rb', line 42 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"bar-key": "value"}`
74 75 76 |
# File 'lib/oci/devops/models/trigger.rb', line 74 def end |
#description ⇒ String
Description about the trigger.
34 35 36 |
# File 'lib/oci/devops/models/trigger.rb', line 34 def description @description end |
#display_name ⇒ String
Trigger display name. Avoid entering confidential information.
30 31 32 |
# File 'lib/oci/devops/models/trigger.rb', line 30 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"value"`
70 71 72 |
# File 'lib/oci/devops/models/trigger.rb', line 70 def end |
#id ⇒ String
[Required] Unique identifier that is immutable on creation.
26 27 28 |
# File 'lib/oci/devops/models/trigger.rb', line 26 def id @id end |
#lifecycle_details ⇒ String
A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
62 63 64 |
# File 'lib/oci/devops/models/trigger.rb', line 62 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
The current state of the trigger.
58 59 60 |
# File 'lib/oci/devops/models/trigger.rb', line 58 def lifecycle_state @lifecycle_state end |
#project_id ⇒ String
[Required] The OCID of the DevOps project to which the trigger belongs to.
38 39 40 |
# File 'lib/oci/devops/models/trigger.rb', line 38 def project_id @project_id end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys. These predefined keys are scoped to namespaces. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"free-tier-retained": "true"}`
78 79 80 |
# File 'lib/oci/devops/models/trigger.rb', line 78 def end |
#time_created ⇒ DateTime
The time the trigger was created. Format defined by [RFC3339](datatracker.ietf.org/doc/html/rfc3339).
50 51 52 |
# File 'lib/oci/devops/models/trigger.rb', line 50 def time_created @time_created end |
#time_updated ⇒ DateTime
The time the trigger was updated. Format defined by [RFC3339](datatracker.ietf.org/doc/html/rfc3339).
54 55 56 |
# File 'lib/oci/devops/models/trigger.rb', line 54 def time_updated @time_updated end |
#trigger_source ⇒ String
[Required] Source of the trigger. Allowed values are, GITHUB, GITLAB and DEVOPS_CODE_REPOSITORY.
46 47 48 |
# File 'lib/oci/devops/models/trigger.rb', line 46 def trigger_source @trigger_source end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/oci/devops/models/trigger.rb', line 81 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'description': :'description', 'project_id': :'projectId', 'compartment_id': :'compartmentId', 'trigger_source': :'triggerSource', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'actions': :'actions', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
129 130 131 132 133 134 135 136 137 138 |
# File 'lib/oci/devops/models/trigger.rb', line 129 def self.get_subtype(object_hash) type = object_hash[:'triggerSource'] # rubocop:disable Style/SymbolLiteral return 'OCI::Devops::Models::GitlabTrigger' if type == 'GITLAB' return 'OCI::Devops::Models::GithubTrigger' if type == 'GITHUB' return 'OCI::Devops::Models::DevopsCodeRepositoryTrigger' if type == 'DEVOPS_CODE_REPOSITORY' # TODO: Log a warning when the subtype is not found. 'OCI::Devops::Models::Trigger' end |
.swagger_types ⇒ Object
Attribute type mapping.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/oci/devops/models/trigger.rb', line 103 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'description': :'String', 'project_id': :'String', 'compartment_id': :'String', 'trigger_source': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'actions': :'Array<OCI::Devops::Models::TriggerAction>', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'lib/oci/devops/models/trigger.rb', line 273 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && description == other.description && project_id == other.project_id && compartment_id == other.compartment_id && trigger_source == other.trigger_source && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && actions == other.actions && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 |
# File 'lib/oci/devops/models/trigger.rb', line 316 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
296 297 298 |
# File 'lib/oci/devops/models/trigger.rb', line 296 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
305 306 307 |
# File 'lib/oci/devops/models/trigger.rb', line 305 def hash [id, display_name, description, project_id, compartment_id, trigger_source, time_created, time_updated, lifecycle_state, lifecycle_details, actions, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
349 350 351 352 353 354 355 356 357 358 |
# File 'lib/oci/devops/models/trigger.rb', line 349 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
343 344 345 |
# File 'lib/oci/devops/models/trigger.rb', line 343 def to_s to_hash.to_s end |