Class: OCI::Devops::Models::TriggerSchedule

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/devops/models/trigger_schedule.rb

Overview

Specifies a trigger schedule. Timing information for when to initiate automated syncs.

Constant Summary collapse

SCHEDULE_TYPE_ENUM =
[
  SCHEDULE_TYPE_NONE = 'NONE'.freeze,
  SCHEDULE_TYPE_DEFAULT = 'DEFAULT'.freeze,
  SCHEDULE_TYPE_CUSTOM = 'CUSTOM'.freeze,
  SCHEDULE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ TriggerSchedule

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :schedule_type (String)

    The value to assign to the #schedule_type property

  • :custom_schedule (String)

    The value to assign to the #custom_schedule property



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/oci/devops/models/trigger_schedule.rb', line 61

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.schedule_type = attributes[:'scheduleType'] if attributes[:'scheduleType']
  self.schedule_type = "DEFAULT" if schedule_type.nil? && !attributes.key?(:'scheduleType') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :scheduleType and :schedule_type' if attributes.key?(:'scheduleType') && attributes.key?(:'schedule_type')

  self.schedule_type = attributes[:'schedule_type'] if attributes[:'schedule_type']
  self.schedule_type = "DEFAULT" if schedule_type.nil? && !attributes.key?(:'scheduleType') && !attributes.key?(:'schedule_type') # rubocop:disable Style/StringLiterals

  self.custom_schedule = attributes[:'customSchedule'] if attributes[:'customSchedule']

  raise 'You cannot provide both :customSchedule and :custom_schedule' if attributes.key?(:'customSchedule') && attributes.key?(:'custom_schedule')

  self.custom_schedule = attributes[:'custom_schedule'] if attributes[:'custom_schedule']
end

Instance Attribute Details

#custom_scheduleString

Valid if type is CUSTOM. Following RFC 5545 recurrence rules, we can specify starting time, occurrence frequency, and interval size. Example for frequency could be DAILY/WEEKLY/HOURLY or any RFC 5545 supported frequency, which is followed by start time of this window. You can control the start time with BYHOUR, BYMINUTE and BYSECONDS. It is followed by the interval size.

Returns:

  • (String)


31
32
33
# File 'lib/oci/devops/models/trigger_schedule.rb', line 31

def custom_schedule
  @custom_schedule
end

#schedule_typeString

[Required] Different types of trigger schedule: None - No automated synchronization schedule. Default - Trigger schedule is every 30 minutes. Custom - Custom triggering schedule.

Returns:

  • (String)


24
25
26
# File 'lib/oci/devops/models/trigger_schedule.rb', line 24

def schedule_type
  @schedule_type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
# File 'lib/oci/devops/models/trigger_schedule.rb', line 34

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'schedule_type': :'scheduleType',
    'custom_schedule': :'customSchedule'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



44
45
46
47
48
49
50
51
# File 'lib/oci/devops/models/trigger_schedule.rb', line 44

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'schedule_type': :'String',
    'custom_schedule': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



102
103
104
105
106
107
108
# File 'lib/oci/devops/models/trigger_schedule.rb', line 102

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    schedule_type == other.schedule_type &&
    custom_schedule == other.custom_schedule
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/oci/devops/models/trigger_schedule.rb', line 133

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


113
114
115
# File 'lib/oci/devops/models/trigger_schedule.rb', line 113

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



122
123
124
# File 'lib/oci/devops/models/trigger_schedule.rb', line 122

def hash
  [schedule_type, custom_schedule].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



166
167
168
169
170
171
172
173
174
175
# File 'lib/oci/devops/models/trigger_schedule.rb', line 166

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



160
161
162
# File 'lib/oci/devops/models/trigger_schedule.rb', line 160

def to_s
  to_hash.to_s
end