Class: OCI::Devops::Models::UpdateBuildRunDetails
- Inherits:
-
Object
- Object
- OCI::Devops::Models::UpdateBuildRunDetails
- Defined in:
- lib/oci/devops/models/update_build_run_details.rb
Overview
The build run information to be updated.
Instance Attribute Summary collapse
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
Build run display name.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateBuildRunDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateBuildRunDetails
Initializes the object
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/oci/devops/models/update_build_run_details.rb', line 53 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"bar-key": "value"}`
20 21 22 |
# File 'lib/oci/devops/models/update_build_run_details.rb', line 20 def @defined_tags end |
#display_name ⇒ String
Build run display name. Avoid entering confidential information.
12 13 14 |
# File 'lib/oci/devops/models/update_build_run_details.rb', line 12 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"value"`
16 17 18 |
# File 'lib/oci/devops/models/update_build_run_details.rb', line 16 def @freeform_tags end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
23 24 25 26 27 28 29 30 31 |
# File 'lib/oci/devops/models/update_build_run_details.rb', line 23 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
34 35 36 37 38 39 40 41 42 |
# File 'lib/oci/devops/models/update_build_run_details.rb', line 34 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
85 86 87 88 89 90 91 92 |
# File 'lib/oci/devops/models/update_build_run_details.rb', line 85 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/oci/devops/models/update_build_run_details.rb', line 117 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
97 98 99 |
# File 'lib/oci/devops/models/update_build_run_details.rb', line 97 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
106 107 108 |
# File 'lib/oci/devops/models/update_build_run_details.rb', line 106 def hash [display_name, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
150 151 152 153 154 155 156 157 158 159 |
# File 'lib/oci/devops/models/update_build_run_details.rb', line 150 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
144 145 146 |
# File 'lib/oci/devops/models/update_build_run_details.rb', line 144 def to_s to_hash.to_s end |