Class: OCI::Devops::Models::UpdateComputeInstanceGroupBlueGreenDeployStageDetails
- Inherits:
-
UpdateDeployStageDetails
- Object
- UpdateDeployStageDetails
- OCI::Devops::Models::UpdateComputeInstanceGroupBlueGreenDeployStageDetails
- Defined in:
- lib/oci/devops/models/update_compute_instance_group_blue_green_deploy_stage_details.rb
Overview
Specifies the Instance Group Blue-Green deployment stage.
Instance Attribute Summary collapse
-
#deploy_artifact_ids ⇒ Array<String>
The list of file artifact OCIDs to deploy.
-
#deployment_spec_deploy_artifact_id ⇒ String
The OCID of the artifact that contains the deployment specification.
- #failure_policy ⇒ OCI::Devops::Models::ComputeInstanceGroupFailurePolicy
- #rollout_policy ⇒ OCI::Devops::Models::ComputeInstanceGroupRolloutPolicy
- #test_load_balancer_config ⇒ OCI::Devops::Models::LoadBalancerConfig
Attributes inherited from UpdateDeployStageDetails
#defined_tags, #deploy_stage_predecessor_collection, #deploy_stage_type, #description, #display_name, #freeform_tags
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateComputeInstanceGroupBlueGreenDeployStageDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from UpdateDeployStageDetails
Constructor Details
#initialize(attributes = {}) ⇒ UpdateComputeInstanceGroupBlueGreenDeployStageDetails
Initializes the object
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/oci/devops/models/update_compute_instance_group_blue_green_deploy_stage_details.rb', line 82 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['deployStageType'] = 'COMPUTE_INSTANCE_GROUP_BLUE_GREEN_DEPLOYMENT' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.deployment_spec_deploy_artifact_id = attributes[:'deploymentSpecDeployArtifactId'] if attributes[:'deploymentSpecDeployArtifactId'] raise 'You cannot provide both :deploymentSpecDeployArtifactId and :deployment_spec_deploy_artifact_id' if attributes.key?(:'deploymentSpecDeployArtifactId') && attributes.key?(:'deployment_spec_deploy_artifact_id') self.deployment_spec_deploy_artifact_id = attributes[:'deployment_spec_deploy_artifact_id'] if attributes[:'deployment_spec_deploy_artifact_id'] self.deploy_artifact_ids = attributes[:'deployArtifactIds'] if attributes[:'deployArtifactIds'] raise 'You cannot provide both :deployArtifactIds and :deploy_artifact_ids' if attributes.key?(:'deployArtifactIds') && attributes.key?(:'deploy_artifact_ids') self.deploy_artifact_ids = attributes[:'deploy_artifact_ids'] if attributes[:'deploy_artifact_ids'] self.rollout_policy = attributes[:'rolloutPolicy'] if attributes[:'rolloutPolicy'] raise 'You cannot provide both :rolloutPolicy and :rollout_policy' if attributes.key?(:'rolloutPolicy') && attributes.key?(:'rollout_policy') self.rollout_policy = attributes[:'rollout_policy'] if attributes[:'rollout_policy'] self.failure_policy = attributes[:'failurePolicy'] if attributes[:'failurePolicy'] raise 'You cannot provide both :failurePolicy and :failure_policy' if attributes.key?(:'failurePolicy') && attributes.key?(:'failure_policy') self.failure_policy = attributes[:'failure_policy'] if attributes[:'failure_policy'] self.test_load_balancer_config = attributes[:'testLoadBalancerConfig'] if attributes[:'testLoadBalancerConfig'] raise 'You cannot provide both :testLoadBalancerConfig and :test_load_balancer_config' if attributes.key?(:'testLoadBalancerConfig') && attributes.key?(:'test_load_balancer_config') self.test_load_balancer_config = attributes[:'test_load_balancer_config'] if attributes[:'test_load_balancer_config'] end |
Instance Attribute Details
#deploy_artifact_ids ⇒ Array<String>
The list of file artifact OCIDs to deploy.
17 18 19 |
# File 'lib/oci/devops/models/update_compute_instance_group_blue_green_deploy_stage_details.rb', line 17 def deploy_artifact_ids @deploy_artifact_ids end |
#deployment_spec_deploy_artifact_id ⇒ String
The OCID of the artifact that contains the deployment specification.
13 14 15 |
# File 'lib/oci/devops/models/update_compute_instance_group_blue_green_deploy_stage_details.rb', line 13 def deployment_spec_deploy_artifact_id @deployment_spec_deploy_artifact_id end |
#failure_policy ⇒ OCI::Devops::Models::ComputeInstanceGroupFailurePolicy
23 24 25 |
# File 'lib/oci/devops/models/update_compute_instance_group_blue_green_deploy_stage_details.rb', line 23 def failure_policy @failure_policy end |
#rollout_policy ⇒ OCI::Devops::Models::ComputeInstanceGroupRolloutPolicy
20 21 22 |
# File 'lib/oci/devops/models/update_compute_instance_group_blue_green_deploy_stage_details.rb', line 20 def rollout_policy @rollout_policy end |
#test_load_balancer_config ⇒ OCI::Devops::Models::LoadBalancerConfig
26 27 28 |
# File 'lib/oci/devops/models/update_compute_instance_group_blue_green_deploy_stage_details.rb', line 26 def test_load_balancer_config @test_load_balancer_config end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 |
# File 'lib/oci/devops/models/update_compute_instance_group_blue_green_deploy_stage_details.rb', line 29 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'description': :'description', 'display_name': :'displayName', 'deploy_stage_type': :'deployStageType', 'deploy_stage_predecessor_collection': :'deployStagePredecessorCollection', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'deployment_spec_deploy_artifact_id': :'deploymentSpecDeployArtifactId', 'deploy_artifact_ids': :'deployArtifactIds', 'rollout_policy': :'rolloutPolicy', 'failure_policy': :'failurePolicy', 'test_load_balancer_config': :'testLoadBalancerConfig' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/oci/devops/models/update_compute_instance_group_blue_green_deploy_stage_details.rb', line 48 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'description': :'String', 'display_name': :'String', 'deploy_stage_type': :'String', 'deploy_stage_predecessor_collection': :'OCI::Devops::Models::DeployStagePredecessorCollection', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'deployment_spec_deploy_artifact_id': :'String', 'deploy_artifact_ids': :'Array<String>', 'rollout_policy': :'OCI::Devops::Models::ComputeInstanceGroupRolloutPolicy', 'failure_policy': :'OCI::Devops::Models::ComputeInstanceGroupFailurePolicy', 'test_load_balancer_config': :'OCI::Devops::Models::LoadBalancerConfig' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/oci/devops/models/update_compute_instance_group_blue_green_deploy_stage_details.rb', line 130 def ==(other) return true if equal?(other) self.class == other.class && description == other.description && display_name == other.display_name && deploy_stage_type == other.deploy_stage_type && deploy_stage_predecessor_collection == other.deploy_stage_predecessor_collection && == other. && == other. && deployment_spec_deploy_artifact_id == other.deployment_spec_deploy_artifact_id && deploy_artifact_ids == other.deploy_artifact_ids && rollout_policy == other.rollout_policy && failure_policy == other.failure_policy && test_load_balancer_config == other.test_load_balancer_config end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/oci/devops/models/update_compute_instance_group_blue_green_deploy_stage_details.rb', line 170 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
150 151 152 |
# File 'lib/oci/devops/models/update_compute_instance_group_blue_green_deploy_stage_details.rb', line 150 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
159 160 161 |
# File 'lib/oci/devops/models/update_compute_instance_group_blue_green_deploy_stage_details.rb', line 159 def hash [description, display_name, deploy_stage_type, deploy_stage_predecessor_collection, , , deployment_spec_deploy_artifact_id, deploy_artifact_ids, rollout_policy, failure_policy, test_load_balancer_config].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
203 204 205 206 207 208 209 210 211 212 |
# File 'lib/oci/devops/models/update_compute_instance_group_blue_green_deploy_stage_details.rb', line 203 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
197 198 199 |
# File 'lib/oci/devops/models/update_compute_instance_group_blue_green_deploy_stage_details.rb', line 197 def to_s to_hash.to_s end |