Class: OCI::Devops::Models::UpdateComputeInstanceGroupDeployEnvironmentDetails
- Inherits:
-
UpdateDeployEnvironmentDetails
- Object
- UpdateDeployEnvironmentDetails
- OCI::Devops::Models::UpdateComputeInstanceGroupDeployEnvironmentDetails
- Defined in:
- lib/oci/devops/models/update_compute_instance_group_deploy_environment_details.rb
Overview
Specifies the Compute instance group environment.
Instance Attribute Summary collapse
Attributes inherited from UpdateDeployEnvironmentDetails
#defined_tags, #deploy_environment_type, #description, #display_name, #freeform_tags
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateComputeInstanceGroupDeployEnvironmentDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from UpdateDeployEnvironmentDetails
Constructor Details
#initialize(attributes = {}) ⇒ UpdateComputeInstanceGroupDeployEnvironmentDetails
Initializes the object
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/oci/devops/models/update_compute_instance_group_deploy_environment_details.rb', line 53 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['deployEnvironmentType'] = 'COMPUTE_INSTANCE_GROUP' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compute_instance_group_selectors = attributes[:'computeInstanceGroupSelectors'] if attributes[:'computeInstanceGroupSelectors'] raise 'You cannot provide both :computeInstanceGroupSelectors and :compute_instance_group_selectors' if attributes.key?(:'computeInstanceGroupSelectors') && attributes.key?(:'compute_instance_group_selectors') self.compute_instance_group_selectors = attributes[:'compute_instance_group_selectors'] if attributes[:'compute_instance_group_selectors'] end |
Instance Attribute Details
#compute_instance_group_selectors ⇒ OCI::Devops::Models::ComputeInstanceGroupSelectorCollection
12 13 14 |
# File 'lib/oci/devops/models/update_compute_instance_group_deploy_environment_details.rb', line 12 def compute_instance_group_selectors @compute_instance_group_selectors end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
15 16 17 18 19 20 21 22 23 24 25 26 |
# File 'lib/oci/devops/models/update_compute_instance_group_deploy_environment_details.rb', line 15 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'description': :'description', 'display_name': :'displayName', 'deploy_environment_type': :'deployEnvironmentType', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'compute_instance_group_selectors': :'computeInstanceGroupSelectors' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
29 30 31 32 33 34 35 36 37 38 39 40 |
# File 'lib/oci/devops/models/update_compute_instance_group_deploy_environment_details.rb', line 29 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'description': :'String', 'display_name': :'String', 'deploy_environment_type': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'compute_instance_group_selectors': :'OCI::Devops::Models::ComputeInstanceGroupSelectorCollection' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/oci/devops/models/update_compute_instance_group_deploy_environment_details.rb', line 77 def ==(other) return true if equal?(other) self.class == other.class && description == other.description && display_name == other.display_name && deploy_environment_type == other.deploy_environment_type && == other. && == other. && compute_instance_group_selectors == other.compute_instance_group_selectors end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/oci/devops/models/update_compute_instance_group_deploy_environment_details.rb', line 112 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
92 93 94 |
# File 'lib/oci/devops/models/update_compute_instance_group_deploy_environment_details.rb', line 92 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
101 102 103 |
# File 'lib/oci/devops/models/update_compute_instance_group_deploy_environment_details.rb', line 101 def hash [description, display_name, deploy_environment_type, , , compute_instance_group_selectors].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
145 146 147 148 149 150 151 152 153 154 |
# File 'lib/oci/devops/models/update_compute_instance_group_deploy_environment_details.rb', line 145 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
139 140 141 |
# File 'lib/oci/devops/models/update_compute_instance_group_deploy_environment_details.rb', line 139 def to_s to_hash.to_s end |