Class: OCI::Devops::Models::UpdateDeployArtifactDetails
- Inherits:
-
Object
- Object
- OCI::Devops::Models::UpdateDeployArtifactDetails
- Defined in:
- lib/oci/devops/models/update_deploy_artifact_details.rb
Overview
The information to be updated for the artifact.
Instance Attribute Summary collapse
-
#argument_substitution_mode ⇒ String
Mode for artifact parameter substitution.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
- #deploy_artifact_source ⇒ OCI::Devops::Models::DeployArtifactSource
-
#deploy_artifact_type ⇒ String
Type of the deployment artifact.
-
#description ⇒ String
Optional description about the deployment artifact.
-
#display_name ⇒ String
Deployment artifact display name.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateDeployArtifactDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateDeployArtifactDetails
Initializes the object
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/oci/devops/models/update_deploy_artifact_details.rb', line 80 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.description = attributes[:'description'] if attributes[:'description'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.deploy_artifact_type = attributes[:'deployArtifactType'] if attributes[:'deployArtifactType'] raise 'You cannot provide both :deployArtifactType and :deploy_artifact_type' if attributes.key?(:'deployArtifactType') && attributes.key?(:'deploy_artifact_type') self.deploy_artifact_type = attributes[:'deploy_artifact_type'] if attributes[:'deploy_artifact_type'] self.deploy_artifact_source = attributes[:'deployArtifactSource'] if attributes[:'deployArtifactSource'] raise 'You cannot provide both :deployArtifactSource and :deploy_artifact_source' if attributes.key?(:'deployArtifactSource') && attributes.key?(:'deploy_artifact_source') self.deploy_artifact_source = attributes[:'deploy_artifact_source'] if attributes[:'deploy_artifact_source'] self.argument_substitution_mode = attributes[:'argumentSubstitutionMode'] if attributes[:'argumentSubstitutionMode'] raise 'You cannot provide both :argumentSubstitutionMode and :argument_substitution_mode' if attributes.key?(:'argumentSubstitutionMode') && attributes.key?(:'argument_substitution_mode') self.argument_substitution_mode = attributes[:'argument_substitution_mode'] if attributes[:'argument_substitution_mode'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#argument_substitution_mode ⇒ String
Mode for artifact parameter substitution.
27 28 29 |
# File 'lib/oci/devops/models/update_deploy_artifact_details.rb', line 27 def argument_substitution_mode @argument_substitution_mode end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"bar-key": "value"}`
35 36 37 |
# File 'lib/oci/devops/models/update_deploy_artifact_details.rb', line 35 def end |
#deploy_artifact_source ⇒ OCI::Devops::Models::DeployArtifactSource
23 24 25 |
# File 'lib/oci/devops/models/update_deploy_artifact_details.rb', line 23 def deploy_artifact_source @deploy_artifact_source end |
#deploy_artifact_type ⇒ String
Type of the deployment artifact.
20 21 22 |
# File 'lib/oci/devops/models/update_deploy_artifact_details.rb', line 20 def deploy_artifact_type @deploy_artifact_type end |
#description ⇒ String
Optional description about the deployment artifact.
12 13 14 |
# File 'lib/oci/devops/models/update_deploy_artifact_details.rb', line 12 def description @description end |
#display_name ⇒ String
Deployment artifact display name. Avoid entering confidential information.
16 17 18 |
# File 'lib/oci/devops/models/update_deploy_artifact_details.rb', line 16 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"value"`
31 32 33 |
# File 'lib/oci/devops/models/update_deploy_artifact_details.rb', line 31 def end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
38 39 40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/oci/devops/models/update_deploy_artifact_details.rb', line 38 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'description': :'description', 'display_name': :'displayName', 'deploy_artifact_type': :'deployArtifactType', 'deploy_artifact_source': :'deployArtifactSource', 'argument_substitution_mode': :'argumentSubstitutionMode', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/oci/devops/models/update_deploy_artifact_details.rb', line 53 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'description': :'String', 'display_name': :'String', 'deploy_artifact_type': :'String', 'deploy_artifact_source': :'OCI::Devops::Models::DeployArtifactSource', 'argument_substitution_mode': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/oci/devops/models/update_deploy_artifact_details.rb', line 132 def ==(other) return true if equal?(other) self.class == other.class && description == other.description && display_name == other.display_name && deploy_artifact_type == other.deploy_artifact_type && deploy_artifact_source == other.deploy_artifact_source && argument_substitution_mode == other.argument_substitution_mode && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/oci/devops/models/update_deploy_artifact_details.rb', line 168 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
148 149 150 |
# File 'lib/oci/devops/models/update_deploy_artifact_details.rb', line 148 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
157 158 159 |
# File 'lib/oci/devops/models/update_deploy_artifact_details.rb', line 157 def hash [description, display_name, deploy_artifact_type, deploy_artifact_source, argument_substitution_mode, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
201 202 203 204 205 206 207 208 209 210 |
# File 'lib/oci/devops/models/update_deploy_artifact_details.rb', line 201 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
195 196 197 |
# File 'lib/oci/devops/models/update_deploy_artifact_details.rb', line 195 def to_s to_hash.to_s end |