Class: OCI::Devops::Models::UpdateDeploymentDetails
- Inherits:
-
Object
- Object
- OCI::Devops::Models::UpdateDeploymentDetails
- Defined in:
- lib/oci/devops/models/update_deployment_details.rb
Overview
The information to be updated. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
UpdateDeployPipelineDeploymentDetails, UpdateDeployPipelineRedeploymentDetails, UpdateSingleDeployStageDeploymentDetails, UpdateSingleDeployStageRedeploymentDetails
Instance Attribute Summary collapse
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#deployment_type ⇒ String
**[Required]** Specifies type for this deployment.
-
#display_name ⇒ String
Deployment display name.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateDeploymentDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateDeploymentDetails
Initializes the object
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/oci/devops/models/update_deployment_details.rb', line 79 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.deployment_type = attributes[:'deploymentType'] if attributes[:'deploymentType'] raise 'You cannot provide both :deploymentType and :deployment_type' if attributes.key?(:'deploymentType') && attributes.key?(:'deployment_type') self.deployment_type = attributes[:'deployment_type'] if attributes[:'deployment_type'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `{"bar-key": "value"}`
25 26 27 |
# File 'lib/oci/devops/models/update_deployment_details.rb', line 25 def @defined_tags end |
#deployment_type ⇒ String
**[Required]** Specifies type for this deployment.
13 14 15 |
# File 'lib/oci/devops/models/update_deployment_details.rb', line 13 def deployment_type @deployment_type end |
#display_name ⇒ String
Deployment display name. Avoid entering confidential information.
17 18 19 |
# File 'lib/oci/devops/models/update_deployment_details.rb', line 17 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `"value"`
21 22 23 |
# File 'lib/oci/devops/models/update_deployment_details.rb', line 21 def @freeform_tags end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 35 36 37 |
# File 'lib/oci/devops/models/update_deployment_details.rb', line 28 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'deployment_type': :'deploymentType', 'display_name': :'displayName', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/oci/devops/models/update_deployment_details.rb', line 56 def self.get_subtype(object_hash) type = object_hash[:'deploymentType'] # rubocop:disable Style/SymbolLiteral return 'OCI::Devops::Models::UpdateSingleDeployStageDeploymentDetails' if type == 'SINGLE_STAGE_DEPLOYMENT' return 'OCI::Devops::Models::UpdateDeployPipelineRedeploymentDetails' if type == 'PIPELINE_REDEPLOYMENT' return 'OCI::Devops::Models::UpdateDeployPipelineDeploymentDetails' if type == 'PIPELINE_DEPLOYMENT' return 'OCI::Devops::Models::UpdateSingleDeployStageRedeploymentDetails' if type == 'SINGLE_STAGE_REDEPLOYMENT' # TODO: Log a warning when the subtype is not found. 'OCI::Devops::Models::UpdateDeploymentDetails' end |
.swagger_types ⇒ Object
Attribute type mapping.
40 41 42 43 44 45 46 47 48 49 |
# File 'lib/oci/devops/models/update_deployment_details.rb', line 40 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'deployment_type': :'String', 'display_name': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
117 118 119 120 121 122 123 124 125 |
# File 'lib/oci/devops/models/update_deployment_details.rb', line 117 def ==(other) return true if equal?(other) self.class == other.class && deployment_type == other.deployment_type && display_name == other.display_name && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/oci/devops/models/update_deployment_details.rb', line 150 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
130 131 132 |
# File 'lib/oci/devops/models/update_deployment_details.rb', line 130 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
139 140 141 |
# File 'lib/oci/devops/models/update_deployment_details.rb', line 139 def hash [deployment_type, display_name, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
183 184 185 186 187 188 189 190 191 192 |
# File 'lib/oci/devops/models/update_deployment_details.rb', line 183 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
177 178 179 |
# File 'lib/oci/devops/models/update_deployment_details.rb', line 177 def to_s to_hash.to_s end |