Class: OCI::Devops::Models::UpdateInvokeFunctionDeployStageDetails
- Inherits:
-
UpdateDeployStageDetails
- Object
- UpdateDeployStageDetails
- OCI::Devops::Models::UpdateInvokeFunctionDeployStageDetails
- Defined in:
- lib/oci/devops/models/update_invoke_function_deploy_stage_details.rb
Overview
Specifies Invoke Function stage.
Instance Attribute Summary collapse
-
#deploy_artifact_id ⇒ String
Optional binary artifact OCID user may provide to this stage.
-
#function_deploy_environment_id ⇒ String
Function environment OCID.
-
#is_async ⇒ BOOLEAN
A boolean flag specifies whether this stage executes asynchronously.
-
#is_validation_enabled ⇒ BOOLEAN
A boolean flag specifies whether the invoked function must be validated.
Attributes inherited from UpdateDeployStageDetails
#defined_tags, #deploy_stage_predecessor_collection, #deploy_stage_type, #description, #display_name, #freeform_tags
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateInvokeFunctionDeployStageDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from UpdateDeployStageDetails
Constructor Details
#initialize(attributes = {}) ⇒ UpdateInvokeFunctionDeployStageDetails
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/oci/devops/models/update_invoke_function_deploy_stage_details.rb', line 78 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['deployStageType'] = 'INVOKE_FUNCTION' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.function_deploy_environment_id = attributes[:'functionDeployEnvironmentId'] if attributes[:'functionDeployEnvironmentId'] raise 'You cannot provide both :functionDeployEnvironmentId and :function_deploy_environment_id' if attributes.key?(:'functionDeployEnvironmentId') && attributes.key?(:'function_deploy_environment_id') self.function_deploy_environment_id = attributes[:'function_deploy_environment_id'] if attributes[:'function_deploy_environment_id'] self.deploy_artifact_id = attributes[:'deployArtifactId'] if attributes[:'deployArtifactId'] raise 'You cannot provide both :deployArtifactId and :deploy_artifact_id' if attributes.key?(:'deployArtifactId') && attributes.key?(:'deploy_artifact_id') self.deploy_artifact_id = attributes[:'deploy_artifact_id'] if attributes[:'deploy_artifact_id'] self.is_async = attributes[:'isAsync'] unless attributes[:'isAsync'].nil? raise 'You cannot provide both :isAsync and :is_async' if attributes.key?(:'isAsync') && attributes.key?(:'is_async') self.is_async = attributes[:'is_async'] unless attributes[:'is_async'].nil? self.is_validation_enabled = attributes[:'isValidationEnabled'] unless attributes[:'isValidationEnabled'].nil? raise 'You cannot provide both :isValidationEnabled and :is_validation_enabled' if attributes.key?(:'isValidationEnabled') && attributes.key?(:'is_validation_enabled') self.is_validation_enabled = attributes[:'is_validation_enabled'] unless attributes[:'is_validation_enabled'].nil? end |
Instance Attribute Details
#deploy_artifact_id ⇒ String
Optional binary artifact OCID user may provide to this stage.
17 18 19 |
# File 'lib/oci/devops/models/update_invoke_function_deploy_stage_details.rb', line 17 def deploy_artifact_id @deploy_artifact_id end |
#function_deploy_environment_id ⇒ String
Function environment OCID.
13 14 15 |
# File 'lib/oci/devops/models/update_invoke_function_deploy_stage_details.rb', line 13 def function_deploy_environment_id @function_deploy_environment_id end |
#is_async ⇒ BOOLEAN
A boolean flag specifies whether this stage executes asynchronously.
21 22 23 |
# File 'lib/oci/devops/models/update_invoke_function_deploy_stage_details.rb', line 21 def is_async @is_async end |
#is_validation_enabled ⇒ BOOLEAN
A boolean flag specifies whether the invoked function must be validated.
25 26 27 |
# File 'lib/oci/devops/models/update_invoke_function_deploy_stage_details.rb', line 25 def is_validation_enabled @is_validation_enabled end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 |
# File 'lib/oci/devops/models/update_invoke_function_deploy_stage_details.rb', line 28 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'description': :'description', 'display_name': :'displayName', 'deploy_stage_type': :'deployStageType', 'deploy_stage_predecessor_collection': :'deployStagePredecessorCollection', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'function_deploy_environment_id': :'functionDeployEnvironmentId', 'deploy_artifact_id': :'deployArtifactId', 'is_async': :'isAsync', 'is_validation_enabled': :'isValidationEnabled' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/oci/devops/models/update_invoke_function_deploy_stage_details.rb', line 46 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'description': :'String', 'display_name': :'String', 'deploy_stage_type': :'String', 'deploy_stage_predecessor_collection': :'OCI::Devops::Models::DeployStagePredecessorCollection', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'function_deploy_environment_id': :'String', 'deploy_artifact_id': :'String', 'is_async': :'BOOLEAN', 'is_validation_enabled': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/oci/devops/models/update_invoke_function_deploy_stage_details.rb', line 120 def ==(other) return true if equal?(other) self.class == other.class && description == other.description && display_name == other.display_name && deploy_stage_type == other.deploy_stage_type && deploy_stage_predecessor_collection == other.deploy_stage_predecessor_collection && == other. && == other. && function_deploy_environment_id == other.function_deploy_environment_id && deploy_artifact_id == other.deploy_artifact_id && is_async == other.is_async && is_validation_enabled == other.is_validation_enabled end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/oci/devops/models/update_invoke_function_deploy_stage_details.rb', line 159 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
139 140 141 |
# File 'lib/oci/devops/models/update_invoke_function_deploy_stage_details.rb', line 139 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
148 149 150 |
# File 'lib/oci/devops/models/update_invoke_function_deploy_stage_details.rb', line 148 def hash [description, display_name, deploy_stage_type, deploy_stage_predecessor_collection, , , function_deploy_environment_id, deploy_artifact_id, is_async, is_validation_enabled].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
192 193 194 195 196 197 198 199 200 201 |
# File 'lib/oci/devops/models/update_invoke_function_deploy_stage_details.rb', line 192 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
186 187 188 |
# File 'lib/oci/devops/models/update_invoke_function_deploy_stage_details.rb', line 186 def to_s to_hash.to_s end |