Class: OCI::Dns::Models::CreateZoneDetails
- Inherits:
-
CreateZoneBaseDetails
- Object
- CreateZoneBaseDetails
- OCI::Dns::Models::CreateZoneDetails
- Defined in:
- lib/oci/dns/models/create_zone_details.rb
Overview
The body for defining a new zone.
*Warning:* Oracle recommends that you avoid using any confidential information when you supply string values using the API.
Constant Summary collapse
- ZONE_TYPE_ENUM =
[ ZONE_TYPE_PRIMARY = 'PRIMARY'.freeze, ZONE_TYPE_SECONDARY = 'SECONDARY'.freeze ].freeze
- SCOPE_ENUM =
[ SCOPE_GLOBAL = 'GLOBAL'.freeze, SCOPE_PRIVATE = 'PRIVATE'.freeze ].freeze
Constants inherited from CreateZoneBaseDetails
OCI::Dns::Models::CreateZoneBaseDetails::MIGRATION_SOURCE_ENUM
Instance Attribute Summary collapse
-
#external_masters ⇒ Array<OCI::Dns::Models::ExternalMaster>
External master servers for the zone.
-
#scope ⇒ String
The scope of the zone.
-
#view_id ⇒ String
This value will be null for zones in the global DNS.
-
#zone_type ⇒ String
The type of the zone.
Attributes inherited from CreateZoneBaseDetails
#compartment_id, #defined_tags, #freeform_tags, #migration_source, #name
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateZoneDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from CreateZoneBaseDetails
Constructor Details
#initialize(attributes = {}) ⇒ CreateZoneDetails
Initializes the object
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/oci/dns/models/create_zone_details.rb', line 93 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['migrationSource'] = 'NONE' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.zone_type = attributes[:'zoneType'] if attributes[:'zoneType'] raise 'You cannot provide both :zoneType and :zone_type' if attributes.key?(:'zoneType') && attributes.key?(:'zone_type') self.zone_type = attributes[:'zone_type'] if attributes[:'zone_type'] self.view_id = attributes[:'viewId'] if attributes[:'viewId'] raise 'You cannot provide both :viewId and :view_id' if attributes.key?(:'viewId') && attributes.key?(:'view_id') self.view_id = attributes[:'view_id'] if attributes[:'view_id'] self.scope = attributes[:'scope'] if attributes[:'scope'] self.external_masters = attributes[:'externalMasters'] if attributes[:'externalMasters'] raise 'You cannot provide both :externalMasters and :external_masters' if attributes.key?(:'externalMasters') && attributes.key?(:'external_masters') self.external_masters = attributes[:'external_masters'] if attributes[:'external_masters'] end |
Instance Attribute Details
#external_masters ⇒ Array<OCI::Dns::Models::ExternalMaster>
External master servers for the zone. `externalMasters` becomes a required parameter when the `zoneType` value is `SECONDARY`.
43 44 45 |
# File 'lib/oci/dns/models/create_zone_details.rb', line 43 def external_masters @external_masters end |
#scope ⇒ String
The scope of the zone.
37 38 39 |
# File 'lib/oci/dns/models/create_zone_details.rb', line 37 def scope @scope end |
#view_id ⇒ String
This value will be null for zones in the global DNS.
33 34 35 |
# File 'lib/oci/dns/models/create_zone_details.rb', line 33 def view_id @view_id end |
#zone_type ⇒ String
The type of the zone. Must be either `PRIMARY` or `SECONDARY`. `SECONDARY` is only supported for GLOBAL zones.
28 29 30 |
# File 'lib/oci/dns/models/create_zone_details.rb', line 28 def zone_type @zone_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/oci/dns/models/create_zone_details.rb', line 46 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'migration_source': :'migrationSource', 'name': :'name', 'compartment_id': :'compartmentId', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'zone_type': :'zoneType', 'view_id': :'viewId', 'scope': :'scope', 'external_masters': :'externalMasters' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/oci/dns/models/create_zone_details.rb', line 63 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'migration_source': :'String', 'name': :'String', 'compartment_id': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'zone_type': :'String', 'view_id': :'String', 'scope': :'String', 'external_masters': :'Array<OCI::Dns::Models::ExternalMaster>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/oci/dns/models/create_zone_details.rb', line 147 def ==(other) return true if equal?(other) self.class == other.class && migration_source == other.migration_source && name == other.name && compartment_id == other.compartment_id && == other. && == other. && zone_type == other.zone_type && view_id == other.view_id && scope == other.scope && external_masters == other.external_masters end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/oci/dns/models/create_zone_details.rb', line 185 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
165 166 167 |
# File 'lib/oci/dns/models/create_zone_details.rb', line 165 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
174 175 176 |
# File 'lib/oci/dns/models/create_zone_details.rb', line 174 def hash [migration_source, name, compartment_id, , , zone_type, view_id, scope, external_masters].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
218 219 220 221 222 223 224 225 226 227 |
# File 'lib/oci/dns/models/create_zone_details.rb', line 218 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
212 213 214 |
# File 'lib/oci/dns/models/create_zone_details.rb', line 212 def to_s to_hash.to_s end |