Class: OCI::Dns::Models::ResolverEndpoint
- Inherits:
-
Object
- Object
- OCI::Dns::Models::ResolverEndpoint
- Defined in:
- lib/oci/dns/models/resolver_endpoint.rb
Overview
An OCI DNS resolver endpoint.
Warning: Oracle recommends that you avoid using any confidential information when you supply string values using the API.
This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
Constant Summary collapse
- ENDPOINT_TYPE_ENUM =
[ ENDPOINT_TYPE_VNIC = 'VNIC'.freeze, ENDPOINT_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#_self ⇒ String
[Required] The canonical absolute URL of the resource.
-
#compartment_id ⇒ String
[Required] The OCID of the owning compartment.
-
#endpoint_type ⇒ String
The type of resolver endpoint.
-
#forwarding_address ⇒ String
An IP address from which forwarded queries may be sent.
-
#is_forwarding ⇒ BOOLEAN
[Required] A Boolean flag indicating whether or not the resolver endpoint is for forwarding.
-
#is_listening ⇒ BOOLEAN
[Required] A Boolean flag indicating whether or not the resolver endpoint is for listening.
-
#lifecycle_state ⇒ String
[Required] The current state of the resource.
-
#listening_address ⇒ String
An IP address to listen to queries on.
-
#name ⇒ String
[Required] The name of the resolver endpoint.
-
#time_created ⇒ DateTime
[Required] The date and time the resource was created in "YYYY-MM-ddThh:mm:ssZ" format with a Z offset, as defined by RFC 3339.
-
#time_updated ⇒ DateTime
[Required] The date and time the resource was last updated in "YYYY-MM-ddThh:mm:ssZ" format with a Z offset, as defined by RFC 3339.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ResolverEndpoint
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ResolverEndpoint
Initializes the object
162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/oci/dns/models/resolver_endpoint.rb', line 162 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.endpoint_type = attributes[:'endpointType'] if attributes[:'endpointType'] self.endpoint_type = "VNIC" if endpoint_type.nil? && !attributes.key?(:'endpointType') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :endpointType and :endpoint_type' if attributes.key?(:'endpointType') && attributes.key?(:'endpoint_type') self.endpoint_type = attributes[:'endpoint_type'] if attributes[:'endpoint_type'] self.endpoint_type = "VNIC" if endpoint_type.nil? && !attributes.key?(:'endpointType') && !attributes.key?(:'endpoint_type') # rubocop:disable Style/StringLiterals self.forwarding_address = attributes[:'forwardingAddress'] if attributes[:'forwardingAddress'] raise 'You cannot provide both :forwardingAddress and :forwarding_address' if attributes.key?(:'forwardingAddress') && attributes.key?(:'forwarding_address') self.forwarding_address = attributes[:'forwarding_address'] if attributes[:'forwarding_address'] self.is_forwarding = attributes[:'isForwarding'] unless attributes[:'isForwarding'].nil? raise 'You cannot provide both :isForwarding and :is_forwarding' if attributes.key?(:'isForwarding') && attributes.key?(:'is_forwarding') self.is_forwarding = attributes[:'is_forwarding'] unless attributes[:'is_forwarding'].nil? self.is_listening = attributes[:'isListening'] unless attributes[:'isListening'].nil? raise 'You cannot provide both :isListening and :is_listening' if attributes.key?(:'isListening') && attributes.key?(:'is_listening') self.is_listening = attributes[:'is_listening'] unless attributes[:'is_listening'].nil? self.listening_address = attributes[:'listeningAddress'] if attributes[:'listeningAddress'] raise 'You cannot provide both :listeningAddress and :listening_address' if attributes.key?(:'listeningAddress') && attributes.key?(:'listening_address') self.listening_address = attributes[:'listening_address'] if attributes[:'listening_address'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self._self = attributes[:'self'] if attributes[:'self'] raise 'You cannot provide both :self and :_self' if attributes.key?(:'self') && attributes.key?(:'_self') self._self = attributes[:'_self'] if attributes[:'_self'] end |
Instance Attribute Details
#_self ⇒ String
[Required] The canonical absolute URL of the resource.
90 91 92 |
# File 'lib/oci/dns/models/resolver_endpoint.rb', line 90 def _self @_self end |
#compartment_id ⇒ String
[Required] The OCID of the owning compartment. This will match the resolver that the resolver endpoint is under and will be updated if the resolver’s compartment is changed.
66 67 68 |
# File 'lib/oci/dns/models/resolver_endpoint.rb', line 66 def compartment_id @compartment_id end |
#endpoint_type ⇒ String
The type of resolver endpoint. VNIC is currently the only supported type.
38 39 40 |
# File 'lib/oci/dns/models/resolver_endpoint.rb', line 38 def endpoint_type @endpoint_type end |
#forwarding_address ⇒ String
An IP address from which forwarded queries may be sent. For VNIC endpoints, this IP address must be part of the subnet and will be assigned by the system if unspecified when isForwarding is true.
44 45 46 |
# File 'lib/oci/dns/models/resolver_endpoint.rb', line 44 def forwarding_address @forwarding_address end |
#is_forwarding ⇒ BOOLEAN
[Required] A Boolean flag indicating whether or not the resolver endpoint is for forwarding.
49 50 51 |
# File 'lib/oci/dns/models/resolver_endpoint.rb', line 49 def is_forwarding @is_forwarding end |
#is_listening ⇒ BOOLEAN
[Required] A Boolean flag indicating whether or not the resolver endpoint is for listening.
54 55 56 |
# File 'lib/oci/dns/models/resolver_endpoint.rb', line 54 def is_listening @is_listening end |
#lifecycle_state ⇒ String
[Required] The current state of the resource.
86 87 88 |
# File 'lib/oci/dns/models/resolver_endpoint.rb', line 86 def lifecycle_state @lifecycle_state end |
#listening_address ⇒ String
An IP address to listen to queries on. For VNIC endpoints this IP address must be part of the subnet and will be assigned by the system if unspecified when isListening is true.
60 61 62 |
# File 'lib/oci/dns/models/resolver_endpoint.rb', line 60 def listening_address @listening_address end |
#name ⇒ String
[Required] The name of the resolver endpoint. Must be unique, case-insensitive, within the resolver.
33 34 35 |
# File 'lib/oci/dns/models/resolver_endpoint.rb', line 33 def name @name end |
#time_created ⇒ DateTime
[Required] The date and time the resource was created in "YYYY-MM-ddThh:mm:ssZ" format with a Z offset, as defined by RFC 3339.
Example: 2016-07-22T17:23:59:60Z
74 75 76 |
# File 'lib/oci/dns/models/resolver_endpoint.rb', line 74 def time_created @time_created end |
#time_updated ⇒ DateTime
[Required] The date and time the resource was last updated in "YYYY-MM-ddThh:mm:ssZ" format with a Z offset, as defined by RFC 3339.
Example: 2016-07-22T17:23:59:60Z
82 83 84 |
# File 'lib/oci/dns/models/resolver_endpoint.rb', line 82 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/oci/dns/models/resolver_endpoint.rb', line 93 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'endpoint_type': :'endpointType', 'forwarding_address': :'forwardingAddress', 'is_forwarding': :'isForwarding', 'is_listening': :'isListening', 'listening_address': :'listeningAddress', 'compartment_id': :'compartmentId', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', '_self': :'self' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
135 136 137 138 139 140 141 142 |
# File 'lib/oci/dns/models/resolver_endpoint.rb', line 135 def self.get_subtype(object_hash) type = object_hash[:'endpointType'] # rubocop:disable Style/SymbolLiteral return 'OCI::Dns::Models::ResolverVnicEndpoint' if type == 'VNIC' # TODO: Log a warning when the subtype is not found. 'OCI::Dns::Models::ResolverEndpoint' end |
.swagger_types ⇒ Object
Attribute type mapping.
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/oci/dns/models/resolver_endpoint.rb', line 112 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'endpoint_type': :'String', 'forwarding_address': :'String', 'is_forwarding': :'BOOLEAN', 'is_listening': :'BOOLEAN', 'listening_address': :'String', 'compartment_id': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', '_self': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/oci/dns/models/resolver_endpoint.rb', line 266 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && endpoint_type == other.endpoint_type && forwarding_address == other.forwarding_address && is_forwarding == other.is_forwarding && is_listening == other.is_listening && listening_address == other.listening_address && compartment_id == other.compartment_id && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && _self == other._self end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 |
# File 'lib/oci/dns/models/resolver_endpoint.rb', line 306 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
286 287 288 |
# File 'lib/oci/dns/models/resolver_endpoint.rb', line 286 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
295 296 297 |
# File 'lib/oci/dns/models/resolver_endpoint.rb', line 295 def hash [name, endpoint_type, forwarding_address, is_forwarding, is_listening, listening_address, compartment_id, time_created, time_updated, lifecycle_state, _self].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
339 340 341 342 343 344 345 346 347 348 |
# File 'lib/oci/dns/models/resolver_endpoint.rb', line 339 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
333 334 335 |
# File 'lib/oci/dns/models/resolver_endpoint.rb', line 333 def to_s to_hash.to_s end |