Class: OCI::Dns::Models::ResolverForwardRule
- Inherits:
-
ResolverRule
- Object
- ResolverRule
- OCI::Dns::Models::ResolverForwardRule
- Defined in:
- lib/oci/dns/models/resolver_forward_rule.rb
Overview
ResolverForwardRule model.
Constant Summary
Constants inherited from ResolverRule
OCI::Dns::Models::ResolverRule::ACTION_ENUM
Instance Attribute Summary collapse
-
#destination_addresses ⇒ Array<String>
[Required] IP addresses to which queries should be forwarded.
-
#source_endpoint_name ⇒ String
Name of an endpoint, that is a sub-resource of the resolver, to use as the forwarding interface.
Attributes inherited from ResolverRule
#action, #client_address_conditions, #qname_cover_conditions
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ResolverForwardRule
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from ResolverRule
Constructor Details
#initialize(attributes = {}) ⇒ ResolverForwardRule
Initializes the object
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/oci/dns/models/resolver_forward_rule.rb', line 58 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['action'] = 'FORWARD' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.destination_addresses = attributes[:'destinationAddresses'] if attributes[:'destinationAddresses'] raise 'You cannot provide both :destinationAddresses and :destination_addresses' if attributes.key?(:'destinationAddresses') && attributes.key?(:'destination_addresses') self.destination_addresses = attributes[:'destination_addresses'] if attributes[:'destination_addresses'] self.source_endpoint_name = attributes[:'sourceEndpointName'] if attributes[:'sourceEndpointName'] raise 'You cannot provide both :sourceEndpointName and :source_endpoint_name' if attributes.key?(:'sourceEndpointName') && attributes.key?(:'source_endpoint_name') self.source_endpoint_name = attributes[:'source_endpoint_name'] if attributes[:'source_endpoint_name'] end |
Instance Attribute Details
#destination_addresses ⇒ Array<String>
[Required] IP addresses to which queries should be forwarded. Currently limited to a single address.
14 15 16 |
# File 'lib/oci/dns/models/resolver_forward_rule.rb', line 14 def destination_addresses @destination_addresses end |
#source_endpoint_name ⇒ String
Name of an endpoint, that is a sub-resource of the resolver, to use as the forwarding interface. The endpoint must have isForwarding set to true.
20 21 22 |
# File 'lib/oci/dns/models/resolver_forward_rule.rb', line 20 def source_endpoint_name @source_endpoint_name end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
23 24 25 26 27 28 29 30 31 32 33 |
# File 'lib/oci/dns/models/resolver_forward_rule.rb', line 23 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'client_address_conditions': :'clientAddressConditions', 'qname_cover_conditions': :'qnameCoverConditions', 'action': :'action', 'destination_addresses': :'destinationAddresses', 'source_endpoint_name': :'sourceEndpointName' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/oci/dns/models/resolver_forward_rule.rb', line 36 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'client_address_conditions': :'Array<String>', 'qname_cover_conditions': :'Array<String>', 'action': :'String', 'destination_addresses': :'Array<String>', 'source_endpoint_name': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
88 89 90 91 92 93 94 95 96 97 |
# File 'lib/oci/dns/models/resolver_forward_rule.rb', line 88 def ==(other) return true if equal?(other) self.class == other.class && client_address_conditions == other.client_address_conditions && qname_cover_conditions == other.qname_cover_conditions && action == other.action && destination_addresses == other.destination_addresses && source_endpoint_name == other.source_endpoint_name end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/oci/dns/models/resolver_forward_rule.rb', line 122 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
102 103 104 |
# File 'lib/oci/dns/models/resolver_forward_rule.rb', line 102 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
111 112 113 |
# File 'lib/oci/dns/models/resolver_forward_rule.rb', line 111 def hash [client_address_conditions, qname_cover_conditions, action, destination_addresses, source_endpoint_name].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
155 156 157 158 159 160 161 162 163 164 |
# File 'lib/oci/dns/models/resolver_forward_rule.rb', line 155 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
149 150 151 |
# File 'lib/oci/dns/models/resolver_forward_rule.rb', line 149 def to_s to_hash.to_s end |