Class: OCI::Dns::Models::ResolverRule
- Inherits:
-
Object
- Object
- OCI::Dns::Models::ResolverRule
- Defined in:
- lib/oci/dns/models/resolver_rule.rb
Overview
A rule for a resolver. Specifying both qnameCoverConditions and clientAddressConditions is not allowed.
Warning: Oracle recommends that you avoid using any confidential information when you supply string values using the API.
This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
Constant Summary collapse
- ACTION_ENUM =
[ ACTION_FORWARD = 'FORWARD'.freeze, ACTION_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#action ⇒ String
[Required] The action determines the behavior of the rule.
-
#client_address_conditions ⇒ Array<String>
[Required] A list of CIDR blocks.
-
#qname_cover_conditions ⇒ Array<String>
[Required] A list of domain names.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ResolverRule
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ResolverRule
Initializes the object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/oci/dns/models/resolver_rule.rb', line 84 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.client_address_conditions = attributes[:'clientAddressConditions'] if attributes[:'clientAddressConditions'] raise 'You cannot provide both :clientAddressConditions and :client_address_conditions' if attributes.key?(:'clientAddressConditions') && attributes.key?(:'client_address_conditions') self.client_address_conditions = attributes[:'client_address_conditions'] if attributes[:'client_address_conditions'] self.qname_cover_conditions = attributes[:'qnameCoverConditions'] if attributes[:'qnameCoverConditions'] raise 'You cannot provide both :qnameCoverConditions and :qname_cover_conditions' if attributes.key?(:'qnameCoverConditions') && attributes.key?(:'qname_cover_conditions') self.qname_cover_conditions = attributes[:'qname_cover_conditions'] if attributes[:'qname_cover_conditions'] self.action = attributes[:'action'] if attributes[:'action'] end |
Instance Attribute Details
#action ⇒ String
[Required] The action determines the behavior of the rule. If a query matches a supplied condition then the action will apply. If there are no conditions on the rule then all queries are subject to the specified action.
-
FORWARD- Matching requests will be forwarded from the source interface to the destination address.
36 37 38 |
# File 'lib/oci/dns/models/resolver_rule.rb', line 36 def action @action end |
#client_address_conditions ⇒ Array<String>
[Required] A list of CIDR blocks. The query must come from a client within one of the blocks in order for the rule action to apply.
24 25 26 |
# File 'lib/oci/dns/models/resolver_rule.rb', line 24 def client_address_conditions @client_address_conditions end |
#qname_cover_conditions ⇒ Array<String>
[Required] A list of domain names. The query must be covered by one of the domains in order for the rule action to apply.
29 30 31 |
# File 'lib/oci/dns/models/resolver_rule.rb', line 29 def qname_cover_conditions @qname_cover_conditions end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 |
# File 'lib/oci/dns/models/resolver_rule.rb', line 39 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'client_address_conditions': :'clientAddressConditions', 'qname_cover_conditions': :'qnameCoverConditions', 'action': :'action' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
65 66 67 68 69 70 71 72 |
# File 'lib/oci/dns/models/resolver_rule.rb', line 65 def self.get_subtype(object_hash) type = object_hash[:'action'] # rubocop:disable Style/SymbolLiteral return 'OCI::Dns::Models::ResolverForwardRule' if type == 'FORWARD' # TODO: Log a warning when the subtype is not found. 'OCI::Dns::Models::ResolverRule' end |
.swagger_types ⇒ Object
Attribute type mapping.
50 51 52 53 54 55 56 57 58 |
# File 'lib/oci/dns/models/resolver_rule.rb', line 50 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'client_address_conditions': :'Array<String>', 'qname_cover_conditions': :'Array<String>', 'action': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
125 126 127 128 129 130 131 132 |
# File 'lib/oci/dns/models/resolver_rule.rb', line 125 def ==(other) return true if equal?(other) self.class == other.class && client_address_conditions == other.client_address_conditions && qname_cover_conditions == other.qname_cover_conditions && action == other.action end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/oci/dns/models/resolver_rule.rb', line 157 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
137 138 139 |
# File 'lib/oci/dns/models/resolver_rule.rb', line 137 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
146 147 148 |
# File 'lib/oci/dns/models/resolver_rule.rb', line 146 def hash [client_address_conditions, qname_cover_conditions, action].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
190 191 192 193 194 195 196 197 198 199 |
# File 'lib/oci/dns/models/resolver_rule.rb', line 190 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
184 185 186 |
# File 'lib/oci/dns/models/resolver_rule.rb', line 184 def to_s to_hash.to_s end |