Class: OCI::Dns::Models::ResolverRuleDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/dns/models/resolver_rule_details.rb

Overview

A rule for a resolver. Specifying both qnameCoverConditions and clientAddressConditions is not allowed.

Warning: Oracle recommends that you avoid using any confidential information when you supply string values using the API.

This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class

Direct Known Subclasses

ResolverForwardRuleDetails

Constant Summary collapse

ACTION_ENUM =
[
  ACTION_FORWARD = 'FORWARD'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ResolverRuleDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :client_address_conditions (Array<String>)

    The value to assign to the #client_address_conditions property

  • :qname_cover_conditions (Array<String>)

    The value to assign to the #qname_cover_conditions property

  • :action (String)

    The value to assign to the #action property



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/oci/dns/models/resolver_rule_details.rb', line 82

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.client_address_conditions = attributes[:'clientAddressConditions'] if attributes[:'clientAddressConditions']

  raise 'You cannot provide both :clientAddressConditions and :client_address_conditions' if attributes.key?(:'clientAddressConditions') && attributes.key?(:'client_address_conditions')

  self.client_address_conditions = attributes[:'client_address_conditions'] if attributes[:'client_address_conditions']

  self.qname_cover_conditions = attributes[:'qnameCoverConditions'] if attributes[:'qnameCoverConditions']

  raise 'You cannot provide both :qnameCoverConditions and :qname_cover_conditions' if attributes.key?(:'qnameCoverConditions') && attributes.key?(:'qname_cover_conditions')

  self.qname_cover_conditions = attributes[:'qname_cover_conditions'] if attributes[:'qname_cover_conditions']

  self.action = attributes[:'action'] if attributes[:'action']
end

Instance Attribute Details

#actionString

[Required] The action determines the behavior of the rule. If a query matches a supplied condition, the action will apply. If there are no conditions on the rule, all queries are subject to the specified action.

  • FORWARD - Matching requests will be forwarded from the source interface to the destination address.

Returns:

  • (String)


34
35
36
# File 'lib/oci/dns/models/resolver_rule_details.rb', line 34

def action
  @action
end

#client_address_conditionsArray<String>

A list of CIDR blocks. The query must come from a client within one of the blocks in order for the rule action to apply.

Returns:

  • (Array<String>)


22
23
24
# File 'lib/oci/dns/models/resolver_rule_details.rb', line 22

def client_address_conditions
  @client_address_conditions
end

#qname_cover_conditionsArray<String>

A list of domain names. The query must be covered by one of the domains in order for the rule action to apply.

Returns:

  • (Array<String>)


27
28
29
# File 'lib/oci/dns/models/resolver_rule_details.rb', line 27

def qname_cover_conditions
  @qname_cover_conditions
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
# File 'lib/oci/dns/models/resolver_rule_details.rb', line 37

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'client_address_conditions': :'clientAddressConditions',
    'qname_cover_conditions': :'qnameCoverConditions',
    'action': :'action'
    # rubocop:enable Style/SymbolLiteral
  }
end

.get_subtype(object_hash) ⇒ Object

Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.



63
64
65
66
67
68
69
70
# File 'lib/oci/dns/models/resolver_rule_details.rb', line 63

def self.get_subtype(object_hash)
  type = object_hash[:'action'] # rubocop:disable Style/SymbolLiteral

  return 'OCI::Dns::Models::ResolverForwardRuleDetails' if type == 'FORWARD'

  # TODO: Log a warning when the subtype is not found.
  'OCI::Dns::Models::ResolverRuleDetails'
end

.swagger_typesObject

Attribute type mapping.



48
49
50
51
52
53
54
55
56
# File 'lib/oci/dns/models/resolver_rule_details.rb', line 48

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'client_address_conditions': :'Array<String>',
    'qname_cover_conditions': :'Array<String>',
    'action': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



118
119
120
121
122
123
124
125
# File 'lib/oci/dns/models/resolver_rule_details.rb', line 118

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    client_address_conditions == other.client_address_conditions &&
    qname_cover_conditions == other.qname_cover_conditions &&
    action == other.action
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/oci/dns/models/resolver_rule_details.rb', line 150

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


130
131
132
# File 'lib/oci/dns/models/resolver_rule_details.rb', line 130

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



139
140
141
# File 'lib/oci/dns/models/resolver_rule_details.rb', line 139

def hash
  [client_address_conditions, qname_cover_conditions, action].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



183
184
185
186
187
188
189
190
191
192
# File 'lib/oci/dns/models/resolver_rule_details.rb', line 183

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



177
178
179
# File 'lib/oci/dns/models/resolver_rule_details.rb', line 177

def to_s
  to_hash.to_s
end