Class: OCI::Dns::Models::ResolverSummary
- Inherits:
-
Object
- Object
- OCI::Dns::Models::ResolverSummary
- Defined in:
- lib/oci/dns/models/resolver_summary.rb
Overview
An OCI DNS resolver. If the resolver has an attached VCN then the VCN will attempt to answer queries based on the attached views in priority order. If the query does not match any of the attached views then the query will be evaluated against the default view. If the default view does not match then the rules will be evaluated in priority order. If no rules match the query then answers come from Internet DNS. A resolver may have at most 10 resolver endpoints.
Warning: Oracle recommends that you avoid using any confidential information when you supply string values using the API.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#_self ⇒ String
[Required] The canonical absolute URL of the resource.
-
#attached_vcn_id ⇒ String
The OCID of the attached VCN.
-
#compartment_id ⇒ String
[Required] The OCID of the owning compartment.
-
#default_view_id ⇒ String
The OCID of the default view.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
[Required] Defined tags for this resource.
-
#display_name ⇒ String
[Required] The display name of the resolver.
-
#freeform_tags ⇒ Hash<String, String>
[Required] Free-form tags for this resource.
-
#id ⇒ String
[Required] The OCID of the resolver.
-
#is_protected ⇒ BOOLEAN
[Required] A Boolean flag indicating whether or not parts of the resource are unable to be explicitly managed.
-
#lifecycle_state ⇒ String
[Required] The current state of the resource.
-
#time_created ⇒ DateTime
[Required] The date and time the resource was created in "YYYY-MM-ddThh:mm:ssZ" format with a Z offset, as defined by RFC 3339.
-
#time_updated ⇒ DateTime
[Required] The date and time the resource was last updated in "YYYY-MM-ddThh:mm:ssZ" format with a Z offset, as defined by RFC 3339.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ResolverSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ResolverSummary
Initializes the object
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/oci/dns/models/resolver_summary.rb', line 156 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.attached_vcn_id = attributes[:'attachedVcnId'] if attributes[:'attachedVcnId'] raise 'You cannot provide both :attachedVcnId and :attached_vcn_id' if attributes.key?(:'attachedVcnId') && attributes.key?(:'attached_vcn_id') self.attached_vcn_id = attributes[:'attached_vcn_id'] if attributes[:'attached_vcn_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.id = attributes[:'id'] if attributes[:'id'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self._self = attributes[:'self'] if attributes[:'self'] raise 'You cannot provide both :self and :_self' if attributes.key?(:'self') && attributes.key?(:'_self') self._self = attributes[:'_self'] if attributes[:'_self'] self.default_view_id = attributes[:'defaultViewId'] if attributes[:'defaultViewId'] raise 'You cannot provide both :defaultViewId and :default_view_id' if attributes.key?(:'defaultViewId') && attributes.key?(:'default_view_id') self.default_view_id = attributes[:'default_view_id'] if attributes[:'default_view_id'] self.is_protected = attributes[:'isProtected'] unless attributes[:'isProtected'].nil? raise 'You cannot provide both :isProtected and :is_protected' if attributes.key?(:'isProtected') && attributes.key?(:'is_protected') self.is_protected = attributes[:'is_protected'] unless attributes[:'is_protected'].nil? end |
Instance Attribute Details
#_self ⇒ String
[Required] The canonical absolute URL of the resource.
86 87 88 |
# File 'lib/oci/dns/models/resolver_summary.rb', line 86 def _self @_self end |
#attached_vcn_id ⇒ String
The OCID of the attached VCN.
35 36 37 |
# File 'lib/oci/dns/models/resolver_summary.rb', line 35 def attached_vcn_id @attached_vcn_id end |
#compartment_id ⇒ String
[Required] The OCID of the owning compartment.
30 31 32 |
# File 'lib/oci/dns/models/resolver_summary.rb', line 30 def compartment_id @compartment_id end |
#default_view_id ⇒ String
The OCID of the default view.
91 92 93 |
# File 'lib/oci/dns/models/resolver_summary.rb', line 91 def default_view_id @default_view_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
[Required] Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
58 59 60 |
# File 'lib/oci/dns/models/resolver_summary.rb', line 58 def @defined_tags end |
#display_name ⇒ String
[Required] The display name of the resolver.
40 41 42 |
# File 'lib/oci/dns/models/resolver_summary.rb', line 40 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
[Required] Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
49 50 51 |
# File 'lib/oci/dns/models/resolver_summary.rb', line 49 def @freeform_tags end |
#id ⇒ String
[Required] The OCID of the resolver.
62 63 64 |
# File 'lib/oci/dns/models/resolver_summary.rb', line 62 def id @id end |
#is_protected ⇒ BOOLEAN
[Required] A Boolean flag indicating whether or not parts of the resource are unable to be explicitly managed.
96 97 98 |
# File 'lib/oci/dns/models/resolver_summary.rb', line 96 def is_protected @is_protected end |
#lifecycle_state ⇒ String
[Required] The current state of the resource.
82 83 84 |
# File 'lib/oci/dns/models/resolver_summary.rb', line 82 def lifecycle_state @lifecycle_state end |
#time_created ⇒ DateTime
[Required] The date and time the resource was created in "YYYY-MM-ddThh:mm:ssZ" format with a Z offset, as defined by RFC 3339.
Example: 2016-07-22T17:23:59:60Z
70 71 72 |
# File 'lib/oci/dns/models/resolver_summary.rb', line 70 def time_created @time_created end |
#time_updated ⇒ DateTime
[Required] The date and time the resource was last updated in "YYYY-MM-ddThh:mm:ssZ" format with a Z offset, as defined by RFC 3339.
Example: 2016-07-22T17:23:59:60Z
78 79 80 |
# File 'lib/oci/dns/models/resolver_summary.rb', line 78 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/oci/dns/models/resolver_summary.rb', line 99 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'attached_vcn_id': :'attachedVcnId', 'display_name': :'displayName', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'id': :'id', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', '_self': :'self', 'default_view_id': :'defaultViewId', 'is_protected': :'isProtected' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/oci/dns/models/resolver_summary.rb', line 119 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'attached_vcn_id': :'String', 'display_name': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'id': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', '_self': :'String', 'default_view_id': :'String', 'is_protected': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'lib/oci/dns/models/resolver_summary.rb', line 251 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && attached_vcn_id == other.attached_vcn_id && display_name == other.display_name && == other. && == other. && id == other.id && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && _self == other._self && default_view_id == other.default_view_id && is_protected == other.is_protected end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 |
# File 'lib/oci/dns/models/resolver_summary.rb', line 292 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
272 273 274 |
# File 'lib/oci/dns/models/resolver_summary.rb', line 272 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
281 282 283 |
# File 'lib/oci/dns/models/resolver_summary.rb', line 281 def hash [compartment_id, attached_vcn_id, display_name, , , id, time_created, time_updated, lifecycle_state, _self, default_view_id, is_protected].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
325 326 327 328 329 330 331 332 333 334 |
# File 'lib/oci/dns/models/resolver_summary.rb', line 325 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
319 320 321 |
# File 'lib/oci/dns/models/resolver_summary.rb', line 319 def to_s to_hash.to_s end |