Class: OCI::Dns::Models::SteeringPolicyPriorityAnswerData

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/dns/models/steering_policy_priority_answer_data.rb

Overview

SteeringPolicyPriorityAnswerData model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ SteeringPolicyPriorityAnswerData

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :answer_condition (String)

    The value to assign to the #answer_condition property

  • :value (Integer)

    The value to assign to the #value property



49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/oci/dns/models/steering_policy_priority_answer_data.rb', line 49

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.answer_condition = attributes[:'answerCondition'] if attributes[:'answerCondition']

  raise 'You cannot provide both :answerCondition and :answer_condition' if attributes.key?(:'answerCondition') && attributes.key?(:'answer_condition')

  self.answer_condition = attributes[:'answer_condition'] if attributes[:'answer_condition']

  self.value = attributes[:'value'] if attributes[:'value']
end

Instance Attribute Details

#answer_conditionString

An expression that is used to select a set of answers that match a condition. For example, answers with matching pool properties.

Returns:

  • (String)


12
13
14
# File 'lib/oci/dns/models/steering_policy_priority_answer_data.rb', line 12

def answer_condition
  @answer_condition
end

#valueInteger

[Required] The rank assigned to the set of answers that match the expression in answerCondition. Answers with the lowest values move to the beginning of the list without changing the relative order of those with the same value. Answers can be given a value between 0 and 255.

Returns:

  • (Integer)


19
20
21
# File 'lib/oci/dns/models/steering_policy_priority_answer_data.rb', line 19

def value
  @value
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



22
23
24
25
26
27
28
29
# File 'lib/oci/dns/models/steering_policy_priority_answer_data.rb', line 22

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'answer_condition': :'answerCondition',
    'value': :'value'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



32
33
34
35
36
37
38
39
# File 'lib/oci/dns/models/steering_policy_priority_answer_data.rb', line 32

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'answer_condition': :'String',
    'value': :'Integer'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



71
72
73
74
75
76
77
# File 'lib/oci/dns/models/steering_policy_priority_answer_data.rb', line 71

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    answer_condition == other.answer_condition &&
    value == other.value
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/oci/dns/models/steering_policy_priority_answer_data.rb', line 102

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


82
83
84
# File 'lib/oci/dns/models/steering_policy_priority_answer_data.rb', line 82

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



91
92
93
# File 'lib/oci/dns/models/steering_policy_priority_answer_data.rb', line 91

def hash
  [answer_condition, value].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



135
136
137
138
139
140
141
142
143
144
# File 'lib/oci/dns/models/steering_policy_priority_answer_data.rb', line 135

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



129
130
131
# File 'lib/oci/dns/models/steering_policy_priority_answer_data.rb', line 129

def to_s
  to_hash.to_s
end