Class: OCI::Dns::Models::TsigKey
- Inherits:
-
Object
- Object
- OCI::Dns::Models::TsigKey
- Defined in:
- lib/oci/dns/models/tsig_key.rb
Overview
A TSIG key. *Warning:* Oracle recommends that you avoid using any confidential information when you supply string values using the API.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#_self ⇒ String
**[Required]** The canonical absolute URL of the resource.
-
#algorithm ⇒ String
**[Required]** TSIG key algorithms are encoded as domain names, but most consist of only one non-empty label, which is not required to be explicitly absolute.
-
#compartment_id ⇒ String
**[Required]** The OCID of the compartment containing the TSIG key.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
**[Required]** Defined tags for this resource.
-
#freeform_tags ⇒ Hash<String, String>
**[Required]** Free-form tags for this resource.
-
#id ⇒ String
**[Required]** The OCID of the resource.
-
#lifecycle_state ⇒ String
**[Required]** The current state of the resource.
-
#name ⇒ String
**[Required]** A globally unique domain name identifying the key for a given pair of hosts.
-
#secret ⇒ String
**[Required]** A base64 string encoding the binary shared secret.
-
#time_created ⇒ DateTime
**[Required]** The date and time the resource was created, expressed in RFC 3339 timestamp format.
-
#time_updated ⇒ DateTime
The date and time the resource was last updated, expressed in RFC 3339 timestamp format.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TsigKey
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ TsigKey
Initializes the object
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/oci/dns/models/tsig_key.rb', line 142 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.algorithm = attributes[:'algorithm'] if attributes[:'algorithm'] self.name = attributes[:'name'] if attributes[:'name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.secret = attributes[:'secret'] if attributes[:'secret'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.id = attributes[:'id'] if attributes[:'id'] self._self = attributes[:'self'] if attributes[:'self'] raise 'You cannot provide both :self and :_self' if attributes.key?(:'self') && attributes.key?(:'_self') self._self = attributes[:'_self'] if attributes[:'_self'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] end |
Instance Attribute Details
#_self ⇒ String
**[Required]** The canonical absolute URL of the resource.
67 68 69 |
# File 'lib/oci/dns/models/tsig_key.rb', line 67 def _self @_self end |
#algorithm ⇒ String
**[Required]** TSIG key algorithms are encoded as domain names, but most consist of only one non-empty label, which is not required to be explicitly absolute. Applicable algorithms include: hmac-sha1, hmac-sha224, hmac-sha256, hmac-sha512. For more information on these algorithms, see [RFC 4635](tools.ietf.org/html/rfc4635#section-2).
29 30 31 |
# File 'lib/oci/dns/models/tsig_key.rb', line 29 def algorithm @algorithm end |
#compartment_id ⇒ String
**[Required]** The OCID of the compartment containing the TSIG key.
37 38 39 |
# File 'lib/oci/dns/models/tsig_key.rb', line 37 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
**[Required]** Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
*Example:* `{"CostCenter": "42"}`
59 60 61 |
# File 'lib/oci/dns/models/tsig_key.rb', line 59 def @defined_tags end |
#freeform_tags ⇒ Hash<String, String>
**[Required]** Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
*Example:* `"Finance"`
50 51 52 |
# File 'lib/oci/dns/models/tsig_key.rb', line 50 def @freeform_tags end |
#id ⇒ String
**[Required]** The OCID of the resource.
63 64 65 |
# File 'lib/oci/dns/models/tsig_key.rb', line 63 def id @id end |
#lifecycle_state ⇒ String
**[Required]** The current state of the resource.
78 79 80 |
# File 'lib/oci/dns/models/tsig_key.rb', line 78 def lifecycle_state @lifecycle_state end |
#name ⇒ String
**[Required]** A globally unique domain name identifying the key for a given pair of hosts.
33 34 35 |
# File 'lib/oci/dns/models/tsig_key.rb', line 33 def name @name end |
#secret ⇒ String
**[Required]** A base64 string encoding the binary shared secret.
41 42 43 |
# File 'lib/oci/dns/models/tsig_key.rb', line 41 def secret @secret end |
#time_created ⇒ DateTime
**[Required]** The date and time the resource was created, expressed in RFC 3339 timestamp format.
*Example:* `2016-07-22T17:23:59:60Z`
74 75 76 |
# File 'lib/oci/dns/models/tsig_key.rb', line 74 def time_created @time_created end |
#time_updated ⇒ DateTime
The date and time the resource was last updated, expressed in RFC 3339 timestamp format.
*Example:* `2016-07-22T17:23:59:60Z`
85 86 87 |
# File 'lib/oci/dns/models/tsig_key.rb', line 85 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/oci/dns/models/tsig_key.rb', line 88 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'algorithm': :'algorithm', 'name': :'name', 'compartment_id': :'compartmentId', 'secret': :'secret', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'id': :'id', '_self': :'self', 'time_created': :'timeCreated', 'lifecycle_state': :'lifecycleState', 'time_updated': :'timeUpdated' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/oci/dns/models/tsig_key.rb', line 107 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'algorithm': :'String', 'name': :'String', 'compartment_id': :'String', 'secret': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'id': :'String', '_self': :'String', 'time_created': :'DateTime', 'lifecycle_state': :'String', 'time_updated': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/oci/dns/models/tsig_key.rb', line 219 def ==(other) return true if equal?(other) self.class == other.class && algorithm == other.algorithm && name == other.name && compartment_id == other.compartment_id && secret == other.secret && == other. && == other. && id == other.id && _self == other._self && time_created == other.time_created && lifecycle_state == other.lifecycle_state && time_updated == other.time_updated end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/oci/dns/models/tsig_key.rb', line 259 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
239 240 241 |
# File 'lib/oci/dns/models/tsig_key.rb', line 239 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
248 249 250 |
# File 'lib/oci/dns/models/tsig_key.rb', line 248 def hash [algorithm, name, compartment_id, secret, , , id, _self, time_created, lifecycle_state, time_updated].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
292 293 294 295 296 297 298 299 300 301 |
# File 'lib/oci/dns/models/tsig_key.rb', line 292 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
286 287 288 |
# File 'lib/oci/dns/models/tsig_key.rb', line 286 def to_s to_hash.to_s end |