Class: OCI::Dns::Models::TsigKeySummary
- Inherits:
-
Object
- Object
- OCI::Dns::Models::TsigKeySummary
- Defined in:
- lib/oci/dns/models/tsig_key_summary.rb
Overview
A TSIG key.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#_self ⇒ String
**[Required]** The canonical absolute URL of the resource.
-
#algorithm ⇒ String
**[Required]** TSIG key algorithms are encoded as domain names, but most consist of only one non-empty label, which is not required to be explicitly absolute.
-
#compartment_id ⇒ String
**[Required]** The OCID of the compartment containing the TSIG key.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
**[Required]** Defined tags for this resource.
-
#freeform_tags ⇒ Hash<String, String>
**[Required]** Free-form tags for this resource.
-
#id ⇒ String
**[Required]** The OCID of the resource.
-
#lifecycle_state ⇒ String
**[Required]** The current state of the resource.
-
#name ⇒ String
**[Required]** A globally unique domain name identifying the key for a given pair of hosts.
-
#time_created ⇒ DateTime
**[Required]** The date and time the resource was created, expressed in RFC 3339 timestamp format.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TsigKeySummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ TsigKeySummary
Initializes the object
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/oci/dns/models/tsig_key_summary.rb', line 123 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.algorithm = attributes[:'algorithm'] if attributes[:'algorithm'] self.name = attributes[:'name'] if attributes[:'name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.id = attributes[:'id'] if attributes[:'id'] self._self = attributes[:'self'] if attributes[:'self'] raise 'You cannot provide both :self and :_self' if attributes.key?(:'self') && attributes.key?(:'_self') self._self = attributes[:'_self'] if attributes[:'_self'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] end |
Instance Attribute Details
#_self ⇒ String
**[Required]** The canonical absolute URL of the resource.
61 62 63 |
# File 'lib/oci/dns/models/tsig_key_summary.rb', line 61 def _self @_self end |
#algorithm ⇒ String
**[Required]** TSIG key algorithms are encoded as domain names, but most consist of only one non-empty label, which is not required to be explicitly absolute. Applicable algorithms include: hmac-sha1, hmac-sha224, hmac-sha256, hmac-sha512. For more information on these algorithms, see [RFC 4635](tools.ietf.org/html/rfc4635#section-2).
27 28 29 |
# File 'lib/oci/dns/models/tsig_key_summary.rb', line 27 def algorithm @algorithm end |
#compartment_id ⇒ String
**[Required]** The OCID of the compartment containing the TSIG key.
35 36 37 |
# File 'lib/oci/dns/models/tsig_key_summary.rb', line 35 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
**[Required]** Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
*Example:* `{"CostCenter": "42"}`
53 54 55 |
# File 'lib/oci/dns/models/tsig_key_summary.rb', line 53 def @defined_tags end |
#freeform_tags ⇒ Hash<String, String>
**[Required]** Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
*Example:* `"Finance"`
44 45 46 |
# File 'lib/oci/dns/models/tsig_key_summary.rb', line 44 def @freeform_tags end |
#id ⇒ String
**[Required]** The OCID of the resource.
57 58 59 |
# File 'lib/oci/dns/models/tsig_key_summary.rb', line 57 def id @id end |
#lifecycle_state ⇒ String
**[Required]** The current state of the resource.
72 73 74 |
# File 'lib/oci/dns/models/tsig_key_summary.rb', line 72 def lifecycle_state @lifecycle_state end |
#name ⇒ String
**[Required]** A globally unique domain name identifying the key for a given pair of hosts.
31 32 33 |
# File 'lib/oci/dns/models/tsig_key_summary.rb', line 31 def name @name end |
#time_created ⇒ DateTime
**[Required]** The date and time the resource was created, expressed in RFC 3339 timestamp format.
*Example:* `2016-07-22T17:23:59:60Z`
68 69 70 |
# File 'lib/oci/dns/models/tsig_key_summary.rb', line 68 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/oci/dns/models/tsig_key_summary.rb', line 75 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'algorithm': :'algorithm', 'name': :'name', 'compartment_id': :'compartmentId', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'id': :'id', '_self': :'self', 'time_created': :'timeCreated', 'lifecycle_state': :'lifecycleState' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/oci/dns/models/tsig_key_summary.rb', line 92 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'algorithm': :'String', 'name': :'String', 'compartment_id': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'id': :'String', '_self': :'String', 'time_created': :'DateTime', 'lifecycle_state': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/oci/dns/models/tsig_key_summary.rb', line 192 def ==(other) return true if equal?(other) self.class == other.class && algorithm == other.algorithm && name == other.name && compartment_id == other.compartment_id && == other. && == other. && id == other.id && _self == other._self && time_created == other.time_created && lifecycle_state == other.lifecycle_state end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/oci/dns/models/tsig_key_summary.rb', line 230 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
210 211 212 |
# File 'lib/oci/dns/models/tsig_key_summary.rb', line 210 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
219 220 221 |
# File 'lib/oci/dns/models/tsig_key_summary.rb', line 219 def hash [algorithm, name, compartment_id, , , id, _self, time_created, lifecycle_state].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
263 264 265 266 267 268 269 270 271 272 |
# File 'lib/oci/dns/models/tsig_key_summary.rb', line 263 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
257 258 259 |
# File 'lib/oci/dns/models/tsig_key_summary.rb', line 257 def to_s to_hash.to_s end |