Class: OCI::Dns::Models::UpdateResolverEndpointDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/dns/models/update_resolver_endpoint_details.rb

Overview

The body for updating an existing resolver endpoint.

Warning: Oracle recommends that you avoid using any confidential information when you supply string values using the API.

This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class

Direct Known Subclasses

UpdateResolverVnicEndpointDetails

Constant Summary collapse

ENDPOINT_TYPE_ENUM =
[
  ENDPOINT_TYPE_VNIC = 'VNIC'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateResolverEndpointDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :endpoint_type (String)

    The value to assign to the #endpoint_type property



63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/oci/dns/models/update_resolver_endpoint_details.rb', line 63

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.endpoint_type = attributes[:'endpointType'] if attributes[:'endpointType']
  self.endpoint_type = "VNIC" if endpoint_type.nil? && !attributes.key?(:'endpointType') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :endpointType and :endpoint_type' if attributes.key?(:'endpointType') && attributes.key?(:'endpoint_type')

  self.endpoint_type = attributes[:'endpoint_type'] if attributes[:'endpoint_type']
  self.endpoint_type = "VNIC" if endpoint_type.nil? && !attributes.key?(:'endpointType') && !attributes.key?(:'endpoint_type') # rubocop:disable Style/StringLiterals
end

Instance Attribute Details

#endpoint_typeString

The type of resolver endpoint. VNIC is currently the only supported type.

Returns:

  • (String)


21
22
23
# File 'lib/oci/dns/models/update_resolver_endpoint_details.rb', line 21

def endpoint_type
  @endpoint_type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



24
25
26
27
28
29
30
# File 'lib/oci/dns/models/update_resolver_endpoint_details.rb', line 24

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'endpoint_type': :'endpointType'
    # rubocop:enable Style/SymbolLiteral
  }
end

.get_subtype(object_hash) ⇒ Object

Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.



46
47
48
49
50
51
52
53
# File 'lib/oci/dns/models/update_resolver_endpoint_details.rb', line 46

def self.get_subtype(object_hash)
  type = object_hash[:'endpointType'] # rubocop:disable Style/SymbolLiteral

  return 'OCI::Dns::Models::UpdateResolverVnicEndpointDetails' if type == 'VNIC'

  # TODO: Log a warning when the subtype is not found.
  'OCI::Dns::Models::UpdateResolverEndpointDetails'
end

.swagger_typesObject

Attribute type mapping.



33
34
35
36
37
38
39
# File 'lib/oci/dns/models/update_resolver_endpoint_details.rb', line 33

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'endpoint_type': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



93
94
95
96
97
98
# File 'lib/oci/dns/models/update_resolver_endpoint_details.rb', line 93

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    endpoint_type == other.endpoint_type
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'lib/oci/dns/models/update_resolver_endpoint_details.rb', line 123

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


103
104
105
# File 'lib/oci/dns/models/update_resolver_endpoint_details.rb', line 103

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



112
113
114
# File 'lib/oci/dns/models/update_resolver_endpoint_details.rb', line 112

def hash
  [endpoint_type].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



156
157
158
159
160
161
162
163
164
165
# File 'lib/oci/dns/models/update_resolver_endpoint_details.rb', line 156

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



150
151
152
# File 'lib/oci/dns/models/update_resolver_endpoint_details.rb', line 150

def to_s
  to_hash.to_s
end