Class: OCI::Dns::Models::Zone

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/dns/models/zone.rb

Overview

A DNS zone.

*Warning:* Oracle recommends that you avoid using any confidential information when you supply string values using the API.

Constant Summary collapse

ZONE_TYPE_ENUM =
[
  ZONE_TYPE_PRIMARY = 'PRIMARY'.freeze,
  ZONE_TYPE_SECONDARY = 'SECONDARY'.freeze,
  ZONE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
SCOPE_ENUM =
[
  SCOPE_GLOBAL = 'GLOBAL'.freeze,
  SCOPE_PRIVATE = 'PRIVATE'.freeze,
  SCOPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Zone

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
# File 'lib/oci/dns/models/zone.rb', line 203

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.name = attributes[:'name'] if attributes[:'name']

  self.zone_type = attributes[:'zoneType'] if attributes[:'zoneType']

  raise 'You cannot provide both :zoneType and :zone_type' if attributes.key?(:'zoneType') && attributes.key?(:'zone_type')

  self.zone_type = attributes[:'zone_type'] if attributes[:'zone_type']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.view_id = attributes[:'viewId'] if attributes[:'viewId']

  raise 'You cannot provide both :viewId and :view_id' if attributes.key?(:'viewId') && attributes.key?(:'view_id')

  self.view_id = attributes[:'view_id'] if attributes[:'view_id']

  self.scope = attributes[:'scope'] if attributes[:'scope']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.external_masters = attributes[:'externalMasters'] if attributes[:'externalMasters']

  raise 'You cannot provide both :externalMasters and :external_masters' if attributes.key?(:'externalMasters') && attributes.key?(:'external_masters')

  self.external_masters = attributes[:'external_masters'] if attributes[:'external_masters']

  self.self_uri = attributes[:'self'] if attributes[:'self']

  raise 'You cannot provide both :self and :self_uri' if attributes.key?(:'self') && attributes.key?(:'self_uri')

  self.self_uri = attributes[:'self_uri'] if attributes[:'self_uri']

  self.id = attributes[:'id'] if attributes[:'id']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.version = attributes[:'version'] if attributes[:'version']

  self.serial = attributes[:'serial'] if attributes[:'serial']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.is_protected = attributes[:'isProtected'] unless attributes[:'isProtected'].nil?

  raise 'You cannot provide both :isProtected and :is_protected' if attributes.key?(:'isProtected') && attributes.key?(:'is_protected')

  self.is_protected = attributes[:'is_protected'] unless attributes[:'is_protected'].nil?

  self.nameservers = attributes[:'nameservers'] if attributes[:'nameservers']

  self.zone_transfer_servers = attributes[:'zoneTransferServers'] if attributes[:'zoneTransferServers']

  raise 'You cannot provide both :zoneTransferServers and :zone_transfer_servers' if attributes.key?(:'zoneTransferServers') && attributes.key?(:'zone_transfer_servers')

  self.zone_transfer_servers = attributes[:'zone_transfer_servers'] if attributes[:'zone_transfer_servers']
end

Instance Attribute Details

#compartment_idString

**[Required]** The OCID of the compartment containing the zone.

Returns:

  • (String)


47
48
49
# File 'lib/oci/dns/models/zone.rb', line 47

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

**[Required]** Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

*Example:* `{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


76
77
78
# File 'lib/oci/dns/models/zone.rb', line 76

def defined_tags
  @defined_tags
end

#external_mastersArray<OCI::Dns::Models::ExternalMaster>

**[Required]** External master servers for the zone. `externalMasters` becomes a required parameter when the `zoneType` value is `SECONDARY`.



82
83
84
# File 'lib/oci/dns/models/zone.rb', line 82

def external_masters
  @external_masters
end

#freeform_tagsHash<String, String>

**[Required]** Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

*Example:* `"Finance"`

Returns:

  • (Hash<String, String>)


67
68
69
# File 'lib/oci/dns/models/zone.rb', line 67

def freeform_tags
  @freeform_tags
end

#idString

**[Required]** The OCID of the zone.

Returns:

  • (String)


90
91
92
# File 'lib/oci/dns/models/zone.rb', line 90

def id
  @id
end

#is_protectedBOOLEAN

**[Required]** A Boolean flag indicating whether or not parts of the resource are unable to be explicitly managed.

Returns:

  • (BOOLEAN)


119
120
121
# File 'lib/oci/dns/models/zone.rb', line 119

def is_protected
  @is_protected
end

#lifecycle_stateString

**[Required]** The current state of the zone resource.

Returns:

  • (String)


114
115
116
# File 'lib/oci/dns/models/zone.rb', line 114

def lifecycle_state
  @lifecycle_state
end

#nameString

**[Required]** The name of the zone.

Returns:

  • (String)


38
39
40
# File 'lib/oci/dns/models/zone.rb', line 38

def name
  @name
end

#nameserversArray<OCI::Dns::Models::Nameserver>

**[Required]** The authoritative nameservers for the zone.

Returns:



123
124
125
# File 'lib/oci/dns/models/zone.rb', line 123

def nameservers
  @nameservers
end

#scopeString

**[Required]** The scope of the zone.

Returns:

  • (String)


58
59
60
# File 'lib/oci/dns/models/zone.rb', line 58

def scope
  @scope
end

#self_uriString

**[Required]** The canonical absolute URL of the resource.

Returns:

  • (String)


86
87
88
# File 'lib/oci/dns/models/zone.rb', line 86

def self_uri
  @self_uri
end

#serialInteger

**[Required]** The current serial of the zone. As seen in the zone's SOA record.

Returns:

  • (Integer)


110
111
112
# File 'lib/oci/dns/models/zone.rb', line 110

def serial
  @serial
end

#time_createdDateTime

**[Required]** The date and time the resource was created in "YYYY-MM-ddThh:mm:ssZ" format with a Z offset, as defined by RFC 3339.

*Example:* `2016-07-22T17:23:59:60Z`

Returns:

  • (DateTime)


98
99
100
# File 'lib/oci/dns/models/zone.rb', line 98

def time_created
  @time_created
end

#versionString

**[Required]** Version is the never-repeating, totally-orderable, version of the zone, from which the serial field of the zone's SOA record is derived.

Returns:

  • (String)


105
106
107
# File 'lib/oci/dns/models/zone.rb', line 105

def version
  @version
end

#view_idString

The OCID of the private view containing the zone. This value will be null for zones in the global DNS, which are publicly resolvable and not part of a private view.

Returns:

  • (String)


54
55
56
# File 'lib/oci/dns/models/zone.rb', line 54

def view_id
  @view_id
end

#zone_transfer_serversArray<OCI::Dns::Models::ZoneTransferServer>

The OCI nameservers that transfer the zone data with external nameservers.



128
129
130
# File 'lib/oci/dns/models/zone.rb', line 128

def zone_transfer_servers
  @zone_transfer_servers
end

#zone_typeString

**[Required]** The type of the zone. Must be either `PRIMARY` or `SECONDARY`. `SECONDARY` is only supported for GLOBAL zones.

Returns:

  • (String)


43
44
45
# File 'lib/oci/dns/models/zone.rb', line 43

def zone_type
  @zone_type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/oci/dns/models/zone.rb', line 131

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'name': :'name',
    'zone_type': :'zoneType',
    'compartment_id': :'compartmentId',
    'view_id': :'viewId',
    'scope': :'scope',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'external_masters': :'externalMasters',
    'self_uri': :'self',
    'id': :'id',
    'time_created': :'timeCreated',
    'version': :'version',
    'serial': :'serial',
    'lifecycle_state': :'lifecycleState',
    'is_protected': :'isProtected',
    'nameservers': :'nameservers',
    'zone_transfer_servers': :'zoneTransferServers'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/oci/dns/models/zone.rb', line 156

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'name': :'String',
    'zone_type': :'String',
    'compartment_id': :'String',
    'view_id': :'String',
    'scope': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'external_masters': :'Array<OCI::Dns::Models::ExternalMaster>',
    'self_uri': :'String',
    'id': :'String',
    'time_created': :'DateTime',
    'version': :'String',
    'serial': :'Integer',
    'lifecycle_state': :'String',
    'is_protected': :'BOOLEAN',
    'nameservers': :'Array<OCI::Dns::Models::Nameserver>',
    'zone_transfer_servers': :'Array<OCI::Dns::Models::ZoneTransferServer>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
# File 'lib/oci/dns/models/zone.rb', line 334

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    name == other.name &&
    zone_type == other.zone_type &&
    compartment_id == other.compartment_id &&
    view_id == other.view_id &&
    scope == other.scope &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    external_masters == other.external_masters &&
    self_uri == other.self_uri &&
    id == other.id &&
    time_created == other.time_created &&
    version == other.version &&
    serial == other.serial &&
    lifecycle_state == other.lifecycle_state &&
    is_protected == other.is_protected &&
    nameservers == other.nameservers &&
    zone_transfer_servers == other.zone_transfer_servers
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
# File 'lib/oci/dns/models/zone.rb', line 380

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


360
361
362
# File 'lib/oci/dns/models/zone.rb', line 360

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



369
370
371
# File 'lib/oci/dns/models/zone.rb', line 369

def hash
  [name, zone_type, compartment_id, view_id, scope, freeform_tags, defined_tags, external_masters, self_uri, id, time_created, version, serial, lifecycle_state, is_protected, nameservers, zone_transfer_servers].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



413
414
415
416
417
418
419
420
421
422
# File 'lib/oci/dns/models/zone.rb', line 413

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



407
408
409
# File 'lib/oci/dns/models/zone.rb', line 407

def to_s
  to_hash.to_s
end