Class: OCI::Dns::Models::ZoneSummary
- Inherits:
-
Object
- Object
- OCI::Dns::Models::ZoneSummary
- Defined in:
- lib/oci/dns/models/zone_summary.rb
Overview
A DNS zone.
*Warning:* Oracle recommends that you avoid using any confidential information when you supply string values using the API.
Constant Summary collapse
- ZONE_TYPE_ENUM =
[ ZONE_TYPE_PRIMARY = 'PRIMARY'.freeze, ZONE_TYPE_SECONDARY = 'SECONDARY'.freeze, ZONE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- SCOPE_ENUM =
[ SCOPE_GLOBAL = 'GLOBAL'.freeze, SCOPE_PRIVATE = 'PRIVATE'.freeze, SCOPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The OCID of the compartment containing the zone.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
**[Required]** Defined tags for this resource.
-
#freeform_tags ⇒ Hash<String, String>
**[Required]** Free-form tags for this resource.
-
#id ⇒ String
**[Required]** The OCID of the zone.
-
#is_protected ⇒ BOOLEAN
**[Required]** A Boolean flag indicating whether or not parts of the resource are unable to be explicitly managed.
-
#lifecycle_state ⇒ String
**[Required]** The current state of the zone resource.
-
#name ⇒ String
**[Required]** The name of the zone.
-
#scope ⇒ String
**[Required]** The scope of the zone.
-
#self_uri ⇒ String
**[Required]** The canonical absolute URL of the resource.
-
#serial ⇒ Integer
**[Required]** The current serial of the zone.
-
#time_created ⇒ DateTime
**[Required]** The date and time the resource was created in "YYYY-MM-ddThh:mm:ssZ" format with a Z offset, as defined by RFC 3339.
-
#version ⇒ String
**[Required]** Version is the never-repeating, totally-orderable, version of the zone, from which the serial field of the zone's SOA record is derived.
-
#view_id ⇒ String
The OCID of the private view containing the zone.
-
#zone_type ⇒ String
**[Required]** The type of the zone.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ZoneSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ZoneSummary
Initializes the object
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/oci/dns/models/zone_summary.rb', line 179 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.zone_type = attributes[:'zoneType'] if attributes[:'zoneType'] raise 'You cannot provide both :zoneType and :zone_type' if attributes.key?(:'zoneType') && attributes.key?(:'zone_type') self.zone_type = attributes[:'zone_type'] if attributes[:'zone_type'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.view_id = attributes[:'viewId'] if attributes[:'viewId'] raise 'You cannot provide both :viewId and :view_id' if attributes.key?(:'viewId') && attributes.key?(:'view_id') self.view_id = attributes[:'view_id'] if attributes[:'view_id'] self.scope = attributes[:'scope'] if attributes[:'scope'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.self_uri = attributes[:'self'] if attributes[:'self'] raise 'You cannot provide both :self and :self_uri' if attributes.key?(:'self') && attributes.key?(:'self_uri') self.self_uri = attributes[:'self_uri'] if attributes[:'self_uri'] self.id = attributes[:'id'] if attributes[:'id'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.version = attributes[:'version'] if attributes[:'version'] self.serial = attributes[:'serial'] if attributes[:'serial'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.is_protected = attributes[:'isProtected'] unless attributes[:'isProtected'].nil? raise 'You cannot provide both :isProtected and :is_protected' if attributes.key?(:'isProtected') && attributes.key?(:'is_protected') self.is_protected = attributes[:'is_protected'] unless attributes[:'is_protected'].nil? end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The OCID of the compartment containing the zone.
47 48 49 |
# File 'lib/oci/dns/models/zone_summary.rb', line 47 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
**[Required]** Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
*Example:* `{"CostCenter": "42"}`
76 77 78 |
# File 'lib/oci/dns/models/zone_summary.rb', line 76 def @defined_tags end |
#freeform_tags ⇒ Hash<String, String>
**[Required]** Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
*Example:* `"Finance"`
67 68 69 |
# File 'lib/oci/dns/models/zone_summary.rb', line 67 def @freeform_tags end |
#id ⇒ String
**[Required]** The OCID of the zone.
84 85 86 |
# File 'lib/oci/dns/models/zone_summary.rb', line 84 def id @id end |
#is_protected ⇒ BOOLEAN
**[Required]** A Boolean flag indicating whether or not parts of the resource are unable to be explicitly managed.
113 114 115 |
# File 'lib/oci/dns/models/zone_summary.rb', line 113 def is_protected @is_protected end |
#lifecycle_state ⇒ String
**[Required]** The current state of the zone resource.
108 109 110 |
# File 'lib/oci/dns/models/zone_summary.rb', line 108 def lifecycle_state @lifecycle_state end |
#name ⇒ String
**[Required]** The name of the zone.
38 39 40 |
# File 'lib/oci/dns/models/zone_summary.rb', line 38 def name @name end |
#scope ⇒ String
**[Required]** The scope of the zone.
58 59 60 |
# File 'lib/oci/dns/models/zone_summary.rb', line 58 def scope @scope end |
#self_uri ⇒ String
**[Required]** The canonical absolute URL of the resource.
80 81 82 |
# File 'lib/oci/dns/models/zone_summary.rb', line 80 def self_uri @self_uri end |
#serial ⇒ Integer
**[Required]** The current serial of the zone. As seen in the zone's SOA record.
104 105 106 |
# File 'lib/oci/dns/models/zone_summary.rb', line 104 def serial @serial end |
#time_created ⇒ DateTime
**[Required]** The date and time the resource was created in "YYYY-MM-ddThh:mm:ssZ" format with a Z offset, as defined by RFC 3339.
*Example:* `2016-07-22T17:23:59:60Z`
92 93 94 |
# File 'lib/oci/dns/models/zone_summary.rb', line 92 def time_created @time_created end |
#version ⇒ String
**[Required]** Version is the never-repeating, totally-orderable, version of the zone, from which the serial field of the zone's SOA record is derived.
99 100 101 |
# File 'lib/oci/dns/models/zone_summary.rb', line 99 def version @version end |
#view_id ⇒ String
The OCID of the private view containing the zone. This value will be null for zones in the global DNS, which are publicly resolvable and not part of a private view.
54 55 56 |
# File 'lib/oci/dns/models/zone_summary.rb', line 54 def view_id @view_id end |
#zone_type ⇒ String
**[Required]** The type of the zone. Must be either `PRIMARY` or `SECONDARY`. `SECONDARY` is only supported for GLOBAL zones.
43 44 45 |
# File 'lib/oci/dns/models/zone_summary.rb', line 43 def zone_type @zone_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/oci/dns/models/zone_summary.rb', line 116 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'zone_type': :'zoneType', 'compartment_id': :'compartmentId', 'view_id': :'viewId', 'scope': :'scope', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'self_uri': :'self', 'id': :'id', 'time_created': :'timeCreated', 'version': :'version', 'serial': :'serial', 'lifecycle_state': :'lifecycleState', 'is_protected': :'isProtected' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/oci/dns/models/zone_summary.rb', line 138 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'zone_type': :'String', 'compartment_id': :'String', 'view_id': :'String', 'scope': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'self_uri': :'String', 'id': :'String', 'time_created': :'DateTime', 'version': :'String', 'serial': :'Integer', 'lifecycle_state': :'String', 'is_protected': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 |
# File 'lib/oci/dns/models/zone_summary.rb', line 296 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && zone_type == other.zone_type && compartment_id == other.compartment_id && view_id == other.view_id && scope == other.scope && == other. && == other. && self_uri == other.self_uri && id == other.id && time_created == other.time_created && version == other.version && serial == other.serial && lifecycle_state == other.lifecycle_state && is_protected == other.is_protected end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 |
# File 'lib/oci/dns/models/zone_summary.rb', line 339 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
319 320 321 |
# File 'lib/oci/dns/models/zone_summary.rb', line 319 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
328 329 330 |
# File 'lib/oci/dns/models/zone_summary.rb', line 328 def hash [name, zone_type, compartment_id, view_id, scope, , , self_uri, id, time_created, version, serial, lifecycle_state, is_protected].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
372 373 374 375 376 377 378 379 380 381 |
# File 'lib/oci/dns/models/zone_summary.rb', line 372 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
366 367 368 |
# File 'lib/oci/dns/models/zone_summary.rb', line 366 def to_s to_hash.to_s end |