Class: OCI::Dns::Models::ZoneTransferServer
- Inherits:
-
Object
- Object
- OCI::Dns::Models::ZoneTransferServer
- Defined in:
- lib/oci/dns/models/zone_transfer_server.rb
Overview
An OCI nameserver that transfers zone data with external nameservers.
Instance Attribute Summary collapse
-
#address ⇒ String
[Required] The server’s IP address (IPv4 or IPv6).
-
#is_transfer_destination ⇒ BOOLEAN
A Boolean flag indicating whether or not the server is a zone data transfer destination.
-
#is_transfer_source ⇒ BOOLEAN
A Boolean flag indicating whether or not the server is a zone data transfer source.
-
#port ⇒ Integer
The server’s port.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ZoneTransferServer
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ZoneTransferServer
Initializes the object
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/oci/dns/models/zone_transfer_server.rb', line 64 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.address = attributes[:'address'] if attributes[:'address'] self.port = attributes[:'port'] if attributes[:'port'] self.is_transfer_source = attributes[:'isTransferSource'] unless attributes[:'isTransferSource'].nil? raise 'You cannot provide both :isTransferSource and :is_transfer_source' if attributes.key?(:'isTransferSource') && attributes.key?(:'is_transfer_source') self.is_transfer_source = attributes[:'is_transfer_source'] unless attributes[:'is_transfer_source'].nil? self.is_transfer_destination = attributes[:'isTransferDestination'] unless attributes[:'isTransferDestination'].nil? raise 'You cannot provide both :isTransferDestination and :is_transfer_destination' if attributes.key?(:'isTransferDestination') && attributes.key?(:'is_transfer_destination') self.is_transfer_destination = attributes[:'is_transfer_destination'] unless attributes[:'is_transfer_destination'].nil? end |
Instance Attribute Details
#address ⇒ String
[Required] The server’s IP address (IPv4 or IPv6).
13 14 15 |
# File 'lib/oci/dns/models/zone_transfer_server.rb', line 13 def address @address end |
#is_transfer_destination ⇒ BOOLEAN
A Boolean flag indicating whether or not the server is a zone data transfer destination.
28 29 30 |
# File 'lib/oci/dns/models/zone_transfer_server.rb', line 28 def is_transfer_destination @is_transfer_destination end |
#is_transfer_source ⇒ BOOLEAN
A Boolean flag indicating whether or not the server is a zone data transfer source.
23 24 25 |
# File 'lib/oci/dns/models/zone_transfer_server.rb', line 23 def is_transfer_source @is_transfer_source end |
#port ⇒ Integer
The server’s port.
18 19 20 |
# File 'lib/oci/dns/models/zone_transfer_server.rb', line 18 def port @port end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 40 |
# File 'lib/oci/dns/models/zone_transfer_server.rb', line 31 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'address': :'address', 'port': :'port', 'is_transfer_source': :'isTransferSource', 'is_transfer_destination': :'isTransferDestination' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
43 44 45 46 47 48 49 50 51 52 |
# File 'lib/oci/dns/models/zone_transfer_server.rb', line 43 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'address': :'String', 'port': :'Integer', 'is_transfer_source': :'BOOLEAN', 'is_transfer_destination': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
94 95 96 97 98 99 100 101 102 |
# File 'lib/oci/dns/models/zone_transfer_server.rb', line 94 def ==(other) return true if equal?(other) self.class == other.class && address == other.address && port == other.port && is_transfer_source == other.is_transfer_source && is_transfer_destination == other.is_transfer_destination end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/oci/dns/models/zone_transfer_server.rb', line 127 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
107 108 109 |
# File 'lib/oci/dns/models/zone_transfer_server.rb', line 107 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
116 117 118 |
# File 'lib/oci/dns/models/zone_transfer_server.rb', line 116 def hash [address, port, is_transfer_source, is_transfer_destination].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
160 161 162 163 164 165 166 167 168 169 |
# File 'lib/oci/dns/models/zone_transfer_server.rb', line 160 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
154 155 156 |
# File 'lib/oci/dns/models/zone_transfer_server.rb', line 154 def to_s to_hash.to_s end |