Class: OCI::Dts::Models::ShippingAddress

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/dts/models/shipping_address.rb

Overview

ShippingAddress model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ShippingAddress

Initializes the object

Options Hash (attributes):

  • :addressee (String)

    The value to assign to the #addressee property

  • :care_of (String)

    The value to assign to the #care_of property

  • :address1 (String)

    The value to assign to the #address1 property

  • :address2 (String)

    The value to assign to the #address2 property

  • :address3 (String)

    The value to assign to the #address3 property

  • :address4 (String)

    The value to assign to the #address4 property

  • :city_or_locality (String)

    The value to assign to the #city_or_locality property

  • :state_or_region (String)

    The value to assign to the #state_or_region property

  • :zipcode (String)

    The value to assign to the #zipcode property

  • :country (String)

    The value to assign to the #country property

  • :phone_number (String)

    The value to assign to the #phone_number property

  • :email (String)

    The value to assign to the #email property



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/oci/dts/models/shipping_address.rb', line 104

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.addressee = attributes[:'addressee'] if attributes[:'addressee']

  self.care_of = attributes[:'careOf'] if attributes[:'careOf']

  raise 'You cannot provide both :careOf and :care_of' if attributes.key?(:'careOf') && attributes.key?(:'care_of')

  self.care_of = attributes[:'care_of'] if attributes[:'care_of']

  self.address1 = attributes[:'address1'] if attributes[:'address1']

  self.address2 = attributes[:'address2'] if attributes[:'address2']

  self.address3 = attributes[:'address3'] if attributes[:'address3']

  self.address4 = attributes[:'address4'] if attributes[:'address4']

  self.city_or_locality = attributes[:'cityOrLocality'] if attributes[:'cityOrLocality']

  raise 'You cannot provide both :cityOrLocality and :city_or_locality' if attributes.key?(:'cityOrLocality') && attributes.key?(:'city_or_locality')

  self.city_or_locality = attributes[:'city_or_locality'] if attributes[:'city_or_locality']

  self.state_or_region = attributes[:'stateOrRegion'] if attributes[:'stateOrRegion']

  raise 'You cannot provide both :stateOrRegion and :state_or_region' if attributes.key?(:'stateOrRegion') && attributes.key?(:'state_or_region')

  self.state_or_region = attributes[:'state_or_region'] if attributes[:'state_or_region']

  self.zipcode = attributes[:'zipcode'] if attributes[:'zipcode']

  self.country = attributes[:'country'] if attributes[:'country']

  self.phone_number = attributes[:'phoneNumber'] if attributes[:'phoneNumber']

  raise 'You cannot provide both :phoneNumber and :phone_number' if attributes.key?(:'phoneNumber') && attributes.key?(:'phone_number')

  self.phone_number = attributes[:'phone_number'] if attributes[:'phone_number']

  self.email = attributes[:'email'] if attributes[:'email']
end

Instance Attribute Details

#address1String



17
18
19
# File 'lib/oci/dts/models/shipping_address.rb', line 17

def address1
  @address1
end

#address2String



20
21
22
# File 'lib/oci/dts/models/shipping_address.rb', line 20

def address2
  @address2
end

#address3String



23
24
25
# File 'lib/oci/dts/models/shipping_address.rb', line 23

def address3
  @address3
end

#address4String



26
27
28
# File 'lib/oci/dts/models/shipping_address.rb', line 26

def address4
  @address4
end

#addresseeString



11
12
13
# File 'lib/oci/dts/models/shipping_address.rb', line 11

def addressee
  @addressee
end

#care_ofString



14
15
16
# File 'lib/oci/dts/models/shipping_address.rb', line 14

def care_of
  @care_of
end

#city_or_localityString



29
30
31
# File 'lib/oci/dts/models/shipping_address.rb', line 29

def city_or_locality
  @city_or_locality
end

#countryString



38
39
40
# File 'lib/oci/dts/models/shipping_address.rb', line 38

def country
  @country
end

#emailString



44
45
46
# File 'lib/oci/dts/models/shipping_address.rb', line 44

def email
  @email
end

#phone_numberString



41
42
43
# File 'lib/oci/dts/models/shipping_address.rb', line 41

def phone_number
  @phone_number
end

#state_or_regionString



32
33
34
# File 'lib/oci/dts/models/shipping_address.rb', line 32

def state_or_region
  @state_or_region
end

#zipcodeString



35
36
37
# File 'lib/oci/dts/models/shipping_address.rb', line 35

def zipcode
  @zipcode
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/oci/dts/models/shipping_address.rb', line 47

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'addressee': :'addressee',
    'care_of': :'careOf',
    'address1': :'address1',
    'address2': :'address2',
    'address3': :'address3',
    'address4': :'address4',
    'city_or_locality': :'cityOrLocality',
    'state_or_region': :'stateOrRegion',
    'zipcode': :'zipcode',
    'country': :'country',
    'phone_number': :'phoneNumber',
    'email': :'email'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/oci/dts/models/shipping_address.rb', line 67

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'addressee': :'String',
    'care_of': :'String',
    'address1': :'String',
    'address2': :'String',
    'address3': :'String',
    'address4': :'String',
    'city_or_locality': :'String',
    'state_or_region': :'String',
    'zipcode': :'String',
    'country': :'String',
    'phone_number': :'String',
    'email': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.



158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/oci/dts/models/shipping_address.rb', line 158

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    addressee == other.addressee &&
    care_of == other.care_of &&
    address1 == other.address1 &&
    address2 == other.address2 &&
    address3 == other.address3 &&
    address4 == other.address4 &&
    city_or_locality == other.city_or_locality &&
    state_or_region == other.state_or_region &&
    zipcode == other.zipcode &&
    country == other.country &&
    phone_number == other.phone_number &&
    email == other.email
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/oci/dts/models/shipping_address.rb', line 199

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method


179
180
181
# File 'lib/oci/dts/models/shipping_address.rb', line 179

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.



188
189
190
# File 'lib/oci/dts/models/shipping_address.rb', line 188

def hash
  [addressee, care_of, address1, address2, address3, address4, city_or_locality, state_or_region, zipcode, country, phone_number, email].hash
end

#to_hashHash

Returns the object in the form of hash



232
233
234
235
236
237
238
239
240
241
# File 'lib/oci/dts/models/shipping_address.rb', line 232

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



226
227
228
# File 'lib/oci/dts/models/shipping_address.rb', line 226

def to_s
  to_hash.to_s
end