Class: OCI::Dts::TransferJobClient
- Inherits:
-
Object
- Object
- OCI::Dts::TransferJobClient
- Defined in:
- lib/oci/dts/transfer_job_client.rb
Overview
Data Transfer Service API Specification
Instance Attribute Summary collapse
-
#api_client ⇒ OCI::ApiClient
readonly
Client used to make HTTP requests.
-
#endpoint ⇒ String
readonly
Fully qualified endpoint URL.
-
#region ⇒ String
The region, which will usually correspond to a value in Regions::REGION_ENUM.
-
#retry_config ⇒ OCI::Retry::RetryConfig
readonly
The default retry configuration to apply to all operations in this service client.
Instance Method Summary collapse
-
#change_transfer_job_compartment(transfer_job_id, change_transfer_job_compartment_details, opts = {}) ⇒ Response
Moves a TransferJob into a different compartment.
-
#create_transfer_job(create_transfer_job_details, opts = {}) ⇒ Response
Create a new Transfer Job that corresponds with customer’s logical dataset e.g.
-
#delete_transfer_job(id, opts = {}) ⇒ Response
deletes a transfer job.
-
#get_transfer_job(id, opts = {}) ⇒ Response
Describes a transfer job in detail.
-
#initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) ⇒ TransferJobClient
constructor
Creates a new TransferJobClient.
-
#list_transfer_jobs(compartment_id, opts = {}) ⇒ Response
Lists Transfer Jobs in a given compartment.
-
#logger ⇒ Logger
The logger for this client.
-
#update_transfer_job(id, update_transfer_job_details, opts = {}) ⇒ Response
Updates a Transfer Job that corresponds with customer’s logical dataset e.g.
Constructor Details
#initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) ⇒ TransferJobClient
Creates a new TransferJobClient. Notes:
If a config is not specified, then the global OCI.config will be used.
This client is not thread-safe
Either a region or an endpoint must be specified. If an endpoint is specified, it will be used instead of the
region. A region may be specified in the config or via or the region parameter. If specified in both, then the
region parameter will be used.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/oci/dts/transfer_job_client.rb', line 53 def initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) # If the signer is an InstancePrincipalsSecurityTokenSigner or SecurityTokenSigner and no config was supplied (they are self-sufficient signers) # then create a dummy config to pass to the ApiClient constructor. If customers wish to create a client which uses instance principals # and has config (either populated programmatically or loaded from a file), they must construct that config themselves and then # pass it to this constructor. # # If there is no signer (or the signer is not an instance principals signer) and no config was supplied, this is not valid # so try and load the config from the default file. config = OCI::Config.validate_and_build_config_with_signer(config, signer) signer = OCI::Signer.config_file_auth_builder(config) if signer.nil? @api_client = OCI::ApiClient.new(config, signer, proxy_settings: proxy_settings) @retry_config = retry_config if endpoint @endpoint = endpoint + '/20171001' else region ||= config.region region ||= signer.region if signer.respond_to?(:region) self.region = region end logger.info "TransferJobClient endpoint set to '#{@endpoint}'." if logger end |
Instance Attribute Details
#api_client ⇒ OCI::ApiClient (readonly)
Client used to make HTTP requests.
13 14 15 |
# File 'lib/oci/dts/transfer_job_client.rb', line 13 def api_client @api_client end |
#endpoint ⇒ String (readonly)
Fully qualified endpoint URL
17 18 19 |
# File 'lib/oci/dts/transfer_job_client.rb', line 17 def endpoint @endpoint end |
#region ⇒ String
The region, which will usually correspond to a value in Regions::REGION_ENUM.
27 28 29 |
# File 'lib/oci/dts/transfer_job_client.rb', line 27 def region @region end |
#retry_config ⇒ OCI::Retry::RetryConfig (readonly)
The default retry configuration to apply to all operations in this service client. This can be overridden on a per-operation basis. The default retry configuration value is nil, which means that an operation will not perform any retries
23 24 25 |
# File 'lib/oci/dts/transfer_job_client.rb', line 23 def retry_config @retry_config end |
Instance Method Details
#change_transfer_job_compartment(transfer_job_id, change_transfer_job_compartment_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/dts/change_transfer_job_compartment.rb.html) to see an example of how to use change_transfer_job_compartment API.
Moves a TransferJob into a different compartment.
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/oci/dts/transfer_job_client.rb', line 121 def change_transfer_job_compartment(transfer_job_id, change_transfer_job_compartment_details, opts = {}) logger.debug 'Calling operation TransferJobClient#change_transfer_job_compartment.' if logger raise "Missing the required parameter 'transfer_job_id' when calling change_transfer_job_compartment." if transfer_job_id.nil? raise "Missing the required parameter 'change_transfer_job_compartment_details' when calling change_transfer_job_compartment." if change_transfer_job_compartment_details.nil? raise "Parameter value for 'transfer_job_id' must not be blank" if OCI::Internal::Util.blank_string?(transfer_job_id) path = '/transferJobs/{transferJobId}/actions/changeCompartment'.sub('{transferJobId}', transfer_job_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = @api_client.object_to_http_body(change_transfer_job_compartment_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'TransferJobClient#change_transfer_job_compartment') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#create_transfer_job(create_transfer_job_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/dts/create_transfer_job.rb.html) to see an example of how to use create_transfer_job API.
Create a new Transfer Job that corresponds with customer’s logical dataset e.g. a DB or a filesystem.
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/oci/dts/transfer_job_client.rb', line 181 def create_transfer_job(create_transfer_job_details, opts = {}) logger.debug 'Calling operation TransferJobClient#create_transfer_job.' if logger raise "Missing the required parameter 'create_transfer_job_details' when calling create_transfer_job." if create_transfer_job_details.nil? path = '/transferJobs' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = @api_client.object_to_http_body(create_transfer_job_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'TransferJobClient#create_transfer_job') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Dts::Models::TransferJob' ) end # rubocop:enable Metrics/BlockLength end |
#delete_transfer_job(id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/dts/delete_transfer_job.rb.html) to see an example of how to use delete_transfer_job API.
deletes a transfer job
238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/oci/dts/transfer_job_client.rb', line 238 def delete_transfer_job(id, opts = {}) logger.debug 'Calling operation TransferJobClient#delete_transfer_job.' if logger raise "Missing the required parameter 'id' when calling delete_transfer_job." if id.nil? raise "Parameter value for 'id' must not be blank" if OCI::Internal::Util.blank_string?(id) path = '/transferJobs/{id}'.sub('{id}', id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'TransferJobClient#delete_transfer_job') do @api_client.call_api( :DELETE, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#get_transfer_job(id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/dts/get_transfer_job.rb.html) to see an example of how to use get_transfer_job API.
Describes a transfer job in detail
293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 |
# File 'lib/oci/dts/transfer_job_client.rb', line 293 def get_transfer_job(id, opts = {}) logger.debug 'Calling operation TransferJobClient#get_transfer_job.' if logger raise "Missing the required parameter 'id' when calling get_transfer_job." if id.nil? raise "Parameter value for 'id' must not be blank" if OCI::Internal::Util.blank_string?(id) path = '/transferJobs/{id}'.sub('{id}', id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'TransferJobClient#get_transfer_job') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Dts::Models::TransferJob' ) end # rubocop:enable Metrics/BlockLength end |
#list_transfer_jobs(compartment_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/dts/list_transfer_jobs.rb.html) to see an example of how to use list_transfer_jobs API.
Lists Transfer Jobs in a given compartment
362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 |
# File 'lib/oci/dts/transfer_job_client.rb', line 362 def list_transfer_jobs(compartment_id, opts = {}) logger.debug 'Calling operation TransferJobClient#list_transfer_jobs.' if logger raise "Missing the required parameter 'compartment_id' when calling list_transfer_jobs." if compartment_id.nil? if opts[:lifecycle_state] && !%w[INITIATED PREPARING ACTIVE DELETED CLOSED].include?(opts[:lifecycle_state]) raise 'Invalid value for "lifecycle_state", must be one of INITIATED, PREPARING, ACTIVE, DELETED, CLOSED.' end path = '/transferJobs' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:compartmentId] = compartment_id query_params[:lifecycleState] = opts[:lifecycle_state] if opts[:lifecycle_state] query_params[:displayName] = opts[:display_name] if opts[:display_name] query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'TransferJobClient#list_transfer_jobs') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'Array<OCI::Dts::Models::TransferJobSummary>' ) end # rubocop:enable Metrics/BlockLength end |
#logger ⇒ Logger
Returns The logger for this client. May be nil.
92 93 94 |
# File 'lib/oci/dts/transfer_job_client.rb', line 92 def logger @api_client.config.logger end |
#update_transfer_job(id, update_transfer_job_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/dts/update_transfer_job.rb.html) to see an example of how to use update_transfer_job API.
Updates a Transfer Job that corresponds with customer’s logical dataset e.g. a DB or a filesystem.
430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 |
# File 'lib/oci/dts/transfer_job_client.rb', line 430 def update_transfer_job(id, update_transfer_job_details, opts = {}) logger.debug 'Calling operation TransferJobClient#update_transfer_job.' if logger raise "Missing the required parameter 'id' when calling update_transfer_job." if id.nil? raise "Missing the required parameter 'update_transfer_job_details' when calling update_transfer_job." if update_transfer_job_details.nil? raise "Parameter value for 'id' must not be blank" if OCI::Internal::Util.blank_string?(id) path = '/transferJobs/{id}'.sub('{id}', id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(update_transfer_job_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'TransferJobClient#update_transfer_job') do @api_client.call_api( :PUT, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Dts::Models::TransferJob' ) end # rubocop:enable Metrics/BlockLength end |