Class: OCI::Dts::TransferPackageClient
- Inherits:
-
Object
- Object
- OCI::Dts::TransferPackageClient
- Defined in:
- lib/oci/dts/transfer_package_client.rb
Overview
Data Transfer Service API Specification
Instance Attribute Summary collapse
-
#api_client ⇒ OCI::ApiClient
readonly
Client used to make HTTP requests.
-
#endpoint ⇒ String
readonly
Fully qualified endpoint URL.
-
#region ⇒ String
The region, which will usually correspond to a value in Regions::REGION_ENUM.
-
#retry_config ⇒ OCI::Retry::RetryConfig
readonly
The default retry configuration to apply to all operations in this service client.
Instance Method Summary collapse
-
#attach_devices_to_transfer_package(id, transfer_package_label, attach_devices_details, opts = {}) ⇒ Response
Attaches Devices to a Transfer Package.
-
#create_transfer_package(id, opts = {}) ⇒ Response
Create a new Transfer Package.
-
#delete_transfer_package(id, transfer_package_label, opts = {}) ⇒ Response
deletes a transfer Package.
-
#detach_devices_from_transfer_package(id, transfer_package_label, detach_devices_details, opts = {}) ⇒ Response
Detaches Devices from a Transfer Package.
-
#get_transfer_package(id, transfer_package_label, opts = {}) ⇒ Response
Describes a transfer package in detail.
-
#initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) ⇒ TransferPackageClient
constructor
Creates a new TransferPackageClient.
-
#list_transfer_packages(id, opts = {}) ⇒ Response
Lists Transfer Packages associated with a transferJob.
-
#logger ⇒ Logger
The logger for this client.
-
#update_transfer_package(id, transfer_package_label, update_transfer_package_details, opts = {}) ⇒ Response
Updates a Transfer Package.
Constructor Details
#initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) ⇒ TransferPackageClient
Creates a new TransferPackageClient. Notes:
If a config is not specified, then the global OCI.config will be used.
This client is not thread-safe
Either a region or an endpoint must be specified. If an endpoint is specified, it will be used instead of the
region. A region may be specified in the config or via or the region parameter. If specified in both, then the
region parameter will be used.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/oci/dts/transfer_package_client.rb', line 53 def initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) # If the signer is an InstancePrincipalsSecurityTokenSigner or SecurityTokenSigner and no config was supplied (they are self-sufficient signers) # then create a dummy config to pass to the ApiClient constructor. If customers wish to create a client which uses instance principals # and has config (either populated programmatically or loaded from a file), they must construct that config themselves and then # pass it to this constructor. # # If there is no signer (or the signer is not an instance principals signer) and no config was supplied, this is not valid # so try and load the config from the default file. config = OCI::Config.validate_and_build_config_with_signer(config, signer) signer = OCI::Signer.config_file_auth_builder(config) if signer.nil? @api_client = OCI::ApiClient.new(config, signer, proxy_settings: proxy_settings) @retry_config = retry_config if endpoint @endpoint = endpoint + '/20171001' else region ||= config.region region ||= signer.region if signer.respond_to?(:region) self.region = region end logger.info "TransferPackageClient endpoint set to '#{@endpoint}'." if logger end |
Instance Attribute Details
#api_client ⇒ OCI::ApiClient (readonly)
Client used to make HTTP requests.
13 14 15 |
# File 'lib/oci/dts/transfer_package_client.rb', line 13 def api_client @api_client end |
#endpoint ⇒ String (readonly)
Fully qualified endpoint URL
17 18 19 |
# File 'lib/oci/dts/transfer_package_client.rb', line 17 def endpoint @endpoint end |
#region ⇒ String
The region, which will usually correspond to a value in Regions::REGION_ENUM.
27 28 29 |
# File 'lib/oci/dts/transfer_package_client.rb', line 27 def region @region end |
#retry_config ⇒ OCI::Retry::RetryConfig (readonly)
The default retry configuration to apply to all operations in this service client. This can be overridden on a per-operation basis. The default retry configuration value is nil, which means that an operation will not perform any retries
23 24 25 |
# File 'lib/oci/dts/transfer_package_client.rb', line 23 def retry_config @retry_config end |
Instance Method Details
#attach_devices_to_transfer_package(id, transfer_package_label, attach_devices_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/dts/attach_devices_to_transfer_package.rb.html) to see an example of how to use attach_devices_to_transfer_package API.
Attaches Devices to a Transfer Package
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/oci/dts/transfer_package_client.rb', line 111 def attach_devices_to_transfer_package(id, transfer_package_label, attach_devices_details, opts = {}) logger.debug 'Calling operation TransferPackageClient#attach_devices_to_transfer_package.' if logger raise "Missing the required parameter 'id' when calling attach_devices_to_transfer_package." if id.nil? raise "Missing the required parameter 'transfer_package_label' when calling attach_devices_to_transfer_package." if transfer_package_label.nil? raise "Missing the required parameter 'attach_devices_details' when calling attach_devices_to_transfer_package." if attach_devices_details.nil? raise "Parameter value for 'id' must not be blank" if OCI::Internal::Util.blank_string?(id) raise "Parameter value for 'transfer_package_label' must not be blank" if OCI::Internal::Util.blank_string?(transfer_package_label) path = '/transferJobs/{id}/transferPackages/{transferPackageLabel}/actions/attachDevices'.sub('{id}', id.to_s).sub('{transferPackageLabel}', transfer_package_label.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(attach_devices_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'TransferPackageClient#attach_devices_to_transfer_package') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#create_transfer_package(id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/dts/create_transfer_package.rb.html) to see an example of how to use create_transfer_package API.
Create a new Transfer Package
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/oci/dts/transfer_package_client.rb', line 168 def create_transfer_package(id, opts = {}) logger.debug 'Calling operation TransferPackageClient#create_transfer_package.' if logger raise "Missing the required parameter 'id' when calling create_transfer_package." if id.nil? raise "Parameter value for 'id' must not be blank" if OCI::Internal::Util.blank_string?(id) path = '/transferJobs/{id}/transferPackages'.sub('{id}', id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = @api_client.object_to_http_body(opts[:create_transfer_package_details]) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'TransferPackageClient#create_transfer_package') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Dts::Models::TransferPackage' ) end # rubocop:enable Metrics/BlockLength end |
#delete_transfer_package(id, transfer_package_label, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/dts/delete_transfer_package.rb.html) to see an example of how to use delete_transfer_package API.
deletes a transfer Package
224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 |
# File 'lib/oci/dts/transfer_package_client.rb', line 224 def delete_transfer_package(id, transfer_package_label, opts = {}) logger.debug 'Calling operation TransferPackageClient#delete_transfer_package.' if logger raise "Missing the required parameter 'id' when calling delete_transfer_package." if id.nil? raise "Missing the required parameter 'transfer_package_label' when calling delete_transfer_package." if transfer_package_label.nil? raise "Parameter value for 'id' must not be blank" if OCI::Internal::Util.blank_string?(id) raise "Parameter value for 'transfer_package_label' must not be blank" if OCI::Internal::Util.blank_string?(transfer_package_label) path = '/transferJobs/{id}/transferPackages/{transferPackageLabel}'.sub('{id}', id.to_s).sub('{transferPackageLabel}', transfer_package_label.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'TransferPackageClient#delete_transfer_package') do @api_client.call_api( :DELETE, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#detach_devices_from_transfer_package(id, transfer_package_label, detach_devices_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/dts/detach_devices_from_transfer_package.rb.html) to see an example of how to use detach_devices_from_transfer_package API.
Detaches Devices from a Transfer Package
281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 |
# File 'lib/oci/dts/transfer_package_client.rb', line 281 def detach_devices_from_transfer_package(id, transfer_package_label, detach_devices_details, opts = {}) logger.debug 'Calling operation TransferPackageClient#detach_devices_from_transfer_package.' if logger raise "Missing the required parameter 'id' when calling detach_devices_from_transfer_package." if id.nil? raise "Missing the required parameter 'transfer_package_label' when calling detach_devices_from_transfer_package." if transfer_package_label.nil? raise "Missing the required parameter 'detach_devices_details' when calling detach_devices_from_transfer_package." if detach_devices_details.nil? raise "Parameter value for 'id' must not be blank" if OCI::Internal::Util.blank_string?(id) raise "Parameter value for 'transfer_package_label' must not be blank" if OCI::Internal::Util.blank_string?(transfer_package_label) path = '/transferJobs/{id}/transferPackages/{transferPackageLabel}/actions/detachDevices'.sub('{id}', id.to_s).sub('{transferPackageLabel}', transfer_package_label.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(detach_devices_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'TransferPackageClient#detach_devices_from_transfer_package') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#get_transfer_package(id, transfer_package_label, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/dts/get_transfer_package.rb.html) to see an example of how to use get_transfer_package API.
Describes a transfer package in detail
338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 |
# File 'lib/oci/dts/transfer_package_client.rb', line 338 def get_transfer_package(id, transfer_package_label, opts = {}) logger.debug 'Calling operation TransferPackageClient#get_transfer_package.' if logger raise "Missing the required parameter 'id' when calling get_transfer_package." if id.nil? raise "Missing the required parameter 'transfer_package_label' when calling get_transfer_package." if transfer_package_label.nil? raise "Parameter value for 'id' must not be blank" if OCI::Internal::Util.blank_string?(id) raise "Parameter value for 'transfer_package_label' must not be blank" if OCI::Internal::Util.blank_string?(transfer_package_label) path = '/transferJobs/{id}/transferPackages/{transferPackageLabel}'.sub('{id}', id.to_s).sub('{transferPackageLabel}', transfer_package_label.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'TransferPackageClient#get_transfer_package') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Dts::Models::TransferPackage' ) end # rubocop:enable Metrics/BlockLength end |
#list_transfer_packages(id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/dts/list_transfer_packages.rb.html) to see an example of how to use list_transfer_packages API.
Lists Transfer Packages associated with a transferJob
396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 |
# File 'lib/oci/dts/transfer_package_client.rb', line 396 def list_transfer_packages(id, opts = {}) logger.debug 'Calling operation TransferPackageClient#list_transfer_packages.' if logger raise "Missing the required parameter 'id' when calling list_transfer_packages." if id.nil? if opts[:lifecycle_state] && !%w[PREPARING SHIPPING RECEIVED PROCESSING PROCESSED RETURNED DELETED CANCELLED CANCELLED_RETURNED].include?(opts[:lifecycle_state]) raise 'Invalid value for "lifecycle_state", must be one of PREPARING, SHIPPING, RECEIVED, PROCESSING, PROCESSED, RETURNED, DELETED, CANCELLED, CANCELLED_RETURNED.' end raise "Parameter value for 'id' must not be blank" if OCI::Internal::Util.blank_string?(id) path = '/transferJobs/{id}/transferPackages'.sub('{id}', id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:lifecycleState] = opts[:lifecycle_state] if opts[:lifecycle_state] query_params[:displayName] = opts[:display_name] if opts[:display_name] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'TransferPackageClient#list_transfer_packages') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Dts::Models::MultipleTransferPackages' ) end # rubocop:enable Metrics/BlockLength end |
#logger ⇒ Logger
Returns The logger for this client. May be nil.
92 93 94 |
# File 'lib/oci/dts/transfer_package_client.rb', line 92 def logger @api_client.config.logger end |
#update_transfer_package(id, transfer_package_label, update_transfer_package_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/dts/update_transfer_package.rb.html) to see an example of how to use update_transfer_package API.
Updates a Transfer Package
459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 |
# File 'lib/oci/dts/transfer_package_client.rb', line 459 def update_transfer_package(id, transfer_package_label, update_transfer_package_details, opts = {}) logger.debug 'Calling operation TransferPackageClient#update_transfer_package.' if logger raise "Missing the required parameter 'id' when calling update_transfer_package." if id.nil? raise "Missing the required parameter 'transfer_package_label' when calling update_transfer_package." if transfer_package_label.nil? raise "Missing the required parameter 'update_transfer_package_details' when calling update_transfer_package." if update_transfer_package_details.nil? raise "Parameter value for 'id' must not be blank" if OCI::Internal::Util.blank_string?(id) raise "Parameter value for 'transfer_package_label' must not be blank" if OCI::Internal::Util.blank_string?(transfer_package_label) path = '/transferJobs/{id}/transferPackages/{transferPackageLabel}'.sub('{id}', id.to_s).sub('{transferPackageLabel}', transfer_package_label.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(update_transfer_package_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'TransferPackageClient#update_transfer_package') do @api_client.call_api( :PUT, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Dts::Models::TransferPackage' ) end # rubocop:enable Metrics/BlockLength end |