Class: OCI::EmWarehouse::Models::EmInstancesDetails
- Inherits:
-
Object
- Object
- OCI::EmWarehouse::Models::EmInstancesDetails
- Defined in:
- lib/oci/em_warehouse/models/em_instances_details.rb
Overview
Results of a emWarehouse search. Contains boh EmWarehouseSummary items and other information, such as metadata.
Instance Attribute Summary collapse
-
#em_host ⇒ String
emHost name.
-
#em_id ⇒ String
**[Required]** operations Insights Warehouse Identifier.
-
#targets_count ⇒ Integer
EmInstance Target count.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EmInstancesDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ EmInstancesDetails
Initializes the object
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/oci/em_warehouse/models/em_instances_details.rb', line 53 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.em_id = attributes[:'emId'] if attributes[:'emId'] raise 'You cannot provide both :emId and :em_id' if attributes.key?(:'emId') && attributes.key?(:'em_id') self.em_id = attributes[:'em_id'] if attributes[:'em_id'] self.targets_count = attributes[:'targetsCount'] if attributes[:'targetsCount'] raise 'You cannot provide both :targetsCount and :targets_count' if attributes.key?(:'targetsCount') && attributes.key?(:'targets_count') self.targets_count = attributes[:'targets_count'] if attributes[:'targets_count'] self.em_host = attributes[:'emHost'] if attributes[:'emHost'] raise 'You cannot provide both :emHost and :em_host' if attributes.key?(:'emHost') && attributes.key?(:'em_host') self.em_host = attributes[:'em_host'] if attributes[:'em_host'] end |
Instance Attribute Details
#em_host ⇒ String
emHost name
20 21 22 |
# File 'lib/oci/em_warehouse/models/em_instances_details.rb', line 20 def em_host @em_host end |
#em_id ⇒ String
**[Required]** operations Insights Warehouse Identifier
12 13 14 |
# File 'lib/oci/em_warehouse/models/em_instances_details.rb', line 12 def em_id @em_id end |
#targets_count ⇒ Integer
EmInstance Target count
16 17 18 |
# File 'lib/oci/em_warehouse/models/em_instances_details.rb', line 16 def targets_count @targets_count end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
23 24 25 26 27 28 29 30 31 |
# File 'lib/oci/em_warehouse/models/em_instances_details.rb', line 23 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'em_id': :'emId', 'targets_count': :'targetsCount', 'em_host': :'emHost' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
34 35 36 37 38 39 40 41 42 |
# File 'lib/oci/em_warehouse/models/em_instances_details.rb', line 34 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'em_id': :'String', 'targets_count': :'Integer', 'em_host': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
85 86 87 88 89 90 91 92 |
# File 'lib/oci/em_warehouse/models/em_instances_details.rb', line 85 def ==(other) return true if equal?(other) self.class == other.class && em_id == other.em_id && targets_count == other.targets_count && em_host == other.em_host end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/oci/em_warehouse/models/em_instances_details.rb', line 117 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
97 98 99 |
# File 'lib/oci/em_warehouse/models/em_instances_details.rb', line 97 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
106 107 108 |
# File 'lib/oci/em_warehouse/models/em_instances_details.rb', line 106 def hash [em_id, targets_count, em_host].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
150 151 152 153 154 155 156 157 158 159 |
# File 'lib/oci/em_warehouse/models/em_instances_details.rb', line 150 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
144 145 146 |
# File 'lib/oci/em_warehouse/models/em_instances_details.rb', line 144 def to_s to_hash.to_s end |