Class: OCI::EmWarehouse::Models::EmWarehouse
- Inherits:
-
Object
- Object
- OCI::EmWarehouse::Models::EmWarehouse
- Defined in:
- lib/oci/em_warehouse/models/em_warehouse.rb
Overview
Description of EmWarehouse.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** Compartment Identifier.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
**[Required]** Defined tags for this resource.
-
#display_name ⇒ String
**[Required]** EmWarehouse Identifier, can be renamed.
-
#em_bridge_id ⇒ String
EMBridge Identifier.
-
#em_warehouse_type ⇒ String
**[Required]** Type of the EmWarehouse.
-
#freeform_tags ⇒ Hash<String, String>
**[Required]** Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
**[Required]** Unique identifier that is immutable on creation.
-
#latest_etl_run_message ⇒ String
Data Flow Run Status Message.
-
#latest_etl_run_status ⇒ String
Data Flow Run Status.
-
#latest_etl_run_time ⇒ String
Data Flow Run Total Time.
-
#lifecycle_details ⇒ String
A message describing the current state in more detail.
-
#lifecycle_state ⇒ String
**[Required]** The current state of the EmWarehouse.
-
#operations_insights_warehouse_id ⇒ String
**[Required]** operations Insights Warehouse Identifier.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys.
-
#time_created ⇒ DateTime
**[Required]** The time the the EmWarehouse was created.
-
#time_updated ⇒ DateTime
The time the EmWarehouse was updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EmWarehouse
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ EmWarehouse
Initializes the object
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/oci/em_warehouse/models/em_warehouse.rb', line 161 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.operations_insights_warehouse_id = attributes[:'operationsInsightsWarehouseId'] if attributes[:'operationsInsightsWarehouseId'] raise 'You cannot provide both :operationsInsightsWarehouseId and :operations_insights_warehouse_id' if attributes.key?(:'operationsInsightsWarehouseId') && attributes.key?(:'operations_insights_warehouse_id') self.operations_insights_warehouse_id = attributes[:'operations_insights_warehouse_id'] if attributes[:'operations_insights_warehouse_id'] self.latest_etl_run_status = attributes[:'latestEtlRunStatus'] if attributes[:'latestEtlRunStatus'] raise 'You cannot provide both :latestEtlRunStatus and :latest_etl_run_status' if attributes.key?(:'latestEtlRunStatus') && attributes.key?(:'latest_etl_run_status') self.latest_etl_run_status = attributes[:'latest_etl_run_status'] if attributes[:'latest_etl_run_status'] self. = attributes[:'latestEtlRunMessage'] if attributes[:'latestEtlRunMessage'] raise 'You cannot provide both :latestEtlRunMessage and :latest_etl_run_message' if attributes.key?(:'latestEtlRunMessage') && attributes.key?(:'latest_etl_run_message') self. = attributes[:'latest_etl_run_message'] if attributes[:'latest_etl_run_message'] self.latest_etl_run_time = attributes[:'latestEtlRunTime'] if attributes[:'latestEtlRunTime'] raise 'You cannot provide both :latestEtlRunTime and :latest_etl_run_time' if attributes.key?(:'latestEtlRunTime') && attributes.key?(:'latest_etl_run_time') self.latest_etl_run_time = attributes[:'latest_etl_run_time'] if attributes[:'latest_etl_run_time'] self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.em_warehouse_type = attributes[:'emWarehouseType'] if attributes[:'emWarehouseType'] raise 'You cannot provide both :emWarehouseType and :em_warehouse_type' if attributes.key?(:'emWarehouseType') && attributes.key?(:'em_warehouse_type') self.em_warehouse_type = attributes[:'em_warehouse_type'] if attributes[:'em_warehouse_type'] self.em_bridge_id = attributes[:'emBridgeId'] if attributes[:'emBridgeId'] raise 'You cannot provide both :emBridgeId and :em_bridge_id' if attributes.key?(:'emBridgeId') && attributes.key?(:'em_bridge_id') self.em_bridge_id = attributes[:'em_bridge_id'] if attributes[:'em_bridge_id'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** Compartment Identifier
47 48 49 |
# File 'lib/oci/em_warehouse/models/em_warehouse.rb', line 47 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
**[Required]** Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
83 84 85 |
# File 'lib/oci/em_warehouse/models/em_warehouse.rb', line 83 def @defined_tags end |
#display_name ⇒ String
**[Required]** EmWarehouse Identifier, can be renamed
43 44 45 |
# File 'lib/oci/em_warehouse/models/em_warehouse.rb', line 43 def display_name @display_name end |
#em_bridge_id ⇒ String
EMBridge Identifier
55 56 57 |
# File 'lib/oci/em_warehouse/models/em_warehouse.rb', line 55 def em_bridge_id @em_bridge_id end |
#em_warehouse_type ⇒ String
**[Required]** Type of the EmWarehouse.
51 52 53 |
# File 'lib/oci/em_warehouse/models/em_warehouse.rb', line 51 def em_warehouse_type @em_warehouse_type end |
#freeform_tags ⇒ Hash<String, String>
**[Required]** Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
77 78 79 |
# File 'lib/oci/em_warehouse/models/em_warehouse.rb', line 77 def @freeform_tags end |
#id ⇒ String
**[Required]** Unique identifier that is immutable on creation
39 40 41 |
# File 'lib/oci/em_warehouse/models/em_warehouse.rb', line 39 def id @id end |
#latest_etl_run_message ⇒ String
Data Flow Run Status Message
31 32 33 |
# File 'lib/oci/em_warehouse/models/em_warehouse.rb', line 31 def @latest_etl_run_message end |
#latest_etl_run_status ⇒ String
Data Flow Run Status
27 28 29 |
# File 'lib/oci/em_warehouse/models/em_warehouse.rb', line 27 def latest_etl_run_status @latest_etl_run_status end |
#latest_etl_run_time ⇒ String
Data Flow Run Total Time
35 36 37 |
# File 'lib/oci/em_warehouse/models/em_warehouse.rb', line 35 def latest_etl_run_time @latest_etl_run_time end |
#lifecycle_details ⇒ String
A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
71 72 73 |
# File 'lib/oci/em_warehouse/models/em_warehouse.rb', line 71 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
**[Required]** The current state of the EmWarehouse.
67 68 69 |
# File 'lib/oci/em_warehouse/models/em_warehouse.rb', line 67 def lifecycle_state @lifecycle_state end |
#operations_insights_warehouse_id ⇒ String
**[Required]** operations Insights Warehouse Identifier
23 24 25 |
# File 'lib/oci/em_warehouse/models/em_warehouse.rb', line 23 def operations_insights_warehouse_id @operations_insights_warehouse_id end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"free-tier-retained": "true"}`
89 90 91 |
# File 'lib/oci/em_warehouse/models/em_warehouse.rb', line 89 def @system_tags end |
#time_created ⇒ DateTime
**[Required]** The time the the EmWarehouse was created. An RFC3339 formatted datetime string
59 60 61 |
# File 'lib/oci/em_warehouse/models/em_warehouse.rb', line 59 def time_created @time_created end |
#time_updated ⇒ DateTime
The time the EmWarehouse was updated. An RFC3339 formatted datetime string
63 64 65 |
# File 'lib/oci/em_warehouse/models/em_warehouse.rb', line 63 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/oci/em_warehouse/models/em_warehouse.rb', line 92 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'operations_insights_warehouse_id': :'operationsInsightsWarehouseId', 'latest_etl_run_status': :'latestEtlRunStatus', 'latest_etl_run_message': :'latestEtlRunMessage', 'latest_etl_run_time': :'latestEtlRunTime', 'id': :'id', 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'em_warehouse_type': :'emWarehouseType', 'em_bridge_id': :'emBridgeId', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/oci/em_warehouse/models/em_warehouse.rb', line 116 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'operations_insights_warehouse_id': :'String', 'latest_etl_run_status': :'String', 'latest_etl_run_message': :'String', 'latest_etl_run_time': :'String', 'id': :'String', 'display_name': :'String', 'compartment_id': :'String', 'em_warehouse_type': :'String', 'em_bridge_id': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/oci/em_warehouse/models/em_warehouse.rb', line 280 def ==(other) return true if equal?(other) self.class == other.class && operations_insights_warehouse_id == other.operations_insights_warehouse_id && latest_etl_run_status == other.latest_etl_run_status && == other. && latest_etl_run_time == other.latest_etl_run_time && id == other.id && display_name == other.display_name && compartment_id == other.compartment_id && em_warehouse_type == other.em_warehouse_type && em_bridge_id == other.em_bridge_id && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 |
# File 'lib/oci/em_warehouse/models/em_warehouse.rb', line 325 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
305 306 307 |
# File 'lib/oci/em_warehouse/models/em_warehouse.rb', line 305 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
314 315 316 |
# File 'lib/oci/em_warehouse/models/em_warehouse.rb', line 314 def hash [operations_insights_warehouse_id, latest_etl_run_status, , latest_etl_run_time, id, display_name, compartment_id, em_warehouse_type, em_bridge_id, time_created, time_updated, lifecycle_state, lifecycle_details, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
358 359 360 361 362 363 364 365 366 367 |
# File 'lib/oci/em_warehouse/models/em_warehouse.rb', line 358 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
352 353 354 |
# File 'lib/oci/em_warehouse/models/em_warehouse.rb', line 352 def to_s to_hash.to_s end |