Class: OCI::EmWarehouse::Models::EmWarehouseSummary
- Inherits:
-
Object
- Object
- OCI::EmWarehouse::Models::EmWarehouseSummary
- Defined in:
- lib/oci/em_warehouse/models/em_warehouse_summary.rb
Overview
Summary of the EmWarehouse.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** Compartment Identifier.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
**[Required]** Defined tags for this resource.
-
#display_name ⇒ String
**[Required]** EmWarehouse Identifier, can be renamed.
-
#em_bridge_id ⇒ String
EMBridge Identifier.
-
#em_warehouse_type ⇒ String
**[Required]** Type of the EmWarehouse.
-
#freeform_tags ⇒ Hash<String, String>
**[Required]** Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
**[Required]** Unique identifier that is immutable on creation.
-
#latest_etl_run_message ⇒ String
Data Flow Run Status Message.
-
#latest_etl_run_status ⇒ String
Data Flow Run Status.
-
#latest_etl_run_time ⇒ String
Data Flow Run Total Time.
-
#lifecycle_details ⇒ String
A message describing the current state in more detail.
-
#lifecycle_state ⇒ String
**[Required]** The current state of the EmWarehouse.
-
#operations_insights_warehouse_id ⇒ String
**[Required]** operations Insights Warehouse Identifier.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys.
-
#time_created ⇒ DateTime
**[Required]** The time the the EmWarehouse was created.
-
#time_updated ⇒ DateTime
The time the EmWarehouse was updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EmWarehouseSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ EmWarehouseSummary
Initializes the object
150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/oci/em_warehouse/models/em_warehouse_summary.rb', line 150 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.operations_insights_warehouse_id = attributes[:'operationsInsightsWarehouseId'] if attributes[:'operationsInsightsWarehouseId'] raise 'You cannot provide both :operationsInsightsWarehouseId and :operations_insights_warehouse_id' if attributes.key?(:'operationsInsightsWarehouseId') && attributes.key?(:'operations_insights_warehouse_id') self.operations_insights_warehouse_id = attributes[:'operations_insights_warehouse_id'] if attributes[:'operations_insights_warehouse_id'] self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.em_warehouse_type = attributes[:'emWarehouseType'] if attributes[:'emWarehouseType'] raise 'You cannot provide both :emWarehouseType and :em_warehouse_type' if attributes.key?(:'emWarehouseType') && attributes.key?(:'em_warehouse_type') self.em_warehouse_type = attributes[:'em_warehouse_type'] if attributes[:'em_warehouse_type'] self.em_bridge_id = attributes[:'emBridgeId'] if attributes[:'emBridgeId'] raise 'You cannot provide both :emBridgeId and :em_bridge_id' if attributes.key?(:'emBridgeId') && attributes.key?(:'em_bridge_id') self.em_bridge_id = attributes[:'em_bridge_id'] if attributes[:'em_bridge_id'] self.latest_etl_run_status = attributes[:'latestEtlRunStatus'] if attributes[:'latestEtlRunStatus'] raise 'You cannot provide both :latestEtlRunStatus and :latest_etl_run_status' if attributes.key?(:'latestEtlRunStatus') && attributes.key?(:'latest_etl_run_status') self.latest_etl_run_status = attributes[:'latest_etl_run_status'] if attributes[:'latest_etl_run_status'] self. = attributes[:'latestEtlRunMessage'] if attributes[:'latestEtlRunMessage'] raise 'You cannot provide both :latestEtlRunMessage and :latest_etl_run_message' if attributes.key?(:'latestEtlRunMessage') && attributes.key?(:'latest_etl_run_message') self. = attributes[:'latest_etl_run_message'] if attributes[:'latest_etl_run_message'] self.latest_etl_run_time = attributes[:'latestEtlRunTime'] if attributes[:'latestEtlRunTime'] raise 'You cannot provide both :latestEtlRunTime and :latest_etl_run_time' if attributes.key?(:'latestEtlRunTime') && attributes.key?(:'latest_etl_run_time') self.latest_etl_run_time = attributes[:'latest_etl_run_time'] if attributes[:'latest_etl_run_time'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** Compartment Identifier
24 25 26 |
# File 'lib/oci/em_warehouse/models/em_warehouse_summary.rb', line 24 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
**[Required]** Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
72 73 74 |
# File 'lib/oci/em_warehouse/models/em_warehouse_summary.rb', line 72 def @defined_tags end |
#display_name ⇒ String
**[Required]** EmWarehouse Identifier, can be renamed
20 21 22 |
# File 'lib/oci/em_warehouse/models/em_warehouse_summary.rb', line 20 def display_name @display_name end |
#em_bridge_id ⇒ String
EMBridge Identifier
32 33 34 |
# File 'lib/oci/em_warehouse/models/em_warehouse_summary.rb', line 32 def em_bridge_id @em_bridge_id end |
#em_warehouse_type ⇒ String
**[Required]** Type of the EmWarehouse.
28 29 30 |
# File 'lib/oci/em_warehouse/models/em_warehouse_summary.rb', line 28 def em_warehouse_type @em_warehouse_type end |
#freeform_tags ⇒ Hash<String, String>
**[Required]** Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
66 67 68 |
# File 'lib/oci/em_warehouse/models/em_warehouse_summary.rb', line 66 def @freeform_tags end |
#id ⇒ String
**[Required]** Unique identifier that is immutable on creation
16 17 18 |
# File 'lib/oci/em_warehouse/models/em_warehouse_summary.rb', line 16 def id @id end |
#latest_etl_run_message ⇒ String
Data Flow Run Status Message
40 41 42 |
# File 'lib/oci/em_warehouse/models/em_warehouse_summary.rb', line 40 def @latest_etl_run_message end |
#latest_etl_run_status ⇒ String
Data Flow Run Status
36 37 38 |
# File 'lib/oci/em_warehouse/models/em_warehouse_summary.rb', line 36 def latest_etl_run_status @latest_etl_run_status end |
#latest_etl_run_time ⇒ String
Data Flow Run Total Time
44 45 46 |
# File 'lib/oci/em_warehouse/models/em_warehouse_summary.rb', line 44 def latest_etl_run_time @latest_etl_run_time end |
#lifecycle_details ⇒ String
A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
60 61 62 |
# File 'lib/oci/em_warehouse/models/em_warehouse_summary.rb', line 60 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
**[Required]** The current state of the EmWarehouse.
56 57 58 |
# File 'lib/oci/em_warehouse/models/em_warehouse_summary.rb', line 56 def lifecycle_state @lifecycle_state end |
#operations_insights_warehouse_id ⇒ String
**[Required]** operations Insights Warehouse Identifier
12 13 14 |
# File 'lib/oci/em_warehouse/models/em_warehouse_summary.rb', line 12 def operations_insights_warehouse_id @operations_insights_warehouse_id end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"free-tier-retained": "true"}`
78 79 80 |
# File 'lib/oci/em_warehouse/models/em_warehouse_summary.rb', line 78 def @system_tags end |
#time_created ⇒ DateTime
**[Required]** The time the the EmWarehouse was created. An RFC3339 formatted datetime string
48 49 50 |
# File 'lib/oci/em_warehouse/models/em_warehouse_summary.rb', line 48 def time_created @time_created end |
#time_updated ⇒ DateTime
The time the EmWarehouse was updated. An RFC3339 formatted datetime string
52 53 54 |
# File 'lib/oci/em_warehouse/models/em_warehouse_summary.rb', line 52 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/oci/em_warehouse/models/em_warehouse_summary.rb', line 81 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'operations_insights_warehouse_id': :'operationsInsightsWarehouseId', 'id': :'id', 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'em_warehouse_type': :'emWarehouseType', 'em_bridge_id': :'emBridgeId', 'latest_etl_run_status': :'latestEtlRunStatus', 'latest_etl_run_message': :'latestEtlRunMessage', 'latest_etl_run_time': :'latestEtlRunTime', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/oci/em_warehouse/models/em_warehouse_summary.rb', line 105 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'operations_insights_warehouse_id': :'String', 'id': :'String', 'display_name': :'String', 'compartment_id': :'String', 'em_warehouse_type': :'String', 'em_bridge_id': :'String', 'latest_etl_run_status': :'String', 'latest_etl_run_message': :'String', 'latest_etl_run_time': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/oci/em_warehouse/models/em_warehouse_summary.rb', line 256 def ==(other) return true if equal?(other) self.class == other.class && operations_insights_warehouse_id == other.operations_insights_warehouse_id && id == other.id && display_name == other.display_name && compartment_id == other.compartment_id && em_warehouse_type == other.em_warehouse_type && em_bridge_id == other.em_bridge_id && latest_etl_run_status == other.latest_etl_run_status && == other. && latest_etl_run_time == other.latest_etl_run_time && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 |
# File 'lib/oci/em_warehouse/models/em_warehouse_summary.rb', line 301 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
281 282 283 |
# File 'lib/oci/em_warehouse/models/em_warehouse_summary.rb', line 281 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
290 291 292 |
# File 'lib/oci/em_warehouse/models/em_warehouse_summary.rb', line 290 def hash [operations_insights_warehouse_id, id, display_name, compartment_id, em_warehouse_type, em_bridge_id, latest_etl_run_status, , latest_etl_run_time, time_created, time_updated, lifecycle_state, lifecycle_details, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
334 335 336 337 338 339 340 341 342 343 |
# File 'lib/oci/em_warehouse/models/em_warehouse_summary.rb', line 334 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
328 329 330 |
# File 'lib/oci/em_warehouse/models/em_warehouse_summary.rb', line 328 def to_s to_hash.to_s end |