Class: OCI::EmWarehouse::Models::EtlRunSummary
- Inherits:
-
Object
- Object
- OCI::EmWarehouse::Models::EtlRunSummary
- Defined in:
- lib/oci/em_warehouse/models/etl_run_summary.rb
Overview
Contains summary of a run.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_ACCEPTED = 'ACCEPTED'.freeze, LIFECYCLE_STATE_IN_PROGRESS = 'IN_PROGRESS'.freeze, LIFECYCLE_STATE_CANCELING = 'CANCELING'.freeze, LIFECYCLE_STATE_CANCELED = 'CANCELED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_SUCCEEDED = 'SUCCEEDED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** Compartment Identifier.
-
#data_read_in_bytes ⇒ Integer
Data read by the dataflow run.
-
#data_written ⇒ Integer
Data written by the dataflow run.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
The name of the ETLRun.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#lifecycle_details ⇒ String
Details of the lifecycle state.
-
#lifecycle_state ⇒ String
The current state of the etlRun.
-
#run_duration_in_milliseconds ⇒ Integer
Dataflow run duration.
-
#time_created ⇒ DateTime
Time when the dataflow run was created.
-
#time_updated ⇒ DateTime
Time when the dataflow run was updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EtlRunSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ EtlRunSummary
Initializes the object
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/oci/em_warehouse/models/etl_run_summary.rb', line 124 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.data_read_in_bytes = attributes[:'dataReadInBytes'] if attributes[:'dataReadInBytes'] raise 'You cannot provide both :dataReadInBytes and :data_read_in_bytes' if attributes.key?(:'dataReadInBytes') && attributes.key?(:'data_read_in_bytes') self.data_read_in_bytes = attributes[:'data_read_in_bytes'] if attributes[:'data_read_in_bytes'] self.data_written = attributes[:'dataWritten'] if attributes[:'dataWritten'] raise 'You cannot provide both :dataWritten and :data_written' if attributes.key?(:'dataWritten') && attributes.key?(:'data_written') self.data_written = attributes[:'data_written'] if attributes[:'data_written'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.run_duration_in_milliseconds = attributes[:'runDurationInMilliseconds'] if attributes[:'runDurationInMilliseconds'] raise 'You cannot provide both :runDurationInMilliseconds and :run_duration_in_milliseconds' if attributes.key?(:'runDurationInMilliseconds') && attributes.key?(:'run_duration_in_milliseconds') self.run_duration_in_milliseconds = attributes[:'run_duration_in_milliseconds'] if attributes[:'run_duration_in_milliseconds'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** Compartment Identifier
23 24 25 |
# File 'lib/oci/em_warehouse/models/etl_run_summary.rb', line 23 def compartment_id @compartment_id end |
#data_read_in_bytes ⇒ Integer
Data read by the dataflow run
27 28 29 |
# File 'lib/oci/em_warehouse/models/etl_run_summary.rb', line 27 def data_read_in_bytes @data_read_in_bytes end |
#data_written ⇒ Integer
Data written by the dataflow run
31 32 33 |
# File 'lib/oci/em_warehouse/models/etl_run_summary.rb', line 31 def data_written @data_written end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
67 68 69 |
# File 'lib/oci/em_warehouse/models/etl_run_summary.rb', line 67 def @defined_tags end |
#display_name ⇒ String
The name of the ETLRun.
39 40 41 |
# File 'lib/oci/em_warehouse/models/etl_run_summary.rb', line 39 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
61 62 63 |
# File 'lib/oci/em_warehouse/models/etl_run_summary.rb', line 61 def @freeform_tags end |
#lifecycle_details ⇒ String
Details of the lifecycle state
43 44 45 |
# File 'lib/oci/em_warehouse/models/etl_run_summary.rb', line 43 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
The current state of the etlRun.
35 36 37 |
# File 'lib/oci/em_warehouse/models/etl_run_summary.rb', line 35 def lifecycle_state @lifecycle_state end |
#run_duration_in_milliseconds ⇒ Integer
Dataflow run duration
47 48 49 |
# File 'lib/oci/em_warehouse/models/etl_run_summary.rb', line 47 def run_duration_in_milliseconds @run_duration_in_milliseconds end |
#time_created ⇒ DateTime
Time when the dataflow run was created
51 52 53 |
# File 'lib/oci/em_warehouse/models/etl_run_summary.rb', line 51 def time_created @time_created end |
#time_updated ⇒ DateTime
Time when the dataflow run was updated
55 56 57 |
# File 'lib/oci/em_warehouse/models/etl_run_summary.rb', line 55 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/oci/em_warehouse/models/etl_run_summary.rb', line 70 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'data_read_in_bytes': :'dataReadInBytes', 'data_written': :'dataWritten', 'lifecycle_state': :'lifecycleState', 'display_name': :'displayName', 'lifecycle_details': :'lifecycleDetails', 'run_duration_in_milliseconds': :'runDurationInMilliseconds', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/oci/em_warehouse/models/etl_run_summary.rb', line 89 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'data_read_in_bytes': :'Integer', 'data_written': :'Integer', 'lifecycle_state': :'String', 'display_name': :'String', 'lifecycle_details': :'String', 'run_duration_in_milliseconds': :'Integer', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/oci/em_warehouse/models/etl_run_summary.rb', line 217 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && data_read_in_bytes == other.data_read_in_bytes && data_written == other.data_written && lifecycle_state == other.lifecycle_state && display_name == other.display_name && lifecycle_details == other.lifecycle_details && run_duration_in_milliseconds == other.run_duration_in_milliseconds && time_created == other.time_created && time_updated == other.time_updated && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/oci/em_warehouse/models/etl_run_summary.rb', line 257 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
237 238 239 |
# File 'lib/oci/em_warehouse/models/etl_run_summary.rb', line 237 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
246 247 248 |
# File 'lib/oci/em_warehouse/models/etl_run_summary.rb', line 246 def hash [compartment_id, data_read_in_bytes, data_written, lifecycle_state, display_name, lifecycle_details, run_duration_in_milliseconds, time_created, time_updated, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
290 291 292 293 294 295 296 297 298 299 |
# File 'lib/oci/em_warehouse/models/etl_run_summary.rb', line 290 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
284 285 286 |
# File 'lib/oci/em_warehouse/models/etl_run_summary.rb', line 284 def to_s to_hash.to_s end |