Class: OCI::EmWarehouse::Models::ResourceUsage
- Inherits:
-
Object
- Object
- OCI::EmWarehouse::Models::ResourceUsage
- Defined in:
- lib/oci/em_warehouse/models/resource_usage.rb
Overview
The resource usage information.
Instance Attribute Summary collapse
-
#em_instance_count ⇒ Integer
EmInstanceCount.
-
#em_instances ⇒ Array<OCI::EmWarehouse::Models::EmInstancesDetails>
List of emInstances.
-
#id ⇒ String
**[Required]** Unique identifier that is immutable on creation.
-
#operations_insights_warehouse_id ⇒ String
**[Required]** operations Insights Warehouse Identifier.
-
#targets_count ⇒ Integer
EmInstance Target count.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ResourceUsage
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ResourceUsage
Initializes the object
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/oci/em_warehouse/models/resource_usage.rb', line 67 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.operations_insights_warehouse_id = attributes[:'operationsInsightsWarehouseId'] if attributes[:'operationsInsightsWarehouseId'] raise 'You cannot provide both :operationsInsightsWarehouseId and :operations_insights_warehouse_id' if attributes.key?(:'operationsInsightsWarehouseId') && attributes.key?(:'operations_insights_warehouse_id') self.operations_insights_warehouse_id = attributes[:'operations_insights_warehouse_id'] if attributes[:'operations_insights_warehouse_id'] self.id = attributes[:'id'] if attributes[:'id'] self.em_instance_count = attributes[:'emInstanceCount'] if attributes[:'emInstanceCount'] raise 'You cannot provide both :emInstanceCount and :em_instance_count' if attributes.key?(:'emInstanceCount') && attributes.key?(:'em_instance_count') self.em_instance_count = attributes[:'em_instance_count'] if attributes[:'em_instance_count'] self.targets_count = attributes[:'targetsCount'] if attributes[:'targetsCount'] raise 'You cannot provide both :targetsCount and :targets_count' if attributes.key?(:'targetsCount') && attributes.key?(:'targets_count') self.targets_count = attributes[:'targets_count'] if attributes[:'targets_count'] self.em_instances = attributes[:'emInstances'] if attributes[:'emInstances'] raise 'You cannot provide both :emInstances and :em_instances' if attributes.key?(:'emInstances') && attributes.key?(:'em_instances') self.em_instances = attributes[:'em_instances'] if attributes[:'em_instances'] end |
Instance Attribute Details
#em_instance_count ⇒ Integer
EmInstanceCount
20 21 22 |
# File 'lib/oci/em_warehouse/models/resource_usage.rb', line 20 def em_instance_count @em_instance_count end |
#em_instances ⇒ Array<OCI::EmWarehouse::Models::EmInstancesDetails>
List of emInstances
28 29 30 |
# File 'lib/oci/em_warehouse/models/resource_usage.rb', line 28 def em_instances @em_instances end |
#id ⇒ String
**[Required]** Unique identifier that is immutable on creation
16 17 18 |
# File 'lib/oci/em_warehouse/models/resource_usage.rb', line 16 def id @id end |
#operations_insights_warehouse_id ⇒ String
**[Required]** operations Insights Warehouse Identifier
12 13 14 |
# File 'lib/oci/em_warehouse/models/resource_usage.rb', line 12 def operations_insights_warehouse_id @operations_insights_warehouse_id end |
#targets_count ⇒ Integer
EmInstance Target count
24 25 26 |
# File 'lib/oci/em_warehouse/models/resource_usage.rb', line 24 def targets_count @targets_count end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 40 41 |
# File 'lib/oci/em_warehouse/models/resource_usage.rb', line 31 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'operations_insights_warehouse_id': :'operationsInsightsWarehouseId', 'id': :'id', 'em_instance_count': :'emInstanceCount', 'targets_count': :'targetsCount', 'em_instances': :'emInstances' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/oci/em_warehouse/models/resource_usage.rb', line 44 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'operations_insights_warehouse_id': :'String', 'id': :'String', 'em_instance_count': :'Integer', 'targets_count': :'Integer', 'em_instances': :'Array<OCI::EmWarehouse::Models::EmInstancesDetails>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
107 108 109 110 111 112 113 114 115 116 |
# File 'lib/oci/em_warehouse/models/resource_usage.rb', line 107 def ==(other) return true if equal?(other) self.class == other.class && operations_insights_warehouse_id == other.operations_insights_warehouse_id && id == other.id && em_instance_count == other.em_instance_count && targets_count == other.targets_count && em_instances == other.em_instances end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/oci/em_warehouse/models/resource_usage.rb', line 141 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
121 122 123 |
# File 'lib/oci/em_warehouse/models/resource_usage.rb', line 121 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
130 131 132 |
# File 'lib/oci/em_warehouse/models/resource_usage.rb', line 130 def hash [operations_insights_warehouse_id, id, em_instance_count, targets_count, em_instances].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
174 175 176 177 178 179 180 181 182 183 |
# File 'lib/oci/em_warehouse/models/resource_usage.rb', line 174 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
168 169 170 |
# File 'lib/oci/em_warehouse/models/resource_usage.rb', line 168 def to_s to_hash.to_s end |