Class: OCI::Email::EmailClient
- Inherits:
-
Object
- Object
- OCI::Email::EmailClient
- Defined in:
- lib/oci/email/email_client.rb
Overview
API for the Email Delivery service. Use this API to send high-volume, application-generated emails. For more information, see [Overview of the Email Delivery Service](/iaas/Content/Email/Concepts/overview.htm).
Note: Write actions (POST, UPDATE, DELETE) may take several minutes to propagate and be reflected by the API. If a subsequent read request fails to reflect your changes, wait a few minutes and try again.
Instance Attribute Summary collapse
-
#api_client ⇒ OCI::ApiClient
readonly
Client used to make HTTP requests.
-
#endpoint ⇒ String
readonly
Fully qualified endpoint URL.
-
#region ⇒ String
The region, which will usually correspond to a value in Regions::REGION_ENUM.
-
#retry_config ⇒ OCI::Retry::RetryConfig
readonly
The default retry configuration to apply to all operations in this service client.
Instance Method Summary collapse
-
#change_sender_compartment(sender_id, change_sender_compartment_details, opts = {}) ⇒ Response
Moves a sender into a different compartment.
-
#create_sender(create_sender_details, opts = {}) ⇒ Response
Creates a sender for a tenancy in a given compartment.
-
#create_suppression(create_suppression_details, opts = {}) ⇒ Response
Adds recipient email addresses to the suppression list for a tenancy.
-
#delete_sender(sender_id, opts = {}) ⇒ Response
Deletes an approved sender for a tenancy in a given compartment for a provided
senderId. -
#delete_suppression(suppression_id, opts = {}) ⇒ Response
Removes a suppressed recipient email address from the suppression list for a tenancy in a given compartment for a provided
suppressionId. -
#get_sender(sender_id, opts = {}) ⇒ Response
Gets an approved sender for a given
senderId. -
#get_suppression(suppression_id, opts = {}) ⇒ Response
Gets the details of a suppressed recipient email address for a given
suppressionId. -
#initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) ⇒ EmailClient
constructor
Creates a new EmailClient.
-
#list_senders(compartment_id, opts = {}) ⇒ Response
Gets a collection of approved sender email addresses and sender IDs.
-
#list_suppressions(compartment_id, opts = {}) ⇒ Response
Gets a list of suppressed recipient email addresses for a user.
-
#logger ⇒ Logger
The logger for this client.
-
#update_sender(sender_id, update_sender_details, opts = {}) ⇒ Response
Replaces the set of tags for a sender with the tags provided.
Constructor Details
#initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) ⇒ EmailClient
Creates a new EmailClient. Notes:
If a config is not specified, then the global OCI.config will be used.
This client is not thread-safe
Either a region or an endpoint must be specified. If an endpoint is specified, it will be used instead of the
region. A region may be specified in the config or via or the region parameter. If specified in both, then the
region parameter will be used.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/oci/email/email_client.rb', line 57 def initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) # If the signer is an InstancePrincipalsSecurityTokenSigner or SecurityTokenSigner and no config was supplied (they are self-sufficient signers) # then create a dummy config to pass to the ApiClient constructor. If customers wish to create a client which uses instance principals # and has config (either populated programmatically or loaded from a file), they must construct that config themselves and then # pass it to this constructor. # # If there is no signer (or the signer is not an instance principals signer) and no config was supplied, this is not valid # so try and load the config from the default file. config = OCI::Config.validate_and_build_config_with_signer(config, signer) signer = OCI::Signer.config_file_auth_builder(config) if signer.nil? @api_client = OCI::ApiClient.new(config, signer, proxy_settings: proxy_settings) @retry_config = retry_config if endpoint @endpoint = endpoint + '/20170907' else region ||= config.region region ||= signer.region if signer.respond_to?(:region) self.region = region end logger.info "EmailClient endpoint set to '#{@endpoint}'." if logger end |
Instance Attribute Details
#api_client ⇒ OCI::ApiClient (readonly)
Client used to make HTTP requests.
17 18 19 |
# File 'lib/oci/email/email_client.rb', line 17 def api_client @api_client end |
#endpoint ⇒ String (readonly)
Fully qualified endpoint URL
21 22 23 |
# File 'lib/oci/email/email_client.rb', line 21 def endpoint @endpoint end |
#region ⇒ String
The region, which will usually correspond to a value in Regions::REGION_ENUM.
31 32 33 |
# File 'lib/oci/email/email_client.rb', line 31 def region @region end |
#retry_config ⇒ OCI::Retry::RetryConfig (readonly)
The default retry configuration to apply to all operations in this service client. This can be overridden on a per-operation basis. The default retry configuration value is nil, which means that an operation will not perform any retries
27 28 29 |
# File 'lib/oci/email/email_client.rb', line 27 def retry_config @retry_config end |
Instance Method Details
#change_sender_compartment(sender_id, change_sender_compartment_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/email/change_sender_compartment.rb.html) to see an example of how to use change_sender_compartment API.
Moves a sender into a different compartment. When provided, If-Match is checked against ETag values of the resource.
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/oci/email/email_client.rb', line 118 def change_sender_compartment(sender_id, change_sender_compartment_details, opts = {}) logger.debug 'Calling operation EmailClient#change_sender_compartment.' if logger raise "Missing the required parameter 'sender_id' when calling change_sender_compartment." if sender_id.nil? raise "Missing the required parameter 'change_sender_compartment_details' when calling change_sender_compartment." if change_sender_compartment_details.nil? raise "Parameter value for 'sender_id' must not be blank" if OCI::Internal::Util.blank_string?(sender_id) path = '/senders/{senderId}/actions/changeCompartment'.sub('{senderId}', sender_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(change_sender_compartment_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'EmailClient#change_sender_compartment') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#create_sender(create_sender_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/email/create_sender.rb.html) to see an example of how to use create_sender API.
Creates a sender for a tenancy in a given compartment.
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/oci/email/email_client.rb', line 173 def create_sender(create_sender_details, opts = {}) logger.debug 'Calling operation EmailClient#create_sender.' if logger raise "Missing the required parameter 'create_sender_details' when calling create_sender." if create_sender_details.nil? path = '/senders' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(create_sender_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'EmailClient#create_sender') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Email::Models::Sender' ) end # rubocop:enable Metrics/BlockLength end |
#create_suppression(create_suppression_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/email/create_suppression.rb.html) to see an example of how to use create_suppression API.
Adds recipient email addresses to the suppression list for a tenancy. Addresses added to the suppression list via the API are denoted as "MANUAL" in the reason field. Note: All email addresses added to the suppression list are normalized to include only lowercase letters.
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/oci/email/email_client.rb', line 231 def create_suppression(create_suppression_details, opts = {}) logger.debug 'Calling operation EmailClient#create_suppression.' if logger raise "Missing the required parameter 'create_suppression_details' when calling create_suppression." if create_suppression_details.nil? path = '/suppressions' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(create_suppression_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'EmailClient#create_suppression') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Email::Models::Suppression' ) end # rubocop:enable Metrics/BlockLength end |
#delete_sender(sender_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/email/delete_sender.rb.html) to see an example of how to use delete_sender API.
Deletes an approved sender for a tenancy in a given compartment for a provided senderId.
290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 |
# File 'lib/oci/email/email_client.rb', line 290 def delete_sender(sender_id, opts = {}) logger.debug 'Calling operation EmailClient#delete_sender.' if logger raise "Missing the required parameter 'sender_id' when calling delete_sender." if sender_id.nil? raise "Parameter value for 'sender_id' must not be blank" if OCI::Internal::Util.blank_string?(sender_id) path = '/senders/{senderId}'.sub('{senderId}', sender_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'EmailClient#delete_sender') do @api_client.call_api( :DELETE, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#delete_suppression(suppression_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/email/delete_suppression.rb.html) to see an example of how to use delete_suppression API.
Removes a suppressed recipient email address from the suppression list for a tenancy in a given compartment for a provided suppressionId.
346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 |
# File 'lib/oci/email/email_client.rb', line 346 def delete_suppression(suppression_id, opts = {}) logger.debug 'Calling operation EmailClient#delete_suppression.' if logger raise "Missing the required parameter 'suppression_id' when calling delete_suppression." if suppression_id.nil? raise "Parameter value for 'suppression_id' must not be blank" if OCI::Internal::Util.blank_string?(suppression_id) path = '/suppressions/{suppressionId}'.sub('{suppressionId}', suppression_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'EmailClient#delete_suppression') do @api_client.call_api( :DELETE, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#get_sender(sender_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/email/get_sender.rb.html) to see an example of how to use get_sender API.
Gets an approved sender for a given senderId.
399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 |
# File 'lib/oci/email/email_client.rb', line 399 def get_sender(sender_id, opts = {}) logger.debug 'Calling operation EmailClient#get_sender.' if logger raise "Missing the required parameter 'sender_id' when calling get_sender." if sender_id.nil? raise "Parameter value for 'sender_id' must not be blank" if OCI::Internal::Util.blank_string?(sender_id) path = '/senders/{senderId}'.sub('{senderId}', sender_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'EmailClient#get_sender') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Email::Models::Sender' ) end # rubocop:enable Metrics/BlockLength end |
#get_suppression(suppression_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/email/get_suppression.rb.html) to see an example of how to use get_suppression API.
Gets the details of a suppressed recipient email address for a given suppressionId. Each suppression is given a unique OCID.
455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 |
# File 'lib/oci/email/email_client.rb', line 455 def get_suppression(suppression_id, opts = {}) logger.debug 'Calling operation EmailClient#get_suppression.' if logger raise "Missing the required parameter 'suppression_id' when calling get_suppression." if suppression_id.nil? raise "Parameter value for 'suppression_id' must not be blank" if OCI::Internal::Util.blank_string?(suppression_id) path = '/suppressions/{suppressionId}'.sub('{suppressionId}', suppression_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'EmailClient#get_suppression') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Email::Models::Suppression' ) end # rubocop:enable Metrics/BlockLength end |
#list_senders(compartment_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/email/list_senders.rb.html) to see an example of how to use list_senders API.
Gets a collection of approved sender email addresses and sender IDs.
529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 |
# File 'lib/oci/email/email_client.rb', line 529 def list_senders(compartment_id, opts = {}) logger.debug 'Calling operation EmailClient#list_senders.' if logger raise "Missing the required parameter 'compartment_id' when calling list_senders." if compartment_id.nil? if opts[:lifecycle_state] && !OCI::Email::Models::Sender::LIFECYCLE_STATE_ENUM.include?(opts[:lifecycle_state]) raise 'Invalid value for "lifecycle_state", must be one of the values in OCI::Email::Models::Sender::LIFECYCLE_STATE_ENUM.' end if opts[:sort_by] && !%w[TIMECREATED EMAILADDRESS].include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of TIMECREATED, EMAILADDRESS.' end if opts[:sort_order] && !%w[ASC DESC].include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of ASC, DESC.' end path = '/senders' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:compartmentId] = compartment_id query_params[:lifecycleState] = opts[:lifecycle_state] if opts[:lifecycle_state] query_params[:emailAddress] = opts[:email_address] if opts[:email_address] query_params[:page] = opts[:page] if opts[:page] query_params[:limit] = opts[:limit] if opts[:limit] query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'EmailClient#list_senders') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'Array<OCI::Email::Models::SenderSummary>' ) end # rubocop:enable Metrics/BlockLength end |
#list_suppressions(compartment_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/email/list_suppressions.rb.html) to see an example of how to use list_suppressions API.
Gets a list of suppressed recipient email addresses for a user. The compartmentId for suppressions must be a tenancy OCID. The returned list is sorted by creation time in descending order.
640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 |
# File 'lib/oci/email/email_client.rb', line 640 def list_suppressions(compartment_id, opts = {}) logger.debug 'Calling operation EmailClient#list_suppressions.' if logger raise "Missing the required parameter 'compartment_id' when calling list_suppressions." if compartment_id.nil? if opts[:sort_by] && !%w[TIMECREATED EMAILADDRESS].include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of TIMECREATED, EMAILADDRESS.' end if opts[:sort_order] && !%w[ASC DESC].include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of ASC, DESC.' end path = '/suppressions' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:compartmentId] = compartment_id query_params[:emailAddress] = opts[:email_address] if opts[:email_address] query_params[:timeCreatedGreaterThanOrEqualTo] = opts[:time_created_greater_than_or_equal_to] if opts[:time_created_greater_than_or_equal_to] query_params[:timeCreatedLessThan] = opts[:time_created_less_than] if opts[:time_created_less_than] query_params[:page] = opts[:page] if opts[:page] query_params[:limit] = opts[:limit] if opts[:limit] query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'EmailClient#list_suppressions') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'Array<OCI::Email::Models::SuppressionSummary>' ) end # rubocop:enable Metrics/BlockLength end |
#logger ⇒ Logger
Returns The logger for this client. May be nil.
96 97 98 |
# File 'lib/oci/email/email_client.rb', line 96 def logger @api_client.config.logger end |
#update_sender(sender_id, update_sender_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/email/update_sender.rb.html) to see an example of how to use update_sender API.
Replaces the set of tags for a sender with the tags provided. If either freeform or defined tags are omitted, the tags for that set remain the same. Each set must include the full set of tags for the sender, partial updates are not permitted. For more information about tagging, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 |
# File 'lib/oci/email/email_client.rb', line 718 def update_sender(sender_id, update_sender_details, opts = {}) logger.debug 'Calling operation EmailClient#update_sender.' if logger raise "Missing the required parameter 'sender_id' when calling update_sender." if sender_id.nil? raise "Missing the required parameter 'update_sender_details' when calling update_sender." if update_sender_details.nil? raise "Parameter value for 'sender_id' must not be blank" if OCI::Internal::Util.blank_string?(sender_id) path = '/senders/{senderId}'.sub('{senderId}', sender_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(update_sender_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'EmailClient#update_sender') do @api_client.call_api( :PUT, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Email::Models::Sender' ) end # rubocop:enable Metrics/BlockLength end |