Class: OCI::Email::Models::Dkim
- Inherits:
-
Object
- Object
- OCI::Email::Models::Dkim
- Defined in:
- lib/oci/email/models/dkim.rb
Overview
The properties that define a DKIM.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_NEEDS_ATTENTION = 'NEEDS_ATTENTION'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#cname_record_value ⇒ String
The DNS CNAME record value to provision to the DKIM DNS subdomain, when using the CNAME method for DKIM setup (preferred).
-
#compartment_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment that contains this DKIM.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
The description of the DKIM.
-
#dns_subdomain_name ⇒ String
The name of the DNS subdomain that must be provisioned to enable email recipients to verify DKIM signatures.
-
#email_domain_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the email domain that this DKIM belongs to.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the DKIM.
-
#lifecycle_details ⇒ String
A message describing the current state in more detail.
-
#lifecycle_state ⇒ String
The current state of the DKIM.
-
#name ⇒ String
**[Required]** The DKIM selector.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys.
-
#time_created ⇒ DateTime
The time the DKIM was created.
-
#time_updated ⇒ DateTime
The time of the last change to the DKIM configuration, due to a state change or an update operation.
-
#txt_record_value ⇒ String
The DNS TXT record value to provision to the DKIM DNS subdomain in place of using a CNAME record.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Dkim
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Dkim
Initializes the object
185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 |
# File 'lib/oci/email/models/dkim.rb', line 185 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.id = attributes[:'id'] if attributes[:'id'] self.email_domain_id = attributes[:'emailDomainId'] if attributes[:'emailDomainId'] raise 'You cannot provide both :emailDomainId and :email_domain_id' if attributes.key?(:'emailDomainId') && attributes.key?(:'email_domain_id') self.email_domain_id = attributes[:'email_domain_id'] if attributes[:'email_domain_id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.description = attributes[:'description'] if attributes[:'description'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.dns_subdomain_name = attributes[:'dnsSubdomainName'] if attributes[:'dnsSubdomainName'] raise 'You cannot provide both :dnsSubdomainName and :dns_subdomain_name' if attributes.key?(:'dnsSubdomainName') && attributes.key?(:'dns_subdomain_name') self.dns_subdomain_name = attributes[:'dns_subdomain_name'] if attributes[:'dns_subdomain_name'] self.cname_record_value = attributes[:'cnameRecordValue'] if attributes[:'cnameRecordValue'] raise 'You cannot provide both :cnameRecordValue and :cname_record_value' if attributes.key?(:'cnameRecordValue') && attributes.key?(:'cname_record_value') self.cname_record_value = attributes[:'cname_record_value'] if attributes[:'cname_record_value'] self.txt_record_value = attributes[:'txtRecordValue'] if attributes[:'txtRecordValue'] raise 'You cannot provide both :txtRecordValue and :txt_record_value' if attributes.key?(:'txtRecordValue') && attributes.key?(:'txt_record_value') self.txt_record_value = attributes[:'txt_record_value'] if attributes[:'txt_record_value'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#cname_record_value ⇒ String
The DNS CNAME record value to provision to the DKIM DNS subdomain, when using the CNAME method for DKIM setup (preferred).
86 87 88 |
# File 'lib/oci/email/models/dkim.rb', line 86 def cname_record_value @cname_record_value end |
#compartment_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment that contains this DKIM.
44 45 46 |
# File 'lib/oci/email/models/dkim.rb', line 44 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: `{"CostCenter": "42"}`
110 111 112 |
# File 'lib/oci/email/models/dkim.rb', line 110 def @defined_tags end |
#description ⇒ String
The description of the DKIM. Avoid entering confidential information.
58 59 60 |
# File 'lib/oci/email/models/dkim.rb', line 58 def description @description end |
#dns_subdomain_name ⇒ String
The name of the DNS subdomain that must be provisioned to enable email recipients to verify DKIM signatures. It is usually created with a CNAME record set to the cnameRecordValue
81 82 83 |
# File 'lib/oci/email/models/dkim.rb', line 81 def dns_subdomain_name @dns_subdomain_name end |
#email_domain_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the email domain that this DKIM belongs to.
39 40 41 |
# File 'lib/oci/email/models/dkim.rb', line 39 def email_domain_id @email_domain_id end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: `"Finance"`
102 103 104 |
# File 'lib/oci/email/models/dkim.rb', line 102 def @freeform_tags end |
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the DKIM.
33 34 35 |
# File 'lib/oci/email/models/dkim.rb', line 33 def id @id end |
#lifecycle_details ⇒ String
A message describing the current state in more detail. For example, can be used to provide actionable information for a resource.
54 55 56 |
# File 'lib/oci/email/models/dkim.rb', line 54 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
The current state of the DKIM.
48 49 50 |
# File 'lib/oci/email/models/dkim.rb', line 48 def lifecycle_state @lifecycle_state end |
#name ⇒ String
**[Required]** The DKIM selector. If the same domain is managed in more than one region, each region must use different selectors.
28 29 30 |
# File 'lib/oci/email/models/dkim.rb', line 28 def name @name end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"free-tier-retained": "true"}`
116 117 118 |
# File 'lib/oci/email/models/dkim.rb', line 116 def @system_tags end |
#time_created ⇒ DateTime
The time the DKIM was created. Times are expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format, "YYYY-MM-ddThh:mmZ".
Example: `2021-02-12T22:47:12.613Z`
67 68 69 |
# File 'lib/oci/email/models/dkim.rb', line 67 def time_created @time_created end |
#time_updated ⇒ DateTime
The time of the last change to the DKIM configuration, due to a state change or an update operation. Times are expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format, "YYYY-MM-ddThh:mmZ".
75 76 77 |
# File 'lib/oci/email/models/dkim.rb', line 75 def time_updated @time_updated end |
#txt_record_value ⇒ String
The DNS TXT record value to provision to the DKIM DNS subdomain in place of using a CNAME record. This is used in cases where a CNAME can not be used, such as when the cnameRecordValue would exceed the maximum length for a DNS entry. This can also be used by customers who have an existing procedure to directly provision TXT records for DKIM. Be aware that many DNS APIs will require you to break this string into segments of less than 255 characters.
94 95 96 |
# File 'lib/oci/email/models/dkim.rb', line 94 def txt_record_value @txt_record_value end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/oci/email/models/dkim.rb', line 119 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'id': :'id', 'email_domain_id': :'emailDomainId', 'compartment_id': :'compartmentId', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'description': :'description', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'dns_subdomain_name': :'dnsSubdomainName', 'cname_record_value': :'cnameRecordValue', 'txt_record_value': :'txtRecordValue', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/oci/email/models/dkim.rb', line 142 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'id': :'String', 'email_domain_id': :'String', 'compartment_id': :'String', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'description': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'dns_subdomain_name': :'String', 'cname_record_value': :'String', 'txt_record_value': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 |
# File 'lib/oci/email/models/dkim.rb', line 290 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && id == other.id && email_domain_id == other.email_domain_id && compartment_id == other.compartment_id && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && description == other.description && time_created == other.time_created && time_updated == other.time_updated && dns_subdomain_name == other.dns_subdomain_name && cname_record_value == other.cname_record_value && txt_record_value == other.txt_record_value && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 |
# File 'lib/oci/email/models/dkim.rb', line 334 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
314 315 316 |
# File 'lib/oci/email/models/dkim.rb', line 314 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
323 324 325 |
# File 'lib/oci/email/models/dkim.rb', line 323 def hash [name, id, email_domain_id, compartment_id, lifecycle_state, lifecycle_details, description, time_created, time_updated, dns_subdomain_name, cname_record_value, txt_record_value, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
367 368 369 370 371 372 373 374 375 376 |
# File 'lib/oci/email/models/dkim.rb', line 367 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
361 362 363 |
# File 'lib/oci/email/models/dkim.rb', line 361 def to_s to_hash.to_s end |