Class: OCI::Email::Models::DkimSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/email/models/dkim_summary.rb

Overview

The properties that define a DKIM.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DkimSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :name (String)

    The value to assign to the #name property

  • :id (String)

    The value to assign to the #id property

  • :email_domain_id (String)

    The value to assign to the #email_domain_id property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :description (String)

    The value to assign to the #description property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :time_updated (DateTime)

    The value to assign to the #time_updated property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property

  • :system_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #system_tags property



134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/oci/email/models/dkim_summary.rb', line 134

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.name = attributes[:'name'] if attributes[:'name']

  self.id = attributes[:'id'] if attributes[:'id']

  self.email_domain_id = attributes[:'emailDomainId'] if attributes[:'emailDomainId']

  raise 'You cannot provide both :emailDomainId and :email_domain_id' if attributes.key?(:'emailDomainId') && attributes.key?(:'email_domain_id')

  self.email_domain_id = attributes[:'email_domain_id'] if attributes[:'email_domain_id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.description = attributes[:'description'] if attributes[:'description']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

  raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

  self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']
end

Instance Attribute Details

#compartment_idString

The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment that contains this DKIM.

Returns:

  • (String)


30
31
32
# File 'lib/oci/email/models/dkim_summary.rb', line 30

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: `{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


71
72
73
# File 'lib/oci/email/models/dkim_summary.rb', line 71

def defined_tags
  @defined_tags
end

#descriptionString

The description of a DKIM. Avoid entering confidential information.

Returns:

  • (String)


38
39
40
# File 'lib/oci/email/models/dkim_summary.rb', line 38

def description
  @description
end

#email_domain_idString

**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the email domain that this DKIM belongs to.

Returns:

  • (String)


25
26
27
# File 'lib/oci/email/models/dkim_summary.rb', line 25

def email_domain_id
  @email_domain_id
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: `"Finance"`

Returns:

  • (Hash<String, String>)


63
64
65
# File 'lib/oci/email/models/dkim_summary.rb', line 63

def freeform_tags
  @freeform_tags
end

#idString

Returns:

  • (String)


19
20
21
# File 'lib/oci/email/models/dkim_summary.rb', line 19

def id
  @id
end

#lifecycle_stateString

The current state of the DKIM.

Returns:

  • (String)


34
35
36
# File 'lib/oci/email/models/dkim_summary.rb', line 34

def lifecycle_state
  @lifecycle_state
end

#nameString

**[Required]** The DKIM selector. This selector is required to be globally unique for this email domain.

Returns:

  • (String)


14
15
16
# File 'lib/oci/email/models/dkim_summary.rb', line 14

def name
  @name
end

#system_tagsHash<String, Hash<String, Object>>

Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"free-tier-retained": "true"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


77
78
79
# File 'lib/oci/email/models/dkim_summary.rb', line 77

def system_tags
  @system_tags
end

#time_createdDateTime

The time the DKIM was created. Times are expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format, "YYYY-MM-ddThh:mmZ".

Example: `2021-02-12T22:47:12.613Z`

Returns:

  • (DateTime)


47
48
49
# File 'lib/oci/email/models/dkim_summary.rb', line 47

def time_created
  @time_created
end

#time_updatedDateTime

The time of the last change to the DKIM configuration, due to a state change or an update operation. Times are expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format, "YYYY-MM-ddThh:mmZ".

Returns:

  • (DateTime)


55
56
57
# File 'lib/oci/email/models/dkim_summary.rb', line 55

def time_updated
  @time_updated
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/oci/email/models/dkim_summary.rb', line 80

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'name': :'name',
    'id': :'id',
    'email_domain_id': :'emailDomainId',
    'compartment_id': :'compartmentId',
    'lifecycle_state': :'lifecycleState',
    'description': :'description',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/oci/email/models/dkim_summary.rb', line 99

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'name': :'String',
    'id': :'String',
    'email_domain_id': :'String',
    'compartment_id': :'String',
    'lifecycle_state': :'String',
    'description': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/oci/email/models/dkim_summary.rb', line 202

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    name == other.name &&
    id == other.id &&
    email_domain_id == other.email_domain_id &&
    compartment_id == other.compartment_id &&
    lifecycle_state == other.lifecycle_state &&
    description == other.description &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/oci/email/models/dkim_summary.rb', line 242

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


222
223
224
# File 'lib/oci/email/models/dkim_summary.rb', line 222

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



231
232
233
# File 'lib/oci/email/models/dkim_summary.rb', line 231

def hash
  [name, id, email_domain_id, compartment_id, lifecycle_state, description, time_created, time_updated, freeform_tags, defined_tags, system_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



275
276
277
278
279
280
281
282
283
284
# File 'lib/oci/email/models/dkim_summary.rb', line 275

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



269
270
271
# File 'lib/oci/email/models/dkim_summary.rb', line 269

def to_s
  to_hash.to_s
end