Class: OCI::Email::Models::Sender
- Inherits:
-
Object
- Object
- OCI::Email::Models::Sender
- Defined in:
- lib/oci/email/models/sender.rb
Overview
The full information representing an approved sender.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The OCID for the compartment.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#email_address ⇒ String
[Required] Email address of the sender.
-
#email_domain_id ⇒ String
The email domain used to assert responsibility for emails sent from this sender.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] The unique OCID of the sender.
-
#is_spf ⇒ BOOLEAN
Value of the SPF field.
-
#lifecycle_state ⇒ String
The sender’s current lifecycle state.
-
#time_created ⇒ DateTime
The date and time the approved sender was added in "YYYY-MM-ddThh:mmZ" format with a Z offset, as defined by RFC 3339.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Sender
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Sender
Initializes the object
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/oci/email/models/sender.rb', line 117 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.email_address = attributes[:'emailAddress'] if attributes[:'emailAddress'] raise 'You cannot provide both :emailAddress and :email_address' if attributes.key?(:'emailAddress') && attributes.key?(:'email_address') self.email_address = attributes[:'email_address'] if attributes[:'email_address'] self.id = attributes[:'id'] if attributes[:'id'] self.is_spf = attributes[:'isSpf'] unless attributes[:'isSpf'].nil? self.is_spf = false if is_spf.nil? && !attributes.key?(:'isSpf') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isSpf and :is_spf' if attributes.key?(:'isSpf') && attributes.key?(:'is_spf') self.is_spf = attributes[:'is_spf'] unless attributes[:'is_spf'].nil? self.is_spf = false if is_spf.nil? && !attributes.key?(:'isSpf') && !attributes.key?(:'is_spf') # rubocop:disable Style/StringLiterals self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.email_domain_id = attributes[:'emailDomainId'] if attributes[:'emailDomainId'] raise 'You cannot provide both :emailDomainId and :email_domain_id' if attributes.key?(:'emailDomainId') && attributes.key?(:'email_domain_id') self.email_domain_id = attributes[:'email_domain_id'] if attributes[:'email_domain_id'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The OCID for the compartment.
21 22 23 |
# File 'lib/oci/email/models/sender.rb', line 21 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
66 67 68 |
# File 'lib/oci/email/models/sender.rb', line 66 def @defined_tags end |
#email_address ⇒ String
[Required] Email address of the sender.
25 26 27 |
# File 'lib/oci/email/models/sender.rb', line 25 def email_address @email_address end |
#email_domain_id ⇒ String
The email domain used to assert responsibility for emails sent from this sender.
50 51 52 |
# File 'lib/oci/email/models/sender.rb', line 50 def email_domain_id @email_domain_id end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
58 59 60 |
# File 'lib/oci/email/models/sender.rb', line 58 def @freeform_tags end |
#id ⇒ String
[Required] The unique OCID of the sender.
29 30 31 |
# File 'lib/oci/email/models/sender.rb', line 29 def id @id end |
#is_spf ⇒ BOOLEAN
Value of the SPF field. For more information about SPF, please see [SPF Authentication](docs.cloud.oracle.com/Content/Email/Concepts/overview.htm#components).
35 36 37 |
# File 'lib/oci/email/models/sender.rb', line 35 def is_spf @is_spf end |
#lifecycle_state ⇒ String
The sender’s current lifecycle state.
39 40 41 |
# File 'lib/oci/email/models/sender.rb', line 39 def lifecycle_state @lifecycle_state end |
#time_created ⇒ DateTime
The date and time the approved sender was added in "YYYY-MM-ddThh:mmZ" format with a Z offset, as defined by RFC 3339.
45 46 47 |
# File 'lib/oci/email/models/sender.rb', line 45 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/oci/email/models/sender.rb', line 69 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'email_address': :'emailAddress', 'id': :'id', 'is_spf': :'isSpf', 'lifecycle_state': :'lifecycleState', 'time_created': :'timeCreated', 'email_domain_id': :'emailDomainId', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/oci/email/models/sender.rb', line 86 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'email_address': :'String', 'id': :'String', 'is_spf': :'BOOLEAN', 'lifecycle_state': :'String', 'time_created': :'DateTime', 'email_domain_id': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/oci/email/models/sender.rb', line 196 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && email_address == other.email_address && id == other.id && is_spf == other.is_spf && lifecycle_state == other.lifecycle_state && time_created == other.time_created && email_domain_id == other.email_domain_id && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/oci/email/models/sender.rb', line 234 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
214 215 216 |
# File 'lib/oci/email/models/sender.rb', line 214 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
223 224 225 |
# File 'lib/oci/email/models/sender.rb', line 223 def hash [compartment_id, email_address, id, is_spf, lifecycle_state, time_created, email_domain_id, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
267 268 269 270 271 272 273 274 275 276 |
# File 'lib/oci/email/models/sender.rb', line 267 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
261 262 263 |
# File 'lib/oci/email/models/sender.rb', line 261 def to_s to_hash.to_s end |