Class: OCI::Email::Models::Suppression
- Inherits:
-
Object
- Object
- OCI::Email::Models::Suppression
- Defined in:
- lib/oci/email/models/suppression.rb
Overview
The full information representing an email suppression.
Constant Summary collapse
- REASON_ENUM =
[ REASON_UNKNOWN = 'UNKNOWN'.freeze, REASON_HARDBOUNCE = 'HARDBOUNCE'.freeze, REASON_COMPLAINT = 'COMPLAINT'.freeze, REASON_MANUAL = 'MANUAL'.freeze, REASON_SOFTBOUNCE = 'SOFTBOUNCE'.freeze, REASON_UNSUBSCRIBE = 'UNSUBSCRIBE'.freeze, REASON_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The OCID of the compartment to contain the suppression.
-
#email_address ⇒ String
**[Required]** Email address of the suppression.
-
#error_detail ⇒ String
The specific error message returned by a system that resulted in the suppression.
-
#error_source ⇒ String
DNS name of the source of the error that caused the suppression.
-
#id ⇒ String
**[Required]** The unique ID of the suppression.
-
#message_id ⇒ String
The value of the Message-ID header from the email that triggered a suppression.
-
#reason ⇒ String
The reason that the email address was suppressed.
-
#time_created ⇒ DateTime
The date and time the suppression was added in "YYYY-MM-ddThh:mmZ" format with a Z offset, as defined by RFC 3339.
-
#time_last_suppressed ⇒ DateTime
The last date and time the suppression prevented submission in "YYYY-MM-ddThh:mmZ" format with a Z offset, as defined by RFC 3339.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Suppression
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Suppression
Initializes the object
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/oci/email/models/suppression.rb', line 125 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.email_address = attributes[:'emailAddress'] if attributes[:'emailAddress'] raise 'You cannot provide both :emailAddress and :email_address' if attributes.key?(:'emailAddress') && attributes.key?(:'email_address') self.email_address = attributes[:'email_address'] if attributes[:'email_address'] self.id = attributes[:'id'] if attributes[:'id'] self.reason = attributes[:'reason'] if attributes[:'reason'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_last_suppressed = attributes[:'timeLastSuppressed'] if attributes[:'timeLastSuppressed'] raise 'You cannot provide both :timeLastSuppressed and :time_last_suppressed' if attributes.key?(:'timeLastSuppressed') && attributes.key?(:'time_last_suppressed') self.time_last_suppressed = attributes[:'time_last_suppressed'] if attributes[:'time_last_suppressed'] self. = attributes[:'messageId'] if attributes[:'messageId'] raise 'You cannot provide both :messageId and :message_id' if attributes.key?(:'messageId') && attributes.key?(:'message_id') self. = attributes[:'message_id'] if attributes[:'message_id'] self.error_detail = attributes[:'errorDetail'] if attributes[:'errorDetail'] raise 'You cannot provide both :errorDetail and :error_detail' if attributes.key?(:'errorDetail') && attributes.key?(:'error_detail') self.error_detail = attributes[:'error_detail'] if attributes[:'error_detail'] self.error_source = attributes[:'errorSource'] if attributes[:'errorSource'] raise 'You cannot provide both :errorSource and :error_source' if attributes.key?(:'errorSource') && attributes.key?(:'error_source') self.error_source = attributes[:'error_source'] if attributes[:'error_source'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The OCID of the compartment to contain the suppression. Since suppressions are at the customer level, this must be the tenancy OCID.
26 27 28 |
# File 'lib/oci/email/models/suppression.rb', line 26 def compartment_id @compartment_id end |
#email_address ⇒ String
**[Required]** Email address of the suppression.
30 31 32 |
# File 'lib/oci/email/models/suppression.rb', line 30 def email_address @email_address end |
#error_detail ⇒ String
The specific error message returned by a system that resulted in the suppression. This message is usually an SMTP error code with additional descriptive text. Not provided for all types of suppressions.
65 66 67 |
# File 'lib/oci/email/models/suppression.rb', line 65 def error_detail @error_detail end |
#error_source ⇒ String
DNS name of the source of the error that caused the suppression. Will be set to either the remote-mta or reporting-mta field from a delivery status notification (RFC 3464) when available. Not provided for all types of suppressions, and not always known.
Note: Most SMTP errors that cause suppressions come from software run by email receiving systems rather than from OCI email delivery itself.
74 75 76 |
# File 'lib/oci/email/models/suppression.rb', line 74 def error_source @error_source end |
#id ⇒ String
**[Required]** The unique ID of the suppression.
34 35 36 |
# File 'lib/oci/email/models/suppression.rb', line 34 def id @id end |
#message_id ⇒ String
The value of the Message-ID header from the email that triggered a suppression. This value is as defined in RFC 5322 section 3.6.4, excluding angle-brackets. Not provided for all types of suppressions.
58 59 60 |
# File 'lib/oci/email/models/suppression.rb', line 58 def @message_id end |
#reason ⇒ String
The reason that the email address was suppressed. For more information on the types of bounces, see [Suppression List](docs.cloud.oracle.com/Content/Email/Concepts/overview.htm#components).
38 39 40 |
# File 'lib/oci/email/models/suppression.rb', line 38 def reason @reason end |
#time_created ⇒ DateTime
The date and time the suppression was added in "YYYY-MM-ddThh:mmZ" format with a Z offset, as defined by RFC 3339.
44 45 46 |
# File 'lib/oci/email/models/suppression.rb', line 44 def time_created @time_created end |
#time_last_suppressed ⇒ DateTime
The last date and time the suppression prevented submission in "YYYY-MM-ddThh:mmZ" format with a Z offset, as defined by RFC 3339.
51 52 53 |
# File 'lib/oci/email/models/suppression.rb', line 51 def time_last_suppressed @time_last_suppressed end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/oci/email/models/suppression.rb', line 77 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'email_address': :'emailAddress', 'id': :'id', 'reason': :'reason', 'time_created': :'timeCreated', 'time_last_suppressed': :'timeLastSuppressed', 'message_id': :'messageId', 'error_detail': :'errorDetail', 'error_source': :'errorSource' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/oci/email/models/suppression.rb', line 94 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'email_address': :'String', 'id': :'String', 'reason': :'String', 'time_created': :'DateTime', 'time_last_suppressed': :'DateTime', 'message_id': :'String', 'error_detail': :'String', 'error_source': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/oci/email/models/suppression.rb', line 198 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && email_address == other.email_address && id == other.id && reason == other.reason && time_created == other.time_created && time_last_suppressed == other.time_last_suppressed && == other. && error_detail == other.error_detail && error_source == other.error_source end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/oci/email/models/suppression.rb', line 236 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
216 217 218 |
# File 'lib/oci/email/models/suppression.rb', line 216 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
225 226 227 |
# File 'lib/oci/email/models/suppression.rb', line 225 def hash [compartment_id, email_address, id, reason, time_created, time_last_suppressed, , error_detail, error_source].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
269 270 271 272 273 274 275 276 277 278 |
# File 'lib/oci/email/models/suppression.rb', line 269 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
263 264 265 |
# File 'lib/oci/email/models/suppression.rb', line 263 def to_s to_hash.to_s end |