Class: OCI::FileStorage::Models::Snapshot
- Inherits:
-
Object
- Object
- OCI::FileStorage::Models::Snapshot
- Defined in:
- lib/oci/file_storage/models/snapshot.rb
Overview
A point-in-time snapshot of a specified file system.
Warning: Oracle recommends that you avoid using any confidential information when you supply string values using the API.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#file_system_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the file system from which the snapshot was created.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the snapshot.
-
#is_clone_source ⇒ BOOLEAN
Specifies whether the snapshot has been cloned.
-
#lifecycle_details ⇒ String
Additional information about the current ‘lifecycleState’.
-
#lifecycle_state ⇒ String
[Required] The current state of the snapshot.
-
#name ⇒ String
[Required] Name of the snapshot.
-
#provenance_id ⇒ String
An [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) identifying the parent from which this snapshot was cloned.
-
#time_created ⇒ DateTime
[Required] The date and time the snapshot was created, expressed in [RFC 3339](tools.ietf.org/rfc/rfc3339) timestamp format.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Snapshot
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Snapshot
Initializes the object
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/oci/file_storage/models/snapshot.rb', line 138 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.file_system_id = attributes[:'fileSystemId'] if attributes[:'fileSystemId'] raise 'You cannot provide both :fileSystemId and :file_system_id' if attributes.key?(:'fileSystemId') && attributes.key?(:'file_system_id') self.file_system_id = attributes[:'file_system_id'] if attributes[:'file_system_id'] self.id = attributes[:'id'] if attributes[:'id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.name = attributes[:'name'] if attributes[:'name'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.provenance_id = attributes[:'provenanceId'] if attributes[:'provenanceId'] raise 'You cannot provide both :provenanceId and :provenance_id' if attributes.key?(:'provenanceId') && attributes.key?(:'provenance_id') self.provenance_id = attributes[:'provenance_id'] if attributes[:'provenance_id'] self.is_clone_source = attributes[:'isCloneSource'] unless attributes[:'isCloneSource'].nil? raise 'You cannot provide both :isCloneSource and :is_clone_source' if attributes.key?(:'isCloneSource') && attributes.key?(:'is_clone_source') self.is_clone_source = attributes[:'is_clone_source'] unless attributes[:'is_clone_source'].nil? self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"CostCenter": "42"}`
84 85 86 |
# File 'lib/oci/file_storage/models/snapshot.rb', line 84 def end |
#file_system_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the file system from which the snapshot was created.
26 27 28 |
# File 'lib/oci/file_storage/models/snapshot.rb', line 26 def file_system_id @file_system_id end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair
with no predefined name, type, or namespace.
For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"Finance"`
77 78 79 |
# File 'lib/oci/file_storage/models/snapshot.rb', line 77 def end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the snapshot.
30 31 32 |
# File 'lib/oci/file_storage/models/snapshot.rb', line 30 def id @id end |
#is_clone_source ⇒ BOOLEAN
Specifies whether the snapshot has been cloned. See [Cloning a File System](docs.cloud.oracle.com/iaas/Content/File/Tasks/cloningafilesystem.htm).
65 66 67 |
# File 'lib/oci/file_storage/models/snapshot.rb', line 65 def is_clone_source @is_clone_source end |
#lifecycle_details ⇒ String
Additional information about the current ‘lifecycleState’.
69 70 71 |
# File 'lib/oci/file_storage/models/snapshot.rb', line 69 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
[Required] The current state of the snapshot.
34 35 36 |
# File 'lib/oci/file_storage/models/snapshot.rb', line 34 def lifecycle_state @lifecycle_state end |
#name ⇒ String
[Required] Name of the snapshot. This value is immutable.
Avoid entering confidential information.
Example: Sunday
43 44 45 |
# File 'lib/oci/file_storage/models/snapshot.rb', line 43 def name @name end |
#provenance_id ⇒ String
An [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) identifying the parent from which this snapshot was cloned. If this snapshot was not cloned, then the provenanceId is the same as the snapshot id value. If this snapshot was cloned, then the provenanceId value is the parent’s provenanceId. See [Cloning a File System](docs.cloud.oracle.com/iaas/Content/File/Tasks/cloningafilesystem.htm).
59 60 61 |
# File 'lib/oci/file_storage/models/snapshot.rb', line 59 def provenance_id @provenance_id end |
#time_created ⇒ DateTime
[Required] The date and time the snapshot was created, expressed in [RFC 3339](tools.ietf.org/rfc/rfc3339) timestamp format.
Example: 2016-08-25T21:10:29.600Z
51 52 53 |
# File 'lib/oci/file_storage/models/snapshot.rb', line 51 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/oci/file_storage/models/snapshot.rb', line 87 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'file_system_id': :'fileSystemId', 'id': :'id', 'lifecycle_state': :'lifecycleState', 'name': :'name', 'time_created': :'timeCreated', 'provenance_id': :'provenanceId', 'is_clone_source': :'isCloneSource', 'lifecycle_details': :'lifecycleDetails', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/oci/file_storage/models/snapshot.rb', line 105 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'file_system_id': :'String', 'id': :'String', 'lifecycle_state': :'String', 'name': :'String', 'time_created': :'DateTime', 'provenance_id': :'String', 'is_clone_source': :'BOOLEAN', 'lifecycle_details': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/oci/file_storage/models/snapshot.rb', line 217 def ==(other) return true if equal?(other) self.class == other.class && file_system_id == other.file_system_id && id == other.id && lifecycle_state == other.lifecycle_state && name == other.name && time_created == other.time_created && provenance_id == other.provenance_id && is_clone_source == other.is_clone_source && lifecycle_details == other.lifecycle_details && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 |
# File 'lib/oci/file_storage/models/snapshot.rb', line 256 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
236 237 238 |
# File 'lib/oci/file_storage/models/snapshot.rb', line 236 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
245 246 247 |
# File 'lib/oci/file_storage/models/snapshot.rb', line 245 def hash [file_system_id, id, lifecycle_state, name, time_created, provenance_id, is_clone_source, lifecycle_details, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
289 290 291 292 293 294 295 296 297 298 |
# File 'lib/oci/file_storage/models/snapshot.rb', line 289 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
283 284 285 |
# File 'lib/oci/file_storage/models/snapshot.rb', line 283 def to_s to_hash.to_s end |