Class: OCI::Functions::Models::Application

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/functions/models/application.rb

Overview

An application contains functions and defined attributes shared between those functions, such as network configuration and configuration. Avoid entering confidential information.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Application

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
# File 'lib/oci/functions/models/application.rb', line 172

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.config = attributes[:'config'] if attributes[:'config']

  self.subnet_ids = attributes[:'subnetIds'] if attributes[:'subnetIds']

  raise 'You cannot provide both :subnetIds and :subnet_ids' if attributes.key?(:'subnetIds') && attributes.key?(:'subnet_ids')

  self.subnet_ids = attributes[:'subnet_ids'] if attributes[:'subnet_ids']

  self.network_security_group_ids = attributes[:'networkSecurityGroupIds'] if attributes[:'networkSecurityGroupIds']

  raise 'You cannot provide both :networkSecurityGroupIds and :network_security_group_ids' if attributes.key?(:'networkSecurityGroupIds') && attributes.key?(:'network_security_group_ids')

  self.network_security_group_ids = attributes[:'network_security_group_ids'] if attributes[:'network_security_group_ids']

  self.syslog_url = attributes[:'syslogUrl'] if attributes[:'syslogUrl']

  raise 'You cannot provide both :syslogUrl and :syslog_url' if attributes.key?(:'syslogUrl') && attributes.key?(:'syslog_url')

  self.syslog_url = attributes[:'syslog_url'] if attributes[:'syslog_url']

  self.trace_config = attributes[:'traceConfig'] if attributes[:'traceConfig']

  raise 'You cannot provide both :traceConfig and :trace_config' if attributes.key?(:'traceConfig') && attributes.key?(:'trace_config')

  self.trace_config = attributes[:'trace_config'] if attributes[:'trace_config']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.image_policy_config = attributes[:'imagePolicyConfig'] if attributes[:'imagePolicyConfig']

  raise 'You cannot provide both :imagePolicyConfig and :image_policy_config' if attributes.key?(:'imagePolicyConfig') && attributes.key?(:'image_policy_config')

  self.image_policy_config = attributes[:'image_policy_config'] if attributes[:'image_policy_config']
end

Instance Attribute Details

#compartment_idString

The OCID of the compartment that contains the application.

Returns:

  • (String)


31
32
33
# File 'lib/oci/functions/models/application.rb', line 31

def compartment_id
  @compartment_id
end

#configHash<String, String>

Application configuration for functions in this application (passed as environment variables). Can be overridden by function configuration. Keys must be ASCII strings consisting solely of letters, digits, and the ‘_’ (underscore) character, and must not begin with a digit. Values should be limited to printable unicode characters.

Example: ‘"ConfVal"`

The maximum size for all configuration keys and values is limited to 4KB. This is measured as the sum of octets necessary to represent each key and value in UTF-8.

Returns:

  • (Hash<String, String>)


51
52
53
# File 'lib/oci/functions/models/application.rb', line 51

def config
  @config
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).

Example: ‘{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


88
89
90
# File 'lib/oci/functions/models/application.rb', line 88

def defined_tags
  @defined_tags
end

#display_nameString

The display name of the application. The display name is unique within the compartment containing the application.

Returns:

  • (String)


36
37
38
# File 'lib/oci/functions/models/application.rb', line 36

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).

Example: ‘"Finance"`

Returns:

  • (Hash<String, String>)


81
82
83
# File 'lib/oci/functions/models/application.rb', line 81

def freeform_tags
  @freeform_tags
end

#idString

[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the application.

Returns:

  • (String)


26
27
28
# File 'lib/oci/functions/models/application.rb', line 26

def id
  @id
end

#image_policy_configOCI::Functions::Models::ImagePolicyConfig



106
107
108
# File 'lib/oci/functions/models/application.rb', line 106

def image_policy_config
  @image_policy_config
end

#lifecycle_stateString

The current state of the application.

Returns:

  • (String)


41
42
43
# File 'lib/oci/functions/models/application.rb', line 41

def lifecycle_state
  @lifecycle_state
end

#network_security_group_idsArray<String>

The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)s of the Network Security Groups to add the application to.

Returns:

  • (Array<String>)


61
62
63
# File 'lib/oci/functions/models/application.rb', line 61

def network_security_group_ids
  @network_security_group_ids
end

#subnet_idsArray<String>

The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)s of the subnets in which to run functions in the application.

Returns:

  • (Array<String>)


56
57
58
# File 'lib/oci/functions/models/application.rb', line 56

def subnet_ids
  @subnet_ids
end

#syslog_urlString

A syslog URL to which to send all function logs. Supports tcp, udp, and tcp+tls. The syslog URL must be reachable from all of the subnets configured for the application. Note: If you enable the OCI Logging service for this application, the syslogUrl value is ignored. Function logs are sent to the OCI Logging service, and not to the syslog URL.

Example: tcp://logserver.myserver:1234

Returns:

  • (String)


70
71
72
# File 'lib/oci/functions/models/application.rb', line 70

def syslog_url
  @syslog_url
end

#time_createdDateTime

The time the application was created, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.

Example: 2018-09-12T22:47:12.613Z

Returns:

  • (DateTime)


96
97
98
# File 'lib/oci/functions/models/application.rb', line 96

def time_created
  @time_created
end

#time_updatedDateTime

The time the application was updated, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format. Example: 2018-09-12T22:47:12.613Z

Returns:

  • (DateTime)


103
104
105
# File 'lib/oci/functions/models/application.rb', line 103

def time_updated
  @time_updated
end

#trace_configOCI::Functions::Models::ApplicationTraceConfig



73
74
75
# File 'lib/oci/functions/models/application.rb', line 73

def trace_config
  @trace_config
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/oci/functions/models/application.rb', line 109

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'compartment_id': :'compartmentId',
    'display_name': :'displayName',
    'lifecycle_state': :'lifecycleState',
    'config': :'config',
    'subnet_ids': :'subnetIds',
    'network_security_group_ids': :'networkSecurityGroupIds',
    'syslog_url': :'syslogUrl',
    'trace_config': :'traceConfig',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'image_policy_config': :'imagePolicyConfig'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/oci/functions/models/application.rb', line 131

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'compartment_id': :'String',
    'display_name': :'String',
    'lifecycle_state': :'String',
    'config': :'Hash<String, String>',
    'subnet_ids': :'Array<String>',
    'network_security_group_ids': :'Array<String>',
    'syslog_url': :'String',
    'trace_config': :'OCI::Functions::Models::ApplicationTraceConfig',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'image_policy_config': :'OCI::Functions::Models::ImagePolicyConfig'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'lib/oci/functions/models/application.rb', line 275

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    display_name == other.display_name &&
    lifecycle_state == other.lifecycle_state &&
    config == other.config &&
    subnet_ids == other.subnet_ids &&
    network_security_group_ids == other.network_security_group_ids &&
    syslog_url == other.syslog_url &&
    trace_config == other.trace_config &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    image_policy_config == other.image_policy_config
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
# File 'lib/oci/functions/models/application.rb', line 318

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


298
299
300
# File 'lib/oci/functions/models/application.rb', line 298

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



307
308
309
# File 'lib/oci/functions/models/application.rb', line 307

def hash
  [id, compartment_id, display_name, lifecycle_state, config, subnet_ids, network_security_group_ids, syslog_url, trace_config, freeform_tags, defined_tags, time_created, time_updated, image_policy_config].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



351
352
353
354
355
356
357
358
359
360
# File 'lib/oci/functions/models/application.rb', line 351

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



345
346
347
# File 'lib/oci/functions/models/application.rb', line 345

def to_s
  to_hash.to_s
end