Class: OCI::Functions::Models::CreateApplicationDetails
- Inherits:
-
Object
- Object
- OCI::Functions::Models::CreateApplicationDetails
- Defined in:
- lib/oci/functions/models/create_application_details.rb
Overview
Properties for a new application.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The OCID of the compartment to create the application within.
-
#config ⇒ Hash<String, String>
Application configuration.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
[Required] The display name of the application.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
- #image_policy_config ⇒ OCI::Functions::Models::ImagePolicyConfig
-
#network_security_group_ids ⇒ Array<String>
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)s of the Network Security Groups to add the application to.
-
#subnet_ids ⇒ Array<String>
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)s of the subnets in which to run functions in the application.
-
#syslog_url ⇒ String
A syslog URL to which to send all function logs.
- #trace_config ⇒ OCI::Functions::Models::ApplicationTraceConfig
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateApplicationDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateApplicationDetails
Initializes the object
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/oci/functions/models/create_application_details.rb', line 123 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.config = attributes[:'config'] if attributes[:'config'] self.subnet_ids = attributes[:'subnetIds'] if attributes[:'subnetIds'] raise 'You cannot provide both :subnetIds and :subnet_ids' if attributes.key?(:'subnetIds') && attributes.key?(:'subnet_ids') self.subnet_ids = attributes[:'subnet_ids'] if attributes[:'subnet_ids'] self.network_security_group_ids = attributes[:'networkSecurityGroupIds'] if attributes[:'networkSecurityGroupIds'] raise 'You cannot provide both :networkSecurityGroupIds and :network_security_group_ids' if attributes.key?(:'networkSecurityGroupIds') && attributes.key?(:'network_security_group_ids') self.network_security_group_ids = attributes[:'network_security_group_ids'] if attributes[:'network_security_group_ids'] self.syslog_url = attributes[:'syslogUrl'] if attributes[:'syslogUrl'] raise 'You cannot provide both :syslogUrl and :syslog_url' if attributes.key?(:'syslogUrl') && attributes.key?(:'syslog_url') self.syslog_url = attributes[:'syslog_url'] if attributes[:'syslog_url'] self.trace_config = attributes[:'traceConfig'] if attributes[:'traceConfig'] raise 'You cannot provide both :traceConfig and :trace_config' if attributes.key?(:'traceConfig') && attributes.key?(:'trace_config') self.trace_config = attributes[:'trace_config'] if attributes[:'trace_config'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.image_policy_config = attributes[:'imagePolicyConfig'] if attributes[:'imagePolicyConfig'] raise 'You cannot provide both :imagePolicyConfig and :image_policy_config' if attributes.key?(:'imagePolicyConfig') && attributes.key?(:'image_policy_config') self.image_policy_config = attributes[:'image_policy_config'] if attributes[:'image_policy_config'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The OCID of the compartment to create the application within.
14 15 16 |
# File 'lib/oci/functions/models/create_application_details.rb', line 14 def compartment_id @compartment_id end |
#config ⇒ Hash<String, String>
Application configuration. These values are passed on to the function as environment variables, functions may override application configuration. Keys must be ASCII strings consisting solely of letters, digits, and the ‘_’ (underscore) character, and must not begin with a digit. Values should be limited to printable unicode characters.
Example: ‘"ConfVal"`
The maximum size for all configuration keys and values is limited to 4KB. This is measured as the sum of octets necessary to represent each key and value in UTF-8.
29 30 31 |
# File 'lib/oci/functions/models/create_application_details.rb', line 29 def config @config end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
66 67 68 |
# File 'lib/oci/functions/models/create_application_details.rb', line 66 def end |
#display_name ⇒ String
[Required] The display name of the application. The display name must be unique within the compartment containing the application. Avoid entering confidential information.
19 20 21 |
# File 'lib/oci/functions/models/create_application_details.rb', line 19 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
59 60 61 |
# File 'lib/oci/functions/models/create_application_details.rb', line 59 def end |
#image_policy_config ⇒ OCI::Functions::Models::ImagePolicyConfig
69 70 71 |
# File 'lib/oci/functions/models/create_application_details.rb', line 69 def image_policy_config @image_policy_config end |
#network_security_group_ids ⇒ Array<String>
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)s of the Network Security Groups to add the application to.
39 40 41 |
# File 'lib/oci/functions/models/create_application_details.rb', line 39 def network_security_group_ids @network_security_group_ids end |
#subnet_ids ⇒ Array<String>
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)s of the subnets in which to run functions in the application.
34 35 36 |
# File 'lib/oci/functions/models/create_application_details.rb', line 34 def subnet_ids @subnet_ids end |
#syslog_url ⇒ String
A syslog URL to which to send all function logs. Supports tcp, udp, and tcp+tls. The syslog URL must be reachable from all of the subnets configured for the application. Note: If you enable the OCI Logging service for this application, the syslogUrl value is ignored. Function logs are sent to the OCI Logging service, and not to the syslog URL.
Example: tcp://logserver.myserver:1234
48 49 50 |
# File 'lib/oci/functions/models/create_application_details.rb', line 48 def syslog_url @syslog_url end |
#trace_config ⇒ OCI::Functions::Models::ApplicationTraceConfig
51 52 53 |
# File 'lib/oci/functions/models/create_application_details.rb', line 51 def trace_config @trace_config end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/oci/functions/models/create_application_details.rb', line 72 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'config': :'config', 'subnet_ids': :'subnetIds', 'network_security_group_ids': :'networkSecurityGroupIds', 'syslog_url': :'syslogUrl', 'trace_config': :'traceConfig', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'image_policy_config': :'imagePolicyConfig' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/oci/functions/models/create_application_details.rb', line 90 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'display_name': :'String', 'config': :'Hash<String, String>', 'subnet_ids': :'Array<String>', 'network_security_group_ids': :'Array<String>', 'syslog_url': :'String', 'trace_config': :'OCI::Functions::Models::ApplicationTraceConfig', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'image_policy_config': :'OCI::Functions::Models::ImagePolicyConfig' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/oci/functions/models/create_application_details.rb', line 193 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && display_name == other.display_name && config == other.config && subnet_ids == other.subnet_ids && network_security_group_ids == other.network_security_group_ids && syslog_url == other.syslog_url && trace_config == other.trace_config && == other. && == other. && image_policy_config == other.image_policy_config end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/oci/functions/models/create_application_details.rb', line 232 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
212 213 214 |
# File 'lib/oci/functions/models/create_application_details.rb', line 212 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
221 222 223 |
# File 'lib/oci/functions/models/create_application_details.rb', line 221 def hash [compartment_id, display_name, config, subnet_ids, network_security_group_ids, syslog_url, trace_config, , , image_policy_config].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
265 266 267 268 269 270 271 272 273 274 |
# File 'lib/oci/functions/models/create_application_details.rb', line 265 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
259 260 261 |
# File 'lib/oci/functions/models/create_application_details.rb', line 259 def to_s to_hash.to_s end |