Class: OCI::Functions::Models::Function
- Inherits:
-
Object
- Object
- OCI::Functions::Models::Function
- Defined in:
- lib/oci/functions/models/function.rb
Overview
A function resource defines the code (Docker image) and configuration for a specific function. Functions are defined in applications. Avoid entering confidential information.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#application_id ⇒ String
The OCID of the application the function belongs to.
-
#compartment_id ⇒ String
The OCID of the compartment that contains the function.
-
#config ⇒ Hash<String, String>
Function configuration.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
The display name of the function.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the function.
-
#image ⇒ String
The qualified name of the Docker image to use in the function, including the image tag.
-
#image_digest ⇒ String
The image digest for the version of the image that will be pulled when invoking this function.
-
#invoke_endpoint ⇒ String
The base https invoke URL to set on a client in order to invoke a function.
-
#lifecycle_state ⇒ String
The current state of the function.
-
#memory_in_m_bs ⇒ Integer
Maximum usable memory for the function (MiB).
- #provisioned_concurrency_config ⇒ OCI::Functions::Models::FunctionProvisionedConcurrencyConfig
-
#time_created ⇒ DateTime
The time the function was created, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.
-
#time_updated ⇒ DateTime
The time the function was updated, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.
-
#timeout_in_seconds ⇒ Integer
Timeout for executions of the function.
- #trace_config ⇒ OCI::Functions::Models::FunctionTraceConfig
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Function
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Function
Initializes the object
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'lib/oci/functions/models/function.rb', line 194 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.application_id = attributes[:'applicationId'] if attributes[:'applicationId'] raise 'You cannot provide both :applicationId and :application_id' if attributes.key?(:'applicationId') && attributes.key?(:'application_id') self.application_id = attributes[:'application_id'] if attributes[:'application_id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.image = attributes[:'image'] if attributes[:'image'] self.image_digest = attributes[:'imageDigest'] if attributes[:'imageDigest'] raise 'You cannot provide both :imageDigest and :image_digest' if attributes.key?(:'imageDigest') && attributes.key?(:'image_digest') self.image_digest = attributes[:'image_digest'] if attributes[:'image_digest'] self.memory_in_m_bs = attributes[:'memoryInMBs'] if attributes[:'memoryInMBs'] raise 'You cannot provide both :memoryInMBs and :memory_in_m_bs' if attributes.key?(:'memoryInMBs') && attributes.key?(:'memory_in_m_bs') self.memory_in_m_bs = attributes[:'memory_in_m_bs'] if attributes[:'memory_in_m_bs'] self.config = attributes[:'config'] if attributes[:'config'] self.timeout_in_seconds = attributes[:'timeoutInSeconds'] if attributes[:'timeoutInSeconds'] self.timeout_in_seconds = 30 if timeout_in_seconds.nil? && !attributes.key?(:'timeoutInSeconds') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :timeoutInSeconds and :timeout_in_seconds' if attributes.key?(:'timeoutInSeconds') && attributes.key?(:'timeout_in_seconds') self.timeout_in_seconds = attributes[:'timeout_in_seconds'] if attributes[:'timeout_in_seconds'] self.timeout_in_seconds = 30 if timeout_in_seconds.nil? && !attributes.key?(:'timeoutInSeconds') && !attributes.key?(:'timeout_in_seconds') # rubocop:disable Style/StringLiterals self.provisioned_concurrency_config = attributes[:'provisionedConcurrencyConfig'] if attributes[:'provisionedConcurrencyConfig'] raise 'You cannot provide both :provisionedConcurrencyConfig and :provisioned_concurrency_config' if attributes.key?(:'provisionedConcurrencyConfig') && attributes.key?(:'provisioned_concurrency_config') self.provisioned_concurrency_config = attributes[:'provisioned_concurrency_config'] if attributes[:'provisioned_concurrency_config'] self.trace_config = attributes[:'traceConfig'] if attributes[:'traceConfig'] raise 'You cannot provide both :traceConfig and :trace_config' if attributes.key?(:'traceConfig') && attributes.key?(:'trace_config') self.trace_config = attributes[:'trace_config'] if attributes[:'trace_config'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.invoke_endpoint = attributes[:'invokeEndpoint'] if attributes[:'invokeEndpoint'] raise 'You cannot provide both :invokeEndpoint and :invoke_endpoint' if attributes.key?(:'invokeEndpoint') && attributes.key?(:'invoke_endpoint') self.invoke_endpoint = attributes[:'invoke_endpoint'] if attributes[:'invoke_endpoint'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] end |
Instance Attribute Details
#application_id ⇒ String
The OCID of the application the function belongs to.
40 41 42 |
# File 'lib/oci/functions/models/function.rb', line 40 def application_id @application_id end |
#compartment_id ⇒ String
The OCID of the compartment that contains the function.
45 46 47 |
# File 'lib/oci/functions/models/function.rb', line 45 def compartment_id @compartment_id end |
#config ⇒ Hash<String, String>
Function configuration. Overrides application configuration. Keys must be ASCII strings consisting solely of letters, digits, and the '_' (underscore) character, and must not begin with a digit. Values should be limited to printable unicode characters.
Example: `"ConfVal"`
The maximum size for all configuration keys and values is limited to 4KB. This is measured as the sum of octets necessary to represent each key and value in UTF-8.
73 74 75 |
# File 'lib/oci/functions/models/function.rb', line 73 def config @config end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: `{"CostCenter": "42"}`
103 104 105 |
# File 'lib/oci/functions/models/function.rb', line 103 def @defined_tags end |
#display_name ⇒ String
The display name of the function. The display name is unique within the application containing the function.
31 32 33 |
# File 'lib/oci/functions/models/function.rb', line 31 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: `"Finance"`
91 92 93 |
# File 'lib/oci/functions/models/function.rb', line 91 def @freeform_tags end |
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the function.
26 27 28 |
# File 'lib/oci/functions/models/function.rb', line 26 def id @id end |
#image ⇒ String
The qualified name of the Docker image to use in the function, including the image tag. The image should be in the OCI Registry that is in the same region as the function itself. Example: `phx.ocir.io/ten/functions/function:0.0.1`
52 53 54 |
# File 'lib/oci/functions/models/function.rb', line 52 def image @image end |
#image_digest ⇒ String
The image digest for the version of the image that will be pulled when invoking this function. If no value is specified, the digest currently associated with the image in the OCI Registry will be used. Example: `sha256:ca0eeb6fb05351dfc8759c20733c91def84cb8007aa89a5bf606bc8b315b9fc7`
59 60 61 |
# File 'lib/oci/functions/models/function.rb', line 59 def image_digest @image_digest end |
#invoke_endpoint ⇒ String
The base https invoke URL to set on a client in order to invoke a function. This URL will never change over the lifetime of the function and can be cached.
96 97 98 |
# File 'lib/oci/functions/models/function.rb', line 96 def invoke_endpoint @invoke_endpoint end |
#lifecycle_state ⇒ String
The current state of the function.
36 37 38 |
# File 'lib/oci/functions/models/function.rb', line 36 def lifecycle_state @lifecycle_state end |
#memory_in_m_bs ⇒ Integer
Maximum usable memory for the function (MiB).
63 64 65 |
# File 'lib/oci/functions/models/function.rb', line 63 def memory_in_m_bs @memory_in_m_bs end |
#provisioned_concurrency_config ⇒ OCI::Functions::Models::FunctionProvisionedConcurrencyConfig
80 81 82 |
# File 'lib/oci/functions/models/function.rb', line 80 def provisioned_concurrency_config @provisioned_concurrency_config end |
#time_created ⇒ DateTime
The time the function was created, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.
Example: `2018-09-12T22:47:12.613Z`
111 112 113 |
# File 'lib/oci/functions/models/function.rb', line 111 def time_created @time_created end |
#time_updated ⇒ DateTime
The time the function was updated, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.
Example: `2018-09-12T22:47:12.613Z`
119 120 121 |
# File 'lib/oci/functions/models/function.rb', line 119 def time_updated @time_updated end |
#timeout_in_seconds ⇒ Integer
Timeout for executions of the function. Value in seconds.
77 78 79 |
# File 'lib/oci/functions/models/function.rb', line 77 def timeout_in_seconds @timeout_in_seconds end |
#trace_config ⇒ OCI::Functions::Models::FunctionTraceConfig
83 84 85 |
# File 'lib/oci/functions/models/function.rb', line 83 def trace_config @trace_config end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/oci/functions/models/function.rb', line 122 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'lifecycle_state': :'lifecycleState', 'application_id': :'applicationId', 'compartment_id': :'compartmentId', 'image': :'image', 'image_digest': :'imageDigest', 'memory_in_m_bs': :'memoryInMBs', 'config': :'config', 'timeout_in_seconds': :'timeoutInSeconds', 'provisioned_concurrency_config': :'provisionedConcurrencyConfig', 'trace_config': :'traceConfig', 'freeform_tags': :'freeformTags', 'invoke_endpoint': :'invokeEndpoint', 'defined_tags': :'definedTags', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/oci/functions/models/function.rb', line 147 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'lifecycle_state': :'String', 'application_id': :'String', 'compartment_id': :'String', 'image': :'String', 'image_digest': :'String', 'memory_in_m_bs': :'Integer', 'config': :'Hash<String, String>', 'timeout_in_seconds': :'Integer', 'provisioned_concurrency_config': :'OCI::Functions::Models::FunctionProvisionedConcurrencyConfig', 'trace_config': :'OCI::Functions::Models::FunctionTraceConfig', 'freeform_tags': :'Hash<String, String>', 'invoke_endpoint': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'time_created': :'DateTime', 'time_updated': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'lib/oci/functions/models/function.rb', line 313 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && lifecycle_state == other.lifecycle_state && application_id == other.application_id && compartment_id == other.compartment_id && image == other.image && image_digest == other.image_digest && memory_in_m_bs == other.memory_in_m_bs && config == other.config && timeout_in_seconds == other.timeout_in_seconds && provisioned_concurrency_config == other.provisioned_concurrency_config && trace_config == other.trace_config && == other. && invoke_endpoint == other.invoke_endpoint && == other. && time_created == other.time_created && time_updated == other.time_updated end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 |
# File 'lib/oci/functions/models/function.rb', line 359 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
339 340 341 |
# File 'lib/oci/functions/models/function.rb', line 339 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
348 349 350 |
# File 'lib/oci/functions/models/function.rb', line 348 def hash [id, display_name, lifecycle_state, application_id, compartment_id, image, image_digest, memory_in_m_bs, config, timeout_in_seconds, provisioned_concurrency_config, trace_config, , invoke_endpoint, , time_created, time_updated].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
392 393 394 395 396 397 398 399 400 401 |
# File 'lib/oci/functions/models/function.rb', line 392 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
386 387 388 |
# File 'lib/oci/functions/models/function.rb', line 386 def to_s to_hash.to_s end |