Class: OCI::Functions::Models::UpdateApplicationDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/functions/models/update_application_details.rb

Overview

Properties to update an application.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateApplicationDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
# File 'lib/oci/functions/models/update_application_details.rb', line 99

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.config = attributes[:'config'] if attributes[:'config']

  self.network_security_group_ids = attributes[:'networkSecurityGroupIds'] if attributes[:'networkSecurityGroupIds']

  raise 'You cannot provide both :networkSecurityGroupIds and :network_security_group_ids' if attributes.key?(:'networkSecurityGroupIds') && attributes.key?(:'network_security_group_ids')

  self.network_security_group_ids = attributes[:'network_security_group_ids'] if attributes[:'network_security_group_ids']

  self.syslog_url = attributes[:'syslogUrl'] if attributes[:'syslogUrl']

  raise 'You cannot provide both :syslogUrl and :syslog_url' if attributes.key?(:'syslogUrl') && attributes.key?(:'syslog_url')

  self.syslog_url = attributes[:'syslog_url'] if attributes[:'syslog_url']

  self.trace_config = attributes[:'traceConfig'] if attributes[:'traceConfig']

  raise 'You cannot provide both :traceConfig and :trace_config' if attributes.key?(:'traceConfig') && attributes.key?(:'trace_config')

  self.trace_config = attributes[:'trace_config'] if attributes[:'trace_config']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.image_policy_config = attributes[:'imagePolicyConfig'] if attributes[:'imagePolicyConfig']

  raise 'You cannot provide both :imagePolicyConfig and :image_policy_config' if attributes.key?(:'imagePolicyConfig') && attributes.key?(:'image_policy_config')

  self.image_policy_config = attributes[:'image_policy_config'] if attributes[:'image_policy_config']
end

Instance Attribute Details

#configHash<String, String>

Application configuration. These values are passed on to the function as environment variables, functions may override application configuration. Keys must be ASCII strings consisting solely of letters, digits, and the ‘_’ (underscore) character, and must not begin with a digit. Values should be limited to printable unicode characters.

Example: ‘"ConfVal"`

The maximum size for all configuration keys and values is limited to 4KB. This is measured as the sum of octets necessary to represent each key and value in UTF-8.

Returns:

  • (Hash<String, String>)


19
20
21
# File 'lib/oci/functions/models/update_application_details.rb', line 19

def config
  @config
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).

Example: ‘{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


51
52
53
# File 'lib/oci/functions/models/update_application_details.rb', line 51

def defined_tags
  @defined_tags
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).

Example: ‘"Finance"`

Returns:

  • (Hash<String, String>)


44
45
46
# File 'lib/oci/functions/models/update_application_details.rb', line 44

def freeform_tags
  @freeform_tags
end

#image_policy_configOCI::Functions::Models::ImagePolicyConfig



54
55
56
# File 'lib/oci/functions/models/update_application_details.rb', line 54

def image_policy_config
  @image_policy_config
end

#network_security_group_idsArray<String>

The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)s of the Network Security Groups to add the application to.

Returns:

  • (Array<String>)


24
25
26
# File 'lib/oci/functions/models/update_application_details.rb', line 24

def network_security_group_ids
  @network_security_group_ids
end

#syslog_urlString

A syslog URL to which to send all function logs. Supports tcp, udp, and tcp+tls. The syslog URL must be reachable from all of the subnets configured for the application. Note: If you enable the OCI Logging service for this application, the syslogUrl value is ignored. Function logs are sent to the OCI Logging service, and not to the syslog URL.

Example: tcp://logserver.myserver:1234

Returns:

  • (String)


33
34
35
# File 'lib/oci/functions/models/update_application_details.rb', line 33

def syslog_url
  @syslog_url
end

#trace_configOCI::Functions::Models::ApplicationTraceConfig



36
37
38
# File 'lib/oci/functions/models/update_application_details.rb', line 36

def trace_config
  @trace_config
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/oci/functions/models/update_application_details.rb', line 57

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'config': :'config',
    'network_security_group_ids': :'networkSecurityGroupIds',
    'syslog_url': :'syslogUrl',
    'trace_config': :'traceConfig',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'image_policy_config': :'imagePolicyConfig'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/oci/functions/models/update_application_details.rb', line 72

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'config': :'Hash<String, String>',
    'network_security_group_ids': :'Array<String>',
    'syslog_url': :'String',
    'trace_config': :'OCI::Functions::Models::ApplicationTraceConfig',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'image_policy_config': :'OCI::Functions::Models::ImagePolicyConfig'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/oci/functions/models/update_application_details.rb', line 151

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    config == other.config &&
    network_security_group_ids == other.network_security_group_ids &&
    syslog_url == other.syslog_url &&
    trace_config == other.trace_config &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    image_policy_config == other.image_policy_config
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/oci/functions/models/update_application_details.rb', line 187

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


167
168
169
# File 'lib/oci/functions/models/update_application_details.rb', line 167

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



176
177
178
# File 'lib/oci/functions/models/update_application_details.rb', line 176

def hash
  [config, network_security_group_ids, syslog_url, trace_config, freeform_tags, defined_tags, image_policy_config].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



220
221
222
223
224
225
226
227
228
229
# File 'lib/oci/functions/models/update_application_details.rb', line 220

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



214
215
216
# File 'lib/oci/functions/models/update_application_details.rb', line 214

def to_s
  to_hash.to_s
end