Class: OCI::Functions::Models::UpdateFunctionDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/functions/models/update_function_details.rb

Overview

Updates attributes of a function.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateFunctionDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/oci/functions/models/update_function_details.rb', line 106

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.image = attributes[:'image'] if attributes[:'image']

  self.image_digest = attributes[:'imageDigest'] if attributes[:'imageDigest']

  raise 'You cannot provide both :imageDigest and :image_digest' if attributes.key?(:'imageDigest') && attributes.key?(:'image_digest')

  self.image_digest = attributes[:'image_digest'] if attributes[:'image_digest']

  self.memory_in_m_bs = attributes[:'memoryInMBs'] if attributes[:'memoryInMBs']

  raise 'You cannot provide both :memoryInMBs and :memory_in_m_bs' if attributes.key?(:'memoryInMBs') && attributes.key?(:'memory_in_m_bs')

  self.memory_in_m_bs = attributes[:'memory_in_m_bs'] if attributes[:'memory_in_m_bs']

  self.config = attributes[:'config'] if attributes[:'config']

  self.timeout_in_seconds = attributes[:'timeoutInSeconds'] if attributes[:'timeoutInSeconds']
  self.timeout_in_seconds = 30 if timeout_in_seconds.nil? && !attributes.key?(:'timeoutInSeconds') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :timeoutInSeconds and :timeout_in_seconds' if attributes.key?(:'timeoutInSeconds') && attributes.key?(:'timeout_in_seconds')

  self.timeout_in_seconds = attributes[:'timeout_in_seconds'] if attributes[:'timeout_in_seconds']
  self.timeout_in_seconds = 30 if timeout_in_seconds.nil? && !attributes.key?(:'timeoutInSeconds') && !attributes.key?(:'timeout_in_seconds') # rubocop:disable Style/StringLiterals

  self.trace_config = attributes[:'traceConfig'] if attributes[:'traceConfig']

  raise 'You cannot provide both :traceConfig and :trace_config' if attributes.key?(:'traceConfig') && attributes.key?(:'trace_config')

  self.trace_config = attributes[:'trace_config'] if attributes[:'trace_config']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#configHash<String, String>

Function configuration. These values are passed on to the function as environment variables, this overrides application configuration values. Keys must be ASCII strings consisting solely of letters, digits, and the ‘_’ (underscore) character, and must not begin with a digit. Values should be limited to printable unicode characters.

Example: ‘"ConfVal"`

The maximum size for all configuration keys and values is limited to 4KB. This is measured as the sum of octets necessary to represent each key and value in UTF-8.

Returns:

  • (Hash<String, String>)


37
38
39
# File 'lib/oci/functions/models/update_function_details.rb', line 37

def config
  @config
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).

Example: ‘{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


58
59
60
# File 'lib/oci/functions/models/update_function_details.rb', line 58

def defined_tags
  @defined_tags
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: ‘"Finance"`

Returns:

  • (Hash<String, String>)


51
52
53
# File 'lib/oci/functions/models/update_function_details.rb', line 51

def freeform_tags
  @freeform_tags
end

#imageString

The qualified name of the Docker image to use in the function, including the image tag. The image should be in the OCI Registry that is in the same region as the function itself. If an image is specified but no value for imageDigest is provided, the digest currently associated with the image tag in the OCI Registry will be used. Example: phx.ocir.io/ten/functions/function:0.0.1

Returns:

  • (String)


17
18
19
# File 'lib/oci/functions/models/update_function_details.rb', line 17

def image
  @image
end

#image_digestString

The image digest for the version of the image that will be pulled when invoking this function. Example: sha256:ca0eeb6fb05351dfc8759c20733c91def84cb8007aa89a5bf606bc8b315b9fc7

Returns:

  • (String)


23
24
25
# File 'lib/oci/functions/models/update_function_details.rb', line 23

def image_digest
  @image_digest
end

#memory_in_m_bsInteger

Maximum usable memory for the function (MiB).

Returns:

  • (Integer)


27
28
29
# File 'lib/oci/functions/models/update_function_details.rb', line 27

def memory_in_m_bs
  @memory_in_m_bs
end

#timeout_in_secondsInteger

Timeout for executions of the function. Value in seconds.

Returns:

  • (Integer)


41
42
43
# File 'lib/oci/functions/models/update_function_details.rb', line 41

def timeout_in_seconds
  @timeout_in_seconds
end

#trace_configOCI::Functions::Models::FunctionTraceConfig



44
45
46
# File 'lib/oci/functions/models/update_function_details.rb', line 44

def trace_config
  @trace_config
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/oci/functions/models/update_function_details.rb', line 61

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'image': :'image',
    'image_digest': :'imageDigest',
    'memory_in_m_bs': :'memoryInMBs',
    'config': :'config',
    'timeout_in_seconds': :'timeoutInSeconds',
    'trace_config': :'traceConfig',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/oci/functions/models/update_function_details.rb', line 77

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'image': :'String',
    'image_digest': :'String',
    'memory_in_m_bs': :'Integer',
    'config': :'Hash<String, String>',
    'timeout_in_seconds': :'Integer',
    'trace_config': :'OCI::Functions::Models::FunctionTraceConfig',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/oci/functions/models/update_function_details.rb', line 162

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    image == other.image &&
    image_digest == other.image_digest &&
    memory_in_m_bs == other.memory_in_m_bs &&
    config == other.config &&
    timeout_in_seconds == other.timeout_in_seconds &&
    trace_config == other.trace_config &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/oci/functions/models/update_function_details.rb', line 199

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


179
180
181
# File 'lib/oci/functions/models/update_function_details.rb', line 179

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



188
189
190
# File 'lib/oci/functions/models/update_function_details.rb', line 188

def hash
  [image, image_digest, memory_in_m_bs, config, timeout_in_seconds, trace_config, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



232
233
234
235
236
237
238
239
240
241
# File 'lib/oci/functions/models/update_function_details.rb', line 232

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



226
227
228
# File 'lib/oci/functions/models/update_function_details.rb', line 226

def to_s
  to_hash.to_s
end