Class: GenericArtifactsContent::Models::GenericArtifact
- Inherits:
-
Object
- Object
- GenericArtifactsContent::Models::GenericArtifact
- Defined in:
- lib/oci/generic_artifacts_content/models/generic_artifact.rb
Overview
The metadata of the artifact.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#artifact_path ⇒ String
**[Required]** A user-defined path to describe the location of an artifact.
-
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the repository's compartment.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
**[Required]** Defined tags for this resource.
-
#display_name ⇒ String
**[Required]** The artifact name with the format of `<artifact-path>:<artifact-version>`.
-
#freeform_tags ⇒ Hash<String, String>
**[Required]** Free-form tags for this resource.
-
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the artifact.
-
#lifecycle_state ⇒ String
**[Required]** The current state of the artifact.
-
#repository_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the repository.
-
#sha256 ⇒ String
**[Required]** The SHA256 digest for the artifact.
-
#size_in_bytes ⇒ Integer
**[Required]** The size of the artifact in bytes.
-
#time_created ⇒ DateTime
**[Required]** An RFC 3339 timestamp indicating when the repository was created.
-
#version ⇒ String
**[Required]** A user-defined string to describe the artifact version.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GenericArtifact
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ GenericArtifact
Initializes the object
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/oci/generic_artifacts_content/models/generic_artifact.rb', line 144 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.repository_id = attributes[:'repositoryId'] if attributes[:'repositoryId'] raise 'You cannot provide both :repositoryId and :repository_id' if attributes.key?(:'repositoryId') && attributes.key?(:'repository_id') self.repository_id = attributes[:'repository_id'] if attributes[:'repository_id'] self.artifact_path = attributes[:'artifactPath'] if attributes[:'artifactPath'] raise 'You cannot provide both :artifactPath and :artifact_path' if attributes.key?(:'artifactPath') && attributes.key?(:'artifact_path') self.artifact_path = attributes[:'artifact_path'] if attributes[:'artifact_path'] self.version = attributes[:'version'] if attributes[:'version'] self.sha256 = attributes[:'sha256'] if attributes[:'sha256'] self.size_in_bytes = attributes[:'sizeInBytes'] if attributes[:'sizeInBytes'] raise 'You cannot provide both :sizeInBytes and :size_in_bytes' if attributes.key?(:'sizeInBytes') && attributes.key?(:'size_in_bytes') self.size_in_bytes = attributes[:'size_in_bytes'] if attributes[:'size_in_bytes'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] end |
Instance Attribute Details
#artifact_path ⇒ String
**[Required]** A user-defined path to describe the location of an artifact. Slashes do not create a directory structure, but you can use slashes to organize the repository. An artifact path does not include an artifact version.
Example: `project01/my-web-app/artifact-abc`
45 46 47 |
# File 'lib/oci/generic_artifacts_content/models/generic_artifact.rb', line 45 def artifact_path @artifact_path end |
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the repository's compartment.
34 35 36 |
# File 'lib/oci/generic_artifacts_content/models/generic_artifact.rb', line 34 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
**[Required]** Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: `{"CostCenter": "42"}`
80 81 82 |
# File 'lib/oci/generic_artifacts_content/models/generic_artifact.rb', line 80 def @defined_tags end |
#display_name ⇒ String
**[Required]** The artifact name with the format of `<artifact-path>:<artifact-version>`. The artifact name is truncated to a maximum length of 255.
Example: `project01/my-web-app/artifact-abc:1.0.0`
30 31 32 |
# File 'lib/oci/generic_artifacts_content/models/generic_artifact.rb', line 30 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
**[Required]** Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: `"Finance"`
72 73 74 |
# File 'lib/oci/generic_artifacts_content/models/generic_artifact.rb', line 72 def @freeform_tags end |
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the artifact.
Example: `ocid1.genericartifact.oc1..exampleuniqueID`
23 24 25 |
# File 'lib/oci/generic_artifacts_content/models/generic_artifact.rb', line 23 def id @id end |
#lifecycle_state ⇒ String
**[Required]** The current state of the artifact.
64 65 66 |
# File 'lib/oci/generic_artifacts_content/models/generic_artifact.rb', line 64 def lifecycle_state @lifecycle_state end |
#repository_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the repository.
38 39 40 |
# File 'lib/oci/generic_artifacts_content/models/generic_artifact.rb', line 38 def repository_id @repository_id end |
#sha256 ⇒ String
**[Required]** The SHA256 digest for the artifact. When you upload an artifact to the repository, a SHA256 digest is calculated and added to the artifact properties.
56 57 58 |
# File 'lib/oci/generic_artifacts_content/models/generic_artifact.rb', line 56 def sha256 @sha256 end |
#size_in_bytes ⇒ Integer
**[Required]** The size of the artifact in bytes.
60 61 62 |
# File 'lib/oci/generic_artifacts_content/models/generic_artifact.rb', line 60 def size_in_bytes @size_in_bytes end |
#time_created ⇒ DateTime
**[Required]** An RFC 3339 timestamp indicating when the repository was created.
84 85 86 |
# File 'lib/oci/generic_artifacts_content/models/generic_artifact.rb', line 84 def time_created @time_created end |
#version ⇒ String
**[Required]** A user-defined string to describe the artifact version.
Example: `1.1.0` or `1.2-beta-2`
52 53 54 |
# File 'lib/oci/generic_artifacts_content/models/generic_artifact.rb', line 52 def version @version end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/oci/generic_artifacts_content/models/generic_artifact.rb', line 87 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'repository_id': :'repositoryId', 'artifact_path': :'artifactPath', 'version': :'version', 'sha256': :'sha256', 'size_in_bytes': :'sizeInBytes', 'lifecycle_state': :'lifecycleState', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'time_created': :'timeCreated' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/oci/generic_artifacts_content/models/generic_artifact.rb', line 107 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'compartment_id': :'String', 'repository_id': :'String', 'artifact_path': :'String', 'version': :'String', 'sha256': :'String', 'size_in_bytes': :'Integer', 'lifecycle_state': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'time_created': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/oci/generic_artifacts_content/models/generic_artifact.rb', line 231 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && compartment_id == other.compartment_id && repository_id == other.repository_id && artifact_path == other.artifact_path && version == other.version && sha256 == other.sha256 && size_in_bytes == other.size_in_bytes && lifecycle_state == other.lifecycle_state && == other. && == other. && time_created == other.time_created end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 |
# File 'lib/oci/generic_artifacts_content/models/generic_artifact.rb', line 272 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
252 253 254 |
# File 'lib/oci/generic_artifacts_content/models/generic_artifact.rb', line 252 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
261 262 263 |
# File 'lib/oci/generic_artifacts_content/models/generic_artifact.rb', line 261 def hash [id, display_name, compartment_id, repository_id, artifact_path, version, sha256, size_in_bytes, lifecycle_state, , , time_created].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
305 306 307 308 309 310 311 312 313 314 |
# File 'lib/oci/generic_artifacts_content/models/generic_artifact.rb', line 305 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
299 300 301 |
# File 'lib/oci/generic_artifacts_content/models/generic_artifact.rb', line 299 def to_s to_hash.to_s end |