Class: OCI::GoldenGate::Models::CreateDeploymentBackupDetails
- Inherits:
-
Object
- Object
- OCI::GoldenGate::Models::CreateDeploymentBackupDetails
- Defined in:
- lib/oci/golden_gate/models/create_deployment_backup_details.rb
Overview
The information about a new DeploymentBackup.
Instance Attribute Summary collapse
-
#bucket_name ⇒ String
[Required] Name of the bucket where the object is to be uploaded in the object storage.
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment being referenced.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Tags defined for this resource.
-
#deployment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the deployment being referenced.
-
#display_name ⇒ String
[Required] An object’s Display Name.
-
#freeform_tags ⇒ Hash<String, String>
A simple key-value pair that is applied without any predefined name, type, or scope.
-
#namespace_name ⇒ String
[Required] Name of namespace that serves as a container for all of your buckets.
-
#object_name ⇒ String
[Required] Name of the object to be uploaded to object storage.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateDeploymentBackupDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateDeploymentBackupDetails
Initializes the object
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/oci/golden_gate/models/create_deployment_backup_details.rb', line 96 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.deployment_id = attributes[:'deploymentId'] if attributes[:'deploymentId'] raise 'You cannot provide both :deploymentId and :deployment_id' if attributes.key?(:'deploymentId') && attributes.key?(:'deployment_id') self.deployment_id = attributes[:'deployment_id'] if attributes[:'deployment_id'] self.namespace_name = attributes[:'namespaceName'] if attributes[:'namespaceName'] raise 'You cannot provide both :namespaceName and :namespace_name' if attributes.key?(:'namespaceName') && attributes.key?(:'namespace_name') self.namespace_name = attributes[:'namespace_name'] if attributes[:'namespace_name'] self.bucket_name = attributes[:'bucketName'] if attributes[:'bucketName'] raise 'You cannot provide both :bucketName and :bucket_name' if attributes.key?(:'bucketName') && attributes.key?(:'bucket_name') self.bucket_name = attributes[:'bucket_name'] if attributes[:'bucket_name'] self.object_name = attributes[:'objectName'] if attributes[:'objectName'] raise 'You cannot provide both :objectName and :object_name' if attributes.key?(:'objectName') && attributes.key?(:'object_name') self.object_name = attributes[:'object_name'] if attributes[:'object_name'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#bucket_name ⇒ String
[Required] Name of the bucket where the object is to be uploaded in the object storage
32 33 34 |
# File 'lib/oci/golden_gate/models/create_deployment_backup_details.rb', line 32 def bucket_name @bucket_name end |
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment being referenced.
19 20 21 |
# File 'lib/oci/golden_gate/models/create_deployment_backup_details.rb', line 19 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Tags defined for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
48 49 50 |
# File 'lib/oci/golden_gate/models/create_deployment_backup_details.rb', line 48 def @defined_tags end |
#deployment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the deployment being referenced.
24 25 26 |
# File 'lib/oci/golden_gate/models/create_deployment_backup_details.rb', line 24 def deployment_id @deployment_id end |
#display_name ⇒ String
[Required] An object’s Display Name.
14 15 16 |
# File 'lib/oci/golden_gate/models/create_deployment_backup_details.rb', line 14 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
A simple key-value pair that is applied without any predefined name, type, or scope. Exists for cross-compatibility only. Example: ‘"value"`
42 43 44 |
# File 'lib/oci/golden_gate/models/create_deployment_backup_details.rb', line 42 def @freeform_tags end |
#namespace_name ⇒ String
[Required] Name of namespace that serves as a container for all of your buckets
28 29 30 |
# File 'lib/oci/golden_gate/models/create_deployment_backup_details.rb', line 28 def namespace_name @namespace_name end |
#object_name ⇒ String
[Required] Name of the object to be uploaded to object storage
36 37 38 |
# File 'lib/oci/golden_gate/models/create_deployment_backup_details.rb', line 36 def object_name @object_name end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/oci/golden_gate/models/create_deployment_backup_details.rb', line 51 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'deployment_id': :'deploymentId', 'namespace_name': :'namespaceName', 'bucket_name': :'bucketName', 'object_name': :'objectName', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/oci/golden_gate/models/create_deployment_backup_details.rb', line 67 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'compartment_id': :'String', 'deployment_id': :'String', 'namespace_name': :'String', 'bucket_name': :'String', 'object_name': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/oci/golden_gate/models/create_deployment_backup_details.rb', line 158 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && compartment_id == other.compartment_id && deployment_id == other.deployment_id && namespace_name == other.namespace_name && bucket_name == other.bucket_name && object_name == other.object_name && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/oci/golden_gate/models/create_deployment_backup_details.rb', line 195 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
175 176 177 |
# File 'lib/oci/golden_gate/models/create_deployment_backup_details.rb', line 175 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
184 185 186 |
# File 'lib/oci/golden_gate/models/create_deployment_backup_details.rb', line 184 def hash [display_name, compartment_id, deployment_id, namespace_name, bucket_name, object_name, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
228 229 230 231 232 233 234 235 236 237 |
# File 'lib/oci/golden_gate/models/create_deployment_backup_details.rb', line 228 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
222 223 224 |
# File 'lib/oci/golden_gate/models/create_deployment_backup_details.rb', line 222 def to_s to_hash.to_s end |