Class: OCI::GoldenGate::Models::CreateDeploymentDetails
- Inherits:
-
Object
- Object
- OCI::GoldenGate::Models::CreateDeploymentDetails
- Defined in:
- lib/oci/golden_gate/models/create_deployment_details.rb
Overview
The information about a new Deployment.
Constant Summary collapse
- LICENSE_MODEL_ENUM =
[ LICENSE_MODEL_LICENSE_INCLUDED = 'LICENSE_INCLUDED'.freeze, LICENSE_MODEL_BRING_YOUR_OWN_LICENSE = 'BRING_YOUR_OWN_LICENSE'.freeze ].freeze
- DEPLOYMENT_TYPE_ENUM =
[ DEPLOYMENT_TYPE_OGG = 'OGG'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment being referenced.
-
#cpu_core_count ⇒ Integer
[Required] The Minimum number of OCPUs to be made available for this Deployment.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Tags defined for this resource.
-
#deployment_backup_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the backup being referenced.
-
#deployment_type ⇒ String
[Required] The type of deployment, the value determines the exact ‘type’ of service executed in the Deployment.
-
#description ⇒ String
Metadata about this specific object.
-
#display_name ⇒ String
[Required] An object’s Display Name.
-
#fqdn ⇒ String
A three-label Fully Qualified Domain Name (FQDN) for a resource.
-
#freeform_tags ⇒ Hash<String, String>
A simple key-value pair that is applied without any predefined name, type, or scope.
-
#is_auto_scaling_enabled ⇒ BOOLEAN
[Required] Indicates if auto scaling is enabled for the Deployment’s CPU core count.
-
#is_public ⇒ BOOLEAN
True if this object is publicly available.
-
#license_model ⇒ String
[Required] The Oracle license model that applies to a Deployment.
-
#nsg_ids ⇒ Array<String>
An array of [Network Security Group](docs.cloud.oracle.com/Content/Network/Concepts/networksecuritygroups.htm) OCIDs used to define network access for a deployment.
- #ogg_data ⇒ OCI::GoldenGate::Models::CreateOggDeploymentDetails
-
#subnet_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the subnet being referenced.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateDeploymentDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateDeploymentDetails
Initializes the object
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/oci/golden_gate/models/create_deployment_details.rb', line 163 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.license_model = attributes[:'licenseModel'] if attributes[:'licenseModel'] raise 'You cannot provide both :licenseModel and :license_model' if attributes.key?(:'licenseModel') && attributes.key?(:'license_model') self.license_model = attributes[:'license_model'] if attributes[:'license_model'] self.description = attributes[:'description'] if attributes[:'description'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.deployment_backup_id = attributes[:'deploymentBackupId'] if attributes[:'deploymentBackupId'] raise 'You cannot provide both :deploymentBackupId and :deployment_backup_id' if attributes.key?(:'deploymentBackupId') && attributes.key?(:'deployment_backup_id') self.deployment_backup_id = attributes[:'deployment_backup_id'] if attributes[:'deployment_backup_id'] self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId'] raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id') self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id'] self.fqdn = attributes[:'fqdn'] if attributes[:'fqdn'] self.nsg_ids = attributes[:'nsgIds'] if attributes[:'nsgIds'] raise 'You cannot provide both :nsgIds and :nsg_ids' if attributes.key?(:'nsgIds') && attributes.key?(:'nsg_ids') self.nsg_ids = attributes[:'nsg_ids'] if attributes[:'nsg_ids'] self.is_public = attributes[:'isPublic'] unless attributes[:'isPublic'].nil? raise 'You cannot provide both :isPublic and :is_public' if attributes.key?(:'isPublic') && attributes.key?(:'is_public') self.is_public = attributes[:'is_public'] unless attributes[:'is_public'].nil? self.cpu_core_count = attributes[:'cpuCoreCount'] if attributes[:'cpuCoreCount'] raise 'You cannot provide both :cpuCoreCount and :cpu_core_count' if attributes.key?(:'cpuCoreCount') && attributes.key?(:'cpu_core_count') self.cpu_core_count = attributes[:'cpu_core_count'] if attributes[:'cpu_core_count'] self.is_auto_scaling_enabled = attributes[:'isAutoScalingEnabled'] unless attributes[:'isAutoScalingEnabled'].nil? raise 'You cannot provide both :isAutoScalingEnabled and :is_auto_scaling_enabled' if attributes.key?(:'isAutoScalingEnabled') && attributes.key?(:'is_auto_scaling_enabled') self.is_auto_scaling_enabled = attributes[:'is_auto_scaling_enabled'] unless attributes[:'is_auto_scaling_enabled'].nil? self.deployment_type = attributes[:'deploymentType'] if attributes[:'deploymentType'] raise 'You cannot provide both :deploymentType and :deployment_type' if attributes.key?(:'deploymentType') && attributes.key?(:'deployment_type') self.deployment_type = attributes[:'deployment_type'] if attributes[:'deployment_type'] self.ogg_data = attributes[:'oggData'] if attributes[:'oggData'] raise 'You cannot provide both :oggData and :ogg_data' if attributes.key?(:'oggData') && attributes.key?(:'ogg_data') self.ogg_data = attributes[:'ogg_data'] if attributes[:'ogg_data'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment being referenced.
38 39 40 |
# File 'lib/oci/golden_gate/models/create_deployment_details.rb', line 38 def compartment_id @compartment_id end |
#cpu_core_count ⇒ Integer
[Required] The Minimum number of OCPUs to be made available for this Deployment.
80 81 82 |
# File 'lib/oci/golden_gate/models/create_deployment_details.rb', line 80 def cpu_core_count @cpu_core_count end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Tags defined for this resource. Each key is predefined and scoped to a namespace. Example: ‘{\“bar-key\”: \“value\”}`
50 51 52 |
# File 'lib/oci/golden_gate/models/create_deployment_details.rb', line 50 def @defined_tags end |
#deployment_backup_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the backup being referenced.
55 56 57 |
# File 'lib/oci/golden_gate/models/create_deployment_details.rb', line 55 def deployment_backup_id @deployment_backup_id end |
#deployment_type ⇒ String
[Required] The type of deployment, the value determines the exact ‘type’ of service executed in the Deployment. NOTE: Use of the value OGG is maintained for backward compatibility purposes. Its use is discouraged
in favor of the equivalent DATABASE_ORACLE value.
91 92 93 |
# File 'lib/oci/golden_gate/models/create_deployment_details.rb', line 91 def deployment_type @deployment_type end |
#description ⇒ String
Metadata about this specific object.
33 34 35 |
# File 'lib/oci/golden_gate/models/create_deployment_details.rb', line 33 def description @description end |
#display_name ⇒ String
[Required] An object’s Display Name.
23 24 25 |
# File 'lib/oci/golden_gate/models/create_deployment_details.rb', line 23 def display_name @display_name end |
#fqdn ⇒ String
A three-label Fully Qualified Domain Name (FQDN) for a resource.
65 66 67 |
# File 'lib/oci/golden_gate/models/create_deployment_details.rb', line 65 def fqdn @fqdn end |
#freeform_tags ⇒ Hash<String, String>
A simple key-value pair that is applied without any predefined name, type, or scope. Exists for cross-compatibility only. Example: ‘\“value\”`
44 45 46 |
# File 'lib/oci/golden_gate/models/create_deployment_details.rb', line 44 def @freeform_tags end |
#is_auto_scaling_enabled ⇒ BOOLEAN
[Required] Indicates if auto scaling is enabled for the Deployment’s CPU core count.
85 86 87 |
# File 'lib/oci/golden_gate/models/create_deployment_details.rb', line 85 def is_auto_scaling_enabled @is_auto_scaling_enabled end |
#is_public ⇒ BOOLEAN
True if this object is publicly available.
75 76 77 |
# File 'lib/oci/golden_gate/models/create_deployment_details.rb', line 75 def is_public @is_public end |
#license_model ⇒ String
[Required] The Oracle license model that applies to a Deployment.
28 29 30 |
# File 'lib/oci/golden_gate/models/create_deployment_details.rb', line 28 def license_model @license_model end |
#nsg_ids ⇒ Array<String>
An array of [Network Security Group](docs.cloud.oracle.com/Content/Network/Concepts/networksecuritygroups.htm) OCIDs used to define network access for a deployment.
70 71 72 |
# File 'lib/oci/golden_gate/models/create_deployment_details.rb', line 70 def nsg_ids @nsg_ids end |
#ogg_data ⇒ OCI::GoldenGate::Models::CreateOggDeploymentDetails
94 95 96 |
# File 'lib/oci/golden_gate/models/create_deployment_details.rb', line 94 def ogg_data @ogg_data end |
#subnet_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the subnet being referenced.
60 61 62 |
# File 'lib/oci/golden_gate/models/create_deployment_details.rb', line 60 def subnet_id @subnet_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/oci/golden_gate/models/create_deployment_details.rb', line 97 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'license_model': :'licenseModel', 'description': :'description', 'compartment_id': :'compartmentId', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'deployment_backup_id': :'deploymentBackupId', 'subnet_id': :'subnetId', 'fqdn': :'fqdn', 'nsg_ids': :'nsgIds', 'is_public': :'isPublic', 'cpu_core_count': :'cpuCoreCount', 'is_auto_scaling_enabled': :'isAutoScalingEnabled', 'deployment_type': :'deploymentType', 'ogg_data': :'oggData' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/oci/golden_gate/models/create_deployment_details.rb', line 120 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'license_model': :'String', 'description': :'String', 'compartment_id': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'deployment_backup_id': :'String', 'subnet_id': :'String', 'fqdn': :'String', 'nsg_ids': :'Array<String>', 'is_public': :'BOOLEAN', 'cpu_core_count': :'Integer', 'is_auto_scaling_enabled': :'BOOLEAN', 'deployment_type': :'String', 'ogg_data': :'OCI::GoldenGate::Models::CreateOggDeploymentDetails' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 |
# File 'lib/oci/golden_gate/models/create_deployment_details.rb', line 275 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && license_model == other.license_model && description == other.description && compartment_id == other.compartment_id && == other. && == other. && deployment_backup_id == other.deployment_backup_id && subnet_id == other.subnet_id && fqdn == other.fqdn && nsg_ids == other.nsg_ids && is_public == other.is_public && cpu_core_count == other.cpu_core_count && is_auto_scaling_enabled == other.is_auto_scaling_enabled && deployment_type == other.deployment_type && ogg_data == other.ogg_data end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 |
# File 'lib/oci/golden_gate/models/create_deployment_details.rb', line 319 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
299 300 301 |
# File 'lib/oci/golden_gate/models/create_deployment_details.rb', line 299 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
308 309 310 |
# File 'lib/oci/golden_gate/models/create_deployment_details.rb', line 308 def hash [display_name, license_model, description, compartment_id, , , deployment_backup_id, subnet_id, fqdn, nsg_ids, is_public, cpu_core_count, is_auto_scaling_enabled, deployment_type, ogg_data].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
352 353 354 355 356 357 358 359 360 361 |
# File 'lib/oci/golden_gate/models/create_deployment_details.rb', line 352 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
346 347 348 |
# File 'lib/oci/golden_gate/models/create_deployment_details.rb', line 346 def to_s to_hash.to_s end |