Class: OCI::GoldenGate::Models::DatabaseRegistration
- Inherits:
-
Object
- Object
- OCI::GoldenGate::Models::DatabaseRegistration
- Defined in:
- lib/oci/golden_gate/models/database_registration.rb
Overview
Represents the metadata description of a database used by deployments in the same compartment.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_NEEDS_ATTENTION = 'NEEDS_ATTENTION'.freeze, LIFECYCLE_STATE_IN_PROGRESS = 'IN_PROGRESS'.freeze, LIFECYCLE_STATE_CANCELING = 'CANCELING'.freeze, LIFECYCLE_STATE_CANCELED = 'CANCELED'.freeze, LIFECYCLE_STATE_SUCCEEDED = 'SUCCEEDED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- SESSION_MODE_ENUM =
[ SESSION_MODE_DIRECT = 'DIRECT'.freeze, SESSION_MODE_REDIRECT = 'REDIRECT'.freeze, SESSION_MODE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#alias_name ⇒ String
[Required] Credential store alias.
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment being referenced.
-
#connection_string ⇒ String
Connect descriptor or Easy Connect Naming method that Oracle GoldenGate uses to connect to a database.
-
#database_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the database being referenced.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Tags defined for this resource.
-
#description ⇒ String
Metadata about this specific object.
-
#display_name ⇒ String
[Required] An object’s Display Name.
-
#fqdn ⇒ String
[Required] A three-label Fully Qualified Domain Name (FQDN) for a resource.
-
#freeform_tags ⇒ Hash<String, String>
A simple key-value pair that is applied without any predefined name, type, or scope.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the databaseRegistration being referenced.
-
#ip_address ⇒ String
[Required] The private IP address in the customer’s VCN of the customer’s endpoint, typically a database.
-
#key_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the customer "Master" key being referenced.
-
#lifecycle_details ⇒ String
Describes the object’s current state in detail.
-
#lifecycle_state ⇒ String
Possible lifecycle states.
-
#rce_private_ip ⇒ String
A Private Endpoint IP Address created in the customer’s subnet.
-
#secret_compartment_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment where the the GGS Secret will be created.
-
#secret_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the customer GGS Secret being referenced.
-
#session_mode ⇒ String
The mode of the database connection session to be established by the data client.
-
#subnet_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the subnet being referenced.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
The system tags associated with this resource, if any.
-
#time_created ⇒ DateTime
The time the resource was created.
-
#time_updated ⇒ DateTime
The time the resource was last updated.
-
#username ⇒ String
[Required] The username Oracle GoldenGate uses to connect the associated RDBMS.
-
#vault_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the customer vault being referenced.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DatabaseRegistration
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DatabaseRegistration
Initializes the object
251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 251 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.fqdn = attributes[:'fqdn'] if attributes[:'fqdn'] self.ip_address = attributes[:'ipAddress'] if attributes[:'ipAddress'] raise 'You cannot provide both :ipAddress and :ip_address' if attributes.key?(:'ipAddress') && attributes.key?(:'ip_address') self.ip_address = attributes[:'ip_address'] if attributes[:'ip_address'] self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId'] raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id') self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id'] self.database_id = attributes[:'databaseId'] if attributes[:'databaseId'] raise 'You cannot provide both :databaseId and :database_id' if attributes.key?(:'databaseId') && attributes.key?(:'database_id') self.database_id = attributes[:'database_id'] if attributes[:'database_id'] self.rce_private_ip = attributes[:'rcePrivateIp'] if attributes[:'rcePrivateIp'] raise 'You cannot provide both :rcePrivateIp and :rce_private_ip' if attributes.key?(:'rcePrivateIp') && attributes.key?(:'rce_private_ip') self.rce_private_ip = attributes[:'rce_private_ip'] if attributes[:'rce_private_ip'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] self.username = attributes[:'username'] if attributes[:'username'] self.connection_string = attributes[:'connectionString'] if attributes[:'connectionString'] raise 'You cannot provide both :connectionString and :connection_string' if attributes.key?(:'connectionString') && attributes.key?(:'connection_string') self.connection_string = attributes[:'connection_string'] if attributes[:'connection_string'] self.session_mode = attributes[:'sessionMode'] if attributes[:'sessionMode'] self.session_mode = "DIRECT" if session_mode.nil? && !attributes.key?(:'sessionMode') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :sessionMode and :session_mode' if attributes.key?(:'sessionMode') && attributes.key?(:'session_mode') self.session_mode = attributes[:'session_mode'] if attributes[:'session_mode'] self.session_mode = "DIRECT" if session_mode.nil? && !attributes.key?(:'sessionMode') && !attributes.key?(:'session_mode') # rubocop:disable Style/StringLiterals self.alias_name = attributes[:'aliasName'] if attributes[:'aliasName'] raise 'You cannot provide both :aliasName and :alias_name' if attributes.key?(:'aliasName') && attributes.key?(:'alias_name') self.alias_name = attributes[:'alias_name'] if attributes[:'alias_name'] self.vault_id = attributes[:'vaultId'] if attributes[:'vaultId'] raise 'You cannot provide both :vaultId and :vault_id' if attributes.key?(:'vaultId') && attributes.key?(:'vault_id') self.vault_id = attributes[:'vault_id'] if attributes[:'vault_id'] self.key_id = attributes[:'keyId'] if attributes[:'keyId'] raise 'You cannot provide both :keyId and :key_id' if attributes.key?(:'keyId') && attributes.key?(:'key_id') self.key_id = attributes[:'key_id'] if attributes[:'key_id'] self.secret_compartment_id = attributes[:'secretCompartmentId'] if attributes[:'secretCompartmentId'] raise 'You cannot provide both :secretCompartmentId and :secret_compartment_id' if attributes.key?(:'secretCompartmentId') && attributes.key?(:'secret_compartment_id') self.secret_compartment_id = attributes[:'secret_compartment_id'] if attributes[:'secret_compartment_id'] self.secret_id = attributes[:'secretId'] if attributes[:'secretId'] raise 'You cannot provide both :secretId and :secret_id' if attributes.key?(:'secretId') && attributes.key?(:'secret_id') self.secret_id = attributes[:'secret_id'] if attributes[:'secret_id'] end |
Instance Attribute Details
#alias_name ⇒ String
[Required] Credential store alias.
135 136 137 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 135 def alias_name @alias_name end |
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment being referenced.
52 53 54 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 52 def compartment_id @compartment_id end |
#connection_string ⇒ String
Connect descriptor or Easy Connect Naming method that Oracle GoldenGate uses to connect to a database.
125 126 127 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 125 def connection_string @connection_string end |
#database_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the database being referenced.
104 105 106 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 104 def database_id @database_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Tags defined for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
84 85 86 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 84 def end |
#description ⇒ String
Metadata about this specific object.
47 48 49 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 47 def description @description end |
#display_name ⇒ String
[Required] An object’s Display Name.
42 43 44 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 42 def display_name @display_name end |
#fqdn ⇒ String
[Required] A three-label Fully Qualified Domain Name (FQDN) for a resource.
89 90 91 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 89 def fqdn @fqdn end |
#freeform_tags ⇒ Hash<String, String>
A simple key-value pair that is applied without any predefined name, type, or scope. Exists for cross-compatibility only. Example: ‘"value"`
78 79 80 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 78 def end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the databaseRegistration being referenced.
37 38 39 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 37 def id @id end |
#ip_address ⇒ String
[Required] The private IP address in the customer’s VCN of the customer’s endpoint, typically a database.
94 95 96 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 94 def ip_address @ip_address end |
#key_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the customer "Master" key being referenced. If provided, this will reference a key which the customer will be required to ensure the policies are established to permit the GoldenGate Service to utilize this key to manage secrets.
145 146 147 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 145 def key_id @key_id end |
#lifecycle_details ⇒ String
Describes the object’s current state in detail. For example, it can be used to provide actionable information for a resource in a Failed state.
72 73 74 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 72 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
Possible lifecycle states.
67 68 69 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 67 def lifecycle_state @lifecycle_state end |
#rce_private_ip ⇒ String
A Private Endpoint IP Address created in the customer’s subnet. A customer database can expect network traffic initiated by GGS from this IP address and send network traffic to this IP address, typically in response to requests from GGS (OGG). The customer may utilize this IP address in Security Lists or Network Security Groups (NSG) as needed.
109 110 111 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 109 def rce_private_ip @rce_private_ip end |
#secret_compartment_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment where the the GGS Secret will be created. If provided, this will reference a key which the customer will be required to ensure the policies are established to permit the GoldenGate Service to utilize this Compartment in which to create a Secret.
150 151 152 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 150 def secret_compartment_id @secret_compartment_id end |
#secret_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the customer GGS Secret being referenced. If provided, this will reference a key which the customer will be required to ensure the policies are established to permit the GoldenGate Service to utilize this Secret
155 156 157 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 155 def secret_id @secret_id end |
#session_mode ⇒ String
The mode of the database connection session to be established by the data client. REDIRECT - for a RAC database, DIRECT - for a non-RAC database. Connection to a RAC database involves a redirection received from the SCAN listeners to the database node to connect to. By default the mode would be DIRECT.
130 131 132 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 130 def session_mode @session_mode end |
#subnet_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the subnet being referenced.
99 100 101 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 99 def subnet_id @subnet_id end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
The system tags associated with this resource, if any. The system tags are set by Oracle Cloud Infrastructure services. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: ‘{free-tier-retain: true}`
115 116 117 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 115 def end |
#time_created ⇒ DateTime
The time the resource was created. The format is defined by [RFC3339](tools.ietf.org/html/rfc3339), such as 2016-08-25T21:10:29.600Z.
57 58 59 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 57 def time_created @time_created end |
#time_updated ⇒ DateTime
The time the resource was last updated. The format is defined by [RFC3339](tools.ietf.org/html/rfc3339), such as 2016-08-25T21:10:29.600Z.
62 63 64 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 62 def time_updated @time_updated end |
#username ⇒ String
[Required] The username Oracle GoldenGate uses to connect the associated RDBMS. This username must already exist and be available for use by the database. It must conform to the security requirements implemented by the database including length, case sensitivity, and so on.
120 121 122 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 120 def username @username end |
#vault_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the customer vault being referenced. If provided, this will reference a vault which the customer will be required to ensure the policies are established to permit the GoldenGate Service to manage secrets contained within this vault.
140 141 142 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 140 def vault_id @vault_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 158 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'description': :'description', 'compartment_id': :'compartmentId', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'fqdn': :'fqdn', 'ip_address': :'ipAddress', 'subnet_id': :'subnetId', 'database_id': :'databaseId', 'rce_private_ip': :'rcePrivateIp', 'system_tags': :'systemTags', 'username': :'username', 'connection_string': :'connectionString', 'session_mode': :'sessionMode', 'alias_name': :'aliasName', 'vault_id': :'vaultId', 'key_id': :'keyId', 'secret_compartment_id': :'secretCompartmentId', 'secret_id': :'secretId' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 190 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'description': :'String', 'compartment_id': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'fqdn': :'String', 'ip_address': :'String', 'subnet_id': :'String', 'database_id': :'String', 'rce_private_ip': :'String', 'system_tags': :'Hash<String, Hash<String, Object>>', 'username': :'String', 'connection_string': :'String', 'session_mode': :'String', 'alias_name': :'String', 'vault_id': :'String', 'key_id': :'String', 'secret_compartment_id': :'String', 'secret_id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 421 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && description == other.description && compartment_id == other.compartment_id && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && == other. && == other. && fqdn == other.fqdn && ip_address == other.ip_address && subnet_id == other.subnet_id && database_id == other.database_id && rce_private_ip == other.rce_private_ip && == other. && username == other.username && connection_string == other.connection_string && session_mode == other.session_mode && alias_name == other.alias_name && vault_id == other.vault_id && key_id == other.key_id && secret_compartment_id == other.secret_compartment_id && secret_id == other.secret_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 474 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
454 455 456 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 454 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
463 464 465 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 463 def hash [id, display_name, description, compartment_id, time_created, time_updated, lifecycle_state, lifecycle_details, , , fqdn, ip_address, subnet_id, database_id, rce_private_ip, , username, connection_string, session_mode, alias_name, vault_id, key_id, secret_compartment_id, secret_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
507 508 509 510 511 512 513 514 515 516 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 507 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
501 502 503 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 501 def to_s to_hash.to_s end |