Class: OCI::GoldenGate::Models::Deployment

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/golden_gate/models/deployment.rb

Overview

A container for your OCI GoldenGate resources, such as the OCI GoldenGate deployment console.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_NEEDS_ATTENTION = 'NEEDS_ATTENTION'.freeze,
  LIFECYCLE_STATE_IN_PROGRESS = 'IN_PROGRESS'.freeze,
  LIFECYCLE_STATE_CANCELING = 'CANCELING'.freeze,
  LIFECYCLE_STATE_CANCELED = 'CANCELED'.freeze,
  LIFECYCLE_STATE_SUCCEEDED = 'SUCCEEDED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_SUB_STATE_ENUM =
[
  LIFECYCLE_SUB_STATE_RECOVERING = 'RECOVERING'.freeze,
  LIFECYCLE_SUB_STATE_STARTING = 'STARTING'.freeze,
  LIFECYCLE_SUB_STATE_STOPPING = 'STOPPING'.freeze,
  LIFECYCLE_SUB_STATE_MOVING = 'MOVING'.freeze,
  LIFECYCLE_SUB_STATE_UPGRADING = 'UPGRADING'.freeze,
  LIFECYCLE_SUB_STATE_RESTORING = 'RESTORING'.freeze,
  LIFECYCLE_SUB_STATE_BACKUP_IN_PROGRESS = 'BACKUP_IN_PROGRESS'.freeze,
  LIFECYCLE_SUB_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LICENSE_MODEL_ENUM =
[
  LICENSE_MODEL_LICENSE_INCLUDED = 'LICENSE_INCLUDED'.freeze,
  LICENSE_MODEL_BRING_YOUR_OWN_LICENSE = 'BRING_YOUR_OWN_LICENSE'.freeze,
  LICENSE_MODEL_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
DEPLOYMENT_TYPE_ENUM =
[
  DEPLOYMENT_TYPE_OGG = 'OGG'.freeze,
  DEPLOYMENT_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Deployment

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :display_name (String)

    The value to assign to the #display_name property

  • :description (String)

    The value to assign to the #description property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :deployment_backup_id (String)

    The value to assign to the #deployment_backup_id property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :time_updated (DateTime)

    The value to assign to the #time_updated property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :lifecycle_sub_state (String)

    The value to assign to the #lifecycle_sub_state property

  • :lifecycle_details (String)

    The value to assign to the #lifecycle_details property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property

  • :is_healthy (BOOLEAN)

    The value to assign to the #is_healthy property

  • :subnet_id (String)

    The value to assign to the #subnet_id property

  • :fqdn (String)

    The value to assign to the #fqdn property

  • :license_model (String)

    The value to assign to the #license_model property

  • :cpu_core_count (Integer)

    The value to assign to the #cpu_core_count property

  • :is_auto_scaling_enabled (BOOLEAN)

    The value to assign to the #is_auto_scaling_enabled property

  • :nsg_ids (Array<String>)

    The value to assign to the #nsg_ids property

  • :is_public (BOOLEAN)

    The value to assign to the #is_public property

  • :public_ip_address (String)

    The value to assign to the #public_ip_address property

  • :private_ip_address (String)

    The value to assign to the #private_ip_address property

  • :deployment_url (String)

    The value to assign to the #deployment_url property

  • :system_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #system_tags property

  • :is_latest_version (BOOLEAN)

    The value to assign to the #is_latest_version property

  • :time_upgrade_required (DateTime)

    The value to assign to the #time_upgrade_required property

  • :storage_utilization_in_bytes (Integer)

    The value to assign to the #storage_utilization_in_bytes property

  • :is_storage_utilization_limit_exceeded (BOOLEAN)

    The value to assign to the #is_storage_utilization_limit_exceeded property

  • :deployment_type (String)

    The value to assign to the #deployment_type property

  • :ogg_data (OCI::GoldenGate::Models::OggDeployment)

    The value to assign to the #ogg_data property



313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
# File 'lib/oci/golden_gate/models/deployment.rb', line 313

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.deployment_backup_id = attributes[:'deploymentBackupId'] if attributes[:'deploymentBackupId']

  raise 'You cannot provide both :deploymentBackupId and :deployment_backup_id' if attributes.key?(:'deploymentBackupId') && attributes.key?(:'deployment_backup_id')

  self.deployment_backup_id = attributes[:'deployment_backup_id'] if attributes[:'deployment_backup_id']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.lifecycle_sub_state = attributes[:'lifecycleSubState'] if attributes[:'lifecycleSubState']

  raise 'You cannot provide both :lifecycleSubState and :lifecycle_sub_state' if attributes.key?(:'lifecycleSubState') && attributes.key?(:'lifecycle_sub_state')

  self.lifecycle_sub_state = attributes[:'lifecycle_sub_state'] if attributes[:'lifecycle_sub_state']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.is_healthy = attributes[:'isHealthy'] unless attributes[:'isHealthy'].nil?

  raise 'You cannot provide both :isHealthy and :is_healthy' if attributes.key?(:'isHealthy') && attributes.key?(:'is_healthy')

  self.is_healthy = attributes[:'is_healthy'] unless attributes[:'is_healthy'].nil?

  self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId']

  raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id')

  self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id']

  self.fqdn = attributes[:'fqdn'] if attributes[:'fqdn']

  self.license_model = attributes[:'licenseModel'] if attributes[:'licenseModel']

  raise 'You cannot provide both :licenseModel and :license_model' if attributes.key?(:'licenseModel') && attributes.key?(:'license_model')

  self.license_model = attributes[:'license_model'] if attributes[:'license_model']

  self.cpu_core_count = attributes[:'cpuCoreCount'] if attributes[:'cpuCoreCount']

  raise 'You cannot provide both :cpuCoreCount and :cpu_core_count' if attributes.key?(:'cpuCoreCount') && attributes.key?(:'cpu_core_count')

  self.cpu_core_count = attributes[:'cpu_core_count'] if attributes[:'cpu_core_count']

  self.is_auto_scaling_enabled = attributes[:'isAutoScalingEnabled'] unless attributes[:'isAutoScalingEnabled'].nil?

  raise 'You cannot provide both :isAutoScalingEnabled and :is_auto_scaling_enabled' if attributes.key?(:'isAutoScalingEnabled') && attributes.key?(:'is_auto_scaling_enabled')

  self.is_auto_scaling_enabled = attributes[:'is_auto_scaling_enabled'] unless attributes[:'is_auto_scaling_enabled'].nil?

  self.nsg_ids = attributes[:'nsgIds'] if attributes[:'nsgIds']

  raise 'You cannot provide both :nsgIds and :nsg_ids' if attributes.key?(:'nsgIds') && attributes.key?(:'nsg_ids')

  self.nsg_ids = attributes[:'nsg_ids'] if attributes[:'nsg_ids']

  self.is_public = attributes[:'isPublic'] unless attributes[:'isPublic'].nil?

  raise 'You cannot provide both :isPublic and :is_public' if attributes.key?(:'isPublic') && attributes.key?(:'is_public')

  self.is_public = attributes[:'is_public'] unless attributes[:'is_public'].nil?

  self.public_ip_address = attributes[:'publicIpAddress'] if attributes[:'publicIpAddress']

  raise 'You cannot provide both :publicIpAddress and :public_ip_address' if attributes.key?(:'publicIpAddress') && attributes.key?(:'public_ip_address')

  self.public_ip_address = attributes[:'public_ip_address'] if attributes[:'public_ip_address']

  self.private_ip_address = attributes[:'privateIpAddress'] if attributes[:'privateIpAddress']

  raise 'You cannot provide both :privateIpAddress and :private_ip_address' if attributes.key?(:'privateIpAddress') && attributes.key?(:'private_ip_address')

  self.private_ip_address = attributes[:'private_ip_address'] if attributes[:'private_ip_address']

  self.deployment_url = attributes[:'deploymentUrl'] if attributes[:'deploymentUrl']

  raise 'You cannot provide both :deploymentUrl and :deployment_url' if attributes.key?(:'deploymentUrl') && attributes.key?(:'deployment_url')

  self.deployment_url = attributes[:'deployment_url'] if attributes[:'deployment_url']

  self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

  raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

  self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']

  self.is_latest_version = attributes[:'isLatestVersion'] unless attributes[:'isLatestVersion'].nil?

  raise 'You cannot provide both :isLatestVersion and :is_latest_version' if attributes.key?(:'isLatestVersion') && attributes.key?(:'is_latest_version')

  self.is_latest_version = attributes[:'is_latest_version'] unless attributes[:'is_latest_version'].nil?

  self.time_upgrade_required = attributes[:'timeUpgradeRequired'] if attributes[:'timeUpgradeRequired']

  raise 'You cannot provide both :timeUpgradeRequired and :time_upgrade_required' if attributes.key?(:'timeUpgradeRequired') && attributes.key?(:'time_upgrade_required')

  self.time_upgrade_required = attributes[:'time_upgrade_required'] if attributes[:'time_upgrade_required']

  self.storage_utilization_in_bytes = attributes[:'storageUtilizationInBytes'] if attributes[:'storageUtilizationInBytes']

  raise 'You cannot provide both :storageUtilizationInBytes and :storage_utilization_in_bytes' if attributes.key?(:'storageUtilizationInBytes') && attributes.key?(:'storage_utilization_in_bytes')

  self.storage_utilization_in_bytes = attributes[:'storage_utilization_in_bytes'] if attributes[:'storage_utilization_in_bytes']

  self.is_storage_utilization_limit_exceeded = attributes[:'isStorageUtilizationLimitExceeded'] unless attributes[:'isStorageUtilizationLimitExceeded'].nil?

  raise 'You cannot provide both :isStorageUtilizationLimitExceeded and :is_storage_utilization_limit_exceeded' if attributes.key?(:'isStorageUtilizationLimitExceeded') && attributes.key?(:'is_storage_utilization_limit_exceeded')

  self.is_storage_utilization_limit_exceeded = attributes[:'is_storage_utilization_limit_exceeded'] unless attributes[:'is_storage_utilization_limit_exceeded'].nil?

  self.deployment_type = attributes[:'deploymentType'] if attributes[:'deploymentType']

  raise 'You cannot provide both :deploymentType and :deployment_type' if attributes.key?(:'deploymentType') && attributes.key?(:'deployment_type')

  self.deployment_type = attributes[:'deployment_type'] if attributes[:'deployment_type']

  self.ogg_data = attributes[:'oggData'] if attributes[:'oggData']

  raise 'You cannot provide both :oggData and :ogg_data' if attributes.key?(:'oggData') && attributes.key?(:'ogg_data')

  self.ogg_data = attributes[:'ogg_data'] if attributes[:'ogg_data']
end

Instance Attribute Details

#compartment_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment being referenced.

Returns:

  • (String)


68
69
70
# File 'lib/oci/golden_gate/models/deployment.rb', line 68

def compartment_id
  @compartment_id
end

#cpu_core_countInteger

**[Required]** The Minimum number of OCPUs to be made available for this Deployment.

Returns:

  • (Integer)


135
136
137
# File 'lib/oci/golden_gate/models/deployment.rb', line 135

def cpu_core_count
  @cpu_core_count
end

#defined_tagsHash<String, Hash<String, Object>>

Tags defined for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


110
111
112
# File 'lib/oci/golden_gate/models/deployment.rb', line 110

def defined_tags
  @defined_tags
end

#deployment_backup_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the backup being referenced.

Returns:

  • (String)


73
74
75
# File 'lib/oci/golden_gate/models/deployment.rb', line 73

def deployment_backup_id
  @deployment_backup_id
end

#deployment_typeString

**[Required]** The deployment type.

Returns:

  • (String)


196
197
198
# File 'lib/oci/golden_gate/models/deployment.rb', line 196

def deployment_type
  @deployment_type
end

#deployment_urlString

The URL of a resource.

Returns:

  • (String)


165
166
167
# File 'lib/oci/golden_gate/models/deployment.rb', line 165

def deployment_url
  @deployment_url
end

#descriptionString

Metadata about this specific object.

Returns:

  • (String)


63
64
65
# File 'lib/oci/golden_gate/models/deployment.rb', line 63

def description
  @description
end

#display_nameString

An object's Display Name.

Returns:

  • (String)


58
59
60
# File 'lib/oci/golden_gate/models/deployment.rb', line 58

def display_name
  @display_name
end

#fqdnString

A three-label Fully Qualified Domain Name (FQDN) for a resource.

Returns:

  • (String)


125
126
127
# File 'lib/oci/golden_gate/models/deployment.rb', line 125

def fqdn
  @fqdn
end

#freeform_tagsHash<String, String>

A simple key-value pair that is applied without any predefined name, type, or scope. Exists for cross-compatibility only. Example: `"value"`

Returns:

  • (Hash<String, String>)


104
105
106
# File 'lib/oci/golden_gate/models/deployment.rb', line 104

def freeform_tags
  @freeform_tags
end

#idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the deployment being referenced.

Returns:

  • (String)


53
54
55
# File 'lib/oci/golden_gate/models/deployment.rb', line 53

def id
  @id
end

#is_auto_scaling_enabledBOOLEAN

**[Required]** Indicates if auto scaling is enabled for the Deployment's CPU core count.

Returns:

  • (BOOLEAN)


140
141
142
# File 'lib/oci/golden_gate/models/deployment.rb', line 140

def is_auto_scaling_enabled
  @is_auto_scaling_enabled
end

#is_healthyBOOLEAN

True if all of the aggregate resources are working correctly.

Returns:

  • (BOOLEAN)


115
116
117
# File 'lib/oci/golden_gate/models/deployment.rb', line 115

def is_healthy
  @is_healthy
end

#is_latest_versionBOOLEAN

Indicates if the resource is the the latest available version.

Returns:

  • (BOOLEAN)


176
177
178
# File 'lib/oci/golden_gate/models/deployment.rb', line 176

def is_latest_version
  @is_latest_version
end

#is_publicBOOLEAN

True if this object is publicly available.

Returns:

  • (BOOLEAN)


150
151
152
# File 'lib/oci/golden_gate/models/deployment.rb', line 150

def is_public
  @is_public
end

#is_storage_utilization_limit_exceededBOOLEAN

Indicator will be true if the amount of storage being utilized exceeds the allowable storage utilization limit. Exceeding the limit may be an indication of a misconfiguration of the deployment's GoldenGate service.

Returns:

  • (BOOLEAN)


191
192
193
# File 'lib/oci/golden_gate/models/deployment.rb', line 191

def is_storage_utilization_limit_exceeded
  @is_storage_utilization_limit_exceeded
end

#license_modelString

**[Required]** The Oracle license model that applies to a Deployment.

Returns:

  • (String)


130
131
132
# File 'lib/oci/golden_gate/models/deployment.rb', line 130

def license_model
  @license_model
end

#lifecycle_detailsString

Describes the object's current state in detail. For example, it can be used to provide actionable information for a resource in a Failed state.

Returns:

  • (String)


98
99
100
# File 'lib/oci/golden_gate/models/deployment.rb', line 98

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

Possible lifecycle states.

Returns:

  • (String)


88
89
90
# File 'lib/oci/golden_gate/models/deployment.rb', line 88

def lifecycle_state
  @lifecycle_state
end

#lifecycle_sub_stateString

Possible GGS lifecycle sub-states.

Returns:

  • (String)


93
94
95
# File 'lib/oci/golden_gate/models/deployment.rb', line 93

def lifecycle_sub_state
  @lifecycle_sub_state
end

#nsg_idsArray<String>

An array of [Network Security Group](docs.cloud.oracle.com/Content/Network/Concepts/networksecuritygroups.htm) OCIDs used to define network access for a deployment.

Returns:

  • (Array<String>)


145
146
147
# File 'lib/oci/golden_gate/models/deployment.rb', line 145

def nsg_ids
  @nsg_ids
end

#ogg_dataOCI::GoldenGate::Models::OggDeployment



199
200
201
# File 'lib/oci/golden_gate/models/deployment.rb', line 199

def ogg_data
  @ogg_data
end

#private_ip_addressString

The private IP address in the customer's VCN representing the access point for the associated endpoint service in the GoldenGate service VCN.

Returns:

  • (String)


160
161
162
# File 'lib/oci/golden_gate/models/deployment.rb', line 160

def private_ip_address
  @private_ip_address
end

#public_ip_addressString

The public IP address representing the access point for the Deployment.

Returns:

  • (String)


155
156
157
# File 'lib/oci/golden_gate/models/deployment.rb', line 155

def public_ip_address
  @public_ip_address
end

#storage_utilization_in_bytesInteger

The amount of storage being utilized (in bytes)

Returns:

  • (Integer)


186
187
188
# File 'lib/oci/golden_gate/models/deployment.rb', line 186

def storage_utilization_in_bytes
  @storage_utilization_in_bytes
end

#subnet_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the subnet being referenced.

Returns:

  • (String)


120
121
122
# File 'lib/oci/golden_gate/models/deployment.rb', line 120

def subnet_id
  @subnet_id
end

#system_tagsHash<String, Hash<String, Object>>

The system tags associated with this resource, if any. The system tags are set by Oracle Cloud Infrastructure services. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{free-tier-retain: true}`

Returns:

  • (Hash<String, Hash<String, Object>>)


171
172
173
# File 'lib/oci/golden_gate/models/deployment.rb', line 171

def system_tags
  @system_tags
end

#time_createdDateTime

The time the resource was created. The format is defined by [RFC3339](tools.ietf.org/html/rfc3339), such as `2016-08-25T21:10:29.600Z`.

Returns:

  • (DateTime)


78
79
80
# File 'lib/oci/golden_gate/models/deployment.rb', line 78

def time_created
  @time_created
end

#time_updatedDateTime

The time the resource was last updated. The format is defined by [RFC3339](tools.ietf.org/html/rfc3339), such as `2016-08-25T21:10:29.600Z`.

Returns:

  • (DateTime)


83
84
85
# File 'lib/oci/golden_gate/models/deployment.rb', line 83

def time_updated
  @time_updated
end

#time_upgrade_requiredDateTime

The date the existing version in use will no longer be considered as usable and an upgrade will be required. This date is typically 6 months after the version was released for use by GGS. The format is defined by [RFC3339](tools.ietf.org/html/rfc3339), such as `2016-08-25T21:10:29.600Z`.

Returns:

  • (DateTime)


181
182
183
# File 'lib/oci/golden_gate/models/deployment.rb', line 181

def time_upgrade_required
  @time_upgrade_required
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/oci/golden_gate/models/deployment.rb', line 202

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'display_name': :'displayName',
    'description': :'description',
    'compartment_id': :'compartmentId',
    'deployment_backup_id': :'deploymentBackupId',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_sub_state': :'lifecycleSubState',
    'lifecycle_details': :'lifecycleDetails',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'is_healthy': :'isHealthy',
    'subnet_id': :'subnetId',
    'fqdn': :'fqdn',
    'license_model': :'licenseModel',
    'cpu_core_count': :'cpuCoreCount',
    'is_auto_scaling_enabled': :'isAutoScalingEnabled',
    'nsg_ids': :'nsgIds',
    'is_public': :'isPublic',
    'public_ip_address': :'publicIpAddress',
    'private_ip_address': :'privateIpAddress',
    'deployment_url': :'deploymentUrl',
    'system_tags': :'systemTags',
    'is_latest_version': :'isLatestVersion',
    'time_upgrade_required': :'timeUpgradeRequired',
    'storage_utilization_in_bytes': :'storageUtilizationInBytes',
    'is_storage_utilization_limit_exceeded': :'isStorageUtilizationLimitExceeded',
    'deployment_type': :'deploymentType',
    'ogg_data': :'oggData'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/oci/golden_gate/models/deployment.rb', line 240

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'display_name': :'String',
    'description': :'String',
    'compartment_id': :'String',
    'deployment_backup_id': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'lifecycle_state': :'String',
    'lifecycle_sub_state': :'String',
    'lifecycle_details': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'is_healthy': :'BOOLEAN',
    'subnet_id': :'String',
    'fqdn': :'String',
    'license_model': :'String',
    'cpu_core_count': :'Integer',
    'is_auto_scaling_enabled': :'BOOLEAN',
    'nsg_ids': :'Array<String>',
    'is_public': :'BOOLEAN',
    'public_ip_address': :'String',
    'private_ip_address': :'String',
    'deployment_url': :'String',
    'system_tags': :'Hash<String, Hash<String, Object>>',
    'is_latest_version': :'BOOLEAN',
    'time_upgrade_required': :'DateTime',
    'storage_utilization_in_bytes': :'Integer',
    'is_storage_utilization_limit_exceeded': :'BOOLEAN',
    'deployment_type': :'String',
    'ogg_data': :'OCI::GoldenGate::Models::OggDeployment'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
# File 'lib/oci/golden_gate/models/deployment.rb', line 547

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    display_name == other.display_name &&
    description == other.description &&
    compartment_id == other.compartment_id &&
    deployment_backup_id == other.deployment_backup_id &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_sub_state == other.lifecycle_sub_state &&
    lifecycle_details == other.lifecycle_details &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    is_healthy == other.is_healthy &&
    subnet_id == other.subnet_id &&
    fqdn == other.fqdn &&
    license_model == other.license_model &&
    cpu_core_count == other.cpu_core_count &&
    is_auto_scaling_enabled == other.is_auto_scaling_enabled &&
    nsg_ids == other.nsg_ids &&
    is_public == other.is_public &&
    public_ip_address == other.public_ip_address &&
    private_ip_address == other.private_ip_address &&
    deployment_url == other.deployment_url &&
    system_tags == other.system_tags &&
    is_latest_version == other.is_latest_version &&
    time_upgrade_required == other.time_upgrade_required &&
    storage_utilization_in_bytes == other.storage_utilization_in_bytes &&
    is_storage_utilization_limit_exceeded == other.is_storage_utilization_limit_exceeded &&
    deployment_type == other.deployment_type &&
    ogg_data == other.ogg_data
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
# File 'lib/oci/golden_gate/models/deployment.rb', line 606

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


586
587
588
# File 'lib/oci/golden_gate/models/deployment.rb', line 586

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



595
596
597
# File 'lib/oci/golden_gate/models/deployment.rb', line 595

def hash
  [id, display_name, description, compartment_id, deployment_backup_id, time_created, time_updated, lifecycle_state, lifecycle_sub_state, lifecycle_details, freeform_tags, defined_tags, is_healthy, subnet_id, fqdn, license_model, cpu_core_count, is_auto_scaling_enabled, nsg_ids, is_public, public_ip_address, private_ip_address, deployment_url, system_tags, is_latest_version, time_upgrade_required, storage_utilization_in_bytes, is_storage_utilization_limit_exceeded, deployment_type, ogg_data].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



639
640
641
642
643
644
645
646
647
648
# File 'lib/oci/golden_gate/models/deployment.rb', line 639

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



633
634
635
# File 'lib/oci/golden_gate/models/deployment.rb', line 633

def to_s
  to_hash.to_s
end