Class: OCI::GoldenGate::Models::DeploymentSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/golden_gate/models/deployment_summary.rb

Overview

Summary of the Deployment.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_NEEDS_ATTENTION = 'NEEDS_ATTENTION'.freeze,
  LIFECYCLE_STATE_IN_PROGRESS = 'IN_PROGRESS'.freeze,
  LIFECYCLE_STATE_CANCELING = 'CANCELING'.freeze,
  LIFECYCLE_STATE_CANCELED = 'CANCELED'.freeze,
  LIFECYCLE_STATE_SUCCEEDED = 'SUCCEEDED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_SUB_STATE_ENUM =
[
  LIFECYCLE_SUB_STATE_RECOVERING = 'RECOVERING'.freeze,
  LIFECYCLE_SUB_STATE_STARTING = 'STARTING'.freeze,
  LIFECYCLE_SUB_STATE_STOPPING = 'STOPPING'.freeze,
  LIFECYCLE_SUB_STATE_MOVING = 'MOVING'.freeze,
  LIFECYCLE_SUB_STATE_UPGRADING = 'UPGRADING'.freeze,
  LIFECYCLE_SUB_STATE_RESTORING = 'RESTORING'.freeze,
  LIFECYCLE_SUB_STATE_BACKUP_IN_PROGRESS = 'BACKUP_IN_PROGRESS'.freeze,
  LIFECYCLE_SUB_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LICENSE_MODEL_ENUM =
[
  LICENSE_MODEL_LICENSE_INCLUDED = 'LICENSE_INCLUDED'.freeze,
  LICENSE_MODEL_BRING_YOUR_OWN_LICENSE = 'BRING_YOUR_OWN_LICENSE'.freeze,
  LICENSE_MODEL_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
DEPLOYMENT_TYPE_ENUM =
[
  DEPLOYMENT_TYPE_OGG = 'OGG'.freeze,
  DEPLOYMENT_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DeploymentSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :display_name (String)

    The value to assign to the #display_name property

  • :description (String)

    The value to assign to the #description property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :time_updated (DateTime)

    The value to assign to the #time_updated property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :lifecycle_sub_state (String)

    The value to assign to the #lifecycle_sub_state property

  • :lifecycle_details (String)

    The value to assign to the #lifecycle_details property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property

  • :subnet_id (String)

    The value to assign to the #subnet_id property

  • :license_model (String)

    The value to assign to the #license_model property

  • :fqdn (String)

    The value to assign to the #fqdn property

  • :cpu_core_count (Integer)

    The value to assign to the #cpu_core_count property

  • :is_auto_scaling_enabled (BOOLEAN)

    The value to assign to the #is_auto_scaling_enabled property

  • :is_public (BOOLEAN)

    The value to assign to the #is_public property

  • :public_ip_address (String)

    The value to assign to the #public_ip_address property

  • :private_ip_address (String)

    The value to assign to the #private_ip_address property

  • :deployment_url (String)

    The value to assign to the #deployment_url property

  • :system_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #system_tags property

  • :is_latest_version (BOOLEAN)

    The value to assign to the #is_latest_version property

  • :time_upgrade_required (DateTime)

    The value to assign to the #time_upgrade_required property

  • :deployment_type (String)

    The value to assign to the #deployment_type property

  • :storage_utilization_in_bytes (Integer)

    The value to assign to the #storage_utilization_in_bytes property

  • :is_storage_utilization_limit_exceeded (BOOLEAN)

    The value to assign to the #is_storage_utilization_limit_exceeded property



283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
# File 'lib/oci/golden_gate/models/deployment_summary.rb', line 283

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.lifecycle_sub_state = attributes[:'lifecycleSubState'] if attributes[:'lifecycleSubState']

  raise 'You cannot provide both :lifecycleSubState and :lifecycle_sub_state' if attributes.key?(:'lifecycleSubState') && attributes.key?(:'lifecycle_sub_state')

  self.lifecycle_sub_state = attributes[:'lifecycle_sub_state'] if attributes[:'lifecycle_sub_state']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId']

  raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id')

  self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id']

  self.license_model = attributes[:'licenseModel'] if attributes[:'licenseModel']

  raise 'You cannot provide both :licenseModel and :license_model' if attributes.key?(:'licenseModel') && attributes.key?(:'license_model')

  self.license_model = attributes[:'license_model'] if attributes[:'license_model']

  self.fqdn = attributes[:'fqdn'] if attributes[:'fqdn']

  self.cpu_core_count = attributes[:'cpuCoreCount'] if attributes[:'cpuCoreCount']

  raise 'You cannot provide both :cpuCoreCount and :cpu_core_count' if attributes.key?(:'cpuCoreCount') && attributes.key?(:'cpu_core_count')

  self.cpu_core_count = attributes[:'cpu_core_count'] if attributes[:'cpu_core_count']

  self.is_auto_scaling_enabled = attributes[:'isAutoScalingEnabled'] unless attributes[:'isAutoScalingEnabled'].nil?

  raise 'You cannot provide both :isAutoScalingEnabled and :is_auto_scaling_enabled' if attributes.key?(:'isAutoScalingEnabled') && attributes.key?(:'is_auto_scaling_enabled')

  self.is_auto_scaling_enabled = attributes[:'is_auto_scaling_enabled'] unless attributes[:'is_auto_scaling_enabled'].nil?

  self.is_public = attributes[:'isPublic'] unless attributes[:'isPublic'].nil?

  raise 'You cannot provide both :isPublic and :is_public' if attributes.key?(:'isPublic') && attributes.key?(:'is_public')

  self.is_public = attributes[:'is_public'] unless attributes[:'is_public'].nil?

  self.public_ip_address = attributes[:'publicIpAddress'] if attributes[:'publicIpAddress']

  raise 'You cannot provide both :publicIpAddress and :public_ip_address' if attributes.key?(:'publicIpAddress') && attributes.key?(:'public_ip_address')

  self.public_ip_address = attributes[:'public_ip_address'] if attributes[:'public_ip_address']

  self.private_ip_address = attributes[:'privateIpAddress'] if attributes[:'privateIpAddress']

  raise 'You cannot provide both :privateIpAddress and :private_ip_address' if attributes.key?(:'privateIpAddress') && attributes.key?(:'private_ip_address')

  self.private_ip_address = attributes[:'private_ip_address'] if attributes[:'private_ip_address']

  self.deployment_url = attributes[:'deploymentUrl'] if attributes[:'deploymentUrl']

  raise 'You cannot provide both :deploymentUrl and :deployment_url' if attributes.key?(:'deploymentUrl') && attributes.key?(:'deployment_url')

  self.deployment_url = attributes[:'deployment_url'] if attributes[:'deployment_url']

  self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

  raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

  self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']

  self.is_latest_version = attributes[:'isLatestVersion'] unless attributes[:'isLatestVersion'].nil?

  raise 'You cannot provide both :isLatestVersion and :is_latest_version' if attributes.key?(:'isLatestVersion') && attributes.key?(:'is_latest_version')

  self.is_latest_version = attributes[:'is_latest_version'] unless attributes[:'is_latest_version'].nil?

  self.time_upgrade_required = attributes[:'timeUpgradeRequired'] if attributes[:'timeUpgradeRequired']

  raise 'You cannot provide both :timeUpgradeRequired and :time_upgrade_required' if attributes.key?(:'timeUpgradeRequired') && attributes.key?(:'time_upgrade_required')

  self.time_upgrade_required = attributes[:'time_upgrade_required'] if attributes[:'time_upgrade_required']

  self.deployment_type = attributes[:'deploymentType'] if attributes[:'deploymentType']

  raise 'You cannot provide both :deploymentType and :deployment_type' if attributes.key?(:'deploymentType') && attributes.key?(:'deployment_type')

  self.deployment_type = attributes[:'deployment_type'] if attributes[:'deployment_type']

  self.storage_utilization_in_bytes = attributes[:'storageUtilizationInBytes'] if attributes[:'storageUtilizationInBytes']

  raise 'You cannot provide both :storageUtilizationInBytes and :storage_utilization_in_bytes' if attributes.key?(:'storageUtilizationInBytes') && attributes.key?(:'storage_utilization_in_bytes')

  self.storage_utilization_in_bytes = attributes[:'storage_utilization_in_bytes'] if attributes[:'storage_utilization_in_bytes']

  self.is_storage_utilization_limit_exceeded = attributes[:'isStorageUtilizationLimitExceeded'] unless attributes[:'isStorageUtilizationLimitExceeded'].nil?

  raise 'You cannot provide both :isStorageUtilizationLimitExceeded and :is_storage_utilization_limit_exceeded' if attributes.key?(:'isStorageUtilizationLimitExceeded') && attributes.key?(:'is_storage_utilization_limit_exceeded')

  self.is_storage_utilization_limit_exceeded = attributes[:'is_storage_utilization_limit_exceeded'] unless attributes[:'is_storage_utilization_limit_exceeded'].nil?
end

Instance Attribute Details

#compartment_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment being referenced.

Returns:

  • (String)


68
69
70
# File 'lib/oci/golden_gate/models/deployment_summary.rb', line 68

def compartment_id
  @compartment_id
end

#cpu_core_countInteger

The Minimum number of OCPUs to be made available for this Deployment.

Returns:

  • (Integer)


125
126
127
# File 'lib/oci/golden_gate/models/deployment_summary.rb', line 125

def cpu_core_count
  @cpu_core_count
end

#defined_tagsHash<String, Hash<String, Object>>

Tags defined for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


105
106
107
# File 'lib/oci/golden_gate/models/deployment_summary.rb', line 105

def defined_tags
  @defined_tags
end

#deployment_typeString

The deployment type.

Returns:

  • (String)


171
172
173
# File 'lib/oci/golden_gate/models/deployment_summary.rb', line 171

def deployment_type
  @deployment_type
end

#deployment_urlString

The URL of a resource.

Returns:

  • (String)


150
151
152
# File 'lib/oci/golden_gate/models/deployment_summary.rb', line 150

def deployment_url
  @deployment_url
end

#descriptionString

Metadata about this specific object.

Returns:

  • (String)


63
64
65
# File 'lib/oci/golden_gate/models/deployment_summary.rb', line 63

def description
  @description
end

#display_nameString

An object's Display Name.

Returns:

  • (String)


58
59
60
# File 'lib/oci/golden_gate/models/deployment_summary.rb', line 58

def display_name
  @display_name
end

#fqdnString

A three-label Fully Qualified Domain Name (FQDN) for a resource.

Returns:

  • (String)


120
121
122
# File 'lib/oci/golden_gate/models/deployment_summary.rb', line 120

def fqdn
  @fqdn
end

#freeform_tagsHash<String, String>

A simple key-value pair that is applied without any predefined name, type, or scope. Exists for cross-compatibility only. Example: `"value"`

Returns:

  • (Hash<String, String>)


99
100
101
# File 'lib/oci/golden_gate/models/deployment_summary.rb', line 99

def freeform_tags
  @freeform_tags
end

#idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the deployment being referenced.

Returns:

  • (String)


53
54
55
# File 'lib/oci/golden_gate/models/deployment_summary.rb', line 53

def id
  @id
end

#is_auto_scaling_enabledBOOLEAN

Indicates if auto scaling is enabled for the Deployment's CPU core count.

Returns:

  • (BOOLEAN)


130
131
132
# File 'lib/oci/golden_gate/models/deployment_summary.rb', line 130

def is_auto_scaling_enabled
  @is_auto_scaling_enabled
end

#is_latest_versionBOOLEAN

Indicates if the resource is the the latest available version.

Returns:

  • (BOOLEAN)


161
162
163
# File 'lib/oci/golden_gate/models/deployment_summary.rb', line 161

def is_latest_version
  @is_latest_version
end

#is_publicBOOLEAN

True if this object is publicly available.

Returns:

  • (BOOLEAN)


135
136
137
# File 'lib/oci/golden_gate/models/deployment_summary.rb', line 135

def is_public
  @is_public
end

#is_storage_utilization_limit_exceededBOOLEAN

Indicator will be true if the amount of storage being utilized exceeds the allowable storage utilization limit. Exceeding the limit may be an indication of a misconfiguration of the deployment's GoldenGate service.

Returns:

  • (BOOLEAN)


181
182
183
# File 'lib/oci/golden_gate/models/deployment_summary.rb', line 181

def is_storage_utilization_limit_exceeded
  @is_storage_utilization_limit_exceeded
end

#license_modelString

**[Required]** The Oracle license model that applies to a Deployment.

Returns:

  • (String)


115
116
117
# File 'lib/oci/golden_gate/models/deployment_summary.rb', line 115

def license_model
  @license_model
end

#lifecycle_detailsString

Describes the object's current state in detail. For example, it can be used to provide actionable information for a resource in a Failed state.

Returns:

  • (String)


93
94
95
# File 'lib/oci/golden_gate/models/deployment_summary.rb', line 93

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

Possible lifecycle states.

Returns:

  • (String)


83
84
85
# File 'lib/oci/golden_gate/models/deployment_summary.rb', line 83

def lifecycle_state
  @lifecycle_state
end

#lifecycle_sub_stateString

Possible GGS lifecycle sub-states.

Returns:

  • (String)


88
89
90
# File 'lib/oci/golden_gate/models/deployment_summary.rb', line 88

def lifecycle_sub_state
  @lifecycle_sub_state
end

#private_ip_addressString

The private IP address in the customer's VCN representing the access point for the associated endpoint service in the GoldenGate service VCN.

Returns:

  • (String)


145
146
147
# File 'lib/oci/golden_gate/models/deployment_summary.rb', line 145

def private_ip_address
  @private_ip_address
end

#public_ip_addressString

The public IP address representing the access point for the Deployment.

Returns:

  • (String)


140
141
142
# File 'lib/oci/golden_gate/models/deployment_summary.rb', line 140

def public_ip_address
  @public_ip_address
end

#storage_utilization_in_bytesInteger

The amount of storage being utilized (in bytes)

Returns:

  • (Integer)


176
177
178
# File 'lib/oci/golden_gate/models/deployment_summary.rb', line 176

def storage_utilization_in_bytes
  @storage_utilization_in_bytes
end

#subnet_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the subnet being referenced.

Returns:

  • (String)


110
111
112
# File 'lib/oci/golden_gate/models/deployment_summary.rb', line 110

def subnet_id
  @subnet_id
end

#system_tagsHash<String, Hash<String, Object>>

The system tags associated with this resource, if any. The system tags are set by Oracle Cloud Infrastructure services. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{free-tier-retain: true}`

Returns:

  • (Hash<String, Hash<String, Object>>)


156
157
158
# File 'lib/oci/golden_gate/models/deployment_summary.rb', line 156

def system_tags
  @system_tags
end

#time_createdDateTime

The time the resource was created. The format is defined by [RFC3339](tools.ietf.org/html/rfc3339), such as `2016-08-25T21:10:29.600Z`.

Returns:

  • (DateTime)


73
74
75
# File 'lib/oci/golden_gate/models/deployment_summary.rb', line 73

def time_created
  @time_created
end

#time_updatedDateTime

The time the resource was last updated. The format is defined by [RFC3339](tools.ietf.org/html/rfc3339), such as `2016-08-25T21:10:29.600Z`.

Returns:

  • (DateTime)


78
79
80
# File 'lib/oci/golden_gate/models/deployment_summary.rb', line 78

def time_updated
  @time_updated
end

#time_upgrade_requiredDateTime

The date the existing version in use will no longer be considered as usable and an upgrade will be required. This date is typically 6 months after the version was released for use by GGS. The format is defined by [RFC3339](tools.ietf.org/html/rfc3339), such as `2016-08-25T21:10:29.600Z`.

Returns:

  • (DateTime)


166
167
168
# File 'lib/oci/golden_gate/models/deployment_summary.rb', line 166

def time_upgrade_required
  @time_upgrade_required
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/oci/golden_gate/models/deployment_summary.rb', line 184

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'display_name': :'displayName',
    'description': :'description',
    'compartment_id': :'compartmentId',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_sub_state': :'lifecycleSubState',
    'lifecycle_details': :'lifecycleDetails',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'subnet_id': :'subnetId',
    'license_model': :'licenseModel',
    'fqdn': :'fqdn',
    'cpu_core_count': :'cpuCoreCount',
    'is_auto_scaling_enabled': :'isAutoScalingEnabled',
    'is_public': :'isPublic',
    'public_ip_address': :'publicIpAddress',
    'private_ip_address': :'privateIpAddress',
    'deployment_url': :'deploymentUrl',
    'system_tags': :'systemTags',
    'is_latest_version': :'isLatestVersion',
    'time_upgrade_required': :'timeUpgradeRequired',
    'deployment_type': :'deploymentType',
    'storage_utilization_in_bytes': :'storageUtilizationInBytes',
    'is_storage_utilization_limit_exceeded': :'isStorageUtilizationLimitExceeded'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/oci/golden_gate/models/deployment_summary.rb', line 218

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'display_name': :'String',
    'description': :'String',
    'compartment_id': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'lifecycle_state': :'String',
    'lifecycle_sub_state': :'String',
    'lifecycle_details': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'subnet_id': :'String',
    'license_model': :'String',
    'fqdn': :'String',
    'cpu_core_count': :'Integer',
    'is_auto_scaling_enabled': :'BOOLEAN',
    'is_public': :'BOOLEAN',
    'public_ip_address': :'String',
    'private_ip_address': :'String',
    'deployment_url': :'String',
    'system_tags': :'Hash<String, Hash<String, Object>>',
    'is_latest_version': :'BOOLEAN',
    'time_upgrade_required': :'DateTime',
    'deployment_type': :'String',
    'storage_utilization_in_bytes': :'Integer',
    'is_storage_utilization_limit_exceeded': :'BOOLEAN'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
# File 'lib/oci/golden_gate/models/deployment_summary.rb', line 493

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    display_name == other.display_name &&
    description == other.description &&
    compartment_id == other.compartment_id &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_sub_state == other.lifecycle_sub_state &&
    lifecycle_details == other.lifecycle_details &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    subnet_id == other.subnet_id &&
    license_model == other.license_model &&
    fqdn == other.fqdn &&
    cpu_core_count == other.cpu_core_count &&
    is_auto_scaling_enabled == other.is_auto_scaling_enabled &&
    is_public == other.is_public &&
    public_ip_address == other.public_ip_address &&
    private_ip_address == other.private_ip_address &&
    deployment_url == other.deployment_url &&
    system_tags == other.system_tags &&
    is_latest_version == other.is_latest_version &&
    time_upgrade_required == other.time_upgrade_required &&
    deployment_type == other.deployment_type &&
    storage_utilization_in_bytes == other.storage_utilization_in_bytes &&
    is_storage_utilization_limit_exceeded == other.is_storage_utilization_limit_exceeded
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
# File 'lib/oci/golden_gate/models/deployment_summary.rb', line 548

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


528
529
530
# File 'lib/oci/golden_gate/models/deployment_summary.rb', line 528

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



537
538
539
# File 'lib/oci/golden_gate/models/deployment_summary.rb', line 537

def hash
  [id, display_name, description, compartment_id, time_created, time_updated, lifecycle_state, lifecycle_sub_state, lifecycle_details, freeform_tags, defined_tags, subnet_id, license_model, fqdn, cpu_core_count, is_auto_scaling_enabled, is_public, public_ip_address, private_ip_address, deployment_url, system_tags, is_latest_version, time_upgrade_required, deployment_type, storage_utilization_in_bytes, is_storage_utilization_limit_exceeded].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



581
582
583
584
585
586
587
588
589
590
# File 'lib/oci/golden_gate/models/deployment_summary.rb', line 581

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



575
576
577
# File 'lib/oci/golden_gate/models/deployment_summary.rb', line 575

def to_s
  to_hash.to_s
end