Class: OCI::GoldenGate::Models::UpdateDeploymentDetails
- Inherits:
-
Object
- Object
- OCI::GoldenGate::Models::UpdateDeploymentDetails
- Defined in:
- lib/oci/golden_gate/models/update_deployment_details.rb
Overview
The information to use to update a Deployment.
Constant Summary collapse
- LICENSE_MODEL_ENUM =
[ LICENSE_MODEL_LICENSE_INCLUDED = 'LICENSE_INCLUDED'.freeze, LICENSE_MODEL_BRING_YOUR_OWN_LICENSE = 'BRING_YOUR_OWN_LICENSE'.freeze ].freeze
Instance Attribute Summary collapse
-
#cpu_core_count ⇒ Integer
The Minimum number of OCPUs to be made available for this Deployment.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Tags defined for this resource.
-
#description ⇒ String
Metadata about this specific object.
-
#display_name ⇒ String
An object’s Display Name.
-
#fqdn ⇒ String
A three-label Fully Qualified Domain Name (FQDN) for a resource.
-
#freeform_tags ⇒ Hash<String, String>
A simple key-value pair that is applied without any predefined name, type, or scope.
-
#is_auto_scaling_enabled ⇒ BOOLEAN
Indicates if auto scaling is enabled for the Deployment’s CPU core count.
-
#is_public ⇒ BOOLEAN
True if this object is publicly available.
-
#license_model ⇒ String
The Oracle license model that applies to a Deployment.
-
#nsg_ids ⇒ Array<String>
An array of [Network Security Group](docs.cloud.oracle.com/Content/Network/Concepts/networksecuritygroups.htm) OCIDs used to define network access for a deployment.
- #ogg_data ⇒ OCI::GoldenGate::Models::UpdateOggDeploymentDetails
-
#subnet_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the subnet being referenced.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateDeploymentDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateDeploymentDetails
Initializes the object
134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/oci/golden_gate/models/update_deployment_details.rb', line 134 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.license_model = attributes[:'licenseModel'] if attributes[:'licenseModel'] raise 'You cannot provide both :licenseModel and :license_model' if attributes.key?(:'licenseModel') && attributes.key?(:'license_model') self.license_model = attributes[:'license_model'] if attributes[:'license_model'] self.description = attributes[:'description'] if attributes[:'description'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.nsg_ids = attributes[:'nsgIds'] if attributes[:'nsgIds'] raise 'You cannot provide both :nsgIds and :nsg_ids' if attributes.key?(:'nsgIds') && attributes.key?(:'nsg_ids') self.nsg_ids = attributes[:'nsg_ids'] if attributes[:'nsg_ids'] self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId'] raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id') self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id'] self.is_public = attributes[:'isPublic'] unless attributes[:'isPublic'].nil? raise 'You cannot provide both :isPublic and :is_public' if attributes.key?(:'isPublic') && attributes.key?(:'is_public') self.is_public = attributes[:'is_public'] unless attributes[:'is_public'].nil? self.fqdn = attributes[:'fqdn'] if attributes[:'fqdn'] self.cpu_core_count = attributes[:'cpuCoreCount'] if attributes[:'cpuCoreCount'] raise 'You cannot provide both :cpuCoreCount and :cpu_core_count' if attributes.key?(:'cpuCoreCount') && attributes.key?(:'cpu_core_count') self.cpu_core_count = attributes[:'cpu_core_count'] if attributes[:'cpu_core_count'] self.is_auto_scaling_enabled = attributes[:'isAutoScalingEnabled'] unless attributes[:'isAutoScalingEnabled'].nil? raise 'You cannot provide both :isAutoScalingEnabled and :is_auto_scaling_enabled' if attributes.key?(:'isAutoScalingEnabled') && attributes.key?(:'is_auto_scaling_enabled') self.is_auto_scaling_enabled = attributes[:'is_auto_scaling_enabled'] unless attributes[:'is_auto_scaling_enabled'].nil? self.ogg_data = attributes[:'oggData'] if attributes[:'oggData'] raise 'You cannot provide both :oggData and :ogg_data' if attributes.key?(:'oggData') && attributes.key?(:'ogg_data') self.ogg_data = attributes[:'ogg_data'] if attributes[:'ogg_data'] end |
Instance Attribute Details
#cpu_core_count ⇒ Integer
The Minimum number of OCPUs to be made available for this Deployment.
66 67 68 |
# File 'lib/oci/golden_gate/models/update_deployment_details.rb', line 66 def cpu_core_count @cpu_core_count end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Tags defined for this resource. Each key is predefined and scoped to a namespace. Example: ‘{\“bar-key\”: \“value\”}`
41 42 43 |
# File 'lib/oci/golden_gate/models/update_deployment_details.rb', line 41 def end |
#description ⇒ String
Metadata about this specific object.
29 30 31 |
# File 'lib/oci/golden_gate/models/update_deployment_details.rb', line 29 def description @description end |
#display_name ⇒ String
An object’s Display Name.
19 20 21 |
# File 'lib/oci/golden_gate/models/update_deployment_details.rb', line 19 def display_name @display_name end |
#fqdn ⇒ String
A three-label Fully Qualified Domain Name (FQDN) for a resource.
61 62 63 |
# File 'lib/oci/golden_gate/models/update_deployment_details.rb', line 61 def fqdn @fqdn end |
#freeform_tags ⇒ Hash<String, String>
A simple key-value pair that is applied without any predefined name, type, or scope. Exists for cross-compatibility only. Example: ‘\“value\”`
35 36 37 |
# File 'lib/oci/golden_gate/models/update_deployment_details.rb', line 35 def end |
#is_auto_scaling_enabled ⇒ BOOLEAN
Indicates if auto scaling is enabled for the Deployment’s CPU core count.
71 72 73 |
# File 'lib/oci/golden_gate/models/update_deployment_details.rb', line 71 def is_auto_scaling_enabled @is_auto_scaling_enabled end |
#is_public ⇒ BOOLEAN
True if this object is publicly available.
56 57 58 |
# File 'lib/oci/golden_gate/models/update_deployment_details.rb', line 56 def is_public @is_public end |
#license_model ⇒ String
The Oracle license model that applies to a Deployment.
24 25 26 |
# File 'lib/oci/golden_gate/models/update_deployment_details.rb', line 24 def license_model @license_model end |
#nsg_ids ⇒ Array<String>
An array of [Network Security Group](docs.cloud.oracle.com/Content/Network/Concepts/networksecuritygroups.htm) OCIDs used to define network access for a deployment.
46 47 48 |
# File 'lib/oci/golden_gate/models/update_deployment_details.rb', line 46 def nsg_ids @nsg_ids end |
#ogg_data ⇒ OCI::GoldenGate::Models::UpdateOggDeploymentDetails
74 75 76 |
# File 'lib/oci/golden_gate/models/update_deployment_details.rb', line 74 def ogg_data @ogg_data end |
#subnet_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the subnet being referenced.
51 52 53 |
# File 'lib/oci/golden_gate/models/update_deployment_details.rb', line 51 def subnet_id @subnet_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/oci/golden_gate/models/update_deployment_details.rb', line 77 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'license_model': :'licenseModel', 'description': :'description', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'nsg_ids': :'nsgIds', 'subnet_id': :'subnetId', 'is_public': :'isPublic', 'fqdn': :'fqdn', 'cpu_core_count': :'cpuCoreCount', 'is_auto_scaling_enabled': :'isAutoScalingEnabled', 'ogg_data': :'oggData' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/oci/golden_gate/models/update_deployment_details.rb', line 97 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'license_model': :'String', 'description': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'nsg_ids': :'Array<String>', 'subnet_id': :'String', 'is_public': :'BOOLEAN', 'fqdn': :'String', 'cpu_core_count': :'Integer', 'is_auto_scaling_enabled': :'BOOLEAN', 'ogg_data': :'OCI::GoldenGate::Models::UpdateOggDeploymentDetails' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/oci/golden_gate/models/update_deployment_details.rb', line 220 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && license_model == other.license_model && description == other.description && == other. && == other. && nsg_ids == other.nsg_ids && subnet_id == other.subnet_id && is_public == other.is_public && fqdn == other.fqdn && cpu_core_count == other.cpu_core_count && is_auto_scaling_enabled == other.is_auto_scaling_enabled && ogg_data == other.ogg_data end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 |
# File 'lib/oci/golden_gate/models/update_deployment_details.rb', line 261 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
241 242 243 |
# File 'lib/oci/golden_gate/models/update_deployment_details.rb', line 241 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
250 251 252 |
# File 'lib/oci/golden_gate/models/update_deployment_details.rb', line 250 def hash [display_name, license_model, description, , , nsg_ids, subnet_id, is_public, fqdn, cpu_core_count, is_auto_scaling_enabled, ogg_data].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
294 295 296 297 298 299 300 301 302 303 |
# File 'lib/oci/golden_gate/models/update_deployment_details.rb', line 294 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
288 289 290 |
# File 'lib/oci/golden_gate/models/update_deployment_details.rb', line 288 def to_s to_hash.to_s end |