Class: OCI::GoldenGate::Models::UpdateOggDeploymentDetails
- Inherits:
-
Object
- Object
- OCI::GoldenGate::Models::UpdateOggDeploymentDetails
- Defined in:
- lib/oci/golden_gate/models/update_ogg_deployment_details.rb
Overview
Deployment Details for updating an OggDeployment
Instance Attribute Summary collapse
-
#admin_password ⇒ String
The password associated with the GoldenGate deployment console username.
-
#admin_username ⇒ String
The GoldenGate deployment console username.
-
#certificate ⇒ String
A PEM-encoded SSL certificate.
-
#key ⇒ String
A PEM-encoded private key.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateOggDeploymentDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateOggDeploymentDetails
Initializes the object
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/oci/golden_gate/models/update_ogg_deployment_details.rb', line 65 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.admin_username = attributes[:'adminUsername'] if attributes[:'adminUsername'] raise 'You cannot provide both :adminUsername and :admin_username' if attributes.key?(:'adminUsername') && attributes.key?(:'admin_username') self.admin_username = attributes[:'admin_username'] if attributes[:'admin_username'] self.admin_password = attributes[:'adminPassword'] if attributes[:'adminPassword'] raise 'You cannot provide both :adminPassword and :admin_password' if attributes.key?(:'adminPassword') && attributes.key?(:'admin_password') self.admin_password = attributes[:'admin_password'] if attributes[:'admin_password'] self.certificate = attributes[:'certificate'] if attributes[:'certificate'] self.key = attributes[:'key'] if attributes[:'key'] end |
Instance Attribute Details
#admin_password ⇒ String
The password associated with the GoldenGate deployment console username. The password must be 8 to 30 characters long and must contain at least 1 uppercase, 1 lowercase, 1 numeric, and 1 special character. Special characters such as u2018$u2019, u2018^u2019, or u2018?u2019 are not allowed.
19 20 21 |
# File 'lib/oci/golden_gate/models/update_ogg_deployment_details.rb', line 19 def admin_password @admin_password end |
#admin_username ⇒ String
The GoldenGate deployment console username.
14 15 16 |
# File 'lib/oci/golden_gate/models/update_ogg_deployment_details.rb', line 14 def admin_username @admin_username end |
#certificate ⇒ String
A PEM-encoded SSL certificate.
24 25 26 |
# File 'lib/oci/golden_gate/models/update_ogg_deployment_details.rb', line 24 def certificate @certificate end |
#key ⇒ String
A PEM-encoded private key.
29 30 31 |
# File 'lib/oci/golden_gate/models/update_ogg_deployment_details.rb', line 29 def key @key end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 40 41 |
# File 'lib/oci/golden_gate/models/update_ogg_deployment_details.rb', line 32 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'admin_username': :'adminUsername', 'admin_password': :'adminPassword', 'certificate': :'certificate', 'key': :'key' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
44 45 46 47 48 49 50 51 52 53 |
# File 'lib/oci/golden_gate/models/update_ogg_deployment_details.rb', line 44 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'admin_username': :'String', 'admin_password': :'String', 'certificate': :'String', 'key': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
95 96 97 98 99 100 101 102 103 |
# File 'lib/oci/golden_gate/models/update_ogg_deployment_details.rb', line 95 def ==(other) return true if equal?(other) self.class == other.class && admin_username == other.admin_username && admin_password == other.admin_password && certificate == other.certificate && key == other.key end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/oci/golden_gate/models/update_ogg_deployment_details.rb', line 128 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
108 109 110 |
# File 'lib/oci/golden_gate/models/update_ogg_deployment_details.rb', line 108 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
117 118 119 |
# File 'lib/oci/golden_gate/models/update_ogg_deployment_details.rb', line 117 def hash [admin_username, admin_password, certificate, key].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
161 162 163 164 165 166 167 168 169 170 |
# File 'lib/oci/golden_gate/models/update_ogg_deployment_details.rb', line 161 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
155 156 157 |
# File 'lib/oci/golden_gate/models/update_ogg_deployment_details.rb', line 155 def to_s to_hash.to_s end |