Class: OCI::GovernanceRulesControlPlane::Models::CreateGovernanceRuleDetails
- Inherits:
-
Object
- Object
- OCI::GovernanceRulesControlPlane::Models::CreateGovernanceRuleDetails
- Defined in:
- lib/oci/governance_rules_control_plane/models/create_governance_rule_details.rb
Overview
Request object for CreateGovernanceRule operation.
Constant Summary collapse
- TYPE_ENUM =
[ TYPE_QUOTA = 'QUOTA'.freeze, TYPE_TAG = 'TAG'.freeze, TYPE_ALLOWED_REGIONS = 'ALLOWED_REGIONS'.freeze ].freeze
- CREATION_OPTION_ENUM =
[ CREATION_OPTION_TEMPLATE = 'TEMPLATE'.freeze, CREATION_OPTION_CLONE = 'CLONE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The Oracle ID ([OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the root compartment containing the governance rule.
-
#creation_option ⇒ String
**[Required]** The type of option used to create the governance rule, could be one of TEMPLATE or CLONE.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
Description of the governance rule.
-
#display_name ⇒ String
**[Required]** Display name of the governance rule.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#related_resource_id ⇒ String
The Oracle ID ([OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the resource, which was used as a template to create this governance rule.
-
#template ⇒ OCI::GovernanceRulesControlPlane::Models::Template
This attribute is required.
-
#type ⇒ String
**[Required]** Type of the governance rule, can be one of QUOTA, TAG, ALLOWED_REGIONS.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateGovernanceRuleDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateGovernanceRuleDetails
Initializes the object
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/oci/governance_rules_control_plane/models/create_governance_rule_details.rb', line 116 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.type = attributes[:'type'] if attributes[:'type'] self.creation_option = attributes[:'creationOption'] if attributes[:'creationOption'] raise 'You cannot provide both :creationOption and :creation_option' if attributes.key?(:'creationOption') && attributes.key?(:'creation_option') self.creation_option = attributes[:'creation_option'] if attributes[:'creation_option'] self.template = attributes[:'template'] if attributes[:'template'] self. = attributes[:'relatedResourceId'] if attributes[:'relatedResourceId'] raise 'You cannot provide both :relatedResourceId and :related_resource_id' if attributes.key?(:'relatedResourceId') && attributes.key?(:'related_resource_id') self. = attributes[:'related_resource_id'] if attributes[:'related_resource_id'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The Oracle ID ([OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the root compartment containing the governance rule.
23 24 25 |
# File 'lib/oci/governance_rules_control_plane/models/create_governance_rule_details.rb', line 23 def compartment_id @compartment_id end |
#creation_option ⇒ String
**[Required]** The type of option used to create the governance rule, could be one of TEMPLATE or CLONE.
Example: `TEMPLATE`
45 46 47 |
# File 'lib/oci/governance_rules_control_plane/models/create_governance_rule_details.rb', line 45 def creation_option @creation_option end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
65 66 67 |
# File 'lib/oci/governance_rules_control_plane/models/create_governance_rule_details.rb', line 65 def @defined_tags end |
#description ⇒ String
Description of the governance rule.
31 32 33 |
# File 'lib/oci/governance_rules_control_plane/models/create_governance_rule_details.rb', line 31 def description @description end |
#display_name ⇒ String
**[Required]** Display name of the governance rule.
27 28 29 |
# File 'lib/oci/governance_rules_control_plane/models/create_governance_rule_details.rb', line 27 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
59 60 61 |
# File 'lib/oci/governance_rules_control_plane/models/create_governance_rule_details.rb', line 59 def @freeform_tags end |
#related_resource_id ⇒ String
The Oracle ID ([OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the resource, which was used as a template to create this governance rule.
53 54 55 |
# File 'lib/oci/governance_rules_control_plane/models/create_governance_rule_details.rb', line 53 def @related_resource_id end |
#template ⇒ OCI::GovernanceRulesControlPlane::Models::Template
This attribute is required.
49 50 51 |
# File 'lib/oci/governance_rules_control_plane/models/create_governance_rule_details.rb', line 49 def template @template end |
#type ⇒ String
**[Required]** Type of the governance rule, can be one of QUOTA, TAG, ALLOWED_REGIONS.
Example: `QUOTA`
38 39 40 |
# File 'lib/oci/governance_rules_control_plane/models/create_governance_rule_details.rb', line 38 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/oci/governance_rules_control_plane/models/create_governance_rule_details.rb', line 68 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'description': :'description', 'type': :'type', 'creation_option': :'creationOption', 'template': :'template', 'related_resource_id': :'relatedResourceId', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/oci/governance_rules_control_plane/models/create_governance_rule_details.rb', line 85 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'display_name': :'String', 'description': :'String', 'type': :'String', 'creation_option': :'String', 'template': :'OCI::GovernanceRulesControlPlane::Models::Template', 'related_resource_id': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/oci/governance_rules_control_plane/models/create_governance_rule_details.rb', line 188 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && display_name == other.display_name && description == other.description && type == other.type && creation_option == other.creation_option && template == other.template && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/oci/governance_rules_control_plane/models/create_governance_rule_details.rb', line 226 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
206 207 208 |
# File 'lib/oci/governance_rules_control_plane/models/create_governance_rule_details.rb', line 206 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
215 216 217 |
# File 'lib/oci/governance_rules_control_plane/models/create_governance_rule_details.rb', line 215 def hash [compartment_id, display_name, description, type, creation_option, template, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
259 260 261 262 263 264 265 266 267 268 |
# File 'lib/oci/governance_rules_control_plane/models/create_governance_rule_details.rb', line 259 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
253 254 255 |
# File 'lib/oci/governance_rules_control_plane/models/create_governance_rule_details.rb', line 253 def to_s to_hash.to_s end |