Class: OCI::GovernanceRulesControlPlane::Models::EnforcedGovernanceRule

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/governance_rules_control_plane/models/enforced_governance_rule.rb

Overview

Represents the governance rule shown to the child which is a subset of governance rule resource in parent tenancy.

Constant Summary collapse

TYPE_ENUM =
[
  TYPE_QUOTA = 'QUOTA'.freeze,
  TYPE_TAG = 'TAG'.freeze,
  TYPE_ALLOWED_REGIONS = 'ALLOWED_REGIONS'.freeze,
  TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ EnforcedGovernanceRule

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :governance_rule_display_name (String)

    The value to assign to the #governance_rule_display_name property

  • :type (String)

    The value to assign to the #type property

  • :template (OCI::GovernanceRulesControlPlane::Models::Template)

    The value to assign to the #template property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :time_updated (DateTime)

    The value to assign to the #time_updated property



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/oci/governance_rules_control_plane/models/enforced_governance_rule.rb', line 111

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.governance_rule_display_name = attributes[:'governanceRuleDisplayName'] if attributes[:'governanceRuleDisplayName']

  raise 'You cannot provide both :governanceRuleDisplayName and :governance_rule_display_name' if attributes.key?(:'governanceRuleDisplayName') && attributes.key?(:'governance_rule_display_name')

  self.governance_rule_display_name = attributes[:'governance_rule_display_name'] if attributes[:'governance_rule_display_name']

  self.type = attributes[:'type'] if attributes[:'type']

  self.template = attributes[:'template'] if attributes[:'template']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']
end

Instance Attribute Details

#compartment_idString

**[Required]** The Oracle ID ([OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the child's root compartment to which the governance rule is attached.

Returns:

  • (String)


30
31
32
# File 'lib/oci/governance_rules_control_plane/models/enforced_governance_rule.rb', line 30

def compartment_id
  @compartment_id
end

#governance_rule_display_nameString

**[Required]** Display name of the governance rule.

Returns:

  • (String)


34
35
36
# File 'lib/oci/governance_rules_control_plane/models/enforced_governance_rule.rb', line 34

def governance_rule_display_name
  @governance_rule_display_name
end

#idString

**[Required]** The Oracle ID ([OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the enforced governance rule.

Returns:

  • (String)


26
27
28
# File 'lib/oci/governance_rules_control_plane/models/enforced_governance_rule.rb', line 26

def id
  @id
end

#lifecycle_stateString

**[Required]** The current state of the governance rule.

Returns:

  • (String)


49
50
51
# File 'lib/oci/governance_rules_control_plane/models/enforced_governance_rule.rb', line 49

def lifecycle_state
  @lifecycle_state
end

#templateOCI::GovernanceRulesControlPlane::Models::Template

This attribute is required.

Returns:

  • (OCI::GovernanceRulesControlPlane::Models::Template)


45
46
47
# File 'lib/oci/governance_rules_control_plane/models/enforced_governance_rule.rb', line 45

def template
  @template
end

#time_createdDateTime

**[Required]** Date and time the governance rule was created. An RFC3339 formatted datetime string.

Example: `2016-08-25T21:10:29.600Z`

Returns:

  • (DateTime)


56
57
58
# File 'lib/oci/governance_rules_control_plane/models/enforced_governance_rule.rb', line 56

def time_created
  @time_created
end

#time_updatedDateTime

**[Required]** Date and time the governance rule was updated. An RFC3339 formatted datetime string.

Example: `2016-08-25T21:10:29.600Z`

Returns:

  • (DateTime)


63
64
65
# File 'lib/oci/governance_rules_control_plane/models/enforced_governance_rule.rb', line 63

def time_updated
  @time_updated
end

#typeString

**[Required]** Type of the governance rule, can be one of QUOTA, TAG, ALLOWED_REGIONS.

Example: `QUOTA`

Returns:

  • (String)


41
42
43
# File 'lib/oci/governance_rules_control_plane/models/enforced_governance_rule.rb', line 41

def type
  @type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/oci/governance_rules_control_plane/models/enforced_governance_rule.rb', line 66

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'compartment_id': :'compartmentId',
    'governance_rule_display_name': :'governanceRuleDisplayName',
    'type': :'type',
    'template': :'template',
    'lifecycle_state': :'lifecycleState',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/oci/governance_rules_control_plane/models/enforced_governance_rule.rb', line 82

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'compartment_id': :'String',
    'governance_rule_display_name': :'String',
    'type': :'String',
    'template': :'OCI::GovernanceRulesControlPlane::Models::Template',
    'lifecycle_state': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/oci/governance_rules_control_plane/models/enforced_governance_rule.rb', line 187

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    governance_rule_display_name == other.governance_rule_display_name &&
    type == other.type &&
    template == other.template &&
    lifecycle_state == other.lifecycle_state &&
    time_created == other.time_created &&
    time_updated == other.time_updated
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
# File 'lib/oci/governance_rules_control_plane/models/enforced_governance_rule.rb', line 224

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


204
205
206
# File 'lib/oci/governance_rules_control_plane/models/enforced_governance_rule.rb', line 204

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



213
214
215
# File 'lib/oci/governance_rules_control_plane/models/enforced_governance_rule.rb', line 213

def hash
  [id, compartment_id, governance_rule_display_name, type, template, lifecycle_state, time_created, time_updated].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



257
258
259
260
261
262
263
264
265
266
# File 'lib/oci/governance_rules_control_plane/models/enforced_governance_rule.rb', line 257

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



251
252
253
# File 'lib/oci/governance_rules_control_plane/models/enforced_governance_rule.rb', line 251

def to_s
  to_hash.to_s
end