Class: OCI::GovernanceRulesControlPlane::Models::EnforcedGovernanceRuleSummary
- Inherits:
-
Object
- Object
- OCI::GovernanceRulesControlPlane::Models::EnforcedGovernanceRuleSummary
- Defined in:
- lib/oci/governance_rules_control_plane/models/enforced_governance_rule_summary.rb
Overview
A summary of the enforced governance rule.
Constant Summary collapse
- TYPE_ENUM =
[ TYPE_QUOTA = 'QUOTA'.freeze, TYPE_TAG = 'TAG'.freeze, TYPE_ALLOWED_REGIONS = 'ALLOWED_REGIONS'.freeze, TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The Oracle ID ([OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the child's root compartment to which the governance rule is attached.
-
#governance_rule_display_name ⇒ String
**[Required]** Display name of the governance rule.
-
#id ⇒ String
**[Required]** The Oracle ID ([OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the enforced governance rule.
-
#lifecycle_state ⇒ String
**[Required]** The current state of the governance rule.
-
#time_created ⇒ DateTime
**[Required]** Date and time the governance rule was created.
-
#time_updated ⇒ DateTime
**[Required]** Date and time the governance rule was updated.
-
#type ⇒ String
**[Required]** Type of the governance rule, can be one of QUOTA, TAG, ALLOWED_REGIONS.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EnforcedGovernanceRuleSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ EnforcedGovernanceRuleSummary
Initializes the object
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/oci/governance_rules_control_plane/models/enforced_governance_rule_summary.rb', line 104 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.governance_rule_display_name = attributes[:'governanceRuleDisplayName'] if attributes[:'governanceRuleDisplayName'] raise 'You cannot provide both :governanceRuleDisplayName and :governance_rule_display_name' if attributes.key?(:'governanceRuleDisplayName') && attributes.key?(:'governance_rule_display_name') self.governance_rule_display_name = attributes[:'governance_rule_display_name'] if attributes[:'governance_rule_display_name'] self.type = attributes[:'type'] if attributes[:'type'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The Oracle ID ([OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the child's root compartment to which the governance rule is attached.
30 31 32 |
# File 'lib/oci/governance_rules_control_plane/models/enforced_governance_rule_summary.rb', line 30 def compartment_id @compartment_id end |
#governance_rule_display_name ⇒ String
**[Required]** Display name of the governance rule.
34 35 36 |
# File 'lib/oci/governance_rules_control_plane/models/enforced_governance_rule_summary.rb', line 34 def governance_rule_display_name @governance_rule_display_name end |
#id ⇒ String
**[Required]** The Oracle ID ([OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the enforced governance rule.
26 27 28 |
# File 'lib/oci/governance_rules_control_plane/models/enforced_governance_rule_summary.rb', line 26 def id @id end |
#lifecycle_state ⇒ String
**[Required]** The current state of the governance rule.
45 46 47 |
# File 'lib/oci/governance_rules_control_plane/models/enforced_governance_rule_summary.rb', line 45 def lifecycle_state @lifecycle_state end |
#time_created ⇒ DateTime
**[Required]** Date and time the governance rule was created. An RFC3339 formatted datetime string.
Example: `2016-08-25T21:10:29.600Z`
52 53 54 |
# File 'lib/oci/governance_rules_control_plane/models/enforced_governance_rule_summary.rb', line 52 def time_created @time_created end |
#time_updated ⇒ DateTime
**[Required]** Date and time the governance rule was updated. An RFC3339 formatted datetime string.
Example: `2016-08-25T21:10:29.600Z`
59 60 61 |
# File 'lib/oci/governance_rules_control_plane/models/enforced_governance_rule_summary.rb', line 59 def time_updated @time_updated end |
#type ⇒ String
**[Required]** Type of the governance rule, can be one of QUOTA, TAG, ALLOWED_REGIONS.
Example: `QUOTA`
41 42 43 |
# File 'lib/oci/governance_rules_control_plane/models/enforced_governance_rule_summary.rb', line 41 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/oci/governance_rules_control_plane/models/enforced_governance_rule_summary.rb', line 62 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'governance_rule_display_name': :'governanceRuleDisplayName', 'type': :'type', 'lifecycle_state': :'lifecycleState', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/oci/governance_rules_control_plane/models/enforced_governance_rule_summary.rb', line 77 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'governance_rule_display_name': :'String', 'type': :'String', 'lifecycle_state': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/oci/governance_rules_control_plane/models/enforced_governance_rule_summary.rb', line 178 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && governance_rule_display_name == other.governance_rule_display_name && type == other.type && lifecycle_state == other.lifecycle_state && time_created == other.time_created && time_updated == other.time_updated end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/oci/governance_rules_control_plane/models/enforced_governance_rule_summary.rb', line 214 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
194 195 196 |
# File 'lib/oci/governance_rules_control_plane/models/enforced_governance_rule_summary.rb', line 194 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
203 204 205 |
# File 'lib/oci/governance_rules_control_plane/models/enforced_governance_rule_summary.rb', line 203 def hash [id, compartment_id, governance_rule_display_name, type, lifecycle_state, time_created, time_updated].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
247 248 249 250 251 252 253 254 255 256 |
# File 'lib/oci/governance_rules_control_plane/models/enforced_governance_rule_summary.rb', line 247 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
241 242 243 |
# File 'lib/oci/governance_rules_control_plane/models/enforced_governance_rule_summary.rb', line 241 def to_s to_hash.to_s end |