Class: GovernanceRulesControlPlane::Models::GovernanceRule

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/governance_rules_control_plane/models/governance_rule.rb

Overview

Represents a rule in parent tenancy which governs resources in child tenancies.

Constant Summary collapse

TYPE_ENUM =
[
  TYPE_QUOTA = 'QUOTA'.freeze,
  TYPE_TAG = 'TAG'.freeze,
  TYPE_ALLOWED_REGIONS = 'ALLOWED_REGIONS'.freeze,
  TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
CREATION_OPTION_ENUM =
[
  CREATION_OPTION_TEMPLATE = 'TEMPLATE'.freeze,
  CREATION_OPTION_CLONE = 'CLONE'.freeze,
  CREATION_OPTION_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ GovernanceRule

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :display_name (String)

    The value to assign to the #display_name property

  • :description (String)

    The value to assign to the #description property

  • :type (String)

    The value to assign to the #type property

  • :creation_option (String)

    The value to assign to the #creation_option property

  • :template (OCI::GovernanceRulesControlPlane::Models::Template)

    The value to assign to the #template property

  • :related_resource_id (String)

    The value to assign to the #related_resource_id property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :time_updated (DateTime)

    The value to assign to the #time_updated property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property

  • :system_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #system_tags property



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/oci/governance_rules_control_plane/models/governance_rule.rb', line 168

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.type = attributes[:'type'] if attributes[:'type']

  self.creation_option = attributes[:'creationOption'] if attributes[:'creationOption']

  raise 'You cannot provide both :creationOption and :creation_option' if attributes.key?(:'creationOption') && attributes.key?(:'creation_option')

  self.creation_option = attributes[:'creation_option'] if attributes[:'creation_option']

  self.template = attributes[:'template'] if attributes[:'template']

  self.related_resource_id = attributes[:'relatedResourceId'] if attributes[:'relatedResourceId']

  raise 'You cannot provide both :relatedResourceId and :related_resource_id' if attributes.key?(:'relatedResourceId') && attributes.key?(:'related_resource_id')

  self.related_resource_id = attributes[:'related_resource_id'] if attributes[:'related_resource_id']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

  raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

  self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']
end

Instance Attribute Details

#compartment_idString

**[Required]** The Oracle ID ([OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the root compartment containing the governance rule.

Returns:

  • (String)


36
37
38
# File 'lib/oci/governance_rules_control_plane/models/governance_rule.rb', line 36

def compartment_id
  @compartment_id
end

#creation_optionString

**[Required]** The type of option used to create the governance rule, could be one of TEMPLATE or CLONE.

Example: `TEMPLATE`

Returns:

  • (String)


58
59
60
# File 'lib/oci/governance_rules_control_plane/models/governance_rule.rb', line 58

def creation_option
  @creation_option
end

#defined_tagsHash<String, Hash<String, Object>>

**[Required]** Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


96
97
98
# File 'lib/oci/governance_rules_control_plane/models/governance_rule.rb', line 96

def defined_tags
  @defined_tags
end

#descriptionString

Description of the governance rule.

Returns:

  • (String)


44
45
46
# File 'lib/oci/governance_rules_control_plane/models/governance_rule.rb', line 44

def description
  @description
end

#display_nameString

**[Required]** Display name of the governance rule.

Returns:

  • (String)


40
41
42
# File 'lib/oci/governance_rules_control_plane/models/governance_rule.rb', line 40

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

**[Required]** Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`

Returns:

  • (Hash<String, String>)


90
91
92
# File 'lib/oci/governance_rules_control_plane/models/governance_rule.rb', line 90

def freeform_tags
  @freeform_tags
end

#idString

**[Required]** The Oracle ID ([OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the governance rule.

Returns:

  • (String)


32
33
34
# File 'lib/oci/governance_rules_control_plane/models/governance_rule.rb', line 32

def id
  @id
end

#lifecycle_stateString

**[Required]** The current state of the governance rule.

Returns:

  • (String)


84
85
86
# File 'lib/oci/governance_rules_control_plane/models/governance_rule.rb', line 84

def lifecycle_state
  @lifecycle_state
end

The Oracle ID ([OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the resource, which was used as a template to create this governance rule.

Returns:

  • (String)


66
67
68
# File 'lib/oci/governance_rules_control_plane/models/governance_rule.rb', line 66

def related_resource_id
  @related_resource_id
end

#system_tagsHash<String, Hash<String, Object>>

System tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"free-tier-retained": "true"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


102
103
104
# File 'lib/oci/governance_rules_control_plane/models/governance_rule.rb', line 102

def system_tags
  @system_tags
end

#templateOCI::GovernanceRulesControlPlane::Models::Template

This attribute is required.

Returns:

  • (OCI::GovernanceRulesControlPlane::Models::Template)


62
63
64
# File 'lib/oci/governance_rules_control_plane/models/governance_rule.rb', line 62

def template
  @template
end

#time_createdDateTime

**[Required]** Date and time the governance rule was created. An RFC3339 formatted datetime string.

Example: `2016-08-25T21:10:29.600Z`

Returns:

  • (DateTime)


73
74
75
# File 'lib/oci/governance_rules_control_plane/models/governance_rule.rb', line 73

def time_created
  @time_created
end

#time_updatedDateTime

**[Required]** Date and time the governance rule was updated. An RFC3339 formatted datetime string.

Example: `2016-08-25T21:10:29.600Z`

Returns:

  • (DateTime)


80
81
82
# File 'lib/oci/governance_rules_control_plane/models/governance_rule.rb', line 80

def time_updated
  @time_updated
end

#typeString

**[Required]** Type of the governance rule, can be one of QUOTA, TAG, ALLOWED_REGIONS.

Example: `QUOTA`

Returns:

  • (String)


51
52
53
# File 'lib/oci/governance_rules_control_plane/models/governance_rule.rb', line 51

def type
  @type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/oci/governance_rules_control_plane/models/governance_rule.rb', line 105

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'compartment_id': :'compartmentId',
    'display_name': :'displayName',
    'description': :'description',
    'type': :'type',
    'creation_option': :'creationOption',
    'template': :'template',
    'related_resource_id': :'relatedResourceId',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'lifecycle_state': :'lifecycleState',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/oci/governance_rules_control_plane/models/governance_rule.rb', line 127

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'compartment_id': :'String',
    'display_name': :'String',
    'description': :'String',
    'type': :'String',
    'creation_option': :'String',
    'template': :'OCI::GovernanceRulesControlPlane::Models::Template',
    'related_resource_id': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'lifecycle_state': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
# File 'lib/oci/governance_rules_control_plane/models/governance_rule.rb', line 289

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    display_name == other.display_name &&
    description == other.description &&
    type == other.type &&
    creation_option == other.creation_option &&
    template == other.template &&
    related_resource_id == other.related_resource_id &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    lifecycle_state == other.lifecycle_state &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
# File 'lib/oci/governance_rules_control_plane/models/governance_rule.rb', line 332

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


312
313
314
# File 'lib/oci/governance_rules_control_plane/models/governance_rule.rb', line 312

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



321
322
323
# File 'lib/oci/governance_rules_control_plane/models/governance_rule.rb', line 321

def hash
  [id, compartment_id, display_name, description, type, creation_option, template, related_resource_id, time_created, time_updated, lifecycle_state, freeform_tags, defined_tags, system_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



365
366
367
368
369
370
371
372
373
374
# File 'lib/oci/governance_rules_control_plane/models/governance_rule.rb', line 365

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



359
360
361
# File 'lib/oci/governance_rules_control_plane/models/governance_rule.rb', line 359

def to_s
  to_hash.to_s
end