Class: OCI::GovernanceRulesControlPlane::Models::GovernanceRuleSummary
- Inherits:
-
Object
- Object
- OCI::GovernanceRulesControlPlane::Models::GovernanceRuleSummary
- Defined in:
- lib/oci/governance_rules_control_plane/models/governance_rule_summary.rb
Overview
A summary of the governance rule.
Constant Summary collapse
- TYPE_ENUM =
[ TYPE_QUOTA = 'QUOTA'.freeze, TYPE_TAG = 'TAG'.freeze, TYPE_ALLOWED_REGIONS = 'ALLOWED_REGIONS'.freeze, TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- CREATION_OPTION_ENUM =
[ CREATION_OPTION_TEMPLATE = 'TEMPLATE'.freeze, CREATION_OPTION_CLONE = 'CLONE'.freeze, CREATION_OPTION_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The Oracle ID ([OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the root compartment containing the governance rule.
-
#creation_option ⇒ String
**[Required]** The type of option used to create the governance rule, could be one of TEMPLATE or CLONE.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
**[Required]** Defined tags for this resource.
-
#display_name ⇒ String
**[Required]** Display name of the governance rule.
-
#freeform_tags ⇒ Hash<String, String>
**[Required]** Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
**[Required]** The Oracle ID ([OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the governance rule.
-
#lifecycle_state ⇒ String
**[Required]** The current state of the governance rule.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
System tags for this resource.
-
#time_created ⇒ DateTime
**[Required]** Date and time the governance rule was created.
-
#time_updated ⇒ DateTime
**[Required]** Date and time the governance rule was updated.
-
#type ⇒ String
**[Required]** Type of the governance rule, can be one of QUOTA, TAG, ALLOWED_REGIONS.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GovernanceRuleSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ GovernanceRuleSummary
Initializes the object
147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/oci/governance_rules_control_plane/models/governance_rule_summary.rb', line 147 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.type = attributes[:'type'] if attributes[:'type'] self.creation_option = attributes[:'creationOption'] if attributes[:'creationOption'] raise 'You cannot provide both :creationOption and :creation_option' if attributes.key?(:'creationOption') && attributes.key?(:'creation_option') self.creation_option = attributes[:'creation_option'] if attributes[:'creation_option'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The Oracle ID ([OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the root compartment containing the governance rule.
36 37 38 |
# File 'lib/oci/governance_rules_control_plane/models/governance_rule_summary.rb', line 36 def compartment_id @compartment_id end |
#creation_option ⇒ String
**[Required]** The type of option used to create the governance rule, could be one of TEMPLATE or CLONE.
Example: `TEMPLATE`
54 55 56 |
# File 'lib/oci/governance_rules_control_plane/models/governance_rule_summary.rb', line 54 def creation_option @creation_option end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
**[Required]** Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
84 85 86 |
# File 'lib/oci/governance_rules_control_plane/models/governance_rule_summary.rb', line 84 def @defined_tags end |
#display_name ⇒ String
**[Required]** Display name of the governance rule.
40 41 42 |
# File 'lib/oci/governance_rules_control_plane/models/governance_rule_summary.rb', line 40 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
**[Required]** Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
78 79 80 |
# File 'lib/oci/governance_rules_control_plane/models/governance_rule_summary.rb', line 78 def @freeform_tags end |
#id ⇒ String
**[Required]** The Oracle ID ([OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the governance rule.
32 33 34 |
# File 'lib/oci/governance_rules_control_plane/models/governance_rule_summary.rb', line 32 def id @id end |
#lifecycle_state ⇒ String
**[Required]** The current state of the governance rule.
72 73 74 |
# File 'lib/oci/governance_rules_control_plane/models/governance_rule_summary.rb', line 72 def lifecycle_state @lifecycle_state end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
System tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"free-tier-retained": "true"}`
90 91 92 |
# File 'lib/oci/governance_rules_control_plane/models/governance_rule_summary.rb', line 90 def @system_tags end |
#time_created ⇒ DateTime
**[Required]** Date and time the governance rule was created. An RFC3339 formatted datetime string.
Example: `2016-08-25T21:10:29.600Z`
61 62 63 |
# File 'lib/oci/governance_rules_control_plane/models/governance_rule_summary.rb', line 61 def time_created @time_created end |
#time_updated ⇒ DateTime
**[Required]** Date and time the governance rule was updated. An RFC3339 formatted datetime string.
Example: `2016-08-25T21:10:29.600Z`
68 69 70 |
# File 'lib/oci/governance_rules_control_plane/models/governance_rule_summary.rb', line 68 def time_updated @time_updated end |
#type ⇒ String
**[Required]** Type of the governance rule, can be one of QUOTA, TAG, ALLOWED_REGIONS.
Example: `QUOTA`
47 48 49 |
# File 'lib/oci/governance_rules_control_plane/models/governance_rule_summary.rb', line 47 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/oci/governance_rules_control_plane/models/governance_rule_summary.rb', line 93 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'type': :'type', 'creation_option': :'creationOption', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/oci/governance_rules_control_plane/models/governance_rule_summary.rb', line 112 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'display_name': :'String', 'type': :'String', 'creation_option': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/oci/governance_rules_control_plane/models/governance_rule_summary.rb', line 258 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && display_name == other.display_name && type == other.type && creation_option == other.creation_option && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 |
# File 'lib/oci/governance_rules_control_plane/models/governance_rule_summary.rb', line 298 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
278 279 280 |
# File 'lib/oci/governance_rules_control_plane/models/governance_rule_summary.rb', line 278 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
287 288 289 |
# File 'lib/oci/governance_rules_control_plane/models/governance_rule_summary.rb', line 287 def hash [id, compartment_id, display_name, type, creation_option, time_created, time_updated, lifecycle_state, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
331 332 333 334 335 336 337 338 339 340 |
# File 'lib/oci/governance_rules_control_plane/models/governance_rule_summary.rb', line 331 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
325 326 327 |
# File 'lib/oci/governance_rules_control_plane/models/governance_rule_summary.rb', line 325 def to_s to_hash.to_s end |