Class: GovernanceRulesControlPlane::Models::InclusionCriterion

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/governance_rules_control_plane/models/inclusion_criterion.rb

Overview

Represents the criterion for the inclusion of the child tenancies under a governance rule. This can be either TENANCY or TAG.

Constant Summary collapse

TYPE_ENUM =
[
  TYPE_TENANCY = 'TENANCY'.freeze,
  TYPE_ALL = 'ALL'.freeze,
  TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ InclusionCriterion

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :governance_rule_id (String)

    The value to assign to the #governance_rule_id property

  • :type (String)

    The value to assign to the #type property

  • :association (OCI::GovernanceRulesControlPlane::Models::Association)

    The value to assign to the #association property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :time_updated (DateTime)

    The value to assign to the #time_updated property



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/oci/governance_rules_control_plane/models/inclusion_criterion.rb', line 99

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.governance_rule_id = attributes[:'governanceRuleId'] if attributes[:'governanceRuleId']

  raise 'You cannot provide both :governanceRuleId and :governance_rule_id' if attributes.key?(:'governanceRuleId') && attributes.key?(:'governance_rule_id')

  self.governance_rule_id = attributes[:'governance_rule_id'] if attributes[:'governance_rule_id']

  self.type = attributes[:'type'] if attributes[:'type']

  self.association = attributes[:'association'] if attributes[:'association']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']
end

Instance Attribute Details

#associationOCI::GovernanceRulesControlPlane::Models::Association

Returns:

  • (OCI::GovernanceRulesControlPlane::Models::Association)


36
37
38
# File 'lib/oci/governance_rules_control_plane/models/inclusion_criterion.rb', line 36

def association
  @association
end

#governance_rule_idString

**[Required]** The Oracle ID ([OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the governance rule. Every inclusion criterion is associated with a governance rule.

Returns:

  • (String)


29
30
31
# File 'lib/oci/governance_rules_control_plane/models/inclusion_criterion.rb', line 29

def governance_rule_id
  @governance_rule_id
end

#idString

**[Required]** The Oracle ID ([OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the inclusion criterion.

Returns:

  • (String)


25
26
27
# File 'lib/oci/governance_rules_control_plane/models/inclusion_criterion.rb', line 25

def id
  @id
end

#lifecycle_stateString

**[Required]** The current state of the inclusion criterion.

Returns:

  • (String)


40
41
42
# File 'lib/oci/governance_rules_control_plane/models/inclusion_criterion.rb', line 40

def lifecycle_state
  @lifecycle_state
end

#time_createdDateTime

**[Required]** Date and time the inclusion criterion was created. An RFC3339 formatted datetime string.

Example: `2016-08-25T21:10:29.600Z`

Returns:

  • (DateTime)


47
48
49
# File 'lib/oci/governance_rules_control_plane/models/inclusion_criterion.rb', line 47

def time_created
  @time_created
end

#time_updatedDateTime

**[Required]** Date and time the inclusion criterion was updated. An RFC3339 formatted datetime string.

Example: `2016-08-25T21:10:29.600Z`

Returns:

  • (DateTime)


54
55
56
# File 'lib/oci/governance_rules_control_plane/models/inclusion_criterion.rb', line 54

def time_updated
  @time_updated
end

#typeString

**[Required]** Type of inclusion criterion - TENANCY, ALL or TAG. We support TENANCY and ALL for now.

Returns:

  • (String)


33
34
35
# File 'lib/oci/governance_rules_control_plane/models/inclusion_criterion.rb', line 33

def type
  @type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/oci/governance_rules_control_plane/models/inclusion_criterion.rb', line 57

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'governance_rule_id': :'governanceRuleId',
    'type': :'type',
    'association': :'association',
    'lifecycle_state': :'lifecycleState',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/oci/governance_rules_control_plane/models/inclusion_criterion.rb', line 72

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'governance_rule_id': :'String',
    'type': :'String',
    'association': :'OCI::GovernanceRulesControlPlane::Models::Association',
    'lifecycle_state': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/oci/governance_rules_control_plane/models/inclusion_criterion.rb', line 169

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    governance_rule_id == other.governance_rule_id &&
    type == other.type &&
    association == other.association &&
    lifecycle_state == other.lifecycle_state &&
    time_created == other.time_created &&
    time_updated == other.time_updated
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/oci/governance_rules_control_plane/models/inclusion_criterion.rb', line 205

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


185
186
187
# File 'lib/oci/governance_rules_control_plane/models/inclusion_criterion.rb', line 185

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



194
195
196
# File 'lib/oci/governance_rules_control_plane/models/inclusion_criterion.rb', line 194

def hash
  [id, governance_rule_id, type, association, lifecycle_state, time_created, time_updated].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



238
239
240
241
242
243
244
245
246
247
# File 'lib/oci/governance_rules_control_plane/models/inclusion_criterion.rb', line 238

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



232
233
234
# File 'lib/oci/governance_rules_control_plane/models/inclusion_criterion.rb', line 232

def to_s
  to_hash.to_s
end