Class: OCI::GovernanceRulesControlPlane::Models::InclusionCriterionSummary
- Inherits:
-
Object
- Object
- OCI::GovernanceRulesControlPlane::Models::InclusionCriterionSummary
- Defined in:
- lib/oci/governance_rules_control_plane/models/inclusion_criterion_summary.rb
Overview
Summary of the inclusion criterion.
Instance Attribute Summary collapse
- #association ⇒ OCI::GovernanceRulesControlPlane::Models::Association
-
#governance_rule_id ⇒ String
**[Required]** The Oracle ID ([OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the governance rule.
-
#id ⇒ String
**[Required]** The Oracle ID ([OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the inclusion criterion.
-
#lifecycle_state ⇒ String
**[Required]** The current state of the inclusion criterion.
-
#time_created ⇒ DateTime
**[Required]** Date and time the inclusion criterion was created.
-
#time_updated ⇒ DateTime
**[Required]** Date and time the inclusion criterion was updated.
-
#type ⇒ String
**[Required]** Type of inclusion criterion - TENANCY, ALL or TAG.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ InclusionCriterionSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ InclusionCriterionSummary
Initializes the object
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/oci/governance_rules_control_plane/models/inclusion_criterion_summary.rb', line 86 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.governance_rule_id = attributes[:'governanceRuleId'] if attributes[:'governanceRuleId'] raise 'You cannot provide both :governanceRuleId and :governance_rule_id' if attributes.key?(:'governanceRuleId') && attributes.key?(:'governance_rule_id') self.governance_rule_id = attributes[:'governance_rule_id'] if attributes[:'governance_rule_id'] self.type = attributes[:'type'] if attributes[:'type'] self.association = attributes[:'association'] if attributes[:'association'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] end |
Instance Attribute Details
#association ⇒ OCI::GovernanceRulesControlPlane::Models::Association
23 24 25 |
# File 'lib/oci/governance_rules_control_plane/models/inclusion_criterion_summary.rb', line 23 def association @association end |
#governance_rule_id ⇒ String
**[Required]** The Oracle ID ([OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the governance rule. Every inclusion criterion is associated with a governance rule.
16 17 18 |
# File 'lib/oci/governance_rules_control_plane/models/inclusion_criterion_summary.rb', line 16 def governance_rule_id @governance_rule_id end |
#id ⇒ String
**[Required]** The Oracle ID ([OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the inclusion criterion.
12 13 14 |
# File 'lib/oci/governance_rules_control_plane/models/inclusion_criterion_summary.rb', line 12 def id @id end |
#lifecycle_state ⇒ String
**[Required]** The current state of the inclusion criterion.
27 28 29 |
# File 'lib/oci/governance_rules_control_plane/models/inclusion_criterion_summary.rb', line 27 def lifecycle_state @lifecycle_state end |
#time_created ⇒ DateTime
**[Required]** Date and time the inclusion criterion was created. An RFC3339 formatted datetime string.
Example: `2016-08-25T21:10:29.600Z`
34 35 36 |
# File 'lib/oci/governance_rules_control_plane/models/inclusion_criterion_summary.rb', line 34 def time_created @time_created end |
#time_updated ⇒ DateTime
**[Required]** Date and time the inclusion criterion was updated. An RFC3339 formatted datetime string.
Example: `2016-08-25T21:10:29.600Z`
41 42 43 |
# File 'lib/oci/governance_rules_control_plane/models/inclusion_criterion_summary.rb', line 41 def time_updated @time_updated end |
#type ⇒ String
**[Required]** Type of inclusion criterion - TENANCY, ALL or TAG. We support TENANCY and ALL for now.
20 21 22 |
# File 'lib/oci/governance_rules_control_plane/models/inclusion_criterion_summary.rb', line 20 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
44 45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/oci/governance_rules_control_plane/models/inclusion_criterion_summary.rb', line 44 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'governance_rule_id': :'governanceRuleId', 'type': :'type', 'association': :'association', 'lifecycle_state': :'lifecycleState', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/oci/governance_rules_control_plane/models/inclusion_criterion_summary.rb', line 59 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'governance_rule_id': :'String', 'type': :'String', 'association': :'OCI::GovernanceRulesControlPlane::Models::Association', 'lifecycle_state': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/oci/governance_rules_control_plane/models/inclusion_criterion_summary.rb', line 130 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && governance_rule_id == other.governance_rule_id && type == other.type && association == other.association && lifecycle_state == other.lifecycle_state && time_created == other.time_created && time_updated == other.time_updated end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/oci/governance_rules_control_plane/models/inclusion_criterion_summary.rb', line 166 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
146 147 148 |
# File 'lib/oci/governance_rules_control_plane/models/inclusion_criterion_summary.rb', line 146 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
155 156 157 |
# File 'lib/oci/governance_rules_control_plane/models/inclusion_criterion_summary.rb', line 155 def hash [id, governance_rule_id, type, association, lifecycle_state, time_created, time_updated].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
199 200 201 202 203 204 205 206 207 208 |
# File 'lib/oci/governance_rules_control_plane/models/inclusion_criterion_summary.rb', line 199 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
193 194 195 |
# File 'lib/oci/governance_rules_control_plane/models/inclusion_criterion_summary.rb', line 193 def to_s to_hash.to_s end |