Class: GovernanceRulesControlPlane::Models::TagDefault
- Inherits:
-
Object
- Object
- GovernanceRulesControlPlane::Models::TagDefault
- Defined in:
- lib/oci/governance_rules_control_plane/models/tag_default.rb
Overview
Tag defaults let you specify a default tag (tagnamespace.tag="value") to apply to all resource types in a specified compartment. The tag default is applied at the time the resource is created. Resources that exist in the compartment before you create the tag default are not tagged.
Instance Attribute Summary collapse
-
#is_required ⇒ BOOLEAN
**[Required]** If you specify that a value is required, a value is set during resource creation (either by the user creating the resource or another tag default).
-
#tag_name ⇒ String
**[Required]** The name of the tag.
-
#value ⇒ String
**[Required]** The default value for the tag name.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TagDefault
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ TagDefault
Initializes the object
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/oci/governance_rules_control_plane/models/tag_default.rb', line 67 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.tag_name = attributes[:'tagName'] if attributes[:'tagName'] raise 'You cannot provide both :tagName and :tag_name' if attributes.key?(:'tagName') && attributes.key?(:'tag_name') self.tag_name = attributes[:'tag_name'] if attributes[:'tag_name'] self.value = attributes[:'value'] if attributes[:'value'] self.is_required = attributes[:'isRequired'] unless attributes[:'isRequired'].nil? raise 'You cannot provide both :isRequired and :is_required' if attributes.key?(:'isRequired') && attributes.key?(:'is_required') self.is_required = attributes[:'is_required'] unless attributes[:'is_required'].nil? end |
Instance Attribute Details
#is_required ⇒ BOOLEAN
**[Required]** If you specify that a value is required, a value is set during resource creation (either by the user creating the resource or another tag default). If no value is set, resource creation is blocked.
-
If the `isRequired` flag is set to "true", the value is set during resource creation.
-
If the `isRequired` flag is set to "false", the value you enter is set during resource creation.
Example: `false`
34 35 36 |
# File 'lib/oci/governance_rules_control_plane/models/tag_default.rb', line 34 def is_required @is_required end |
#tag_name ⇒ String
**[Required]** The name of the tag. The tag default will always assign a default value for this tag name.
17 18 19 |
# File 'lib/oci/governance_rules_control_plane/models/tag_default.rb', line 17 def tag_name @tag_name end |
#value ⇒ String
**[Required]** The default value for the tag name. This will be applied to all new resources created in the compartment.
22 23 24 |
# File 'lib/oci/governance_rules_control_plane/models/tag_default.rb', line 22 def value @value end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 |
# File 'lib/oci/governance_rules_control_plane/models/tag_default.rb', line 37 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'tag_name': :'tagName', 'value': :'value', 'is_required': :'isRequired' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
48 49 50 51 52 53 54 55 56 |
# File 'lib/oci/governance_rules_control_plane/models/tag_default.rb', line 48 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'tag_name': :'String', 'value': :'String', 'is_required': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
95 96 97 98 99 100 101 102 |
# File 'lib/oci/governance_rules_control_plane/models/tag_default.rb', line 95 def ==(other) return true if equal?(other) self.class == other.class && tag_name == other.tag_name && value == other.value && is_required == other.is_required end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/oci/governance_rules_control_plane/models/tag_default.rb', line 127 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
107 108 109 |
# File 'lib/oci/governance_rules_control_plane/models/tag_default.rb', line 107 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
116 117 118 |
# File 'lib/oci/governance_rules_control_plane/models/tag_default.rb', line 116 def hash [tag_name, value, is_required].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
160 161 162 163 164 165 166 167 168 169 |
# File 'lib/oci/governance_rules_control_plane/models/tag_default.rb', line 160 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
154 155 156 |
# File 'lib/oci/governance_rules_control_plane/models/tag_default.rb', line 154 def to_s to_hash.to_s end |