Class: GovernanceRulesControlPlane::Models::TagTemplate
- Inherits:
-
Template
- Object
- Template
- GovernanceRulesControlPlane::Models::TagTemplate
- Defined in:
- lib/oci/governance_rules_control_plane/models/tag_template.rb
Overview
Template for governance rules of type tag.
Instance Attribute Summary collapse
-
#description ⇒ String
Description of the tag namespace.
-
#name ⇒ String
**[Required]** The name of the tag namespace.
- #tag_defaults ⇒ Array<OCI::GovernanceRulesControlPlane::Models::TagDefault>
-
#tags ⇒ Array<OCI::GovernanceRulesControlPlane::Models::Tag>
Represents an array of tags for tag namespace.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TagTemplate
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ TagTemplate
Initializes the object
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/oci/governance_rules_control_plane/models/tag_template.rb', line 63 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['type'] = 'TAG' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self. = attributes[:'tags'] if attributes[:'tags'] self.tag_defaults = attributes[:'tagDefaults'] if attributes[:'tagDefaults'] raise 'You cannot provide both :tagDefaults and :tag_defaults' if attributes.key?(:'tagDefaults') && attributes.key?(:'tag_defaults') self.tag_defaults = attributes[:'tag_defaults'] if attributes[:'tag_defaults'] end |
Instance Attribute Details
#description ⇒ String
Description of the tag namespace.
18 19 20 |
# File 'lib/oci/governance_rules_control_plane/models/tag_template.rb', line 18 def description @description end |
#name ⇒ String
**[Required]** The name of the tag namespace. It must be unique across all tag namespaces in the tenancy and cannot be changed.
14 15 16 |
# File 'lib/oci/governance_rules_control_plane/models/tag_template.rb', line 14 def name @name end |
#tag_defaults ⇒ Array<OCI::GovernanceRulesControlPlane::Models::TagDefault>
25 26 27 |
# File 'lib/oci/governance_rules_control_plane/models/tag_template.rb', line 25 def tag_defaults @tag_defaults end |
#tags ⇒ Array<OCI::GovernanceRulesControlPlane::Models::Tag>
Represents an array of tags for tag namespace.
22 23 24 |
# File 'lib/oci/governance_rules_control_plane/models/tag_template.rb', line 22 def @tags end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 35 36 37 38 |
# File 'lib/oci/governance_rules_control_plane/models/tag_template.rb', line 28 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'type': :'type', 'name': :'name', 'description': :'description', 'tags': :'tags', 'tag_defaults': :'tagDefaults' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/oci/governance_rules_control_plane/models/tag_template.rb', line 41 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'type': :'String', 'name': :'String', 'description': :'String', 'tags': :'Array<OCI::GovernanceRulesControlPlane::Models::Tag>', 'tag_defaults': :'Array<OCI::GovernanceRulesControlPlane::Models::TagDefault>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
93 94 95 96 97 98 99 100 101 102 |
# File 'lib/oci/governance_rules_control_plane/models/tag_template.rb', line 93 def ==(other) return true if equal?(other) self.class == other.class && type == other.type && name == other.name && description == other.description && == other. && tag_defaults == other.tag_defaults end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/oci/governance_rules_control_plane/models/tag_template.rb', line 127 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
107 108 109 |
# File 'lib/oci/governance_rules_control_plane/models/tag_template.rb', line 107 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
116 117 118 |
# File 'lib/oci/governance_rules_control_plane/models/tag_template.rb', line 116 def hash [type, name, description, , tag_defaults].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
160 161 162 163 164 165 166 167 168 169 |
# File 'lib/oci/governance_rules_control_plane/models/tag_template.rb', line 160 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
154 155 156 |
# File 'lib/oci/governance_rules_control_plane/models/tag_template.rb', line 154 def to_s to_hash.to_s end |