Class: GovernanceRulesControlPlane::Models::TenancyAttachment
- Inherits:
-
Object
- Object
- GovernanceRulesControlPlane::Models::TenancyAttachment
- Defined in:
- lib/oci/governance_rules_control_plane/models/tenancy_attachment.rb
Overview
Tenancy attachment associates a tenancy to a governance rule via an inclusion criterion.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_NEEDS_ATTENTION = 'NEEDS_ATTENTION'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The Oracle ID ([OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the root compartment containing the tenancy attachment.
-
#governance_rule_id ⇒ String
**[Required]** The Oracle ID ([OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the governance rule.
-
#id ⇒ String
**[Required]** The Oracle ID ([OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the tenancy attachment.
-
#lifecycle_state ⇒ String
**[Required]** The current state of the tenancy attachment.
-
#tenancy_id ⇒ String
**[Required]** The Oracle ID ([OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the tenancy to which the governance rule is attached.
-
#time_created ⇒ DateTime
**[Required]** Date and time the tenancy attachment was created.
-
#time_last_attempted ⇒ DateTime
Date and time the tenancy attachment was last attempted.
-
#time_updated ⇒ DateTime
**[Required]** Date and time the tenancy attachment was updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TenancyAttachment
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ TenancyAttachment
Initializes the object
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/oci/governance_rules_control_plane/models/tenancy_attachment.rb', line 108 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.governance_rule_id = attributes[:'governanceRuleId'] if attributes[:'governanceRuleId'] raise 'You cannot provide both :governanceRuleId and :governance_rule_id' if attributes.key?(:'governanceRuleId') && attributes.key?(:'governance_rule_id') self.governance_rule_id = attributes[:'governance_rule_id'] if attributes[:'governance_rule_id'] self.tenancy_id = attributes[:'tenancyId'] if attributes[:'tenancyId'] raise 'You cannot provide both :tenancyId and :tenancy_id' if attributes.key?(:'tenancyId') && attributes.key?(:'tenancy_id') self.tenancy_id = attributes[:'tenancy_id'] if attributes[:'tenancy_id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.time_last_attempted = attributes[:'timeLastAttempted'] if attributes[:'timeLastAttempted'] raise 'You cannot provide both :timeLastAttempted and :time_last_attempted' if attributes.key?(:'timeLastAttempted') && attributes.key?(:'time_last_attempted') self.time_last_attempted = attributes[:'time_last_attempted'] if attributes[:'time_last_attempted'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The Oracle ID ([OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the root compartment containing the tenancy attachment.
27 28 29 |
# File 'lib/oci/governance_rules_control_plane/models/tenancy_attachment.rb', line 27 def compartment_id @compartment_id end |
#governance_rule_id ⇒ String
**[Required]** The Oracle ID ([OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the governance rule. Every tenancy attachment is associated with a governance rule.
31 32 33 |
# File 'lib/oci/governance_rules_control_plane/models/tenancy_attachment.rb', line 31 def governance_rule_id @governance_rule_id end |
#id ⇒ String
**[Required]** The Oracle ID ([OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the tenancy attachment.
23 24 25 |
# File 'lib/oci/governance_rules_control_plane/models/tenancy_attachment.rb', line 23 def id @id end |
#lifecycle_state ⇒ String
**[Required]** The current state of the tenancy attachment.
39 40 41 |
# File 'lib/oci/governance_rules_control_plane/models/tenancy_attachment.rb', line 39 def lifecycle_state @lifecycle_state end |
#tenancy_id ⇒ String
**[Required]** The Oracle ID ([OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the tenancy to which the governance rule is attached.
35 36 37 |
# File 'lib/oci/governance_rules_control_plane/models/tenancy_attachment.rb', line 35 def tenancy_id @tenancy_id end |
#time_created ⇒ DateTime
**[Required]** Date and time the tenancy attachment was created. An RFC3339 formatted datetime string.
Example: `2016-08-25T21:10:29.600Z`
46 47 48 |
# File 'lib/oci/governance_rules_control_plane/models/tenancy_attachment.rb', line 46 def time_created @time_created end |
#time_last_attempted ⇒ DateTime
Date and time the tenancy attachment was last attempted. An RFC3339 formatted datetime string.
Example: `2016-08-25T21:10:29.600Z`
60 61 62 |
# File 'lib/oci/governance_rules_control_plane/models/tenancy_attachment.rb', line 60 def time_last_attempted @time_last_attempted end |
#time_updated ⇒ DateTime
**[Required]** Date and time the tenancy attachment was updated. An RFC3339 formatted datetime string.
Example: `2016-08-25T21:10:29.600Z`
53 54 55 |
# File 'lib/oci/governance_rules_control_plane/models/tenancy_attachment.rb', line 53 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/oci/governance_rules_control_plane/models/tenancy_attachment.rb', line 63 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'governance_rule_id': :'governanceRuleId', 'tenancy_id': :'tenancyId', 'lifecycle_state': :'lifecycleState', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'time_last_attempted': :'timeLastAttempted' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/oci/governance_rules_control_plane/models/tenancy_attachment.rb', line 79 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'governance_rule_id': :'String', 'tenancy_id': :'String', 'lifecycle_state': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'time_last_attempted': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/oci/governance_rules_control_plane/models/tenancy_attachment.rb', line 179 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && governance_rule_id == other.governance_rule_id && tenancy_id == other.tenancy_id && lifecycle_state == other.lifecycle_state && time_created == other.time_created && time_updated == other.time_updated && time_last_attempted == other.time_last_attempted end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/oci/governance_rules_control_plane/models/tenancy_attachment.rb', line 216 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
196 197 198 |
# File 'lib/oci/governance_rules_control_plane/models/tenancy_attachment.rb', line 196 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
205 206 207 |
# File 'lib/oci/governance_rules_control_plane/models/tenancy_attachment.rb', line 205 def hash [id, compartment_id, governance_rule_id, tenancy_id, lifecycle_state, time_created, time_updated, time_last_attempted].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
249 250 251 252 253 254 255 256 257 258 |
# File 'lib/oci/governance_rules_control_plane/models/tenancy_attachment.rb', line 249 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
243 244 245 |
# File 'lib/oci/governance_rules_control_plane/models/tenancy_attachment.rb', line 243 def to_s to_hash.to_s end |