Class: OCI::GovernanceRulesControlPlane::Models::UpdateGovernanceRuleDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/governance_rules_control_plane/models/update_governance_rule_details.rb

Overview

Request object for UpdateGovernanceRule operation.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateGovernanceRuleDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :display_name (String)

    The value to assign to the #display_name property

  • :description (String)

    The value to assign to the #description property

  • :template (OCI::GovernanceRulesControlPlane::Models::Template)

    The value to assign to the #template property

  • :related_resource_id (String)

    The value to assign to the #related_resource_id property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/oci/governance_rules_control_plane/models/update_governance_rule_details.rb', line 77

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.template = attributes[:'template'] if attributes[:'template']

  self.related_resource_id = attributes[:'relatedResourceId'] if attributes[:'relatedResourceId']

  raise 'You cannot provide both :relatedResourceId and :related_resource_id' if attributes.key?(:'relatedResourceId') && attributes.key?(:'related_resource_id')

  self.related_resource_id = attributes[:'related_resource_id'] if attributes[:'related_resource_id']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


35
36
37
# File 'lib/oci/governance_rules_control_plane/models/update_governance_rule_details.rb', line 35

def defined_tags
  @defined_tags
end

#descriptionString

Description of the governance rule.

Returns:

  • (String)


16
17
18
# File 'lib/oci/governance_rules_control_plane/models/update_governance_rule_details.rb', line 16

def description
  @description
end

#display_nameString

Display name of the governance rule.

Returns:

  • (String)


12
13
14
# File 'lib/oci/governance_rules_control_plane/models/update_governance_rule_details.rb', line 12

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`

Returns:

  • (Hash<String, String>)


29
30
31
# File 'lib/oci/governance_rules_control_plane/models/update_governance_rule_details.rb', line 29

def freeform_tags
  @freeform_tags
end

The Oracle ID ([OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the resource, which was used as a template to create this governance rule.

Returns:

  • (String)


23
24
25
# File 'lib/oci/governance_rules_control_plane/models/update_governance_rule_details.rb', line 23

def related_resource_id
  @related_resource_id
end

#templateOCI::GovernanceRulesControlPlane::Models::Template

Returns:

  • (OCI::GovernanceRulesControlPlane::Models::Template)


19
20
21
# File 'lib/oci/governance_rules_control_plane/models/update_governance_rule_details.rb', line 19

def template
  @template
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
48
49
# File 'lib/oci/governance_rules_control_plane/models/update_governance_rule_details.rb', line 38

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'displayName',
    'description': :'description',
    'template': :'template',
    'related_resource_id': :'relatedResourceId',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/oci/governance_rules_control_plane/models/update_governance_rule_details.rb', line 52

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'String',
    'description': :'String',
    'template': :'OCI::GovernanceRulesControlPlane::Models::Template',
    'related_resource_id': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



119
120
121
122
123
124
125
126
127
128
129
# File 'lib/oci/governance_rules_control_plane/models/update_governance_rule_details.rb', line 119

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    display_name == other.display_name &&
    description == other.description &&
    template == other.template &&
    related_resource_id == other.related_resource_id &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
# File 'lib/oci/governance_rules_control_plane/models/update_governance_rule_details.rb', line 154

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


134
135
136
# File 'lib/oci/governance_rules_control_plane/models/update_governance_rule_details.rb', line 134

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



143
144
145
# File 'lib/oci/governance_rules_control_plane/models/update_governance_rule_details.rb', line 143

def hash
  [display_name, description, template, related_resource_id, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



187
188
189
190
191
192
193
194
195
196
# File 'lib/oci/governance_rules_control_plane/models/update_governance_rule_details.rb', line 187

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



181
182
183
# File 'lib/oci/governance_rules_control_plane/models/update_governance_rule_details.rb', line 181

def to_s
  to_hash.to_s
end