Class: OCI::Healthchecks::Models::CreateHttpMonitorDetails
- Inherits:
-
Object
- Object
- OCI::Healthchecks::Models::CreateHttpMonitorDetails
- Defined in:
- lib/oci/healthchecks/models/create_http_monitor_details.rb
Overview
The request body used to create an HTTP monitor.
Constant Summary collapse
- PROTOCOL_ENUM =
[ PROTOCOL_HTTP = 'HTTP'.freeze, PROTOCOL_HTTPS = 'HTTPS'.freeze ].freeze
- METHOD_ENUM =
[ METHOD_GET = 'GET'.freeze, METHOD_HEAD = 'HEAD'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The OCID of the compartment.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
[Required] A user-friendly and mutable name suitable for display in a user interface.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#headers ⇒ Hash<String, String>
A dictionary of HTTP request headers.
-
#interval_in_seconds ⇒ Integer
[Required] The monitor interval in seconds.
-
#is_enabled ⇒ BOOLEAN
Enables or disables the monitor.
- #method ⇒ String
-
#path ⇒ String
The optional URL path to probe, including query parameters.
-
#port ⇒ Integer
The port on which to probe endpoints.
-
#protocol ⇒ String
This attribute is required.
-
#targets ⇒ Array<String>
This attribute is required.
-
#timeout_in_seconds ⇒ Integer
The probe timeout in seconds.
- #vantage_point_names ⇒ Array<String>
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateHttpMonitorDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateHttpMonitorDetails
Initializes the object
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/oci/healthchecks/models/create_http_monitor_details.rb', line 153 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.targets = attributes[:'targets'] if attributes[:'targets'] self.vantage_point_names = attributes[:'vantagePointNames'] if attributes[:'vantagePointNames'] raise 'You cannot provide both :vantagePointNames and :vantage_point_names' if attributes.key?(:'vantagePointNames') && attributes.key?(:'vantage_point_names') self.vantage_point_names = attributes[:'vantage_point_names'] if attributes[:'vantage_point_names'] self.port = attributes[:'port'] if attributes[:'port'] self.timeout_in_seconds = attributes[:'timeoutInSeconds'] if attributes[:'timeoutInSeconds'] raise 'You cannot provide both :timeoutInSeconds and :timeout_in_seconds' if attributes.key?(:'timeoutInSeconds') && attributes.key?(:'timeout_in_seconds') self.timeout_in_seconds = attributes[:'timeout_in_seconds'] if attributes[:'timeout_in_seconds'] self.protocol = attributes[:'protocol'] if attributes[:'protocol'] self.method = attributes[:'method'] if attributes[:'method'] self.method = "HEAD" if method.nil? && !attributes.key?(:'method') # rubocop:disable Style/StringLiterals self.path = attributes[:'path'] if attributes[:'path'] self.path = "/" if path.nil? && !attributes.key?(:'path') # rubocop:disable Style/StringLiterals self.headers = attributes[:'headers'] if attributes[:'headers'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.interval_in_seconds = attributes[:'intervalInSeconds'] if attributes[:'intervalInSeconds'] raise 'You cannot provide both :intervalInSeconds and :interval_in_seconds' if attributes.key?(:'intervalInSeconds') && attributes.key?(:'interval_in_seconds') self.interval_in_seconds = attributes[:'interval_in_seconds'] if attributes[:'interval_in_seconds'] self.is_enabled = attributes[:'isEnabled'] unless attributes[:'isEnabled'].nil? self.is_enabled = true if is_enabled.nil? && !attributes.key?(:'isEnabled') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isEnabled and :is_enabled' if attributes.key?(:'isEnabled') && attributes.key?(:'is_enabled') self.is_enabled = attributes[:'is_enabled'] unless attributes[:'is_enabled'].nil? self.is_enabled = true if is_enabled.nil? && !attributes.key?(:'isEnabled') && !attributes.key?(:'is_enabled') # rubocop:disable Style/StringLiterals self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The OCID of the compartment.
21 22 23 |
# File 'lib/oci/healthchecks/models/create_http_monitor_details.rb', line 21 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"CostCenter": "42"}`
87 88 89 |
# File 'lib/oci/healthchecks/models/create_http_monitor_details.rb', line 87 def end |
#display_name ⇒ String
[Required] A user-friendly and mutable name suitable for display in a user interface.
62 63 64 |
# File 'lib/oci/healthchecks/models/create_http_monitor_details.rb', line 62 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"Finance"`
80 81 82 |
# File 'lib/oci/healthchecks/models/create_http_monitor_details.rb', line 80 def end |
#headers ⇒ Hash<String, String>
A dictionary of HTTP request headers.
Note: Monitors and probes do not support the use of the Authorization HTTP header.
58 59 60 |
# File 'lib/oci/healthchecks/models/create_http_monitor_details.rb', line 58 def headers @headers end |
#interval_in_seconds ⇒ Integer
[Required] The monitor interval in seconds. Valid values: 10, 30, and 60.
67 68 69 |
# File 'lib/oci/healthchecks/models/create_http_monitor_details.rb', line 67 def interval_in_seconds @interval_in_seconds end |
#is_enabled ⇒ BOOLEAN
Enables or disables the monitor. Set to ‘true’ to launch monitoring.
72 73 74 |
# File 'lib/oci/healthchecks/models/create_http_monitor_details.rb', line 72 def is_enabled @is_enabled end |
#method ⇒ String
47 48 49 |
# File 'lib/oci/healthchecks/models/create_http_monitor_details.rb', line 47 def method @method end |
#path ⇒ String
The optional URL path to probe, including query parameters.
51 52 53 |
# File 'lib/oci/healthchecks/models/create_http_monitor_details.rb', line 51 def path @path end |
#port ⇒ Integer
The port on which to probe endpoints. If unspecified, probes will use the default port of their protocol.
34 35 36 |
# File 'lib/oci/healthchecks/models/create_http_monitor_details.rb', line 34 def port @port end |
#protocol ⇒ String
This attribute is required.
44 45 46 |
# File 'lib/oci/healthchecks/models/create_http_monitor_details.rb', line 44 def protocol @protocol end |
#targets ⇒ Array<String>
This attribute is required.
25 26 27 |
# File 'lib/oci/healthchecks/models/create_http_monitor_details.rb', line 25 def targets @targets end |
#timeout_in_seconds ⇒ Integer
The probe timeout in seconds. Valid values: 10, 20, 30, and 60. The probe timeout must be less than or equal to intervalInSeconds for monitors.
40 41 42 |
# File 'lib/oci/healthchecks/models/create_http_monitor_details.rb', line 40 def timeout_in_seconds @timeout_in_seconds end |
#vantage_point_names ⇒ Array<String>
28 29 30 |
# File 'lib/oci/healthchecks/models/create_http_monitor_details.rb', line 28 def vantage_point_names @vantage_point_names end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/oci/healthchecks/models/create_http_monitor_details.rb', line 90 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'targets': :'targets', 'vantage_point_names': :'vantagePointNames', 'port': :'port', 'timeout_in_seconds': :'timeoutInSeconds', 'protocol': :'protocol', 'method': :'method', 'path': :'path', 'headers': :'headers', 'display_name': :'displayName', 'interval_in_seconds': :'intervalInSeconds', 'is_enabled': :'isEnabled', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/oci/healthchecks/models/create_http_monitor_details.rb', line 112 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'targets': :'Array<String>', 'vantage_point_names': :'Array<String>', 'port': :'Integer', 'timeout_in_seconds': :'Integer', 'protocol': :'String', 'method': :'String', 'path': :'String', 'headers': :'Hash<String, String>', 'display_name': :'String', 'interval_in_seconds': :'Integer', 'is_enabled': :'BOOLEAN', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 |
# File 'lib/oci/healthchecks/models/create_http_monitor_details.rb', line 247 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && targets == other.targets && vantage_point_names == other.vantage_point_names && port == other.port && timeout_in_seconds == other.timeout_in_seconds && protocol == other.protocol && method == other.method && path == other.path && headers == other.headers && display_name == other.display_name && interval_in_seconds == other.interval_in_seconds && is_enabled == other.is_enabled && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 |
# File 'lib/oci/healthchecks/models/create_http_monitor_details.rb', line 290 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
270 271 272 |
# File 'lib/oci/healthchecks/models/create_http_monitor_details.rb', line 270 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
279 280 281 |
# File 'lib/oci/healthchecks/models/create_http_monitor_details.rb', line 279 def hash [compartment_id, targets, vantage_point_names, port, timeout_in_seconds, protocol, method, path, headers, display_name, interval_in_seconds, is_enabled, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
323 324 325 326 327 328 329 330 331 332 |
# File 'lib/oci/healthchecks/models/create_http_monitor_details.rb', line 323 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
317 318 319 |
# File 'lib/oci/healthchecks/models/create_http_monitor_details.rb', line 317 def to_s to_hash.to_s end |