Class: OCI::Identity::Models::AuthToken
- Inherits:
-
Object
- Object
- OCI::Identity::Models::AuthToken
- Defined in:
- lib/oci/identity/models/auth_token.rb
Overview
An `AuthToken` is an Oracle-generated token string that you can use to authenticate with third-party APIs that do not support Oracle Cloud Infrastructure's signature-based authentication. For example, use an `AuthToken` to authenticate with a Swift client with the Object Storage Service.
The auth token is associated with the user's Console login. Auth tokens never expire. A user can have up to two auth tokens at a time.
*Note:* The token is always an Oracle-generated string; you can't change it to a string of your choice.
For more information, see [Managing User Credentials](docs.cloud.oracle.com/Content/Identity/access/managing-user-credentials.htm).
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#description ⇒ String
The description you assign to the auth token.
-
#id ⇒ String
The OCID of the auth token.
-
#inactive_status ⇒ Integer
The detailed status of INACTIVE lifecycleState.
-
#lifecycle_state ⇒ String
The token's current state.
-
#time_created ⇒ DateTime
Date and time the `AuthToken` object was created, in the format defined by RFC3339.
-
#time_expires ⇒ DateTime
Date and time when this auth token will expire, in the format defined by RFC3339.
-
#token ⇒ String
The auth token.
-
#user_id ⇒ String
The OCID of the user the auth token belongs to.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AuthToken
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ AuthToken
Initializes the object
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/oci/identity/models/auth_token.rb', line 122 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.token = attributes[:'token'] if attributes[:'token'] self.id = attributes[:'id'] if attributes[:'id'] self.user_id = attributes[:'userId'] if attributes[:'userId'] raise 'You cannot provide both :userId and :user_id' if attributes.key?(:'userId') && attributes.key?(:'user_id') self.user_id = attributes[:'user_id'] if attributes[:'user_id'] self.description = attributes[:'description'] if attributes[:'description'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_expires = attributes[:'timeExpires'] if attributes[:'timeExpires'] raise 'You cannot provide both :timeExpires and :time_expires' if attributes.key?(:'timeExpires') && attributes.key?(:'time_expires') self.time_expires = attributes[:'time_expires'] if attributes[:'time_expires'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.inactive_status = attributes[:'inactiveStatus'] if attributes[:'inactiveStatus'] raise 'You cannot provide both :inactiveStatus and :inactive_status' if attributes.key?(:'inactiveStatus') && attributes.key?(:'inactive_status') self.inactive_status = attributes[:'inactive_status'] if attributes[:'inactive_status'] end |
Instance Attribute Details
#description ⇒ String
The description you assign to the auth token. Does not have to be unique, and it's changeable.
(For tenancies that support identity domains) You can have an empty description.
49 50 51 |
# File 'lib/oci/identity/models/auth_token.rb', line 49 def description @description end |
#id ⇒ String
The OCID of the auth token.
38 39 40 |
# File 'lib/oci/identity/models/auth_token.rb', line 38 def id @id end |
#inactive_status ⇒ Integer
The detailed status of INACTIVE lifecycleState.
74 75 76 |
# File 'lib/oci/identity/models/auth_token.rb', line 74 def inactive_status @inactive_status end |
#lifecycle_state ⇒ String
The token's current state. After creating an auth token, make sure its `lifecycleState` changes from CREATING to ACTIVE before using it.
70 71 72 |
# File 'lib/oci/identity/models/auth_token.rb', line 70 def lifecycle_state @lifecycle_state end |
#time_created ⇒ DateTime
Date and time the `AuthToken` object was created, in the format defined by RFC3339.
Example: `2016-08-25T21:10:29.600Z`
56 57 58 |
# File 'lib/oci/identity/models/auth_token.rb', line 56 def time_created @time_created end |
#time_expires ⇒ DateTime
Date and time when this auth token will expire, in the format defined by RFC3339. Null if it never expires.
Example: `2016-08-25T21:10:29.600Z`
64 65 66 |
# File 'lib/oci/identity/models/auth_token.rb', line 64 def time_expires @time_expires end |
#token ⇒ String
The auth token. The value is available only in the response for `CreateAuthToken`, and not for `ListAuthTokens` or `UpdateAuthToken`.
34 35 36 |
# File 'lib/oci/identity/models/auth_token.rb', line 34 def token @token end |
#user_id ⇒ String
The OCID of the user the auth token belongs to.
42 43 44 |
# File 'lib/oci/identity/models/auth_token.rb', line 42 def user_id @user_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/oci/identity/models/auth_token.rb', line 77 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'token': :'token', 'id': :'id', 'user_id': :'userId', 'description': :'description', 'time_created': :'timeCreated', 'time_expires': :'timeExpires', 'lifecycle_state': :'lifecycleState', 'inactive_status': :'inactiveStatus' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/oci/identity/models/auth_token.rb', line 93 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'token': :'String', 'id': :'String', 'user_id': :'String', 'description': :'String', 'time_created': :'DateTime', 'time_expires': :'DateTime', 'lifecycle_state': :'String', 'inactive_status': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/oci/identity/models/auth_token.rb', line 185 def ==(other) return true if equal?(other) self.class == other.class && token == other.token && id == other.id && user_id == other.user_id && description == other.description && time_created == other.time_created && time_expires == other.time_expires && lifecycle_state == other.lifecycle_state && inactive_status == other.inactive_status end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/oci/identity/models/auth_token.rb', line 222 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
202 203 204 |
# File 'lib/oci/identity/models/auth_token.rb', line 202 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
211 212 213 |
# File 'lib/oci/identity/models/auth_token.rb', line 211 def hash [token, id, user_id, description, time_created, time_expires, lifecycle_state, inactive_status].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
255 256 257 258 259 260 261 262 263 264 |
# File 'lib/oci/identity/models/auth_token.rb', line 255 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
249 250 251 |
# File 'lib/oci/identity/models/auth_token.rb', line 249 def to_s to_hash.to_s end |