Class: OCI::Identity::Models::BulkEditOperationDetails
- Inherits:
-
Object
- Object
- OCI::Identity::Models::BulkEditOperationDetails
- Defined in:
- lib/oci/identity/models/bulk_edit_operation_details.rb
Overview
BulkEditOperationDetails model.
Constant Summary collapse
- OPERATION_TYPE_ENUM =
[ OPERATION_TYPE_ADD_WHERE_ABSENT = 'ADD_WHERE_ABSENT'.freeze, OPERATION_TYPE_SET_WHERE_PRESENT = 'SET_WHERE_PRESENT'.freeze, OPERATION_TYPE_ADD_OR_SET = 'ADD_OR_SET'.freeze, OPERATION_TYPE_REMOVE = 'REMOVE'.freeze ].freeze
Instance Attribute Summary collapse
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
**[Required]** Defined tags for this resource.
-
#operation_type ⇒ String
**[Required]** An enum-like description of the type of operation.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BulkEditOperationDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ BulkEditOperationDetails
Initializes the object
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/oci/identity/models/bulk_edit_operation_details.rb', line 63 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.operation_type = attributes[:'operationType'] if attributes[:'operationType'] raise 'You cannot provide both :operationType and :operation_type' if attributes.key?(:'operationType') && attributes.key?(:'operation_type') self.operation_type = attributes[:'operation_type'] if attributes[:'operation_type'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#defined_tags ⇒ Hash<String, Hash<String, Object>>
**[Required]** Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `{"CostCenter": "42"}`
33 34 35 |
# File 'lib/oci/identity/models/bulk_edit_operation_details.rb', line 33 def @defined_tags end |
#operation_type ⇒ String
**[Required]** An enum-like description of the type of operation.
-
`ADD_WHERE_ABSENT` adds a defined tag only if the tag does not already exist on the resource.
-
`SET_WHERE_PRESENT` updates the value for a defined tag only if the tag is present on the resource.
-
`ADD_OR_SET` combines the first two operations to add a defined tag if it does not already exist on the resource
or update the value for a defined tag only if the tag is present on the resource.
-
`REMOVE` removes the defined tag from the resource. The tag is removed from the resource regardless of the tag value.
26 27 28 |
# File 'lib/oci/identity/models/bulk_edit_operation_details.rb', line 26 def operation_type @operation_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
36 37 38 39 40 41 42 43 |
# File 'lib/oci/identity/models/bulk_edit_operation_details.rb', line 36 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'operation_type': :'operationType', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
46 47 48 49 50 51 52 53 |
# File 'lib/oci/identity/models/bulk_edit_operation_details.rb', line 46 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'operation_type': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
97 98 99 100 101 102 103 |
# File 'lib/oci/identity/models/bulk_edit_operation_details.rb', line 97 def ==(other) return true if equal?(other) self.class == other.class && operation_type == other.operation_type && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/oci/identity/models/bulk_edit_operation_details.rb', line 128 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
108 109 110 |
# File 'lib/oci/identity/models/bulk_edit_operation_details.rb', line 108 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
117 118 119 |
# File 'lib/oci/identity/models/bulk_edit_operation_details.rb', line 117 def hash [operation_type, ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
161 162 163 164 165 166 167 168 169 170 |
# File 'lib/oci/identity/models/bulk_edit_operation_details.rb', line 161 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
155 156 157 |
# File 'lib/oci/identity/models/bulk_edit_operation_details.rb', line 155 def to_s to_hash.to_s end |