Class: OCI::Identity::Models::CreateDynamicGroupDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/identity/models/create_dynamic_group_details.rb

Overview

Properties for creating a dynamic group.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateDynamicGroupDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :name (String)

    The value to assign to the #name property

  • :matching_rule (String)

    The value to assign to the #matching_rule property

  • :description (String)

    The value to assign to the #description property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/oci/identity/models/create_dynamic_group_details.rb', line 87

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.name = attributes[:'name'] if attributes[:'name']

  self.matching_rule = attributes[:'matchingRule'] if attributes[:'matchingRule']

  raise 'You cannot provide both :matchingRule and :matching_rule' if attributes.key?(:'matchingRule') && attributes.key?(:'matching_rule')

  self.matching_rule = attributes[:'matching_rule'] if attributes[:'matching_rule']

  self.description = attributes[:'description'] if attributes[:'description']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#compartment_idString

**[Required]** The OCID of the tenancy containing the group.

Returns:

  • (String)


12
13
14
# File 'lib/oci/identity/models/create_dynamic_group_details.rb', line 12

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


45
46
47
# File 'lib/oci/identity/models/create_dynamic_group_details.rb', line 45

def defined_tags
  @defined_tags
end

#descriptionString

**[Required]** The description you assign to the group during creation. Does not have to be unique, and it's changeable.

(For tenancies that support identity domains) You can have an empty description.

Returns:

  • (String)


31
32
33
# File 'lib/oci/identity/models/create_dynamic_group_details.rb', line 31

def description
  @description
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `"Finance"`

Returns:

  • (Hash<String, String>)


38
39
40
# File 'lib/oci/identity/models/create_dynamic_group_details.rb', line 38

def freeform_tags
  @freeform_tags
end

#matching_ruleString

**[Required]** The matching rule to dynamically match an instance certificate to this dynamic group. For rule syntax, see [Managing Dynamic Groups](docs.cloud.oracle.com/Content/Identity/dynamicgroups/managingdynamicgroups.htm).

Returns:

  • (String)


24
25
26
# File 'lib/oci/identity/models/create_dynamic_group_details.rb', line 24

def matching_rule
  @matching_rule
end

#nameString

**[Required]** The name you assign to the group during creation. The name must be unique across all groups in the tenancy and cannot be changed.

Returns:

  • (String)


18
19
20
# File 'lib/oci/identity/models/create_dynamic_group_details.rb', line 18

def name
  @name
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/oci/identity/models/create_dynamic_group_details.rb', line 48

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'compartmentId',
    'name': :'name',
    'matching_rule': :'matchingRule',
    'description': :'description',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/oci/identity/models/create_dynamic_group_details.rb', line 62

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'String',
    'name': :'String',
    'matching_rule': :'String',
    'description': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



129
130
131
132
133
134
135
136
137
138
139
# File 'lib/oci/identity/models/create_dynamic_group_details.rb', line 129

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    compartment_id == other.compartment_id &&
    name == other.name &&
    matching_rule == other.matching_rule &&
    description == other.description &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/oci/identity/models/create_dynamic_group_details.rb', line 164

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


144
145
146
# File 'lib/oci/identity/models/create_dynamic_group_details.rb', line 144

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



153
154
155
# File 'lib/oci/identity/models/create_dynamic_group_details.rb', line 153

def hash
  [compartment_id, name, matching_rule, description, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



197
198
199
200
201
202
203
204
205
206
# File 'lib/oci/identity/models/create_dynamic_group_details.rb', line 197

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



191
192
193
# File 'lib/oci/identity/models/create_dynamic_group_details.rb', line 191

def to_s
  to_hash.to_s
end