Class: OCI::Identity::Models::CreateIdentityProviderDetails
- Inherits:
-
Object
- Object
- OCI::Identity::Models::CreateIdentityProviderDetails
- Defined in:
- lib/oci/identity/models/create_identity_provider_details.rb
Overview
CreateIdentityProviderDetails model. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
Constant Summary collapse
- PRODUCT_TYPE_ENUM =
rubocop:disable Metrics/LineLength
[ PRODUCT_TYPE_IDCS = 'IDCS'.freeze, PRODUCT_TYPE_ADFS = 'ADFS'.freeze ].freeze
- PROTOCOL_ENUM =
[ PROTOCOL_SAML2 = 'SAML2'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The OCID of your tenancy.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
[Required] The description you assign to the
IdentityProviderduring creation. -
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#name ⇒ String
[Required] The name you assign to the
IdentityProviderduring creation. -
#product_type ⇒ String
[Required] The identity provider service or product.
-
#protocol ⇒ String
[Required] The protocol used for federation.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateIdentityProviderDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateIdentityProviderDetails
Initializes the object
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/oci/identity/models/create_identity_provider_details.rb', line 124 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.product_type = attributes[:'productType'] if attributes[:'productType'] raise 'You cannot provide both :productType and :product_type' if attributes.key?(:'productType') && attributes.key?(:'product_type') self.product_type = attributes[:'product_type'] if attributes[:'product_type'] self.protocol = attributes[:'protocol'] if attributes[:'protocol'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The OCID of your tenancy.
21 22 23 |
# File 'lib/oci/identity/models/create_identity_provider_details.rb', line 21 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.us-phoenix-1.oraclecloud.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"CostCenter": "42"}`
64 65 66 |
# File 'lib/oci/identity/models/create_identity_provider_details.rb', line 64 def @defined_tags end |
#description ⇒ String
[Required] The description you assign to the IdentityProvider during creation. Does not have to be unique, and it’s changeable.
34 35 36 |
# File 'lib/oci/identity/models/create_identity_provider_details.rb', line 34 def description @description end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.us-phoenix-1.oraclecloud.com/Content/General/Concepts/resourcetags.htm). Example: ‘"Finance"`
57 58 59 |
# File 'lib/oci/identity/models/create_identity_provider_details.rb', line 57 def @freeform_tags end |
#name ⇒ String
[Required] The name you assign to the IdentityProvider during creation. The name must be unique across all IdentityProvider objects in the tenancy and cannot be changed.
28 29 30 |
# File 'lib/oci/identity/models/create_identity_provider_details.rb', line 28 def name @name end |
#product_type ⇒ String
[Required] The identity provider service or product. Supported identity providers are Oracle Identity Cloud Service (IDCS) and Microsoft Active Directory Federation Services (ADFS).
Example: IDCS
43 44 45 |
# File 'lib/oci/identity/models/create_identity_provider_details.rb', line 43 def product_type @product_type end |
#protocol ⇒ String
[Required] The protocol used for federation.
Example: SAML2
50 51 52 |
# File 'lib/oci/identity/models/create_identity_provider_details.rb', line 50 def protocol @protocol end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/oci/identity/models/create_identity_provider_details.rb', line 67 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'name': :'name', 'description': :'description', 'product_type': :'productType', 'protocol': :'protocol', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
101 102 103 104 105 106 107 108 |
# File 'lib/oci/identity/models/create_identity_provider_details.rb', line 101 def self.get_subtype(object_hash) type = object_hash[:'protocol'] # rubocop:disable Style/SymbolLiteral return 'OCI::Identity::Models::CreateSaml2IdentityProviderDetails' if type == 'SAML2' # TODO: Log a warning when the subtype is not found. 'OCI::Identity::Models::CreateIdentityProviderDetails' end |
.swagger_types ⇒ Object
Attribute type mapping.
82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/oci/identity/models/create_identity_provider_details.rb', line 82 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'name': :'String', 'description': :'String', 'product_type': :'String', 'protocol': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/oci/identity/models/create_identity_provider_details.rb', line 188 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && name == other.name && description == other.description && product_type == other.product_type && protocol == other.protocol && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 |
# File 'lib/oci/identity/models/create_identity_provider_details.rb', line 224 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
204 205 206 |
# File 'lib/oci/identity/models/create_identity_provider_details.rb', line 204 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
213 214 215 |
# File 'lib/oci/identity/models/create_identity_provider_details.rb', line 213 def hash [compartment_id, name, description, product_type, protocol, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
257 258 259 260 261 262 263 264 265 266 |
# File 'lib/oci/identity/models/create_identity_provider_details.rb', line 257 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
251 252 253 |
# File 'lib/oci/identity/models/create_identity_provider_details.rb', line 251 def to_s to_hash.to_s end |