Class: OCI::Identity::Models::CreateTagDefaultDetails
- Inherits:
-
Object
- Object
- OCI::Identity::Models::CreateTagDefaultDetails
- Defined in:
- lib/oci/identity/models/create_tag_default_details.rb
Overview
CreateTagDefaultDetails model.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The OCID of the compartment.
-
#is_required ⇒ BOOLEAN
If you specify that a value is required, a value is set during resource creation (either by the user creating the resource or another tag defualt).
-
#locks ⇒ Array<OCI::Identity::Models::AddLockDetails>
Locks associated with this resource.
-
#tag_definition_id ⇒ String
**[Required]** The OCID of the tag definition.
-
#value ⇒ String
**[Required]** The default value for the tag definition.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateTagDefaultDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateTagDefaultDetails
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/oci/identity/models/create_tag_default_details.rb', line 78 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.tag_definition_id = attributes[:'tagDefinitionId'] if attributes[:'tagDefinitionId'] raise 'You cannot provide both :tagDefinitionId and :tag_definition_id' if attributes.key?(:'tagDefinitionId') && attributes.key?(:'tag_definition_id') self.tag_definition_id = attributes[:'tag_definition_id'] if attributes[:'tag_definition_id'] self.value = attributes[:'value'] if attributes[:'value'] self.is_required = attributes[:'isRequired'] unless attributes[:'isRequired'].nil? raise 'You cannot provide both :isRequired and :is_required' if attributes.key?(:'isRequired') && attributes.key?(:'is_required') self.is_required = attributes[:'is_required'] unless attributes[:'is_required'].nil? self.locks = attributes[:'locks'] if attributes[:'locks'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The OCID of the compartment. The tag default will be applied to all new resources created in this compartment.
13 14 15 |
# File 'lib/oci/identity/models/create_tag_default_details.rb', line 13 def compartment_id @compartment_id end |
#is_required ⇒ BOOLEAN
If you specify that a value is required, a value is set during resource creation (either by the user creating the resource or another tag defualt). If no value is set, resource creation is blocked.
-
If the `isRequired` flag is set to "true", the value is set during resource creation.
-
If the `isRequired` flag is set to "false", the value you enter is set during resource creation.
Example: `false`
35 36 37 |
# File 'lib/oci/identity/models/create_tag_default_details.rb', line 35 def is_required @is_required end |
#locks ⇒ Array<OCI::Identity::Models::AddLockDetails>
Locks associated with this resource.
39 40 41 |
# File 'lib/oci/identity/models/create_tag_default_details.rb', line 39 def locks @locks end |
#tag_definition_id ⇒ String
**[Required]** The OCID of the tag definition. The tag default will always assign a default value for this tag definition.
18 19 20 |
# File 'lib/oci/identity/models/create_tag_default_details.rb', line 18 def tag_definition_id @tag_definition_id end |
#value ⇒ String
**[Required]** The default value for the tag definition. This will be applied to all new resources created in the compartment.
23 24 25 |
# File 'lib/oci/identity/models/create_tag_default_details.rb', line 23 def value @value end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/oci/identity/models/create_tag_default_details.rb', line 42 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'tag_definition_id': :'tagDefinitionId', 'value': :'value', 'is_required': :'isRequired', 'locks': :'locks' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/oci/identity/models/create_tag_default_details.rb', line 55 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'tag_definition_id': :'String', 'value': :'String', 'is_required': :'BOOLEAN', 'locks': :'Array<OCI::Identity::Models::AddLockDetails>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
114 115 116 117 118 119 120 121 122 123 |
# File 'lib/oci/identity/models/create_tag_default_details.rb', line 114 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && tag_definition_id == other.tag_definition_id && value == other.value && is_required == other.is_required && locks == other.locks end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/oci/identity/models/create_tag_default_details.rb', line 148 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
128 129 130 |
# File 'lib/oci/identity/models/create_tag_default_details.rb', line 128 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
137 138 139 |
# File 'lib/oci/identity/models/create_tag_default_details.rb', line 137 def hash [compartment_id, tag_definition_id, value, is_required, locks].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
181 182 183 184 185 186 187 188 189 190 |
# File 'lib/oci/identity/models/create_tag_default_details.rb', line 181 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
175 176 177 |
# File 'lib/oci/identity/models/create_tag_default_details.rb', line 175 def to_s to_hash.to_s end |