Class: OCI::Identity::Models::CreateTagDetails
- Inherits:
-
Object
- Object
- OCI::Identity::Models::CreateTagDetails
- Defined in:
- lib/oci/identity/models/create_tag_details.rb
Overview
CreateTagDetails model.
Instance Attribute Summary collapse
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
[Required] The description you assign to the tag during creation.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#is_cost_tracking ⇒ BOOLEAN
Indicates whether the tag is enabled for cost tracking.
-
#name ⇒ String
[Required] The name you assign to the tag during creation.
- #validator ⇒ OCI::Identity::Models::BaseTagDefinitionValidator
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateTagDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateTagDetails
Initializes the object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/oci/identity/models/create_tag_details.rb', line 84 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.is_cost_tracking = attributes[:'isCostTracking'] unless attributes[:'isCostTracking'].nil? raise 'You cannot provide both :isCostTracking and :is_cost_tracking' if attributes.key?(:'isCostTracking') && attributes.key?(:'is_cost_tracking') self.is_cost_tracking = attributes[:'is_cost_tracking'] unless attributes[:'is_cost_tracking'].nil? self.validator = attributes[:'validator'] if attributes[:'validator'] end |
Instance Attribute Details
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
34 35 36 |
# File 'lib/oci/identity/models/create_tag_details.rb', line 34 def end |
#description ⇒ String
[Required] The description you assign to the tag during creation.
18 19 20 |
# File 'lib/oci/identity/models/create_tag_details.rb', line 18 def description @description end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
26 27 28 |
# File 'lib/oci/identity/models/create_tag_details.rb', line 26 def end |
#is_cost_tracking ⇒ BOOLEAN
Indicates whether the tag is enabled for cost tracking.
39 40 41 |
# File 'lib/oci/identity/models/create_tag_details.rb', line 39 def is_cost_tracking @is_cost_tracking end |
#name ⇒ String
[Required] The name you assign to the tag during creation. This is the tag key definition. The name must be unique within the tag namespace and cannot be changed.
14 15 16 |
# File 'lib/oci/identity/models/create_tag_details.rb', line 14 def name @name end |
#validator ⇒ OCI::Identity::Models::BaseTagDefinitionValidator
42 43 44 |
# File 'lib/oci/identity/models/create_tag_details.rb', line 42 def validator @validator end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/oci/identity/models/create_tag_details.rb', line 45 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'description': :'description', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'is_cost_tracking': :'isCostTracking', 'validator': :'validator' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/oci/identity/models/create_tag_details.rb', line 59 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'description': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'is_cost_tracking': :'BOOLEAN', 'validator': :'OCI::Identity::Models::BaseTagDefinitionValidator' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/oci/identity/models/create_tag_details.rb', line 122 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && description == other.description && == other. && == other. && is_cost_tracking == other.is_cost_tracking && validator == other.validator end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/oci/identity/models/create_tag_details.rb', line 157 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
137 138 139 |
# File 'lib/oci/identity/models/create_tag_details.rb', line 137 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
146 147 148 |
# File 'lib/oci/identity/models/create_tag_details.rb', line 146 def hash [name, description, , , is_cost_tracking, validator].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
190 191 192 193 194 195 196 197 198 199 |
# File 'lib/oci/identity/models/create_tag_details.rb', line 190 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
184 185 186 |
# File 'lib/oci/identity/models/create_tag_details.rb', line 184 def to_s to_hash.to_s end |