Class: OCI::Identity::Models::DefaultTagDefinitionValidator
- Inherits:
-
BaseTagDefinitionValidator
- Object
- BaseTagDefinitionValidator
- OCI::Identity::Models::DefaultTagDefinitionValidator
- Defined in:
- lib/oci/identity/models/default_tag_definition_validator.rb
Overview
Use this validator to clear any existing validator on the tag key definition with the UpdateTag operation. Using this validatorType is the same as not setting any value on the validator field. The resultant value for validatorType returned in the response body is null.
Constant Summary
Constants inherited from BaseTagDefinitionValidator
BaseTagDefinitionValidator::VALIDATOR_TYPE_ENUM
Instance Attribute Summary
Attributes inherited from BaseTagDefinitionValidator
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DefaultTagDefinitionValidator
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from BaseTagDefinitionValidator
Constructor Details
#initialize(attributes = {}) ⇒ DefaultTagDefinitionValidator
Initializes the object
38 39 40 41 42 43 44 |
# File 'lib/oci/identity/models/default_tag_definition_validator.rb', line 38 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['validatorType'] = 'DEFAULT' super(attributes) end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
15 16 17 18 19 20 21 |
# File 'lib/oci/identity/models/default_tag_definition_validator.rb', line 15 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'validator_type': :'validatorType' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
24 25 26 27 28 29 30 |
# File 'lib/oci/identity/models/default_tag_definition_validator.rb', line 24 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'validator_type': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
53 54 55 56 57 58 |
# File 'lib/oci/identity/models/default_tag_definition_validator.rb', line 53 def ==(other) return true if equal?(other) self.class == other.class && validator_type == other.validator_type end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/oci/identity/models/default_tag_definition_validator.rb', line 83 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
63 64 65 |
# File 'lib/oci/identity/models/default_tag_definition_validator.rb', line 63 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
72 73 74 |
# File 'lib/oci/identity/models/default_tag_definition_validator.rb', line 72 def hash [validator_type].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
116 117 118 119 120 121 122 123 124 125 |
# File 'lib/oci/identity/models/default_tag_definition_validator.rb', line 116 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
110 111 112 |
# File 'lib/oci/identity/models/default_tag_definition_validator.rb', line 110 def to_s to_hash.to_s end |