Class: OCI::Identity::Models::DomainReplication

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/identity/models/domain_replication.rb

Overview

Domain replication states.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DomainReplication

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/oci/identity/models/domain_replication.rb', line 53

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.opc_water_mark = attributes[:'opcWaterMark'] if attributes[:'opcWaterMark']

  raise 'You cannot provide both :opcWaterMark and :opc_water_mark' if attributes.key?(:'opcWaterMark') && attributes.key?(:'opc_water_mark')

  self.opc_water_mark = attributes[:'opc_water_mark'] if attributes[:'opc_water_mark']

  self.txn_seq_number = attributes[:'txnSeqNumber'] if attributes[:'txnSeqNumber']

  raise 'You cannot provide both :txnSeqNumber and :txn_seq_number' if attributes.key?(:'txnSeqNumber') && attributes.key?(:'txn_seq_number')

  self.txn_seq_number = attributes[:'txn_seq_number'] if attributes[:'txn_seq_number']

  self.domain_replication_states = attributes[:'domainReplicationStates'] if attributes[:'domainReplicationStates']

  raise 'You cannot provide both :domainReplicationStates and :domain_replication_states' if attributes.key?(:'domainReplicationStates') && attributes.key?(:'domain_replication_states')

  self.domain_replication_states = attributes[:'domain_replication_states'] if attributes[:'domain_replication_states']
end

Instance Attribute Details

#domain_replication_statesArray<OCI::Identity::Models::DomainReplicationStates>

[Required] The domain’s replication state



20
21
22
# File 'lib/oci/identity/models/domain_replication.rb', line 20

def domain_replication_states
  @domain_replication_states
end

#opc_water_markFloat

[Required] Version number indicating the value of kievTxnId, starting from which, the domain replication events need to be returned.

Returns:

  • (Float)


12
13
14
# File 'lib/oci/identity/models/domain_replication.rb', line 12

def opc_water_mark
  @opc_water_mark
end

#txn_seq_numberFloat

[Required] Custom value defining the order of records with same kievTxnId

Returns:

  • (Float)


16
17
18
# File 'lib/oci/identity/models/domain_replication.rb', line 16

def txn_seq_number
  @txn_seq_number
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



23
24
25
26
27
28
29
30
31
# File 'lib/oci/identity/models/domain_replication.rb', line 23

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'opc_water_mark': :'opcWaterMark',
    'txn_seq_number': :'txnSeqNumber',
    'domain_replication_states': :'domainReplicationStates'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



34
35
36
37
38
39
40
41
42
# File 'lib/oci/identity/models/domain_replication.rb', line 34

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'opc_water_mark': :'Float',
    'txn_seq_number': :'Float',
    'domain_replication_states': :'Array<OCI::Identity::Models::DomainReplicationStates>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



85
86
87
88
89
90
91
92
# File 'lib/oci/identity/models/domain_replication.rb', line 85

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    opc_water_mark == other.opc_water_mark &&
    txn_seq_number == other.txn_seq_number &&
    domain_replication_states == other.domain_replication_states
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/oci/identity/models/domain_replication.rb', line 117

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


97
98
99
# File 'lib/oci/identity/models/domain_replication.rb', line 97

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



106
107
108
# File 'lib/oci/identity/models/domain_replication.rb', line 106

def hash
  [opc_water_mark, txn_seq_number, domain_replication_states].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



150
151
152
153
154
155
156
157
158
159
# File 'lib/oci/identity/models/domain_replication.rb', line 150

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



144
145
146
# File 'lib/oci/identity/models/domain_replication.rb', line 144

def to_s
  to_hash.to_s
end