Class: OCI::Identity::Models::DomainSummary
- Inherits:
-
Object
- Object
- OCI::Identity::Models::DomainSummary
- Defined in:
- lib/oci/identity/models/domain_summary.rb
Overview
As the name suggests, a DomainSummary object contains information about a Domain.
Constant Summary collapse
- TYPE_ENUM =
[ TYPE_DEFAULT = 'DEFAULT'.freeze, TYPE_SECONDARY = 'SECONDARY'.freeze, TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_DETAILS_ENUM =
[ LIFECYCLE_DETAILS_DEACTIVATING = 'DEACTIVATING'.freeze, LIFECYCLE_DETAILS_ACTIVATING = 'ACTIVATING'.freeze, LIFECYCLE_DETAILS_UPDATING = 'UPDATING'.freeze, LIFECYCLE_DETAILS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The OCID of the comparment containing the domain.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
[Required] The domain descripition.
-
#display_name ⇒ String
[Required] The mutable display name of the domain.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#home_region ⇒ String
[Required] The home region for the domain.
-
#home_region_url ⇒ String
[Required] Region specific domain URL.
-
#id ⇒ String
[Required] The OCID of the domain.
-
#is_hidden_on_login ⇒ BOOLEAN
[Required] Indicates whether domain is hidden on login screen or not.
-
#license_type ⇒ String
[Required] The License type of Domain.
-
#lifecycle_details ⇒ String
Any additional details about the current state of the Domain.
-
#lifecycle_state ⇒ String
[Required] The current state.
-
#replica_regions ⇒ Array<OCI::Identity::Models::ReplicatedRegionDetails>
[Required] The regions domain is replicated to.
-
#time_created ⇒ DateTime
[Required] Date and time the domain was created, in the format defined by RFC3339.
-
#type ⇒ String
[Required] The type of the domain.
-
#url ⇒ String
[Required] Region agnostic domain URL.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DomainSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DomainSummary
Initializes the object
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 |
# File 'lib/oci/identity/models/domain_summary.rb', line 180 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.url = attributes[:'url'] if attributes[:'url'] self.home_region_url = attributes[:'homeRegionUrl'] if attributes[:'homeRegionUrl'] raise 'You cannot provide both :homeRegionUrl and :home_region_url' if attributes.key?(:'homeRegionUrl') && attributes.key?(:'home_region_url') self.home_region_url = attributes[:'home_region_url'] if attributes[:'home_region_url'] self.home_region = attributes[:'homeRegion'] if attributes[:'homeRegion'] raise 'You cannot provide both :homeRegion and :home_region' if attributes.key?(:'homeRegion') && attributes.key?(:'home_region') self.home_region = attributes[:'home_region'] if attributes[:'home_region'] self.replica_regions = attributes[:'replicaRegions'] if attributes[:'replicaRegions'] raise 'You cannot provide both :replicaRegions and :replica_regions' if attributes.key?(:'replicaRegions') && attributes.key?(:'replica_regions') self.replica_regions = attributes[:'replica_regions'] if attributes[:'replica_regions'] self.type = attributes[:'type'] if attributes[:'type'] self.license_type = attributes[:'licenseType'] if attributes[:'licenseType'] raise 'You cannot provide both :licenseType and :license_type' if attributes.key?(:'licenseType') && attributes.key?(:'license_type') self.license_type = attributes[:'license_type'] if attributes[:'license_type'] self.is_hidden_on_login = attributes[:'isHiddenOnLogin'] unless attributes[:'isHiddenOnLogin'].nil? raise 'You cannot provide both :isHiddenOnLogin and :is_hidden_on_login' if attributes.key?(:'isHiddenOnLogin') && attributes.key?(:'is_hidden_on_login') self.is_hidden_on_login = attributes[:'is_hidden_on_login'] unless attributes[:'is_hidden_on_login'].nil? self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The OCID of the comparment containing the domain.
39 40 41 |
# File 'lib/oci/identity/models/domain_summary.rb', line 39 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"CostCenter": "42"}`
108 109 110 |
# File 'lib/oci/identity/models/domain_summary.rb', line 108 def @defined_tags end |
#description ⇒ String
[Required] The domain descripition
47 48 49 |
# File 'lib/oci/identity/models/domain_summary.rb', line 47 def description @description end |
#display_name ⇒ String
[Required] The mutable display name of the domain
43 44 45 |
# File 'lib/oci/identity/models/domain_summary.rb', line 43 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"Finance"`
101 102 103 |
# File 'lib/oci/identity/models/domain_summary.rb', line 101 def @freeform_tags end |
#home_region ⇒ String
[Required] The home region for the domain.
59 60 61 |
# File 'lib/oci/identity/models/domain_summary.rb', line 59 def home_region @home_region end |
#home_region_url ⇒ String
[Required] Region specific domain URL.
55 56 57 |
# File 'lib/oci/identity/models/domain_summary.rb', line 55 def home_region_url @home_region_url end |
#id ⇒ String
[Required] The OCID of the domain
35 36 37 |
# File 'lib/oci/identity/models/domain_summary.rb', line 35 def id @id end |
#is_hidden_on_login ⇒ BOOLEAN
[Required] Indicates whether domain is hidden on login screen or not.
77 78 79 |
# File 'lib/oci/identity/models/domain_summary.rb', line 77 def is_hidden_on_login @is_hidden_on_login end |
#license_type ⇒ String
[Required] The License type of Domain
72 73 74 |
# File 'lib/oci/identity/models/domain_summary.rb', line 72 def license_type @license_type end |
#lifecycle_details ⇒ String
Any additional details about the current state of the Domain.
94 95 96 |
# File 'lib/oci/identity/models/domain_summary.rb', line 94 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
[Required] The current state.
89 90 91 |
# File 'lib/oci/identity/models/domain_summary.rb', line 89 def lifecycle_state @lifecycle_state end |
#replica_regions ⇒ Array<OCI::Identity::Models::ReplicatedRegionDetails>
[Required] The regions domain is replicated to.
63 64 65 |
# File 'lib/oci/identity/models/domain_summary.rb', line 63 def replica_regions @replica_regions end |
#time_created ⇒ DateTime
[Required] Date and time the domain was created, in the format defined by RFC3339.
Example: 2016-08-25T21:10:29.600Z
84 85 86 |
# File 'lib/oci/identity/models/domain_summary.rb', line 84 def time_created @time_created end |
#type ⇒ String
[Required] The type of the domain.
68 69 70 |
# File 'lib/oci/identity/models/domain_summary.rb', line 68 def type @type end |
#url ⇒ String
[Required] Region agnostic domain URL.
51 52 53 |
# File 'lib/oci/identity/models/domain_summary.rb', line 51 def url @url end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/oci/identity/models/domain_summary.rb', line 111 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'description': :'description', 'url': :'url', 'home_region_url': :'homeRegionUrl', 'home_region': :'homeRegion', 'replica_regions': :'replicaRegions', 'type': :'type', 'license_type': :'licenseType', 'is_hidden_on_login': :'isHiddenOnLogin', 'time_created': :'timeCreated', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/oci/identity/models/domain_summary.rb', line 135 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'display_name': :'String', 'description': :'String', 'url': :'String', 'home_region_url': :'String', 'home_region': :'String', 'replica_regions': :'Array<OCI::Identity::Models::ReplicatedRegionDetails>', 'type': :'String', 'license_type': :'String', 'is_hidden_on_login': :'BOOLEAN', 'time_created': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 |
# File 'lib/oci/identity/models/domain_summary.rb', line 313 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && display_name == other.display_name && description == other.description && url == other.url && home_region_url == other.home_region_url && home_region == other.home_region && replica_regions == other.replica_regions && type == other.type && license_type == other.license_type && is_hidden_on_login == other.is_hidden_on_login && time_created == other.time_created && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/oci/identity/models/domain_summary.rb', line 358 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
338 339 340 |
# File 'lib/oci/identity/models/domain_summary.rb', line 338 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
347 348 349 |
# File 'lib/oci/identity/models/domain_summary.rb', line 347 def hash [id, compartment_id, display_name, description, url, home_region_url, home_region, replica_regions, type, license_type, is_hidden_on_login, time_created, lifecycle_state, lifecycle_details, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
391 392 393 394 395 396 397 398 399 400 |
# File 'lib/oci/identity/models/domain_summary.rb', line 391 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
385 386 387 |
# File 'lib/oci/identity/models/domain_summary.rb', line 385 def to_s to_hash.to_s end |