Class: OCI::Identity::Models::Group
- Inherits:
-
Object
- Object
- OCI::Identity::Models::Group
- Defined in:
- lib/oci/identity/models/group.rb
Overview
A collection of users who all need the same type of access to a particular set of resources or compartment. For conceptual information about groups and other IAM Service components, see [Overview of IAM](docs.cloud.oracle.com/Content/Identity/getstarted/identity-domains.htm).
If you're federating with an identity provider (IdP), you need to create mappings between the groups defined in the IdP and groups you define in the IAM service. For more information, see [Identity Providers and Federation](docs.cloud.oracle.com/Content/Identity/Concepts/federation.htm). Also see IdentityProvider and IdpGroupMapping.
To use any of the API operations, you must be authorized in an IAM policy. If you're not authorized, talk to an administrator. If you're an administrator who needs to write policies to give users access, see [Get Started with Policies](docs.cloud.oracle.com/Content/Identity/policiesgs/get-started-with-policies.htm).
*Warning:* Oracle recommends that you avoid using any confidential information when you supply string values using the API.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The OCID of the tenancy containing the group.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
**[Required]** The description you assign to the group.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
**[Required]** The OCID of the group.
-
#inactive_status ⇒ Integer
The detailed status of INACTIVE lifecycleState.
-
#lifecycle_state ⇒ String
**[Required]** The group's current state.
-
#name ⇒ String
**[Required]** The name you assign to the group during creation.
-
#time_created ⇒ DateTime
**[Required]** Date and time the group was created, in the format defined by RFC3339.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Group
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Group
Initializes the object
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/oci/identity/models/group.rb', line 137 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.inactive_status = attributes[:'inactiveStatus'] if attributes[:'inactiveStatus'] raise 'You cannot provide both :inactiveStatus and :inactive_status' if attributes.key?(:'inactiveStatus') && attributes.key?(:'inactive_status') self.inactive_status = attributes[:'inactive_status'] if attributes[:'inactive_status'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The OCID of the tenancy containing the group.
42 43 44 |
# File 'lib/oci/identity/models/group.rb', line 42 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `{"CostCenter": "42"}`
86 87 88 |
# File 'lib/oci/identity/models/group.rb', line 86 def @defined_tags end |
#description ⇒ String
**[Required]** The description you assign to the group. Does not have to be unique, and it's changeable.
(For tenancies that support identity domains) You can have an empty description.
55 56 57 |
# File 'lib/oci/identity/models/group.rb', line 55 def description @description end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `"Finance"`
79 80 81 |
# File 'lib/oci/identity/models/group.rb', line 79 def @freeform_tags end |
#id ⇒ String
**[Required]** The OCID of the group.
38 39 40 |
# File 'lib/oci/identity/models/group.rb', line 38 def id @id end |
#inactive_status ⇒ Integer
The detailed status of INACTIVE lifecycleState.
72 73 74 |
# File 'lib/oci/identity/models/group.rb', line 72 def inactive_status @inactive_status end |
#lifecycle_state ⇒ String
**[Required]** The group's current state. After creating a group, make sure its `lifecycleState` changes from CREATING to ACTIVE before using it.
68 69 70 |
# File 'lib/oci/identity/models/group.rb', line 68 def lifecycle_state @lifecycle_state end |
#name ⇒ String
**[Required]** The name you assign to the group during creation. The name must be unique across all groups in the tenancy and cannot be changed.
48 49 50 |
# File 'lib/oci/identity/models/group.rb', line 48 def name @name end |
#time_created ⇒ DateTime
**[Required]** Date and time the group was created, in the format defined by RFC3339.
Example: `2016-08-25T21:10:29.600Z`
62 63 64 |
# File 'lib/oci/identity/models/group.rb', line 62 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/oci/identity/models/group.rb', line 89 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'name': :'name', 'description': :'description', 'time_created': :'timeCreated', 'lifecycle_state': :'lifecycleState', 'inactive_status': :'inactiveStatus', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/oci/identity/models/group.rb', line 106 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'name': :'String', 'description': :'String', 'time_created': :'DateTime', 'lifecycle_state': :'String', 'inactive_status': :'Integer', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
206 207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/oci/identity/models/group.rb', line 206 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && name == other.name && description == other.description && time_created == other.time_created && lifecycle_state == other.lifecycle_state && inactive_status == other.inactive_status && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/oci/identity/models/group.rb', line 244 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
224 225 226 |
# File 'lib/oci/identity/models/group.rb', line 224 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
233 234 235 |
# File 'lib/oci/identity/models/group.rb', line 233 def hash [id, compartment_id, name, description, time_created, lifecycle_state, inactive_status, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
277 278 279 280 281 282 283 284 285 286 |
# File 'lib/oci/identity/models/group.rb', line 277 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
271 272 273 |
# File 'lib/oci/identity/models/group.rb', line 271 def to_s to_hash.to_s end |