Class: OCI::Identity::Models::NetworkSources
- Inherits:
-
Object
- Object
- OCI::Identity::Models::NetworkSources
- Defined in:
- lib/oci/identity/models/network_sources.rb
Overview
A network source specifies a list of source IP addresses that are allowed to make authorization requests. Use the network source in policy statements to restrict access to only requests that come from the specified IPs. For more information, see [Managing Network Sources](docs.cloud.oracle.com/Content/Identity/Tasks/managingnetworksources.htm).
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The OCID of the tenancy containing the network source.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
**[Required]** The description you assign to the network source.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
**[Required]** The OCID of the network source.
-
#inactive_status ⇒ Integer
The detailed status of INACTIVE lifecycleState.
-
#lifecycle_state ⇒ String
**[Required]** The network source object's current state.
-
#name ⇒ String
**[Required]** The name you assign to the network source during creation.
-
#public_source_list ⇒ Array<String>
A list of allowed public IPs and CIDR ranges.
-
#services ⇒ Array<String>
– The services attribute has no effect and is reserved for use by Oracle.
-
#time_created ⇒ DateTime
**[Required]** Date and time the group was created, in the format defined by RFC3339.
-
#virtual_source_list ⇒ Array<OCI::Identity::Models::NetworkSourcesVirtualSourceList>
A list of allowed VCN OCID and IP range pairs.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NetworkSources
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ NetworkSources
Initializes the object
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/oci/identity/models/network_sources.rb', line 146 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.public_source_list = attributes[:'publicSourceList'] if attributes[:'publicSourceList'] raise 'You cannot provide both :publicSourceList and :public_source_list' if attributes.key?(:'publicSourceList') && attributes.key?(:'public_source_list') self.public_source_list = attributes[:'public_source_list'] if attributes[:'public_source_list'] self.virtual_source_list = attributes[:'virtualSourceList'] if attributes[:'virtualSourceList'] raise 'You cannot provide both :virtualSourceList and :virtual_source_list' if attributes.key?(:'virtualSourceList') && attributes.key?(:'virtual_source_list') self.virtual_source_list = attributes[:'virtual_source_list'] if attributes[:'virtual_source_list'] self.services = attributes[:'services'] if attributes[:'services'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.inactive_status = attributes[:'inactiveStatus'] if attributes[:'inactiveStatus'] raise 'You cannot provide both :inactiveStatus and :inactive_status' if attributes.key?(:'inactiveStatus') && attributes.key?(:'inactive_status') self.inactive_status = attributes[:'inactive_status'] if attributes[:'inactive_status'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The OCID of the tenancy containing the network source. The tenancy is the root compartment.
29 30 31 |
# File 'lib/oci/identity/models/network_sources.rb', line 29 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `{"CostCenter": "42"}`
86 87 88 |
# File 'lib/oci/identity/models/network_sources.rb', line 86 def @defined_tags end |
#description ⇒ String
**[Required]** The description you assign to the network source. Does not have to be unique, and it's changeable.
39 40 41 |
# File 'lib/oci/identity/models/network_sources.rb', line 39 def description @description end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `"Finance"`
79 80 81 |
# File 'lib/oci/identity/models/network_sources.rb', line 79 def @freeform_tags end |
#id ⇒ String
**[Required]** The OCID of the network source.
25 26 27 |
# File 'lib/oci/identity/models/network_sources.rb', line 25 def id @id end |
#inactive_status ⇒ Integer
The detailed status of INACTIVE lifecycleState.
72 73 74 |
# File 'lib/oci/identity/models/network_sources.rb', line 72 def inactive_status @inactive_status end |
#lifecycle_state ⇒ String
**[Required]** The network source object's current state. After creating a network source, make sure its `lifecycleState` changes from CREATING to ACTIVE before using it.
68 69 70 |
# File 'lib/oci/identity/models/network_sources.rb', line 68 def lifecycle_state @lifecycle_state end |
#name ⇒ String
**[Required]** The name you assign to the network source during creation. The name must be unique across the tenancy and cannot be changed.
35 36 37 |
# File 'lib/oci/identity/models/network_sources.rb', line 35 def name @name end |
#public_source_list ⇒ Array<String>
A list of allowed public IPs and CIDR ranges.
44 45 46 |
# File 'lib/oci/identity/models/network_sources.rb', line 44 def public_source_list @public_source_list end |
#services ⇒ Array<String>
– The services attribute has no effect and is reserved for use by Oracle. –
55 56 57 |
# File 'lib/oci/identity/models/network_sources.rb', line 55 def services @services end |
#time_created ⇒ DateTime
**[Required]** Date and time the group was created, in the format defined by RFC3339.
Example: `2016-08-25T21:10:29.600Z`
62 63 64 |
# File 'lib/oci/identity/models/network_sources.rb', line 62 def time_created @time_created end |
#virtual_source_list ⇒ Array<OCI::Identity::Models::NetworkSourcesVirtualSourceList>
A list of allowed VCN OCID and IP range pairs. Example:`"vcnId": "ocid1.vcn.oc1.iad.aaaaaaaaexampleuniqueID", "ipRanges": [ "129.213.39.0/24" ]`
50 51 52 |
# File 'lib/oci/identity/models/network_sources.rb', line 50 def virtual_source_list @virtual_source_list end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/oci/identity/models/network_sources.rb', line 89 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'name': :'name', 'description': :'description', 'public_source_list': :'publicSourceList', 'virtual_source_list': :'virtualSourceList', 'services': :'services', 'time_created': :'timeCreated', 'lifecycle_state': :'lifecycleState', 'inactive_status': :'inactiveStatus', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/oci/identity/models/network_sources.rb', line 109 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'name': :'String', 'description': :'String', 'public_source_list': :'Array<String>', 'virtual_source_list': :'Array<OCI::Identity::Models::NetworkSourcesVirtualSourceList>', 'services': :'Array<String>', 'time_created': :'DateTime', 'lifecycle_state': :'String', 'inactive_status': :'Integer', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/oci/identity/models/network_sources.rb', line 229 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && name == other.name && description == other.description && public_source_list == other.public_source_list && virtual_source_list == other.virtual_source_list && services == other.services && time_created == other.time_created && lifecycle_state == other.lifecycle_state && inactive_status == other.inactive_status && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 |
# File 'lib/oci/identity/models/network_sources.rb', line 270 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
250 251 252 |
# File 'lib/oci/identity/models/network_sources.rb', line 250 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
259 260 261 |
# File 'lib/oci/identity/models/network_sources.rb', line 259 def hash [id, compartment_id, name, description, public_source_list, virtual_source_list, services, time_created, lifecycle_state, inactive_status, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
303 304 305 306 307 308 309 310 311 312 |
# File 'lib/oci/identity/models/network_sources.rb', line 303 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
297 298 299 |
# File 'lib/oci/identity/models/network_sources.rb', line 297 def to_s to_hash.to_s end |