Class: OCI::Identity::Models::ResourceLock
- Inherits:
-
Object
- Object
- OCI::Identity::Models::ResourceLock
- Defined in:
- lib/oci/identity/models/resource_lock.rb
Overview
Resource locks are used to prevent certain APIs from being called for the resource. A full lock prevents both updating the resource and deleting the resource. A delete lock prevents deleting the resource.
Constant Summary collapse
- TYPE_ENUM =
[ TYPE_FULL = 'FULL'.freeze, TYPE_DELETE = 'DELETE'.freeze, TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#is_active ⇒ BOOLEAN
Indicates if the lock is active or not.
-
#message ⇒ String
A message added by the creator of the lock.
-
#related_resource_id ⇒ String
The ID of the resource that is locking this resource.
-
#time_created ⇒ DateTime
When the lock was created.
-
#type ⇒ String
**[Required]** Type of the lock.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ResourceLock
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ResourceLock
Initializes the object
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/oci/identity/models/resource_lock.rb', line 80 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.type = attributes[:'type'] if attributes[:'type'] self. = attributes[:'relatedResourceId'] if attributes[:'relatedResourceId'] raise 'You cannot provide both :relatedResourceId and :related_resource_id' if attributes.key?(:'relatedResourceId') && attributes.key?(:'related_resource_id') self. = attributes[:'related_resource_id'] if attributes[:'related_resource_id'] self. = attributes[:'message'] if attributes[:'message'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.is_active = attributes[:'isActive'] unless attributes[:'isActive'].nil? raise 'You cannot provide both :isActive and :is_active' if attributes.key?(:'isActive') && attributes.key?(:'is_active') self.is_active = attributes[:'is_active'] unless attributes[:'is_active'].nil? end |
Instance Attribute Details
#is_active ⇒ BOOLEAN
Indicates if the lock is active or not. For example, if there are mutliple FULL locks, the first-created FULL lock will be effective.
41 42 43 |
# File 'lib/oci/identity/models/resource_lock.rb', line 41 def is_active @is_active end |
#message ⇒ String
A message added by the creator of the lock. This is typically used to give an indication of why the resource is locked.
33 34 35 |
# File 'lib/oci/identity/models/resource_lock.rb', line 33 def @message end |
#related_resource_id ⇒ String
The ID of the resource that is locking this resource. Indicates that deleting this resource will remove the lock.
27 28 29 |
# File 'lib/oci/identity/models/resource_lock.rb', line 27 def @related_resource_id end |
#time_created ⇒ DateTime
When the lock was created.
37 38 39 |
# File 'lib/oci/identity/models/resource_lock.rb', line 37 def time_created @time_created end |
#type ⇒ String
**[Required]** Type of the lock.
22 23 24 |
# File 'lib/oci/identity/models/resource_lock.rb', line 22 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/oci/identity/models/resource_lock.rb', line 44 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'type': :'type', 'related_resource_id': :'relatedResourceId', 'message': :'message', 'time_created': :'timeCreated', 'is_active': :'isActive' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/oci/identity/models/resource_lock.rb', line 57 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'type': :'String', 'related_resource_id': :'String', 'message': :'String', 'time_created': :'DateTime', 'is_active': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
129 130 131 132 133 134 135 136 137 138 |
# File 'lib/oci/identity/models/resource_lock.rb', line 129 def ==(other) return true if equal?(other) self.class == other.class && type == other.type && == other. && == other. && time_created == other.time_created && is_active == other.is_active end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/oci/identity/models/resource_lock.rb', line 163 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
143 144 145 |
# File 'lib/oci/identity/models/resource_lock.rb', line 143 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
152 153 154 |
# File 'lib/oci/identity/models/resource_lock.rb', line 152 def hash [type, , , time_created, is_active].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
196 197 198 199 200 201 202 203 204 205 |
# File 'lib/oci/identity/models/resource_lock.rb', line 196 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
190 191 192 |
# File 'lib/oci/identity/models/resource_lock.rb', line 190 def to_s to_hash.to_s end |