Class: OCI::Identity::Models::SmtpCredential
- Inherits:
-
Object
- Object
- OCI::Identity::Models::SmtpCredential
- Defined in:
- lib/oci/identity/models/smtp_credential.rb
Overview
Simple Mail Transfer Protocol (SMTP) credentials are needed to send email through Email Delivery. The SMTP credentials are used for SMTP authentication with the service. The credentials never expire. A user can have up to 2 SMTP credentials at a time.
*Note:* The credential set is always an Oracle-generated SMTP user name and password pair; you cannot designate the SMTP user name or the SMTP password.
For more information, see [Managing User Credentials](docs.cloud.oracle.com/Content/Identity/access/managing-user-credentials.htm#SMTP).
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#description ⇒ String
The description you assign to the SMTP credential.
-
#id ⇒ String
The OCID of the SMTP credential.
-
#inactive_status ⇒ Integer
The detailed status of INACTIVE lifecycleState.
-
#lifecycle_state ⇒ String
The credential's current state.
-
#password ⇒ String
The SMTP password.
-
#time_created ⇒ DateTime
Date and time the `SmtpCredential` object was created, in the format defined by RFC3339.
-
#time_expires ⇒ DateTime
Date and time when this credential will expire, in the format defined by RFC3339.
-
#user_id ⇒ String
The OCID of the user the SMTP credential belongs to.
-
#username ⇒ String
The SMTP user name.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SmtpCredential
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ SmtpCredential
Initializes the object
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/oci/identity/models/smtp_credential.rb', line 127 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.username = attributes[:'username'] if attributes[:'username'] self.password = attributes[:'password'] if attributes[:'password'] self.id = attributes[:'id'] if attributes[:'id'] self.user_id = attributes[:'userId'] if attributes[:'userId'] raise 'You cannot provide both :userId and :user_id' if attributes.key?(:'userId') && attributes.key?(:'user_id') self.user_id = attributes[:'user_id'] if attributes[:'user_id'] self.description = attributes[:'description'] if attributes[:'description'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_expires = attributes[:'timeExpires'] if attributes[:'timeExpires'] raise 'You cannot provide both :timeExpires and :time_expires' if attributes.key?(:'timeExpires') && attributes.key?(:'time_expires') self.time_expires = attributes[:'time_expires'] if attributes[:'time_expires'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.inactive_status = attributes[:'inactiveStatus'] if attributes[:'inactiveStatus'] raise 'You cannot provide both :inactiveStatus and :inactive_status' if attributes.key?(:'inactiveStatus') && attributes.key?(:'inactive_status') self.inactive_status = attributes[:'inactive_status'] if attributes[:'inactive_status'] end |
Instance Attribute Details
#description ⇒ String
The description you assign to the SMTP credential. Does not have to be unique, and it's changeable.
(For tenancies that support identity domains) You can have an empty description.
51 52 53 |
# File 'lib/oci/identity/models/smtp_credential.rb', line 51 def description @description end |
#id ⇒ String
The OCID of the SMTP credential.
40 41 42 |
# File 'lib/oci/identity/models/smtp_credential.rb', line 40 def id @id end |
#inactive_status ⇒ Integer
The detailed status of INACTIVE lifecycleState.
76 77 78 |
# File 'lib/oci/identity/models/smtp_credential.rb', line 76 def inactive_status @inactive_status end |
#lifecycle_state ⇒ String
The credential's current state. After creating a SMTP credential, make sure its `lifecycleState` changes from CREATING to ACTIVE before using it.
72 73 74 |
# File 'lib/oci/identity/models/smtp_credential.rb', line 72 def lifecycle_state @lifecycle_state end |
#password ⇒ String
The SMTP password.
36 37 38 |
# File 'lib/oci/identity/models/smtp_credential.rb', line 36 def password @password end |
#time_created ⇒ DateTime
Date and time the `SmtpCredential` object was created, in the format defined by RFC3339.
Example: `2016-08-25T21:10:29.600Z`
58 59 60 |
# File 'lib/oci/identity/models/smtp_credential.rb', line 58 def time_created @time_created end |
#time_expires ⇒ DateTime
Date and time when this credential will expire, in the format defined by RFC3339. Null if it never expires.
Example: `2016-08-25T21:10:29.600Z`
66 67 68 |
# File 'lib/oci/identity/models/smtp_credential.rb', line 66 def time_expires @time_expires end |
#user_id ⇒ String
The OCID of the user the SMTP credential belongs to.
44 45 46 |
# File 'lib/oci/identity/models/smtp_credential.rb', line 44 def user_id @user_id end |
#username ⇒ String
The SMTP user name.
31 32 33 |
# File 'lib/oci/identity/models/smtp_credential.rb', line 31 def username @username end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/oci/identity/models/smtp_credential.rb', line 79 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'username': :'username', 'password': :'password', 'id': :'id', 'user_id': :'userId', 'description': :'description', 'time_created': :'timeCreated', 'time_expires': :'timeExpires', 'lifecycle_state': :'lifecycleState', 'inactive_status': :'inactiveStatus' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/oci/identity/models/smtp_credential.rb', line 96 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'username': :'String', 'password': :'String', 'id': :'String', 'user_id': :'String', 'description': :'String', 'time_created': :'DateTime', 'time_expires': :'DateTime', 'lifecycle_state': :'String', 'inactive_status': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/oci/identity/models/smtp_credential.rb', line 192 def ==(other) return true if equal?(other) self.class == other.class && username == other.username && password == other.password && id == other.id && user_id == other.user_id && description == other.description && time_created == other.time_created && time_expires == other.time_expires && lifecycle_state == other.lifecycle_state && inactive_status == other.inactive_status end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/oci/identity/models/smtp_credential.rb', line 230 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
210 211 212 |
# File 'lib/oci/identity/models/smtp_credential.rb', line 210 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
219 220 221 |
# File 'lib/oci/identity/models/smtp_credential.rb', line 219 def hash [username, password, id, user_id, description, time_created, time_expires, lifecycle_state, inactive_status].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
263 264 265 266 267 268 269 270 271 272 |
# File 'lib/oci/identity/models/smtp_credential.rb', line 263 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
257 258 259 |
# File 'lib/oci/identity/models/smtp_credential.rb', line 257 def to_s to_hash.to_s end |