Class: OCI::Identity::Models::SmtpCredentialSummary
- Inherits:
-
Object
- Object
- OCI::Identity::Models::SmtpCredentialSummary
- Defined in:
- lib/oci/identity/models/smtp_credential_summary.rb
Overview
As the name suggests, an `SmtpCredentialSummary` object contains information about an `SmtpCredential`. The SMTP credential is used for SMTP authentication with the [Email Delivery Service](docs.cloud.oracle.com/Content/Email/Concepts/overview.htm).
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#description ⇒ String
The description you assign to the SMTP credential.
-
#id ⇒ String
The OCID of the SMTP credential.
-
#inactive_status ⇒ Integer
The detailed status of INACTIVE lifecycleState.
-
#lifecycle_state ⇒ String
The credential's current state.
-
#time_created ⇒ DateTime
Date and time the `SmtpCredential` object was created, in the format defined by RFC3339.
-
#time_expires ⇒ DateTime
Date and time when this credential will expire, in the format defined by RFC3339.
-
#user_id ⇒ String
The OCID of the user the SMTP credential belongs to.
-
#username ⇒ String
The SMTP user name.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SmtpCredentialSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ SmtpCredentialSummary
Initializes the object
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/oci/identity/models/smtp_credential_summary.rb', line 114 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.username = attributes[:'username'] if attributes[:'username'] self.id = attributes[:'id'] if attributes[:'id'] self.user_id = attributes[:'userId'] if attributes[:'userId'] raise 'You cannot provide both :userId and :user_id' if attributes.key?(:'userId') && attributes.key?(:'user_id') self.user_id = attributes[:'user_id'] if attributes[:'user_id'] self.description = attributes[:'description'] if attributes[:'description'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_expires = attributes[:'timeExpires'] if attributes[:'timeExpires'] raise 'You cannot provide both :timeExpires and :time_expires' if attributes.key?(:'timeExpires') && attributes.key?(:'time_expires') self.time_expires = attributes[:'time_expires'] if attributes[:'time_expires'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.inactive_status = attributes[:'inactiveStatus'] if attributes[:'inactiveStatus'] raise 'You cannot provide both :inactiveStatus and :inactive_status' if attributes.key?(:'inactiveStatus') && attributes.key?(:'inactive_status') self.inactive_status = attributes[:'inactive_status'] if attributes[:'inactive_status'] end |
Instance Attribute Details
#description ⇒ String
The description you assign to the SMTP credential. Does not have to be unique, and it's changeable.
(For tenancies that support identity domains) You can have an empty description.
41 42 43 |
# File 'lib/oci/identity/models/smtp_credential_summary.rb', line 41 def description @description end |
#id ⇒ String
The OCID of the SMTP credential.
30 31 32 |
# File 'lib/oci/identity/models/smtp_credential_summary.rb', line 30 def id @id end |
#inactive_status ⇒ Integer
The detailed status of INACTIVE lifecycleState.
66 67 68 |
# File 'lib/oci/identity/models/smtp_credential_summary.rb', line 66 def inactive_status @inactive_status end |
#lifecycle_state ⇒ String
The credential's current state. After creating a SMTP credential, make sure its `lifecycleState` changes from CREATING to ACTIVE before using it.
62 63 64 |
# File 'lib/oci/identity/models/smtp_credential_summary.rb', line 62 def lifecycle_state @lifecycle_state end |
#time_created ⇒ DateTime
Date and time the `SmtpCredential` object was created, in the format defined by RFC3339.
Example: `2016-08-25T21:10:29.600Z`
48 49 50 |
# File 'lib/oci/identity/models/smtp_credential_summary.rb', line 48 def time_created @time_created end |
#time_expires ⇒ DateTime
Date and time when this credential will expire, in the format defined by RFC3339. Null if it never expires.
Example: `2016-08-25T21:10:29.600Z`
56 57 58 |
# File 'lib/oci/identity/models/smtp_credential_summary.rb', line 56 def time_expires @time_expires end |
#user_id ⇒ String
The OCID of the user the SMTP credential belongs to.
34 35 36 |
# File 'lib/oci/identity/models/smtp_credential_summary.rb', line 34 def user_id @user_id end |
#username ⇒ String
The SMTP user name.
26 27 28 |
# File 'lib/oci/identity/models/smtp_credential_summary.rb', line 26 def username @username end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/oci/identity/models/smtp_credential_summary.rb', line 69 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'username': :'username', 'id': :'id', 'user_id': :'userId', 'description': :'description', 'time_created': :'timeCreated', 'time_expires': :'timeExpires', 'lifecycle_state': :'lifecycleState', 'inactive_status': :'inactiveStatus' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/oci/identity/models/smtp_credential_summary.rb', line 85 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'username': :'String', 'id': :'String', 'user_id': :'String', 'description': :'String', 'time_created': :'DateTime', 'time_expires': :'DateTime', 'lifecycle_state': :'String', 'inactive_status': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/oci/identity/models/smtp_credential_summary.rb', line 177 def ==(other) return true if equal?(other) self.class == other.class && username == other.username && id == other.id && user_id == other.user_id && description == other.description && time_created == other.time_created && time_expires == other.time_expires && lifecycle_state == other.lifecycle_state && inactive_status == other.inactive_status end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/oci/identity/models/smtp_credential_summary.rb', line 214 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
194 195 196 |
# File 'lib/oci/identity/models/smtp_credential_summary.rb', line 194 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
203 204 205 |
# File 'lib/oci/identity/models/smtp_credential_summary.rb', line 203 def hash [username, id, user_id, description, time_created, time_expires, lifecycle_state, inactive_status].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
247 248 249 250 251 252 253 254 255 256 |
# File 'lib/oci/identity/models/smtp_credential_summary.rb', line 247 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
241 242 243 |
# File 'lib/oci/identity/models/smtp_credential_summary.rb', line 241 def to_s to_hash.to_s end |