Class: OCI::Identity::Models::StandardTagNamespaceTemplate
- Inherits:
-
Object
- Object
- OCI::Identity::Models::StandardTagNamespaceTemplate
- Defined in:
- lib/oci/identity/models/standard_tag_namespace_template.rb
Overview
The template of the standard tag namespace. This object includes necessary details to create the provided standard tag namespace.
Instance Attribute Summary collapse
-
#description ⇒ String
[Required] The default description of the tag namespace that users can use to create the tag namespace.
-
#standard_tag_namespace_name ⇒ String
[Required] The reserved name of this standard tag namespace.
-
#status ⇒ String
[Required] The status of the standard tag namespace.
-
#tag_definition_templates ⇒ Array<OCI::Identity::Models::StandardTagDefinitionTemplate>
[Required] The template of the tag definition.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ StandardTagNamespaceTemplate
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ StandardTagNamespaceTemplate
Initializes the object
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/oci/identity/models/standard_tag_namespace_template.rb', line 60 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.description = attributes[:'description'] if attributes[:'description'] self.standard_tag_namespace_name = attributes[:'standardTagNamespaceName'] if attributes[:'standardTagNamespaceName'] raise 'You cannot provide both :standardTagNamespaceName and :standard_tag_namespace_name' if attributes.key?(:'standardTagNamespaceName') && attributes.key?(:'standard_tag_namespace_name') self.standard_tag_namespace_name = attributes[:'standard_tag_namespace_name'] if attributes[:'standard_tag_namespace_name'] self.tag_definition_templates = attributes[:'tagDefinitionTemplates'] if attributes[:'tagDefinitionTemplates'] raise 'You cannot provide both :tagDefinitionTemplates and :tag_definition_templates' if attributes.key?(:'tagDefinitionTemplates') && attributes.key?(:'tag_definition_templates') self.tag_definition_templates = attributes[:'tag_definition_templates'] if attributes[:'tag_definition_templates'] self.status = attributes[:'status'] if attributes[:'status'] end |
Instance Attribute Details
#description ⇒ String
[Required] The default description of the tag namespace that users can use to create the tag namespace
12 13 14 |
# File 'lib/oci/identity/models/standard_tag_namespace_template.rb', line 12 def description @description end |
#standard_tag_namespace_name ⇒ String
[Required] The reserved name of this standard tag namespace
16 17 18 |
# File 'lib/oci/identity/models/standard_tag_namespace_template.rb', line 16 def standard_tag_namespace_name @standard_tag_namespace_name end |
#status ⇒ String
[Required] The status of the standard tag namespace
24 25 26 |
# File 'lib/oci/identity/models/standard_tag_namespace_template.rb', line 24 def status @status end |
#tag_definition_templates ⇒ Array<OCI::Identity::Models::StandardTagDefinitionTemplate>
[Required] The template of the tag definition. This object includes necessary details to create the provided standard tag definition.
20 21 22 |
# File 'lib/oci/identity/models/standard_tag_namespace_template.rb', line 20 def tag_definition_templates @tag_definition_templates end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
27 28 29 30 31 32 33 34 35 36 |
# File 'lib/oci/identity/models/standard_tag_namespace_template.rb', line 27 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'description': :'description', 'standard_tag_namespace_name': :'standardTagNamespaceName', 'tag_definition_templates': :'tagDefinitionTemplates', 'status': :'status' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
39 40 41 42 43 44 45 46 47 48 |
# File 'lib/oci/identity/models/standard_tag_namespace_template.rb', line 39 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'description': :'String', 'standard_tag_namespace_name': :'String', 'tag_definition_templates': :'Array<OCI::Identity::Models::StandardTagDefinitionTemplate>', 'status': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
90 91 92 93 94 95 96 97 98 |
# File 'lib/oci/identity/models/standard_tag_namespace_template.rb', line 90 def ==(other) return true if equal?(other) self.class == other.class && description == other.description && standard_tag_namespace_name == other.standard_tag_namespace_name && tag_definition_templates == other.tag_definition_templates && status == other.status end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/oci/identity/models/standard_tag_namespace_template.rb', line 123 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
103 104 105 |
# File 'lib/oci/identity/models/standard_tag_namespace_template.rb', line 103 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
112 113 114 |
# File 'lib/oci/identity/models/standard_tag_namespace_template.rb', line 112 def hash [description, standard_tag_namespace_name, tag_definition_templates, status].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
156 157 158 159 160 161 162 163 164 165 |
# File 'lib/oci/identity/models/standard_tag_namespace_template.rb', line 156 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
150 151 152 |
# File 'lib/oci/identity/models/standard_tag_namespace_template.rb', line 150 def to_s to_hash.to_s end |