Class: OCI::Identity::Models::TagDefaultSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/identity/models/tag_default_summary.rb

Overview

Summary information for the specified tag default.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ TagDefaultSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/oci/identity/models/tag_default_summary.rb', line 126

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.tag_namespace_id = attributes[:'tagNamespaceId'] if attributes[:'tagNamespaceId']

  raise 'You cannot provide both :tagNamespaceId and :tag_namespace_id' if attributes.key?(:'tagNamespaceId') && attributes.key?(:'tag_namespace_id')

  self.tag_namespace_id = attributes[:'tag_namespace_id'] if attributes[:'tag_namespace_id']

  self.tag_definition_id = attributes[:'tagDefinitionId'] if attributes[:'tagDefinitionId']

  raise 'You cannot provide both :tagDefinitionId and :tag_definition_id' if attributes.key?(:'tagDefinitionId') && attributes.key?(:'tag_definition_id')

  self.tag_definition_id = attributes[:'tag_definition_id'] if attributes[:'tag_definition_id']

  self.tag_definition_name = attributes[:'tagDefinitionName'] if attributes[:'tagDefinitionName']

  raise 'You cannot provide both :tagDefinitionName and :tag_definition_name' if attributes.key?(:'tagDefinitionName') && attributes.key?(:'tag_definition_name')

  self.tag_definition_name = attributes[:'tag_definition_name'] if attributes[:'tag_definition_name']

  self.value = attributes[:'value'] if attributes[:'value']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.is_required = attributes[:'isRequired'] unless attributes[:'isRequired'].nil?

  raise 'You cannot provide both :isRequired and :is_required' if attributes.key?(:'isRequired') && attributes.key?(:'is_required')

  self.is_required = attributes[:'is_required'] unless attributes[:'is_required'].nil?

  self.locks = attributes[:'locks'] if attributes[:'locks']
end

Instance Attribute Details

#compartment_idString

**[Required]** The OCID of the compartment. The tag default will apply to all new resources that are created in the compartment.

Returns:

  • (String)


24
25
26
# File 'lib/oci/identity/models/tag_default_summary.rb', line 24

def compartment_id
  @compartment_id
end

#idString

**[Required]** The OCID of the tag default.

Returns:

  • (String)


19
20
21
# File 'lib/oci/identity/models/tag_default_summary.rb', line 19

def id
  @id
end

#is_requiredBOOLEAN

**[Required]** If you specify that a value is required, a value is set during resource creation (either by the user creating the resource or another tag defualt). If no value is set, resource creation is blocked.

  • If the `isRequired` flag is set to "true", the value is set during resource creation.

  • If the `isRequired` flag is set to "false", the value you enter is set during resource creation.

Example: `false`

Returns:

  • (BOOLEAN)


68
69
70
# File 'lib/oci/identity/models/tag_default_summary.rb', line 68

def is_required
  @is_required
end

#lifecycle_stateString

The tag default's current state. After creating a `TagDefault`, make sure its `lifecycleState` is ACTIVE before using it.

Returns:

  • (String)


56
57
58
# File 'lib/oci/identity/models/tag_default_summary.rb', line 56

def lifecycle_state
  @lifecycle_state
end

#locksArray<OCI::Identity::Models::ResourceLock>

Locks associated with this resource.



72
73
74
# File 'lib/oci/identity/models/tag_default_summary.rb', line 72

def locks
  @locks
end

#tag_definition_idString

**[Required]** The OCID of the tag definition. The tag default will always assign a default value for this tag definition.

Returns:

  • (String)


34
35
36
# File 'lib/oci/identity/models/tag_default_summary.rb', line 34

def tag_definition_id
  @tag_definition_id
end

#tag_definition_nameString

**[Required]** The name used in the tag definition. This field is informational in the context of the tag default.

Returns:

  • (String)


39
40
41
# File 'lib/oci/identity/models/tag_default_summary.rb', line 39

def tag_definition_name
  @tag_definition_name
end

#tag_namespace_idString

**[Required]** The OCID of the tag namespace that contains the tag definition.

Returns:

  • (String)


29
30
31
# File 'lib/oci/identity/models/tag_default_summary.rb', line 29

def tag_namespace_id
  @tag_namespace_id
end

#time_createdDateTime

**[Required]** Date and time the `TagDefault` object was created, in the format defined by RFC3339.

Example: `2016-08-25T21:10:29.600Z`

Returns:

  • (DateTime)


51
52
53
# File 'lib/oci/identity/models/tag_default_summary.rb', line 51

def time_created
  @time_created
end

#valueString

**[Required]** The default value for the tag definition. This will be applied to all new resources created in the compartment.

Returns:

  • (String)


44
45
46
# File 'lib/oci/identity/models/tag_default_summary.rb', line 44

def value
  @value
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/oci/identity/models/tag_default_summary.rb', line 75

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'compartment_id': :'compartmentId',
    'tag_namespace_id': :'tagNamespaceId',
    'tag_definition_id': :'tagDefinitionId',
    'tag_definition_name': :'tagDefinitionName',
    'value': :'value',
    'time_created': :'timeCreated',
    'lifecycle_state': :'lifecycleState',
    'is_required': :'isRequired',
    'locks': :'locks'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/oci/identity/models/tag_default_summary.rb', line 93

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'compartment_id': :'String',
    'tag_namespace_id': :'String',
    'tag_definition_id': :'String',
    'tag_definition_name': :'String',
    'value': :'String',
    'time_created': :'DateTime',
    'lifecycle_state': :'String',
    'is_required': :'BOOLEAN',
    'locks': :'Array<OCI::Identity::Models::ResourceLock>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/oci/identity/models/tag_default_summary.rb', line 201

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    tag_namespace_id == other.tag_namespace_id &&
    tag_definition_id == other.tag_definition_id &&
    tag_definition_name == other.tag_definition_name &&
    value == other.value &&
    time_created == other.time_created &&
    lifecycle_state == other.lifecycle_state &&
    is_required == other.is_required &&
    locks == other.locks
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
# File 'lib/oci/identity/models/tag_default_summary.rb', line 240

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


220
221
222
# File 'lib/oci/identity/models/tag_default_summary.rb', line 220

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



229
230
231
# File 'lib/oci/identity/models/tag_default_summary.rb', line 229

def hash
  [id, compartment_id, tag_namespace_id, tag_definition_id, tag_definition_name, value, time_created, lifecycle_state, is_required, locks].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



273
274
275
276
277
278
279
280
281
282
# File 'lib/oci/identity/models/tag_default_summary.rb', line 273

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



267
268
269
# File 'lib/oci/identity/models/tag_default_summary.rb', line 267

def to_s
  to_hash.to_s
end