Class: OCI::Identity::Models::TagNamespaceSummary
- Inherits:
-
Object
- Object
- OCI::Identity::Models::TagNamespaceSummary
- Defined in:
- lib/oci/identity/models/tag_namespace_summary.rb
Overview
A container for defined tags.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
The OCID of the compartment that contains the tag namespace.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
The description you assign to the tag namespace.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
The OCID of the tag namespace.
-
#is_retired ⇒ BOOLEAN
Whether the tag namespace is retired.
-
#lifecycle_state ⇒ String
The tagnamespace's current state.
-
#locks ⇒ Array<OCI::Identity::Models::ResourceLock>
Locks associated with this resource.
-
#name ⇒ String
The name of the tag namespace.
-
#time_created ⇒ DateTime
Date and time the tag namespace was created, in the format defined by RFC3339.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TagNamespaceSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ TagNamespaceSummary
Initializes the object
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/oci/identity/models/tag_namespace_summary.rb', line 114 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.is_retired = attributes[:'isRetired'] unless attributes[:'isRetired'].nil? raise 'You cannot provide both :isRetired and :is_retired' if attributes.key?(:'isRetired') && attributes.key?(:'is_retired') self.is_retired = attributes[:'is_retired'] unless attributes[:'is_retired'].nil? self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.locks = attributes[:'locks'] if attributes[:'locks'] end |
Instance Attribute Details
#compartment_id ⇒ String
The OCID of the compartment that contains the tag namespace.
17 18 19 |
# File 'lib/oci/identity/models/tag_namespace_summary.rb', line 17 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `{"CostCenter": "42"}`
40 41 42 |
# File 'lib/oci/identity/models/tag_namespace_summary.rb', line 40 def @defined_tags end |
#description ⇒ String
The description you assign to the tag namespace.
26 27 28 |
# File 'lib/oci/identity/models/tag_namespace_summary.rb', line 26 def description @description end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `"Finance"`
33 34 35 |
# File 'lib/oci/identity/models/tag_namespace_summary.rb', line 33 def @freeform_tags end |
#id ⇒ String
The OCID of the tag namespace.
13 14 15 |
# File 'lib/oci/identity/models/tag_namespace_summary.rb', line 13 def id @id end |
#is_retired ⇒ BOOLEAN
Whether the tag namespace is retired. For more information, see [Retiring Key Definitions and Namespace Definitions](docs.cloud.oracle.com/Content/Tagging/Tasks/managingtagsandtagnamespaces.htm#retiringkeys).
46 47 48 |
# File 'lib/oci/identity/models/tag_namespace_summary.rb', line 46 def is_retired @is_retired end |
#lifecycle_state ⇒ String
The tagnamespace's current state. After creating a tagnamespace, make sure its `lifecycleState` is ACTIVE before using it. After retiring a tagnamespace, make sure its `lifecycleState` is INACTIVE before using it.
50 51 52 |
# File 'lib/oci/identity/models/tag_namespace_summary.rb', line 50 def lifecycle_state @lifecycle_state end |
#locks ⇒ Array<OCI::Identity::Models::ResourceLock>
Locks associated with this resource.
60 61 62 |
# File 'lib/oci/identity/models/tag_namespace_summary.rb', line 60 def locks @locks end |
#name ⇒ String
The name of the tag namespace. It must be unique across all tag namespaces in the tenancy and cannot be changed.
22 23 24 |
# File 'lib/oci/identity/models/tag_namespace_summary.rb', line 22 def name @name end |
#time_created ⇒ DateTime
Date and time the tag namespace was created, in the format defined by RFC3339. Example: `2016-08-25T21:10:29.600Z`
56 57 58 |
# File 'lib/oci/identity/models/tag_namespace_summary.rb', line 56 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/oci/identity/models/tag_namespace_summary.rb', line 63 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'name': :'name', 'description': :'description', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'is_retired': :'isRetired', 'lifecycle_state': :'lifecycleState', 'time_created': :'timeCreated', 'locks': :'locks' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/oci/identity/models/tag_namespace_summary.rb', line 81 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'name': :'String', 'description': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'is_retired': :'BOOLEAN', 'lifecycle_state': :'String', 'time_created': :'DateTime', 'locks': :'Array<OCI::Identity::Models::ResourceLock>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/oci/identity/models/tag_namespace_summary.rb', line 172 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && name == other.name && description == other.description && == other. && == other. && is_retired == other.is_retired && lifecycle_state == other.lifecycle_state && time_created == other.time_created && locks == other.locks end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/oci/identity/models/tag_namespace_summary.rb', line 211 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
191 192 193 |
# File 'lib/oci/identity/models/tag_namespace_summary.rb', line 191 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
200 201 202 |
# File 'lib/oci/identity/models/tag_namespace_summary.rb', line 200 def hash [id, compartment_id, name, description, , , is_retired, lifecycle_state, time_created, locks].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
244 245 246 247 248 249 250 251 252 253 |
# File 'lib/oci/identity/models/tag_namespace_summary.rb', line 244 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
238 239 240 |
# File 'lib/oci/identity/models/tag_namespace_summary.rb', line 238 def to_s to_hash.to_s end |