Class: OCI::Identity::Models::UpdateUserCapabilitiesDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/identity/models/update_user_capabilities_details.rb

Overview

UpdateUserCapabilitiesDetails model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateUserCapabilitiesDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/oci/identity/models/update_user_capabilities_details.rb', line 88

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.can_use_console_password = attributes[:'canUseConsolePassword'] unless attributes[:'canUseConsolePassword'].nil?

  raise 'You cannot provide both :canUseConsolePassword and :can_use_console_password' if attributes.key?(:'canUseConsolePassword') && attributes.key?(:'can_use_console_password')

  self.can_use_console_password = attributes[:'can_use_console_password'] unless attributes[:'can_use_console_password'].nil?

  self.can_use_api_keys = attributes[:'canUseApiKeys'] unless attributes[:'canUseApiKeys'].nil?

  raise 'You cannot provide both :canUseApiKeys and :can_use_api_keys' if attributes.key?(:'canUseApiKeys') && attributes.key?(:'can_use_api_keys')

  self.can_use_api_keys = attributes[:'can_use_api_keys'] unless attributes[:'can_use_api_keys'].nil?

  self.can_use_auth_tokens = attributes[:'canUseAuthTokens'] unless attributes[:'canUseAuthTokens'].nil?

  raise 'You cannot provide both :canUseAuthTokens and :can_use_auth_tokens' if attributes.key?(:'canUseAuthTokens') && attributes.key?(:'can_use_auth_tokens')

  self.can_use_auth_tokens = attributes[:'can_use_auth_tokens'] unless attributes[:'can_use_auth_tokens'].nil?

  self.can_use_smtp_credentials = attributes[:'canUseSmtpCredentials'] unless attributes[:'canUseSmtpCredentials'].nil?

  raise 'You cannot provide both :canUseSmtpCredentials and :can_use_smtp_credentials' if attributes.key?(:'canUseSmtpCredentials') && attributes.key?(:'can_use_smtp_credentials')

  self.can_use_smtp_credentials = attributes[:'can_use_smtp_credentials'] unless attributes[:'can_use_smtp_credentials'].nil?

  self.can_use_db_credentials = attributes[:'canUseDBCredentials'] unless attributes[:'canUseDBCredentials'].nil?

  raise 'You cannot provide both :canUseDBCredentials and :can_use_db_credentials' if attributes.key?(:'canUseDBCredentials') && attributes.key?(:'can_use_db_credentials')

  self.can_use_db_credentials = attributes[:'can_use_db_credentials'] unless attributes[:'can_use_db_credentials'].nil?

  self.can_use_customer_secret_keys = attributes[:'canUseCustomerSecretKeys'] unless attributes[:'canUseCustomerSecretKeys'].nil?

  raise 'You cannot provide both :canUseCustomerSecretKeys and :can_use_customer_secret_keys' if attributes.key?(:'canUseCustomerSecretKeys') && attributes.key?(:'can_use_customer_secret_keys')

  self.can_use_customer_secret_keys = attributes[:'can_use_customer_secret_keys'] unless attributes[:'can_use_customer_secret_keys'].nil?

  self.can_use_o_auth2_client_credentials = attributes[:'canUseOAuth2ClientCredentials'] unless attributes[:'canUseOAuth2ClientCredentials'].nil?

  raise 'You cannot provide both :canUseOAuth2ClientCredentials and :can_use_o_auth2_client_credentials' if attributes.key?(:'canUseOAuth2ClientCredentials') && attributes.key?(:'can_use_o_auth2_client_credentials')

  self.can_use_o_auth2_client_credentials = attributes[:'can_use_o_auth2_client_credentials'] unless attributes[:'can_use_o_auth2_client_credentials'].nil?
end

Instance Attribute Details

#can_use_api_keysBOOLEAN

Indicates if the user can use API keys.

Returns:

  • (BOOLEAN)


18
19
20
# File 'lib/oci/identity/models/update_user_capabilities_details.rb', line 18

def can_use_api_keys
  @can_use_api_keys
end

#can_use_auth_tokensBOOLEAN

Indicates if the user can use SWIFT passwords / auth tokens.

Returns:

  • (BOOLEAN)


23
24
25
# File 'lib/oci/identity/models/update_user_capabilities_details.rb', line 23

def can_use_auth_tokens
  @can_use_auth_tokens
end

#can_use_console_passwordBOOLEAN

Indicates if the user can log in to the console.

Returns:

  • (BOOLEAN)


13
14
15
# File 'lib/oci/identity/models/update_user_capabilities_details.rb', line 13

def can_use_console_password
  @can_use_console_password
end

#can_use_customer_secret_keysBOOLEAN

Indicates if the user can use SigV4 symmetric keys.

Returns:

  • (BOOLEAN)


38
39
40
# File 'lib/oci/identity/models/update_user_capabilities_details.rb', line 38

def can_use_customer_secret_keys
  @can_use_customer_secret_keys
end

#can_use_db_credentialsBOOLEAN

Indicates if the user can use DB passwords.

Returns:

  • (BOOLEAN)


33
34
35
# File 'lib/oci/identity/models/update_user_capabilities_details.rb', line 33

def can_use_db_credentials
  @can_use_db_credentials
end

#can_use_o_auth2_client_credentialsBOOLEAN

Indicates if the user can use OAuth2 credentials and tokens.

Returns:

  • (BOOLEAN)


43
44
45
# File 'lib/oci/identity/models/update_user_capabilities_details.rb', line 43

def can_use_o_auth2_client_credentials
  @can_use_o_auth2_client_credentials
end

#can_use_smtp_credentialsBOOLEAN

Indicates if the user can use SMTP passwords.

Returns:

  • (BOOLEAN)


28
29
30
# File 'lib/oci/identity/models/update_user_capabilities_details.rb', line 28

def can_use_smtp_credentials
  @can_use_smtp_credentials
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



46
47
48
49
50
51
52
53
54
55
56
57
58
# File 'lib/oci/identity/models/update_user_capabilities_details.rb', line 46

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'can_use_console_password': :'canUseConsolePassword',
    'can_use_api_keys': :'canUseApiKeys',
    'can_use_auth_tokens': :'canUseAuthTokens',
    'can_use_smtp_credentials': :'canUseSmtpCredentials',
    'can_use_db_credentials': :'canUseDBCredentials',
    'can_use_customer_secret_keys': :'canUseCustomerSecretKeys',
    'can_use_o_auth2_client_credentials': :'canUseOAuth2ClientCredentials'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/oci/identity/models/update_user_capabilities_details.rb', line 61

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'can_use_console_password': :'BOOLEAN',
    'can_use_api_keys': :'BOOLEAN',
    'can_use_auth_tokens': :'BOOLEAN',
    'can_use_smtp_credentials': :'BOOLEAN',
    'can_use_db_credentials': :'BOOLEAN',
    'can_use_customer_secret_keys': :'BOOLEAN',
    'can_use_o_auth2_client_credentials': :'BOOLEAN'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/oci/identity/models/update_user_capabilities_details.rb', line 144

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    can_use_console_password == other.can_use_console_password &&
    can_use_api_keys == other.can_use_api_keys &&
    can_use_auth_tokens == other.can_use_auth_tokens &&
    can_use_smtp_credentials == other.can_use_smtp_credentials &&
    can_use_db_credentials == other.can_use_db_credentials &&
    can_use_customer_secret_keys == other.can_use_customer_secret_keys &&
    can_use_o_auth2_client_credentials == other.can_use_o_auth2_client_credentials
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/oci/identity/models/update_user_capabilities_details.rb', line 180

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


160
161
162
# File 'lib/oci/identity/models/update_user_capabilities_details.rb', line 160

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



169
170
171
# File 'lib/oci/identity/models/update_user_capabilities_details.rb', line 169

def hash
  [can_use_console_password, can_use_api_keys, can_use_auth_tokens, can_use_smtp_credentials, can_use_db_credentials, can_use_customer_secret_keys, can_use_o_auth2_client_credentials].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



213
214
215
216
217
218
219
220
221
222
# File 'lib/oci/identity/models/update_user_capabilities_details.rb', line 213

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



207
208
209
# File 'lib/oci/identity/models/update_user_capabilities_details.rb', line 207

def to_s
  to_hash.to_s
end