Class: OCI::Identity::Models::UpdateUserDetails
- Inherits:
-
Object
- Object
- OCI::Identity::Models::UpdateUserDetails
- Defined in:
- lib/oci/identity/models/update_user_details.rb
Overview
UpdateUserDetails model.
Instance Attribute Summary collapse
-
#db_user_name ⇒ String
DB username of the DB credential.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
The description you assign to the user.
-
#email ⇒ String
The email you assign to the user during creation.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateUserDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateUserDetails
Initializes the object
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/oci/identity/models/update_user_details.rb', line 79 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.description = attributes[:'description'] if attributes[:'description'] self.email = attributes[:'email'] if attributes[:'email'] self.db_user_name = attributes[:'dbUserName'] if attributes[:'dbUserName'] raise 'You cannot provide both :dbUserName and :db_user_name' if attributes.key?(:'dbUserName') && attributes.key?(:'db_user_name') self.db_user_name = attributes[:'db_user_name'] if attributes[:'db_user_name'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#db_user_name ⇒ String
DB username of the DB credential. Has to be unique across the tenancy.
26 27 28 |
# File 'lib/oci/identity/models/update_user_details.rb', line 26 def db_user_name @db_user_name end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `{"CostCenter": "42"}`
40 41 42 |
# File 'lib/oci/identity/models/update_user_details.rb', line 40 def @defined_tags end |
#description ⇒ String
The description you assign to the user. Does not have to be unique, and it's changeable.
(For tenancies that support identity domains) You can have an empty description.
15 16 17 |
# File 'lib/oci/identity/models/update_user_details.rb', line 15 def description @description end |
#email ⇒ String
The email you assign to the user during creation. The email must be unique across all users in the tenancy.
(For tenancies that support identity domains) You must provide an email for each user.
22 23 24 |
# File 'lib/oci/identity/models/update_user_details.rb', line 22 def email @email end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `"Finance"`
33 34 35 |
# File 'lib/oci/identity/models/update_user_details.rb', line 33 def @freeform_tags end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/oci/identity/models/update_user_details.rb', line 43 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'description': :'description', 'email': :'email', 'db_user_name': :'dbUserName', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/oci/identity/models/update_user_details.rb', line 56 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'description': :'String', 'email': :'String', 'db_user_name': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
115 116 117 118 119 120 121 122 123 124 |
# File 'lib/oci/identity/models/update_user_details.rb', line 115 def ==(other) return true if equal?(other) self.class == other.class && description == other.description && email == other.email && db_user_name == other.db_user_name && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/oci/identity/models/update_user_details.rb', line 149 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
129 130 131 |
# File 'lib/oci/identity/models/update_user_details.rb', line 129 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
138 139 140 |
# File 'lib/oci/identity/models/update_user_details.rb', line 138 def hash [description, email, db_user_name, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
182 183 184 185 186 187 188 189 190 191 |
# File 'lib/oci/identity/models/update_user_details.rb', line 182 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
176 177 178 |
# File 'lib/oci/identity/models/update_user_details.rb', line 176 def to_s to_hash.to_s end |