Method: OCI::Identity::Models::User#inactive_status

Defined in:
lib/oci/identity/models/user.rb

#inactive_statusInteger

Returned only if the user’s lifecycleState is INACTIVE. A 16-bit value showing the reason why the user is inactive:

  • bit 0: SUSPENDED (reserved for future use)

  • bit 1: DISABLED (reserved for future use)

  • bit 2: BLOCKED (the user has exceeded the maximum number of failed login attempts for the Console)

Returns:

  • (Integer)


101
102
103
# File 'lib/oci/identity/models/user.rb', line 101

def inactive_status
  @inactive_status
end