Class: OCI::Identity::Models::UserCapabilities

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/identity/models/user_capabilities.rb

Overview

Properties indicating how the user is allowed to authenticate.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UserCapabilities

Initializes the object

Options Hash (attributes):

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/oci/identity/models/user_capabilities.rb', line 75

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.can_use_console_password = attributes[:'canUseConsolePassword'] unless attributes[:'canUseConsolePassword'].nil?

  raise 'You cannot provide both :canUseConsolePassword and :can_use_console_password' if attributes.key?(:'canUseConsolePassword') && attributes.key?(:'can_use_console_password')

  self.can_use_console_password = attributes[:'can_use_console_password'] unless attributes[:'can_use_console_password'].nil?

  self.can_use_api_keys = attributes[:'canUseApiKeys'] unless attributes[:'canUseApiKeys'].nil?

  raise 'You cannot provide both :canUseApiKeys and :can_use_api_keys' if attributes.key?(:'canUseApiKeys') && attributes.key?(:'can_use_api_keys')

  self.can_use_api_keys = attributes[:'can_use_api_keys'] unless attributes[:'can_use_api_keys'].nil?

  self.can_use_auth_tokens = attributes[:'canUseAuthTokens'] unless attributes[:'canUseAuthTokens'].nil?

  raise 'You cannot provide both :canUseAuthTokens and :can_use_auth_tokens' if attributes.key?(:'canUseAuthTokens') && attributes.key?(:'can_use_auth_tokens')

  self.can_use_auth_tokens = attributes[:'can_use_auth_tokens'] unless attributes[:'can_use_auth_tokens'].nil?

  self.can_use_smtp_credentials = attributes[:'canUseSmtpCredentials'] unless attributes[:'canUseSmtpCredentials'].nil?

  raise 'You cannot provide both :canUseSmtpCredentials and :can_use_smtp_credentials' if attributes.key?(:'canUseSmtpCredentials') && attributes.key?(:'can_use_smtp_credentials')

  self.can_use_smtp_credentials = attributes[:'can_use_smtp_credentials'] unless attributes[:'can_use_smtp_credentials'].nil?

  self.can_use_customer_secret_keys = attributes[:'canUseCustomerSecretKeys'] unless attributes[:'canUseCustomerSecretKeys'].nil?

  raise 'You cannot provide both :canUseCustomerSecretKeys and :can_use_customer_secret_keys' if attributes.key?(:'canUseCustomerSecretKeys') && attributes.key?(:'can_use_customer_secret_keys')

  self.can_use_customer_secret_keys = attributes[:'can_use_customer_secret_keys'] unless attributes[:'can_use_customer_secret_keys'].nil?

  self.can_use_o_auth2_client_credentials = attributes[:'canUseOAuth2ClientCredentials'] unless attributes[:'canUseOAuth2ClientCredentials'].nil?

  raise 'You cannot provide both :canUseOAuth2ClientCredentials and :can_use_o_auth2_client_credentials' if attributes.key?(:'canUseOAuth2ClientCredentials') && attributes.key?(:'can_use_o_auth2_client_credentials')

  self.can_use_o_auth2_client_credentials = attributes[:'can_use_o_auth2_client_credentials'] unless attributes[:'can_use_o_auth2_client_credentials'].nil?
end

Instance Attribute Details

#can_use_api_keysBOOLEAN

Indicates if the user can use API keys.

Returns:



16
17
18
# File 'lib/oci/identity/models/user_capabilities.rb', line 16

def can_use_api_keys
  @can_use_api_keys
end

#can_use_auth_tokensBOOLEAN

Indicates if the user can use SWIFT passwords / auth tokens.

Returns:



20
21
22
# File 'lib/oci/identity/models/user_capabilities.rb', line 20

def can_use_auth_tokens
  @can_use_auth_tokens
end

#can_use_console_passwordBOOLEAN

Indicates if the user can log in to the console.

Returns:



12
13
14
# File 'lib/oci/identity/models/user_capabilities.rb', line 12

def can_use_console_password
  @can_use_console_password
end

#can_use_customer_secret_keysBOOLEAN

Indicates if the user can use SigV4 symmetric keys.

Returns:



28
29
30
# File 'lib/oci/identity/models/user_capabilities.rb', line 28

def can_use_customer_secret_keys
  @can_use_customer_secret_keys
end

#can_use_o_auth2_client_credentialsBOOLEAN

Indicates if the user can use OAuth2 credentials and tokens.

Returns:



33
34
35
# File 'lib/oci/identity/models/user_capabilities.rb', line 33

def can_use_o_auth2_client_credentials
  @can_use_o_auth2_client_credentials
end

#can_use_smtp_credentialsBOOLEAN

Indicates if the user can use SMTP passwords.

Returns:



24
25
26
# File 'lib/oci/identity/models/user_capabilities.rb', line 24

def can_use_smtp_credentials
  @can_use_smtp_credentials
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



36
37
38
39
40
41
42
43
44
45
46
47
# File 'lib/oci/identity/models/user_capabilities.rb', line 36

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'can_use_console_password': :'canUseConsolePassword',
    'can_use_api_keys': :'canUseApiKeys',
    'can_use_auth_tokens': :'canUseAuthTokens',
    'can_use_smtp_credentials': :'canUseSmtpCredentials',
    'can_use_customer_secret_keys': :'canUseCustomerSecretKeys',
    'can_use_o_auth2_client_credentials': :'canUseOAuth2ClientCredentials'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/oci/identity/models/user_capabilities.rb', line 50

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'can_use_console_password': :'BOOLEAN',
    'can_use_api_keys': :'BOOLEAN',
    'can_use_auth_tokens': :'BOOLEAN',
    'can_use_smtp_credentials': :'BOOLEAN',
    'can_use_customer_secret_keys': :'BOOLEAN',
    'can_use_o_auth2_client_credentials': :'BOOLEAN'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • the other object to be compared



125
126
127
128
129
130
131
132
133
134
135
# File 'lib/oci/identity/models/user_capabilities.rb', line 125

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    can_use_console_password == other.can_use_console_password &&
    can_use_api_keys == other.can_use_api_keys &&
    can_use_auth_tokens == other.can_use_auth_tokens &&
    can_use_smtp_credentials == other.can_use_smtp_credentials &&
    can_use_customer_secret_keys == other.can_use_customer_secret_keys &&
    can_use_o_auth2_client_credentials == other.can_use_o_auth2_client_credentials
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/oci/identity/models/user_capabilities.rb', line 160

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method

Parameters:

  • the other object to be compared

Returns:



140
141
142
# File 'lib/oci/identity/models/user_capabilities.rb', line 140

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • Hash code



149
150
151
# File 'lib/oci/identity/models/user_capabilities.rb', line 149

def hash
  [can_use_console_password, can_use_api_keys, can_use_auth_tokens, can_use_smtp_credentials, can_use_customer_secret_keys, can_use_o_auth2_client_credentials].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



193
194
195
196
197
198
199
200
201
202
# File 'lib/oci/identity/models/user_capabilities.rb', line 193

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



187
188
189
# File 'lib/oci/identity/models/user_capabilities.rb', line 187

def to_s
  to_hash.to_s
end