Class: OCI::IdentityDataPlane::Models::AuthorizationRequest
- Inherits:
-
Object
- Object
- OCI::IdentityDataPlane::Models::AuthorizationRequest
- Defined in:
- lib/oci/identity_data_plane/models/authorization_request.rb
Overview
AuthorizationRequest model.
Instance Attribute Summary collapse
-
#context ⇒ Array<OCI::IdentityDataPlane::Models::PermissionContext>
[Required] A set of permission contexts.
-
#policy_hash ⇒ String
[Required] The hash of cached policy on the caller service side.
-
#request_id ⇒ String
[Required] The id of this request.
-
#service_name ⇒ String
[Required] The name of the service that is making this authorization request.
-
#svc_principal ⇒ OCI::IdentityDataPlane::Models::Principal
[Required] The service principal object for service to service calls.
-
#user_principal ⇒ OCI::IdentityDataPlane::Models::Principal
[Required] The user principal object.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AuthorizationRequest
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ AuthorizationRequest
Initializes the object
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/oci/identity_data_plane/models/authorization_request.rb', line 76 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.request_id = attributes[:'requestId'] if attributes[:'requestId'] raise 'You cannot provide both :requestId and :request_id' if attributes.key?(:'requestId') && attributes.key?(:'request_id') self.request_id = attributes[:'request_id'] if attributes[:'request_id'] self.user_principal = attributes[:'userPrincipal'] if attributes[:'userPrincipal'] raise 'You cannot provide both :userPrincipal and :user_principal' if attributes.key?(:'userPrincipal') && attributes.key?(:'user_principal') self.user_principal = attributes[:'user_principal'] if attributes[:'user_principal'] self.svc_principal = attributes[:'svcPrincipal'] if attributes[:'svcPrincipal'] raise 'You cannot provide both :svcPrincipal and :svc_principal' if attributes.key?(:'svcPrincipal') && attributes.key?(:'svc_principal') self.svc_principal = attributes[:'svc_principal'] if attributes[:'svc_principal'] self.service_name = attributes[:'serviceName'] if attributes[:'serviceName'] raise 'You cannot provide both :serviceName and :service_name' if attributes.key?(:'serviceName') && attributes.key?(:'service_name') self.service_name = attributes[:'service_name'] if attributes[:'service_name'] self.context = attributes[:'context'] if attributes[:'context'] self.policy_hash = attributes[:'policyHash'] if attributes[:'policyHash'] raise 'You cannot provide both :policyHash and :policy_hash' if attributes.key?(:'policyHash') && attributes.key?(:'policy_hash') self.policy_hash = attributes[:'policy_hash'] if attributes[:'policy_hash'] end |
Instance Attribute Details
#context ⇒ Array<OCI::IdentityDataPlane::Models::PermissionContext>
[Required] A set of permission contexts
28 29 30 |
# File 'lib/oci/identity_data_plane/models/authorization_request.rb', line 28 def context @context end |
#policy_hash ⇒ String
[Required] The hash of cached policy on the caller service side. If this is different than what Identity has, it will send the most recent policy statements.
34 35 36 |
# File 'lib/oci/identity_data_plane/models/authorization_request.rb', line 34 def policy_hash @policy_hash end |
#request_id ⇒ String
[Required] The id of this request. It is a GUID.
12 13 14 |
# File 'lib/oci/identity_data_plane/models/authorization_request.rb', line 12 def request_id @request_id end |
#service_name ⇒ String
[Required] The name of the service that is making this authorization request
24 25 26 |
# File 'lib/oci/identity_data_plane/models/authorization_request.rb', line 24 def service_name @service_name end |
#svc_principal ⇒ OCI::IdentityDataPlane::Models::Principal
[Required] The service principal object for service to service calls.
20 21 22 |
# File 'lib/oci/identity_data_plane/models/authorization_request.rb', line 20 def svc_principal @svc_principal end |
#user_principal ⇒ OCI::IdentityDataPlane::Models::Principal
[Required] The user principal object
16 17 18 |
# File 'lib/oci/identity_data_plane/models/authorization_request.rb', line 16 def user_principal @user_principal end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 47 48 |
# File 'lib/oci/identity_data_plane/models/authorization_request.rb', line 37 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'request_id': :'requestId', 'user_principal': :'userPrincipal', 'svc_principal': :'svcPrincipal', 'service_name': :'serviceName', 'context': :'context', 'policy_hash': :'policyHash' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/oci/identity_data_plane/models/authorization_request.rb', line 51 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'request_id': :'String', 'user_principal': :'OCI::IdentityDataPlane::Models::Principal', 'svc_principal': :'OCI::IdentityDataPlane::Models::Principal', 'service_name': :'String', 'context': :'Array<OCI::IdentityDataPlane::Models::PermissionContext>', 'policy_hash': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/oci/identity_data_plane/models/authorization_request.rb', line 122 def ==(other) return true if equal?(other) self.class == other.class && request_id == other.request_id && user_principal == other.user_principal && svc_principal == other.svc_principal && service_name == other.service_name && context == other.context && policy_hash == other.policy_hash end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/oci/identity_data_plane/models/authorization_request.rb', line 157 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
137 138 139 |
# File 'lib/oci/identity_data_plane/models/authorization_request.rb', line 137 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
146 147 148 |
# File 'lib/oci/identity_data_plane/models/authorization_request.rb', line 146 def hash [request_id, user_principal, svc_principal, service_name, context, policy_hash].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
190 191 192 193 194 195 196 197 198 199 |
# File 'lib/oci/identity_data_plane/models/authorization_request.rb', line 190 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
184 185 186 |
# File 'lib/oci/identity_data_plane/models/authorization_request.rb', line 184 def to_s to_hash.to_s end |