Class: IdentityDataPlane::Models::Compartment
- Inherits:
-
Object
- Object
- IdentityDataPlane::Models::Compartment
- Defined in:
- lib/oci/identity_data_plane/models/compartment.rb
Overview
Compartment model.
Instance Attribute Summary collapse
-
#display_name ⇒ String
**[Required]** The display name of the compartment.
-
#full_name ⇒ String
**[Required]** The full name of the compartment.
-
#id ⇒ String
**[Required]** The id of the compartment.
-
#name ⇒ String
**[Required]** The name of the compartment.
-
#parent_compartment_id ⇒ String
**[Required]** The id of the parent compartment.
-
#property_map ⇒ Hash<String, String>
**[Required]** The extended properties.
-
#status ⇒ OCI::IdentityDataPlane::Models::EntityStatus
**[Required]** The status of the compartment.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Compartment
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Compartment
Initializes the object
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/oci/identity_data_plane/models/compartment.rb', line 82 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.name = attributes[:'name'] if attributes[:'name'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.full_name = attributes[:'fullName'] if attributes[:'fullName'] raise 'You cannot provide both :fullName and :full_name' if attributes.key?(:'fullName') && attributes.key?(:'full_name') self.full_name = attributes[:'full_name'] if attributes[:'full_name'] self.parent_compartment_id = attributes[:'parentCompartmentId'] if attributes[:'parentCompartmentId'] raise 'You cannot provide both :parentCompartmentId and :parent_compartment_id' if attributes.key?(:'parentCompartmentId') && attributes.key?(:'parent_compartment_id') self.parent_compartment_id = attributes[:'parent_compartment_id'] if attributes[:'parent_compartment_id'] self.status = attributes[:'status'] if attributes[:'status'] self.property_map = attributes[:'propertyMap'] if attributes[:'propertyMap'] raise 'You cannot provide both :propertyMap and :property_map' if attributes.key?(:'propertyMap') && attributes.key?(:'property_map') self.property_map = attributes[:'property_map'] if attributes[:'property_map'] end |
Instance Attribute Details
#display_name ⇒ String
**[Required]** The display name of the compartment.
21 22 23 |
# File 'lib/oci/identity_data_plane/models/compartment.rb', line 21 def display_name @display_name end |
#full_name ⇒ String
**[Required]** The full name of the compartment.
25 26 27 |
# File 'lib/oci/identity_data_plane/models/compartment.rb', line 25 def full_name @full_name end |
#id ⇒ String
**[Required]** The id of the compartment.
13 14 15 |
# File 'lib/oci/identity_data_plane/models/compartment.rb', line 13 def id @id end |
#name ⇒ String
**[Required]** The name of the compartment.
17 18 19 |
# File 'lib/oci/identity_data_plane/models/compartment.rb', line 17 def name @name end |
#parent_compartment_id ⇒ String
**[Required]** The id of the parent compartment.
29 30 31 |
# File 'lib/oci/identity_data_plane/models/compartment.rb', line 29 def parent_compartment_id @parent_compartment_id end |
#property_map ⇒ Hash<String, String>
**[Required]** The extended properties.
37 38 39 |
# File 'lib/oci/identity_data_plane/models/compartment.rb', line 37 def property_map @property_map end |
#status ⇒ OCI::IdentityDataPlane::Models::EntityStatus
**[Required]** The status of the compartment.
33 34 35 |
# File 'lib/oci/identity_data_plane/models/compartment.rb', line 33 def status @status end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/oci/identity_data_plane/models/compartment.rb', line 40 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'name': :'name', 'display_name': :'displayName', 'full_name': :'fullName', 'parent_compartment_id': :'parentCompartmentId', 'status': :'status', 'property_map': :'propertyMap' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/oci/identity_data_plane/models/compartment.rb', line 55 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'name': :'String', 'display_name': :'String', 'full_name': :'String', 'parent_compartment_id': :'String', 'status': :'OCI::IdentityDataPlane::Models::EntityStatus', 'property_map': :'Hash<String, String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/oci/identity_data_plane/models/compartment.rb', line 126 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && name == other.name && display_name == other.display_name && full_name == other.full_name && parent_compartment_id == other.parent_compartment_id && status == other.status && property_map == other.property_map end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/oci/identity_data_plane/models/compartment.rb', line 162 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
142 143 144 |
# File 'lib/oci/identity_data_plane/models/compartment.rb', line 142 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
151 152 153 |
# File 'lib/oci/identity_data_plane/models/compartment.rb', line 151 def hash [id, name, display_name, full_name, parent_compartment_id, status, property_map].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
195 196 197 198 199 200 201 202 203 204 |
# File 'lib/oci/identity_data_plane/models/compartment.rb', line 195 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
189 190 191 |
# File 'lib/oci/identity_data_plane/models/compartment.rb', line 189 def to_s to_hash.to_s end |