Class: OCI::IdentityDataPlane::Models::IdentityProvider
- Inherits:
-
Object
- Object
- OCI::IdentityDataPlane::Models::IdentityProvider
- Defined in:
- lib/oci/identity_data_plane/models/identity_provider.rb
Overview
IdentityProvider model.
Constant Summary collapse
- PROTOCOL_ENUM =
[ PROTOCOL_SAML2 = 'SAML2'.freeze, PROTOCOL_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#authn_context_class_refs ⇒ Array<String>
[Required] Authentication context class refs.
-
#force_authentication ⇒ BOOLEAN
[Required] Whether to force authentication.
-
#id ⇒ String
[Required] The id of the provider.
-
#name ⇒ String
[Required] The name of the provider.
-
#protocol ⇒ String
[Required] The type of the provider.
-
#redirect_uri ⇒ String
[Required] The SAML endpoint where user will be redirected.
-
#service_provider_entity_id ⇒ String
[Required] The id of the service provider entity.
-
#signing_certificate ⇒ String
[Required] The signing certificate of the provider.
-
#tenant_id ⇒ String
[Required] The id of the tenant.
-
#tenant_name ⇒ String
[Required] The name of the tenant.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IdentityProvider
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ IdentityProvider
Initializes the object
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/oci/identity_data_plane/models/identity_provider.rb', line 108 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.name = attributes[:'name'] if attributes[:'name'] self.tenant_name = attributes[:'tenantName'] if attributes[:'tenantName'] raise 'You cannot provide both :tenantName and :tenant_name' if attributes.key?(:'tenantName') && attributes.key?(:'tenant_name') self.tenant_name = attributes[:'tenant_name'] if attributes[:'tenant_name'] self.tenant_id = attributes[:'tenantId'] if attributes[:'tenantId'] raise 'You cannot provide both :tenantId and :tenant_id' if attributes.key?(:'tenantId') && attributes.key?(:'tenant_id') self.tenant_id = attributes[:'tenant_id'] if attributes[:'tenant_id'] self.redirect_uri = attributes[:'redirectUri'] if attributes[:'redirectUri'] raise 'You cannot provide both :redirectUri and :redirect_uri' if attributes.key?(:'redirectUri') && attributes.key?(:'redirect_uri') self.redirect_uri = attributes[:'redirect_uri'] if attributes[:'redirect_uri'] self.signing_certificate = attributes[:'signingCertificate'] if attributes[:'signingCertificate'] raise 'You cannot provide both :signingCertificate and :signing_certificate' if attributes.key?(:'signingCertificate') && attributes.key?(:'signing_certificate') self.signing_certificate = attributes[:'signing_certificate'] if attributes[:'signing_certificate'] self.protocol = attributes[:'protocol'] if attributes[:'protocol'] self.service_provider_entity_id = attributes[:'serviceProviderEntityId'] if attributes[:'serviceProviderEntityId'] raise 'You cannot provide both :serviceProviderEntityId and :service_provider_entity_id' if attributes.key?(:'serviceProviderEntityId') && attributes.key?(:'service_provider_entity_id') self.service_provider_entity_id = attributes[:'service_provider_entity_id'] if attributes[:'service_provider_entity_id'] self.force_authentication = attributes[:'forceAuthentication'] unless attributes[:'forceAuthentication'].nil? raise 'You cannot provide both :forceAuthentication and :force_authentication' if attributes.key?(:'forceAuthentication') && attributes.key?(:'force_authentication') self.force_authentication = attributes[:'force_authentication'] unless attributes[:'force_authentication'].nil? self.authn_context_class_refs = attributes[:'authnContextClassRefs'] if attributes[:'authnContextClassRefs'] raise 'You cannot provide both :authnContextClassRefs and :authn_context_class_refs' if attributes.key?(:'authnContextClassRefs') && attributes.key?(:'authn_context_class_refs') self.authn_context_class_refs = attributes[:'authn_context_class_refs'] if attributes[:'authn_context_class_refs'] end |
Instance Attribute Details
#authn_context_class_refs ⇒ Array<String>
[Required] Authentication context class refs.
54 55 56 |
# File 'lib/oci/identity_data_plane/models/identity_provider.rb', line 54 def authn_context_class_refs @authn_context_class_refs end |
#force_authentication ⇒ BOOLEAN
[Required] Whether to force authentication.
50 51 52 |
# File 'lib/oci/identity_data_plane/models/identity_provider.rb', line 50 def force_authentication @force_authentication end |
#id ⇒ String
[Required] The id of the provider.
18 19 20 |
# File 'lib/oci/identity_data_plane/models/identity_provider.rb', line 18 def id @id end |
#name ⇒ String
[Required] The name of the provider.
22 23 24 |
# File 'lib/oci/identity_data_plane/models/identity_provider.rb', line 22 def name @name end |
#protocol ⇒ String
[Required] The type of the provider.
42 43 44 |
# File 'lib/oci/identity_data_plane/models/identity_provider.rb', line 42 def protocol @protocol end |
#redirect_uri ⇒ String
[Required] The SAML endpoint where user will be redirected.
34 35 36 |
# File 'lib/oci/identity_data_plane/models/identity_provider.rb', line 34 def redirect_uri @redirect_uri end |
#service_provider_entity_id ⇒ String
[Required] The id of the service provider entity.
46 47 48 |
# File 'lib/oci/identity_data_plane/models/identity_provider.rb', line 46 def service_provider_entity_id @service_provider_entity_id end |
#signing_certificate ⇒ String
[Required] The signing certificate of the provider.
38 39 40 |
# File 'lib/oci/identity_data_plane/models/identity_provider.rb', line 38 def signing_certificate @signing_certificate end |
#tenant_id ⇒ String
[Required] The id of the tenant.
30 31 32 |
# File 'lib/oci/identity_data_plane/models/identity_provider.rb', line 30 def tenant_id @tenant_id end |
#tenant_name ⇒ String
[Required] The name of the tenant.
26 27 28 |
# File 'lib/oci/identity_data_plane/models/identity_provider.rb', line 26 def tenant_name @tenant_name end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/oci/identity_data_plane/models/identity_provider.rb', line 57 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'name': :'name', 'tenant_name': :'tenantName', 'tenant_id': :'tenantId', 'redirect_uri': :'redirectUri', 'signing_certificate': :'signingCertificate', 'protocol': :'protocol', 'service_provider_entity_id': :'serviceProviderEntityId', 'force_authentication': :'forceAuthentication', 'authn_context_class_refs': :'authnContextClassRefs' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/oci/identity_data_plane/models/identity_provider.rb', line 75 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'name': :'String', 'tenant_name': :'String', 'tenant_id': :'String', 'redirect_uri': :'String', 'signing_certificate': :'String', 'protocol': :'String', 'service_provider_entity_id': :'String', 'force_authentication': :'BOOLEAN', 'authn_context_class_refs': :'Array<String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/oci/identity_data_plane/models/identity_provider.rb', line 183 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && name == other.name && tenant_name == other.tenant_name && tenant_id == other.tenant_id && redirect_uri == other.redirect_uri && signing_certificate == other.signing_certificate && protocol == other.protocol && service_provider_entity_id == other.service_provider_entity_id && force_authentication == other.force_authentication && authn_context_class_refs == other.authn_context_class_refs end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/oci/identity_data_plane/models/identity_provider.rb', line 222 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
202 203 204 |
# File 'lib/oci/identity_data_plane/models/identity_provider.rb', line 202 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
211 212 213 |
# File 'lib/oci/identity_data_plane/models/identity_provider.rb', line 211 def hash [id, name, tenant_name, tenant_id, redirect_uri, signing_certificate, protocol, service_provider_entity_id, force_authentication, authn_context_class_refs].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
255 256 257 258 259 260 261 262 263 264 |
# File 'lib/oci/identity_data_plane/models/identity_provider.rb', line 255 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
249 250 251 |
# File 'lib/oci/identity_data_plane/models/identity_provider.rb', line 249 def to_s to_hash.to_s end |