Class: IdentityDataPlane::Models::JWK
- Inherits:
-
Object
- Object
- IdentityDataPlane::Models::JWK
- Defined in:
- lib/oci/identity_data_plane/models/jwk.rb
Overview
JWK model.
Instance Attribute Summary collapse
-
#alg ⇒ String
**[Required]** The algorithm.
-
#e ⇒ String
**[Required]** The exponent.
-
#kid ⇒ String
**[Required]** The key id.
-
#kty ⇒ String
**[Required]** The key type.
-
#n ⇒ String
**[Required]** The modulus.
-
#use ⇒ String
**[Required]** The key use.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ JWK
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ JWK
Initializes the object
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/oci/identity_data_plane/models/jwk.rb', line 74 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.n = attributes[:'n'] if attributes[:'n'] self.e = attributes[:'e'] if attributes[:'e'] self.kid = attributes[:'kid'] if attributes[:'kid'] self.use = attributes[:'use'] if attributes[:'use'] self.alg = attributes[:'alg'] if attributes[:'alg'] self.kty = attributes[:'kty'] if attributes[:'kty'] end |
Instance Attribute Details
#alg ⇒ String
**[Required]** The algorithm.
28 29 30 |
# File 'lib/oci/identity_data_plane/models/jwk.rb', line 28 def alg @alg end |
#e ⇒ String
**[Required]** The exponent.
16 17 18 |
# File 'lib/oci/identity_data_plane/models/jwk.rb', line 16 def e @e end |
#kid ⇒ String
**[Required]** The key id.
20 21 22 |
# File 'lib/oci/identity_data_plane/models/jwk.rb', line 20 def kid @kid end |
#kty ⇒ String
**[Required]** The key type.
32 33 34 |
# File 'lib/oci/identity_data_plane/models/jwk.rb', line 32 def kty @kty end |
#n ⇒ String
**[Required]** The modulus.
12 13 14 |
# File 'lib/oci/identity_data_plane/models/jwk.rb', line 12 def n @n end |
#use ⇒ String
**[Required]** The key use.
24 25 26 |
# File 'lib/oci/identity_data_plane/models/jwk.rb', line 24 def use @use end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/oci/identity_data_plane/models/jwk.rb', line 35 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'n': :'n', 'e': :'e', 'kid': :'kid', 'use': :'use', 'alg': :'alg', 'kty': :'kty' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/oci/identity_data_plane/models/jwk.rb', line 49 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'n': :'String', 'e': :'String', 'kid': :'String', 'use': :'String', 'alg': :'String', 'kty': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/oci/identity_data_plane/models/jwk.rb', line 100 def ==(other) return true if equal?(other) self.class == other.class && n == other.n && e == other.e && kid == other.kid && use == other.use && alg == other.alg && kty == other.kty end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/oci/identity_data_plane/models/jwk.rb', line 135 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
115 116 117 |
# File 'lib/oci/identity_data_plane/models/jwk.rb', line 115 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
124 125 126 |
# File 'lib/oci/identity_data_plane/models/jwk.rb', line 124 def hash [n, e, kid, use, alg, kty].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
168 169 170 171 172 173 174 175 176 177 |
# File 'lib/oci/identity_data_plane/models/jwk.rb', line 168 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
162 163 164 |
# File 'lib/oci/identity_data_plane/models/jwk.rb', line 162 def to_s to_hash.to_s end |