Class: OCI::IdentityDataPlane::Models::ThickAuthorizationResponse
- Inherits:
-
Object
- Object
- OCI::IdentityDataPlane::Models::ThickAuthorizationResponse
- Defined in:
- lib/oci/identity_data_plane/models/thick_authorization_response.rb
Overview
ThickAuthorizationResponse model.
Instance Attribute Summary collapse
-
#flush_all_caches ⇒ BOOLEAN
If set to true, the SDK should clear the caches.
-
#group_membership_cache_duration ⇒ String
[Required] The duration of how long the user’s group membership should be cached.
-
#groups ⇒ Array<String>
[Required] The policy string related to the request.
-
#policy ⇒ String
[Required] The policy string related to the request.
-
#policy_cache_duration ⇒ String
[Required] The duration of how long this policy should be cached.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ThickAuthorizationResponse
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ThickAuthorizationResponse
Initializes the object
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/oci/identity_data_plane/models/thick_authorization_response.rb', line 71 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.policy = attributes[:'policy'] if attributes[:'policy'] self.policy_cache_duration = attributes[:'policyCacheDuration'] if attributes[:'policyCacheDuration'] raise 'You cannot provide both :policyCacheDuration and :policy_cache_duration' if attributes.key?(:'policyCacheDuration') && attributes.key?(:'policy_cache_duration') self.policy_cache_duration = attributes[:'policy_cache_duration'] if attributes[:'policy_cache_duration'] self.groups = attributes[:'groups'] if attributes[:'groups'] self.group_membership_cache_duration = attributes[:'groupMembershipCacheDuration'] if attributes[:'groupMembershipCacheDuration'] raise 'You cannot provide both :groupMembershipCacheDuration and :group_membership_cache_duration' if attributes.key?(:'groupMembershipCacheDuration') && attributes.key?(:'group_membership_cache_duration') self.group_membership_cache_duration = attributes[:'group_membership_cache_duration'] if attributes[:'group_membership_cache_duration'] self.flush_all_caches = attributes[:'flushAllCaches'] unless attributes[:'flushAllCaches'].nil? raise 'You cannot provide both :flushAllCaches and :flush_all_caches' if attributes.key?(:'flushAllCaches') && attributes.key?(:'flush_all_caches') self.flush_all_caches = attributes[:'flush_all_caches'] unless attributes[:'flush_all_caches'].nil? end |
Instance Attribute Details
#flush_all_caches ⇒ BOOLEAN
If set to true, the SDK should clear the caches.
32 33 34 |
# File 'lib/oci/identity_data_plane/models/thick_authorization_response.rb', line 32 def flush_all_caches @flush_all_caches end |
#group_membership_cache_duration ⇒ String
[Required] The duration of how long the user’s group membership should be cached. Note that the type is of type java.time.Duration, not string.
28 29 30 |
# File 'lib/oci/identity_data_plane/models/thick_authorization_response.rb', line 28 def group_membership_cache_duration @group_membership_cache_duration end |
#groups ⇒ Array<String>
[Required] The policy string related to the request.
22 23 24 |
# File 'lib/oci/identity_data_plane/models/thick_authorization_response.rb', line 22 def groups @groups end |
#policy ⇒ String
[Required] The policy string related to the request
12 13 14 |
# File 'lib/oci/identity_data_plane/models/thick_authorization_response.rb', line 12 def policy @policy end |
#policy_cache_duration ⇒ String
[Required] The duration of how long this policy should be cached. Note that the type is of type java.time.Duration, not string.
18 19 20 |
# File 'lib/oci/identity_data_plane/models/thick_authorization_response.rb', line 18 def policy_cache_duration @policy_cache_duration end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 45 |
# File 'lib/oci/identity_data_plane/models/thick_authorization_response.rb', line 35 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'policy': :'policy', 'policy_cache_duration': :'policyCacheDuration', 'groups': :'groups', 'group_membership_cache_duration': :'groupMembershipCacheDuration', 'flush_all_caches': :'flushAllCaches' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/oci/identity_data_plane/models/thick_authorization_response.rb', line 48 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'policy': :'String', 'policy_cache_duration': :'String', 'groups': :'Array<String>', 'group_membership_cache_duration': :'String', 'flush_all_caches': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
107 108 109 110 111 112 113 114 115 116 |
# File 'lib/oci/identity_data_plane/models/thick_authorization_response.rb', line 107 def ==(other) return true if equal?(other) self.class == other.class && policy == other.policy && policy_cache_duration == other.policy_cache_duration && groups == other.groups && group_membership_cache_duration == other.group_membership_cache_duration && flush_all_caches == other.flush_all_caches end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/oci/identity_data_plane/models/thick_authorization_response.rb', line 141 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
121 122 123 |
# File 'lib/oci/identity_data_plane/models/thick_authorization_response.rb', line 121 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
130 131 132 |
# File 'lib/oci/identity_data_plane/models/thick_authorization_response.rb', line 130 def hash [policy, policy_cache_duration, groups, group_membership_cache_duration, flush_all_caches].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
174 175 176 177 178 179 180 181 182 183 |
# File 'lib/oci/identity_data_plane/models/thick_authorization_response.rb', line 174 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
168 169 170 |
# File 'lib/oci/identity_data_plane/models/thick_authorization_response.rb', line 168 def to_s to_hash.to_s end |