Class: IdentityDataPlane::Models::User
- Inherits:
-
Object
- Object
- IdentityDataPlane::Models::User
- Defined in:
- lib/oci/identity_data_plane/models/user.rb
Overview
User model.
Instance Attribute Summary collapse
-
#id ⇒ String
**[Required]** The user's Oracle ID (OCID).
-
#is_mfa_activated ⇒ BOOLEAN
**[Required]** If mfa is activated.
-
#is_mfa_verified ⇒ BOOLEAN
**[Required]** If the user has been mfa verified.
-
#is_otp ⇒ BOOLEAN
**[Required]** If the provided password is a one-time password.
-
#name ⇒ String
**[Required]** The name of the user.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ User
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ User
Initializes the object
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/oci/identity_data_plane/models/user.rb', line 68 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.name = attributes[:'name'] if attributes[:'name'] self.is_otp = attributes[:'isOTP'] unless attributes[:'isOTP'].nil? raise 'You cannot provide both :isOTP and :is_otp' if attributes.key?(:'isOTP') && attributes.key?(:'is_otp') self.is_otp = attributes[:'is_otp'] unless attributes[:'is_otp'].nil? self.is_mfa_activated = attributes[:'isMfaActivated'] unless attributes[:'isMfaActivated'].nil? raise 'You cannot provide both :isMfaActivated and :is_mfa_activated' if attributes.key?(:'isMfaActivated') && attributes.key?(:'is_mfa_activated') self.is_mfa_activated = attributes[:'is_mfa_activated'] unless attributes[:'is_mfa_activated'].nil? self.is_mfa_verified = attributes[:'isMfaVerified'] unless attributes[:'isMfaVerified'].nil? raise 'You cannot provide both :isMfaVerified and :is_mfa_verified' if attributes.key?(:'isMfaVerified') && attributes.key?(:'is_mfa_verified') self.is_mfa_verified = attributes[:'is_mfa_verified'] unless attributes[:'is_mfa_verified'].nil? end |
Instance Attribute Details
#id ⇒ String
**[Required]** The user's Oracle ID (OCID).
13 14 15 |
# File 'lib/oci/identity_data_plane/models/user.rb', line 13 def id @id end |
#is_mfa_activated ⇒ BOOLEAN
**[Required]** If mfa is activated.
25 26 27 |
# File 'lib/oci/identity_data_plane/models/user.rb', line 25 def is_mfa_activated @is_mfa_activated end |
#is_mfa_verified ⇒ BOOLEAN
**[Required]** If the user has been mfa verified.
29 30 31 |
# File 'lib/oci/identity_data_plane/models/user.rb', line 29 def is_mfa_verified @is_mfa_verified end |
#is_otp ⇒ BOOLEAN
**[Required]** If the provided password is a one-time password.
21 22 23 |
# File 'lib/oci/identity_data_plane/models/user.rb', line 21 def is_otp @is_otp end |
#name ⇒ String
**[Required]** The name of the user.
17 18 19 |
# File 'lib/oci/identity_data_plane/models/user.rb', line 17 def name @name end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 40 41 42 |
# File 'lib/oci/identity_data_plane/models/user.rb', line 32 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'name': :'name', 'is_otp': :'isOTP', 'is_mfa_activated': :'isMfaActivated', 'is_mfa_verified': :'isMfaVerified' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/oci/identity_data_plane/models/user.rb', line 45 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'name': :'String', 'is_otp': :'BOOLEAN', 'is_mfa_activated': :'BOOLEAN', 'is_mfa_verified': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
104 105 106 107 108 109 110 111 112 113 |
# File 'lib/oci/identity_data_plane/models/user.rb', line 104 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && name == other.name && is_otp == other.is_otp && is_mfa_activated == other.is_mfa_activated && is_mfa_verified == other.is_mfa_verified end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/oci/identity_data_plane/models/user.rb', line 138 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
118 119 120 |
# File 'lib/oci/identity_data_plane/models/user.rb', line 118 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
127 128 129 |
# File 'lib/oci/identity_data_plane/models/user.rb', line 127 def hash [id, name, is_otp, is_mfa_activated, is_mfa_verified].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
171 172 173 174 175 176 177 178 179 180 |
# File 'lib/oci/identity_data_plane/models/user.rb', line 171 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
165 166 167 |
# File 'lib/oci/identity_data_plane/models/user.rb', line 165 def to_s to_hash.to_s end |