Class: OCI::Integration::IntegrationInstanceClient
- Inherits:
-
Object
- Object
- OCI::Integration::IntegrationInstanceClient
- Defined in:
- lib/oci/integration/integration_instance_client.rb
Overview
Oracle Integration API.
Instance Attribute Summary collapse
-
#api_client ⇒ OCI::ApiClient
readonly
Client used to make HTTP requests.
-
#endpoint ⇒ String
readonly
Fully qualified endpoint URL.
-
#region ⇒ String
The region, which will usually correspond to a value in Regions::REGION_ENUM.
-
#retry_config ⇒ OCI::Retry::RetryConfig
readonly
The default retry configuration to apply to all operations in this service client.
Instance Method Summary collapse
-
#change_integration_instance_compartment(integration_instance_id, change_integration_instance_compartment_details, opts = {}) ⇒ Response
Change the compartment for an integration instance.
-
#change_integration_instance_network_endpoint(integration_instance_id, change_integration_instance_network_endpoint_details, opts = {}) ⇒ Response
Change an Integration instance network endpoint.
-
#create_integration_instance(create_integration_instance_details, opts = {}) ⇒ Response
Creates a new Integration Instance.
-
#delete_integration_instance(integration_instance_id, opts = {}) ⇒ Response
Deletes an Integration Instance resource by identifier.
-
#get_integration_instance(integration_instance_id, opts = {}) ⇒ Response
Gets a IntegrationInstance by identifier.
-
#get_work_request(work_request_id, opts = {}) ⇒ Response
Gets the status of the work request with the given ID.
-
#initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) ⇒ IntegrationInstanceClient
constructor
Creates a new IntegrationInstanceClient.
-
#list_integration_instances(compartment_id, opts = {}) ⇒ Response
Returns a list of Integration Instances.
-
#list_work_request_errors(compartment_id, work_request_id, opts = {}) ⇒ Response
Get the errors of a work request.
-
#list_work_request_logs(compartment_id, work_request_id, opts = {}) ⇒ Response
Get the logs of a work request.
-
#list_work_requests(compartment_id, opts = {}) ⇒ Response
Lists the work requests in a compartment.
-
#logger ⇒ Logger
The logger for this client.
-
#start_integration_instance(integration_instance_id, opts = {}) ⇒ Response
Start an integration instance that was previously in an INACTIVE state.
-
#stop_integration_instance(integration_instance_id, opts = {}) ⇒ Response
Stop an integration instance that was previously in an ACTIVE state.
-
#update_integration_instance(integration_instance_id, update_integration_instance_details, opts = {}) ⇒ Response
Updates the Integration Instance.
Constructor Details
#initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) ⇒ IntegrationInstanceClient
Creates a new IntegrationInstanceClient. Notes:
If a config is not specified, then the global OCI.config will be used.
This client is not thread-safe
Either a region or an endpoint must be specified. If an endpoint is specified, it will be used instead of the
region. A region may be specified in the config or via or the region parameter. If specified in both, then the
region parameter will be used.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/oci/integration/integration_instance_client.rb', line 53 def initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) # If the signer is an InstancePrincipalsSecurityTokenSigner or SecurityTokenSigner and no config was supplied (they are self-sufficient signers) # then create a dummy config to pass to the ApiClient constructor. If customers wish to create a client which uses instance principals # and has config (either populated programmatically or loaded from a file), they must construct that config themselves and then # pass it to this constructor. # # If there is no signer (or the signer is not an instance principals signer) and no config was supplied, this is not valid # so try and load the config from the default file. config = OCI::Config.validate_and_build_config_with_signer(config, signer) signer = OCI::Signer.config_file_auth_builder(config) if signer.nil? @api_client = OCI::ApiClient.new(config, signer, proxy_settings: proxy_settings) @retry_config = retry_config if endpoint @endpoint = endpoint + '/20190131' else region ||= config.region region ||= signer.region if signer.respond_to?(:region) self.region = region end logger.info "IntegrationInstanceClient endpoint set to '#{@endpoint}'." if logger end |
Instance Attribute Details
#api_client ⇒ OCI::ApiClient (readonly)
Client used to make HTTP requests.
13 14 15 |
# File 'lib/oci/integration/integration_instance_client.rb', line 13 def api_client @api_client end |
#endpoint ⇒ String (readonly)
Fully qualified endpoint URL
17 18 19 |
# File 'lib/oci/integration/integration_instance_client.rb', line 17 def endpoint @endpoint end |
#region ⇒ String
The region, which will usually correspond to a value in Regions::REGION_ENUM.
27 28 29 |
# File 'lib/oci/integration/integration_instance_client.rb', line 27 def region @region end |
#retry_config ⇒ OCI::Retry::RetryConfig (readonly)
The default retry configuration to apply to all operations in this service client. This can be overridden on a per-operation basis. The default retry configuration value is nil, which means that an operation will not perform any retries
23 24 25 |
# File 'lib/oci/integration/integration_instance_client.rb', line 23 def retry_config @retry_config end |
Instance Method Details
#change_integration_instance_compartment(integration_instance_id, change_integration_instance_compartment_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/integration/change_integration_instance_compartment.rb.html) to see an example of how to use change_integration_instance_compartment API.
Change the compartment for an integration instance
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/oci/integration/integration_instance_client.rb', line 124 def change_integration_instance_compartment(integration_instance_id, change_integration_instance_compartment_details, opts = {}) logger.debug 'Calling operation IntegrationInstanceClient#change_integration_instance_compartment.' if logger raise "Missing the required parameter 'integration_instance_id' when calling change_integration_instance_compartment." if integration_instance_id.nil? raise "Missing the required parameter 'change_integration_instance_compartment_details' when calling change_integration_instance_compartment." if change_integration_instance_compartment_details.nil? raise "Parameter value for 'integration_instance_id' must not be blank" if OCI::Internal::Util.blank_string?(integration_instance_id) path = '/integrationInstances/{integrationInstanceId}/actions/changeCompartment'.sub('{integrationInstanceId}', integration_instance_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = @api_client.object_to_http_body(change_integration_instance_compartment_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'IntegrationInstanceClient#change_integration_instance_compartment') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#change_integration_instance_network_endpoint(integration_instance_id, change_integration_instance_network_endpoint_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/integration/change_integration_instance_network_endpoint.rb.html) to see an example of how to use change_integration_instance_network_endpoint API.
Change an Integration instance network endpoint. The operation is long-running and creates a new WorkRequest.
197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/oci/integration/integration_instance_client.rb', line 197 def change_integration_instance_network_endpoint(integration_instance_id, change_integration_instance_network_endpoint_details, opts = {}) logger.debug 'Calling operation IntegrationInstanceClient#change_integration_instance_network_endpoint.' if logger raise "Missing the required parameter 'integration_instance_id' when calling change_integration_instance_network_endpoint." if integration_instance_id.nil? raise "Missing the required parameter 'change_integration_instance_network_endpoint_details' when calling change_integration_instance_network_endpoint." if change_integration_instance_network_endpoint_details.nil? raise "Parameter value for 'integration_instance_id' must not be blank" if OCI::Internal::Util.blank_string?(integration_instance_id) path = '/integrationInstances/{integrationInstanceId}/actions/changeNetworkEndpoint'.sub('{integrationInstanceId}', integration_instance_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = @api_client.object_to_http_body(change_integration_instance_network_endpoint_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'IntegrationInstanceClient#change_integration_instance_network_endpoint') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#create_integration_instance(create_integration_instance_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/integration/create_integration_instance.rb.html) to see an example of how to use create_integration_instance API.
Creates a new Integration Instance.
262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/oci/integration/integration_instance_client.rb', line 262 def create_integration_instance(create_integration_instance_details, opts = {}) logger.debug 'Calling operation IntegrationInstanceClient#create_integration_instance.' if logger raise "Missing the required parameter 'create_integration_instance_details' when calling create_integration_instance." if create_integration_instance_details.nil? path = '/integrationInstances' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = @api_client.object_to_http_body(create_integration_instance_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'IntegrationInstanceClient#create_integration_instance') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#delete_integration_instance(integration_instance_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/integration/delete_integration_instance.rb.html) to see an example of how to use delete_integration_instance API.
Deletes an Integration Instance resource by identifier.
322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 |
# File 'lib/oci/integration/integration_instance_client.rb', line 322 def delete_integration_instance(integration_instance_id, opts = {}) logger.debug 'Calling operation IntegrationInstanceClient#delete_integration_instance.' if logger raise "Missing the required parameter 'integration_instance_id' when calling delete_integration_instance." if integration_instance_id.nil? raise "Parameter value for 'integration_instance_id' must not be blank" if OCI::Internal::Util.blank_string?(integration_instance_id) path = '/integrationInstances/{integrationInstanceId}'.sub('{integrationInstanceId}', integration_instance_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'IntegrationInstanceClient#delete_integration_instance') do @api_client.call_api( :DELETE, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#get_integration_instance(integration_instance_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/integration/get_integration_instance.rb.html) to see an example of how to use get_integration_instance API.
Gets a IntegrationInstance by identifier
376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 |
# File 'lib/oci/integration/integration_instance_client.rb', line 376 def get_integration_instance(integration_instance_id, opts = {}) logger.debug 'Calling operation IntegrationInstanceClient#get_integration_instance.' if logger raise "Missing the required parameter 'integration_instance_id' when calling get_integration_instance." if integration_instance_id.nil? raise "Parameter value for 'integration_instance_id' must not be blank" if OCI::Internal::Util.blank_string?(integration_instance_id) path = '/integrationInstances/{integrationInstanceId}'.sub('{integrationInstanceId}', integration_instance_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'IntegrationInstanceClient#get_integration_instance') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Integration::Models::IntegrationInstance' ) end # rubocop:enable Metrics/BlockLength end |
#get_work_request(work_request_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/integration/get_work_request.rb.html) to see an example of how to use get_work_request API.
Gets the status of the work request with the given ID.
430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 |
# File 'lib/oci/integration/integration_instance_client.rb', line 430 def get_work_request(work_request_id, opts = {}) logger.debug 'Calling operation IntegrationInstanceClient#get_work_request.' if logger raise "Missing the required parameter 'work_request_id' when calling get_work_request." if work_request_id.nil? raise "Parameter value for 'work_request_id' must not be blank" if OCI::Internal::Util.blank_string?(work_request_id) path = '/workRequests/{workRequestId}'.sub('{workRequestId}', work_request_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'IntegrationInstanceClient#get_work_request') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Integration::Models::WorkRequest' ) end # rubocop:enable Metrics/BlockLength end |
#list_integration_instances(compartment_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/integration/list_integration_instances.rb.html) to see an example of how to use list_integration_instances API.
Returns a list of Integration Instances.
500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 |
# File 'lib/oci/integration/integration_instance_client.rb', line 500 def list_integration_instances(compartment_id, opts = {}) logger.debug 'Calling operation IntegrationInstanceClient#list_integration_instances.' if logger raise "Missing the required parameter 'compartment_id' when calling list_integration_instances." if compartment_id.nil? if opts[:lifecycle_state] && !%w[CREATING UPDATING ACTIVE INACTIVE DELETING DELETED FAILED].include?(opts[:lifecycle_state]) raise 'Invalid value for "lifecycle_state", must be one of CREATING, UPDATING, ACTIVE, INACTIVE, DELETING, DELETED, FAILED.' end if opts[:sort_order] && !%w[ASC DESC].include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of ASC, DESC.' end if opts[:sort_by] && !%w[TIMECREATED DISPLAYNAME].include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of TIMECREATED, DISPLAYNAME.' end path = '/integrationInstances' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:compartmentId] = compartment_id query_params[:displayName] = opts[:display_name] if opts[:display_name] query_params[:lifecycleState] = opts[:lifecycle_state] if opts[:lifecycle_state] query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'IntegrationInstanceClient#list_integration_instances') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'Array<OCI::Integration::Models::IntegrationInstanceSummary>' ) end # rubocop:enable Metrics/BlockLength end |
#list_work_request_errors(compartment_id, work_request_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/integration/list_work_request_errors.rb.html) to see an example of how to use list_work_request_errors API.
Get the errors of a work request.
575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 |
# File 'lib/oci/integration/integration_instance_client.rb', line 575 def list_work_request_errors(compartment_id, work_request_id, opts = {}) logger.debug 'Calling operation IntegrationInstanceClient#list_work_request_errors.' if logger raise "Missing the required parameter 'compartment_id' when calling list_work_request_errors." if compartment_id.nil? raise "Missing the required parameter 'work_request_id' when calling list_work_request_errors." if work_request_id.nil? raise "Parameter value for 'work_request_id' must not be blank" if OCI::Internal::Util.blank_string?(work_request_id) path = '/workRequests/{workRequestId}/errors'.sub('{workRequestId}', work_request_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:compartmentId] = compartment_id query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'IntegrationInstanceClient#list_work_request_errors') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'Array<OCI::Integration::Models::WorkRequestError>' ) end # rubocop:enable Metrics/BlockLength end |
#list_work_request_logs(compartment_id, work_request_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/integration/list_work_request_logs.rb.html) to see an example of how to use list_work_request_logs API.
Get the logs of a work request.
636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 |
# File 'lib/oci/integration/integration_instance_client.rb', line 636 def list_work_request_logs(compartment_id, work_request_id, opts = {}) logger.debug 'Calling operation IntegrationInstanceClient#list_work_request_logs.' if logger raise "Missing the required parameter 'compartment_id' when calling list_work_request_logs." if compartment_id.nil? raise "Missing the required parameter 'work_request_id' when calling list_work_request_logs." if work_request_id.nil? raise "Parameter value for 'work_request_id' must not be blank" if OCI::Internal::Util.blank_string?(work_request_id) path = '/workRequests/{workRequestId}/logs'.sub('{workRequestId}', work_request_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:compartmentId] = compartment_id query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'IntegrationInstanceClient#list_work_request_logs') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'Array<OCI::Integration::Models::WorkRequestLogEntry>' ) end # rubocop:enable Metrics/BlockLength end |
#list_work_requests(compartment_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/integration/list_work_requests.rb.html) to see an example of how to use list_work_requests API.
Lists the work requests in a compartment.
698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 |
# File 'lib/oci/integration/integration_instance_client.rb', line 698 def list_work_requests(compartment_id, opts = {}) logger.debug 'Calling operation IntegrationInstanceClient#list_work_requests.' if logger raise "Missing the required parameter 'compartment_id' when calling list_work_requests." if compartment_id.nil? path = '/workRequests' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:compartmentId] = compartment_id query_params[:page] = opts[:page] if opts[:page] query_params[:limit] = opts[:limit] if opts[:limit] query_params[:integrationInstanceId] = opts[:integration_instance_id] if opts[:integration_instance_id] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'IntegrationInstanceClient#list_work_requests') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'Array<OCI::Integration::Models::WorkRequestSummary>' ) end # rubocop:enable Metrics/BlockLength end |
#logger ⇒ Logger
Returns The logger for this client. May be nil.
92 93 94 |
# File 'lib/oci/integration/integration_instance_client.rb', line 92 def logger @api_client.config.logger end |
#start_integration_instance(integration_instance_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/integration/start_integration_instance.rb.html) to see an example of how to use start_integration_instance API.
Start an integration instance that was previously in an INACTIVE state
769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 |
# File 'lib/oci/integration/integration_instance_client.rb', line 769 def start_integration_instance(integration_instance_id, opts = {}) logger.debug 'Calling operation IntegrationInstanceClient#start_integration_instance.' if logger raise "Missing the required parameter 'integration_instance_id' when calling start_integration_instance." if integration_instance_id.nil? raise "Parameter value for 'integration_instance_id' must not be blank" if OCI::Internal::Util.blank_string?(integration_instance_id) path = '/integrationInstances/{integrationInstanceId}/actions/start'.sub('{integrationInstanceId}', integration_instance_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'IntegrationInstanceClient#start_integration_instance') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#stop_integration_instance(integration_instance_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/integration/stop_integration_instance.rb.html) to see an example of how to use stop_integration_instance API.
Stop an integration instance that was previously in an ACTIVE state
839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 |
# File 'lib/oci/integration/integration_instance_client.rb', line 839 def stop_integration_instance(integration_instance_id, opts = {}) logger.debug 'Calling operation IntegrationInstanceClient#stop_integration_instance.' if logger raise "Missing the required parameter 'integration_instance_id' when calling stop_integration_instance." if integration_instance_id.nil? raise "Parameter value for 'integration_instance_id' must not be blank" if OCI::Internal::Util.blank_string?(integration_instance_id) path = '/integrationInstances/{integrationInstanceId}/actions/stop'.sub('{integrationInstanceId}', integration_instance_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'IntegrationInstanceClient#stop_integration_instance') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#update_integration_instance(integration_instance_id, update_integration_instance_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/integration/update_integration_instance.rb.html) to see an example of how to use update_integration_instance API.
Updates the Integration Instance.
902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 |
# File 'lib/oci/integration/integration_instance_client.rb', line 902 def update_integration_instance(integration_instance_id, update_integration_instance_details, opts = {}) logger.debug 'Calling operation IntegrationInstanceClient#update_integration_instance.' if logger raise "Missing the required parameter 'integration_instance_id' when calling update_integration_instance." if integration_instance_id.nil? raise "Missing the required parameter 'update_integration_instance_details' when calling update_integration_instance." if update_integration_instance_details.nil? raise "Parameter value for 'integration_instance_id' must not be blank" if OCI::Internal::Util.blank_string?(integration_instance_id) path = '/integrationInstances/{integrationInstanceId}'.sub('{integrationInstanceId}', integration_instance_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(update_integration_instance_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'IntegrationInstanceClient#update_integration_instance') do @api_client.call_api( :PUT, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |