Class: OCI::Integration::Models::IntegrationInstance

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/integration/models/integration_instance.rb

Overview

Description of Integration Instance.

Constant Summary collapse

INTEGRATION_INSTANCE_TYPE_ENUM =
[
  INTEGRATION_INSTANCE_TYPE_STANDARD = 'STANDARD'.freeze,
  INTEGRATION_INSTANCE_TYPE_ENTERPRISE = 'ENTERPRISE'.freeze,
  INTEGRATION_INSTANCE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
CONSUMPTION_MODEL_ENUM =
[
  CONSUMPTION_MODEL_UCM = 'UCM'.freeze,
  CONSUMPTION_MODEL_GOV = 'GOV'.freeze,
  CONSUMPTION_MODEL_OIC4_SAAS = 'OIC4SAAS'.freeze,
  CONSUMPTION_MODEL_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ IntegrationInstance

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
# File 'lib/oci/integration/models/integration_instance.rb', line 195

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.integration_instance_type = attributes[:'integrationInstanceType'] if attributes[:'integrationInstanceType']

  raise 'You cannot provide both :integrationInstanceType and :integration_instance_type' if attributes.key?(:'integrationInstanceType') && attributes.key?(:'integration_instance_type')

  self.integration_instance_type = attributes[:'integration_instance_type'] if attributes[:'integration_instance_type']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.state_message = attributes[:'stateMessage'] if attributes[:'stateMessage']

  raise 'You cannot provide both :stateMessage and :state_message' if attributes.key?(:'stateMessage') && attributes.key?(:'state_message')

  self.state_message = attributes[:'state_message'] if attributes[:'state_message']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.is_byol = attributes[:'isByol'] unless attributes[:'isByol'].nil?

  raise 'You cannot provide both :isByol and :is_byol' if attributes.key?(:'isByol') && attributes.key?(:'is_byol')

  self.is_byol = attributes[:'is_byol'] unless attributes[:'is_byol'].nil?

  self.instance_url = attributes[:'instanceUrl'] if attributes[:'instanceUrl']

  raise 'You cannot provide both :instanceUrl and :instance_url' if attributes.key?(:'instanceUrl') && attributes.key?(:'instance_url')

  self.instance_url = attributes[:'instance_url'] if attributes[:'instance_url']

  self.message_packs = attributes[:'messagePacks'] if attributes[:'messagePacks']

  raise 'You cannot provide both :messagePacks and :message_packs' if attributes.key?(:'messagePacks') && attributes.key?(:'message_packs')

  self.message_packs = attributes[:'message_packs'] if attributes[:'message_packs']

  self.is_file_server_enabled = attributes[:'isFileServerEnabled'] unless attributes[:'isFileServerEnabled'].nil?

  raise 'You cannot provide both :isFileServerEnabled and :is_file_server_enabled' if attributes.key?(:'isFileServerEnabled') && attributes.key?(:'is_file_server_enabled')

  self.is_file_server_enabled = attributes[:'is_file_server_enabled'] unless attributes[:'is_file_server_enabled'].nil?

  self.is_visual_builder_enabled = attributes[:'isVisualBuilderEnabled'] unless attributes[:'isVisualBuilderEnabled'].nil?

  raise 'You cannot provide both :isVisualBuilderEnabled and :is_visual_builder_enabled' if attributes.key?(:'isVisualBuilderEnabled') && attributes.key?(:'is_visual_builder_enabled')

  self.is_visual_builder_enabled = attributes[:'is_visual_builder_enabled'] unless attributes[:'is_visual_builder_enabled'].nil?

  self.custom_endpoint = attributes[:'customEndpoint'] if attributes[:'customEndpoint']

  raise 'You cannot provide both :customEndpoint and :custom_endpoint' if attributes.key?(:'customEndpoint') && attributes.key?(:'custom_endpoint')

  self.custom_endpoint = attributes[:'custom_endpoint'] if attributes[:'custom_endpoint']

  self.alternate_custom_endpoints = attributes[:'alternateCustomEndpoints'] if attributes[:'alternateCustomEndpoints']

  raise 'You cannot provide both :alternateCustomEndpoints and :alternate_custom_endpoints' if attributes.key?(:'alternateCustomEndpoints') && attributes.key?(:'alternate_custom_endpoints')

  self.alternate_custom_endpoints = attributes[:'alternate_custom_endpoints'] if attributes[:'alternate_custom_endpoints']

  self.consumption_model = attributes[:'consumptionModel'] if attributes[:'consumptionModel']

  raise 'You cannot provide both :consumptionModel and :consumption_model' if attributes.key?(:'consumptionModel') && attributes.key?(:'consumption_model')

  self.consumption_model = attributes[:'consumption_model'] if attributes[:'consumption_model']

  self.network_endpoint_details = attributes[:'networkEndpointDetails'] if attributes[:'networkEndpointDetails']

  raise 'You cannot provide both :networkEndpointDetails and :network_endpoint_details' if attributes.key?(:'networkEndpointDetails') && attributes.key?(:'network_endpoint_details')

  self.network_endpoint_details = attributes[:'network_endpoint_details'] if attributes[:'network_endpoint_details']
end

Instance Attribute Details

#alternate_custom_endpointsArray<OCI::Integration::Models::CustomEndpointDetails>

A list of alternate custom endpoints used for the integration instance URL.



107
108
109
# File 'lib/oci/integration/models/integration_instance.rb', line 107

def alternate_custom_endpoints
  @alternate_custom_endpoints
end

#compartment_idString

[Required] Compartment Identifier.

Returns:

  • (String)


45
46
47
# File 'lib/oci/integration/models/integration_instance.rb', line 45

def compartment_id
  @compartment_id
end

#consumption_modelString

The entitlement used for billing purposes.

Returns:

  • (String)


111
112
113
# File 'lib/oci/integration/models/integration_instance.rb', line 111

def consumption_model
  @consumption_model
end

#custom_endpointOCI::Integration::Models::CustomEndpointDetails



102
103
104
# File 'lib/oci/integration/models/integration_instance.rb', line 102

def custom_endpoint
  @custom_endpoint
end

#defined_tagsHash<String, Hash<String, Object>>

Usage of predefined tag keys. These predefined keys are scoped to namespaces. Example: ‘{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


79
80
81
# File 'lib/oci/integration/models/integration_instance.rb', line 79

def defined_tags
  @defined_tags
end

#display_nameString

[Required] Integration Instance Identifier, can be renamed.

Returns:

  • (String)


41
42
43
# File 'lib/oci/integration/models/integration_instance.rb', line 41

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`

Returns:

  • (Hash<String, String>)


72
73
74
# File 'lib/oci/integration/models/integration_instance.rb', line 72

def freeform_tags
  @freeform_tags
end

#idString

[Required] Unique identifier that is immutable on creation.

Returns:

  • (String)


37
38
39
# File 'lib/oci/integration/models/integration_instance.rb', line 37

def id
  @id
end

#instance_urlString

[Required] The Integration Instance URL.

Returns:

  • (String)


87
88
89
# File 'lib/oci/integration/models/integration_instance.rb', line 87

def instance_url
  @instance_url
end

#integration_instance_typeString

[Required] Standard or Enterprise type

Returns:

  • (String)


49
50
51
# File 'lib/oci/integration/models/integration_instance.rb', line 49

def integration_instance_type
  @integration_instance_type
end

#is_byolBOOLEAN

[Required] Bring your own license.

Returns:

  • (BOOLEAN)


83
84
85
# File 'lib/oci/integration/models/integration_instance.rb', line 83

def is_byol
  @is_byol
end

#is_file_server_enabledBOOLEAN

The file server is enabled or not.

Returns:

  • (BOOLEAN)


95
96
97
# File 'lib/oci/integration/models/integration_instance.rb', line 95

def is_file_server_enabled
  @is_file_server_enabled
end

#is_visual_builder_enabledBOOLEAN

VisualBuilder is enabled or not.

Returns:

  • (BOOLEAN)


99
100
101
# File 'lib/oci/integration/models/integration_instance.rb', line 99

def is_visual_builder_enabled
  @is_visual_builder_enabled
end

#lifecycle_stateString

The current state of the integration instance.

Returns:

  • (String)


61
62
63
# File 'lib/oci/integration/models/integration_instance.rb', line 61

def lifecycle_state
  @lifecycle_state
end

#message_packsInteger

[Required] The number of configured message packs (if any)

Returns:

  • (Integer)


91
92
93
# File 'lib/oci/integration/models/integration_instance.rb', line 91

def message_packs
  @message_packs
end

#network_endpoint_detailsOCI::Integration::Models::NetworkEndpointDetails



114
115
116
# File 'lib/oci/integration/models/integration_instance.rb', line 114

def network_endpoint_details
  @network_endpoint_details
end

#state_messageString

An message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.

Returns:

  • (String)


65
66
67
# File 'lib/oci/integration/models/integration_instance.rb', line 65

def state_message
  @state_message
end

#time_createdDateTime

The time the the IntegrationInstance was created. An RFC3339 formatted datetime string.

Returns:

  • (DateTime)


53
54
55
# File 'lib/oci/integration/models/integration_instance.rb', line 53

def time_created
  @time_created
end

#time_updatedDateTime

The time the IntegrationInstance was updated. An RFC3339 formatted datetime string.

Returns:

  • (DateTime)


57
58
59
# File 'lib/oci/integration/models/integration_instance.rb', line 57

def time_updated
  @time_updated
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/oci/integration/models/integration_instance.rb', line 117

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'display_name': :'displayName',
    'compartment_id': :'compartmentId',
    'integration_instance_type': :'integrationInstanceType',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'lifecycle_state': :'lifecycleState',
    'state_message': :'stateMessage',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'is_byol': :'isByol',
    'instance_url': :'instanceUrl',
    'message_packs': :'messagePacks',
    'is_file_server_enabled': :'isFileServerEnabled',
    'is_visual_builder_enabled': :'isVisualBuilderEnabled',
    'custom_endpoint': :'customEndpoint',
    'alternate_custom_endpoints': :'alternateCustomEndpoints',
    'consumption_model': :'consumptionModel',
    'network_endpoint_details': :'networkEndpointDetails'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
# File 'lib/oci/integration/models/integration_instance.rb', line 144

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'display_name': :'String',
    'compartment_id': :'String',
    'integration_instance_type': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'lifecycle_state': :'String',
    'state_message': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'is_byol': :'BOOLEAN',
    'instance_url': :'String',
    'message_packs': :'Integer',
    'is_file_server_enabled': :'BOOLEAN',
    'is_visual_builder_enabled': :'BOOLEAN',
    'custom_endpoint': :'OCI::Integration::Models::CustomEndpointDetails',
    'alternate_custom_endpoints': :'Array<OCI::Integration::Models::CustomEndpointDetails>',
    'consumption_model': :'String',
    'network_endpoint_details': :'OCI::Integration::Models::NetworkEndpointDetails'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
# File 'lib/oci/integration/models/integration_instance.rb', line 358

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    display_name == other.display_name &&
    compartment_id == other.compartment_id &&
    integration_instance_type == other.integration_instance_type &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    lifecycle_state == other.lifecycle_state &&
    state_message == other.state_message &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    is_byol == other.is_byol &&
    instance_url == other.instance_url &&
    message_packs == other.message_packs &&
    is_file_server_enabled == other.is_file_server_enabled &&
    is_visual_builder_enabled == other.is_visual_builder_enabled &&
    custom_endpoint == other.custom_endpoint &&
    alternate_custom_endpoints == other.alternate_custom_endpoints &&
    consumption_model == other.consumption_model &&
    network_endpoint_details == other.network_endpoint_details
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
# File 'lib/oci/integration/models/integration_instance.rb', line 406

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


386
387
388
# File 'lib/oci/integration/models/integration_instance.rb', line 386

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



395
396
397
# File 'lib/oci/integration/models/integration_instance.rb', line 395

def hash
  [id, display_name, compartment_id, integration_instance_type, time_created, time_updated, lifecycle_state, state_message, freeform_tags, defined_tags, is_byol, instance_url, message_packs, is_file_server_enabled, is_visual_builder_enabled, custom_endpoint, alternate_custom_endpoints, consumption_model, network_endpoint_details].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



439
440
441
442
443
444
445
446
447
448
# File 'lib/oci/integration/models/integration_instance.rb', line 439

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



433
434
435
# File 'lib/oci/integration/models/integration_instance.rb', line 433

def to_s
  to_hash.to_s
end