Class: OCI::Integration::Models::PublicEndpointDetails
- Inherits:
-
NetworkEndpointDetails
- Object
- NetworkEndpointDetails
- OCI::Integration::Models::PublicEndpointDetails
- Defined in:
- lib/oci/integration/models/public_endpoint_details.rb
Overview
Public endpoint configuration details.
Constant Summary
Constants inherited from NetworkEndpointDetails
NetworkEndpointDetails::NETWORK_ENDPOINT_TYPE_ENUM
Instance Attribute Summary collapse
-
#allowlisted_http_ips ⇒ Array<String>
Source IP addresses or IP address ranges ingress rules.
-
#allowlisted_http_vcns ⇒ Array<OCI::Integration::Models::VirtualCloudNetwork>
Virtual Cloud Networks allowed to access this network endpoint.
-
#is_integration_vcn_allowlisted ⇒ BOOLEAN
The Integration service's VCN is allow-listed to allow integrations to call back into other integrations.
Attributes inherited from NetworkEndpointDetails
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PublicEndpointDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from NetworkEndpointDetails
Constructor Details
#initialize(attributes = {}) ⇒ PublicEndpointDetails
Initializes the object
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/oci/integration/models/public_endpoint_details.rb', line 59 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['networkEndpointType'] = 'PUBLIC' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.allowlisted_http_ips = attributes[:'allowlistedHttpIps'] if attributes[:'allowlistedHttpIps'] raise 'You cannot provide both :allowlistedHttpIps and :allowlisted_http_ips' if attributes.key?(:'allowlistedHttpIps') && attributes.key?(:'allowlisted_http_ips') self.allowlisted_http_ips = attributes[:'allowlisted_http_ips'] if attributes[:'allowlisted_http_ips'] self.allowlisted_http_vcns = attributes[:'allowlistedHttpVcns'] if attributes[:'allowlistedHttpVcns'] raise 'You cannot provide both :allowlistedHttpVcns and :allowlisted_http_vcns' if attributes.key?(:'allowlistedHttpVcns') && attributes.key?(:'allowlisted_http_vcns') self.allowlisted_http_vcns = attributes[:'allowlisted_http_vcns'] if attributes[:'allowlisted_http_vcns'] self.is_integration_vcn_allowlisted = attributes[:'isIntegrationVcnAllowlisted'] unless attributes[:'isIntegrationVcnAllowlisted'].nil? self.is_integration_vcn_allowlisted = false if is_integration_vcn_allowlisted.nil? && !attributes.key?(:'isIntegrationVcnAllowlisted') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isIntegrationVcnAllowlisted and :is_integration_vcn_allowlisted' if attributes.key?(:'isIntegrationVcnAllowlisted') && attributes.key?(:'is_integration_vcn_allowlisted') self.is_integration_vcn_allowlisted = attributes[:'is_integration_vcn_allowlisted'] unless attributes[:'is_integration_vcn_allowlisted'].nil? self.is_integration_vcn_allowlisted = false if is_integration_vcn_allowlisted.nil? && !attributes.key?(:'isIntegrationVcnAllowlisted') && !attributes.key?(:'is_integration_vcn_allowlisted') # rubocop:disable Style/StringLiterals end |
Instance Attribute Details
#allowlisted_http_ips ⇒ Array<String>
Source IP addresses or IP address ranges ingress rules.
15 16 17 |
# File 'lib/oci/integration/models/public_endpoint_details.rb', line 15 def allowlisted_http_ips @allowlisted_http_ips end |
#allowlisted_http_vcns ⇒ Array<OCI::Integration::Models::VirtualCloudNetwork>
Virtual Cloud Networks allowed to access this network endpoint.
20 21 22 |
# File 'lib/oci/integration/models/public_endpoint_details.rb', line 20 def allowlisted_http_vcns @allowlisted_http_vcns end |
#is_integration_vcn_allowlisted ⇒ BOOLEAN
The Integration service's VCN is allow-listed to allow integrations to call back into other integrations
24 25 26 |
# File 'lib/oci/integration/models/public_endpoint_details.rb', line 24 def is_integration_vcn_allowlisted @is_integration_vcn_allowlisted end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
27 28 29 30 31 32 33 34 35 36 |
# File 'lib/oci/integration/models/public_endpoint_details.rb', line 27 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'network_endpoint_type': :'networkEndpointType', 'allowlisted_http_ips': :'allowlistedHttpIps', 'allowlisted_http_vcns': :'allowlistedHttpVcns', 'is_integration_vcn_allowlisted': :'isIntegrationVcnAllowlisted' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
39 40 41 42 43 44 45 46 47 48 |
# File 'lib/oci/integration/models/public_endpoint_details.rb', line 39 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'network_endpoint_type': :'String', 'allowlisted_http_ips': :'Array<String>', 'allowlisted_http_vcns': :'Array<OCI::Integration::Models::VirtualCloudNetwork>', 'is_integration_vcn_allowlisted': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
97 98 99 100 101 102 103 104 105 |
# File 'lib/oci/integration/models/public_endpoint_details.rb', line 97 def ==(other) return true if equal?(other) self.class == other.class && network_endpoint_type == other.network_endpoint_type && allowlisted_http_ips == other.allowlisted_http_ips && allowlisted_http_vcns == other.allowlisted_http_vcns && is_integration_vcn_allowlisted == other.is_integration_vcn_allowlisted end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/oci/integration/models/public_endpoint_details.rb', line 130 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
110 111 112 |
# File 'lib/oci/integration/models/public_endpoint_details.rb', line 110 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
119 120 121 |
# File 'lib/oci/integration/models/public_endpoint_details.rb', line 119 def hash [network_endpoint_type, allowlisted_http_ips, allowlisted_http_vcns, is_integration_vcn_allowlisted].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
163 164 165 166 167 168 169 170 171 172 |
# File 'lib/oci/integration/models/public_endpoint_details.rb', line 163 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
157 158 159 |
# File 'lib/oci/integration/models/public_endpoint_details.rb', line 157 def to_s to_hash.to_s end |