Class: OCI::Jms::JavaManagementServiceClientCompositeOperations
- Inherits:
-
Object
- Object
- OCI::Jms::JavaManagementServiceClientCompositeOperations
- Defined in:
- lib/oci/jms/java_management_service_client_composite_operations.rb
Overview
This class provides a wrapper around JavaManagementServiceClient and offers convenience methods for operations that would otherwise need to be chained together. For example, instead of performing an action on a resource (e.g. launching an instance, creating a load balancer) and then using a waiter to wait for the resource to enter a given state, you can call a single method in this class to accomplish the same functionality
Instance Attribute Summary collapse
-
#service_client ⇒ OCI::Jms::JavaManagementServiceClient
readonly
The JavaManagementServiceClient used to communicate with the service_client.
Instance Method Summary collapse
-
#change_fleet_compartment_and_wait_for_state(fleet_id, change_fleet_compartment_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Jms::JavaManagementServiceClient#change_fleet_compartment and then waits for the Models::WorkRequest to enter the given state(s).
-
#create_fleet_and_wait_for_state(create_fleet_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Jms::JavaManagementServiceClient#create_fleet and then waits for the Models::WorkRequest to enter the given state(s).
-
#delete_fleet_and_wait_for_state(fleet_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Jms::JavaManagementServiceClient#delete_fleet and then waits for the Models::WorkRequest to enter the given state(s).
-
#initialize(service_client = OCI::Jms::JavaManagementServiceClient.new) ⇒ JavaManagementServiceClientCompositeOperations
constructor
Initializes a new JavaManagementServiceClientCompositeOperations.
-
#update_fleet_agent_configuration_and_wait_for_state(fleet_id, update_fleet_agent_configuration_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Jms::JavaManagementServiceClient#update_fleet_agent_configuration and then waits for the Models::WorkRequest to enter the given state(s).
-
#update_fleet_and_wait_for_state(fleet_id, update_fleet_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Jms::JavaManagementServiceClient#update_fleet and then waits for the Models::WorkRequest to enter the given state(s).
Constructor Details
#initialize(service_client = OCI::Jms::JavaManagementServiceClient.new) ⇒ JavaManagementServiceClientCompositeOperations
Initializes a new JavaManagementServiceClientCompositeOperations
20 21 22 |
# File 'lib/oci/jms/java_management_service_client_composite_operations.rb', line 20 def initialize(service_client = OCI::Jms::JavaManagementServiceClient.new) @service_client = service_client end |
Instance Attribute Details
#service_client ⇒ OCI::Jms::JavaManagementServiceClient (readonly)
The OCI::Jms::JavaManagementServiceClient used to communicate with the service_client
14 15 16 |
# File 'lib/oci/jms/java_management_service_client_composite_operations.rb', line 14 def service_client @service_client end |
Instance Method Details
#change_fleet_compartment_and_wait_for_state(fleet_id, change_fleet_compartment_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Jms::JavaManagementServiceClient#change_fleet_compartment and then waits for the Models::WorkRequest to enter the given state(s).
40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/oci/jms/java_management_service_client_composite_operations.rb', line 40 def change_fleet_compartment_and_wait_for_state(fleet_id, change_fleet_compartment_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) operation_result = @service_client.change_fleet_compartment(fleet_id, change_fleet_compartment_details, base_operation_opts) use_util = OCI::Jms::Util.respond_to?(:wait_on_work_request) return operation_result if wait_for_states.empty? && !use_util lowered_wait_for_states = wait_for_states.map(&:downcase) wait_for_resource_id = operation_result.headers['opc-work-request-id'] begin if use_util waiter_result = OCI::Jms::Util.wait_on_work_request( @service_client, wait_for_resource_id, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) else waiter_result = @service_client.get_work_request(wait_for_resource_id).wait_until( eval_proc: ->(response) { response.data.respond_to?(:status) && lowered_wait_for_states.include?(response.data.status.downcase) }, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) end result_to_return = waiter_result return result_to_return rescue StandardError raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result]) end end |
#create_fleet_and_wait_for_state(create_fleet_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Jms::JavaManagementServiceClient#create_fleet and then waits for the Models::WorkRequest to enter the given state(s).
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/oci/jms/java_management_service_client_composite_operations.rb', line 89 def create_fleet_and_wait_for_state(create_fleet_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) operation_result = @service_client.create_fleet(create_fleet_details, base_operation_opts) use_util = OCI::Jms::Util.respond_to?(:wait_on_work_request) return operation_result if wait_for_states.empty? && !use_util lowered_wait_for_states = wait_for_states.map(&:downcase) wait_for_resource_id = operation_result.headers['opc-work-request-id'] begin if use_util waiter_result = OCI::Jms::Util.wait_on_work_request( @service_client, wait_for_resource_id, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) else waiter_result = @service_client.get_work_request(wait_for_resource_id).wait_until( eval_proc: ->(response) { response.data.respond_to?(:status) && lowered_wait_for_states.include?(response.data.status.downcase) }, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) end result_to_return = waiter_result return result_to_return rescue StandardError raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result]) end end |
#delete_fleet_and_wait_for_state(fleet_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Jms::JavaManagementServiceClient#delete_fleet and then waits for the Models::WorkRequest to enter the given state(s).
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/oci/jms/java_management_service_client_composite_operations.rb', line 138 def delete_fleet_and_wait_for_state(fleet_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) operation_result = @service_client.delete_fleet(fleet_id, base_operation_opts) use_util = OCI::Jms::Util.respond_to?(:wait_on_work_request) return operation_result if wait_for_states.empty? && !use_util lowered_wait_for_states = wait_for_states.map(&:downcase) wait_for_resource_id = operation_result.headers['opc-work-request-id'] begin if use_util waiter_result = OCI::Jms::Util.wait_on_work_request( @service_client, wait_for_resource_id, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) else waiter_result = @service_client.get_work_request(wait_for_resource_id).wait_until( eval_proc: ->(response) { response.data.respond_to?(:status) && lowered_wait_for_states.include?(response.data.status.downcase) }, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) end result_to_return = waiter_result return result_to_return rescue StandardError raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result]) end end |
#update_fleet_agent_configuration_and_wait_for_state(fleet_id, update_fleet_agent_configuration_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Jms::JavaManagementServiceClient#update_fleet_agent_configuration and then waits for the Models::WorkRequest to enter the given state(s).
238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 |
# File 'lib/oci/jms/java_management_service_client_composite_operations.rb', line 238 def update_fleet_agent_configuration_and_wait_for_state(fleet_id, update_fleet_agent_configuration_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) operation_result = @service_client.update_fleet_agent_configuration(fleet_id, update_fleet_agent_configuration_details, base_operation_opts) use_util = OCI::Jms::Util.respond_to?(:wait_on_work_request) return operation_result if wait_for_states.empty? && !use_util lowered_wait_for_states = wait_for_states.map(&:downcase) wait_for_resource_id = operation_result.headers['opc-work-request-id'] begin if use_util waiter_result = OCI::Jms::Util.wait_on_work_request( @service_client, wait_for_resource_id, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) else waiter_result = @service_client.get_work_request(wait_for_resource_id).wait_until( eval_proc: ->(response) { response.data.respond_to?(:status) && lowered_wait_for_states.include?(response.data.status.downcase) }, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) end result_to_return = waiter_result return result_to_return rescue StandardError raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result]) end end |
#update_fleet_and_wait_for_state(fleet_id, update_fleet_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Jms::JavaManagementServiceClient#update_fleet and then waits for the Models::WorkRequest to enter the given state(s).
188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/oci/jms/java_management_service_client_composite_operations.rb', line 188 def update_fleet_and_wait_for_state(fleet_id, update_fleet_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) operation_result = @service_client.update_fleet(fleet_id, update_fleet_details, base_operation_opts) use_util = OCI::Jms::Util.respond_to?(:wait_on_work_request) return operation_result if wait_for_states.empty? && !use_util lowered_wait_for_states = wait_for_states.map(&:downcase) wait_for_resource_id = operation_result.headers['opc-work-request-id'] begin if use_util waiter_result = OCI::Jms::Util.wait_on_work_request( @service_client, wait_for_resource_id, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) else waiter_result = @service_client.get_work_request(wait_for_resource_id).wait_until( eval_proc: ->(response) { response.data.respond_to?(:status) && lowered_wait_for_states.include?(response.data.status.downcase) }, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) end result_to_return = waiter_result return result_to_return rescue StandardError raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result]) end end |