Class: OCI::Jms::Models::CreateBlocklistDetails
- Inherits:
-
Object
- Object
- OCI::Jms::Models::CreateBlocklistDetails
- Defined in:
- lib/oci/jms/models/create_blocklist_details.rb
Overview
The blocklist record details.
Constant Summary collapse
- OPERATION_ENUM =
[ OPERATION_CREATE_FLEET = 'CREATE_FLEET'.freeze, OPERATION_DELETE_FLEET = 'DELETE_FLEET'.freeze, OPERATION_MOVE_FLEET = 'MOVE_FLEET'.freeze, OPERATION_UPDATE_FLEET = 'UPDATE_FLEET'.freeze, OPERATION_UPDATE_FLEET_AGENT_CONFIGURATION = 'UPDATE_FLEET_AGENT_CONFIGURATION'.freeze, OPERATION_DELETE_JAVA_INSTALLATION = 'DELETE_JAVA_INSTALLATION'.freeze ].freeze
Instance Attribute Summary collapse
-
#operation ⇒ String
**[Required]** The operation type.
-
#reason ⇒ String
The reason for why the operation is blocklisted.
-
#target ⇒ OCI::Jms::Models::BlocklistTarget
This attribute is required.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateBlocklistDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateBlocklistDetails
Initializes the object
62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/oci/jms/models/create_blocklist_details.rb', line 62 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.target = attributes[:'target'] if attributes[:'target'] self.operation = attributes[:'operation'] if attributes[:'operation'] self.reason = attributes[:'reason'] if attributes[:'reason'] end |
Instance Attribute Details
#operation ⇒ String
**[Required]** The operation type
25 26 27 |
# File 'lib/oci/jms/models/create_blocklist_details.rb', line 25 def operation @operation end |
#reason ⇒ String
The reason for why the operation is blocklisted
29 30 31 |
# File 'lib/oci/jms/models/create_blocklist_details.rb', line 29 def reason @reason end |
#target ⇒ OCI::Jms::Models::BlocklistTarget
This attribute is required.
21 22 23 |
# File 'lib/oci/jms/models/create_blocklist_details.rb', line 21 def target @target end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 40 |
# File 'lib/oci/jms/models/create_blocklist_details.rb', line 32 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'target': :'target', 'operation': :'operation', 'reason': :'reason' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
43 44 45 46 47 48 49 50 51 |
# File 'lib/oci/jms/models/create_blocklist_details.rb', line 43 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'target': :'OCI::Jms::Models::BlocklistTarget', 'operation': :'String', 'reason': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
90 91 92 93 94 95 96 97 |
# File 'lib/oci/jms/models/create_blocklist_details.rb', line 90 def ==(other) return true if equal?(other) self.class == other.class && target == other.target && operation == other.operation && reason == other.reason end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/oci/jms/models/create_blocklist_details.rb', line 122 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
102 103 104 |
# File 'lib/oci/jms/models/create_blocklist_details.rb', line 102 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
111 112 113 |
# File 'lib/oci/jms/models/create_blocklist_details.rb', line 111 def hash [target, operation, reason].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
155 156 157 158 159 160 161 162 163 164 |
# File 'lib/oci/jms/models/create_blocklist_details.rb', line 155 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
149 150 151 |
# File 'lib/oci/jms/models/create_blocklist_details.rb', line 149 def to_s to_hash.to_s end |