Class: OCI::Jms::Models::CreateFleetDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/jms/models/create_fleet_details.rb

Overview

Attributes to create a Fleet.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateFleetDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/oci/jms/models/create_fleet_details.rb', line 83

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.description = attributes[:'description'] if attributes[:'description']

  self.inventory_log = attributes[:'inventoryLog'] if attributes[:'inventoryLog']

  raise 'You cannot provide both :inventoryLog and :inventory_log' if attributes.key?(:'inventoryLog') && attributes.key?(:'inventory_log')

  self.inventory_log = attributes[:'inventory_log'] if attributes[:'inventory_log']

  self.operation_log = attributes[:'operationLog'] if attributes[:'operationLog']

  raise 'You cannot provide both :operationLog and :operation_log' if attributes.key?(:'operationLog') && attributes.key?(:'operation_log')

  self.operation_log = attributes[:'operation_log'] if attributes[:'operation_log']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']
end

Instance Attribute Details

#compartment_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment of the Fleet.

Returns:

  • (String)


16
17
18
# File 'lib/oci/jms/models/create_fleet_details.rb', line 16

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`. (See [Understanding Free-form Tags](docs.cloud.oracle.com/Content/Tagging/Tasks/managingtagsandtagnamespaces.htm)).

Returns:

  • (Hash<String, Hash<String, Object>>)


32
33
34
# File 'lib/oci/jms/models/create_fleet_details.rb', line 32

def defined_tags
  @defined_tags
end

#descriptionString

The Fleet's description. If nothing is provided, the Fleet description will be null.

Returns:

  • (String)


20
21
22
# File 'lib/oci/jms/models/create_fleet_details.rb', line 20

def description
  @description
end

#display_nameString

**[Required]** The name of the Fleet. The displayName must be unique for Fleets in the same compartment.

Returns:

  • (String)


12
13
14
# File 'lib/oci/jms/models/create_fleet_details.rb', line 12

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`. (See [Managing Tags and Tag Namespaces](docs.cloud.oracle.com/Content/Tagging/Concepts/understandingfreeformtags.htm).)

Returns:

  • (Hash<String, String>)


38
39
40
# File 'lib/oci/jms/models/create_fleet_details.rb', line 38

def freeform_tags
  @freeform_tags
end

#inventory_logOCI::Jms::Models::CustomLog



23
24
25
# File 'lib/oci/jms/models/create_fleet_details.rb', line 23

def inventory_log
  @inventory_log
end

#operation_logOCI::Jms::Models::CustomLog



26
27
28
# File 'lib/oci/jms/models/create_fleet_details.rb', line 26

def operation_log
  @operation_log
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



41
42
43
44
45
46
47
48
49
50
51
52
53
# File 'lib/oci/jms/models/create_fleet_details.rb', line 41

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'displayName',
    'compartment_id': :'compartmentId',
    'description': :'description',
    'inventory_log': :'inventoryLog',
    'operation_log': :'operationLog',
    'defined_tags': :'definedTags',
    'freeform_tags': :'freeformTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/oci/jms/models/create_fleet_details.rb', line 56

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'String',
    'compartment_id': :'String',
    'description': :'String',
    'inventory_log': :'OCI::Jms::Models::CustomLog',
    'operation_log': :'OCI::Jms::Models::CustomLog',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'freeform_tags': :'Hash<String, String>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/oci/jms/models/create_fleet_details.rb', line 135

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    display_name == other.display_name &&
    compartment_id == other.compartment_id &&
    description == other.description &&
    inventory_log == other.inventory_log &&
    operation_log == other.operation_log &&
    defined_tags == other.defined_tags &&
    freeform_tags == other.freeform_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/oci/jms/models/create_fleet_details.rb', line 171

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


151
152
153
# File 'lib/oci/jms/models/create_fleet_details.rb', line 151

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



160
161
162
# File 'lib/oci/jms/models/create_fleet_details.rb', line 160

def hash
  [display_name, compartment_id, description, inventory_log, operation_log, defined_tags, freeform_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



204
205
206
207
208
209
210
211
212
213
# File 'lib/oci/jms/models/create_fleet_details.rb', line 204

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



198
199
200
# File 'lib/oci/jms/models/create_fleet_details.rb', line 198

def to_s
  to_hash.to_s
end