Class: OCI::Jms::Models::FleetAgentConfiguration

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/jms/models/fleet_agent_configuration.rb

Overview

Management Agent Configuration for a Fleet. Includes JRE scanning frequency and list of include/exclude file system paths.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ FleetAgentConfiguration

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/oci/jms/models/fleet_agent_configuration.rb', line 71

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.jre_scan_frequency_in_minutes = attributes[:'jreScanFrequencyInMinutes'] if attributes[:'jreScanFrequencyInMinutes']

  raise 'You cannot provide both :jreScanFrequencyInMinutes and :jre_scan_frequency_in_minutes' if attributes.key?(:'jreScanFrequencyInMinutes') && attributes.key?(:'jre_scan_frequency_in_minutes')

  self.jre_scan_frequency_in_minutes = attributes[:'jre_scan_frequency_in_minutes'] if attributes[:'jre_scan_frequency_in_minutes']

  self.java_usage_tracker_processing_frequency_in_minutes = attributes[:'javaUsageTrackerProcessingFrequencyInMinutes'] if attributes[:'javaUsageTrackerProcessingFrequencyInMinutes']

  raise 'You cannot provide both :javaUsageTrackerProcessingFrequencyInMinutes and :java_usage_tracker_processing_frequency_in_minutes' if attributes.key?(:'javaUsageTrackerProcessingFrequencyInMinutes') && attributes.key?(:'java_usage_tracker_processing_frequency_in_minutes')

  self.java_usage_tracker_processing_frequency_in_minutes = attributes[:'java_usage_tracker_processing_frequency_in_minutes'] if attributes[:'java_usage_tracker_processing_frequency_in_minutes']

  self.linux_configuration = attributes[:'linuxConfiguration'] if attributes[:'linuxConfiguration']

  raise 'You cannot provide both :linuxConfiguration and :linux_configuration' if attributes.key?(:'linuxConfiguration') && attributes.key?(:'linux_configuration')

  self.linux_configuration = attributes[:'linux_configuration'] if attributes[:'linux_configuration']

  self.windows_configuration = attributes[:'windowsConfiguration'] if attributes[:'windowsConfiguration']

  raise 'You cannot provide both :windowsConfiguration and :windows_configuration' if attributes.key?(:'windowsConfiguration') && attributes.key?(:'windows_configuration')

  self.windows_configuration = attributes[:'windows_configuration'] if attributes[:'windows_configuration']

  self.time_last_modified = attributes[:'timeLastModified'] if attributes[:'timeLastModified']

  raise 'You cannot provide both :timeLastModified and :time_last_modified' if attributes.key?(:'timeLastModified') && attributes.key?(:'time_last_modified')

  self.time_last_modified = attributes[:'time_last_modified'] if attributes[:'time_last_modified']
end

Instance Attribute Details

#java_usage_tracker_processing_frequency_in_minutesInteger

[Required] The frequency (in minutes) of Java Usage Tracker processing. (That is, how often should JMS process data from the Java Usage Tracker.)

Returns:

  • (Integer)


19
20
21
# File 'lib/oci/jms/models/fleet_agent_configuration.rb', line 19

def java_usage_tracker_processing_frequency_in_minutes
  @java_usage_tracker_processing_frequency_in_minutes
end

#jre_scan_frequency_in_minutesInteger

[Required] The frequency (in minutes) of JRE scanning. (That is, how often should JMS scan for JRE installations.)

Returns:

  • (Integer)


14
15
16
# File 'lib/oci/jms/models/fleet_agent_configuration.rb', line 14

def jre_scan_frequency_in_minutes
  @jre_scan_frequency_in_minutes
end

#linux_configurationOCI::Jms::Models::FleetAgentOsConfiguration

This attribute is required.



23
24
25
# File 'lib/oci/jms/models/fleet_agent_configuration.rb', line 23

def linux_configuration
  @linux_configuration
end

#time_last_modifiedDateTime

[Required] The date and time of the last modification to the Fleet Agent Configuration (formatted according to [RFC3339](datatracker.ietf.org/doc/html/rfc3339)).

Returns:

  • (DateTime)


32
33
34
# File 'lib/oci/jms/models/fleet_agent_configuration.rb', line 32

def time_last_modified
  @time_last_modified
end

#windows_configurationOCI::Jms::Models::FleetAgentOsConfiguration

This attribute is required.



27
28
29
# File 'lib/oci/jms/models/fleet_agent_configuration.rb', line 27

def windows_configuration
  @windows_configuration
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
44
45
# File 'lib/oci/jms/models/fleet_agent_configuration.rb', line 35

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'jre_scan_frequency_in_minutes': :'jreScanFrequencyInMinutes',
    'java_usage_tracker_processing_frequency_in_minutes': :'javaUsageTrackerProcessingFrequencyInMinutes',
    'linux_configuration': :'linuxConfiguration',
    'windows_configuration': :'windowsConfiguration',
    'time_last_modified': :'timeLastModified'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



48
49
50
51
52
53
54
55
56
57
58
# File 'lib/oci/jms/models/fleet_agent_configuration.rb', line 48

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'jre_scan_frequency_in_minutes': :'Integer',
    'java_usage_tracker_processing_frequency_in_minutes': :'Integer',
    'linux_configuration': :'OCI::Jms::Models::FleetAgentOsConfiguration',
    'windows_configuration': :'OCI::Jms::Models::FleetAgentOsConfiguration',
    'time_last_modified': :'DateTime'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



115
116
117
118
119
120
121
122
123
124
# File 'lib/oci/jms/models/fleet_agent_configuration.rb', line 115

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    jre_scan_frequency_in_minutes == other.jre_scan_frequency_in_minutes &&
    java_usage_tracker_processing_frequency_in_minutes == other.java_usage_tracker_processing_frequency_in_minutes &&
    linux_configuration == other.linux_configuration &&
    windows_configuration == other.windows_configuration &&
    time_last_modified == other.time_last_modified
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/oci/jms/models/fleet_agent_configuration.rb', line 149

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


129
130
131
# File 'lib/oci/jms/models/fleet_agent_configuration.rb', line 129

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



138
139
140
# File 'lib/oci/jms/models/fleet_agent_configuration.rb', line 138

def hash
  [jre_scan_frequency_in_minutes, java_usage_tracker_processing_frequency_in_minutes, linux_configuration, windows_configuration, time_last_modified].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



182
183
184
185
186
187
188
189
190
191
# File 'lib/oci/jms/models/fleet_agent_configuration.rb', line 182

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



176
177
178
# File 'lib/oci/jms/models/fleet_agent_configuration.rb', line 176

def to_s
  to_hash.to_s
end