Class: OCI::Jms::Models::OperatingSystem

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/jms/models/operating_system.rb

Overview

Operating System of the platform on which the Java Runtime was reported.

Constant Summary collapse

FAMILY_ENUM =
[
  FAMILY_LINUX = 'LINUX'.freeze,
  FAMILY_WINDOWS = 'WINDOWS'.freeze,
  FAMILY_MACOS = 'MACOS'.freeze,
  FAMILY_UNKNOWN = 'UNKNOWN'.freeze,
  FAMILY_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ OperatingSystem

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :family (String)

    The value to assign to the #family property

  • :name (String)

    The value to assign to the #name property

  • :version (String)

    The value to assign to the #version property

  • :architecture (String)

    The value to assign to the #architecture property



70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/oci/jms/models/operating_system.rb', line 70

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.family = attributes[:'family'] if attributes[:'family']

  self.name = attributes[:'name'] if attributes[:'name']

  self.version = attributes[:'version'] if attributes[:'version']

  self.architecture = attributes[:'architecture'] if attributes[:'architecture']
end

Instance Attribute Details

#architectureString

[Required] The architecture of the operating system as provided by the Java system property os.arch.

Returns:



34
35
36
# File 'lib/oci/jms/models/operating_system.rb', line 34

def architecture
  @architecture
end

#familyString

[Required] The operating system type, such as Windows or Linux

Returns:



22
23
24
# File 'lib/oci/jms/models/operating_system.rb', line 22

def family
  @family
end

#nameString

[Required] The name of the operating system as provided by the Java system property os.name.

Returns:



26
27
28
# File 'lib/oci/jms/models/operating_system.rb', line 26

def name
  @name
end

#versionString

[Required] The version of the operating system as provided by the Java system property os.version.

Returns:



30
31
32
# File 'lib/oci/jms/models/operating_system.rb', line 30

def version
  @version
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
# File 'lib/oci/jms/models/operating_system.rb', line 37

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'family': :'family',
    'name': :'name',
    'version': :'version',
    'architecture': :'architecture'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



49
50
51
52
53
54
55
56
57
58
# File 'lib/oci/jms/models/operating_system.rb', line 49

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'family': :'String',
    'name': :'String',
    'version': :'String',
    'architecture': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • the other object to be compared



105
106
107
108
109
110
111
112
113
# File 'lib/oci/jms/models/operating_system.rb', line 105

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    family == other.family &&
    name == other.name &&
    version == other.version &&
    architecture == other.architecture
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/oci/jms/models/operating_system.rb', line 138

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • the other object to be compared

Returns:

See Also:

  • `==` method


118
119
120
# File 'lib/oci/jms/models/operating_system.rb', line 118

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • Hash code



127
128
129
# File 'lib/oci/jms/models/operating_system.rb', line 127

def hash
  [family, name, version, architecture].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



171
172
173
174
175
176
177
178
179
180
# File 'lib/oci/jms/models/operating_system.rb', line 171

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



165
166
167
# File 'lib/oci/jms/models/operating_system.rb', line 165

def to_s
  to_hash.to_s
end