Class: OCI::Jms::Models::RequestSummarizedApplicationUsageDetails
- Inherits:
-
Object
- Object
- OCI::Jms::Models::RequestSummarizedApplicationUsageDetails
- Defined in:
- lib/oci/jms/models/request_summarized_application_usage_details.rb
Overview
Parameters for filtering applications.
Constant Summary collapse
- SORT_ORDER_ENUM =
[ SORT_ORDER_ASC = 'ASC'.freeze, SORT_ORDER_DESC = 'DESC'.freeze ].freeze
- SORT_BY_ENUM =
[ SORT_BY_TIME_FIRST_SEEN = 'timeFirstSeen'.freeze, SORT_BY_TIME_LAST_SEEN = 'timeLastSeen'.freeze, SORT_BY_DISPLAY_NAME = 'displayName'.freeze, SORT_BY_APPROXIMATE_JRE_COUNT = 'approximateJreCount'.freeze, SORT_BY_APPROXIMATE_INSTALLATION_COUNT = 'approximateInstallationCount'.freeze, SORT_BY_APPROXIMATE_MANAGED_INSTANCE_COUNT = 'approximateManagedInstanceCount'.freeze ].freeze
Instance Attribute Summary collapse
-
#application_id ⇒ String
The ID of the application.
-
#application_type ⇒ String
The way the application was started.
-
#display_name ⇒ String
The display name of the application.
-
#fields ⇒ Array<OCI::Jms::Models::SummarizeApplicationUsageFields>
Additional fields to include into the returned model on top of the required ones.
-
#installation_path ⇒ String
The installation path of the related installation.
-
#jre_distribution ⇒ String
The distribution of the related Java Runtime.
-
#jre_vendor ⇒ String
The vendor of the related Java Runtime.
-
#jre_version ⇒ String
The version of the related Java Runtime.
-
#managed_instance_id ⇒ String
The ID of the related managed instance.
-
#sort_by ⇒ String
The field to sort application views.
-
#sort_order ⇒ String
The sort order to use, either ‘asc’ or ‘desc’.
-
#time_end ⇒ DateTime
The end of the time period during which resources are searched (formatted according to RFC3339).
-
#time_start ⇒ DateTime
The start of the time period during which resources are searched (formatted according to RFC3339).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RequestSummarizedApplicationUsageDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ RequestSummarizedApplicationUsageDetails
Initializes the object
147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/oci/jms/models/request_summarized_application_usage_details.rb', line 147 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.time_start = attributes[:'timeStart'] if attributes[:'timeStart'] raise 'You cannot provide both :timeStart and :time_start' if attributes.key?(:'timeStart') && attributes.key?(:'time_start') self.time_start = attributes[:'time_start'] if attributes[:'time_start'] self.time_end = attributes[:'timeEnd'] if attributes[:'timeEnd'] raise 'You cannot provide both :timeEnd and :time_end' if attributes.key?(:'timeEnd') && attributes.key?(:'time_end') self.time_end = attributes[:'time_end'] if attributes[:'time_end'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.installation_path = attributes[:'installationPath'] if attributes[:'installationPath'] raise 'You cannot provide both :installationPath and :installation_path' if attributes.key?(:'installationPath') && attributes.key?(:'installation_path') self.installation_path = attributes[:'installation_path'] if attributes[:'installation_path'] self.jre_vendor = attributes[:'jreVendor'] if attributes[:'jreVendor'] raise 'You cannot provide both :jreVendor and :jre_vendor' if attributes.key?(:'jreVendor') && attributes.key?(:'jre_vendor') self.jre_vendor = attributes[:'jre_vendor'] if attributes[:'jre_vendor'] self.jre_distribution = attributes[:'jreDistribution'] if attributes[:'jreDistribution'] raise 'You cannot provide both :jreDistribution and :jre_distribution' if attributes.key?(:'jreDistribution') && attributes.key?(:'jre_distribution') self.jre_distribution = attributes[:'jre_distribution'] if attributes[:'jre_distribution'] self.jre_version = attributes[:'jreVersion'] if attributes[:'jreVersion'] raise 'You cannot provide both :jreVersion and :jre_version' if attributes.key?(:'jreVersion') && attributes.key?(:'jre_version') self.jre_version = attributes[:'jre_version'] if attributes[:'jre_version'] self.application_id = attributes[:'applicationId'] if attributes[:'applicationId'] raise 'You cannot provide both :applicationId and :application_id' if attributes.key?(:'applicationId') && attributes.key?(:'application_id') self.application_id = attributes[:'application_id'] if attributes[:'application_id'] self.application_type = attributes[:'applicationType'] if attributes[:'applicationType'] raise 'You cannot provide both :applicationType and :application_type' if attributes.key?(:'applicationType') && attributes.key?(:'application_type') self.application_type = attributes[:'application_type'] if attributes[:'application_type'] self.managed_instance_id = attributes[:'managedInstanceId'] if attributes[:'managedInstanceId'] raise 'You cannot provide both :managedInstanceId and :managed_instance_id' if attributes.key?(:'managedInstanceId') && attributes.key?(:'managed_instance_id') self.managed_instance_id = attributes[:'managed_instance_id'] if attributes[:'managed_instance_id'] self.sort_order = attributes[:'sortOrder'] if attributes[:'sortOrder'] self.sort_order = "ASC" if sort_order.nil? && !attributes.key?(:'sortOrder') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :sortOrder and :sort_order' if attributes.key?(:'sortOrder') && attributes.key?(:'sort_order') self.sort_order = attributes[:'sort_order'] if attributes[:'sort_order'] self.sort_order = "ASC" if sort_order.nil? && !attributes.key?(:'sortOrder') && !attributes.key?(:'sort_order') # rubocop:disable Style/StringLiterals self.sort_by = attributes[:'sortBy'] if attributes[:'sortBy'] self.sort_by = "timeLastSeen" if sort_by.nil? && !attributes.key?(:'sortBy') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :sortBy and :sort_by' if attributes.key?(:'sortBy') && attributes.key?(:'sort_by') self.sort_by = attributes[:'sort_by'] if attributes[:'sort_by'] self.sort_by = "timeLastSeen" if sort_by.nil? && !attributes.key?(:'sortBy') && !attributes.key?(:'sort_by') # rubocop:disable Style/StringLiterals self.fields = attributes[:'fields'] if attributes[:'fields'] end |
Instance Attribute Details
#application_id ⇒ String
The ID of the application.
56 57 58 |
# File 'lib/oci/jms/models/request_summarized_application_usage_details.rb', line 56 def application_id @application_id end |
#application_type ⇒ String
The way the application was started.
60 61 62 |
# File 'lib/oci/jms/models/request_summarized_application_usage_details.rb', line 60 def application_type @application_type end |
#display_name ⇒ String
The display name of the application.
36 37 38 |
# File 'lib/oci/jms/models/request_summarized_application_usage_details.rb', line 36 def display_name @display_name end |
#fields ⇒ Array<OCI::Jms::Models::SummarizeApplicationUsageFields>
Additional fields to include into the returned model on top of the required ones. This parameter can also include ‘approximateJreCount’, ‘approximateInstallationCount’ and ‘approximateManagedInstanceCount’. For example ‘approximateJreCount,approximateInstallationCount’.
84 85 86 |
# File 'lib/oci/jms/models/request_summarized_application_usage_details.rb', line 84 def fields @fields end |
#installation_path ⇒ String
The installation path of the related installation.
40 41 42 |
# File 'lib/oci/jms/models/request_summarized_application_usage_details.rb', line 40 def installation_path @installation_path end |
#jre_distribution ⇒ String
The distribution of the related Java Runtime.
48 49 50 |
# File 'lib/oci/jms/models/request_summarized_application_usage_details.rb', line 48 def jre_distribution @jre_distribution end |
#jre_vendor ⇒ String
The vendor of the related Java Runtime.
44 45 46 |
# File 'lib/oci/jms/models/request_summarized_application_usage_details.rb', line 44 def jre_vendor @jre_vendor end |
#jre_version ⇒ String
The version of the related Java Runtime.
52 53 54 |
# File 'lib/oci/jms/models/request_summarized_application_usage_details.rb', line 52 def jre_version @jre_version end |
#managed_instance_id ⇒ String
The ID of the related managed instance.
64 65 66 |
# File 'lib/oci/jms/models/request_summarized_application_usage_details.rb', line 64 def managed_instance_id @managed_instance_id end |
#sort_by ⇒ String
The field to sort application views. Only one sort order may be provided. Default order for timeFirstSeen, timeLastSeen, approximateJreCount, approximateInstallationCount and approximateManagedInstanceCount is descending. Default order for displayName is ascending. If no value is specified timeLastSeen is default.
77 78 79 |
# File 'lib/oci/jms/models/request_summarized_application_usage_details.rb', line 77 def sort_by @sort_by end |
#sort_order ⇒ String
The sort order to use, either ‘asc’ or ‘desc’.
68 69 70 |
# File 'lib/oci/jms/models/request_summarized_application_usage_details.rb', line 68 def sort_order @sort_order end |
#time_end ⇒ DateTime
The end of the time period during which resources are searched (formatted according to RFC3339). Defaults to current time.
32 33 34 |
# File 'lib/oci/jms/models/request_summarized_application_usage_details.rb', line 32 def time_end @time_end end |
#time_start ⇒ DateTime
The start of the time period during which resources are searched (formatted according to RFC3339). Defaults to current time minus seven days.
27 28 29 |
# File 'lib/oci/jms/models/request_summarized_application_usage_details.rb', line 27 def time_start @time_start end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/oci/jms/models/request_summarized_application_usage_details.rb', line 87 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'time_start': :'timeStart', 'time_end': :'timeEnd', 'display_name': :'displayName', 'installation_path': :'installationPath', 'jre_vendor': :'jreVendor', 'jre_distribution': :'jreDistribution', 'jre_version': :'jreVersion', 'application_id': :'applicationId', 'application_type': :'applicationType', 'managed_instance_id': :'managedInstanceId', 'sort_order': :'sortOrder', 'sort_by': :'sortBy', 'fields': :'fields' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/oci/jms/models/request_summarized_application_usage_details.rb', line 108 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'time_start': :'DateTime', 'time_end': :'DateTime', 'display_name': :'String', 'installation_path': :'String', 'jre_vendor': :'String', 'jre_distribution': :'String', 'jre_version': :'String', 'application_id': :'String', 'application_type': :'String', 'managed_instance_id': :'String', 'sort_order': :'String', 'sort_by': :'String', 'fields': :'Array<OCI::Jms::Models::SummarizeApplicationUsageFields>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 |
# File 'lib/oci/jms/models/request_summarized_application_usage_details.rb', line 255 def ==(other) return true if equal?(other) self.class == other.class && time_start == other.time_start && time_end == other.time_end && display_name == other.display_name && installation_path == other.installation_path && jre_vendor == other.jre_vendor && jre_distribution == other.jre_distribution && jre_version == other.jre_version && application_id == other.application_id && application_type == other.application_type && managed_instance_id == other.managed_instance_id && sort_order == other.sort_order && sort_by == other.sort_by && fields == other.fields end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 |
# File 'lib/oci/jms/models/request_summarized_application_usage_details.rb', line 297 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
277 278 279 |
# File 'lib/oci/jms/models/request_summarized_application_usage_details.rb', line 277 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
286 287 288 |
# File 'lib/oci/jms/models/request_summarized_application_usage_details.rb', line 286 def hash [time_start, time_end, display_name, installation_path, jre_vendor, jre_distribution, jre_version, application_id, application_type, managed_instance_id, sort_order, sort_by, fields].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
330 331 332 333 334 335 336 337 338 339 |
# File 'lib/oci/jms/models/request_summarized_application_usage_details.rb', line 330 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
324 325 326 |
# File 'lib/oci/jms/models/request_summarized_application_usage_details.rb', line 324 def to_s to_hash.to_s end |