Class: OCI::Jms::Models::UpdateFleetAgentConfigurationDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/jms/models/update_fleet_agent_configuration_details.rb

Overview

Attributes to update a Fleet Agent Configuration.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateFleetAgentConfigurationDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/oci/jms/models/update_fleet_agent_configuration_details.rb', line 60

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.jre_scan_frequency_in_minutes = attributes[:'jreScanFrequencyInMinutes'] if attributes[:'jreScanFrequencyInMinutes']

  raise 'You cannot provide both :jreScanFrequencyInMinutes and :jre_scan_frequency_in_minutes' if attributes.key?(:'jreScanFrequencyInMinutes') && attributes.key?(:'jre_scan_frequency_in_minutes')

  self.jre_scan_frequency_in_minutes = attributes[:'jre_scan_frequency_in_minutes'] if attributes[:'jre_scan_frequency_in_minutes']

  self.java_usage_tracker_processing_frequency_in_minutes = attributes[:'javaUsageTrackerProcessingFrequencyInMinutes'] if attributes[:'javaUsageTrackerProcessingFrequencyInMinutes']

  raise 'You cannot provide both :javaUsageTrackerProcessingFrequencyInMinutes and :java_usage_tracker_processing_frequency_in_minutes' if attributes.key?(:'javaUsageTrackerProcessingFrequencyInMinutes') && attributes.key?(:'java_usage_tracker_processing_frequency_in_minutes')

  self.java_usage_tracker_processing_frequency_in_minutes = attributes[:'java_usage_tracker_processing_frequency_in_minutes'] if attributes[:'java_usage_tracker_processing_frequency_in_minutes']

  self.linux_configuration = attributes[:'linuxConfiguration'] if attributes[:'linuxConfiguration']

  raise 'You cannot provide both :linuxConfiguration and :linux_configuration' if attributes.key?(:'linuxConfiguration') && attributes.key?(:'linux_configuration')

  self.linux_configuration = attributes[:'linux_configuration'] if attributes[:'linux_configuration']

  self.windows_configuration = attributes[:'windowsConfiguration'] if attributes[:'windowsConfiguration']

  raise 'You cannot provide both :windowsConfiguration and :windows_configuration' if attributes.key?(:'windowsConfiguration') && attributes.key?(:'windows_configuration')

  self.windows_configuration = attributes[:'windows_configuration'] if attributes[:'windows_configuration']
end

Instance Attribute Details

#java_usage_tracker_processing_frequency_in_minutesInteger

The frequency (in minutes) of Java Usage Tracker processing. (That is, how often should JMS process data from the Java Usage Tracker.)

Returns:

  • (Integer)


18
19
20
# File 'lib/oci/jms/models/update_fleet_agent_configuration_details.rb', line 18

def java_usage_tracker_processing_frequency_in_minutes
  @java_usage_tracker_processing_frequency_in_minutes
end

#jre_scan_frequency_in_minutesInteger

The frequency (in minutes) of JRE scanning. (That is, how often should JMS scan for JRE installations.)

Returns:

  • (Integer)


13
14
15
# File 'lib/oci/jms/models/update_fleet_agent_configuration_details.rb', line 13

def jre_scan_frequency_in_minutes
  @jre_scan_frequency_in_minutes
end

#linux_configurationOCI::Jms::Models::FleetAgentOsConfiguration



21
22
23
# File 'lib/oci/jms/models/update_fleet_agent_configuration_details.rb', line 21

def linux_configuration
  @linux_configuration
end

#windows_configurationOCI::Jms::Models::FleetAgentOsConfiguration



24
25
26
# File 'lib/oci/jms/models/update_fleet_agent_configuration_details.rb', line 24

def windows_configuration
  @windows_configuration
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



27
28
29
30
31
32
33
34
35
36
# File 'lib/oci/jms/models/update_fleet_agent_configuration_details.rb', line 27

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'jre_scan_frequency_in_minutes': :'jreScanFrequencyInMinutes',
    'java_usage_tracker_processing_frequency_in_minutes': :'javaUsageTrackerProcessingFrequencyInMinutes',
    'linux_configuration': :'linuxConfiguration',
    'windows_configuration': :'windowsConfiguration'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



39
40
41
42
43
44
45
46
47
48
# File 'lib/oci/jms/models/update_fleet_agent_configuration_details.rb', line 39

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'jre_scan_frequency_in_minutes': :'Integer',
    'java_usage_tracker_processing_frequency_in_minutes': :'Integer',
    'linux_configuration': :'OCI::Jms::Models::FleetAgentOsConfiguration',
    'windows_configuration': :'OCI::Jms::Models::FleetAgentOsConfiguration'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



98
99
100
101
102
103
104
105
106
# File 'lib/oci/jms/models/update_fleet_agent_configuration_details.rb', line 98

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    jre_scan_frequency_in_minutes == other.jre_scan_frequency_in_minutes &&
    java_usage_tracker_processing_frequency_in_minutes == other.java_usage_tracker_processing_frequency_in_minutes &&
    linux_configuration == other.linux_configuration &&
    windows_configuration == other.windows_configuration
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/oci/jms/models/update_fleet_agent_configuration_details.rb', line 131

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


111
112
113
# File 'lib/oci/jms/models/update_fleet_agent_configuration_details.rb', line 111

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



120
121
122
# File 'lib/oci/jms/models/update_fleet_agent_configuration_details.rb', line 120

def hash
  [jre_scan_frequency_in_minutes, java_usage_tracker_processing_frequency_in_minutes, linux_configuration, windows_configuration].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



164
165
166
167
168
169
170
171
172
173
# File 'lib/oci/jms/models/update_fleet_agent_configuration_details.rb', line 164

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



158
159
160
# File 'lib/oci/jms/models/update_fleet_agent_configuration_details.rb', line 158

def to_s
  to_hash.to_s
end