Class: OCI::Jms::Models::WorkItemSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/jms/models/work_item_summary.rb

Overview

The LCM work request for a JVM installation site.

Constant Summary collapse

STATUS_ENUM =
[
  STATUS_ACCEPTED = 'ACCEPTED'.freeze,
  STATUS_IN_PROGRESS = 'IN_PROGRESS'.freeze,
  STATUS_CANCELING = 'CANCELING'.freeze,
  STATUS_CANCELED = 'CANCELED'.freeze,
  STATUS_SUCCEEDED = 'SUCCEEDED'.freeze,
  STATUS_NEEDS_ATTENTION = 'NEEDS_ATTENTION'.freeze,
  STATUS_RETRYING = 'RETRYING'.freeze,
  STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ WorkItemSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/oci/jms/models/work_item_summary.rb', line 87

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.work_request_id = attributes[:'workRequestId'] if attributes[:'workRequestId']

  raise 'You cannot provide both :workRequestId and :work_request_id' if attributes.key?(:'workRequestId') && attributes.key?(:'work_request_id')

  self.work_request_id = attributes[:'work_request_id'] if attributes[:'work_request_id']

  self.installation_site = attributes[:'installationSite'] if attributes[:'installationSite']

  raise 'You cannot provide both :installationSite and :installation_site' if attributes.key?(:'installationSite') && attributes.key?(:'installation_site')

  self.installation_site = attributes[:'installation_site'] if attributes[:'installation_site']

  self.status = attributes[:'status'] if attributes[:'status']

  self.retry_count = attributes[:'retryCount'] if attributes[:'retryCount']

  raise 'You cannot provide both :retryCount and :retry_count' if attributes.key?(:'retryCount') && attributes.key?(:'retry_count')

  self.retry_count = attributes[:'retry_count'] if attributes[:'retry_count']

  self.time_last_updated = attributes[:'timeLastUpdated'] if attributes[:'timeLastUpdated']

  raise 'You cannot provide both :timeLastUpdated and :time_last_updated' if attributes.key?(:'timeLastUpdated') && attributes.key?(:'time_last_updated')

  self.time_last_updated = attributes[:'time_last_updated'] if attributes[:'time_last_updated']
end

Instance Attribute Details

#idString

**[Required]** The unique ID of ths work item.

Returns:

  • (String)


24
25
26
# File 'lib/oci/jms/models/work_item_summary.rb', line 24

def id
  @id
end

#installation_siteOCI::Jms::Models::InstallationSite

This attribute is required.



32
33
34
# File 'lib/oci/jms/models/work_item_summary.rb', line 32

def installation_site
  @installation_site
end

#retry_countInteger

**[Required]** Number of times this work item is retried.

Returns:

  • (Integer)


40
41
42
# File 'lib/oci/jms/models/work_item_summary.rb', line 40

def retry_count
  @retry_count
end

#statusString

**[Required]** The status of the work item.

Returns:

  • (String)


36
37
38
# File 'lib/oci/jms/models/work_item_summary.rb', line 36

def status
  @status
end

#time_last_updatedDateTime

The date and time the work item was last updated. (formatted according to [RFC3339](datatracker.ietf.org/doc/html/rfc3339)).

Returns:

  • (DateTime)


45
46
47
# File 'lib/oci/jms/models/work_item_summary.rb', line 45

def time_last_updated
  @time_last_updated
end

#work_request_idString

**[Required]** The OCID of the work request created this work item.

Returns:

  • (String)


28
29
30
# File 'lib/oci/jms/models/work_item_summary.rb', line 28

def work_request_id
  @work_request_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/oci/jms/models/work_item_summary.rb', line 48

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'work_request_id': :'workRequestId',
    'installation_site': :'installationSite',
    'status': :'status',
    'retry_count': :'retryCount',
    'time_last_updated': :'timeLastUpdated'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/oci/jms/models/work_item_summary.rb', line 62

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'work_request_id': :'String',
    'installation_site': :'OCI::Jms::Models::InstallationSite',
    'status': :'String',
    'retry_count': :'Integer',
    'time_last_updated': :'DateTime'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



142
143
144
145
146
147
148
149
150
151
152
# File 'lib/oci/jms/models/work_item_summary.rb', line 142

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    work_request_id == other.work_request_id &&
    installation_site == other.installation_site &&
    status == other.status &&
    retry_count == other.retry_count &&
    time_last_updated == other.time_last_updated
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/oci/jms/models/work_item_summary.rb', line 177

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


157
158
159
# File 'lib/oci/jms/models/work_item_summary.rb', line 157

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



166
167
168
# File 'lib/oci/jms/models/work_item_summary.rb', line 166

def hash
  [id, work_request_id, installation_site, status, retry_count, time_last_updated].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



210
211
212
213
214
215
216
217
218
219
# File 'lib/oci/jms/models/work_item_summary.rb', line 210

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



204
205
206
# File 'lib/oci/jms/models/work_item_summary.rb', line 204

def to_s
  to_hash.to_s
end