Class: OCI::Jms::Models::WorkRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/jms/models/work_request.rb

Overview

An asynchronous work request. See [Work Requests](docs.cloud.oracle.com/Content/General/Concepts/workrequestoverview.htm).

Constant Summary collapse

OPERATION_TYPE_ENUM =
[
  OPERATION_TYPE_CREATE_FLEET = 'CREATE_FLEET'.freeze,
  OPERATION_TYPE_DELETE_FLEET = 'DELETE_FLEET'.freeze,
  OPERATION_TYPE_MOVE_FLEET = 'MOVE_FLEET'.freeze,
  OPERATION_TYPE_UPDATE_FLEET = 'UPDATE_FLEET'.freeze,
  OPERATION_TYPE_UPDATE_FLEET_AGENT_CONFIGURATION = 'UPDATE_FLEET_AGENT_CONFIGURATION'.freeze,
  OPERATION_TYPE_DELETE_JAVA_INSTALLATION = 'DELETE_JAVA_INSTALLATION'.freeze,
  OPERATION_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
STATUS_ENUM =
[
  STATUS_ACCEPTED = 'ACCEPTED'.freeze,
  STATUS_CANCELED = 'CANCELED'.freeze,
  STATUS_CANCELING = 'CANCELING'.freeze,
  STATUS_FAILED = 'FAILED'.freeze,
  STATUS_IN_PROGRESS = 'IN_PROGRESS'.freeze,
  STATUS_SUCCEEDED = 'SUCCEEDED'.freeze,
  STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ WorkRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/oci/jms/models/work_request.rb', line 151

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.operation_type = attributes[:'operationType'] if attributes[:'operationType']

  raise 'You cannot provide both :operationType and :operation_type' if attributes.key?(:'operationType') && attributes.key?(:'operation_type')

  self.operation_type = attributes[:'operation_type'] if attributes[:'operation_type']

  self.status = attributes[:'status'] if attributes[:'status']

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.resources = attributes[:'resources'] if attributes[:'resources']

  self.percent_complete = attributes[:'percentComplete'] if attributes[:'percentComplete']

  raise 'You cannot provide both :percentComplete and :percent_complete' if attributes.key?(:'percentComplete') && attributes.key?(:'percent_complete')

  self.percent_complete = attributes[:'percent_complete'] if attributes[:'percent_complete']

  self.time_accepted = attributes[:'timeAccepted'] if attributes[:'timeAccepted']

  raise 'You cannot provide both :timeAccepted and :time_accepted' if attributes.key?(:'timeAccepted') && attributes.key?(:'time_accepted')

  self.time_accepted = attributes[:'time_accepted'] if attributes[:'time_accepted']

  self.time_started = attributes[:'timeStarted'] if attributes[:'timeStarted']

  raise 'You cannot provide both :timeStarted and :time_started' if attributes.key?(:'timeStarted') && attributes.key?(:'time_started')

  self.time_started = attributes[:'time_started'] if attributes[:'time_started']

  self.time_finished = attributes[:'timeFinished'] if attributes[:'timeFinished']

  raise 'You cannot provide both :timeFinished and :time_finished' if attributes.key?(:'timeFinished') && attributes.key?(:'time_finished')

  self.time_finished = attributes[:'time_finished'] if attributes[:'time_finished']

  self.created_by = attributes[:'createdBy'] if attributes[:'createdBy']

  raise 'You cannot provide both :createdBy and :created_by' if attributes.key?(:'createdBy') && attributes.key?(:'created_by')

  self.created_by = attributes[:'created_by'] if attributes[:'created_by']

  self.time_last_updated = attributes[:'timeLastUpdated'] if attributes[:'timeLastUpdated']

  raise 'You cannot provide both :timeLastUpdated and :time_last_updated' if attributes.key?(:'timeLastUpdated') && attributes.key?(:'time_last_updated')

  self.time_last_updated = attributes[:'time_last_updated'] if attributes[:'time_last_updated']

  self.total_task_count = attributes[:'totalTaskCount'] if attributes[:'totalTaskCount']

  raise 'You cannot provide both :totalTaskCount and :total_task_count' if attributes.key?(:'totalTaskCount') && attributes.key?(:'total_task_count')

  self.total_task_count = attributes[:'total_task_count'] if attributes[:'total_task_count']

  self.completed_task_count = attributes[:'completedTaskCount'] if attributes[:'completedTaskCount']

  raise 'You cannot provide both :completedTaskCount and :completed_task_count' if attributes.key?(:'completedTaskCount') && attributes.key?(:'completed_task_count')

  self.completed_task_count = attributes[:'completed_task_count'] if attributes[:'completed_task_count']
end

Instance Attribute Details

#compartment_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment that contains the work request. Work requests should be scoped to the same compartment as the resource the work request affects. If the work request affects multiple resources, and those resources are not in the same compartment, it is up to the service team to pick the primary resource whose compartment should be used.

Returns:

  • (String)


49
50
51
# File 'lib/oci/jms/models/work_request.rb', line 49

def compartment_id
  @compartment_id
end

#completed_task_countInteger

The number of tasks had been executed to a terminal state.

Returns:

  • (Integer)


88
89
90
# File 'lib/oci/jms/models/work_request.rb', line 88

def completed_task_count
  @completed_task_count
end

#created_byOCI::Jms::Models::Principal



75
76
77
# File 'lib/oci/jms/models/work_request.rb', line 75

def created_by
  @created_by
end

#idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the work request.

Returns:

  • (String)


41
42
43
# File 'lib/oci/jms/models/work_request.rb', line 41

def id
  @id
end

#operation_typeString

**[Required]** The asynchronous operation tracked by this work request.

Returns:

  • (String)


33
34
35
# File 'lib/oci/jms/models/work_request.rb', line 33

def operation_type
  @operation_type
end

#percent_completeFloat

**[Required]** The percentage complete of the operation tracked by this work request.

Returns:

  • (Float)


57
58
59
# File 'lib/oci/jms/models/work_request.rb', line 57

def percent_complete
  @percent_complete
end

#resourcesArray<OCI::Jms::Models::WorkRequestResource>

**[Required]** The resources that are affected by this work request.



53
54
55
# File 'lib/oci/jms/models/work_request.rb', line 53

def resources
  @resources
end

#statusString

**[Required]** The status of the work request.

Returns:

  • (String)


37
38
39
# File 'lib/oci/jms/models/work_request.rb', line 37

def status
  @status
end

#time_acceptedDateTime

**[Required]** The date and time the request was created (formatted according to [RFC3339](datatracker.ietf.org/doc/html/rfc3339)).

Returns:

  • (DateTime)


62
63
64
# File 'lib/oci/jms/models/work_request.rb', line 62

def time_accepted
  @time_accepted
end

#time_finishedDateTime

The date and time the work request reached a terminal state, either FAILED or SUCCEEDED (formatted according to [RFC3339](datatracker.ietf.org/doc/html/rfc3339)).

Returns:

  • (DateTime)


72
73
74
# File 'lib/oci/jms/models/work_request.rb', line 72

def time_finished
  @time_finished
end

#time_last_updatedDateTime

The date and time the work request percentage was last updated. (formatted according to [RFC3339](datatracker.ietf.org/doc/html/rfc3339)).

Returns:

  • (DateTime)


80
81
82
# File 'lib/oci/jms/models/work_request.rb', line 80

def time_last_updated
  @time_last_updated
end

#time_startedDateTime

The date and time the work request transitioned from ACCEPTED to IN_PROGRESS (formatted according to [RFC3339](datatracker.ietf.org/doc/html/rfc3339)).

Returns:

  • (DateTime)


67
68
69
# File 'lib/oci/jms/models/work_request.rb', line 67

def time_started
  @time_started
end

#total_task_countInteger

The total number of tasks to be executed for this work request.

Returns:

  • (Integer)


84
85
86
# File 'lib/oci/jms/models/work_request.rb', line 84

def total_task_count
  @total_task_count
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/oci/jms/models/work_request.rb', line 91

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'operation_type': :'operationType',
    'status': :'status',
    'id': :'id',
    'compartment_id': :'compartmentId',
    'resources': :'resources',
    'percent_complete': :'percentComplete',
    'time_accepted': :'timeAccepted',
    'time_started': :'timeStarted',
    'time_finished': :'timeFinished',
    'created_by': :'createdBy',
    'time_last_updated': :'timeLastUpdated',
    'total_task_count': :'totalTaskCount',
    'completed_task_count': :'completedTaskCount'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/oci/jms/models/work_request.rb', line 112

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'operation_type': :'String',
    'status': :'String',
    'id': :'String',
    'compartment_id': :'String',
    'resources': :'Array<OCI::Jms::Models::WorkRequestResource>',
    'percent_complete': :'Float',
    'time_accepted': :'DateTime',
    'time_started': :'DateTime',
    'time_finished': :'DateTime',
    'created_by': :'OCI::Jms::Models::Principal',
    'time_last_updated': :'DateTime',
    'total_task_count': :'Integer',
    'completed_task_count': :'Integer'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/oci/jms/models/work_request.rb', line 257

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    operation_type == other.operation_type &&
    status == other.status &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    resources == other.resources &&
    percent_complete == other.percent_complete &&
    time_accepted == other.time_accepted &&
    time_started == other.time_started &&
    time_finished == other.time_finished &&
    created_by == other.created_by &&
    time_last_updated == other.time_last_updated &&
    total_task_count == other.total_task_count &&
    completed_task_count == other.completed_task_count
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
# File 'lib/oci/jms/models/work_request.rb', line 299

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


279
280
281
# File 'lib/oci/jms/models/work_request.rb', line 279

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



288
289
290
# File 'lib/oci/jms/models/work_request.rb', line 288

def hash
  [operation_type, status, id, compartment_id, resources, percent_complete, time_accepted, time_started, time_finished, created_by, time_last_updated, total_task_count, completed_task_count].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



332
333
334
335
336
337
338
339
340
341
# File 'lib/oci/jms/models/work_request.rb', line 332

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



326
327
328
# File 'lib/oci/jms/models/work_request.rb', line 326

def to_s
  to_hash.to_s
end