Class: OCI::KeyManagement::Models::DecryptedData
- Inherits:
-
Object
- Object
- OCI::KeyManagement::Models::DecryptedData
- Defined in:
- lib/oci/key_management/models/decrypted_data.rb
Overview
DecryptedData model.
Constant Summary collapse
- ENCRYPTION_ALGORITHM_ENUM =
[ ENCRYPTION_ALGORITHM_AES_256_GCM = 'AES_256_GCM'.freeze, ENCRYPTION_ALGORITHM_RSA_OAEP_SHA_1 = 'RSA_OAEP_SHA_1'.freeze, ENCRYPTION_ALGORITHM_RSA_OAEP_SHA_256 = 'RSA_OAEP_SHA_256'.freeze, ENCRYPTION_ALGORITHM_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#encryption_algorithm ⇒ String
The encryption algorithm to use to encrypt and decrypt data with a customer-managed key
AES_256_GCMindicates that the key is a symmetric key that uses the Advanced Encryption Standard (AES) algorithm and that the mode of encryption is the Galois/Counter Mode (GCM). -
#key_id ⇒ String
The OCID of the key used to encrypt the ciphertext.
-
#key_version_id ⇒ String
The OCID of the key version used to encrypt the ciphertext.
-
#plaintext ⇒ String
[Required] The decrypted data, expressed as a base64-encoded value.
-
#plaintext_checksum ⇒ String
[Required] The checksum of the decrypted data.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DecryptedData
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DecryptedData
Initializes the object
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/oci/key_management/models/decrypted_data.rb', line 81 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.plaintext = attributes[:'plaintext'] if attributes[:'plaintext'] self.plaintext_checksum = attributes[:'plaintextChecksum'] if attributes[:'plaintextChecksum'] raise 'You cannot provide both :plaintextChecksum and :plaintext_checksum' if attributes.key?(:'plaintextChecksum') && attributes.key?(:'plaintext_checksum') self.plaintext_checksum = attributes[:'plaintext_checksum'] if attributes[:'plaintext_checksum'] self.key_id = attributes[:'keyId'] if attributes[:'keyId'] raise 'You cannot provide both :keyId and :key_id' if attributes.key?(:'keyId') && attributes.key?(:'key_id') self.key_id = attributes[:'key_id'] if attributes[:'key_id'] self.key_version_id = attributes[:'keyVersionId'] if attributes[:'keyVersionId'] raise 'You cannot provide both :keyVersionId and :key_version_id' if attributes.key?(:'keyVersionId') && attributes.key?(:'key_version_id') self.key_version_id = attributes[:'key_version_id'] if attributes[:'key_version_id'] self.encryption_algorithm = attributes[:'encryptionAlgorithm'] if attributes[:'encryptionAlgorithm'] self.encryption_algorithm = "AES_256_GCM" if encryption_algorithm.nil? && !attributes.key?(:'encryptionAlgorithm') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :encryptionAlgorithm and :encryption_algorithm' if attributes.key?(:'encryptionAlgorithm') && attributes.key?(:'encryption_algorithm') self.encryption_algorithm = attributes[:'encryption_algorithm'] if attributes[:'encryption_algorithm'] self.encryption_algorithm = "AES_256_GCM" if encryption_algorithm.nil? && !attributes.key?(:'encryptionAlgorithm') && !attributes.key?(:'encryption_algorithm') # rubocop:disable Style/StringLiterals end |
Instance Attribute Details
#encryption_algorithm ⇒ String
The encryption algorithm to use to encrypt and decrypt data with a customer-managed key AES_256_GCM indicates that the key is a symmetric key that uses the Advanced Encryption Standard (AES) algorithm and that the mode of encryption is the Galois/Counter Mode (GCM). RSA_OAEP_SHA_1 indicates that the key is an asymmetric key that uses the RSA encryption algorithm and uses Optimal Asymmetric Encryption Padding (OAEP). RSA_OAEP_SHA_256 indicates that the key is an asymmetric key that uses the RSA encryption algorithm with a SHA-256 hash and uses OAEP.
42 43 44 |
# File 'lib/oci/key_management/models/decrypted_data.rb', line 42 def encryption_algorithm @encryption_algorithm end |
#key_id ⇒ String
The OCID of the key used to encrypt the ciphertext.
28 29 30 |
# File 'lib/oci/key_management/models/decrypted_data.rb', line 28 def key_id @key_id end |
#key_version_id ⇒ String
The OCID of the key version used to encrypt the ciphertext.
32 33 34 |
# File 'lib/oci/key_management/models/decrypted_data.rb', line 32 def key_version_id @key_version_id end |
#plaintext ⇒ String
[Required] The decrypted data, expressed as a base64-encoded value.
20 21 22 |
# File 'lib/oci/key_management/models/decrypted_data.rb', line 20 def plaintext @plaintext end |
#plaintext_checksum ⇒ String
[Required] The checksum of the decrypted data.
24 25 26 |
# File 'lib/oci/key_management/models/decrypted_data.rb', line 24 def plaintext_checksum @plaintext_checksum end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/oci/key_management/models/decrypted_data.rb', line 45 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'plaintext': :'plaintext', 'plaintext_checksum': :'plaintextChecksum', 'key_id': :'keyId', 'key_version_id': :'keyVersionId', 'encryption_algorithm': :'encryptionAlgorithm' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/oci/key_management/models/decrypted_data.rb', line 58 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'plaintext': :'String', 'plaintext_checksum': :'String', 'key_id': :'String', 'key_version_id': :'String', 'encryption_algorithm': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
136 137 138 139 140 141 142 143 144 145 |
# File 'lib/oci/key_management/models/decrypted_data.rb', line 136 def ==(other) return true if equal?(other) self.class == other.class && plaintext == other.plaintext && plaintext_checksum == other.plaintext_checksum && key_id == other.key_id && key_version_id == other.key_version_id && encryption_algorithm == other.encryption_algorithm end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/oci/key_management/models/decrypted_data.rb', line 170 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
150 151 152 |
# File 'lib/oci/key_management/models/decrypted_data.rb', line 150 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
159 160 161 |
# File 'lib/oci/key_management/models/decrypted_data.rb', line 159 def hash [plaintext, plaintext_checksum, key_id, key_version_id, encryption_algorithm].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
203 204 205 206 207 208 209 210 211 212 |
# File 'lib/oci/key_management/models/decrypted_data.rb', line 203 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
197 198 199 |
# File 'lib/oci/key_management/models/decrypted_data.rb', line 197 def to_s to_hash.to_s end |