Class: OCI::KeyManagement::Models::ExportedKeyData
- Inherits:
-
Object
- Object
- OCI::KeyManagement::Models::ExportedKeyData
- Defined in:
- lib/oci/key_management/models/exported_key_data.rb
Overview
The response to a request to export key material.
Constant Summary collapse
- ALGORITHM_ENUM =
[ ALGORITHM_RSA_OAEP_AES_SHA256 = 'RSA_OAEP_AES_SHA256'.freeze, ALGORITHM_RSA_OAEP_SHA256 = 'RSA_OAEP_SHA256'.freeze, ALGORITHM_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#algorithm ⇒ String
[Required] The encryption algorithm to use to encrypt exportable key material from a key that persists on the server (as opposed to a key that persists on a hardware security module and, therefore, cannot be exported).
-
#encrypted_key ⇒ String
[Required] The base64-encoded exported key material, which is encrypted by using the public RSA wrapping key specified in the export request.
-
#key_id ⇒ String
[Required] The OCID of the master encryption key associated with this key version.
-
#key_version_id ⇒ String
[Required] The OCID of the key version.
-
#time_created ⇒ DateTime
[Required] The date and time this key version was created, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.
-
#vault_id ⇒ String
[Required] The OCID of the vault that contains this key version.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ExportedKeyData
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ExportedKeyData
Initializes the object
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/oci/key_management/models/exported_key_data.rb', line 90 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.key_version_id = attributes[:'keyVersionId'] if attributes[:'keyVersionId'] raise 'You cannot provide both :keyVersionId and :key_version_id' if attributes.key?(:'keyVersionId') && attributes.key?(:'key_version_id') self.key_version_id = attributes[:'key_version_id'] if attributes[:'key_version_id'] self.key_id = attributes[:'keyId'] if attributes[:'keyId'] raise 'You cannot provide both :keyId and :key_id' if attributes.key?(:'keyId') && attributes.key?(:'key_id') self.key_id = attributes[:'key_id'] if attributes[:'key_id'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.vault_id = attributes[:'vaultId'] if attributes[:'vaultId'] raise 'You cannot provide both :vaultId and :vault_id' if attributes.key?(:'vaultId') && attributes.key?(:'vault_id') self.vault_id = attributes[:'vault_id'] if attributes[:'vault_id'] self.encrypted_key = attributes[:'encryptedKey'] if attributes[:'encryptedKey'] raise 'You cannot provide both :encryptedKey and :encrypted_key' if attributes.key?(:'encryptedKey') && attributes.key?(:'encrypted_key') self.encrypted_key = attributes[:'encrypted_key'] if attributes[:'encrypted_key'] self.algorithm = attributes[:'algorithm'] if attributes[:'algorithm'] end |
Instance Attribute Details
#algorithm ⇒ String
[Required] The encryption algorithm to use to encrypt exportable key material from a key that persists on the server (as opposed to a key that persists on a hardware security module and, therefore, cannot be exported). Specifying RSA_OAEP_AES_SHA256 invokes the RSA AES key wrap mechanism, which generates a temporary AES key. The temporary AES key is wrapped by the RSA public wrapping key provided along with the request, creating a wrapped temporary AES key. The temporary AES key is also used to wrap the exportable key material. The wrapped temporary AES key and the wrapped exportable key material are concatenated, producing concatenated blob output that jointly represents them. Specifying RSA_OAEP_SHA256 means that the exportable key material is wrapped by the RSA public wrapping key provided along with the request.
48 49 50 |
# File 'lib/oci/key_management/models/exported_key_data.rb', line 48 def algorithm @algorithm end |
#encrypted_key ⇒ String
[Required] The base64-encoded exported key material, which is encrypted by using the public RSA wrapping key specified in the export request.
37 38 39 |
# File 'lib/oci/key_management/models/exported_key_data.rb', line 37 def encrypted_key @encrypted_key end |
#key_id ⇒ String
[Required] The OCID of the master encryption key associated with this key version.
23 24 25 |
# File 'lib/oci/key_management/models/exported_key_data.rb', line 23 def key_id @key_id end |
#key_version_id ⇒ String
[Required] The OCID of the key version.
19 20 21 |
# File 'lib/oci/key_management/models/exported_key_data.rb', line 19 def key_version_id @key_version_id end |
#time_created ⇒ DateTime
[Required] The date and time this key version was created, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.
28 29 30 |
# File 'lib/oci/key_management/models/exported_key_data.rb', line 28 def time_created @time_created end |
#vault_id ⇒ String
[Required] The OCID of the vault that contains this key version.
32 33 34 |
# File 'lib/oci/key_management/models/exported_key_data.rb', line 32 def vault_id @vault_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/oci/key_management/models/exported_key_data.rb', line 51 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'key_version_id': :'keyVersionId', 'key_id': :'keyId', 'time_created': :'timeCreated', 'vault_id': :'vaultId', 'encrypted_key': :'encryptedKey', 'algorithm': :'algorithm' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/oci/key_management/models/exported_key_data.rb', line 65 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'key_version_id': :'String', 'key_id': :'String', 'time_created': :'DateTime', 'vault_id': :'String', 'encrypted_key': :'String', 'algorithm': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/oci/key_management/models/exported_key_data.rb', line 149 def ==(other) return true if equal?(other) self.class == other.class && key_version_id == other.key_version_id && key_id == other.key_id && time_created == other.time_created && vault_id == other.vault_id && encrypted_key == other.encrypted_key && algorithm == other.algorithm end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/oci/key_management/models/exported_key_data.rb', line 184 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
164 165 166 |
# File 'lib/oci/key_management/models/exported_key_data.rb', line 164 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
173 174 175 |
# File 'lib/oci/key_management/models/exported_key_data.rb', line 173 def hash [key_version_id, key_id, time_created, vault_id, encrypted_key, algorithm].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
217 218 219 220 221 222 223 224 225 226 |
# File 'lib/oci/key_management/models/exported_key_data.rb', line 217 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
211 212 213 |
# File 'lib/oci/key_management/models/exported_key_data.rb', line 211 def to_s to_hash.to_s end |