Class: OCI::KeyManagement::Models::GenerateKeyDetails
- Inherits:
-
Object
- Object
- OCI::KeyManagement::Models::GenerateKeyDetails
- Defined in:
- lib/oci/key_management/models/generate_key_details.rb
Overview
GenerateKeyDetails model.
Instance Attribute Summary collapse
-
#associated_data ⇒ Hash<String, String>
Information that can be used to provide an encryption context for the encrypted data.
-
#include_plaintext_key ⇒ BOOLEAN
[Required] If true, the generated key is also returned unencrypted.
-
#key_id ⇒ String
[Required] The OCID of the master encryption key to encrypt the generated data encryption key with.
-
#key_shape ⇒ OCI::KeyManagement::Models::KeyShape
This attribute is required.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GenerateKeyDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ GenerateKeyDetails
Initializes the object
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/oci/key_management/models/generate_key_details.rb', line 62 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.associated_data = attributes[:'associatedData'] if attributes[:'associatedData'] raise 'You cannot provide both :associatedData and :associated_data' if attributes.key?(:'associatedData') && attributes.key?(:'associated_data') self.associated_data = attributes[:'associated_data'] if attributes[:'associated_data'] self.include_plaintext_key = attributes[:'includePlaintextKey'] unless attributes[:'includePlaintextKey'].nil? raise 'You cannot provide both :includePlaintextKey and :include_plaintext_key' if attributes.key?(:'includePlaintextKey') && attributes.key?(:'include_plaintext_key') self.include_plaintext_key = attributes[:'include_plaintext_key'] unless attributes[:'include_plaintext_key'].nil? self.key_id = attributes[:'keyId'] if attributes[:'keyId'] raise 'You cannot provide both :keyId and :key_id' if attributes.key?(:'keyId') && attributes.key?(:'key_id') self.key_id = attributes[:'key_id'] if attributes[:'key_id'] self.key_shape = attributes[:'keyShape'] if attributes[:'keyShape'] raise 'You cannot provide both :keyShape and :key_shape' if attributes.key?(:'keyShape') && attributes.key?(:'key_shape') self.key_shape = attributes[:'key_shape'] if attributes[:'key_shape'] end |
Instance Attribute Details
#associated_data ⇒ Hash<String, String>
Information that can be used to provide an encryption context for the encrypted data. The length of the string representation of the associatedData must be fewer than 4096 characters.
14 15 16 |
# File 'lib/oci/key_management/models/generate_key_details.rb', line 14 def associated_data @associated_data end |
#include_plaintext_key ⇒ BOOLEAN
[Required] If true, the generated key is also returned unencrypted.
18 19 20 |
# File 'lib/oci/key_management/models/generate_key_details.rb', line 18 def include_plaintext_key @include_plaintext_key end |
#key_id ⇒ String
[Required] The OCID of the master encryption key to encrypt the generated data encryption key with.
22 23 24 |
# File 'lib/oci/key_management/models/generate_key_details.rb', line 22 def key_id @key_id end |
#key_shape ⇒ OCI::KeyManagement::Models::KeyShape
This attribute is required.
26 27 28 |
# File 'lib/oci/key_management/models/generate_key_details.rb', line 26 def key_shape @key_shape end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 36 37 38 |
# File 'lib/oci/key_management/models/generate_key_details.rb', line 29 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'associated_data': :'associatedData', 'include_plaintext_key': :'includePlaintextKey', 'key_id': :'keyId', 'key_shape': :'keyShape' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
41 42 43 44 45 46 47 48 49 50 |
# File 'lib/oci/key_management/models/generate_key_details.rb', line 41 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'associated_data': :'Hash<String, String>', 'include_plaintext_key': :'BOOLEAN', 'key_id': :'String', 'key_shape': :'OCI::KeyManagement::Models::KeyShape' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
100 101 102 103 104 105 106 107 |
# File 'lib/oci/key_management/models/generate_key_details.rb', line 100 def ==(other) return true if equal?(other) self.class == other.class && associated_data == other.associated_data && include_plaintext_key == other.include_plaintext_key && key_id == other.key_id && key_shape == other.key_shape end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/oci/key_management/models/generate_key_details.rb', line 132 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
112 113 114 |
# File 'lib/oci/key_management/models/generate_key_details.rb', line 112 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
121 122 123 |
# File 'lib/oci/key_management/models/generate_key_details.rb', line 121 def hash [associated_data, include_plaintext_key, key_id, key_shape].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
164 165 166 167 168 169 170 171 172 |
# File 'lib/oci/key_management/models/generate_key_details.rb', line 164 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
158 159 160 |
# File 'lib/oci/key_management/models/generate_key_details.rb', line 158 def to_s to_hash.to_s end |