Class: OCI::KeyManagement::Models::KeyShape
- Inherits:
-
Object
- Object
- OCI::KeyManagement::Models::KeyShape
- Defined in:
- lib/oci/key_management/models/key_shape.rb
Overview
The cryptographic properties of a key.
Constant Summary collapse
- ALGORITHM_ENUM =
[ ALGORITHM_AES = 'AES'.freeze, ALGORITHM_RSA = 'RSA'.freeze, ALGORITHM_ECDSA = 'ECDSA'.freeze, ALGORITHM_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- CURVE_ID_ENUM =
[ CURVE_ID_NIST_P256 = 'NIST_P256'.freeze, CURVE_ID_NIST_P384 = 'NIST_P384'.freeze, CURVE_ID_NIST_P521 = 'NIST_P521'.freeze, CURVE_ID_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#algorithm ⇒ String
[Required] The algorithm used by a key’s key versions to encrypt or decrypt.
-
#curve_id ⇒ String
Supported curve IDs for ECDSA keys.
-
#length ⇒ Integer
[Required] The length of the key in bytes, expressed as an integer.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ KeyShape
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ KeyShape
Initializes the object
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/oci/key_management/models/key_shape.rb', line 72 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.algorithm = attributes[:'algorithm'] if attributes[:'algorithm'] self.length = attributes[:'length'] if attributes[:'length'] self.curve_id = attributes[:'curveId'] if attributes[:'curveId'] raise 'You cannot provide both :curveId and :curve_id' if attributes.key?(:'curveId') && attributes.key?(:'curve_id') self.curve_id = attributes[:'curve_id'] if attributes[:'curve_id'] end |
Instance Attribute Details
#algorithm ⇒ String
[Required] The algorithm used by a key’s key versions to encrypt or decrypt.
27 28 29 |
# File 'lib/oci/key_management/models/key_shape.rb', line 27 def algorithm @algorithm end |
#curve_id ⇒ String
Supported curve IDs for ECDSA keys.
39 40 41 |
# File 'lib/oci/key_management/models/key_shape.rb', line 39 def curve_id @curve_id end |
#length ⇒ Integer
[Required] The length of the key in bytes, expressed as an integer. Supported values include the following:
- AES: 16, 24, or 32
- RSA: 256, 384, or 512
- ECDSA: 32, 48, or 66
35 36 37 |
# File 'lib/oci/key_management/models/key_shape.rb', line 35 def length @length end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
42 43 44 45 46 47 48 49 50 |
# File 'lib/oci/key_management/models/key_shape.rb', line 42 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'algorithm': :'algorithm', 'length': :'length', 'curve_id': :'curveId' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
53 54 55 56 57 58 59 60 61 |
# File 'lib/oci/key_management/models/key_shape.rb', line 53 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'algorithm': :'String', 'length': :'Integer', 'curve_id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
122 123 124 125 126 127 128 129 |
# File 'lib/oci/key_management/models/key_shape.rb', line 122 def ==(other) return true if equal?(other) self.class == other.class && algorithm == other.algorithm && length == other.length && curve_id == other.curve_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/oci/key_management/models/key_shape.rb', line 154 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
134 135 136 |
# File 'lib/oci/key_management/models/key_shape.rb', line 134 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
143 144 145 |
# File 'lib/oci/key_management/models/key_shape.rb', line 143 def hash [algorithm, length, curve_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
187 188 189 190 191 192 193 194 195 196 |
# File 'lib/oci/key_management/models/key_shape.rb', line 187 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
181 182 183 |
# File 'lib/oci/key_management/models/key_shape.rb', line 181 def to_s to_hash.to_s end |