Class: OCI::KeyManagement::Models::KeySummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/key_management/models/key_summary.rb

Overview

KeySummary model.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_ENABLING = 'ENABLING'.freeze,
  LIFECYCLE_STATE_ENABLED = 'ENABLED'.freeze,
  LIFECYCLE_STATE_DISABLING = 'DISABLING'.freeze,
  LIFECYCLE_STATE_DISABLED = 'DISABLED'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_PENDING_DELETION = 'PENDING_DELETION'.freeze,
  LIFECYCLE_STATE_SCHEDULING_DELETION = 'SCHEDULING_DELETION'.freeze,
  LIFECYCLE_STATE_CANCELLING_DELETION = 'CANCELLING_DELETION'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_BACKUP_IN_PROGRESS = 'BACKUP_IN_PROGRESS'.freeze,
  LIFECYCLE_STATE_RESTORING = 'RESTORING'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
PROTECTION_MODE_ENUM =
[
  PROTECTION_MODE_HSM = 'HSM'.freeze,
  PROTECTION_MODE_SOFTWARE = 'SOFTWARE'.freeze,
  PROTECTION_MODE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
ALGORITHM_ENUM =
[
  ALGORITHM_AES = 'AES'.freeze,
  ALGORITHM_RSA = 'RSA'.freeze,
  ALGORITHM_ECDSA = 'ECDSA'.freeze,
  ALGORITHM_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ KeySummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property

  • :display_name (String)

    The value to assign to the #display_name property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :id (String)

    The value to assign to the #id property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :vault_id (String)

    The value to assign to the #vault_id property

  • :protection_mode (String)

    The value to assign to the #protection_mode property

  • :algorithm (String)

    The value to assign to the #algorithm property



152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/oci/key_management/models/key_summary.rb', line 152

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.id = attributes[:'id'] if attributes[:'id']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.vault_id = attributes[:'vaultId'] if attributes[:'vaultId']

  raise 'You cannot provide both :vaultId and :vault_id' if attributes.key?(:'vaultId') && attributes.key?(:'vault_id')

  self.vault_id = attributes[:'vault_id'] if attributes[:'vault_id']

  self.protection_mode = attributes[:'protectionMode'] if attributes[:'protectionMode']

  raise 'You cannot provide both :protectionMode and :protection_mode' if attributes.key?(:'protectionMode') && attributes.key?(:'protection_mode')

  self.protection_mode = attributes[:'protection_mode'] if attributes[:'protection_mode']

  self.algorithm = attributes[:'algorithm'] if attributes[:'algorithm']
end

Instance Attribute Details

#algorithmString

The algorithm used by a key’s key versions to encrypt or decrypt data.

Returns:

  • (String)


98
99
100
# File 'lib/oci/key_management/models/key_summary.rb', line 98

def algorithm
  @algorithm
end

#compartment_idString

[Required] The OCID of the compartment that contains the key.

Returns:

  • (String)


43
44
45
# File 'lib/oci/key_management/models/key_summary.rb', line 43

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


50
51
52
# File 'lib/oci/key_management/models/key_summary.rb', line 50

def defined_tags
  @defined_tags
end

#display_nameString

[Required] A user-friendly name for the key. It does not have to be unique, and it is changeable. Avoid entering confidential information.

Returns:

  • (String)


56
57
58
# File 'lib/oci/key_management/models/key_summary.rb', line 56

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"Finance"`

Returns:

  • (Hash<String, String>)


63
64
65
# File 'lib/oci/key_management/models/key_summary.rb', line 63

def freeform_tags
  @freeform_tags
end

#idString

[Required] The OCID of the key.

Returns:

  • (String)


67
68
69
# File 'lib/oci/key_management/models/key_summary.rb', line 67

def id
  @id
end

#lifecycle_stateString

[Required] The key’s current lifecycle state.

Example: ENABLED

Returns:

  • (String)


74
75
76
# File 'lib/oci/key_management/models/key_summary.rb', line 74

def lifecycle_state
  @lifecycle_state
end

#protection_modeString

The key’s protection mode indicates how the key persists and where cryptographic operations that use the key are performed. A protection mode of HSM means that the key persists on a hardware security module (HSM) and all cryptographic operations are performed inside the HSM. A protection mode of SOFTWARE means that the key persists on the server, protected by the vault’s RSA wrapping key which persists on the HSM. All cryptographic operations that use a key with a protection mode of SOFTWARE are performed on the server. By default, a key’s protection mode is set to HSM. You can’t change a key’s protection mode after the key is created or imported.

Returns:

  • (String)


94
95
96
# File 'lib/oci/key_management/models/key_summary.rb', line 94

def protection_mode
  @protection_mode
end

#time_createdDateTime

[Required] The date and time the key was created, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.

Example: 2018-04-03T21:10:29.600Z

Returns:

  • (DateTime)


81
82
83
# File 'lib/oci/key_management/models/key_summary.rb', line 81

def time_created
  @time_created
end

#vault_idString

[Required] The OCID of the vault that contains the key.

Returns:

  • (String)


85
86
87
# File 'lib/oci/key_management/models/key_summary.rb', line 85

def vault_id
  @vault_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/oci/key_management/models/key_summary.rb', line 101

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'compartmentId',
    'defined_tags': :'definedTags',
    'display_name': :'displayName',
    'freeform_tags': :'freeformTags',
    'id': :'id',
    'lifecycle_state': :'lifecycleState',
    'time_created': :'timeCreated',
    'vault_id': :'vaultId',
    'protection_mode': :'protectionMode',
    'algorithm': :'algorithm'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/oci/key_management/models/key_summary.rb', line 119

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'String',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'display_name': :'String',
    'freeform_tags': :'Hash<String, String>',
    'id': :'String',
    'lifecycle_state': :'String',
    'time_created': :'DateTime',
    'vault_id': :'String',
    'protection_mode': :'String',
    'algorithm': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/oci/key_management/models/key_summary.rb', line 257

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    compartment_id == other.compartment_id &&
    defined_tags == other.defined_tags &&
    display_name == other.display_name &&
    freeform_tags == other.freeform_tags &&
    id == other.id &&
    lifecycle_state == other.lifecycle_state &&
    time_created == other.time_created &&
    vault_id == other.vault_id &&
    protection_mode == other.protection_mode &&
    algorithm == other.algorithm
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
# File 'lib/oci/key_management/models/key_summary.rb', line 296

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


276
277
278
# File 'lib/oci/key_management/models/key_summary.rb', line 276

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



285
286
287
# File 'lib/oci/key_management/models/key_summary.rb', line 285

def hash
  [compartment_id, defined_tags, display_name, freeform_tags, id, lifecycle_state, time_created, vault_id, protection_mode, algorithm].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



329
330
331
332
333
334
335
336
337
338
# File 'lib/oci/key_management/models/key_summary.rb', line 329

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



323
324
325
# File 'lib/oci/key_management/models/key_summary.rb', line 323

def to_s
  to_hash.to_s
end