Class: OCI::KeyManagement::Models::KeyVersion

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/key_management/models/key_version.rb

Overview

KeyVersion model.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_ENABLING = 'ENABLING'.freeze,
  LIFECYCLE_STATE_ENABLED = 'ENABLED'.freeze,
  LIFECYCLE_STATE_DISABLING = 'DISABLING'.freeze,
  LIFECYCLE_STATE_DISABLED = 'DISABLED'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_PENDING_DELETION = 'PENDING_DELETION'.freeze,
  LIFECYCLE_STATE_SCHEDULING_DELETION = 'SCHEDULING_DELETION'.freeze,
  LIFECYCLE_STATE_CANCELLING_DELETION = 'CANCELLING_DELETION'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
ORIGIN_ENUM =
[
  ORIGIN_INTERNAL = 'INTERNAL'.freeze,
  ORIGIN_EXTERNAL = 'EXTERNAL'.freeze,
  ORIGIN_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ KeyVersion

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/oci/key_management/models/key_version.rb', line 147

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.id = attributes[:'id'] if attributes[:'id']

  self.key_id = attributes[:'keyId'] if attributes[:'keyId']

  raise 'You cannot provide both :keyId and :key_id' if attributes.key?(:'keyId') && attributes.key?(:'key_id')

  self.key_id = attributes[:'key_id'] if attributes[:'key_id']

  self.public_key = attributes[:'publicKey'] if attributes[:'publicKey']

  raise 'You cannot provide both :publicKey and :public_key' if attributes.key?(:'publicKey') && attributes.key?(:'public_key')

  self.public_key = attributes[:'public_key'] if attributes[:'public_key']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.origin = attributes[:'origin'] if attributes[:'origin']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_of_deletion = attributes[:'timeOfDeletion'] if attributes[:'timeOfDeletion']

  raise 'You cannot provide both :timeOfDeletion and :time_of_deletion' if attributes.key?(:'timeOfDeletion') && attributes.key?(:'time_of_deletion')

  self.time_of_deletion = attributes[:'time_of_deletion'] if attributes[:'time_of_deletion']

  self.vault_id = attributes[:'vaultId'] if attributes[:'vaultId']

  raise 'You cannot provide both :vaultId and :vault_id' if attributes.key?(:'vaultId') && attributes.key?(:'vault_id')

  self.vault_id = attributes[:'vault_id'] if attributes[:'vault_id']

  self.restored_from_key_version_id = attributes[:'restoredFromKeyVersionId'] if attributes[:'restoredFromKeyVersionId']

  raise 'You cannot provide both :restoredFromKeyVersionId and :restored_from_key_version_id' if attributes.key?(:'restoredFromKeyVersionId') && attributes.key?(:'restored_from_key_version_id')

  self.restored_from_key_version_id = attributes[:'restored_from_key_version_id'] if attributes[:'restored_from_key_version_id']

  self.replica_details = attributes[:'replicaDetails'] if attributes[:'replicaDetails']

  raise 'You cannot provide both :replicaDetails and :replica_details' if attributes.key?(:'replicaDetails') && attributes.key?(:'replica_details')

  self.replica_details = attributes[:'replica_details'] if attributes[:'replica_details']

  self.is_primary = attributes[:'isPrimary'] unless attributes[:'isPrimary'].nil?

  raise 'You cannot provide both :isPrimary and :is_primary' if attributes.key?(:'isPrimary') && attributes.key?(:'is_primary')

  self.is_primary = attributes[:'is_primary'] unless attributes[:'is_primary'].nil?
end

Instance Attribute Details

#compartment_idString

[Required] The OCID of the compartment that contains this key version.

Returns:

  • (String)


33
34
35
# File 'lib/oci/key_management/models/key_version.rb', line 33

def compartment_id
  @compartment_id
end

#idString

[Required] The OCID of the key version.

Returns:

  • (String)


37
38
39
# File 'lib/oci/key_management/models/key_version.rb', line 37

def id
  @id
end

#is_primaryBOOLEAN

Returns:

  • (BOOLEAN)


87
88
89
# File 'lib/oci/key_management/models/key_version.rb', line 87

def is_primary
  @is_primary
end

#key_idString

[Required] The OCID of the key associated with this key version.

Returns:

  • (String)


41
42
43
# File 'lib/oci/key_management/models/key_version.rb', line 41

def key_id
  @key_id
end

#lifecycle_stateString

The key version’s current lifecycle state.

Example: ENABLED

Returns:

  • (String)


53
54
55
# File 'lib/oci/key_management/models/key_version.rb', line 53

def lifecycle_state
  @lifecycle_state
end

#originString

The source of the key material. When this value is INTERNAL, Key Management created the key material. When this value is EXTERNAL, the key material was imported from an external source.

Returns:

  • (String)


60
61
62
# File 'lib/oci/key_management/models/key_version.rb', line 60

def origin
  @origin
end

#public_keyString

The public key in PEM format. (This value pertains only to RSA and ECDSA keys.)

Returns:

  • (String)


46
47
48
# File 'lib/oci/key_management/models/key_version.rb', line 46

def public_key
  @public_key
end

#replica_detailsOCI::KeyManagement::Models::KeyVersionReplicaDetails



84
85
86
# File 'lib/oci/key_management/models/key_version.rb', line 84

def replica_details
  @replica_details
end

#restored_from_key_version_idString

The OCID of the key version from which this key version was restored.

Returns:

  • (String)


81
82
83
# File 'lib/oci/key_management/models/key_version.rb', line 81

def restored_from_key_version_id
  @restored_from_key_version_id
end

#time_createdDateTime

[Required] The date and time this key version was created, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.

Example: "2018-04-03T21:10:29.600Z"

Returns:

  • (DateTime)


67
68
69
# File 'lib/oci/key_management/models/key_version.rb', line 67

def time_created
  @time_created
end

#time_of_deletionDateTime

An optional property indicating when to delete the key version, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format. Example: 2019-04-03T21:10:29.600Z

Returns:

  • (DateTime)


73
74
75
# File 'lib/oci/key_management/models/key_version.rb', line 73

def time_of_deletion
  @time_of_deletion
end

#vault_idString

[Required] The OCID of the vault that contains this key version.

Returns:

  • (String)


77
78
79
# File 'lib/oci/key_management/models/key_version.rb', line 77

def vault_id
  @vault_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/oci/key_management/models/key_version.rb', line 90

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'compartmentId',
    'id': :'id',
    'key_id': :'keyId',
    'public_key': :'publicKey',
    'lifecycle_state': :'lifecycleState',
    'origin': :'origin',
    'time_created': :'timeCreated',
    'time_of_deletion': :'timeOfDeletion',
    'vault_id': :'vaultId',
    'restored_from_key_version_id': :'restoredFromKeyVersionId',
    'replica_details': :'replicaDetails',
    'is_primary': :'isPrimary'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/oci/key_management/models/key_version.rb', line 110

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'String',
    'id': :'String',
    'key_id': :'String',
    'public_key': :'String',
    'lifecycle_state': :'String',
    'origin': :'String',
    'time_created': :'DateTime',
    'time_of_deletion': :'DateTime',
    'vault_id': :'String',
    'restored_from_key_version_id': :'String',
    'replica_details': :'OCI::KeyManagement::Models::KeyVersionReplicaDetails',
    'is_primary': :'BOOLEAN'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
# File 'lib/oci/key_management/models/key_version.rb', line 251

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    compartment_id == other.compartment_id &&
    id == other.id &&
    key_id == other.key_id &&
    public_key == other.public_key &&
    lifecycle_state == other.lifecycle_state &&
    origin == other.origin &&
    time_created == other.time_created &&
    time_of_deletion == other.time_of_deletion &&
    vault_id == other.vault_id &&
    restored_from_key_version_id == other.restored_from_key_version_id &&
    replica_details == other.replica_details &&
    is_primary == other.is_primary
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/oci/key_management/models/key_version.rb', line 292

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


272
273
274
# File 'lib/oci/key_management/models/key_version.rb', line 272

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



281
282
283
# File 'lib/oci/key_management/models/key_version.rb', line 281

def hash
  [compartment_id, id, key_id, public_key, lifecycle_state, origin, time_created, time_of_deletion, vault_id, restored_from_key_version_id, replica_details, is_primary].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



325
326
327
328
329
330
331
332
333
334
# File 'lib/oci/key_management/models/key_version.rb', line 325

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



319
320
321
# File 'lib/oci/key_management/models/key_version.rb', line 319

def to_s
  to_hash.to_s
end