Class: OCI::KeyManagement::Models::VaultUsage
- Inherits:
-
Object
- Object
- OCI::KeyManagement::Models::VaultUsage
- Defined in:
- lib/oci/key_management/models/vault_usage.rb
Overview
VaultUsage model.
Instance Attribute Summary collapse
-
#key_count ⇒ Integer
[Required] The number of keys in this vault that persist on a hardware security module (HSM), across all compartments, excluding keys in a
DELETEDstate. -
#key_version_count ⇒ Integer
[Required] The number of key versions in this vault that persist on a hardware security module (HSM), across all compartments, excluding key versions in a
DELETEDstate. -
#software_key_count ⇒ Integer
The number of keys in this vault that persist on the server, across all compartments, excluding keys in a
DELETEDstate. -
#software_key_version_count ⇒ Integer
The number of key versions in this vault that persist on the server, across all compartments, excluding key versions in a
DELETEDstate.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VaultUsage
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ VaultUsage
Initializes the object
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/oci/key_management/models/vault_usage.rb', line 60 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.key_count = attributes[:'keyCount'] if attributes[:'keyCount'] raise 'You cannot provide both :keyCount and :key_count' if attributes.key?(:'keyCount') && attributes.key?(:'key_count') self.key_count = attributes[:'key_count'] if attributes[:'key_count'] self.key_version_count = attributes[:'keyVersionCount'] if attributes[:'keyVersionCount'] raise 'You cannot provide both :keyVersionCount and :key_version_count' if attributes.key?(:'keyVersionCount') && attributes.key?(:'key_version_count') self.key_version_count = attributes[:'key_version_count'] if attributes[:'key_version_count'] self.software_key_count = attributes[:'softwareKeyCount'] if attributes[:'softwareKeyCount'] raise 'You cannot provide both :softwareKeyCount and :software_key_count' if attributes.key?(:'softwareKeyCount') && attributes.key?(:'software_key_count') self.software_key_count = attributes[:'software_key_count'] if attributes[:'software_key_count'] self.software_key_version_count = attributes[:'softwareKeyVersionCount'] if attributes[:'softwareKeyVersionCount'] raise 'You cannot provide both :softwareKeyVersionCount and :software_key_version_count' if attributes.key?(:'softwareKeyVersionCount') && attributes.key?(:'software_key_version_count') self.software_key_version_count = attributes[:'software_key_version_count'] if attributes[:'software_key_version_count'] end |
Instance Attribute Details
#key_count ⇒ Integer
[Required] The number of keys in this vault that persist on a hardware security module (HSM), across all compartments, excluding keys in a DELETED state.
12 13 14 |
# File 'lib/oci/key_management/models/vault_usage.rb', line 12 def key_count @key_count end |
#key_version_count ⇒ Integer
[Required] The number of key versions in this vault that persist on a hardware security module (HSM), across all compartments, excluding key versions in a DELETED state.
16 17 18 |
# File 'lib/oci/key_management/models/vault_usage.rb', line 16 def key_version_count @key_version_count end |
#software_key_count ⇒ Integer
The number of keys in this vault that persist on the server, across all compartments, excluding keys in a DELETED state.
20 21 22 |
# File 'lib/oci/key_management/models/vault_usage.rb', line 20 def software_key_count @software_key_count end |
#software_key_version_count ⇒ Integer
The number of key versions in this vault that persist on the server, across all compartments, excluding key versions in a DELETED state.
24 25 26 |
# File 'lib/oci/key_management/models/vault_usage.rb', line 24 def software_key_version_count @software_key_version_count end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
27 28 29 30 31 32 33 34 35 36 |
# File 'lib/oci/key_management/models/vault_usage.rb', line 27 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'key_count': :'keyCount', 'key_version_count': :'keyVersionCount', 'software_key_count': :'softwareKeyCount', 'software_key_version_count': :'softwareKeyVersionCount' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
39 40 41 42 43 44 45 46 47 48 |
# File 'lib/oci/key_management/models/vault_usage.rb', line 39 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'key_count': :'Integer', 'key_version_count': :'Integer', 'software_key_count': :'Integer', 'software_key_version_count': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
98 99 100 101 102 103 104 105 106 |
# File 'lib/oci/key_management/models/vault_usage.rb', line 98 def ==(other) return true if equal?(other) self.class == other.class && key_count == other.key_count && key_version_count == other.key_version_count && software_key_count == other.software_key_count && software_key_version_count == other.software_key_version_count end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/oci/key_management/models/vault_usage.rb', line 131 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
111 112 113 |
# File 'lib/oci/key_management/models/vault_usage.rb', line 111 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
120 121 122 |
# File 'lib/oci/key_management/models/vault_usage.rb', line 120 def hash [key_count, key_version_count, software_key_count, software_key_version_count].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
164 165 166 167 168 169 170 171 172 173 |
# File 'lib/oci/key_management/models/vault_usage.rb', line 164 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
158 159 160 |
# File 'lib/oci/key_management/models/vault_usage.rb', line 158 def to_s to_hash.to_s end |