Class: OCI::LicenseManager::Models::BulkUploadResponse
- Inherits:
-
Object
- Object
- OCI::LicenseManager::Models::BulkUploadResponse
- Defined in:
- lib/oci/license_manager/models/bulk_upload_response.rb
Overview
The bulk upload response.
Instance Attribute Summary collapse
-
#failed_license_record_info ⇒ Array<OCI::LicenseManager::Models::BulkUploadFailedRecordInfo>
**[Required]** Error information corresponding to the supported records which are valid but could not be created.
-
#message ⇒ String
**[Required]** Response message for bulk upload.
-
#total_supported_duplicate_records ⇒ Integer
**[Required]** The number of supported license records that were valid but not uploaded since they were duplicates.
-
#total_supported_failed_license_records ⇒ Integer
**[Required]** The number of supported license records that were valid but failed with errors during upload.
-
#total_supported_invalid_records ⇒ Integer
**[Required]** The number of supported license records that could not be uploaded since they were invalid.
-
#total_supported_records ⇒ Integer
**[Required]** The number of license records which were supported.
-
#total_supported_records_saved ⇒ Integer
**[Required]** The number of supported license records that were uploaded successfully.
-
#validation_error_info ⇒ Array<OCI::LicenseManager::Models::BulkUploadValidationErrorInfo>
**[Required]** Detailed error information corresponding to each supported but invalid row for the uploaded file.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BulkUploadResponse
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ BulkUploadResponse
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/oci/license_manager/models/bulk_upload_response.rb', line 88 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.total_supported_records = attributes[:'totalSupportedRecords'] if attributes[:'totalSupportedRecords'] raise 'You cannot provide both :totalSupportedRecords and :total_supported_records' if attributes.key?(:'totalSupportedRecords') && attributes.key?(:'total_supported_records') self.total_supported_records = attributes[:'total_supported_records'] if attributes[:'total_supported_records'] self.total_supported_records_saved = attributes[:'totalSupportedRecordsSaved'] if attributes[:'totalSupportedRecordsSaved'] raise 'You cannot provide both :totalSupportedRecordsSaved and :total_supported_records_saved' if attributes.key?(:'totalSupportedRecordsSaved') && attributes.key?(:'total_supported_records_saved') self.total_supported_records_saved = attributes[:'total_supported_records_saved'] if attributes[:'total_supported_records_saved'] self.total_supported_duplicate_records = attributes[:'totalSupportedDuplicateRecords'] if attributes[:'totalSupportedDuplicateRecords'] raise 'You cannot provide both :totalSupportedDuplicateRecords and :total_supported_duplicate_records' if attributes.key?(:'totalSupportedDuplicateRecords') && attributes.key?(:'total_supported_duplicate_records') self.total_supported_duplicate_records = attributes[:'total_supported_duplicate_records'] if attributes[:'total_supported_duplicate_records'] self.total_supported_failed_license_records = attributes[:'totalSupportedFailedLicenseRecords'] if attributes[:'totalSupportedFailedLicenseRecords'] raise 'You cannot provide both :totalSupportedFailedLicenseRecords and :total_supported_failed_license_records' if attributes.key?(:'totalSupportedFailedLicenseRecords') && attributes.key?(:'total_supported_failed_license_records') self.total_supported_failed_license_records = attributes[:'total_supported_failed_license_records'] if attributes[:'total_supported_failed_license_records'] self.total_supported_invalid_records = attributes[:'totalSupportedInvalidRecords'] if attributes[:'totalSupportedInvalidRecords'] raise 'You cannot provide both :totalSupportedInvalidRecords and :total_supported_invalid_records' if attributes.key?(:'totalSupportedInvalidRecords') && attributes.key?(:'total_supported_invalid_records') self.total_supported_invalid_records = attributes[:'total_supported_invalid_records'] if attributes[:'total_supported_invalid_records'] self.validation_error_info = attributes[:'validationErrorInfo'] if attributes[:'validationErrorInfo'] raise 'You cannot provide both :validationErrorInfo and :validation_error_info' if attributes.key?(:'validationErrorInfo') && attributes.key?(:'validation_error_info') self.validation_error_info = attributes[:'validation_error_info'] if attributes[:'validation_error_info'] self.failed_license_record_info = attributes[:'failedLicenseRecordInfo'] if attributes[:'failedLicenseRecordInfo'] raise 'You cannot provide both :failedLicenseRecordInfo and :failed_license_record_info' if attributes.key?(:'failedLicenseRecordInfo') && attributes.key?(:'failed_license_record_info') self.failed_license_record_info = attributes[:'failed_license_record_info'] if attributes[:'failed_license_record_info'] self. = attributes[:'message'] if attributes[:'message'] end |
Instance Attribute Details
#failed_license_record_info ⇒ Array<OCI::LicenseManager::Models::BulkUploadFailedRecordInfo>
**[Required]** Error information corresponding to the supported records which are valid but could not be created.
36 37 38 |
# File 'lib/oci/license_manager/models/bulk_upload_response.rb', line 36 def failed_license_record_info @failed_license_record_info end |
#message ⇒ String
**[Required]** Response message for bulk upload.
40 41 42 |
# File 'lib/oci/license_manager/models/bulk_upload_response.rb', line 40 def @message end |
#total_supported_duplicate_records ⇒ Integer
**[Required]** The number of supported license records that were valid but not uploaded since they were duplicates.
20 21 22 |
# File 'lib/oci/license_manager/models/bulk_upload_response.rb', line 20 def total_supported_duplicate_records @total_supported_duplicate_records end |
#total_supported_failed_license_records ⇒ Integer
**[Required]** The number of supported license records that were valid but failed with errors during upload.
24 25 26 |
# File 'lib/oci/license_manager/models/bulk_upload_response.rb', line 24 def total_supported_failed_license_records @total_supported_failed_license_records end |
#total_supported_invalid_records ⇒ Integer
**[Required]** The number of supported license records that could not be uploaded since they were invalid.
28 29 30 |
# File 'lib/oci/license_manager/models/bulk_upload_response.rb', line 28 def total_supported_invalid_records @total_supported_invalid_records end |
#total_supported_records ⇒ Integer
**[Required]** The number of license records which were supported.
12 13 14 |
# File 'lib/oci/license_manager/models/bulk_upload_response.rb', line 12 def total_supported_records @total_supported_records end |
#total_supported_records_saved ⇒ Integer
**[Required]** The number of supported license records that were uploaded successfully.
16 17 18 |
# File 'lib/oci/license_manager/models/bulk_upload_response.rb', line 16 def total_supported_records_saved @total_supported_records_saved end |
#validation_error_info ⇒ Array<OCI::LicenseManager::Models::BulkUploadValidationErrorInfo>
**[Required]** Detailed error information corresponding to each supported but invalid row for the uploaded file.
32 33 34 |
# File 'lib/oci/license_manager/models/bulk_upload_response.rb', line 32 def validation_error_info @validation_error_info end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/oci/license_manager/models/bulk_upload_response.rb', line 43 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'total_supported_records': :'totalSupportedRecords', 'total_supported_records_saved': :'totalSupportedRecordsSaved', 'total_supported_duplicate_records': :'totalSupportedDuplicateRecords', 'total_supported_failed_license_records': :'totalSupportedFailedLicenseRecords', 'total_supported_invalid_records': :'totalSupportedInvalidRecords', 'validation_error_info': :'validationErrorInfo', 'failed_license_record_info': :'failedLicenseRecordInfo', 'message': :'message' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/oci/license_manager/models/bulk_upload_response.rb', line 59 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'total_supported_records': :'Integer', 'total_supported_records_saved': :'Integer', 'total_supported_duplicate_records': :'Integer', 'total_supported_failed_license_records': :'Integer', 'total_supported_invalid_records': :'Integer', 'validation_error_info': :'Array<OCI::LicenseManager::Models::BulkUploadValidationErrorInfo>', 'failed_license_record_info': :'Array<OCI::LicenseManager::Models::BulkUploadFailedRecordInfo>', 'message': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/oci/license_manager/models/bulk_upload_response.rb', line 146 def ==(other) return true if equal?(other) self.class == other.class && total_supported_records == other.total_supported_records && total_supported_records_saved == other.total_supported_records_saved && total_supported_duplicate_records == other.total_supported_duplicate_records && total_supported_failed_license_records == other.total_supported_failed_license_records && total_supported_invalid_records == other.total_supported_invalid_records && validation_error_info == other.validation_error_info && failed_license_record_info == other.failed_license_record_info && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/oci/license_manager/models/bulk_upload_response.rb', line 183 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
163 164 165 |
# File 'lib/oci/license_manager/models/bulk_upload_response.rb', line 163 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
172 173 174 |
# File 'lib/oci/license_manager/models/bulk_upload_response.rb', line 172 def hash [total_supported_records, total_supported_records_saved, total_supported_duplicate_records, total_supported_failed_license_records, total_supported_invalid_records, validation_error_info, failed_license_record_info, ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
216 217 218 219 220 221 222 223 224 225 |
# File 'lib/oci/license_manager/models/bulk_upload_response.rb', line 216 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
210 211 212 |
# File 'lib/oci/license_manager/models/bulk_upload_response.rb', line 210 def to_s to_hash.to_s end |