Class: OCI::LicenseManager::Models::BulkUploadValidationErrorInfo
- Inherits:
-
Object
- Object
- OCI::LicenseManager::Models::BulkUploadValidationErrorInfo
- Defined in:
- lib/oci/license_manager/models/bulk_upload_validation_error_info.rb
Overview
Detailed error information corresponding to each column for a particular supported license record that could not be uploaded.
Instance Attribute Summary collapse
-
#product_name ⇒ String
**[Required]** Product name of invalid row.
-
#row_error ⇒ Array<OCI::LicenseManager::Models::BulkUploadCellInfo>
**[Required]** Error information corresponding to each column.
-
#row_number ⇒ Integer
**[Required]** Refers to the license record number as provided in the bulk upload file.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BulkUploadValidationErrorInfo
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ BulkUploadValidationErrorInfo
Initializes the object
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/oci/license_manager/models/bulk_upload_validation_error_info.rb', line 53 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.row_number = attributes[:'rowNumber'] if attributes[:'rowNumber'] raise 'You cannot provide both :rowNumber and :row_number' if attributes.key?(:'rowNumber') && attributes.key?(:'row_number') self.row_number = attributes[:'row_number'] if attributes[:'row_number'] self.product_name = attributes[:'productName'] if attributes[:'productName'] raise 'You cannot provide both :productName and :product_name' if attributes.key?(:'productName') && attributes.key?(:'product_name') self.product_name = attributes[:'product_name'] if attributes[:'product_name'] self.row_error = attributes[:'rowError'] if attributes[:'rowError'] raise 'You cannot provide both :rowError and :row_error' if attributes.key?(:'rowError') && attributes.key?(:'row_error') self.row_error = attributes[:'row_error'] if attributes[:'row_error'] end |
Instance Attribute Details
#product_name ⇒ String
**[Required]** Product name of invalid row.
16 17 18 |
# File 'lib/oci/license_manager/models/bulk_upload_validation_error_info.rb', line 16 def product_name @product_name end |
#row_error ⇒ Array<OCI::LicenseManager::Models::BulkUploadCellInfo>
**[Required]** Error information corresponding to each column.
20 21 22 |
# File 'lib/oci/license_manager/models/bulk_upload_validation_error_info.rb', line 20 def row_error @row_error end |
#row_number ⇒ Integer
**[Required]** Refers to the license record number as provided in the bulk upload file.
12 13 14 |
# File 'lib/oci/license_manager/models/bulk_upload_validation_error_info.rb', line 12 def row_number @row_number end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
23 24 25 26 27 28 29 30 31 |
# File 'lib/oci/license_manager/models/bulk_upload_validation_error_info.rb', line 23 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'row_number': :'rowNumber', 'product_name': :'productName', 'row_error': :'rowError' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
34 35 36 37 38 39 40 41 42 |
# File 'lib/oci/license_manager/models/bulk_upload_validation_error_info.rb', line 34 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'row_number': :'Integer', 'product_name': :'String', 'row_error': :'Array<OCI::LicenseManager::Models::BulkUploadCellInfo>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
85 86 87 88 89 90 91 92 |
# File 'lib/oci/license_manager/models/bulk_upload_validation_error_info.rb', line 85 def ==(other) return true if equal?(other) self.class == other.class && row_number == other.row_number && product_name == other.product_name && row_error == other.row_error end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/oci/license_manager/models/bulk_upload_validation_error_info.rb', line 117 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
97 98 99 |
# File 'lib/oci/license_manager/models/bulk_upload_validation_error_info.rb', line 97 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
106 107 108 |
# File 'lib/oci/license_manager/models/bulk_upload_validation_error_info.rb', line 106 def hash [row_number, product_name, row_error].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
150 151 152 153 154 155 156 157 158 159 |
# File 'lib/oci/license_manager/models/bulk_upload_validation_error_info.rb', line 150 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
144 145 146 |
# File 'lib/oci/license_manager/models/bulk_upload_validation_error_info.rb', line 144 def to_s to_hash.to_s end |