Class: OCI::LicenseManager::Models::CreateProductLicenseDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/license_manager/models/create_product_license_details.rb

Overview

Details for creating a new product license.

Constant Summary collapse

LICENSE_UNIT_ENUM =
[
  LICENSE_UNIT_OCPU = 'OCPU'.freeze,
  LICENSE_UNIT_NAMED_USER_PLUS = 'NAMED_USER_PLUS'.freeze,
  LICENSE_UNIT_PROCESSORS = 'PROCESSORS'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateProductLicenseDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/oci/license_manager/models/create_product_license_details.rb', line 100

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.is_vendor_oracle = attributes[:'isVendorOracle'] unless attributes[:'isVendorOracle'].nil?
  self.is_vendor_oracle = false if is_vendor_oracle.nil? && !attributes.key?(:'isVendorOracle') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isVendorOracle and :is_vendor_oracle' if attributes.key?(:'isVendorOracle') && attributes.key?(:'is_vendor_oracle')

  self.is_vendor_oracle = attributes[:'is_vendor_oracle'] unless attributes[:'is_vendor_oracle'].nil?
  self.is_vendor_oracle = false if is_vendor_oracle.nil? && !attributes.key?(:'isVendorOracle') && !attributes.key?(:'is_vendor_oracle') # rubocop:disable Style/StringLiterals

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.license_unit = attributes[:'licenseUnit'] if attributes[:'licenseUnit']

  raise 'You cannot provide both :licenseUnit and :license_unit' if attributes.key?(:'licenseUnit') && attributes.key?(:'license_unit')

  self.license_unit = attributes[:'license_unit'] if attributes[:'license_unit']

  self.vendor_name = attributes[:'vendorName'] if attributes[:'vendorName']

  raise 'You cannot provide both :vendorName and :vendor_name' if attributes.key?(:'vendorName') && attributes.key?(:'vendor_name')

  self.vendor_name = attributes[:'vendor_name'] if attributes[:'vendor_name']

  self.images = attributes[:'images'] if attributes[:'images']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#compartment_idString

**[Required]** The compartment [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) where product licenses are created.

Returns:

  • (String)


18
19
20
# File 'lib/oci/license_manager/models/create_product_license_details.rb', line 18

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


52
53
54
# File 'lib/oci/license_manager/models/create_product_license_details.rb', line 52

def defined_tags
  @defined_tags
end

#display_nameString

**[Required]** Name of the product license.

Returns:

  • (String)


27
28
29
# File 'lib/oci/license_manager/models/create_product_license_details.rb', line 27

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type, or scope. Exists for cross-compatibility only. Example: `"value"`

Returns:

  • (Hash<String, String>)


46
47
48
# File 'lib/oci/license_manager/models/create_product_license_details.rb', line 46

def freeform_tags
  @freeform_tags
end

#imagesArray<OCI::LicenseManager::Models::ImageDetails>

The image details associated with the product license.



40
41
42
# File 'lib/oci/license_manager/models/create_product_license_details.rb', line 40

def images
  @images
end

#is_vendor_oracleBOOLEAN

**[Required]** Specifies if the product license vendor is Oracle or a third party.

Returns:

  • (BOOLEAN)


22
23
24
# File 'lib/oci/license_manager/models/create_product_license_details.rb', line 22

def is_vendor_oracle
  @is_vendor_oracle
end

#license_unitString

**[Required]** The product license unit.

Returns:

  • (String)


31
32
33
# File 'lib/oci/license_manager/models/create_product_license_details.rb', line 31

def license_unit
  @license_unit
end

#vendor_nameString

The product license vendor name, for example: Microsoft, RHEL, and so on.

Returns:

  • (String)


36
37
38
# File 'lib/oci/license_manager/models/create_product_license_details.rb', line 36

def vendor_name
  @vendor_name
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/oci/license_manager/models/create_product_license_details.rb', line 55

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'compartmentId',
    'is_vendor_oracle': :'isVendorOracle',
    'display_name': :'displayName',
    'license_unit': :'licenseUnit',
    'vendor_name': :'vendorName',
    'images': :'images',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/oci/license_manager/models/create_product_license_details.rb', line 71

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'String',
    'is_vendor_oracle': :'BOOLEAN',
    'display_name': :'String',
    'license_unit': :'String',
    'vendor_name': :'String',
    'images': :'Array<OCI::LicenseManager::Models::ImageDetails>',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/oci/license_manager/models/create_product_license_details.rb', line 168

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    compartment_id == other.compartment_id &&
    is_vendor_oracle == other.is_vendor_oracle &&
    display_name == other.display_name &&
    license_unit == other.license_unit &&
    vendor_name == other.vendor_name &&
    images == other.images &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/oci/license_manager/models/create_product_license_details.rb', line 205

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


185
186
187
# File 'lib/oci/license_manager/models/create_product_license_details.rb', line 185

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



194
195
196
# File 'lib/oci/license_manager/models/create_product_license_details.rb', line 194

def hash
  [compartment_id, is_vendor_oracle, display_name, license_unit, vendor_name, images, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



238
239
240
241
242
243
244
245
246
247
# File 'lib/oci/license_manager/models/create_product_license_details.rb', line 238

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



232
233
234
# File 'lib/oci/license_manager/models/create_product_license_details.rb', line 232

def to_s
  to_hash.to_s
end