Class: OCI::LicenseManager::Models::ImageResponse
- Inherits:
-
Object
- Object
- OCI::LicenseManager::Models::ImageResponse
- Defined in:
- lib/oci/license_manager/models/image_response.rb
Overview
The collection of image details for the product license.
Instance Attribute Summary collapse
-
#id ⇒ String
The image ID associated with the product license.
-
#listing_id ⇒ String
The image listing ID.
-
#listing_name ⇒ String
The listing name associated with the product license.
-
#package_version ⇒ String
The image package version.
-
#publisher ⇒ String
The image publisher.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ImageResponse
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ImageResponse
Initializes the object
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/oci/license_manager/models/image_response.rb', line 67 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.listing_name = attributes[:'listingName'] if attributes[:'listingName'] raise 'You cannot provide both :listingName and :listing_name' if attributes.key?(:'listingName') && attributes.key?(:'listing_name') self.listing_name = attributes[:'listing_name'] if attributes[:'listing_name'] self.publisher = attributes[:'publisher'] if attributes[:'publisher'] self.listing_id = attributes[:'listingId'] if attributes[:'listingId'] raise 'You cannot provide both :listingId and :listing_id' if attributes.key?(:'listingId') && attributes.key?(:'listing_id') self.listing_id = attributes[:'listing_id'] if attributes[:'listing_id'] self.package_version = attributes[:'packageVersion'] if attributes[:'packageVersion'] raise 'You cannot provide both :packageVersion and :package_version' if attributes.key?(:'packageVersion') && attributes.key?(:'package_version') self.package_version = attributes[:'package_version'] if attributes[:'package_version'] end |
Instance Attribute Details
#id ⇒ String
The image ID associated with the product license.
12 13 14 |
# File 'lib/oci/license_manager/models/image_response.rb', line 12 def id @id end |
#listing_id ⇒ String
The image listing ID.
24 25 26 |
# File 'lib/oci/license_manager/models/image_response.rb', line 24 def listing_id @listing_id end |
#listing_name ⇒ String
The listing name associated with the product license.
16 17 18 |
# File 'lib/oci/license_manager/models/image_response.rb', line 16 def listing_name @listing_name end |
#package_version ⇒ String
The image package version.
28 29 30 |
# File 'lib/oci/license_manager/models/image_response.rb', line 28 def package_version @package_version end |
#publisher ⇒ String
The image publisher.
20 21 22 |
# File 'lib/oci/license_manager/models/image_response.rb', line 20 def publisher @publisher end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 40 41 |
# File 'lib/oci/license_manager/models/image_response.rb', line 31 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'listing_name': :'listingName', 'publisher': :'publisher', 'listing_id': :'listingId', 'package_version': :'packageVersion' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/oci/license_manager/models/image_response.rb', line 44 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'listing_name': :'String', 'publisher': :'String', 'listing_id': :'String', 'package_version': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
103 104 105 106 107 108 109 110 111 112 |
# File 'lib/oci/license_manager/models/image_response.rb', line 103 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && listing_name == other.listing_name && publisher == other.publisher && listing_id == other.listing_id && package_version == other.package_version end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/oci/license_manager/models/image_response.rb', line 137 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
117 118 119 |
# File 'lib/oci/license_manager/models/image_response.rb', line 117 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
126 127 128 |
# File 'lib/oci/license_manager/models/image_response.rb', line 126 def hash [id, listing_name, publisher, listing_id, package_version].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
170 171 172 173 174 175 176 177 178 179 |
# File 'lib/oci/license_manager/models/image_response.rb', line 170 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
164 165 166 |
# File 'lib/oci/license_manager/models/image_response.rb', line 164 def to_s to_hash.to_s end |