Class: OCI::LicenseManager::Models::LicenseRecordSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/license_manager/models/license_record_summary.rb

Overview

The license record summary.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LICENSE_UNIT_ENUM =
[
  LICENSE_UNIT_OCPU = 'OCPU'.freeze,
  LICENSE_UNIT_NAMED_USER_PLUS = 'NAMED_USER_PLUS'.freeze,
  LICENSE_UNIT_PROCESSORS = 'PROCESSORS'.freeze,
  LICENSE_UNIT_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ LicenseRecordSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :product_license_id (String)

    The value to assign to the #product_license_id property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :display_name (String)

    The value to assign to the #display_name property

  • :product_id (String)

    The value to assign to the #product_id property

  • :license_count (Integer)

    The value to assign to the #license_count property

  • :expiration_date (DateTime)

    The value to assign to the #expiration_date property

  • :support_end_date (DateTime)

    The value to assign to the #support_end_date property

  • :is_unlimited (BOOLEAN)

    The value to assign to the #is_unlimited property

  • :is_perpetual (BOOLEAN)

    The value to assign to the #is_perpetual property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :time_updated (DateTime)

    The value to assign to the #time_updated property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :license_unit (String)

    The value to assign to the #license_unit property

  • :product_license (String)

    The value to assign to the #product_license property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property

  • :system_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #system_tags property



188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/oci/license_manager/models/license_record_summary.rb', line 188

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.product_license_id = attributes[:'productLicenseId'] if attributes[:'productLicenseId']

  raise 'You cannot provide both :productLicenseId and :product_license_id' if attributes.key?(:'productLicenseId') && attributes.key?(:'product_license_id')

  self.product_license_id = attributes[:'product_license_id'] if attributes[:'product_license_id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.product_id = attributes[:'productId'] if attributes[:'productId']

  raise 'You cannot provide both :productId and :product_id' if attributes.key?(:'productId') && attributes.key?(:'product_id')

  self.product_id = attributes[:'product_id'] if attributes[:'product_id']

  self.license_count = attributes[:'licenseCount'] if attributes[:'licenseCount']

  raise 'You cannot provide both :licenseCount and :license_count' if attributes.key?(:'licenseCount') && attributes.key?(:'license_count')

  self.license_count = attributes[:'license_count'] if attributes[:'license_count']

  self.expiration_date = attributes[:'expirationDate'] if attributes[:'expirationDate']

  raise 'You cannot provide both :expirationDate and :expiration_date' if attributes.key?(:'expirationDate') && attributes.key?(:'expiration_date')

  self.expiration_date = attributes[:'expiration_date'] if attributes[:'expiration_date']

  self.support_end_date = attributes[:'supportEndDate'] if attributes[:'supportEndDate']

  raise 'You cannot provide both :supportEndDate and :support_end_date' if attributes.key?(:'supportEndDate') && attributes.key?(:'support_end_date')

  self.support_end_date = attributes[:'support_end_date'] if attributes[:'support_end_date']

  self.is_unlimited = attributes[:'isUnlimited'] unless attributes[:'isUnlimited'].nil?
  self.is_unlimited = false if is_unlimited.nil? && !attributes.key?(:'isUnlimited') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isUnlimited and :is_unlimited' if attributes.key?(:'isUnlimited') && attributes.key?(:'is_unlimited')

  self.is_unlimited = attributes[:'is_unlimited'] unless attributes[:'is_unlimited'].nil?
  self.is_unlimited = false if is_unlimited.nil? && !attributes.key?(:'isUnlimited') && !attributes.key?(:'is_unlimited') # rubocop:disable Style/StringLiterals

  self.is_perpetual = attributes[:'isPerpetual'] unless attributes[:'isPerpetual'].nil?
  self.is_perpetual = false if is_perpetual.nil? && !attributes.key?(:'isPerpetual') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isPerpetual and :is_perpetual' if attributes.key?(:'isPerpetual') && attributes.key?(:'is_perpetual')

  self.is_perpetual = attributes[:'is_perpetual'] unless attributes[:'is_perpetual'].nil?
  self.is_perpetual = false if is_perpetual.nil? && !attributes.key?(:'isPerpetual') && !attributes.key?(:'is_perpetual') # rubocop:disable Style/StringLiterals

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.license_unit = attributes[:'licenseUnit'] if attributes[:'licenseUnit']

  raise 'You cannot provide both :licenseUnit and :license_unit' if attributes.key?(:'licenseUnit') && attributes.key?(:'license_unit')

  self.license_unit = attributes[:'license_unit'] if attributes[:'license_unit']

  self.product_license = attributes[:'productLicense'] if attributes[:'productLicense']

  raise 'You cannot provide both :productLicense and :product_license' if attributes.key?(:'productLicense') && attributes.key?(:'product_license')

  self.product_license = attributes[:'product_license'] if attributes[:'product_license']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

  raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

  self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']
end

Instance Attribute Details

#compartment_idString

The compartment [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) where the license record is created.

Returns:

  • (String)


35
36
37
# File 'lib/oci/license_manager/models/license_record_summary.rb', line 35

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


104
105
106
# File 'lib/oci/license_manager/models/license_record_summary.rb', line 104

def defined_tags
  @defined_tags
end

#display_nameString

**[Required]** License record display name. Avoid entering confidential information.

Returns:

  • (String)


40
41
42
# File 'lib/oci/license_manager/models/license_record_summary.rb', line 40

def display_name
  @display_name
end

#expiration_dateDateTime

The license record end date in [RFC 3339](tools.ietf.org/html/rfc3339) format. date format. Example: `2018-09-12`

Returns:

  • (DateTime)


57
58
59
# File 'lib/oci/license_manager/models/license_record_summary.rb', line 57

def expiration_date
  @expiration_date
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type, or scope. Exists for cross-compatibility only. Example: `"value"`

Returns:

  • (Hash<String, String>)


98
99
100
# File 'lib/oci/license_manager/models/license_record_summary.rb', line 98

def freeform_tags
  @freeform_tags
end

#idString

**[Required]** The license record [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).

Returns:

  • (String)


27
28
29
# File 'lib/oci/license_manager/models/license_record_summary.rb', line 27

def id
  @id
end

#is_perpetualBOOLEAN

**[Required]** Specifies if the license record term is perpertual.

Returns:

  • (BOOLEAN)


72
73
74
# File 'lib/oci/license_manager/models/license_record_summary.rb', line 72

def is_perpetual
  @is_perpetual
end

#is_unlimitedBOOLEAN

**[Required]** Specifies if the license count is unlimited.

Returns:

  • (BOOLEAN)


68
69
70
# File 'lib/oci/license_manager/models/license_record_summary.rb', line 68

def is_unlimited
  @is_unlimited
end

#license_countInteger

The number of license record units added by the user for the given license record. Default 1

Returns:

  • (Integer)


50
51
52
# File 'lib/oci/license_manager/models/license_record_summary.rb', line 50

def license_count
  @license_count
end

#license_unitString

The product license unit.

Returns:

  • (String)


88
89
90
# File 'lib/oci/license_manager/models/license_record_summary.rb', line 88

def license_unit
  @license_unit
end

#lifecycle_stateString

The current license record state.

Returns:

  • (String)


84
85
86
# File 'lib/oci/license_manager/models/license_record_summary.rb', line 84

def lifecycle_state
  @lifecycle_state
end

#product_idString

The license record product ID.

Returns:

  • (String)


44
45
46
# File 'lib/oci/license_manager/models/license_record_summary.rb', line 44

def product_id
  @product_id
end

#product_licenseString

The product license name with which the license record is associated.

Returns:

  • (String)


92
93
94
# File 'lib/oci/license_manager/models/license_record_summary.rb', line 92

def product_license
  @product_license
end

#product_license_idString

The product license [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) with which the license record is associated.

Returns:

  • (String)


31
32
33
# File 'lib/oci/license_manager/models/license_record_summary.rb', line 31

def product_license_id
  @product_license_id
end

#support_end_dateDateTime

The license record support end date in [RFC 3339](tools.ietf.org/html/rfc3339) format. date format. Example: `2018-09-12`

Returns:

  • (DateTime)


64
65
66
# File 'lib/oci/license_manager/models/license_record_summary.rb', line 64

def support_end_date
  @support_end_date
end

#system_tagsHash<String, Hash<String, Object>>

Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"free-tier-retained": "true"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


110
111
112
# File 'lib/oci/license_manager/models/license_record_summary.rb', line 110

def system_tags
  @system_tags
end

#time_createdDateTime

The time the license record was created. An [RFC 3339](tools.ietf.org/html/rfc3339)-formatted datetime string.

Returns:

  • (DateTime)


76
77
78
# File 'lib/oci/license_manager/models/license_record_summary.rb', line 76

def time_created
  @time_created
end

#time_updatedDateTime

The time the license record was updated. An [RFC 3339](tools.ietf.org/html/rfc3339)-formatted datetime string.

Returns:

  • (DateTime)


80
81
82
# File 'lib/oci/license_manager/models/license_record_summary.rb', line 80

def time_updated
  @time_updated
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/oci/license_manager/models/license_record_summary.rb', line 113

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'product_license_id': :'productLicenseId',
    'compartment_id': :'compartmentId',
    'display_name': :'displayName',
    'product_id': :'productId',
    'license_count': :'licenseCount',
    'expiration_date': :'expirationDate',
    'support_end_date': :'supportEndDate',
    'is_unlimited': :'isUnlimited',
    'is_perpetual': :'isPerpetual',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'lifecycle_state': :'lifecycleState',
    'license_unit': :'licenseUnit',
    'product_license': :'productLicense',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/oci/license_manager/models/license_record_summary.rb', line 139

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'product_license_id': :'String',
    'compartment_id': :'String',
    'display_name': :'String',
    'product_id': :'String',
    'license_count': :'Integer',
    'expiration_date': :'DateTime',
    'support_end_date': :'DateTime',
    'is_unlimited': :'BOOLEAN',
    'is_perpetual': :'BOOLEAN',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'lifecycle_state': :'String',
    'license_unit': :'String',
    'product_license': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
# File 'lib/oci/license_manager/models/license_record_summary.rb', line 336

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    product_license_id == other.product_license_id &&
    compartment_id == other.compartment_id &&
    display_name == other.display_name &&
    product_id == other.product_id &&
    license_count == other.license_count &&
    expiration_date == other.expiration_date &&
    support_end_date == other.support_end_date &&
    is_unlimited == other.is_unlimited &&
    is_perpetual == other.is_perpetual &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    lifecycle_state == other.lifecycle_state &&
    license_unit == other.license_unit &&
    product_license == other.product_license &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
# File 'lib/oci/license_manager/models/license_record_summary.rb', line 383

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


363
364
365
# File 'lib/oci/license_manager/models/license_record_summary.rb', line 363

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



372
373
374
# File 'lib/oci/license_manager/models/license_record_summary.rb', line 372

def hash
  [id, product_license_id, compartment_id, display_name, product_id, license_count, expiration_date, support_end_date, is_unlimited, is_perpetual, time_created, time_updated, lifecycle_state, license_unit, product_license, freeform_tags, defined_tags, system_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



416
417
418
419
420
421
422
423
424
425
# File 'lib/oci/license_manager/models/license_record_summary.rb', line 416

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



410
411
412
# File 'lib/oci/license_manager/models/license_record_summary.rb', line 410

def to_s
  to_hash.to_s
end