Class: OCI::LicenseManager::Models::TopUtilizedResourceSummary
- Inherits:
-
Object
- Object
- OCI::LicenseManager::Models::TopUtilizedResourceSummary
- Defined in:
- lib/oci/license_manager/models/top_utilized_resource_summary.rb
Overview
A summary of a top utlized resource.
Constant Summary collapse
- UNIT_TYPE_ENUM =
[ UNIT_TYPE_OCPU = 'OCPU'.freeze, UNIT_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#resource_compartment_id ⇒ String
**[Required]** The compartment [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) that contains the resource.
-
#resource_compartment_name ⇒ String
**[Required]** The display name of the compartment that contains the resource.
-
#resource_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the resource.
-
#resource_name ⇒ String
**[Required]** Resource canonical name.
-
#total_units ⇒ Float
**[Required]** Number of license units consumed by the resource.
-
#unit_type ⇒ String
**[Required]** The resource unit.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TopUtilizedResourceSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ TopUtilizedResourceSummary
Initializes the object
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/oci/license_manager/models/top_utilized_resource_summary.rb', line 81 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.resource_id = attributes[:'resourceId'] if attributes[:'resourceId'] raise 'You cannot provide both :resourceId and :resource_id' if attributes.key?(:'resourceId') && attributes.key?(:'resource_id') self.resource_id = attributes[:'resource_id'] if attributes[:'resource_id'] self.resource_name = attributes[:'resourceName'] if attributes[:'resourceName'] raise 'You cannot provide both :resourceName and :resource_name' if attributes.key?(:'resourceName') && attributes.key?(:'resource_name') self.resource_name = attributes[:'resource_name'] if attributes[:'resource_name'] self.resource_compartment_id = attributes[:'resourceCompartmentId'] if attributes[:'resourceCompartmentId'] raise 'You cannot provide both :resourceCompartmentId and :resource_compartment_id' if attributes.key?(:'resourceCompartmentId') && attributes.key?(:'resource_compartment_id') self.resource_compartment_id = attributes[:'resource_compartment_id'] if attributes[:'resource_compartment_id'] self.resource_compartment_name = attributes[:'resourceCompartmentName'] if attributes[:'resourceCompartmentName'] raise 'You cannot provide both :resourceCompartmentName and :resource_compartment_name' if attributes.key?(:'resourceCompartmentName') && attributes.key?(:'resource_compartment_name') self.resource_compartment_name = attributes[:'resource_compartment_name'] if attributes[:'resource_compartment_name'] self.total_units = attributes[:'totalUnits'] if attributes[:'totalUnits'] self.total_units = 0.0 if total_units.nil? && !attributes.key?(:'totalUnits') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :totalUnits and :total_units' if attributes.key?(:'totalUnits') && attributes.key?(:'total_units') self.total_units = attributes[:'total_units'] if attributes[:'total_units'] self.total_units = 0.0 if total_units.nil? && !attributes.key?(:'totalUnits') && !attributes.key?(:'total_units') # rubocop:disable Style/StringLiterals self.unit_type = attributes[:'unitType'] if attributes[:'unitType'] raise 'You cannot provide both :unitType and :unit_type' if attributes.key?(:'unitType') && attributes.key?(:'unit_type') self.unit_type = attributes[:'unit_type'] if attributes[:'unit_type'] end |
Instance Attribute Details
#resource_compartment_id ⇒ String
**[Required]** The compartment [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) that contains the resource.
27 28 29 |
# File 'lib/oci/license_manager/models/top_utilized_resource_summary.rb', line 27 def resource_compartment_id @resource_compartment_id end |
#resource_compartment_name ⇒ String
**[Required]** The display name of the compartment that contains the resource.
31 32 33 |
# File 'lib/oci/license_manager/models/top_utilized_resource_summary.rb', line 31 def resource_compartment_name @resource_compartment_name end |
#resource_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the resource.
19 20 21 |
# File 'lib/oci/license_manager/models/top_utilized_resource_summary.rb', line 19 def resource_id @resource_id end |
#resource_name ⇒ String
**[Required]** Resource canonical name.
23 24 25 |
# File 'lib/oci/license_manager/models/top_utilized_resource_summary.rb', line 23 def resource_name @resource_name end |
#total_units ⇒ Float
**[Required]** Number of license units consumed by the resource.
35 36 37 |
# File 'lib/oci/license_manager/models/top_utilized_resource_summary.rb', line 35 def total_units @total_units end |
#unit_type ⇒ String
**[Required]** The resource unit.
39 40 41 |
# File 'lib/oci/license_manager/models/top_utilized_resource_summary.rb', line 39 def unit_type @unit_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/oci/license_manager/models/top_utilized_resource_summary.rb', line 42 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'resource_id': :'resourceId', 'resource_name': :'resourceName', 'resource_compartment_id': :'resourceCompartmentId', 'resource_compartment_name': :'resourceCompartmentName', 'total_units': :'totalUnits', 'unit_type': :'unitType' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/oci/license_manager/models/top_utilized_resource_summary.rb', line 56 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'resource_id': :'String', 'resource_name': :'String', 'resource_compartment_id': :'String', 'resource_compartment_name': :'String', 'total_units': :'Float', 'unit_type': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/oci/license_manager/models/top_utilized_resource_summary.rb', line 146 def ==(other) return true if equal?(other) self.class == other.class && resource_id == other.resource_id && resource_name == other.resource_name && resource_compartment_id == other.resource_compartment_id && resource_compartment_name == other.resource_compartment_name && total_units == other.total_units && unit_type == other.unit_type end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/oci/license_manager/models/top_utilized_resource_summary.rb', line 181 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
161 162 163 |
# File 'lib/oci/license_manager/models/top_utilized_resource_summary.rb', line 161 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
170 171 172 |
# File 'lib/oci/license_manager/models/top_utilized_resource_summary.rb', line 170 def hash [resource_id, resource_name, resource_compartment_id, resource_compartment_name, total_units, unit_type].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
214 215 216 217 218 219 220 221 222 223 |
# File 'lib/oci/license_manager/models/top_utilized_resource_summary.rb', line 214 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
208 209 210 |
# File 'lib/oci/license_manager/models/top_utilized_resource_summary.rb', line 208 def to_s to_hash.to_s end |