Class: OCI::Limits::Models::CreateQuotaDetails
- Inherits:
-
Object
- Object
- OCI::Limits::Models::CreateQuotaDetails
- Defined in:
- lib/oci/limits/models/create_quota_details.rb
Overview
Request object for create quota operation.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The OCID of the compartment containing the resource this quota applies to.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
**[Required]** The description you assign to the quota.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#locks ⇒ Array<OCI::Limits::Models::AddLockDetails>
Locks associated with this resource.
-
#name ⇒ String
**[Required]** The name you assign to the quota during creation.
-
#statements ⇒ Array<String>
**[Required]** An array of quota statements written in the declarative quota statement language.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateQuotaDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateQuotaDetails
Initializes the object
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/oci/limits/models/create_quota_details.rb', line 90 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.description = attributes[:'description'] if attributes[:'description'] self.name = attributes[:'name'] if attributes[:'name'] self.statements = attributes[:'statements'] if attributes[:'statements'] self.locks = attributes[:'locks'] if attributes[:'locks'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The OCID of the compartment containing the resource this quota applies to.
12 13 14 |
# File 'lib/oci/limits/models/create_quota_details.rb', line 12 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `{"CostCenter": "42"}`
45 46 47 |
# File 'lib/oci/limits/models/create_quota_details.rb', line 45 def @defined_tags end |
#description ⇒ String
**[Required]** The description you assign to the quota.
16 17 18 |
# File 'lib/oci/limits/models/create_quota_details.rb', line 16 def description @description end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `"Finance"`
38 39 40 |
# File 'lib/oci/limits/models/create_quota_details.rb', line 38 def @freeform_tags end |
#locks ⇒ Array<OCI::Limits::Models::AddLockDetails>
Locks associated with this resource.
31 32 33 |
# File 'lib/oci/limits/models/create_quota_details.rb', line 31 def locks @locks end |
#name ⇒ String
**[Required]** The name you assign to the quota during creation. The name must be unique across all quotas in the tenancy and cannot be changed.
22 23 24 |
# File 'lib/oci/limits/models/create_quota_details.rb', line 22 def name @name end |
#statements ⇒ Array<String>
**[Required]** An array of quota statements written in the declarative quota statement language.
27 28 29 |
# File 'lib/oci/limits/models/create_quota_details.rb', line 27 def statements @statements end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/oci/limits/models/create_quota_details.rb', line 48 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'description': :'description', 'name': :'name', 'statements': :'statements', 'locks': :'locks', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/oci/limits/models/create_quota_details.rb', line 63 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'description': :'String', 'name': :'String', 'statements': :'Array<String>', 'locks': :'Array<OCI::Limits::Models::AddLockDetails>', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/oci/limits/models/create_quota_details.rb', line 130 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && description == other.description && name == other.name && statements == other.statements && locks == other.locks && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/oci/limits/models/create_quota_details.rb', line 166 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
146 147 148 |
# File 'lib/oci/limits/models/create_quota_details.rb', line 146 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
155 156 157 |
# File 'lib/oci/limits/models/create_quota_details.rb', line 155 def hash [compartment_id, description, name, statements, locks, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
199 200 201 202 203 204 205 206 207 208 |
# File 'lib/oci/limits/models/create_quota_details.rb', line 199 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
193 194 195 |
# File 'lib/oci/limits/models/create_quota_details.rb', line 193 def to_s to_hash.to_s end |