Method: OCI::LoadBalancer::Models::BackendHealth#status

Defined in:
lib/oci/load_balancer/models/backend_health.rb

#statusString

[Required] The general health status of the specified backend server as reported by the primary and standby load balancers.

  • OK: Both health checks returned OK.

  • WARNING: One health check returned OK and one did not.

  • CRITICAL: Neither health check returned OK.

  • UNKNOWN: One or both health checks returned UNKNOWN, or the system was unable to retrieve metrics at this time.

Returns:

  • (String)


30
31
32
# File 'lib/oci/load_balancer/models/backend_health.rb', line 30

def status
  @status
end