Class: OCI::LoadBalancer::Models::CreateBackendDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/load_balancer/models/create_backend_details.rb

Overview

The configuration details for creating a backend server in a backend set. For more information on backend server configuration, see [Managing Backend Servers](docs.cloud.oracle.com/Content/Balance/Tasks/managingbackendservers.htm).

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateBackendDetails

Initializes the object

Options Hash (attributes):

  • :ip_address (String)

    The value to assign to the #ip_address property

  • :port (Integer)

    The value to assign to the #port property

  • :weight (Integer)

    The value to assign to the #weight property

  • :backup (BOOLEAN)

    The value to assign to the #backup property

  • :drain (BOOLEAN)

    The value to assign to the #drain property

  • :offline (BOOLEAN)

    The value to assign to the #offline property

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/oci/load_balancer/models/create_backend_details.rb', line 104

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.ip_address = attributes[:'ipAddress'] if attributes[:'ipAddress']

  raise 'You cannot provide both :ipAddress and :ip_address' if attributes.key?(:'ipAddress') && attributes.key?(:'ip_address')

  self.ip_address = attributes[:'ip_address'] if attributes[:'ip_address']

  self.port = attributes[:'port'] if attributes[:'port']

  self.weight = attributes[:'weight'] if attributes[:'weight']

  self.backup = attributes[:'backup'] unless attributes[:'backup'].nil?
  self.backup = false if backup.nil? && !attributes.key?(:'backup') # rubocop:disable Style/StringLiterals

  self.drain = attributes[:'drain'] unless attributes[:'drain'].nil?
  self.drain = false if drain.nil? && !attributes.key?(:'drain') # rubocop:disable Style/StringLiterals

  self.offline = attributes[:'offline'] unless attributes[:'offline'].nil?
  self.offline = false if offline.nil? && !attributes.key?(:'offline') # rubocop:disable Style/StringLiterals
end

Instance Attribute Details

#backupBOOLEAN

Whether the load balancer should treat this server as a backup unit. If true, the load balancer forwards no ingress traffic to this backend server unless all other backend servers not marked as "backup" fail the health check policy.

Note: You cannot add a backend server marked as backup to a backend set that uses the IP Hash policy.

Example: false

Returns:



46
47
48
# File 'lib/oci/load_balancer/models/create_backend_details.rb', line 46

def backup
  @backup
end

#drainBOOLEAN

Whether the load balancer should drain this server. Servers marked "drain" receive no new incoming traffic.

Example: false

Returns:



54
55
56
# File 'lib/oci/load_balancer/models/create_backend_details.rb', line 54

def drain
  @drain
end

#ip_addressString

[Required] The IP address of the backend server.

Example: 10.0.0.3

Returns:



18
19
20
# File 'lib/oci/load_balancer/models/create_backend_details.rb', line 18

def ip_address
  @ip_address
end

#offlineBOOLEAN

Whether the load balancer should treat this server as offline. Offline servers receive no incoming traffic.

Example: false

Returns:



62
63
64
# File 'lib/oci/load_balancer/models/create_backend_details.rb', line 62

def offline
  @offline
end

#portInteger

[Required] The communication port for the backend server.

Example: 8080

Returns:



25
26
27
# File 'lib/oci/load_balancer/models/create_backend_details.rb', line 25

def port
  @port
end

#weightInteger

The load balancing policy weight assigned to the server. Backend servers with a higher weight receive a larger proportion of incoming traffic. For example, a server weighted ‘3’ receives 3 times the number of new connections as a server weighted ‘1’. For more information on load balancing policies, see [How Load Balancing Policies Work](docs.cloud.oracle.com/Content/Balance/Reference/lbpolicies.htm).

Example: 3

Returns:



36
37
38
# File 'lib/oci/load_balancer/models/create_backend_details.rb', line 36

def weight
  @weight
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/oci/load_balancer/models/create_backend_details.rb', line 65

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'ip_address': :'ipAddress',
    'port': :'port',
    'weight': :'weight',
    'backup': :'backup',
    'drain': :'drain',
    'offline': :'offline'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/oci/load_balancer/models/create_backend_details.rb', line 79

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'ip_address': :'String',
    'port': :'Integer',
    'weight': :'Integer',
    'backup': :'BOOLEAN',
    'drain': :'BOOLEAN',
    'offline': :'BOOLEAN'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • the other object to be compared



137
138
139
140
141
142
143
144
145
146
147
# File 'lib/oci/load_balancer/models/create_backend_details.rb', line 137

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    ip_address == other.ip_address &&
    port == other.port &&
    weight == other.weight &&
    backup == other.backup &&
    drain == other.drain &&
    offline == other.offline
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/oci/load_balancer/models/create_backend_details.rb', line 172

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method

Parameters:

  • the other object to be compared

Returns:



152
153
154
# File 'lib/oci/load_balancer/models/create_backend_details.rb', line 152

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • Hash code



161
162
163
# File 'lib/oci/load_balancer/models/create_backend_details.rb', line 161

def hash
  [ip_address, port, weight, backup, drain, offline].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



205
206
207
208
209
210
211
212
213
214
# File 'lib/oci/load_balancer/models/create_backend_details.rb', line 205

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



199
200
201
# File 'lib/oci/load_balancer/models/create_backend_details.rb', line 199

def to_s
  to_hash.to_s
end