Class: OCI::LoadBalancer::Models::CreateRoutingPolicyDetails
- Inherits:
-
Object
- Object
- OCI::LoadBalancer::Models::CreateRoutingPolicyDetails
- Defined in:
- lib/oci/load_balancer/models/create_routing_policy_details.rb
Overview
An ordered list of routing rules.
Warning: Oracle recommends that you avoid using any confidential information when you supply string values using the API.
Constant Summary collapse
- CONDITION_LANGUAGE_VERSION_ENUM =
[ CONDITION_LANGUAGE_VERSION_V1 = 'V1'.freeze ].freeze
Instance Attribute Summary collapse
-
#condition_language_version ⇒ String
[Required] The version of the language in which
conditionofrulesare composed. -
#name ⇒ String
[Required] The name for this list of routing rules.
-
#rules ⇒ Array<OCI::LoadBalancer::Models::RoutingRule>
[Required] The list of routing rules.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateRoutingPolicyDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateRoutingPolicyDetails
Initializes the object
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/oci/load_balancer/models/create_routing_policy_details.rb', line 65 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.condition_language_version = attributes[:'conditionLanguageVersion'] if attributes[:'conditionLanguageVersion'] raise 'You cannot provide both :conditionLanguageVersion and :condition_language_version' if attributes.key?(:'conditionLanguageVersion') && attributes.key?(:'condition_language_version') self.condition_language_version = attributes[:'condition_language_version'] if attributes[:'condition_language_version'] self.rules = attributes[:'rules'] if attributes[:'rules'] end |
Instance Attribute Details
#condition_language_version ⇒ String
[Required] The version of the language in which condition of rules are composed.
28 29 30 |
# File 'lib/oci/load_balancer/models/create_routing_policy_details.rb', line 28 def condition_language_version @condition_language_version end |
#name ⇒ String
[Required] The name for this list of routing rules. It must be unique and it cannot be changed. Avoid entering confidential information.
Example: example_routing_rules
23 24 25 |
# File 'lib/oci/load_balancer/models/create_routing_policy_details.rb', line 23 def name @name end |
#rules ⇒ Array<OCI::LoadBalancer::Models::RoutingRule>
[Required] The list of routing rules.
32 33 34 |
# File 'lib/oci/load_balancer/models/create_routing_policy_details.rb', line 32 def rules @rules end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 |
# File 'lib/oci/load_balancer/models/create_routing_policy_details.rb', line 35 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'condition_language_version': :'conditionLanguageVersion', 'rules': :'rules' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
46 47 48 49 50 51 52 53 54 |
# File 'lib/oci/load_balancer/models/create_routing_policy_details.rb', line 46 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'condition_language_version': :'String', 'rules': :'Array<OCI::LoadBalancer::Models::RoutingRule>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
97 98 99 100 101 102 103 104 |
# File 'lib/oci/load_balancer/models/create_routing_policy_details.rb', line 97 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && condition_language_version == other.condition_language_version && rules == other.rules end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/oci/load_balancer/models/create_routing_policy_details.rb', line 129 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
109 110 111 |
# File 'lib/oci/load_balancer/models/create_routing_policy_details.rb', line 109 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
118 119 120 |
# File 'lib/oci/load_balancer/models/create_routing_policy_details.rb', line 118 def hash [name, condition_language_version, rules].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
162 163 164 165 166 167 168 169 170 171 |
# File 'lib/oci/load_balancer/models/create_routing_policy_details.rb', line 162 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
156 157 158 |
# File 'lib/oci/load_balancer/models/create_routing_policy_details.rb', line 156 def to_s to_hash.to_s end |