Class: OCI::LoadBalancer::Models::IpAddress

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/load_balancer/models/ip_address.rb

Overview

A load balancer IP address.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ IpAddress

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/oci/load_balancer/models/ip_address.rb', line 60

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.ip_address = attributes[:'ipAddress'] if attributes[:'ipAddress']

  raise 'You cannot provide both :ipAddress and :ip_address' if attributes.key?(:'ipAddress') && attributes.key?(:'ip_address')

  self.ip_address = attributes[:'ip_address'] if attributes[:'ip_address']

  self.is_public = attributes[:'isPublic'] unless attributes[:'isPublic'].nil?

  raise 'You cannot provide both :isPublic and :is_public' if attributes.key?(:'isPublic') && attributes.key?(:'is_public')

  self.is_public = attributes[:'is_public'] unless attributes[:'is_public'].nil?

  self.reserved_ip = attributes[:'reservedIp'] if attributes[:'reservedIp']

  raise 'You cannot provide both :reservedIp and :reserved_ip' if attributes.key?(:'reservedIp') && attributes.key?(:'reserved_ip')

  self.reserved_ip = attributes[:'reserved_ip'] if attributes[:'reserved_ip']
end

Instance Attribute Details

#ip_addressString

[Required] An IP address.

Example: 192.168.0.3

Returns:

  • (String)


15
16
17
# File 'lib/oci/load_balancer/models/ip_address.rb', line 15

def ip_address
  @ip_address
end

#is_publicBOOLEAN

Whether the IP address is public or private.

If "true", the IP address is public and accessible from the internet.

If "false", the IP address is private and accessible only from within the associated VCN.

Returns:

  • (BOOLEAN)


24
25
26
# File 'lib/oci/load_balancer/models/ip_address.rb', line 24

def is_public
  @is_public
end

#reserved_ipOCI::LoadBalancer::Models::ReservedIP



27
28
29
# File 'lib/oci/load_balancer/models/ip_address.rb', line 27

def reserved_ip
  @reserved_ip
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



30
31
32
33
34
35
36
37
38
# File 'lib/oci/load_balancer/models/ip_address.rb', line 30

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'ip_address': :'ipAddress',
    'is_public': :'isPublic',
    'reserved_ip': :'reservedIp'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



41
42
43
44
45
46
47
48
49
# File 'lib/oci/load_balancer/models/ip_address.rb', line 41

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'ip_address': :'String',
    'is_public': :'BOOLEAN',
    'reserved_ip': :'OCI::LoadBalancer::Models::ReservedIP'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



92
93
94
95
96
97
98
99
# File 'lib/oci/load_balancer/models/ip_address.rb', line 92

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    ip_address == other.ip_address &&
    is_public == other.is_public &&
    reserved_ip == other.reserved_ip
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/oci/load_balancer/models/ip_address.rb', line 124

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


104
105
106
# File 'lib/oci/load_balancer/models/ip_address.rb', line 104

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



113
114
115
# File 'lib/oci/load_balancer/models/ip_address.rb', line 113

def hash
  [ip_address, is_public, reserved_ip].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



157
158
159
160
161
162
163
164
165
166
# File 'lib/oci/load_balancer/models/ip_address.rb', line 157

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



151
152
153
# File 'lib/oci/load_balancer/models/ip_address.rb', line 151

def to_s
  to_hash.to_s
end