Class: OCI::LoadBalancer::Models::LoadBalancer

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/load_balancer/models/load_balancer.rb

Overview

The properties that define a load balancer. For more information, see [Managing a Load Balancer](docs.cloud.oracle.com/Content/Balance/Tasks/managingloadbalancer.htm).

To use any of the API operations, you must be authorized in an IAM policy. If you're not authorized, talk to an administrator. If you're an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm).

For information about endpoints and signing API requests, see [About the API](docs.cloud.oracle.com/Content/API/Concepts/usingapi.htm). For information about available SDKs and tools, see [SDKS and Other Tools](docs.cloud.oracle.com/Content/API/Concepts/sdks.htm).

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ LoadBalancer

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 247

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.ip_addresses = attributes[:'ipAddresses'] if attributes[:'ipAddresses']

  raise 'You cannot provide both :ipAddresses and :ip_addresses' if attributes.key?(:'ipAddresses') && attributes.key?(:'ip_addresses')

  self.ip_addresses = attributes[:'ip_addresses'] if attributes[:'ip_addresses']

  self.shape_name = attributes[:'shapeName'] if attributes[:'shapeName']

  raise 'You cannot provide both :shapeName and :shape_name' if attributes.key?(:'shapeName') && attributes.key?(:'shape_name')

  self.shape_name = attributes[:'shape_name'] if attributes[:'shape_name']

  self.shape_details = attributes[:'shapeDetails'] if attributes[:'shapeDetails']

  raise 'You cannot provide both :shapeDetails and :shape_details' if attributes.key?(:'shapeDetails') && attributes.key?(:'shape_details')

  self.shape_details = attributes[:'shape_details'] if attributes[:'shape_details']

  self.is_private = attributes[:'isPrivate'] unless attributes[:'isPrivate'].nil?

  raise 'You cannot provide both :isPrivate and :is_private' if attributes.key?(:'isPrivate') && attributes.key?(:'is_private')

  self.is_private = attributes[:'is_private'] unless attributes[:'is_private'].nil?

  self.subnet_ids = attributes[:'subnetIds'] if attributes[:'subnetIds']

  raise 'You cannot provide both :subnetIds and :subnet_ids' if attributes.key?(:'subnetIds') && attributes.key?(:'subnet_ids')

  self.subnet_ids = attributes[:'subnet_ids'] if attributes[:'subnet_ids']

  self.network_security_group_ids = attributes[:'networkSecurityGroupIds'] if attributes[:'networkSecurityGroupIds']

  raise 'You cannot provide both :networkSecurityGroupIds and :network_security_group_ids' if attributes.key?(:'networkSecurityGroupIds') && attributes.key?(:'network_security_group_ids')

  self.network_security_group_ids = attributes[:'network_security_group_ids'] if attributes[:'network_security_group_ids']

  self.listeners = attributes[:'listeners'] if attributes[:'listeners']

  self.hostnames = attributes[:'hostnames'] if attributes[:'hostnames']

  self.ssl_cipher_suites = attributes[:'sslCipherSuites'] if attributes[:'sslCipherSuites']

  raise 'You cannot provide both :sslCipherSuites and :ssl_cipher_suites' if attributes.key?(:'sslCipherSuites') && attributes.key?(:'ssl_cipher_suites')

  self.ssl_cipher_suites = attributes[:'ssl_cipher_suites'] if attributes[:'ssl_cipher_suites']

  self.certificates = attributes[:'certificates'] if attributes[:'certificates']

  self.backend_sets = attributes[:'backendSets'] if attributes[:'backendSets']

  raise 'You cannot provide both :backendSets and :backend_sets' if attributes.key?(:'backendSets') && attributes.key?(:'backend_sets')

  self.backend_sets = attributes[:'backend_sets'] if attributes[:'backend_sets']

  self.path_route_sets = attributes[:'pathRouteSets'] if attributes[:'pathRouteSets']

  raise 'You cannot provide both :pathRouteSets and :path_route_sets' if attributes.key?(:'pathRouteSets') && attributes.key?(:'path_route_sets')

  self.path_route_sets = attributes[:'path_route_sets'] if attributes[:'path_route_sets']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

  raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

  self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']

  self.rule_sets = attributes[:'ruleSets'] if attributes[:'ruleSets']

  raise 'You cannot provide both :ruleSets and :rule_sets' if attributes.key?(:'ruleSets') && attributes.key?(:'rule_sets')

  self.rule_sets = attributes[:'rule_sets'] if attributes[:'rule_sets']

  self.routing_policies = attributes[:'routingPolicies'] if attributes[:'routingPolicies']

  raise 'You cannot provide both :routingPolicies and :routing_policies' if attributes.key?(:'routingPolicies') && attributes.key?(:'routing_policies')

  self.routing_policies = attributes[:'routing_policies'] if attributes[:'routing_policies']
end

Instance Attribute Details

#backend_setsHash<String, OCI::LoadBalancer::Models::BackendSet>

Returns:



123
124
125
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 123

def backend_sets
  @backend_sets
end

#certificatesHash<String, OCI::LoadBalancer::Models::Certificate>

Returns:



120
121
122
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 120

def certificates
  @certificates
end

#compartment_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment containing the load balancer.

Returns:

  • (String)


36
37
38
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 36

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: `{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


142
143
144
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 142

def defined_tags
  @defined_tags
end

#display_nameString

**[Required]** A user-friendly name. It does not have to be unique, and it is changeable.

Example: `example_load_balancer`

Returns:

  • (String)


43
44
45
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 43

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: `"Finance"`

Returns:

  • (Hash<String, String>)


134
135
136
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 134

def freeform_tags
  @freeform_tags
end

#hostnamesHash<String, OCI::LoadBalancer::Models::Hostname>

Returns:



114
115
116
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 114

def hostnames
  @hostnames
end

#idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the load balancer.

Returns:

  • (String)


32
33
34
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 32

def id
  @id
end

#ip_addressesArray<OCI::LoadBalancer::Models::IpAddress>

An array of IP addresses.



60
61
62
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 60

def ip_addresses
  @ip_addresses
end

#is_privateBOOLEAN

Whether the load balancer has a VCN-local (private) IP address.

If "true", the service assigns a private IP address to the load balancer.

If "false", the service assigns a public IP address to the load balancer.

A public load balancer is accessible from the internet, depending on your VCN's [security list rules](docs.cloud.oracle.com/Content/Network/Concepts/securitylists.htm). For more information about public and private load balancers, see [How Load Balancing Works](docs.cloud.oracle.com/Content/Balance/Concepts/balanceoverview.htm#how-load-balancing-works).

Example: `true`

Returns:

  • (BOOLEAN)


87
88
89
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 87

def is_private
  @is_private
end

#lifecycle_stateString

**[Required]** The current state of the load balancer.

Returns:

  • (String)


48
49
50
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 48

def lifecycle_state
  @lifecycle_state
end

#listenersHash<String, OCI::LoadBalancer::Models::Listener>

Returns:



111
112
113
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 111

def listeners
  @listeners
end

#network_security_group_idsArray<String>

An array of NSG [OCIDs](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) associated with the load balancer.

During the load balancer's creation, the service adds the new load balancer to the specified NSGs.

The benefits of associating the load balancer with NSGs include:

  • NSGs define network security rules to govern ingress and egress traffic for the load balancer.

  • The network security rules of other resources can reference the NSGs associated with the load balancer to ensure access.

Example: ["ocid1.nsg.oc1.phx.unique_ID"]

Returns:

  • (Array<String>)


108
109
110
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 108

def network_security_group_ids
  @network_security_group_ids
end

#path_route_setsHash<String, OCI::LoadBalancer::Models::PathRouteSet>

Returns:



126
127
128
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 126

def path_route_sets
  @path_route_sets
end

#routing_policiesHash<String, OCI::LoadBalancer::Models::RoutingPolicy>

Returns:



157
158
159
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 157

def routing_policies
  @routing_policies
end

#rule_setsHash<String, OCI::LoadBalancer::Models::RuleSet>

Returns:



154
155
156
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 154

def rule_sets
  @rule_sets
end

#shape_detailsOCI::LoadBalancer::Models::ShapeDetails



72
73
74
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 72

def shape_details
  @shape_details
end

#shape_nameString

**[Required]** A template that determines the total pre-provisioned bandwidth (ingress plus egress). To get a list of available shapes, use the list_shapes operation.

Example: `100Mbps`

Returns:

  • (String)


69
70
71
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 69

def shape_name
  @shape_name
end

#ssl_cipher_suitesHash<String, OCI::LoadBalancer::Models::SSLCipherSuite>



117
118
119
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 117

def ssl_cipher_suites
  @ssl_cipher_suites
end

#subnet_idsArray<String>

Returns:

  • (Array<String>)


91
92
93
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 91

def subnet_ids
  @subnet_ids
end

#system_tagsHash<String, Hash<String, Object>>

System tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). System tags can be viewed by users, but can only be created by the system.

Example: `{"free-tier-retained": "true"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


151
152
153
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 151

def system_tags
  @system_tags
end

#time_createdDateTime

**[Required]** The date and time the load balancer was created, in the format defined by RFC3339.

Example: `2016-08-25T21:10:29.600Z`

Returns:

  • (DateTime)


55
56
57
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 55

def time_created
  @time_created
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 160

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'compartment_id': :'compartmentId',
    'display_name': :'displayName',
    'lifecycle_state': :'lifecycleState',
    'time_created': :'timeCreated',
    'ip_addresses': :'ipAddresses',
    'shape_name': :'shapeName',
    'shape_details': :'shapeDetails',
    'is_private': :'isPrivate',
    'subnet_ids': :'subnetIds',
    'network_security_group_ids': :'networkSecurityGroupIds',
    'listeners': :'listeners',
    'hostnames': :'hostnames',
    'ssl_cipher_suites': :'sslCipherSuites',
    'certificates': :'certificates',
    'backend_sets': :'backendSets',
    'path_route_sets': :'pathRouteSets',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags',
    'rule_sets': :'ruleSets',
    'routing_policies': :'routingPolicies'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 190

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'compartment_id': :'String',
    'display_name': :'String',
    'lifecycle_state': :'String',
    'time_created': :'DateTime',
    'ip_addresses': :'Array<OCI::LoadBalancer::Models::IpAddress>',
    'shape_name': :'String',
    'shape_details': :'OCI::LoadBalancer::Models::ShapeDetails',
    'is_private': :'BOOLEAN',
    'subnet_ids': :'Array<String>',
    'network_security_group_ids': :'Array<String>',
    'listeners': :'Hash<String, OCI::LoadBalancer::Models::Listener>',
    'hostnames': :'Hash<String, OCI::LoadBalancer::Models::Hostname>',
    'ssl_cipher_suites': :'Hash<String, OCI::LoadBalancer::Models::SSLCipherSuite>',
    'certificates': :'Hash<String, OCI::LoadBalancer::Models::Certificate>',
    'backend_sets': :'Hash<String, OCI::LoadBalancer::Models::BackendSet>',
    'path_route_sets': :'Hash<String, OCI::LoadBalancer::Models::PathRouteSet>',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>',
    'rule_sets': :'Hash<String, OCI::LoadBalancer::Models::RuleSet>',
    'routing_policies': :'Hash<String, OCI::LoadBalancer::Models::RoutingPolicy>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 390

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    display_name == other.display_name &&
    lifecycle_state == other.lifecycle_state &&
    time_created == other.time_created &&
    ip_addresses == other.ip_addresses &&
    shape_name == other.shape_name &&
    shape_details == other.shape_details &&
    is_private == other.is_private &&
    subnet_ids == other.subnet_ids &&
    network_security_group_ids == other.network_security_group_ids &&
    listeners == other.listeners &&
    hostnames == other.hostnames &&
    ssl_cipher_suites == other.ssl_cipher_suites &&
    certificates == other.certificates &&
    backend_sets == other.backend_sets &&
    path_route_sets == other.path_route_sets &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags &&
    rule_sets == other.rule_sets &&
    routing_policies == other.routing_policies
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 441

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


421
422
423
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 421

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



430
431
432
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 430

def hash
  [id, compartment_id, display_name, lifecycle_state, time_created, ip_addresses, shape_name, shape_details, is_private, subnet_ids, network_security_group_ids, listeners, hostnames, ssl_cipher_suites, certificates, backend_sets, path_route_sets, freeform_tags, defined_tags, system_tags, rule_sets, routing_policies].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



474
475
476
477
478
479
480
481
482
483
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 474

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



468
469
470
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 468

def to_s
  to_hash.to_s
end