Class: OCI::LoadBalancer::Models::RedirectRule
- Inherits:
-
LoadBalancer::Models::Rule
- Object
- LoadBalancer::Models::Rule
- OCI::LoadBalancer::Models::RedirectRule
- Defined in:
- lib/oci/load_balancer/models/redirect_rule.rb
Overview
An object that represents the action of returning a specified response code and a redirect URI. Each RedirectRule object is configured for a particular listener and a designated path.
The default response code is ‘302 Found`.
NOTES:
-
This rule applies only to HTTP listeners.
-
You can specify this rule only with the rule_condition type
PATH. -
A listener can have only one RedirectRule object for a given original path. The
{#path_match_condition path_match_condition} `attributeValue` specifies the
original path.
Instance Attribute Summary collapse
-
#conditions ⇒ Array<OCI::LoadBalancer::Models::RuleCondition>
This attribute is required.
- #redirect_uri ⇒ OCI::LoadBalancer::Models::RedirectUri
-
#response_code ⇒ Integer
The HTTP status code to return when the incoming request is redirected.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RedirectRule
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ RedirectRule
Initializes the object
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/oci/load_balancer/models/redirect_rule.rb', line 80 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['action'] = 'REDIRECT' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.response_code = attributes[:'responseCode'] if attributes[:'responseCode'] self.response_code = 302 if response_code.nil? && !attributes.key?(:'responseCode') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :responseCode and :response_code' if attributes.key?(:'responseCode') && attributes.key?(:'response_code') self.response_code = attributes[:'response_code'] if attributes[:'response_code'] self.response_code = 302 if response_code.nil? && !attributes.key?(:'responseCode') && !attributes.key?(:'response_code') # rubocop:disable Style/StringLiterals self.conditions = attributes[:'conditions'] if attributes[:'conditions'] self.redirect_uri = attributes[:'redirectUri'] if attributes[:'redirectUri'] raise 'You cannot provide both :redirectUri and :redirect_uri' if attributes.key?(:'redirectUri') && attributes.key?(:'redirect_uri') self.redirect_uri = attributes[:'redirect_uri'] if attributes[:'redirect_uri'] end |
Instance Attribute Details
#conditions ⇒ Array<OCI::LoadBalancer::Models::RuleCondition>
This attribute is required.
42 43 44 |
# File 'lib/oci/load_balancer/models/redirect_rule.rb', line 42 def conditions @conditions end |
#redirect_uri ⇒ OCI::LoadBalancer::Models::RedirectUri
45 46 47 |
# File 'lib/oci/load_balancer/models/redirect_rule.rb', line 45 def redirect_uri @redirect_uri end |
#response_code ⇒ Integer
The HTTP status code to return when the incoming request is redirected.
The status line returned with the code is mapped from the standard HTTP specification. Valid response codes for redirection are:
-
301
-
302
-
303
-
307
-
308
The default value is 302 (Found).
Example: 301
38 39 40 |
# File 'lib/oci/load_balancer/models/redirect_rule.rb', line 38 def response_code @response_code end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
48 49 50 51 52 53 54 55 56 57 |
# File 'lib/oci/load_balancer/models/redirect_rule.rb', line 48 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'action': :'action', 'response_code': :'responseCode', 'conditions': :'conditions', 'redirect_uri': :'redirectUri' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
60 61 62 63 64 65 66 67 68 69 |
# File 'lib/oci/load_balancer/models/redirect_rule.rb', line 60 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'action': :'String', 'response_code': :'Integer', 'conditions': :'Array<OCI::LoadBalancer::Models::RuleCondition>', 'redirect_uri': :'OCI::LoadBalancer::Models::RedirectUri' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
114 115 116 117 118 119 120 121 122 |
# File 'lib/oci/load_balancer/models/redirect_rule.rb', line 114 def ==(other) return true if equal?(other) self.class == other.class && action == other.action && response_code == other.response_code && conditions == other.conditions && redirect_uri == other.redirect_uri end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/oci/load_balancer/models/redirect_rule.rb', line 147 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
127 128 129 |
# File 'lib/oci/load_balancer/models/redirect_rule.rb', line 127 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
136 137 138 |
# File 'lib/oci/load_balancer/models/redirect_rule.rb', line 136 def hash [action, response_code, conditions, redirect_uri].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
180 181 182 183 184 185 186 187 188 189 |
# File 'lib/oci/load_balancer/models/redirect_rule.rb', line 180 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
174 175 176 |
# File 'lib/oci/load_balancer/models/redirect_rule.rb', line 174 def to_s to_hash.to_s end |