Class: OCI::LoadBalancer::Models::RoutingRule
- Inherits:
-
Object
- Object
- OCI::LoadBalancer::Models::RoutingRule
- Defined in:
- lib/oci/load_balancer/models/routing_rule.rb
Overview
A routing rule examines an incoming request, routing matching requests to the specified backend set. Routing rules apply only to HTTP and HTTPS requests. They have no effect on TCP requests.
Instance Attribute Summary collapse
-
#actions ⇒ Array<OCI::LoadBalancer::Models::Action>
[Required] A list of actions to be applied when conditions of the routing rule are met.
-
#condition ⇒ String
[Required] A routing rule to evaluate defined conditions against the incoming HTTP request and perform an action.
-
#name ⇒ String
[Required] A unique name for the routing policy rule.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RoutingRule
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ RoutingRule
Initializes the object
58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/oci/load_balancer/models/routing_rule.rb', line 58 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.condition = attributes[:'condition'] if attributes[:'condition'] self.actions = attributes[:'actions'] if attributes[:'actions'] end |
Instance Attribute Details
#actions ⇒ Array<OCI::LoadBalancer::Models::Action>
[Required] A list of actions to be applied when conditions of the routing rule are met.
25 26 27 |
# File 'lib/oci/load_balancer/models/routing_rule.rb', line 25 def actions @actions end |
#condition ⇒ String
[Required] A routing rule to evaluate defined conditions against the incoming HTTP request and perform an action.
20 21 22 |
# File 'lib/oci/load_balancer/models/routing_rule.rb', line 20 def condition @condition end |
#name ⇒ String
[Required] A unique name for the routing policy rule. Avoid entering confidential information.
15 16 17 |
# File 'lib/oci/load_balancer/models/routing_rule.rb', line 15 def name @name end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 35 36 |
# File 'lib/oci/load_balancer/models/routing_rule.rb', line 28 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'condition': :'condition', 'actions': :'actions' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
39 40 41 42 43 44 45 46 47 |
# File 'lib/oci/load_balancer/models/routing_rule.rb', line 39 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'condition': :'String', 'actions': :'Array<OCI::LoadBalancer::Models::Action>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
78 79 80 81 82 83 84 85 |
# File 'lib/oci/load_balancer/models/routing_rule.rb', line 78 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && condition == other.condition && actions == other.actions end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/oci/load_balancer/models/routing_rule.rb', line 110 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
90 91 92 |
# File 'lib/oci/load_balancer/models/routing_rule.rb', line 90 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
99 100 101 |
# File 'lib/oci/load_balancer/models/routing_rule.rb', line 99 def hash [name, condition, actions].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
143 144 145 146 147 148 149 150 151 152 |
# File 'lib/oci/load_balancer/models/routing_rule.rb', line 143 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
137 138 139 |
# File 'lib/oci/load_balancer/models/routing_rule.rb', line 137 def to_s to_hash.to_s end |