Class: OCI::LoadBalancer::Models::UpdateSSLCipherSuiteDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/load_balancer/models/update_ssl_cipher_suite_details.rb

Overview

The configuration details for updating an SSL cipher suite.

Warning: Oracle recommends that you avoid using any confidential information when you supply string values using the API.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateSSLCipherSuiteDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :ciphers (Array<String>)

    The value to assign to the #ciphers property



148
149
150
151
152
153
154
155
# File 'lib/oci/load_balancer/models/update_ssl_cipher_suite_details.rb', line 148

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.ciphers = attributes[:'ciphers'] if attributes[:'ciphers']
end

Instance Attribute Details

#ciphersArray<String>

[Required] A list of SSL ciphers the load balancer must support for HTTPS or SSL connections.

The following ciphers are valid values for this property:

  • __TLSv1.2 ciphers__

    \"AES128-GCM-SHA256\"
    \"AES128-SHA256\"
    \"AES256-GCM-SHA384\"
    \"AES256-SHA256\"
    \"DH-DSS-AES128-GCM-SHA256\"
    \"DH-DSS-AES128-SHA256\"
    \"DH-DSS-AES256-GCM-SHA384\"
    \"DH-DSS-AES256-SHA256\"
    \"DH-RSA-AES128-GCM-SHA256\"
    \"DH-RSA-AES128-SHA256\"
    \"DH-RSA-AES256-GCM-SHA384\"
    \"DH-RSA-AES256-SHA256\"
    \"DHE-DSS-AES128-GCM-SHA256\"
    \"DHE-DSS-AES128-SHA256\"
    \"DHE-DSS-AES256-GCM-SHA384\"
    \"DHE-DSS-AES256-SHA256\"
    \"DHE-RSA-AES128-GCM-SHA256\"
    \"DHE-RSA-AES128-SHA256\"
    \"DHE-RSA-AES256-GCM-SHA384\"
    \"DHE-RSA-AES256-SHA256\"
    \"ECDH-ECDSA-AES128-GCM-SHA256\"
    \"ECDH-ECDSA-AES128-SHA256\"
    \"ECDH-ECDSA-AES256-GCM-SHA384\"
    \"ECDH-ECDSA-AES256-SHA384\"
    \"ECDH-RSA-AES128-GCM-SHA256\"
    \"ECDH-RSA-AES128-SHA256\"
    \"ECDH-RSA-AES256-GCM-SHA384\"
    \"ECDH-RSA-AES256-SHA384\"
    \"ECDHE-ECDSA-AES128-GCM-SHA256\"
    \"ECDHE-ECDSA-AES128-SHA256\"
    \"ECDHE-ECDSA-AES256-GCM-SHA384\"
    \"ECDHE-ECDSA-AES256-SHA384\"
    \"ECDHE-RSA-AES128-GCM-SHA256\"
    \"ECDHE-RSA-AES128-SHA256\"
    \"ECDHE-RSA-AES256-GCM-SHA384\"
    \"ECDHE-RSA-AES256-SHA384\"
    
  • __TLSv1 ciphers also supported by TLSv1.2__

    \"AES128-SHA\"
    \"AES256-SHA\"
    \"CAMELLIA128-SHA\"
    \"CAMELLIA256-SHA\"
    \"DES-CBC3-SHA\"
    \"DH-DSS-AES128-SHA\"
    \"DH-DSS-AES256-SHA\"
    \"DH-DSS-CAMELLIA128-SHA\"
    \"DH-DSS-CAMELLIA256-SHA\"
    \"DH-DSS-DES-CBC3-SHAv\"
    \"DH-DSS-SEED-SHA\"
    \"DH-RSA-AES128-SHA\"
    \"DH-RSA-AES256-SHA\"
    \"DH-RSA-CAMELLIA128-SHA\"
    \"DH-RSA-CAMELLIA256-SHA\"
    \"DH-RSA-DES-CBC3-SHA\"
    \"DH-RSA-SEED-SHA\"
    \"DHE-DSS-AES128-SHA\"
    \"DHE-DSS-AES256-SHA\"
    \"DHE-DSS-CAMELLIA128-SHA\"
    \"DHE-DSS-CAMELLIA256-SHA\"
    \"DHE-DSS-DES-CBC3-SHA\"
    \"DHE-DSS-SEED-SHA\"
    \"DHE-RSA-AES128-SHA\"
    \"DHE-RSA-AES256-SHA\"
    \"DHE-RSA-CAMELLIA128-SHA\"
    \"DHE-RSA-CAMELLIA256-SHA\"
    \"DHE-RSA-DES-CBC3-SHA\"
    \"DHE-RSA-SEED-SHA\"
    \"ECDH-ECDSA-AES128-SHA\"
    \"ECDH-ECDSA-AES256-SHA\"
    \"ECDH-ECDSA-DES-CBC3-SHA\"
    \"ECDH-ECDSA-RC4-SHA\"
    \"ECDH-RSA-AES128-SHA\"
    \"ECDH-RSA-AES256-SHA\"
    \"ECDH-RSA-DES-CBC3-SHA\"
    \"ECDH-RSA-RC4-SHA\"
    \"ECDHE-ECDSA-AES128-SHA\"
    \"ECDHE-ECDSA-AES256-SHA\"
    \"ECDHE-ECDSA-DES-CBC3-SHA\"
    \"ECDHE-ECDSA-RC4-SHA\"
    \"ECDHE-RSA-AES128-SHA\"
    \"ECDHE-RSA-AES256-SHA\"
    \"ECDHE-RSA-DES-CBC3-SHA\"
    \"ECDHE-RSA-RC4-SHA\"
    \"IDEA-CBC-SHA\"
    \"KRB5-DES-CBC3-MD5\"
    \"KRB5-DES-CBC3-SHA\"
    \"KRB5-IDEA-CBC-MD5\"
    \"KRB5-IDEA-CBC-SHA\"
    \"KRB5-RC4-MD5\"
    \"KRB5-RC4-SHA\"
    \"PSK-3DES-EDE-CBC-SHA\"
    \"PSK-AES128-CBC-SHA\"
    \"PSK-AES256-CBC-SHA\"
    \"PSK-RC4-SHA\"
    \"RC4-MD5\"
    \"RC4-SHA\"
    \"SEED-SHA\"
    

example: ‘["ECDHE-RSA-AES256-GCM-SHA384","ECDHE-ECDSA-AES256-GCM-SHA384","ECDHE-RSA-AES128-GCM-SHA256"]`

Returns:

  • (Array<String>)


121
122
123
# File 'lib/oci/load_balancer/models/update_ssl_cipher_suite_details.rb', line 121

def ciphers
  @ciphers
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



124
125
126
127
128
129
130
# File 'lib/oci/load_balancer/models/update_ssl_cipher_suite_details.rb', line 124

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'ciphers': :'ciphers'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



133
134
135
136
137
138
139
# File 'lib/oci/load_balancer/models/update_ssl_cipher_suite_details.rb', line 133

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'ciphers': :'Array<String>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



164
165
166
167
168
169
# File 'lib/oci/load_balancer/models/update_ssl_cipher_suite_details.rb', line 164

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    ciphers == other.ciphers
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/oci/load_balancer/models/update_ssl_cipher_suite_details.rb', line 194

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


174
175
176
# File 'lib/oci/load_balancer/models/update_ssl_cipher_suite_details.rb', line 174

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



183
184
185
# File 'lib/oci/load_balancer/models/update_ssl_cipher_suite_details.rb', line 183

def hash
  [ciphers].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



227
228
229
230
231
232
233
234
235
236
# File 'lib/oci/load_balancer/models/update_ssl_cipher_suite_details.rb', line 227

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



221
222
223
# File 'lib/oci/load_balancer/models/update_ssl_cipher_suite_details.rb', line 221

def to_s
  to_hash.to_s
end