Class: OCI::LoadBalancer::Models::WorkRequest
- Inherits:
-
Object
- Object
- OCI::LoadBalancer::Models::WorkRequest
- Defined in:
- lib/oci/load_balancer/models/work_request.rb
Overview
Many of the API requests you use to create and configure load balancing do not take effect immediately. In these cases, the request spawns an asynchronous work flow to fulfill the request. WorkRequest objects provide visibility for in-progress work flows. For more information about work requests, see [Viewing the State of a Work Request](docs.cloud.oracle.com/Content/Balance/Tasks/viewingworkrequest.htm).
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_ACCEPTED = 'ACCEPTED'.freeze, LIFECYCLE_STATE_IN_PROGRESS = 'IN_PROGRESS'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_SUCCEEDED = 'SUCCEEDED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment containing the load balancer.
-
#error_details ⇒ Array<OCI::LoadBalancer::Models::WorkRequestError>
This attribute is required.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the work request.
-
#lifecycle_state ⇒ String
[Required] The current state of the work request.
-
#load_balancer_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the load balancer with which the work request is associated.
-
#message ⇒ String
[Required] A collection of data, related to the load balancer provisioning process, that helps with debugging in the event of failure.
-
#time_accepted ⇒ DateTime
[Required] The date and time the work request was created, in the format defined by RFC3339.
-
#time_finished ⇒ DateTime
The date and time the work request was completed, in the format defined by RFC3339.
-
#type ⇒ String
[Required] The type of action the work request represents.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WorkRequest
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ WorkRequest
Initializes the object
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/oci/load_balancer/models/work_request.rb', line 128 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.load_balancer_id = attributes[:'loadBalancerId'] if attributes[:'loadBalancerId'] raise 'You cannot provide both :loadBalancerId and :load_balancer_id' if attributes.key?(:'loadBalancerId') && attributes.key?(:'load_balancer_id') self.load_balancer_id = attributes[:'load_balancer_id'] if attributes[:'load_balancer_id'] self.type = attributes[:'type'] if attributes[:'type'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self. = attributes[:'message'] if attributes[:'message'] self.time_accepted = attributes[:'timeAccepted'] if attributes[:'timeAccepted'] raise 'You cannot provide both :timeAccepted and :time_accepted' if attributes.key?(:'timeAccepted') && attributes.key?(:'time_accepted') self.time_accepted = attributes[:'time_accepted'] if attributes[:'time_accepted'] self.time_finished = attributes[:'timeFinished'] if attributes[:'timeFinished'] raise 'You cannot provide both :timeFinished and :time_finished' if attributes.key?(:'timeFinished') && attributes.key?(:'time_finished') self.time_finished = attributes[:'time_finished'] if attributes[:'time_finished'] self.error_details = attributes[:'errorDetails'] if attributes[:'errorDetails'] raise 'You cannot provide both :errorDetails and :error_details' if attributes.key?(:'errorDetails') && attributes.key?(:'error_details') self.error_details = attributes[:'error_details'] if attributes[:'error_details'] end |
Instance Attribute Details
#compartment_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment containing the load balancer.
42 43 44 |
# File 'lib/oci/load_balancer/models/work_request.rb', line 42 def compartment_id @compartment_id end |
#error_details ⇒ Array<OCI::LoadBalancer::Models::WorkRequestError>
This attribute is required.
77 78 79 |
# File 'lib/oci/load_balancer/models/work_request.rb', line 77 def error_details @error_details end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the work request.
25 26 27 |
# File 'lib/oci/load_balancer/models/work_request.rb', line 25 def id @id end |
#lifecycle_state ⇒ String
[Required] The current state of the work request.
47 48 49 |
# File 'lib/oci/load_balancer/models/work_request.rb', line 47 def lifecycle_state @lifecycle_state end |
#load_balancer_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the load balancer with which the work request is associated.
31 32 33 |
# File 'lib/oci/load_balancer/models/work_request.rb', line 31 def load_balancer_id @load_balancer_id end |
#message ⇒ String
[Required] A collection of data, related to the load balancer provisioning process, that helps with debugging in the event of failure. Possible data elements include:
-
workflow name
-
event ID
-
work request ID
-
load balancer ID
-
workflow completion message
59 60 61 |
# File 'lib/oci/load_balancer/models/work_request.rb', line 59 def end |
#time_accepted ⇒ DateTime
[Required] The date and time the work request was created, in the format defined by RFC3339.
Example: 2016-08-25T21:10:29.600Z
66 67 68 |
# File 'lib/oci/load_balancer/models/work_request.rb', line 66 def time_accepted @time_accepted end |
#time_finished ⇒ DateTime
The date and time the work request was completed, in the format defined by RFC3339.
Example: 2016-08-25T21:10:29.600Z
73 74 75 |
# File 'lib/oci/load_balancer/models/work_request.rb', line 73 def time_finished @time_finished end |
#type ⇒ String
[Required] The type of action the work request represents.
Example: CreateListener
38 39 40 |
# File 'lib/oci/load_balancer/models/work_request.rb', line 38 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/oci/load_balancer/models/work_request.rb', line 80 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'load_balancer_id': :'loadBalancerId', 'type': :'type', 'compartment_id': :'compartmentId', 'lifecycle_state': :'lifecycleState', 'message': :'message', 'time_accepted': :'timeAccepted', 'time_finished': :'timeFinished', 'error_details': :'errorDetails' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/oci/load_balancer/models/work_request.rb', line 97 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'load_balancer_id': :'String', 'type': :'String', 'compartment_id': :'String', 'lifecycle_state': :'String', 'message': :'String', 'time_accepted': :'DateTime', 'time_finished': :'DateTime', 'error_details': :'Array<OCI::LoadBalancer::Models::WorkRequestError>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/oci/load_balancer/models/work_request.rb', line 197 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && load_balancer_id == other.load_balancer_id && type == other.type && compartment_id == other.compartment_id && lifecycle_state == other.lifecycle_state && == other. && time_accepted == other.time_accepted && time_finished == other.time_finished && error_details == other.error_details end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/oci/load_balancer/models/work_request.rb', line 235 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
215 216 217 |
# File 'lib/oci/load_balancer/models/work_request.rb', line 215 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
224 225 226 |
# File 'lib/oci/load_balancer/models/work_request.rb', line 224 def hash [id, load_balancer_id, type, compartment_id, lifecycle_state, , time_accepted, time_finished, error_details].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
268 269 270 271 272 273 274 275 276 277 |
# File 'lib/oci/load_balancer/models/work_request.rb', line 268 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
262 263 264 |
# File 'lib/oci/load_balancer/models/work_request.rb', line 262 def to_s to_hash.to_s end |