Class: OCI::LogAnalytics::Models::AbstractParserTestResultLogEntry
- Inherits:
-
Object
- Object
- OCI::LogAnalytics::Models::AbstractParserTestResultLogEntry
- Defined in:
- lib/oci/log_analytics/models/abstract_parser_test_result_log_entry.rb
Overview
AbstractParserTestResultLogEntry
Instance Attribute Summary collapse
-
#extra_info_attributes ⇒ Hash<String, String>
Extra information attributes.
-
#field_name_value_map ⇒ Hash<String, String>
The field name value map.
-
#field_position_value_map ⇒ Hash<String, String>
The field position value map.
-
#fields ⇒ Hash<String, String>
The parser fields.
-
#log_entry ⇒ String
The log entry.
-
#match_status ⇒ String
The match status.
-
#match_status_description ⇒ String
The match status description.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AbstractParserTestResultLogEntry
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ AbstractParserTestResultLogEntry
Initializes the object
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/oci/log_analytics/models/abstract_parser_test_result_log_entry.rb', line 81 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.extra_info_attributes = attributes[:'extraInfoAttributes'] if attributes[:'extraInfoAttributes'] raise 'You cannot provide both :extraInfoAttributes and :extra_info_attributes' if attributes.key?(:'extraInfoAttributes') && attributes.key?(:'extra_info_attributes') self.extra_info_attributes = attributes[:'extra_info_attributes'] if attributes[:'extra_info_attributes'] self.field_name_value_map = attributes[:'fieldNameValueMap'] if attributes[:'fieldNameValueMap'] raise 'You cannot provide both :fieldNameValueMap and :field_name_value_map' if attributes.key?(:'fieldNameValueMap') && attributes.key?(:'field_name_value_map') self.field_name_value_map = attributes[:'field_name_value_map'] if attributes[:'field_name_value_map'] self.field_position_value_map = attributes[:'fieldPositionValueMap'] if attributes[:'fieldPositionValueMap'] raise 'You cannot provide both :fieldPositionValueMap and :field_position_value_map' if attributes.key?(:'fieldPositionValueMap') && attributes.key?(:'field_position_value_map') self.field_position_value_map = attributes[:'field_position_value_map'] if attributes[:'field_position_value_map'] self.fields = attributes[:'fields'] if attributes[:'fields'] self.log_entry = attributes[:'logEntry'] if attributes[:'logEntry'] raise 'You cannot provide both :logEntry and :log_entry' if attributes.key?(:'logEntry') && attributes.key?(:'log_entry') self.log_entry = attributes[:'log_entry'] if attributes[:'log_entry'] self.match_status = attributes[:'matchStatus'] if attributes[:'matchStatus'] raise 'You cannot provide both :matchStatus and :match_status' if attributes.key?(:'matchStatus') && attributes.key?(:'match_status') self.match_status = attributes[:'match_status'] if attributes[:'match_status'] self.match_status_description = attributes[:'matchStatusDescription'] if attributes[:'matchStatusDescription'] raise 'You cannot provide both :matchStatusDescription and :match_status_description' if attributes.key?(:'matchStatusDescription') && attributes.key?(:'match_status_description') self.match_status_description = attributes[:'match_status_description'] if attributes[:'match_status_description'] end |
Instance Attribute Details
#extra_info_attributes ⇒ Hash<String, String>
Extra information attributes.
12 13 14 |
# File 'lib/oci/log_analytics/models/abstract_parser_test_result_log_entry.rb', line 12 def extra_info_attributes @extra_info_attributes end |
#field_name_value_map ⇒ Hash<String, String>
The field name value map.
16 17 18 |
# File 'lib/oci/log_analytics/models/abstract_parser_test_result_log_entry.rb', line 16 def field_name_value_map @field_name_value_map end |
#field_position_value_map ⇒ Hash<String, String>
The field position value map.
20 21 22 |
# File 'lib/oci/log_analytics/models/abstract_parser_test_result_log_entry.rb', line 20 def field_position_value_map @field_position_value_map end |
#fields ⇒ Hash<String, String>
The parser fields.
24 25 26 |
# File 'lib/oci/log_analytics/models/abstract_parser_test_result_log_entry.rb', line 24 def fields @fields end |
#log_entry ⇒ String
The log entry.
28 29 30 |
# File 'lib/oci/log_analytics/models/abstract_parser_test_result_log_entry.rb', line 28 def log_entry @log_entry end |
#match_status ⇒ String
The match status.
32 33 34 |
# File 'lib/oci/log_analytics/models/abstract_parser_test_result_log_entry.rb', line 32 def match_status @match_status end |
#match_status_description ⇒ String
The match status description.
36 37 38 |
# File 'lib/oci/log_analytics/models/abstract_parser_test_result_log_entry.rb', line 36 def match_status_description @match_status_description end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/oci/log_analytics/models/abstract_parser_test_result_log_entry.rb', line 39 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'extra_info_attributes': :'extraInfoAttributes', 'field_name_value_map': :'fieldNameValueMap', 'field_position_value_map': :'fieldPositionValueMap', 'fields': :'fields', 'log_entry': :'logEntry', 'match_status': :'matchStatus', 'match_status_description': :'matchStatusDescription' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/oci/log_analytics/models/abstract_parser_test_result_log_entry.rb', line 54 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'extra_info_attributes': :'Hash<String, String>', 'field_name_value_map': :'Hash<String, String>', 'field_position_value_map': :'Hash<String, String>', 'fields': :'Hash<String, String>', 'log_entry': :'String', 'match_status': :'String', 'match_status_description': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/oci/log_analytics/models/abstract_parser_test_result_log_entry.rb', line 133 def ==(other) return true if equal?(other) self.class == other.class && extra_info_attributes == other.extra_info_attributes && field_name_value_map == other.field_name_value_map && field_position_value_map == other.field_position_value_map && fields == other.fields && log_entry == other.log_entry && match_status == other.match_status && match_status_description == other.match_status_description end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/oci/log_analytics/models/abstract_parser_test_result_log_entry.rb', line 169 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
149 150 151 |
# File 'lib/oci/log_analytics/models/abstract_parser_test_result_log_entry.rb', line 149 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
158 159 160 |
# File 'lib/oci/log_analytics/models/abstract_parser_test_result_log_entry.rb', line 158 def hash [extra_info_attributes, field_name_value_map, field_position_value_map, fields, log_entry, match_status, match_status_description].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
202 203 204 205 206 207 208 209 210 211 |
# File 'lib/oci/log_analytics/models/abstract_parser_test_result_log_entry.rb', line 202 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
196 197 198 |
# File 'lib/oci/log_analytics/models/abstract_parser_test_result_log_entry.rb', line 196 def to_s to_hash.to_s end |