Class: OCI::LogAnalytics::Models::BucketCommandDescriptor
- Inherits:
-
AbstractCommandDescriptor
- Object
- AbstractCommandDescriptor
- OCI::LogAnalytics::Models::BucketCommandDescriptor
- Defined in:
- lib/oci/log_analytics/models/bucket_command_descriptor.rb
Overview
Command descriptor for querylanguage BUCKET command.
Constant Summary
Constants inherited from AbstractCommandDescriptor
AbstractCommandDescriptor::NAME_ENUM
Instance Attribute Summary collapse
-
#default_value ⇒ String
Default value to use in place of null if a result does not fit into any of the specified / calculated ranges.
-
#max_buckets ⇒ Integer
number of auto calculated ranges to compute if specified.
-
#ranges ⇒ Array<OCI::LogAnalytics::Models::BucketRange>
List of the specified numeric ranges.
-
#span ⇒ Float
Size of each numeric range if specified.
Attributes inherited from AbstractCommandDescriptor
#category, #declared_fields, #display_query_string, #internal_query_string, #name, #referenced_fields
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BucketCommandDescriptor
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from AbstractCommandDescriptor
Constructor Details
#initialize(attributes = {}) ⇒ BucketCommandDescriptor
Initializes the object
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/oci/log_analytics/models/bucket_command_descriptor.rb', line 83 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['name'] = 'BUCKET' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.max_buckets = attributes[:'maxBuckets'] if attributes[:'maxBuckets'] self.max_buckets = 10 if max_buckets.nil? && !attributes.key?(:'maxBuckets') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :maxBuckets and :max_buckets' if attributes.key?(:'maxBuckets') && attributes.key?(:'max_buckets') self.max_buckets = attributes[:'max_buckets'] if attributes[:'max_buckets'] self.max_buckets = 10 if max_buckets.nil? && !attributes.key?(:'maxBuckets') && !attributes.key?(:'max_buckets') # rubocop:disable Style/StringLiterals self.span = attributes[:'span'] if attributes[:'span'] self.ranges = attributes[:'ranges'] if attributes[:'ranges'] self.default_value = attributes[:'defaultValue'] if attributes[:'defaultValue'] raise 'You cannot provide both :defaultValue and :default_value' if attributes.key?(:'defaultValue') && attributes.key?(:'default_value') self.default_value = attributes[:'default_value'] if attributes[:'default_value'] end |
Instance Attribute Details
#default_value ⇒ String
Default value to use in place of null if a result does not fit into any of the specified / calculated ranges.
30 31 32 |
# File 'lib/oci/log_analytics/models/bucket_command_descriptor.rb', line 30 def default_value @default_value end |
#max_buckets ⇒ Integer
number of auto calculated ranges to compute if specified.
15 16 17 |
# File 'lib/oci/log_analytics/models/bucket_command_descriptor.rb', line 15 def max_buckets @max_buckets end |
#ranges ⇒ Array<OCI::LogAnalytics::Models::BucketRange>
List of the specified numeric ranges.
25 26 27 |
# File 'lib/oci/log_analytics/models/bucket_command_descriptor.rb', line 25 def ranges @ranges end |
#span ⇒ Float
Size of each numeric range if specified. Data type should match numeric field data type specified in the query string.
20 21 22 |
# File 'lib/oci/log_analytics/models/bucket_command_descriptor.rb', line 20 def span @span end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 |
# File 'lib/oci/log_analytics/models/bucket_command_descriptor.rb', line 33 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'display_query_string': :'displayQueryString', 'internal_query_string': :'internalQueryString', 'category': :'category', 'referenced_fields': :'referencedFields', 'declared_fields': :'declaredFields', 'max_buckets': :'maxBuckets', 'span': :'span', 'ranges': :'ranges', 'default_value': :'defaultValue' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/oci/log_analytics/models/bucket_command_descriptor.rb', line 51 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'display_query_string': :'String', 'internal_query_string': :'String', 'category': :'String', 'referenced_fields': :'Array<OCI::LogAnalytics::Models::AbstractField>', 'declared_fields': :'Array<OCI::LogAnalytics::Models::AbstractField>', 'max_buckets': :'Integer', 'span': :'Float', 'ranges': :'Array<OCI::LogAnalytics::Models::BucketRange>', 'default_value': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/oci/log_analytics/models/bucket_command_descriptor.rb', line 119 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && display_query_string == other.display_query_string && internal_query_string == other.internal_query_string && category == other.category && referenced_fields == other.referenced_fields && declared_fields == other.declared_fields && max_buckets == other.max_buckets && span == other.span && ranges == other.ranges && default_value == other.default_value end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/oci/log_analytics/models/bucket_command_descriptor.rb', line 158 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
138 139 140 |
# File 'lib/oci/log_analytics/models/bucket_command_descriptor.rb', line 138 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
147 148 149 |
# File 'lib/oci/log_analytics/models/bucket_command_descriptor.rb', line 147 def hash [name, display_query_string, internal_query_string, category, referenced_fields, declared_fields, max_buckets, span, ranges, default_value].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
191 192 193 194 195 196 197 198 199 200 |
# File 'lib/oci/log_analytics/models/bucket_command_descriptor.rb', line 191 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
185 186 187 |
# File 'lib/oci/log_analytics/models/bucket_command_descriptor.rb', line 185 def to_s to_hash.to_s end |