Class: OCI::LogAnalytics::Models::BucketRange

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/log_analytics/models/bucket_range.rb

Overview

Represents querylanguage bucket command input arguments in parse output.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ BucketRange

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :lower (Float)

    The value to assign to the #lower property

  • :upper (Float)

    The value to assign to the #upper property

  • :_alias (String)

    The value to assign to the #_alias property



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/oci/log_analytics/models/bucket_range.rb', line 57

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.lower = attributes[:'lower'] if attributes[:'lower']

  self.upper = attributes[:'upper'] if attributes[:'upper']

  self._alias = attributes[:'alias'] if attributes[:'alias']

  raise 'You cannot provide both :alias and :_alias' if attributes.key?(:'alias') && attributes.key?(:'_alias')

  self._alias = attributes[:'_alias'] if attributes[:'_alias']
end

Instance Attribute Details

#_aliasString

Optional alias of the bucket range if specified in the querystring.

Returns:

  • (String)


24
25
26
# File 'lib/oci/log_analytics/models/bucket_range.rb', line 24

def _alias
  @_alias
end

#lowerFloat

Lower bound of the bucket range specified in the querystring for the numeric field referenced in tbe bucket command.

Returns:

  • (Float)


14
15
16
# File 'lib/oci/log_analytics/models/bucket_range.rb', line 14

def lower
  @lower
end

#upperFloat

Upper bound of the bucket range specified in the querystring for the numeric field referenced in tbe bucket command.

Returns:

  • (Float)


19
20
21
# File 'lib/oci/log_analytics/models/bucket_range.rb', line 19

def upper
  @upper
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



27
28
29
30
31
32
33
34
35
# File 'lib/oci/log_analytics/models/bucket_range.rb', line 27

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'lower': :'lower',
    'upper': :'upper',
    '_alias': :'alias'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



38
39
40
41
42
43
44
45
46
# File 'lib/oci/log_analytics/models/bucket_range.rb', line 38

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'lower': :'Float',
    'upper': :'Float',
    '_alias': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



81
82
83
84
85
86
87
88
# File 'lib/oci/log_analytics/models/bucket_range.rb', line 81

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    lower == other.lower &&
    upper == other.upper &&
    _alias == other._alias
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/oci/log_analytics/models/bucket_range.rb', line 113

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


93
94
95
# File 'lib/oci/log_analytics/models/bucket_range.rb', line 93

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



102
103
104
# File 'lib/oci/log_analytics/models/bucket_range.rb', line 102

def hash
  [lower, upper, _alias].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



146
147
148
149
150
151
152
153
154
155
# File 'lib/oci/log_analytics/models/bucket_range.rb', line 146

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



140
141
142
# File 'lib/oci/log_analytics/models/bucket_range.rb', line 140

def to_s
  to_hash.to_s
end