Class: OCI::LogAnalytics::Models::ClassifyColumn
- Inherits:
-
AbstractColumn
- Object
- AbstractColumn
- OCI::LogAnalytics::Models::ClassifyColumn
- Defined in:
- lib/oci/log_analytics/models/classify_column.rb
Overview
Column containing query results produced by the query language classify command.
Constant Summary
Constants inherited from AbstractColumn
AbstractColumn::SUB_SYSTEM_ENUM, AbstractColumn::TYPE_ENUM, AbstractColumn::VALUE_TYPE_ENUM
Instance Attribute Summary collapse
-
#classify_anomaly_interval_counts ⇒ Array<Integer>
Count of anomalies for each timeseries datapoint.
-
#classify_columns ⇒ Array<OCI::LogAnalytics::Models::AbstractColumn>
Column descriptors for the classify result.
-
#classify_correlate_columns ⇒ Array<OCI::LogAnalytics::Models::AbstractColumn>
Column descriptors of fields with strong correlation with the classify fields.
-
#classify_correlate_result ⇒ Array<Hash<String, Object>>
Correlation results of the classify command.
-
#classify_field_names ⇒ Array<String>
A list of fields specified in the classify command in the query string.
-
#classify_field_null_count ⇒ Array<Integer>
Count of nulls found in each of the fields specified in the classify command in the query string.
-
#classify_result ⇒ Array<Hash<String, Object>>
Results of the classify command.
Attributes inherited from AbstractColumn
#display_name, #internal_name, #is_evaluable, #is_groupable, #is_list_of_values, #is_multi_valued, #original_display_name, #sub_system, #type, #value_type, #values
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ClassifyColumn
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from AbstractColumn
Constructor Details
#initialize(attributes = {}) ⇒ ClassifyColumn
Initializes the object
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/oci/log_analytics/models/classify_column.rb', line 122 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['type'] = 'CLASSIFY_COLUMN' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.classify_field_names = attributes[:'classifyFieldNames'] if attributes[:'classifyFieldNames'] raise 'You cannot provide both :classifyFieldNames and :classify_field_names' if attributes.key?(:'classifyFieldNames') && attributes.key?(:'classify_field_names') self.classify_field_names = attributes[:'classify_field_names'] if attributes[:'classify_field_names'] self.classify_field_null_count = attributes[:'classifyFieldNullCount'] if attributes[:'classifyFieldNullCount'] raise 'You cannot provide both :classifyFieldNullCount and :classify_field_null_count' if attributes.key?(:'classifyFieldNullCount') && attributes.key?(:'classify_field_null_count') self.classify_field_null_count = attributes[:'classify_field_null_count'] if attributes[:'classify_field_null_count'] self.classify_anomaly_interval_counts = attributes[:'classifyAnomalyIntervalCounts'] if attributes[:'classifyAnomalyIntervalCounts'] raise 'You cannot provide both :classifyAnomalyIntervalCounts and :classify_anomaly_interval_counts' if attributes.key?(:'classifyAnomalyIntervalCounts') && attributes.key?(:'classify_anomaly_interval_counts') self.classify_anomaly_interval_counts = attributes[:'classify_anomaly_interval_counts'] if attributes[:'classify_anomaly_interval_counts'] self.classify_columns = attributes[:'classifyColumns'] if attributes[:'classifyColumns'] raise 'You cannot provide both :classifyColumns and :classify_columns' if attributes.key?(:'classifyColumns') && attributes.key?(:'classify_columns') self.classify_columns = attributes[:'classify_columns'] if attributes[:'classify_columns'] self.classify_result = attributes[:'classifyResult'] if attributes[:'classifyResult'] raise 'You cannot provide both :classifyResult and :classify_result' if attributes.key?(:'classifyResult') && attributes.key?(:'classify_result') self.classify_result = attributes[:'classify_result'] if attributes[:'classify_result'] self.classify_correlate_columns = attributes[:'classifyCorrelateColumns'] if attributes[:'classifyCorrelateColumns'] raise 'You cannot provide both :classifyCorrelateColumns and :classify_correlate_columns' if attributes.key?(:'classifyCorrelateColumns') && attributes.key?(:'classify_correlate_columns') self.classify_correlate_columns = attributes[:'classify_correlate_columns'] if attributes[:'classify_correlate_columns'] self.classify_correlate_result = attributes[:'classifyCorrelateResult'] if attributes[:'classifyCorrelateResult'] raise 'You cannot provide both :classifyCorrelateResult and :classify_correlate_result' if attributes.key?(:'classifyCorrelateResult') && attributes.key?(:'classify_correlate_result') self.classify_correlate_result = attributes[:'classify_correlate_result'] if attributes[:'classify_correlate_result'] end |
Instance Attribute Details
#classify_anomaly_interval_counts ⇒ Array<Integer>
Count of anomalies for each timeseries datapoint.
25 26 27 |
# File 'lib/oci/log_analytics/models/classify_column.rb', line 25 def classify_anomaly_interval_counts @classify_anomaly_interval_counts end |
#classify_columns ⇒ Array<OCI::LogAnalytics::Models::AbstractColumn>
Column descriptors for the classify result.
30 31 32 |
# File 'lib/oci/log_analytics/models/classify_column.rb', line 30 def classify_columns @classify_columns end |
#classify_correlate_columns ⇒ Array<OCI::LogAnalytics::Models::AbstractColumn>
Column descriptors of fields with strong correlation with the classify fields.
40 41 42 |
# File 'lib/oci/log_analytics/models/classify_column.rb', line 40 def classify_correlate_columns @classify_correlate_columns end |
#classify_correlate_result ⇒ Array<Hash<String, Object>>
Correlation results of the classify command.
45 46 47 |
# File 'lib/oci/log_analytics/models/classify_column.rb', line 45 def classify_correlate_result @classify_correlate_result end |
#classify_field_names ⇒ Array<String>
A list of fields specified in the classify command in the query string.
15 16 17 |
# File 'lib/oci/log_analytics/models/classify_column.rb', line 15 def classify_field_names @classify_field_names end |
#classify_field_null_count ⇒ Array<Integer>
Count of nulls found in each of the fields specified in the classify command in the query string.
20 21 22 |
# File 'lib/oci/log_analytics/models/classify_column.rb', line 20 def classify_field_null_count @classify_field_null_count end |
#classify_result ⇒ Array<Hash<String, Object>>
Results of the classify command.
35 36 37 |
# File 'lib/oci/log_analytics/models/classify_column.rb', line 35 def classify_result @classify_result end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/oci/log_analytics/models/classify_column.rb', line 48 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'type': :'type', 'display_name': :'displayName', 'sub_system': :'subSystem', 'values': :'values', 'is_list_of_values': :'isListOfValues', 'is_multi_valued': :'isMultiValued', 'is_groupable': :'isGroupable', 'is_evaluable': :'isEvaluable', 'value_type': :'valueType', 'original_display_name': :'originalDisplayName', 'internal_name': :'internalName', 'classify_field_names': :'classifyFieldNames', 'classify_field_null_count': :'classifyFieldNullCount', 'classify_anomaly_interval_counts': :'classifyAnomalyIntervalCounts', 'classify_columns': :'classifyColumns', 'classify_result': :'classifyResult', 'classify_correlate_columns': :'classifyCorrelateColumns', 'classify_correlate_result': :'classifyCorrelateResult' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/oci/log_analytics/models/classify_column.rb', line 74 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'type': :'String', 'display_name': :'String', 'sub_system': :'String', 'values': :'Array<OCI::LogAnalytics::Models::FieldValue>', 'is_list_of_values': :'BOOLEAN', 'is_multi_valued': :'BOOLEAN', 'is_groupable': :'BOOLEAN', 'is_evaluable': :'BOOLEAN', 'value_type': :'String', 'original_display_name': :'String', 'internal_name': :'String', 'classify_field_names': :'Array<String>', 'classify_field_null_count': :'Array<Integer>', 'classify_anomaly_interval_counts': :'Array<Integer>', 'classify_columns': :'Array<OCI::LogAnalytics::Models::AbstractColumn>', 'classify_result': :'Array<Hash<String, Object>>', 'classify_correlate_columns': :'Array<OCI::LogAnalytics::Models::AbstractColumn>', 'classify_correlate_result': :'Array<Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/oci/log_analytics/models/classify_column.rb', line 182 def ==(other) return true if equal?(other) self.class == other.class && type == other.type && display_name == other.display_name && sub_system == other.sub_system && values == other.values && is_list_of_values == other.is_list_of_values && is_multi_valued == other.is_multi_valued && is_groupable == other.is_groupable && is_evaluable == other.is_evaluable && value_type == other.value_type && original_display_name == other.original_display_name && internal_name == other.internal_name && classify_field_names == other.classify_field_names && classify_field_null_count == other.classify_field_null_count && classify_anomaly_interval_counts == other.classify_anomaly_interval_counts && classify_columns == other.classify_columns && classify_result == other.classify_result && classify_correlate_columns == other.classify_correlate_columns && classify_correlate_result == other.classify_correlate_result end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/oci/log_analytics/models/classify_column.rb', line 229 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
209 210 211 |
# File 'lib/oci/log_analytics/models/classify_column.rb', line 209 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
218 219 220 |
# File 'lib/oci/log_analytics/models/classify_column.rb', line 218 def hash [type, display_name, sub_system, values, is_list_of_values, is_multi_valued, is_groupable, is_evaluable, value_type, original_display_name, internal_name, classify_field_names, classify_field_null_count, classify_anomaly_interval_counts, classify_columns, classify_result, classify_correlate_columns, classify_correlate_result].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
262 263 264 265 266 267 268 269 270 271 |
# File 'lib/oci/log_analytics/models/classify_column.rb', line 262 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
256 257 258 |
# File 'lib/oci/log_analytics/models/classify_column.rb', line 256 def to_s to_hash.to_s end |