Class: OCI::LogAnalytics::Models::CreateLogAnalyticsEmBridgeDetails
- Inherits:
-
Object
- Object
- OCI::LogAnalytics::Models::CreateLogAnalyticsEmBridgeDetails
- Defined in:
- lib/oci/log_analytics/models/create_log_analytics_em_bridge_details.rb
Overview
Details for a new enterprise manager bridge to be added.
Instance Attribute Summary collapse
-
#bucket_name ⇒ String
[Required] Object store bucket name where enterprise manager harvested entities will be uploaded.
-
#compartment_id ⇒ String
[Required] Compartment Identifier [OCID] (docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
A description for log analytics enterprise manager bridge.
-
#display_name ⇒ String
[Required] Log analytics enterprise manager bridge display name.
-
#em_entities_compartment_id ⇒ String
[Required] Compartment for entities created from enterprise manager.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateLogAnalyticsEmBridgeDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateLogAnalyticsEmBridgeDetails
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/oci/log_analytics/models/create_log_analytics_em_bridge_details.rb', line 88 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.em_entities_compartment_id = attributes[:'emEntitiesCompartmentId'] if attributes[:'emEntitiesCompartmentId'] raise 'You cannot provide both :emEntitiesCompartmentId and :em_entities_compartment_id' if attributes.key?(:'emEntitiesCompartmentId') && attributes.key?(:'em_entities_compartment_id') self.em_entities_compartment_id = attributes[:'em_entities_compartment_id'] if attributes[:'em_entities_compartment_id'] self.bucket_name = attributes[:'bucketName'] if attributes[:'bucketName'] raise 'You cannot provide both :bucketName and :bucket_name' if attributes.key?(:'bucketName') && attributes.key?(:'bucket_name') self.bucket_name = attributes[:'bucket_name'] if attributes[:'bucket_name'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#bucket_name ⇒ String
[Required] Object store bucket name where enterprise manager harvested entities will be uploaded.
31 32 33 |
# File 'lib/oci/log_analytics/models/create_log_analytics_em_bridge_details.rb', line 31 def bucket_name @bucket_name end |
#compartment_id ⇒ String
[Required] Compartment Identifier [OCID] (docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
22 23 24 |
# File 'lib/oci/log_analytics/models/create_log_analytics_em_bridge_details.rb', line 22 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
43 44 45 |
# File 'lib/oci/log_analytics/models/create_log_analytics_em_bridge_details.rb', line 43 def end |
#description ⇒ String
A description for log analytics enterprise manager bridge.
18 19 20 |
# File 'lib/oci/log_analytics/models/create_log_analytics_em_bridge_details.rb', line 18 def description @description end |
#display_name ⇒ String
[Required] Log analytics enterprise manager bridge display name.
13 14 15 |
# File 'lib/oci/log_analytics/models/create_log_analytics_em_bridge_details.rb', line 13 def display_name @display_name end |
#em_entities_compartment_id ⇒ String
[Required] Compartment for entities created from enterprise manager.
27 28 29 |
# File 'lib/oci/log_analytics/models/create_log_analytics_em_bridge_details.rb', line 27 def em_entities_compartment_id @em_entities_compartment_id end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`
37 38 39 |
# File 'lib/oci/log_analytics/models/create_log_analytics_em_bridge_details.rb', line 37 def end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/oci/log_analytics/models/create_log_analytics_em_bridge_details.rb', line 46 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'description': :'description', 'compartment_id': :'compartmentId', 'em_entities_compartment_id': :'emEntitiesCompartmentId', 'bucket_name': :'bucketName', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/oci/log_analytics/models/create_log_analytics_em_bridge_details.rb', line 61 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'description': :'String', 'compartment_id': :'String', 'em_entities_compartment_id': :'String', 'bucket_name': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/oci/log_analytics/models/create_log_analytics_em_bridge_details.rb', line 140 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && description == other.description && compartment_id == other.compartment_id && em_entities_compartment_id == other.em_entities_compartment_id && bucket_name == other.bucket_name && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/oci/log_analytics/models/create_log_analytics_em_bridge_details.rb', line 176 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
156 157 158 |
# File 'lib/oci/log_analytics/models/create_log_analytics_em_bridge_details.rb', line 156 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
165 166 167 |
# File 'lib/oci/log_analytics/models/create_log_analytics_em_bridge_details.rb', line 165 def hash [display_name, description, compartment_id, em_entities_compartment_id, bucket_name, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
209 210 211 212 213 214 215 216 217 218 |
# File 'lib/oci/log_analytics/models/create_log_analytics_em_bridge_details.rb', line 209 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
203 204 205 |
# File 'lib/oci/log_analytics/models/create_log_analytics_em_bridge_details.rb', line 203 def to_s to_hash.to_s end |