Class: OCI::LogAnalytics::Models::CreateScheduledTaskDetails
- Inherits:
-
Object
- Object
- OCI::LogAnalytics::Models::CreateScheduledTaskDetails
- Defined in:
- lib/oci/log_analytics/models/create_scheduled_task_details.rb
Overview
Details for creating a scheduled task.
This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
Constant Summary collapse
- KIND_ENUM =
[ KIND_ACCELERATION = 'ACCELERATION'.freeze, KIND_STANDARD = 'STANDARD'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] Compartment Identifier [OCID] (docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
A user-friendly name that is changeable and that does not have to be unique.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#kind ⇒ String
[Required] Discriminator.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateScheduledTaskDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateScheduledTaskDetails
Initializes the object
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/oci/log_analytics/models/create_scheduled_task_details.rb', line 98 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.kind = attributes[:'kind'] if attributes[:'kind'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] Compartment Identifier [OCID] (docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
23 24 25 |
# File 'lib/oci/log_analytics/models/create_scheduled_task_details.rb', line 23 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
43 44 45 |
# File 'lib/oci/log_analytics/models/create_scheduled_task_details.rb', line 43 def end |
#display_name ⇒ String
A user-friendly name that is changeable and that does not have to be unique. Format: a leading alphanumeric, followed by zero or more alphanumerics, underscores, spaces, backslashes, or hyphens in any order). No trailing spaces allowed.
31 32 33 |
# File 'lib/oci/log_analytics/models/create_scheduled_task_details.rb', line 31 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`
37 38 39 |
# File 'lib/oci/log_analytics/models/create_scheduled_task_details.rb', line 37 def end |
#kind ⇒ String
[Required] Discriminator.
19 20 21 |
# File 'lib/oci/log_analytics/models/create_scheduled_task_details.rb', line 19 def kind @kind end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/oci/log_analytics/models/create_scheduled_task_details.rb', line 46 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'kind': :'kind', 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
76 77 78 79 80 81 82 83 84 |
# File 'lib/oci/log_analytics/models/create_scheduled_task_details.rb', line 76 def self.get_subtype(object_hash) type = object_hash[:'kind'] # rubocop:disable Style/SymbolLiteral return 'OCI::LogAnalytics::Models::CreateStandardTaskDetails' if type == 'STANDARD' return 'OCI::LogAnalytics::Models::CreateAccelerationTaskDetails' if type == 'ACCELERATION' # TODO: Log a warning when the subtype is not found. 'OCI::LogAnalytics::Models::CreateScheduledTaskDetails' end |
.swagger_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/oci/log_analytics/models/create_scheduled_task_details.rb', line 59 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'kind': :'String', 'compartment_id': :'String', 'display_name': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
146 147 148 149 150 151 152 153 154 155 |
# File 'lib/oci/log_analytics/models/create_scheduled_task_details.rb', line 146 def ==(other) return true if equal?(other) self.class == other.class && kind == other.kind && compartment_id == other.compartment_id && display_name == other.display_name && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/oci/log_analytics/models/create_scheduled_task_details.rb', line 180 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
160 161 162 |
# File 'lib/oci/log_analytics/models/create_scheduled_task_details.rb', line 160 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
169 170 171 |
# File 'lib/oci/log_analytics/models/create_scheduled_task_details.rb', line 169 def hash [kind, compartment_id, display_name, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
213 214 215 216 217 218 219 220 221 222 |
# File 'lib/oci/log_analytics/models/create_scheduled_task_details.rb', line 213 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
207 208 209 |
# File 'lib/oci/log_analytics/models/create_scheduled_task_details.rb', line 207 def to_s to_hash.to_s end |