Class: OCI::LogAnalytics::Models::CronSchedule
- Defined in:
- lib/oci/log_analytics/models/cron_schedule.rb
Overview
Cron schedule for a scheduled task.
Constant Summary
Constants inherited from Schedule
Schedule::MISFIRE_POLICY_ENUM, Schedule::TYPE_ENUM
Instance Attribute Summary collapse
-
#expression ⇒ String
[Required] Value in cron format.
-
#time_zone ⇒ String
[Required] Time zone, by default UTC.
Attributes inherited from Schedule
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CronSchedule
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from Schedule
Constructor Details
#initialize(attributes = {}) ⇒ CronSchedule
Initializes the object
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/oci/log_analytics/models/cron_schedule.rb', line 52 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['type'] = 'CRON' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.expression = attributes[:'expression'] if attributes[:'expression'] self.time_zone = attributes[:'timeZone'] if attributes[:'timeZone'] self.time_zone = "UTC" if time_zone.nil? && !attributes.key?(:'timeZone') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :timeZone and :time_zone' if attributes.key?(:'timeZone') && attributes.key?(:'time_zone') self.time_zone = attributes[:'time_zone'] if attributes[:'time_zone'] self.time_zone = "UTC" if time_zone.nil? && !attributes.key?(:'timeZone') && !attributes.key?(:'time_zone') # rubocop:disable Style/StringLiterals end |
Instance Attribute Details
#expression ⇒ String
[Required] Value in cron format.
13 14 15 |
# File 'lib/oci/log_analytics/models/cron_schedule.rb', line 13 def expression @expression end |
#time_zone ⇒ String
[Required] Time zone, by default UTC.
17 18 19 |
# File 'lib/oci/log_analytics/models/cron_schedule.rb', line 17 def time_zone @time_zone end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
20 21 22 23 24 25 26 27 28 29 |
# File 'lib/oci/log_analytics/models/cron_schedule.rb', line 20 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'type': :'type', 'misfire_policy': :'misfirePolicy', 'expression': :'expression', 'time_zone': :'timeZone' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
32 33 34 35 36 37 38 39 40 41 |
# File 'lib/oci/log_analytics/models/cron_schedule.rb', line 32 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'type': :'String', 'misfire_policy': :'String', 'expression': :'String', 'time_zone': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
80 81 82 83 84 85 86 87 88 |
# File 'lib/oci/log_analytics/models/cron_schedule.rb', line 80 def ==(other) return true if equal?(other) self.class == other.class && type == other.type && misfire_policy == other.misfire_policy && expression == other.expression && time_zone == other.time_zone end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/oci/log_analytics/models/cron_schedule.rb', line 113 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
93 94 95 |
# File 'lib/oci/log_analytics/models/cron_schedule.rb', line 93 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
102 103 104 |
# File 'lib/oci/log_analytics/models/cron_schedule.rb', line 102 def hash [type, misfire_policy, expression, time_zone].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
146 147 148 149 150 151 152 153 154 155 |
# File 'lib/oci/log_analytics/models/cron_schedule.rb', line 146 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
140 141 142 |
# File 'lib/oci/log_analytics/models/cron_schedule.rb', line 140 def to_s to_hash.to_s end |