Class: OCI::LogAnalytics::Models::EstimateReleaseDataSizeResult
- Inherits:
-
Object
- Object
- OCI::LogAnalytics::Models::EstimateReleaseDataSizeResult
- Defined in:
- lib/oci/log_analytics/models/estimate_release_data_size_result.rb
Overview
This is the size and time range of data to be released
Instance Attribute Summary collapse
-
#size_in_bytes ⇒ Integer
[Required] This is the size in bytes.
-
#time_data_ended ⇒ DateTime
[Required] This is the end of the time range of data to be released.
-
#time_data_started ⇒ DateTime
[Required] This is the start of the time range of data to be released.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EstimateReleaseDataSizeResult
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ EstimateReleaseDataSizeResult
Initializes the object
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/oci/log_analytics/models/estimate_release_data_size_result.rb', line 56 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.time_data_ended = attributes[:'timeDataEnded'] if attributes[:'timeDataEnded'] raise 'You cannot provide both :timeDataEnded and :time_data_ended' if attributes.key?(:'timeDataEnded') && attributes.key?(:'time_data_ended') self.time_data_ended = attributes[:'time_data_ended'] if attributes[:'time_data_ended'] self.time_data_started = attributes[:'timeDataStarted'] if attributes[:'timeDataStarted'] raise 'You cannot provide both :timeDataStarted and :time_data_started' if attributes.key?(:'timeDataStarted') && attributes.key?(:'time_data_started') self.time_data_started = attributes[:'time_data_started'] if attributes[:'time_data_started'] self.size_in_bytes = attributes[:'sizeInBytes'] if attributes[:'sizeInBytes'] raise 'You cannot provide both :sizeInBytes and :size_in_bytes' if attributes.key?(:'sizeInBytes') && attributes.key?(:'size_in_bytes') self.size_in_bytes = attributes[:'size_in_bytes'] if attributes[:'size_in_bytes'] end |
Instance Attribute Details
#size_in_bytes ⇒ Integer
[Required] This is the size in bytes
23 24 25 |
# File 'lib/oci/log_analytics/models/estimate_release_data_size_result.rb', line 23 def size_in_bytes @size_in_bytes end |
#time_data_ended ⇒ DateTime
[Required] This is the end of the time range of data to be released. timeDataStarted and timeDataEnded delineate the time range of the recalled data to be released. They may not be exact the same as the parameters in the request input (EstimateReleaseDataSizeDetails).
15 16 17 |
# File 'lib/oci/log_analytics/models/estimate_release_data_size_result.rb', line 15 def time_data_ended @time_data_ended end |
#time_data_started ⇒ DateTime
[Required] This is the start of the time range of data to be released
19 20 21 |
# File 'lib/oci/log_analytics/models/estimate_release_data_size_result.rb', line 19 def time_data_started @time_data_started end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
26 27 28 29 30 31 32 33 34 |
# File 'lib/oci/log_analytics/models/estimate_release_data_size_result.rb', line 26 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'time_data_ended': :'timeDataEnded', 'time_data_started': :'timeDataStarted', 'size_in_bytes': :'sizeInBytes' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
37 38 39 40 41 42 43 44 45 |
# File 'lib/oci/log_analytics/models/estimate_release_data_size_result.rb', line 37 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'time_data_ended': :'DateTime', 'time_data_started': :'DateTime', 'size_in_bytes': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
88 89 90 91 92 93 94 95 |
# File 'lib/oci/log_analytics/models/estimate_release_data_size_result.rb', line 88 def ==(other) return true if equal?(other) self.class == other.class && time_data_ended == other.time_data_ended && time_data_started == other.time_data_started && size_in_bytes == other.size_in_bytes end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/oci/log_analytics/models/estimate_release_data_size_result.rb', line 120 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
100 101 102 |
# File 'lib/oci/log_analytics/models/estimate_release_data_size_result.rb', line 100 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
109 110 111 |
# File 'lib/oci/log_analytics/models/estimate_release_data_size_result.rb', line 109 def hash [time_data_ended, time_data_started, size_in_bytes].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
153 154 155 156 157 158 159 160 161 162 |
# File 'lib/oci/log_analytics/models/estimate_release_data_size_result.rb', line 153 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
147 148 149 |
# File 'lib/oci/log_analytics/models/estimate_release_data_size_result.rb', line 147 def to_s to_hash.to_s end |