Class: OCI::LogAnalytics::Models::Filter

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/log_analytics/models/filter.rb

Overview

Query builder filter action to apply edit to queryString.

Constant Summary collapse

OPERATOR_ENUM =
[
  OPERATOR_CLEAR = 'CLEAR'.freeze,
  OPERATOR_REPLACE = 'REPLACE'.freeze,
  OPERATOR_EQUALS = 'EQUALS'.freeze,
  OPERATOR_NOT_EQUALS = 'NOT_EQUALS'.freeze,
  OPERATOR_STARTS_WITH = 'STARTS_WITH'.freeze,
  OPERATOR_DOES_NOT_START_WITH = 'DOES_NOT_START_WITH'.freeze,
  OPERATOR_ENDS_WITH = 'ENDS_WITH'.freeze,
  OPERATOR_DOES_NOT_END_WITH = 'DOES_NOT_END_WITH'.freeze,
  OPERATOR_CONTAINS = 'CONTAINS'.freeze,
  OPERATOR_DOES_NOT_CONTAIN = 'DOES_NOT_CONTAIN'.freeze,
  OPERATOR_IS_LESS_THAN = 'IS_LESS_THAN'.freeze,
  OPERATOR_IS_LESS_THAN_OR_EQUAL_TO = 'IS_LESS_THAN_OR_EQUAL_TO'.freeze,
  OPERATOR_IS_GREATER_THAN = 'IS_GREATER_THAN'.freeze,
  OPERATOR_IS_GREATER_THAN_OR_EQUAL_TO = 'IS_GREATER_THAN_OR_EQUAL_TO'.freeze,
  OPERATOR_IS_BETWEEN = 'IS_BETWEEN'.freeze,
  OPERATOR_IS_NOT_BETWEEN = 'IS_NOT_BETWEEN'.freeze,
  OPERATOR_ADD_SUBQUERY = 'ADD_SUBQUERY'.freeze,
  OPERATOR_CLEAR_SUBQUERY = 'CLEAR_SUBQUERY'.freeze,
  OPERATOR_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Filter

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :field_name (String)

    The value to assign to the #field_name property

  • :values (Array<Object>)

    The value to assign to the #values property

  • :operator (String)

    The value to assign to the #operator property



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/oci/log_analytics/models/filter.rb', line 80

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.field_name = attributes[:'fieldName'] if attributes[:'fieldName']

  raise 'You cannot provide both :fieldName and :field_name' if attributes.key?(:'fieldName') && attributes.key?(:'field_name')

  self.field_name = attributes[:'field_name'] if attributes[:'field_name']

  self.values = attributes[:'values'] if attributes[:'values']

  self.operator = attributes[:'operator'] if attributes[:'operator']
end

Instance Attribute Details

#field_nameString

Field filter references when inserting filter into the query string. Field must be a valid logging analytics out-of-the-box field, virtual field calculated in the query or a user defined field.

Returns:

  • (String)


37
38
39
# File 'lib/oci/log_analytics/models/filter.rb', line 37

def field_name
  @field_name
end

#operatorString

[Required] Operator to apply when editing the query string.

Returns:

  • (String)


47
48
49
# File 'lib/oci/log_analytics/models/filter.rb', line 47

def operator
  @operator
end

#valuesArray<Object>

Field values that will be inserted into the query string for the specified fieldName. Please note all values should reflect the fields data type otherwise the insert is subject to fail.

Returns:

  • (Array<Object>)


42
43
44
# File 'lib/oci/log_analytics/models/filter.rb', line 42

def values
  @values
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



50
51
52
53
54
55
56
57
58
# File 'lib/oci/log_analytics/models/filter.rb', line 50

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'field_name': :'fieldName',
    'values': :'values',
    'operator': :'operator'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



61
62
63
64
65
66
67
68
69
# File 'lib/oci/log_analytics/models/filter.rb', line 61

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'field_name': :'String',
    'values': :'Array<Object>',
    'operator': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



117
118
119
120
121
122
123
124
# File 'lib/oci/log_analytics/models/filter.rb', line 117

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    field_name == other.field_name &&
    values == other.values &&
    operator == other.operator
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/oci/log_analytics/models/filter.rb', line 149

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


129
130
131
# File 'lib/oci/log_analytics/models/filter.rb', line 129

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



138
139
140
# File 'lib/oci/log_analytics/models/filter.rb', line 138

def hash
  [field_name, values, operator].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



182
183
184
185
186
187
188
189
190
191
# File 'lib/oci/log_analytics/models/filter.rb', line 182

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



176
177
178
# File 'lib/oci/log_analytics/models/filter.rb', line 176

def to_s
  to_hash.to_s
end