Class: OCI::LogAnalytics::Models::GeoStatsCommandDescriptor

Inherits:
AbstractCommandDescriptor show all
Defined in:
lib/oci/log_analytics/models/geo_stats_command_descriptor.rb

Overview

Command descriptor for querylanguage GEOSTATS command. This is similiar to STATS with some built in functions for City, State and Country by Coordinates.

Constant Summary collapse

INCLUDE_ENUM =
[
  INCLUDE_CLIENT = 'CLIENT'.freeze,
  INCLUDE_SERVER = 'SERVER'.freeze,
  INCLUDE_CLIENT_AND_SERVER = 'CLIENT_AND_SERVER'.freeze,
  INCLUDE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Constants inherited from AbstractCommandDescriptor

AbstractCommandDescriptor::NAME_ENUM

Instance Attribute Summary collapse

Attributes inherited from AbstractCommandDescriptor

#category, #declared_fields, #display_query_string, #internal_query_string, #name, #referenced_fields

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from AbstractCommandDescriptor

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ GeoStatsCommandDescriptor

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/oci/log_analytics/models/geo_stats_command_descriptor.rb', line 83

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['name'] = 'GEO_STATS'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.include = attributes[:'include'] if attributes[:'include']

  self.group_by_fields = attributes[:'groupByFields'] if attributes[:'groupByFields']

  raise 'You cannot provide both :groupByFields and :group_by_fields' if attributes.key?(:'groupByFields') && attributes.key?(:'group_by_fields')

  self.group_by_fields = attributes[:'group_by_fields'] if attributes[:'group_by_fields']

  self.functions = attributes[:'functions'] if attributes[:'functions']
end

Instance Attribute Details

#functionsArray<OCI::LogAnalytics::Models::FunctionField>

Statistical functions specified in the query string. Atleast 1 is required for a GEOSTATS command.



33
34
35
# File 'lib/oci/log_analytics/models/geo_stats_command_descriptor.rb', line 33

def functions
  @functions
end

#group_by_fieldsArray<OCI::LogAnalytics::Models::AbstractField>

Group by fields if specified in the query string.



28
29
30
# File 'lib/oci/log_analytics/models/geo_stats_command_descriptor.rb', line 28

def group_by_fields
  @group_by_fields
end

#includeString

Indicates which coordinates to show. Either client, server or both. Defaults to client.

Returns:

  • (String)


23
24
25
# File 'lib/oci/log_analytics/models/geo_stats_command_descriptor.rb', line 23

def include
  @include
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
# File 'lib/oci/log_analytics/models/geo_stats_command_descriptor.rb', line 36

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'name': :'name',
    'display_query_string': :'displayQueryString',
    'internal_query_string': :'internalQueryString',
    'category': :'category',
    'referenced_fields': :'referencedFields',
    'declared_fields': :'declaredFields',
    'include': :'include',
    'group_by_fields': :'groupByFields',
    'functions': :'functions'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/oci/log_analytics/models/geo_stats_command_descriptor.rb', line 53

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'name': :'String',
    'display_query_string': :'String',
    'internal_query_string': :'String',
    'category': :'String',
    'referenced_fields': :'Array<OCI::LogAnalytics::Models::AbstractField>',
    'declared_fields': :'Array<OCI::LogAnalytics::Models::AbstractField>',
    'include': :'String',
    'group_by_fields': :'Array<OCI::LogAnalytics::Models::AbstractField>',
    'functions': :'Array<OCI::LogAnalytics::Models::FunctionField>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/oci/log_analytics/models/geo_stats_command_descriptor.rb', line 124

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    name == other.name &&
    display_query_string == other.display_query_string &&
    internal_query_string == other.internal_query_string &&
    category == other.category &&
    referenced_fields == other.referenced_fields &&
    declared_fields == other.declared_fields &&
    include == other.include &&
    group_by_fields == other.group_by_fields &&
    functions == other.functions
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/oci/log_analytics/models/geo_stats_command_descriptor.rb', line 162

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


142
143
144
# File 'lib/oci/log_analytics/models/geo_stats_command_descriptor.rb', line 142

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



151
152
153
# File 'lib/oci/log_analytics/models/geo_stats_command_descriptor.rb', line 151

def hash
  [name, display_query_string, internal_query_string, category, referenced_fields, declared_fields, include, group_by_fields, functions].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



195
196
197
198
199
200
201
202
203
204
# File 'lib/oci/log_analytics/models/geo_stats_command_descriptor.rb', line 195

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



189
190
191
# File 'lib/oci/log_analytics/models/geo_stats_command_descriptor.rb', line 189

def to_s
  to_hash.to_s
end