Class: OCI::LogAnalytics::Models::HighlightRowsCommandDescriptor

Inherits:
AbstractCommandDescriptor show all
Defined in:
lib/oci/log_analytics/models/highlight_rows_command_descriptor.rb

Overview

Command descriptor for querylanguage HIGHLIGHTROWS command.

Constant Summary

Constants inherited from AbstractCommandDescriptor

AbstractCommandDescriptor::NAME_ENUM

Instance Attribute Summary collapse

Attributes inherited from AbstractCommandDescriptor

#category, #declared_fields, #display_query_string, #internal_query_string, #name, #referenced_fields

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from AbstractCommandDescriptor

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ HighlightRowsCommandDescriptor

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/oci/log_analytics/models/highlight_rows_command_descriptor.rb', line 67

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['name'] = 'HIGHLIGHT_ROWS'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.color = attributes[:'color'] if attributes[:'color']

  self.keywords = attributes[:'keywords'] if attributes[:'keywords']
end

Instance Attribute Details

#colorString

User specified color to highlight matches with if found.

Returns:

  • (String)


15
16
17
# File 'lib/oci/log_analytics/models/highlight_rows_command_descriptor.rb', line 15

def color
  @color
end

#keywordsArray<String>

List of terms or phrases to find to mark the result row as highlighted.

Returns:

  • (Array<String>)


20
21
22
# File 'lib/oci/log_analytics/models/highlight_rows_command_descriptor.rb', line 20

def keywords
  @keywords
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



23
24
25
26
27
28
29
30
31
32
33
34
35
36
# File 'lib/oci/log_analytics/models/highlight_rows_command_descriptor.rb', line 23

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'name': :'name',
    'display_query_string': :'displayQueryString',
    'internal_query_string': :'internalQueryString',
    'category': :'category',
    'referenced_fields': :'referencedFields',
    'declared_fields': :'declaredFields',
    'color': :'color',
    'keywords': :'keywords'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



39
40
41
42
43
44
45
46
47
48
49
50
51
52
# File 'lib/oci/log_analytics/models/highlight_rows_command_descriptor.rb', line 39

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'name': :'String',
    'display_query_string': :'String',
    'internal_query_string': :'String',
    'category': :'String',
    'referenced_fields': :'Array<OCI::LogAnalytics::Models::AbstractField>',
    'declared_fields': :'Array<OCI::LogAnalytics::Models::AbstractField>',
    'color': :'String',
    'keywords': :'Array<String>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/oci/log_analytics/models/highlight_rows_command_descriptor.rb', line 89

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    name == other.name &&
    display_query_string == other.display_query_string &&
    internal_query_string == other.internal_query_string &&
    category == other.category &&
    referenced_fields == other.referenced_fields &&
    declared_fields == other.declared_fields &&
    color == other.color &&
    keywords == other.keywords
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'lib/oci/log_analytics/models/highlight_rows_command_descriptor.rb', line 126

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


106
107
108
# File 'lib/oci/log_analytics/models/highlight_rows_command_descriptor.rb', line 106

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



115
116
117
# File 'lib/oci/log_analytics/models/highlight_rows_command_descriptor.rb', line 115

def hash
  [name, display_query_string, internal_query_string, category, referenced_fields, declared_fields, color, keywords].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



159
160
161
162
163
164
165
166
167
168
# File 'lib/oci/log_analytics/models/highlight_rows_command_descriptor.rb', line 159

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



153
154
155
# File 'lib/oci/log_analytics/models/highlight_rows_command_descriptor.rb', line 153

def to_s
  to_hash.to_s
end