Class: OCI::LogAnalytics::Models::LabelSourceSummary
- Inherits:
-
Object
- Object
- OCI::LogAnalytics::Models::LabelSourceSummary
- Defined in:
- lib/oci/log_analytics/models/label_source_summary.rb
Overview
source summary
Instance Attribute Summary collapse
-
#label_condition ⇒ String
The label condition.
-
#label_field_displayname ⇒ String
The label field display name.
-
#label_field_name ⇒ String
The label field name.
-
#label_operator_name ⇒ String
The label operator.
-
#source_display_name ⇒ String
The source display name.
-
#source_id ⇒ Integer
The source unique identifier.
-
#source_name ⇒ String
The source internal name.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LabelSourceSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ LabelSourceSummary
Initializes the object
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/oci/log_analytics/models/label_source_summary.rb', line 81 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.source_display_name = attributes[:'sourceDisplayName'] if attributes[:'sourceDisplayName'] raise 'You cannot provide both :sourceDisplayName and :source_display_name' if attributes.key?(:'sourceDisplayName') && attributes.key?(:'source_display_name') self.source_display_name = attributes[:'source_display_name'] if attributes[:'source_display_name'] self.source_name = attributes[:'sourceName'] if attributes[:'sourceName'] raise 'You cannot provide both :sourceName and :source_name' if attributes.key?(:'sourceName') && attributes.key?(:'source_name') self.source_name = attributes[:'source_name'] if attributes[:'source_name'] self.source_id = attributes[:'sourceId'] if attributes[:'sourceId'] raise 'You cannot provide both :sourceId and :source_id' if attributes.key?(:'sourceId') && attributes.key?(:'source_id') self.source_id = attributes[:'source_id'] if attributes[:'source_id'] self.label_operator_name = attributes[:'labelOperatorName'] if attributes[:'labelOperatorName'] raise 'You cannot provide both :labelOperatorName and :label_operator_name' if attributes.key?(:'labelOperatorName') && attributes.key?(:'label_operator_name') self.label_operator_name = attributes[:'label_operator_name'] if attributes[:'label_operator_name'] self.label_condition = attributes[:'labelCondition'] if attributes[:'labelCondition'] raise 'You cannot provide both :labelCondition and :label_condition' if attributes.key?(:'labelCondition') && attributes.key?(:'label_condition') self.label_condition = attributes[:'label_condition'] if attributes[:'label_condition'] self.label_field_displayname = attributes[:'labelFieldDisplayname'] if attributes[:'labelFieldDisplayname'] raise 'You cannot provide both :labelFieldDisplayname and :label_field_displayname' if attributes.key?(:'labelFieldDisplayname') && attributes.key?(:'label_field_displayname') self.label_field_displayname = attributes[:'label_field_displayname'] if attributes[:'label_field_displayname'] self.label_field_name = attributes[:'labelFieldName'] if attributes[:'labelFieldName'] raise 'You cannot provide both :labelFieldName and :label_field_name' if attributes.key?(:'labelFieldName') && attributes.key?(:'label_field_name') self.label_field_name = attributes[:'label_field_name'] if attributes[:'label_field_name'] end |
Instance Attribute Details
#label_condition ⇒ String
The label condition.
28 29 30 |
# File 'lib/oci/log_analytics/models/label_source_summary.rb', line 28 def label_condition @label_condition end |
#label_field_displayname ⇒ String
The label field display name.
32 33 34 |
# File 'lib/oci/log_analytics/models/label_source_summary.rb', line 32 def label_field_displayname @label_field_displayname end |
#label_field_name ⇒ String
The label field name.
36 37 38 |
# File 'lib/oci/log_analytics/models/label_source_summary.rb', line 36 def label_field_name @label_field_name end |
#label_operator_name ⇒ String
The label operator.
24 25 26 |
# File 'lib/oci/log_analytics/models/label_source_summary.rb', line 24 def label_operator_name @label_operator_name end |
#source_display_name ⇒ String
The source display name.
12 13 14 |
# File 'lib/oci/log_analytics/models/label_source_summary.rb', line 12 def source_display_name @source_display_name end |
#source_id ⇒ Integer
The source unique identifier.
20 21 22 |
# File 'lib/oci/log_analytics/models/label_source_summary.rb', line 20 def source_id @source_id end |
#source_name ⇒ String
The source internal name.
16 17 18 |
# File 'lib/oci/log_analytics/models/label_source_summary.rb', line 16 def source_name @source_name end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/oci/log_analytics/models/label_source_summary.rb', line 39 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'source_display_name': :'sourceDisplayName', 'source_name': :'sourceName', 'source_id': :'sourceId', 'label_operator_name': :'labelOperatorName', 'label_condition': :'labelCondition', 'label_field_displayname': :'labelFieldDisplayname', 'label_field_name': :'labelFieldName' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/oci/log_analytics/models/label_source_summary.rb', line 54 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'source_display_name': :'String', 'source_name': :'String', 'source_id': :'Integer', 'label_operator_name': :'String', 'label_condition': :'String', 'label_field_displayname': :'String', 'label_field_name': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/oci/log_analytics/models/label_source_summary.rb', line 137 def ==(other) return true if equal?(other) self.class == other.class && source_display_name == other.source_display_name && source_name == other.source_name && source_id == other.source_id && label_operator_name == other.label_operator_name && label_condition == other.label_condition && label_field_displayname == other.label_field_displayname && label_field_name == other.label_field_name end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/oci/log_analytics/models/label_source_summary.rb', line 173 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
153 154 155 |
# File 'lib/oci/log_analytics/models/label_source_summary.rb', line 153 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
162 163 164 |
# File 'lib/oci/log_analytics/models/label_source_summary.rb', line 162 def hash [source_display_name, source_name, source_id, label_operator_name, label_condition, label_field_displayname, label_field_name].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
206 207 208 209 210 211 212 213 214 215 |
# File 'lib/oci/log_analytics/models/label_source_summary.rb', line 206 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
200 201 202 |
# File 'lib/oci/log_analytics/models/label_source_summary.rb', line 200 def to_s to_hash.to_s end |