Class: OCI::LogAnalytics::Models::LinkCommandDescriptor
- Inherits:
-
AbstractCommandDescriptor
- Object
- AbstractCommandDescriptor
- OCI::LogAnalytics::Models::LinkCommandDescriptor
- Defined in:
- lib/oci/log_analytics/models/link_command_descriptor.rb
Overview
Command descriptor for querylanguage LINK command.
Constant Summary
Constants inherited from AbstractCommandDescriptor
AbstractCommandDescriptor::NAME_ENUM
Instance Attribute Summary collapse
-
#should_include_nulls ⇒ BOOLEAN
Option to return groups with a null value if specified.
-
#should_include_trends ⇒ BOOLEAN
Option to calculate trends of each group if specified.
-
#span ⇒ String
Option to control the size of buckets in the histogram e.g 8hrs - each bar other than first and last should represent 8hr time span.
Attributes inherited from AbstractCommandDescriptor
#category, #declared_fields, #display_query_string, #internal_query_string, #name, #referenced_fields
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LinkCommandDescriptor
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from AbstractCommandDescriptor
Constructor Details
#initialize(attributes = {}) ⇒ LinkCommandDescriptor
Initializes the object
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/oci/log_analytics/models/link_command_descriptor.rb', line 75 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['name'] = 'LINK' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.should_include_nulls = attributes[:'shouldIncludeNulls'] unless attributes[:'shouldIncludeNulls'].nil? self.should_include_nulls = false if should_include_nulls.nil? && !attributes.key?(:'shouldIncludeNulls') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :shouldIncludeNulls and :should_include_nulls' if attributes.key?(:'shouldIncludeNulls') && attributes.key?(:'should_include_nulls') self.should_include_nulls = attributes[:'should_include_nulls'] unless attributes[:'should_include_nulls'].nil? self.should_include_nulls = false if should_include_nulls.nil? && !attributes.key?(:'shouldIncludeNulls') && !attributes.key?(:'should_include_nulls') # rubocop:disable Style/StringLiterals self.should_include_trends = attributes[:'shouldIncludeTrends'] unless attributes[:'shouldIncludeTrends'].nil? self.should_include_trends = false if should_include_trends.nil? && !attributes.key?(:'shouldIncludeTrends') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :shouldIncludeTrends and :should_include_trends' if attributes.key?(:'shouldIncludeTrends') && attributes.key?(:'should_include_trends') self.should_include_trends = attributes[:'should_include_trends'] unless attributes[:'should_include_trends'].nil? self.should_include_trends = false if should_include_trends.nil? && !attributes.key?(:'shouldIncludeTrends') && !attributes.key?(:'should_include_trends') # rubocop:disable Style/StringLiterals self.span = attributes[:'span'] if attributes[:'span'] end |
Instance Attribute Details
#should_include_nulls ⇒ BOOLEAN
Option to return groups with a null value if specified.
15 16 17 |
# File 'lib/oci/log_analytics/models/link_command_descriptor.rb', line 15 def should_include_nulls @should_include_nulls end |
#should_include_trends ⇒ BOOLEAN
Option to calculate trends of each group if specified.
20 21 22 |
# File 'lib/oci/log_analytics/models/link_command_descriptor.rb', line 20 def should_include_trends @should_include_trends end |
#span ⇒ String
Option to control the size of buckets in the histogram e.g 8hrs - each bar other than first and last should represent 8hr time span. Will be adjusted to a larger span if time range is very large.
25 26 27 |
# File 'lib/oci/log_analytics/models/link_command_descriptor.rb', line 25 def span @span end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 |
# File 'lib/oci/log_analytics/models/link_command_descriptor.rb', line 28 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'display_query_string': :'displayQueryString', 'internal_query_string': :'internalQueryString', 'category': :'category', 'referenced_fields': :'referencedFields', 'declared_fields': :'declaredFields', 'should_include_nulls': :'shouldIncludeNulls', 'should_include_trends': :'shouldIncludeTrends', 'span': :'span' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/oci/log_analytics/models/link_command_descriptor.rb', line 45 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'display_query_string': :'String', 'internal_query_string': :'String', 'category': :'String', 'referenced_fields': :'Array<OCI::LogAnalytics::Models::AbstractField>', 'declared_fields': :'Array<OCI::LogAnalytics::Models::AbstractField>', 'should_include_nulls': :'BOOLEAN', 'should_include_trends': :'BOOLEAN', 'span': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/oci/log_analytics/models/link_command_descriptor.rb', line 111 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && display_query_string == other.display_query_string && internal_query_string == other.internal_query_string && category == other.category && referenced_fields == other.referenced_fields && declared_fields == other.declared_fields && should_include_nulls == other.should_include_nulls && should_include_trends == other.should_include_trends && span == other.span end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/oci/log_analytics/models/link_command_descriptor.rb', line 149 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
129 130 131 |
# File 'lib/oci/log_analytics/models/link_command_descriptor.rb', line 129 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
138 139 140 |
# File 'lib/oci/log_analytics/models/link_command_descriptor.rb', line 138 def hash [name, display_query_string, internal_query_string, category, referenced_fields, declared_fields, should_include_nulls, should_include_trends, span].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
182 183 184 185 186 187 188 189 190 191 |
# File 'lib/oci/log_analytics/models/link_command_descriptor.rb', line 182 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
176 177 178 |
# File 'lib/oci/log_analytics/models/link_command_descriptor.rb', line 176 def to_s to_hash.to_s end |