Class: OCI::LogAnalytics::Models::LogAnalyticsAssociatedEntity
- Inherits:
-
Object
- Object
- OCI::LogAnalytics::Models::LogAnalyticsAssociatedEntity
- Defined in:
- lib/oci/log_analytics/models/log_analytics_associated_entity.rb
Overview
LogAnalyticsAssociatedEntity
Instance Attribute Summary collapse
-
#association_count ⇒ Integer
The association count for the entity.
-
#entity_id ⇒ String
The entity unique identifier.
-
#entity_name ⇒ String
The entity name.
-
#entity_type ⇒ String
The entity type.
-
#entity_type_display_name ⇒ String
The entity type display name.
-
#on_host ⇒ String
The host associated with the entity.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LogAnalyticsAssociatedEntity
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ LogAnalyticsAssociatedEntity
Initializes the object
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/oci/log_analytics/models/log_analytics_associated_entity.rb', line 74 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.entity_id = attributes[:'entityId'] if attributes[:'entityId'] raise 'You cannot provide both :entityId and :entity_id' if attributes.key?(:'entityId') && attributes.key?(:'entity_id') self.entity_id = attributes[:'entity_id'] if attributes[:'entity_id'] self.entity_name = attributes[:'entityName'] if attributes[:'entityName'] raise 'You cannot provide both :entityName and :entity_name' if attributes.key?(:'entityName') && attributes.key?(:'entity_name') self.entity_name = attributes[:'entity_name'] if attributes[:'entity_name'] self.entity_type = attributes[:'entityType'] if attributes[:'entityType'] raise 'You cannot provide both :entityType and :entity_type' if attributes.key?(:'entityType') && attributes.key?(:'entity_type') self.entity_type = attributes[:'entity_type'] if attributes[:'entity_type'] self.entity_type_display_name = attributes[:'entityTypeDisplayName'] if attributes[:'entityTypeDisplayName'] raise 'You cannot provide both :entityTypeDisplayName and :entity_type_display_name' if attributes.key?(:'entityTypeDisplayName') && attributes.key?(:'entity_type_display_name') self.entity_type_display_name = attributes[:'entity_type_display_name'] if attributes[:'entity_type_display_name'] self.on_host = attributes[:'onHost'] if attributes[:'onHost'] raise 'You cannot provide both :onHost and :on_host' if attributes.key?(:'onHost') && attributes.key?(:'on_host') self.on_host = attributes[:'on_host'] if attributes[:'on_host'] self.association_count = attributes[:'associationCount'] if attributes[:'associationCount'] raise 'You cannot provide both :associationCount and :association_count' if attributes.key?(:'associationCount') && attributes.key?(:'association_count') self.association_count = attributes[:'association_count'] if attributes[:'association_count'] end |
Instance Attribute Details
#association_count ⇒ Integer
The association count for the entity.
32 33 34 |
# File 'lib/oci/log_analytics/models/log_analytics_associated_entity.rb', line 32 def association_count @association_count end |
#entity_id ⇒ String
The entity unique identifier.
12 13 14 |
# File 'lib/oci/log_analytics/models/log_analytics_associated_entity.rb', line 12 def entity_id @entity_id end |
#entity_name ⇒ String
The entity name.
16 17 18 |
# File 'lib/oci/log_analytics/models/log_analytics_associated_entity.rb', line 16 def entity_name @entity_name end |
#entity_type ⇒ String
The entity type.
20 21 22 |
# File 'lib/oci/log_analytics/models/log_analytics_associated_entity.rb', line 20 def entity_type @entity_type end |
#entity_type_display_name ⇒ String
The entity type display name.
24 25 26 |
# File 'lib/oci/log_analytics/models/log_analytics_associated_entity.rb', line 24 def entity_type_display_name @entity_type_display_name end |
#on_host ⇒ String
The host associated with the entity.
28 29 30 |
# File 'lib/oci/log_analytics/models/log_analytics_associated_entity.rb', line 28 def on_host @on_host end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/oci/log_analytics/models/log_analytics_associated_entity.rb', line 35 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'entity_id': :'entityId', 'entity_name': :'entityName', 'entity_type': :'entityType', 'entity_type_display_name': :'entityTypeDisplayName', 'on_host': :'onHost', 'association_count': :'associationCount' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/oci/log_analytics/models/log_analytics_associated_entity.rb', line 49 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'entity_id': :'String', 'entity_name': :'String', 'entity_type': :'String', 'entity_type_display_name': :'String', 'on_host': :'String', 'association_count': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/oci/log_analytics/models/log_analytics_associated_entity.rb', line 124 def ==(other) return true if equal?(other) self.class == other.class && entity_id == other.entity_id && entity_name == other.entity_name && entity_type == other.entity_type && entity_type_display_name == other.entity_type_display_name && on_host == other.on_host && association_count == other.association_count end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/oci/log_analytics/models/log_analytics_associated_entity.rb', line 159 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
139 140 141 |
# File 'lib/oci/log_analytics/models/log_analytics_associated_entity.rb', line 139 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
148 149 150 |
# File 'lib/oci/log_analytics/models/log_analytics_associated_entity.rb', line 148 def hash [entity_id, entity_name, entity_type, entity_type_display_name, on_host, association_count].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
192 193 194 195 196 197 198 199 200 201 |
# File 'lib/oci/log_analytics/models/log_analytics_associated_entity.rb', line 192 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
186 187 188 |
# File 'lib/oci/log_analytics/models/log_analytics_associated_entity.rb', line 186 def to_s to_hash.to_s end |