Class: OCI::LogAnalytics::Models::LogAnalyticsEntitySummaryReport
- Inherits:
-
Object
- Object
- OCI::LogAnalytics::Models::LogAnalyticsEntitySummaryReport
- Defined in:
- lib/oci/log_analytics/models/log_analytics_entity_summary_report.rb
Overview
Log-Analytics entity counts summary.
Instance Attribute Summary collapse
-
#active_entities_count ⇒ Integer
[Required] Total number of ACTIVE entities.
-
#compartment_id ⇒ String
[Required] Compartment Identifier [OCID] (docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
-
#entities_with_has_logs_collected_count ⇒ Integer
[Required] Entities with log collection enabled.
-
#entities_with_management_agent_count ⇒ Integer
[Required] Entities with management agent.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LogAnalyticsEntitySummaryReport
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ LogAnalyticsEntitySummaryReport
Initializes the object
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/oci/log_analytics/models/log_analytics_entity_summary_report.rb', line 64 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.active_entities_count = attributes[:'activeEntitiesCount'] if attributes[:'activeEntitiesCount'] raise 'You cannot provide both :activeEntitiesCount and :active_entities_count' if attributes.key?(:'activeEntitiesCount') && attributes.key?(:'active_entities_count') self.active_entities_count = attributes[:'active_entities_count'] if attributes[:'active_entities_count'] self.entities_with_has_logs_collected_count = attributes[:'entitiesWithHasLogsCollectedCount'] if attributes[:'entitiesWithHasLogsCollectedCount'] raise 'You cannot provide both :entitiesWithHasLogsCollectedCount and :entities_with_has_logs_collected_count' if attributes.key?(:'entitiesWithHasLogsCollectedCount') && attributes.key?(:'entities_with_has_logs_collected_count') self.entities_with_has_logs_collected_count = attributes[:'entities_with_has_logs_collected_count'] if attributes[:'entities_with_has_logs_collected_count'] self.entities_with_management_agent_count = attributes[:'entitiesWithManagementAgentCount'] if attributes[:'entitiesWithManagementAgentCount'] raise 'You cannot provide both :entitiesWithManagementAgentCount and :entities_with_management_agent_count' if attributes.key?(:'entitiesWithManagementAgentCount') && attributes.key?(:'entities_with_management_agent_count') self.entities_with_management_agent_count = attributes[:'entities_with_management_agent_count'] if attributes[:'entities_with_management_agent_count'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] end |
Instance Attribute Details
#active_entities_count ⇒ Integer
[Required] Total number of ACTIVE entities
14 15 16 |
# File 'lib/oci/log_analytics/models/log_analytics_entity_summary_report.rb', line 14 def active_entities_count @active_entities_count end |
#compartment_id ⇒ String
[Required] Compartment Identifier [OCID] (docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
28 29 30 |
# File 'lib/oci/log_analytics/models/log_analytics_entity_summary_report.rb', line 28 def compartment_id @compartment_id end |
#entities_with_has_logs_collected_count ⇒ Integer
[Required] Entities with log collection enabled
19 20 21 |
# File 'lib/oci/log_analytics/models/log_analytics_entity_summary_report.rb', line 19 def entities_with_has_logs_collected_count @entities_with_has_logs_collected_count end |
#entities_with_management_agent_count ⇒ Integer
[Required] Entities with management agent
24 25 26 |
# File 'lib/oci/log_analytics/models/log_analytics_entity_summary_report.rb', line 24 def entities_with_management_agent_count @entities_with_management_agent_count end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 40 |
# File 'lib/oci/log_analytics/models/log_analytics_entity_summary_report.rb', line 31 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'active_entities_count': :'activeEntitiesCount', 'entities_with_has_logs_collected_count': :'entitiesWithHasLogsCollectedCount', 'entities_with_management_agent_count': :'entitiesWithManagementAgentCount', 'compartment_id': :'compartmentId' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
43 44 45 46 47 48 49 50 51 52 |
# File 'lib/oci/log_analytics/models/log_analytics_entity_summary_report.rb', line 43 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'active_entities_count': :'Integer', 'entities_with_has_logs_collected_count': :'Integer', 'entities_with_management_agent_count': :'Integer', 'compartment_id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
102 103 104 105 106 107 108 109 110 |
# File 'lib/oci/log_analytics/models/log_analytics_entity_summary_report.rb', line 102 def ==(other) return true if equal?(other) self.class == other.class && active_entities_count == other.active_entities_count && entities_with_has_logs_collected_count == other.entities_with_has_logs_collected_count && entities_with_management_agent_count == other.entities_with_management_agent_count && compartment_id == other.compartment_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/oci/log_analytics/models/log_analytics_entity_summary_report.rb', line 135 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
115 116 117 |
# File 'lib/oci/log_analytics/models/log_analytics_entity_summary_report.rb', line 115 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
124 125 126 |
# File 'lib/oci/log_analytics/models/log_analytics_entity_summary_report.rb', line 124 def hash [active_entities_count, entities_with_has_logs_collected_count, entities_with_management_agent_count, compartment_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
168 169 170 171 172 173 174 175 176 177 |
# File 'lib/oci/log_analytics/models/log_analytics_entity_summary_report.rb', line 168 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
162 163 164 |
# File 'lib/oci/log_analytics/models/log_analytics_entity_summary_report.rb', line 162 def to_s to_hash.to_s end |