Class: OCI::LogAnalytics::Models::LogAnalyticsEntityType

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/log_analytics/models/log_analytics_entity_type.rb

Overview

Description of log analytics entity type.

Constant Summary collapse

CLOUD_TYPE_ENUM =
[
  CLOUD_TYPE_CLOUD = 'CLOUD'.freeze,
  CLOUD_TYPE_NON_CLOUD = 'NON_CLOUD'.freeze,
  CLOUD_TYPE_ALL = 'ALL'.freeze,
  CLOUD_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
MANAGEMENT_AGENT_ELIGIBILITY_STATUS_ENUM =
[
  MANAGEMENT_AGENT_ELIGIBILITY_STATUS_ELIGIBLE = 'ELIGIBLE'.freeze,
  MANAGEMENT_AGENT_ELIGIBILITY_STATUS_INELIGIBLE = 'INELIGIBLE'.freeze,
  MANAGEMENT_AGENT_ELIGIBILITY_STATUS_UNKNOWN = 'UNKNOWN'.freeze,
  MANAGEMENT_AGENT_ELIGIBILITY_STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ LogAnalyticsEntityType

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/oci/log_analytics/models/log_analytics_entity_type.rb', line 133

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.name = attributes[:'name'] if attributes[:'name']

  self.internal_name = attributes[:'internalName'] if attributes[:'internalName']

  raise 'You cannot provide both :internalName and :internal_name' if attributes.key?(:'internalName') && attributes.key?(:'internal_name')

  self.internal_name = attributes[:'internal_name'] if attributes[:'internal_name']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.category = attributes[:'category'] if attributes[:'category']

  self.cloud_type = attributes[:'cloudType'] if attributes[:'cloudType']

  raise 'You cannot provide both :cloudType and :cloud_type' if attributes.key?(:'cloudType') && attributes.key?(:'cloud_type')

  self.cloud_type = attributes[:'cloud_type'] if attributes[:'cloud_type']

  self.properties = attributes[:'properties'] if attributes[:'properties']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.management_agent_eligibility_status = attributes[:'managementAgentEligibilityStatus'] if attributes[:'managementAgentEligibilityStatus']

  raise 'You cannot provide both :managementAgentEligibilityStatus and :management_agent_eligibility_status' if attributes.key?(:'managementAgentEligibilityStatus') && attributes.key?(:'management_agent_eligibility_status')

  self.management_agent_eligibility_status = attributes[:'management_agent_eligibility_status'] if attributes[:'management_agent_eligibility_status']
end

Instance Attribute Details

#categoryString

[Required] Log analytics entity type category. Category will be used for grouping and filtering.

Returns:

  • (String)


49
50
51
# File 'lib/oci/log_analytics/models/log_analytics_entity_type.rb', line 49

def category
  @category
end

#cloud_typeString

[Required] Log analytics entity type group. That can be CLOUD (OCI) or NON_CLOUD otherwise.

Returns:

  • (String)


54
55
56
# File 'lib/oci/log_analytics/models/log_analytics_entity_type.rb', line 54

def cloud_type
  @cloud_type
end

#compartment_idString

Returns:

  • (String)


44
45
46
# File 'lib/oci/log_analytics/models/log_analytics_entity_type.rb', line 44

def compartment_id
  @compartment_id
end

#internal_nameString

[Required] Internal name for the log analytics entity type.

Returns:

  • (String)


40
41
42
# File 'lib/oci/log_analytics/models/log_analytics_entity_type.rb', line 40

def internal_name
  @internal_name
end

#lifecycle_stateString

[Required] The current lifecycle state of the log analytics entity.

Returns:

  • (String)


64
65
66
# File 'lib/oci/log_analytics/models/log_analytics_entity_type.rb', line 64

def lifecycle_state
  @lifecycle_state
end

#management_agent_eligibility_statusString

This field indicates whether logs for entities of this type can be collected using a management agent.

Returns:

  • (String)


79
80
81
# File 'lib/oci/log_analytics/models/log_analytics_entity_type.rb', line 79

def management_agent_eligibility_status
  @management_agent_eligibility_status
end

#nameString

[Required] Log analytics entity type name.

Returns:

  • (String)


35
36
37
# File 'lib/oci/log_analytics/models/log_analytics_entity_type.rb', line 35

def name
  @name
end

#propertiesArray<OCI::LogAnalytics::Models::EntityTypeProperty>

The parameters used in file patterns specified in log sources for this log analytics entity type.



59
60
61
# File 'lib/oci/log_analytics/models/log_analytics_entity_type.rb', line 59

def properties
  @properties
end

#time_createdDateTime

[Required] Time the log analytics entity type was created. An RFC3339 formatted datetime string.

Returns:

  • (DateTime)


69
70
71
# File 'lib/oci/log_analytics/models/log_analytics_entity_type.rb', line 69

def time_created
  @time_created
end

#time_updatedDateTime

[Required] Time the log analytics entity type was updated. An RFC3339 formatted datetime string.

Returns:

  • (DateTime)


74
75
76
# File 'lib/oci/log_analytics/models/log_analytics_entity_type.rb', line 74

def time_updated
  @time_updated
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/oci/log_analytics/models/log_analytics_entity_type.rb', line 82

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'name': :'name',
    'internal_name': :'internalName',
    'compartment_id': :'compartmentId',
    'category': :'category',
    'cloud_type': :'cloudType',
    'properties': :'properties',
    'lifecycle_state': :'lifecycleState',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'management_agent_eligibility_status': :'managementAgentEligibilityStatus'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/oci/log_analytics/models/log_analytics_entity_type.rb', line 100

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'name': :'String',
    'internal_name': :'String',
    'compartment_id': :'String',
    'category': :'String',
    'cloud_type': :'String',
    'properties': :'Array<OCI::LogAnalytics::Models::EntityTypeProperty>',
    'lifecycle_state': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'management_agent_eligibility_status': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
# File 'lib/oci/log_analytics/models/log_analytics_entity_type.rb', line 234

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    name == other.name &&
    internal_name == other.internal_name &&
    compartment_id == other.compartment_id &&
    category == other.category &&
    cloud_type == other.cloud_type &&
    properties == other.properties &&
    lifecycle_state == other.lifecycle_state &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    management_agent_eligibility_status == other.management_agent_eligibility_status
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
# File 'lib/oci/log_analytics/models/log_analytics_entity_type.rb', line 273

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


253
254
255
# File 'lib/oci/log_analytics/models/log_analytics_entity_type.rb', line 253

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



262
263
264
# File 'lib/oci/log_analytics/models/log_analytics_entity_type.rb', line 262

def hash
  [name, internal_name, compartment_id, category, cloud_type, properties, lifecycle_state, time_created, time_updated, management_agent_eligibility_status].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



306
307
308
309
310
311
312
313
314
315
# File 'lib/oci/log_analytics/models/log_analytics_entity_type.rb', line 306

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



300
301
302
# File 'lib/oci/log_analytics/models/log_analytics_entity_type.rb', line 300

def to_s
  to_hash.to_s
end