Class: OCI::LogAnalytics::Models::LogAnalyticsImportCustomContent
- Inherits:
-
Object
- Object
- OCI::LogAnalytics::Models::LogAnalyticsImportCustomContent
- Defined in:
- lib/oci/log_analytics/models/log_analytics_import_custom_content.rb
Overview
LogAnalyticsImportCustomContent
Instance Attribute Summary collapse
- #change_list ⇒ OCI::LogAnalytics::Models::LogAnalyticsImportCustomChangeList
-
#content_name ⇒ String
The content name.
-
#field_names ⇒ Array<String>
The field names.
-
#parser_names ⇒ Array<String>
The parser names.
-
#source_names ⇒ Array<String>
The source names.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LogAnalyticsImportCustomContent
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ LogAnalyticsImportCustomContent
Initializes the object
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/oci/log_analytics/models/log_analytics_import_custom_content.rb', line 66 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.parser_names = attributes[:'parserNames'] if attributes[:'parserNames'] raise 'You cannot provide both :parserNames and :parser_names' if attributes.key?(:'parserNames') && attributes.key?(:'parser_names') self.parser_names = attributes[:'parser_names'] if attributes[:'parser_names'] self.source_names = attributes[:'sourceNames'] if attributes[:'sourceNames'] raise 'You cannot provide both :sourceNames and :source_names' if attributes.key?(:'sourceNames') && attributes.key?(:'source_names') self.source_names = attributes[:'source_names'] if attributes[:'source_names'] self.field_names = attributes[:'fieldNames'] if attributes[:'fieldNames'] raise 'You cannot provide both :fieldNames and :field_names' if attributes.key?(:'fieldNames') && attributes.key?(:'field_names') self.field_names = attributes[:'field_names'] if attributes[:'field_names'] self.change_list = attributes[:'changeList'] if attributes[:'changeList'] raise 'You cannot provide both :changeList and :change_list' if attributes.key?(:'changeList') && attributes.key?(:'change_list') self.change_list = attributes[:'change_list'] if attributes[:'change_list'] self.content_name = attributes[:'contentName'] if attributes[:'contentName'] raise 'You cannot provide both :contentName and :content_name' if attributes.key?(:'contentName') && attributes.key?(:'content_name') self.content_name = attributes[:'content_name'] if attributes[:'content_name'] end |
Instance Attribute Details
#change_list ⇒ OCI::LogAnalytics::Models::LogAnalyticsImportCustomChangeList
23 24 25 |
# File 'lib/oci/log_analytics/models/log_analytics_import_custom_content.rb', line 23 def change_list @change_list end |
#content_name ⇒ String
The content name.
27 28 29 |
# File 'lib/oci/log_analytics/models/log_analytics_import_custom_content.rb', line 27 def content_name @content_name end |
#field_names ⇒ Array<String>
The field names.
20 21 22 |
# File 'lib/oci/log_analytics/models/log_analytics_import_custom_content.rb', line 20 def field_names @field_names end |
#parser_names ⇒ Array<String>
The parser names.
12 13 14 |
# File 'lib/oci/log_analytics/models/log_analytics_import_custom_content.rb', line 12 def parser_names @parser_names end |
#source_names ⇒ Array<String>
The source names.
16 17 18 |
# File 'lib/oci/log_analytics/models/log_analytics_import_custom_content.rb', line 16 def source_names @source_names end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
30 31 32 33 34 35 36 37 38 39 40 |
# File 'lib/oci/log_analytics/models/log_analytics_import_custom_content.rb', line 30 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'parser_names': :'parserNames', 'source_names': :'sourceNames', 'field_names': :'fieldNames', 'change_list': :'changeList', 'content_name': :'contentName' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/oci/log_analytics/models/log_analytics_import_custom_content.rb', line 43 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'parser_names': :'Array<String>', 'source_names': :'Array<String>', 'field_names': :'Array<String>', 'change_list': :'OCI::LogAnalytics::Models::LogAnalyticsImportCustomChangeList', 'content_name': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
110 111 112 113 114 115 116 117 118 119 |
# File 'lib/oci/log_analytics/models/log_analytics_import_custom_content.rb', line 110 def ==(other) return true if equal?(other) self.class == other.class && parser_names == other.parser_names && source_names == other.source_names && field_names == other.field_names && change_list == other.change_list && content_name == other.content_name end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/oci/log_analytics/models/log_analytics_import_custom_content.rb', line 144 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
124 125 126 |
# File 'lib/oci/log_analytics/models/log_analytics_import_custom_content.rb', line 124 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
133 134 135 |
# File 'lib/oci/log_analytics/models/log_analytics_import_custom_content.rb', line 133 def hash [parser_names, source_names, field_names, change_list, content_name].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
177 178 179 180 181 182 183 184 185 186 |
# File 'lib/oci/log_analytics/models/log_analytics_import_custom_content.rb', line 177 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
171 172 173 |
# File 'lib/oci/log_analytics/models/log_analytics_import_custom_content.rb', line 171 def to_s to_hash.to_s end |