Class: OCI::LogAnalytics::Models::LogAnalyticsLabelAlias

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/log_analytics/models/log_analytics_label_alias.rb

Overview

Label alias mapping view

Constant Summary collapse

PRIORITY_ENUM =
[
  PRIORITY_NONE = 'NONE'.freeze,
  PRIORITY_LOW = 'LOW'.freeze,
  PRIORITY_MEDIUM = 'MEDIUM'.freeze,
  PRIORITY_HIGH = 'HIGH'.freeze,
  PRIORITY_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ LogAnalyticsLabelAlias

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :_alias (String)

    The value to assign to the #_alias property

  • :alias_display_name (String)

    The value to assign to the #alias_display_name property

  • :is_system (BOOLEAN)

    The value to assign to the #is_system property

  • :display_name (String)

    The value to assign to the #display_name property

  • :name (String)

    The value to assign to the #name property

  • :priority (String)

    The value to assign to the #priority property



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/oci/log_analytics/models/log_analytics_label_alias.rb', line 85

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self._alias = attributes[:'alias'] if attributes[:'alias']

  raise 'You cannot provide both :alias and :_alias' if attributes.key?(:'alias') && attributes.key?(:'_alias')

  self._alias = attributes[:'_alias'] if attributes[:'_alias']

  self.alias_display_name = attributes[:'aliasDisplayName'] if attributes[:'aliasDisplayName']

  raise 'You cannot provide both :aliasDisplayName and :alias_display_name' if attributes.key?(:'aliasDisplayName') && attributes.key?(:'alias_display_name')

  self.alias_display_name = attributes[:'alias_display_name'] if attributes[:'alias_display_name']

  self.is_system = attributes[:'isSystem'] unless attributes[:'isSystem'].nil?

  raise 'You cannot provide both :isSystem and :is_system' if attributes.key?(:'isSystem') && attributes.key?(:'is_system')

  self.is_system = attributes[:'is_system'] unless attributes[:'is_system'].nil?

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.name = attributes[:'name'] if attributes[:'name']

  self.priority = attributes[:'priority'] if attributes[:'priority']
  self.priority = "NONE" if priority.nil? && !attributes.key?(:'priority') # rubocop:disable Style/StringLiterals
end

Instance Attribute Details

#_aliasString

The alias.

Returns:

  • (String)


21
22
23
# File 'lib/oci/log_analytics/models/log_analytics_label_alias.rb', line 21

def _alias
  @_alias
end

#alias_display_nameString

The alias display name.

Returns:

  • (String)


25
26
27
# File 'lib/oci/log_analytics/models/log_analytics_label_alias.rb', line 25

def alias_display_name
  @alias_display_name
end

#display_nameString

The label display name.

Returns:

  • (String)


35
36
37
# File 'lib/oci/log_analytics/models/log_analytics_label_alias.rb', line 35

def display_name
  @display_name
end

#is_systemBOOLEAN

The system flag. A value of false denotes a custom, or user defined object. A value of true denotes a built in object.

Returns:

  • (BOOLEAN)


31
32
33
# File 'lib/oci/log_analytics/models/log_analytics_label_alias.rb', line 31

def is_system
  @is_system
end

#nameString

The label name.

Returns:

  • (String)


39
40
41
# File 'lib/oci/log_analytics/models/log_analytics_label_alias.rb', line 39

def name
  @name
end

#priorityString

The label priority. Default value is NONE.

Returns:

  • (String)


43
44
45
# File 'lib/oci/log_analytics/models/log_analytics_label_alias.rb', line 43

def priority
  @priority
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



46
47
48
49
50
51
52
53
54
55
56
57
# File 'lib/oci/log_analytics/models/log_analytics_label_alias.rb', line 46

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    '_alias': :'alias',
    'alias_display_name': :'aliasDisplayName',
    'is_system': :'isSystem',
    'display_name': :'displayName',
    'name': :'name',
    'priority': :'priority'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/oci/log_analytics/models/log_analytics_label_alias.rb', line 60

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    '_alias': :'String',
    'alias_display_name': :'String',
    'is_system': :'BOOLEAN',
    'display_name': :'String',
    'name': :'String',
    'priority': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



141
142
143
144
145
146
147
148
149
150
151
# File 'lib/oci/log_analytics/models/log_analytics_label_alias.rb', line 141

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    _alias == other._alias &&
    alias_display_name == other.alias_display_name &&
    is_system == other.is_system &&
    display_name == other.display_name &&
    name == other.name &&
    priority == other.priority
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/oci/log_analytics/models/log_analytics_label_alias.rb', line 176

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


156
157
158
# File 'lib/oci/log_analytics/models/log_analytics_label_alias.rb', line 156

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



165
166
167
# File 'lib/oci/log_analytics/models/log_analytics_label_alias.rb', line 165

def hash
  [_alias, alias_display_name, is_system, display_name, name, priority].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



209
210
211
212
213
214
215
216
217
218
# File 'lib/oci/log_analytics/models/log_analytics_label_alias.rb', line 209

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



203
204
205
# File 'lib/oci/log_analytics/models/log_analytics_label_alias.rb', line 203

def to_s
  to_hash.to_s
end