Class: OCI::LogAnalytics::Models::LogAnalyticsLabelDefinition
- Inherits:
-
Object
- Object
- OCI::LogAnalytics::Models::LogAnalyticsLabelDefinition
- Defined in:
- lib/oci/log_analytics/models/log_analytics_label_definition.rb
Overview
LogAnalyticsLabelDefinition
Instance Attribute Summary collapse
-
#edit_version ⇒ Integer
The edit version.
-
#is_system ⇒ BOOLEAN
The system flag.
-
#label_name ⇒ String
The label name.
-
#source_id ⇒ Integer
The source unique identifier.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LogAnalyticsLabelDefinition
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ LogAnalyticsLabelDefinition
Initializes the object
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/oci/log_analytics/models/log_analytics_label_definition.rb', line 62 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.edit_version = attributes[:'editVersion'] if attributes[:'editVersion'] raise 'You cannot provide both :editVersion and :edit_version' if attributes.key?(:'editVersion') && attributes.key?(:'edit_version') self.edit_version = attributes[:'edit_version'] if attributes[:'edit_version'] self.is_system = attributes[:'isSystem'] unless attributes[:'isSystem'].nil? raise 'You cannot provide both :isSystem and :is_system' if attributes.key?(:'isSystem') && attributes.key?(:'is_system') self.is_system = attributes[:'is_system'] unless attributes[:'is_system'].nil? self.source_id = attributes[:'sourceId'] if attributes[:'sourceId'] raise 'You cannot provide both :sourceId and :source_id' if attributes.key?(:'sourceId') && attributes.key?(:'source_id') self.source_id = attributes[:'source_id'] if attributes[:'source_id'] self.label_name = attributes[:'labelName'] if attributes[:'labelName'] raise 'You cannot provide both :labelName and :label_name' if attributes.key?(:'labelName') && attributes.key?(:'label_name') self.label_name = attributes[:'label_name'] if attributes[:'label_name'] end |
Instance Attribute Details
#edit_version ⇒ Integer
The edit version.
12 13 14 |
# File 'lib/oci/log_analytics/models/log_analytics_label_definition.rb', line 12 def edit_version @edit_version end |
#is_system ⇒ BOOLEAN
The system flag. A value of false denotes a custom, or user defined object. A value of true denotes a built in object.
18 19 20 |
# File 'lib/oci/log_analytics/models/log_analytics_label_definition.rb', line 18 def is_system @is_system end |
#label_name ⇒ String
The label name.
26 27 28 |
# File 'lib/oci/log_analytics/models/log_analytics_label_definition.rb', line 26 def label_name @label_name end |
#source_id ⇒ Integer
The source unique identifier.
22 23 24 |
# File 'lib/oci/log_analytics/models/log_analytics_label_definition.rb', line 22 def source_id @source_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 36 37 38 |
# File 'lib/oci/log_analytics/models/log_analytics_label_definition.rb', line 29 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'edit_version': :'editVersion', 'is_system': :'isSystem', 'source_id': :'sourceId', 'label_name': :'labelName' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
41 42 43 44 45 46 47 48 49 50 |
# File 'lib/oci/log_analytics/models/log_analytics_label_definition.rb', line 41 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'edit_version': :'Integer', 'is_system': :'BOOLEAN', 'source_id': :'Integer', 'label_name': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
100 101 102 103 104 105 106 107 108 |
# File 'lib/oci/log_analytics/models/log_analytics_label_definition.rb', line 100 def ==(other) return true if equal?(other) self.class == other.class && edit_version == other.edit_version && is_system == other.is_system && source_id == other.source_id && label_name == other.label_name end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/oci/log_analytics/models/log_analytics_label_definition.rb', line 133 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
113 114 115 |
# File 'lib/oci/log_analytics/models/log_analytics_label_definition.rb', line 113 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
122 123 124 |
# File 'lib/oci/log_analytics/models/log_analytics_label_definition.rb', line 122 def hash [edit_version, is_system, source_id, label_name].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
166 167 168 169 170 171 172 173 174 175 |
# File 'lib/oci/log_analytics/models/log_analytics_label_definition.rb', line 166 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
160 161 162 |
# File 'lib/oci/log_analytics/models/log_analytics_label_definition.rb', line 160 def to_s to_hash.to_s end |