Class: OCI::LogAnalytics::Models::LogAnalyticsMetaFunction
- Inherits:
-
Object
- Object
- OCI::LogAnalytics::Models::LogAnalyticsMetaFunction
- Defined in:
- lib/oci/log_analytics/models/log_analytics_meta_function.rb
Overview
LogAnalyticsMetaFunction
Instance Attribute Summary collapse
-
#component ⇒ String
The component.
-
#description ⇒ String
The description.
-
#edit_version ⇒ Integer
The edit version.
-
#java_class_name ⇒ String
The java class name.
-
#meta_function_argument ⇒ Array<OCI::LogAnalytics::Models::LogAnalyticsMetaFunctionArgument>
An array of meta function arguments.
-
#meta_function_id ⇒ Integer
The meta function unique identifier.
-
#name ⇒ String
The meta function name.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LogAnalyticsMetaFunction
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ LogAnalyticsMetaFunction
Initializes the object
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/oci/log_analytics/models/log_analytics_meta_function.rb', line 81 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self. = attributes[:'metaFunctionArgument'] if attributes[:'metaFunctionArgument'] raise 'You cannot provide both :metaFunctionArgument and :meta_function_argument' if attributes.key?(:'metaFunctionArgument') && attributes.key?(:'meta_function_argument') self. = attributes[:'meta_function_argument'] if attributes[:'meta_function_argument'] self.component = attributes[:'component'] if attributes[:'component'] self.description = attributes[:'description'] if attributes[:'description'] self.edit_version = attributes[:'editVersion'] if attributes[:'editVersion'] raise 'You cannot provide both :editVersion and :edit_version' if attributes.key?(:'editVersion') && attributes.key?(:'edit_version') self.edit_version = attributes[:'edit_version'] if attributes[:'edit_version'] self. = attributes[:'metaFunctionId'] if attributes[:'metaFunctionId'] raise 'You cannot provide both :metaFunctionId and :meta_function_id' if attributes.key?(:'metaFunctionId') && attributes.key?(:'meta_function_id') self. = attributes[:'meta_function_id'] if attributes[:'meta_function_id'] self.java_class_name = attributes[:'javaClassName'] if attributes[:'javaClassName'] raise 'You cannot provide both :javaClassName and :java_class_name' if attributes.key?(:'javaClassName') && attributes.key?(:'java_class_name') self.java_class_name = attributes[:'java_class_name'] if attributes[:'java_class_name'] self.name = attributes[:'name'] if attributes[:'name'] end |
Instance Attribute Details
#component ⇒ String
The component.
16 17 18 |
# File 'lib/oci/log_analytics/models/log_analytics_meta_function.rb', line 16 def component @component end |
#description ⇒ String
The description.
20 21 22 |
# File 'lib/oci/log_analytics/models/log_analytics_meta_function.rb', line 20 def description @description end |
#edit_version ⇒ Integer
The edit version.
24 25 26 |
# File 'lib/oci/log_analytics/models/log_analytics_meta_function.rb', line 24 def edit_version @edit_version end |
#java_class_name ⇒ String
The java class name.
32 33 34 |
# File 'lib/oci/log_analytics/models/log_analytics_meta_function.rb', line 32 def java_class_name @java_class_name end |
#meta_function_argument ⇒ Array<OCI::LogAnalytics::Models::LogAnalyticsMetaFunctionArgument>
An array of meta function arguments.
12 13 14 |
# File 'lib/oci/log_analytics/models/log_analytics_meta_function.rb', line 12 def end |
#meta_function_id ⇒ Integer
The meta function unique identifier.
28 29 30 |
# File 'lib/oci/log_analytics/models/log_analytics_meta_function.rb', line 28 def end |
#name ⇒ String
The meta function name.
36 37 38 |
# File 'lib/oci/log_analytics/models/log_analytics_meta_function.rb', line 36 def name @name end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/oci/log_analytics/models/log_analytics_meta_function.rb', line 39 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'meta_function_argument': :'metaFunctionArgument', 'component': :'component', 'description': :'description', 'edit_version': :'editVersion', 'meta_function_id': :'metaFunctionId', 'java_class_name': :'javaClassName', 'name': :'name' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/oci/log_analytics/models/log_analytics_meta_function.rb', line 54 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'meta_function_argument': :'Array<OCI::LogAnalytics::Models::LogAnalyticsMetaFunctionArgument>', 'component': :'String', 'description': :'String', 'edit_version': :'Integer', 'meta_function_id': :'Integer', 'java_class_name': :'String', 'name': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/oci/log_analytics/models/log_analytics_meta_function.rb', line 125 def ==(other) return true if equal?(other) self.class == other.class && == other. && component == other.component && description == other.description && edit_version == other.edit_version && == other. && java_class_name == other.java_class_name && name == other.name end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/oci/log_analytics/models/log_analytics_meta_function.rb', line 161 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
141 142 143 |
# File 'lib/oci/log_analytics/models/log_analytics_meta_function.rb', line 141 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
150 151 152 |
# File 'lib/oci/log_analytics/models/log_analytics_meta_function.rb', line 150 def hash [, component, description, edit_version, , java_class_name, name].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
194 195 196 197 198 199 200 201 202 203 |
# File 'lib/oci/log_analytics/models/log_analytics_meta_function.rb', line 194 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
188 189 190 |
# File 'lib/oci/log_analytics/models/log_analytics_meta_function.rb', line 188 def to_s to_hash.to_s end |