Class: OCI::LogAnalytics::Models::LogAnalyticsMetaFunctionArgument
- Inherits:
-
Object
- Object
- OCI::LogAnalytics::Models::LogAnalyticsMetaFunctionArgument
- Defined in:
- lib/oci/log_analytics/models/log_analytics_meta_function_argument.rb
Overview
LogAnalyticsMetaFunctionArgument
Instance Attribute Summary collapse
-
#argument_data_type ⇒ String
The argument data type.
-
#argument_description ⇒ String
The argument description.
-
#argument_display_name ⇒ String
The argument display name.
-
#argument_example ⇒ String
The argument example.
-
#argument_id ⇒ Integer
The argument unique identifier.
-
#argument_lookup_column ⇒ String
The lookup column.
-
#argument_lookup_column_position ⇒ Integer
The lookup column position.
-
#argument_name ⇒ String
The argument name.
-
#argument_order ⇒ Integer
The argument order.
-
#argument_reference ⇒ String
The argument unique identifier as a string.
-
#argument_service ⇒ String
The argument service.
-
#argument_type ⇒ Integer
The argument type.
-
#argument_value ⇒ String
The argument value.
-
#is_override_output_fields ⇒ BOOLEAN
The override output fields.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LogAnalyticsMetaFunctionArgument
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ LogAnalyticsMetaFunctionArgument
Initializes the object
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/oci/log_analytics/models/log_analytics_meta_function_argument.rb', line 130 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.is_override_output_fields = attributes[:'isOverrideOutputFields'] unless attributes[:'isOverrideOutputFields'].nil? raise 'You cannot provide both :isOverrideOutputFields and :is_override_output_fields' if attributes.key?(:'isOverrideOutputFields') && attributes.key?(:'is_override_output_fields') self.is_override_output_fields = attributes[:'is_override_output_fields'] unless attributes[:'is_override_output_fields'].nil? self.argument_display_name = attributes[:'argumentDisplayName'] if attributes[:'argumentDisplayName'] raise 'You cannot provide both :argumentDisplayName and :argument_display_name' if attributes.key?(:'argumentDisplayName') && attributes.key?(:'argument_display_name') self.argument_display_name = attributes[:'argument_display_name'] if attributes[:'argument_display_name'] self.argument_example = attributes[:'argumentExample'] if attributes[:'argumentExample'] raise 'You cannot provide both :argumentExample and :argument_example' if attributes.key?(:'argumentExample') && attributes.key?(:'argument_example') self.argument_example = attributes[:'argument_example'] if attributes[:'argument_example'] self.argument_service = attributes[:'argumentService'] if attributes[:'argumentService'] raise 'You cannot provide both :argumentService and :argument_service' if attributes.key?(:'argumentService') && attributes.key?(:'argument_service') self.argument_service = attributes[:'argument_service'] if attributes[:'argument_service'] self.argument_data_type = attributes[:'argumentDataType'] if attributes[:'argumentDataType'] raise 'You cannot provide both :argumentDataType and :argument_data_type' if attributes.key?(:'argumentDataType') && attributes.key?(:'argument_data_type') self.argument_data_type = attributes[:'argument_data_type'] if attributes[:'argument_data_type'] self.argument_description = attributes[:'argumentDescription'] if attributes[:'argumentDescription'] raise 'You cannot provide both :argumentDescription and :argument_description' if attributes.key?(:'argumentDescription') && attributes.key?(:'argument_description') self.argument_description = attributes[:'argument_description'] if attributes[:'argument_description'] self.argument_name = attributes[:'argumentName'] if attributes[:'argumentName'] raise 'You cannot provide both :argumentName and :argument_name' if attributes.key?(:'argumentName') && attributes.key?(:'argument_name') self.argument_name = attributes[:'argument_name'] if attributes[:'argument_name'] self.argument_order = attributes[:'argumentOrder'] if attributes[:'argumentOrder'] raise 'You cannot provide both :argumentOrder and :argument_order' if attributes.key?(:'argumentOrder') && attributes.key?(:'argument_order') self.argument_order = attributes[:'argument_order'] if attributes[:'argument_order'] self.argument_type = attributes[:'argumentType'] if attributes[:'argumentType'] raise 'You cannot provide both :argumentType and :argument_type' if attributes.key?(:'argumentType') && attributes.key?(:'argument_type') self.argument_type = attributes[:'argument_type'] if attributes[:'argument_type'] self.argument_id = attributes[:'argumentId'] if attributes[:'argumentId'] raise 'You cannot provide both :argumentId and :argument_id' if attributes.key?(:'argumentId') && attributes.key?(:'argument_id') self.argument_id = attributes[:'argument_id'] if attributes[:'argument_id'] self.argument_lookup_column = attributes[:'argumentLookupColumn'] if attributes[:'argumentLookupColumn'] raise 'You cannot provide both :argumentLookupColumn and :argument_lookup_column' if attributes.key?(:'argumentLookupColumn') && attributes.key?(:'argument_lookup_column') self.argument_lookup_column = attributes[:'argument_lookup_column'] if attributes[:'argument_lookup_column'] self.argument_lookup_column_position = attributes[:'argumentLookupColumnPosition'] if attributes[:'argumentLookupColumnPosition'] raise 'You cannot provide both :argumentLookupColumnPosition and :argument_lookup_column_position' if attributes.key?(:'argumentLookupColumnPosition') && attributes.key?(:'argument_lookup_column_position') self.argument_lookup_column_position = attributes[:'argument_lookup_column_position'] if attributes[:'argument_lookup_column_position'] self.argument_value = attributes[:'argumentValue'] if attributes[:'argumentValue'] raise 'You cannot provide both :argumentValue and :argument_value' if attributes.key?(:'argumentValue') && attributes.key?(:'argument_value') self.argument_value = attributes[:'argument_value'] if attributes[:'argument_value'] self.argument_reference = attributes[:'argumentReference'] if attributes[:'argumentReference'] raise 'You cannot provide both :argumentReference and :argument_reference' if attributes.key?(:'argumentReference') && attributes.key?(:'argument_reference') self.argument_reference = attributes[:'argument_reference'] if attributes[:'argument_reference'] end |
Instance Attribute Details
#argument_data_type ⇒ String
The argument data type.
28 29 30 |
# File 'lib/oci/log_analytics/models/log_analytics_meta_function_argument.rb', line 28 def argument_data_type @argument_data_type end |
#argument_description ⇒ String
The argument description.
32 33 34 |
# File 'lib/oci/log_analytics/models/log_analytics_meta_function_argument.rb', line 32 def argument_description @argument_description end |
#argument_display_name ⇒ String
The argument display name.
16 17 18 |
# File 'lib/oci/log_analytics/models/log_analytics_meta_function_argument.rb', line 16 def argument_display_name @argument_display_name end |
#argument_example ⇒ String
The argument example.
20 21 22 |
# File 'lib/oci/log_analytics/models/log_analytics_meta_function_argument.rb', line 20 def argument_example @argument_example end |
#argument_id ⇒ Integer
The argument unique identifier.
48 49 50 |
# File 'lib/oci/log_analytics/models/log_analytics_meta_function_argument.rb', line 48 def argument_id @argument_id end |
#argument_lookup_column ⇒ String
The lookup column.
52 53 54 |
# File 'lib/oci/log_analytics/models/log_analytics_meta_function_argument.rb', line 52 def argument_lookup_column @argument_lookup_column end |
#argument_lookup_column_position ⇒ Integer
The lookup column position.
56 57 58 |
# File 'lib/oci/log_analytics/models/log_analytics_meta_function_argument.rb', line 56 def argument_lookup_column_position @argument_lookup_column_position end |
#argument_name ⇒ String
The argument name.
36 37 38 |
# File 'lib/oci/log_analytics/models/log_analytics_meta_function_argument.rb', line 36 def argument_name @argument_name end |
#argument_order ⇒ Integer
The argument order.
40 41 42 |
# File 'lib/oci/log_analytics/models/log_analytics_meta_function_argument.rb', line 40 def argument_order @argument_order end |
#argument_reference ⇒ String
The argument unique identifier as a string.
64 65 66 |
# File 'lib/oci/log_analytics/models/log_analytics_meta_function_argument.rb', line 64 def argument_reference @argument_reference end |
#argument_service ⇒ String
The argument service.
24 25 26 |
# File 'lib/oci/log_analytics/models/log_analytics_meta_function_argument.rb', line 24 def argument_service @argument_service end |
#argument_type ⇒ Integer
The argument type.
44 45 46 |
# File 'lib/oci/log_analytics/models/log_analytics_meta_function_argument.rb', line 44 def argument_type @argument_type end |
#argument_value ⇒ String
The argument value.
60 61 62 |
# File 'lib/oci/log_analytics/models/log_analytics_meta_function_argument.rb', line 60 def argument_value @argument_value end |
#is_override_output_fields ⇒ BOOLEAN
The override output fields.
12 13 14 |
# File 'lib/oci/log_analytics/models/log_analytics_meta_function_argument.rb', line 12 def is_override_output_fields @is_override_output_fields end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/oci/log_analytics/models/log_analytics_meta_function_argument.rb', line 67 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'is_override_output_fields': :'isOverrideOutputFields', 'argument_display_name': :'argumentDisplayName', 'argument_example': :'argumentExample', 'argument_service': :'argumentService', 'argument_data_type': :'argumentDataType', 'argument_description': :'argumentDescription', 'argument_name': :'argumentName', 'argument_order': :'argumentOrder', 'argument_type': :'argumentType', 'argument_id': :'argumentId', 'argument_lookup_column': :'argumentLookupColumn', 'argument_lookup_column_position': :'argumentLookupColumnPosition', 'argument_value': :'argumentValue', 'argument_reference': :'argumentReference' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/oci/log_analytics/models/log_analytics_meta_function_argument.rb', line 89 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'is_override_output_fields': :'BOOLEAN', 'argument_display_name': :'String', 'argument_example': :'String', 'argument_service': :'String', 'argument_data_type': :'String', 'argument_description': :'String', 'argument_name': :'String', 'argument_order': :'Integer', 'argument_type': :'Integer', 'argument_id': :'Integer', 'argument_lookup_column': :'String', 'argument_lookup_column_position': :'Integer', 'argument_value': :'String', 'argument_reference': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 |
# File 'lib/oci/log_analytics/models/log_analytics_meta_function_argument.rb', line 228 def ==(other) return true if equal?(other) self.class == other.class && is_override_output_fields == other.is_override_output_fields && argument_display_name == other.argument_display_name && argument_example == other.argument_example && argument_service == other.argument_service && argument_data_type == other.argument_data_type && argument_description == other.argument_description && argument_name == other.argument_name && argument_order == other.argument_order && argument_type == other.argument_type && argument_id == other.argument_id && argument_lookup_column == other.argument_lookup_column && argument_lookup_column_position == other.argument_lookup_column_position && argument_value == other.argument_value && argument_reference == other.argument_reference end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'lib/oci/log_analytics/models/log_analytics_meta_function_argument.rb', line 271 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
251 252 253 |
# File 'lib/oci/log_analytics/models/log_analytics_meta_function_argument.rb', line 251 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
260 261 262 |
# File 'lib/oci/log_analytics/models/log_analytics_meta_function_argument.rb', line 260 def hash [is_override_output_fields, argument_display_name, argument_example, argument_service, argument_data_type, argument_description, argument_name, argument_order, argument_type, argument_id, argument_lookup_column, argument_lookup_column_position, argument_value, argument_reference].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
304 305 306 307 308 309 310 311 312 313 |
# File 'lib/oci/log_analytics/models/log_analytics_meta_function_argument.rb', line 304 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
298 299 300 |
# File 'lib/oci/log_analytics/models/log_analytics_meta_function_argument.rb', line 298 def to_s to_hash.to_s end |