Class: OCI::LogAnalytics::Models::LogAnalyticsMetaSourceType

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/log_analytics/models/log_analytics_meta_source_type.rb

Overview

LogAnalyticsMetaSourceType

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ LogAnalyticsMetaSourceType

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :built_in_parser_name (String)

    The value to assign to the #built_in_parser_name property

  • :description (String)

    The value to assign to the #description property

  • :display_name (String)

    The value to assign to the #display_name property

  • :entity_display_name (String)

    The value to assign to the #entity_display_name property

  • :entity_name (String)

    The value to assign to the #entity_name property

  • :name (String)

    The value to assign to the #name property

  • :maximum_exclude_pattern (Integer)

    The value to assign to the #maximum_exclude_pattern property

  • :maximum_include_pattern (Integer)

    The value to assign to the #maximum_include_pattern property



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/oci/log_analytics/models/log_analytics_meta_source_type.rb', line 88

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.built_in_parser_name = attributes[:'builtInParserName'] if attributes[:'builtInParserName']

  raise 'You cannot provide both :builtInParserName and :built_in_parser_name' if attributes.key?(:'builtInParserName') && attributes.key?(:'built_in_parser_name')

  self.built_in_parser_name = attributes[:'built_in_parser_name'] if attributes[:'built_in_parser_name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.entity_display_name = attributes[:'entityDisplayName'] if attributes[:'entityDisplayName']

  raise 'You cannot provide both :entityDisplayName and :entity_display_name' if attributes.key?(:'entityDisplayName') && attributes.key?(:'entity_display_name')

  self.entity_display_name = attributes[:'entity_display_name'] if attributes[:'entity_display_name']

  self.entity_name = attributes[:'entityName'] if attributes[:'entityName']

  raise 'You cannot provide both :entityName and :entity_name' if attributes.key?(:'entityName') && attributes.key?(:'entity_name')

  self.entity_name = attributes[:'entity_name'] if attributes[:'entity_name']

  self.name = attributes[:'name'] if attributes[:'name']

  self.maximum_exclude_pattern = attributes[:'maximumExcludePattern'] if attributes[:'maximumExcludePattern']

  raise 'You cannot provide both :maximumExcludePattern and :maximum_exclude_pattern' if attributes.key?(:'maximumExcludePattern') && attributes.key?(:'maximum_exclude_pattern')

  self.maximum_exclude_pattern = attributes[:'maximum_exclude_pattern'] if attributes[:'maximum_exclude_pattern']

  self.maximum_include_pattern = attributes[:'maximumIncludePattern'] if attributes[:'maximumIncludePattern']

  raise 'You cannot provide both :maximumIncludePattern and :maximum_include_pattern' if attributes.key?(:'maximumIncludePattern') && attributes.key?(:'maximum_include_pattern')

  self.maximum_include_pattern = attributes[:'maximum_include_pattern'] if attributes[:'maximum_include_pattern']
end

Instance Attribute Details

#built_in_parser_nameString

The built in parser name.

Returns:

  • (String)


12
13
14
# File 'lib/oci/log_analytics/models/log_analytics_meta_source_type.rb', line 12

def built_in_parser_name
  @built_in_parser_name
end

#descriptionString

The source type description.

Returns:

  • (String)


16
17
18
# File 'lib/oci/log_analytics/models/log_analytics_meta_source_type.rb', line 16

def description
  @description
end

#display_nameString

The source type display name.

Returns:

  • (String)


20
21
22
# File 'lib/oci/log_analytics/models/log_analytics_meta_source_type.rb', line 20

def display_name
  @display_name
end

#entity_display_nameString

The entity display name.

Returns:

  • (String)


24
25
26
# File 'lib/oci/log_analytics/models/log_analytics_meta_source_type.rb', line 24

def entity_display_name
  @entity_display_name
end

#entity_nameString

The entity internal name.

Returns:

  • (String)


28
29
30
# File 'lib/oci/log_analytics/models/log_analytics_meta_source_type.rb', line 28

def entity_name
  @entity_name
end

#maximum_exclude_patternInteger

The maximum exclude pattern.

Returns:

  • (Integer)


36
37
38
# File 'lib/oci/log_analytics/models/log_analytics_meta_source_type.rb', line 36

def maximum_exclude_pattern
  @maximum_exclude_pattern
end

#maximum_include_patternInteger

The maximum include pattern.

Returns:

  • (Integer)


40
41
42
# File 'lib/oci/log_analytics/models/log_analytics_meta_source_type.rb', line 40

def maximum_include_pattern
  @maximum_include_pattern
end

#nameString

The source type name.

Returns:

  • (String)


32
33
34
# File 'lib/oci/log_analytics/models/log_analytics_meta_source_type.rb', line 32

def name
  @name
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
54
55
56
# File 'lib/oci/log_analytics/models/log_analytics_meta_source_type.rb', line 43

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'built_in_parser_name': :'builtInParserName',
    'description': :'description',
    'display_name': :'displayName',
    'entity_display_name': :'entityDisplayName',
    'entity_name': :'entityName',
    'name': :'name',
    'maximum_exclude_pattern': :'maximumExcludePattern',
    'maximum_include_pattern': :'maximumIncludePattern'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/oci/log_analytics/models/log_analytics_meta_source_type.rb', line 59

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'built_in_parser_name': :'String',
    'description': :'String',
    'display_name': :'String',
    'entity_display_name': :'String',
    'entity_name': :'String',
    'name': :'String',
    'maximum_exclude_pattern': :'Integer',
    'maximum_include_pattern': :'Integer'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/oci/log_analytics/models/log_analytics_meta_source_type.rb', line 142

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    built_in_parser_name == other.built_in_parser_name &&
    description == other.description &&
    display_name == other.display_name &&
    entity_display_name == other.entity_display_name &&
    entity_name == other.entity_name &&
    name == other.name &&
    maximum_exclude_pattern == other.maximum_exclude_pattern &&
    maximum_include_pattern == other.maximum_include_pattern
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/oci/log_analytics/models/log_analytics_meta_source_type.rb', line 179

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


159
160
161
# File 'lib/oci/log_analytics/models/log_analytics_meta_source_type.rb', line 159

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



168
169
170
# File 'lib/oci/log_analytics/models/log_analytics_meta_source_type.rb', line 168

def hash
  [built_in_parser_name, description, display_name, entity_display_name, entity_name, name, maximum_exclude_pattern, maximum_include_pattern].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



212
213
214
215
216
217
218
219
220
221
# File 'lib/oci/log_analytics/models/log_analytics_meta_source_type.rb', line 212

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



206
207
208
# File 'lib/oci/log_analytics/models/log_analytics_meta_source_type.rb', line 206

def to_s
  to_hash.to_s
end