Class: OCI::LogAnalytics::Models::LogAnalyticsMetric
- Inherits:
-
Object
- Object
- OCI::LogAnalytics::Models::LogAnalyticsMetric
- Defined in:
- lib/oci/log_analytics/models/log_analytics_metric.rb
Overview
LogAnalyticsMetric
Constant Summary collapse
- METRIC_TYPE_ENUM =
[ METRIC_TYPE_COUNT = 'COUNT'.freeze, METRIC_TYPE_SUM = 'SUM'.freeze, METRIC_TYPE_AVERAGE = 'AVERAGE'.freeze, METRIC_TYPE_COUNT_DISTRIBUTION = 'COUNT_DISTRIBUTION'.freeze, METRIC_TYPE_SUM_DISTRIBUTION = 'SUM_DISTRIBUTION'.freeze, METRIC_TYPE_AVERAGE_DISTRIBUTION = 'AVERAGE_DISTRIBUTION'.freeze, METRIC_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- OPERATOR_ENUM =
[ OPERATOR_CONTAINS_IGNORE_CASE = 'CONTAINS_IGNORE_CASE'.freeze, OPERATOR_IN_IGNORE_CASE = 'IN_IGNORE_CASE'.freeze, OPERATOR_EQUAL_IGNORE_CASE = 'EQUAL_IGNORE_CASE'.freeze, OPERATOR_NOT_NULL = 'NOT_NULL'.freeze, OPERATOR_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#aggregation_field ⇒ String
The aggregation field.
-
#bucket_metadata ⇒ String
The bucket metadata.
-
#clock_period ⇒ String
The clock period.
-
#description ⇒ String
The metric description.
-
#display_name ⇒ String
The metric display name.
-
#edit_version ⇒ Integer
The metric edit version.
-
#entity_type ⇒ String
The entity type.
-
#field_name ⇒ String
The field name.
-
#field_values ⇒ Array<String>
The field values.
-
#grouping_field ⇒ String
The grouping fields.
-
#is_enabled ⇒ BOOLEAN
A flag inidcating whether or not the metric is enabled.
-
#is_metric_source_enabled ⇒ BOOLEAN
A flag specifying whether or not the metric source is enabled.
-
#is_system ⇒ BOOLEAN
The system flag.
-
#is_user_customized ⇒ BOOLEAN
A flag specifying whether or not this is a custom (user defined) metric.
-
#metric_reference ⇒ Integer
The metric unique identifier.
-
#metric_type ⇒ String
The metric type, specifying the type of aggreation to perform.
-
#name ⇒ String
The metric name.
-
#operator ⇒ String
The metric operator.
-
#sources ⇒ Array<OCI::LogAnalytics::Models::LogAnalyticsSource>
The metric sources.
-
#time_updated ⇒ DateTime
The last updated date.
-
#unit_type ⇒ String
The unit type.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LogAnalyticsMetric
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ LogAnalyticsMetric
Initializes the object
205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 |
# File 'lib/oci/log_analytics/models/log_analytics_metric.rb', line 205 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.aggregation_field = attributes[:'aggregationField'] if attributes[:'aggregationField'] raise 'You cannot provide both :aggregationField and :aggregation_field' if attributes.key?(:'aggregationField') && attributes.key?(:'aggregation_field') self.aggregation_field = attributes[:'aggregation_field'] if attributes[:'aggregation_field'] self. = attributes[:'bucketMetadata'] if attributes[:'bucketMetadata'] raise 'You cannot provide both :bucketMetadata and :bucket_metadata' if attributes.key?(:'bucketMetadata') && attributes.key?(:'bucket_metadata') self. = attributes[:'bucket_metadata'] if attributes[:'bucket_metadata'] self.clock_period = attributes[:'clockPeriod'] if attributes[:'clockPeriod'] raise 'You cannot provide both :clockPeriod and :clock_period' if attributes.key?(:'clockPeriod') && attributes.key?(:'clock_period') self.clock_period = attributes[:'clock_period'] if attributes[:'clock_period'] self.description = attributes[:'description'] if attributes[:'description'] self.edit_version = attributes[:'editVersion'] if attributes[:'editVersion'] raise 'You cannot provide both :editVersion and :edit_version' if attributes.key?(:'editVersion') && attributes.key?(:'edit_version') self.edit_version = attributes[:'edit_version'] if attributes[:'edit_version'] self.field_name = attributes[:'fieldName'] if attributes[:'fieldName'] raise 'You cannot provide both :fieldName and :field_name' if attributes.key?(:'fieldName') && attributes.key?(:'field_name') self.field_name = attributes[:'field_name'] if attributes[:'field_name'] self.field_values = attributes[:'fieldValues'] if attributes[:'fieldValues'] raise 'You cannot provide both :fieldValues and :field_values' if attributes.key?(:'fieldValues') && attributes.key?(:'field_values') self.field_values = attributes[:'field_values'] if attributes[:'field_values'] self.grouping_field = attributes[:'groupingField'] if attributes[:'groupingField'] raise 'You cannot provide both :groupingField and :grouping_field' if attributes.key?(:'groupingField') && attributes.key?(:'grouping_field') self.grouping_field = attributes[:'grouping_field'] if attributes[:'grouping_field'] self.is_enabled = attributes[:'isEnabled'] unless attributes[:'isEnabled'].nil? raise 'You cannot provide both :isEnabled and :is_enabled' if attributes.key?(:'isEnabled') && attributes.key?(:'is_enabled') self.is_enabled = attributes[:'is_enabled'] unless attributes[:'is_enabled'].nil? self.is_system = attributes[:'isSystem'] unless attributes[:'isSystem'].nil? raise 'You cannot provide both :isSystem and :is_system' if attributes.key?(:'isSystem') && attributes.key?(:'is_system') self.is_system = attributes[:'is_system'] unless attributes[:'is_system'].nil? self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.metric_reference = attributes[:'metricReference'] if attributes[:'metricReference'] raise 'You cannot provide both :metricReference and :metric_reference' if attributes.key?(:'metricReference') && attributes.key?(:'metric_reference') self.metric_reference = attributes[:'metric_reference'] if attributes[:'metric_reference'] self.name = attributes[:'name'] if attributes[:'name'] self.metric_type = attributes[:'metricType'] if attributes[:'metricType'] self.metric_type = "COUNT" if metric_type.nil? && !attributes.key?(:'metricType') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :metricType and :metric_type' if attributes.key?(:'metricType') && attributes.key?(:'metric_type') self.metric_type = attributes[:'metric_type'] if attributes[:'metric_type'] self.metric_type = "COUNT" if metric_type.nil? && !attributes.key?(:'metricType') && !attributes.key?(:'metric_type') # rubocop:disable Style/StringLiterals self.is_metric_source_enabled = attributes[:'isMetricSourceEnabled'] unless attributes[:'isMetricSourceEnabled'].nil? raise 'You cannot provide both :isMetricSourceEnabled and :is_metric_source_enabled' if attributes.key?(:'isMetricSourceEnabled') && attributes.key?(:'is_metric_source_enabled') self.is_metric_source_enabled = attributes[:'is_metric_source_enabled'] unless attributes[:'is_metric_source_enabled'].nil? self.operator = attributes[:'operator'] if attributes[:'operator'] self.operator = "CONTAINS_IGNORE_CASE" if operator.nil? && !attributes.key?(:'operator') # rubocop:disable Style/StringLiterals self.sources = attributes[:'sources'] if attributes[:'sources'] self.entity_type = attributes[:'entityType'] if attributes[:'entityType'] raise 'You cannot provide both :entityType and :entity_type' if attributes.key?(:'entityType') && attributes.key?(:'entity_type') self.entity_type = attributes[:'entity_type'] if attributes[:'entity_type'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.unit_type = attributes[:'unitType'] if attributes[:'unitType'] raise 'You cannot provide both :unitType and :unit_type' if attributes.key?(:'unitType') && attributes.key?(:'unit_type') self.unit_type = attributes[:'unit_type'] if attributes[:'unit_type'] self.is_user_customized = attributes[:'isUserCustomized'] unless attributes[:'isUserCustomized'].nil? raise 'You cannot provide both :isUserCustomized and :is_user_customized' if attributes.key?(:'isUserCustomized') && attributes.key?(:'is_user_customized') self.is_user_customized = attributes[:'is_user_customized'] unless attributes[:'is_user_customized'].nil? end |
Instance Attribute Details
#aggregation_field ⇒ String
The aggregation field.
31 32 33 |
# File 'lib/oci/log_analytics/models/log_analytics_metric.rb', line 31 def aggregation_field @aggregation_field end |
#bucket_metadata ⇒ String
The bucket metadata.
35 36 37 |
# File 'lib/oci/log_analytics/models/log_analytics_metric.rb', line 35 def end |
#clock_period ⇒ String
The clock period.
39 40 41 |
# File 'lib/oci/log_analytics/models/log_analytics_metric.rb', line 39 def clock_period @clock_period end |
#description ⇒ String
The metric description.
43 44 45 |
# File 'lib/oci/log_analytics/models/log_analytics_metric.rb', line 43 def description @description end |
#display_name ⇒ String
The metric display name.
74 75 76 |
# File 'lib/oci/log_analytics/models/log_analytics_metric.rb', line 74 def display_name @display_name end |
#edit_version ⇒ Integer
The metric edit version.
47 48 49 |
# File 'lib/oci/log_analytics/models/log_analytics_metric.rb', line 47 def edit_version @edit_version end |
#entity_type ⇒ String
The entity type.
105 106 107 |
# File 'lib/oci/log_analytics/models/log_analytics_metric.rb', line 105 def entity_type @entity_type end |
#field_name ⇒ String
The field name.
51 52 53 |
# File 'lib/oci/log_analytics/models/log_analytics_metric.rb', line 51 def field_name @field_name end |
#field_values ⇒ Array<String>
The field values.
55 56 57 |
# File 'lib/oci/log_analytics/models/log_analytics_metric.rb', line 55 def field_values @field_values end |
#grouping_field ⇒ String
The grouping fields.
59 60 61 |
# File 'lib/oci/log_analytics/models/log_analytics_metric.rb', line 59 def grouping_field @grouping_field end |
#is_enabled ⇒ BOOLEAN
A flag inidcating whether or not the metric is enabled.
64 65 66 |
# File 'lib/oci/log_analytics/models/log_analytics_metric.rb', line 64 def is_enabled @is_enabled end |
#is_metric_source_enabled ⇒ BOOLEAN
A flag specifying whether or not the metric source is enabled.
93 94 95 |
# File 'lib/oci/log_analytics/models/log_analytics_metric.rb', line 93 def is_metric_source_enabled @is_metric_source_enabled end |
#is_system ⇒ BOOLEAN
The system flag. A value of false denotes a custom, or user defined object. A value of true denotes a built in object.
70 71 72 |
# File 'lib/oci/log_analytics/models/log_analytics_metric.rb', line 70 def is_system @is_system end |
#is_user_customized ⇒ BOOLEAN
A flag specifying whether or not this is a custom (user defined) metric.
118 119 120 |
# File 'lib/oci/log_analytics/models/log_analytics_metric.rb', line 118 def is_user_customized @is_user_customized end |
#metric_reference ⇒ Integer
The metric unique identifier.
78 79 80 |
# File 'lib/oci/log_analytics/models/log_analytics_metric.rb', line 78 def metric_reference @metric_reference end |
#metric_type ⇒ String
The metric type, specifying the type of aggreation to perform. Default value is COUNT.
88 89 90 |
# File 'lib/oci/log_analytics/models/log_analytics_metric.rb', line 88 def metric_type @metric_type end |
#name ⇒ String
The metric name.
82 83 84 |
# File 'lib/oci/log_analytics/models/log_analytics_metric.rb', line 82 def name @name end |
#operator ⇒ String
The metric operator.
97 98 99 |
# File 'lib/oci/log_analytics/models/log_analytics_metric.rb', line 97 def operator @operator end |
#sources ⇒ Array<OCI::LogAnalytics::Models::LogAnalyticsSource>
The metric sources.
101 102 103 |
# File 'lib/oci/log_analytics/models/log_analytics_metric.rb', line 101 def sources @sources end |
#time_updated ⇒ DateTime
The last updated date.
109 110 111 |
# File 'lib/oci/log_analytics/models/log_analytics_metric.rb', line 109 def time_updated @time_updated end |
#unit_type ⇒ String
The unit type.
113 114 115 |
# File 'lib/oci/log_analytics/models/log_analytics_metric.rb', line 113 def unit_type @unit_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/oci/log_analytics/models/log_analytics_metric.rb', line 121 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'aggregation_field': :'aggregationField', 'bucket_metadata': :'bucketMetadata', 'clock_period': :'clockPeriod', 'description': :'description', 'edit_version': :'editVersion', 'field_name': :'fieldName', 'field_values': :'fieldValues', 'grouping_field': :'groupingField', 'is_enabled': :'isEnabled', 'is_system': :'isSystem', 'display_name': :'displayName', 'metric_reference': :'metricReference', 'name': :'name', 'metric_type': :'metricType', 'is_metric_source_enabled': :'isMetricSourceEnabled', 'operator': :'operator', 'sources': :'sources', 'entity_type': :'entityType', 'time_updated': :'timeUpdated', 'unit_type': :'unitType', 'is_user_customized': :'isUserCustomized' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/oci/log_analytics/models/log_analytics_metric.rb', line 150 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'aggregation_field': :'String', 'bucket_metadata': :'String', 'clock_period': :'String', 'description': :'String', 'edit_version': :'Integer', 'field_name': :'String', 'field_values': :'Array<String>', 'grouping_field': :'String', 'is_enabled': :'BOOLEAN', 'is_system': :'BOOLEAN', 'display_name': :'String', 'metric_reference': :'Integer', 'name': :'String', 'metric_type': :'String', 'is_metric_source_enabled': :'BOOLEAN', 'operator': :'String', 'sources': :'Array<OCI::LogAnalytics::Models::LogAnalyticsSource>', 'entity_type': :'String', 'time_updated': :'DateTime', 'unit_type': :'String', 'is_user_customized': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 |
# File 'lib/oci/log_analytics/models/log_analytics_metric.rb', line 358 def ==(other) return true if equal?(other) self.class == other.class && aggregation_field == other.aggregation_field && == other. && clock_period == other.clock_period && description == other.description && edit_version == other.edit_version && field_name == other.field_name && field_values == other.field_values && grouping_field == other.grouping_field && is_enabled == other.is_enabled && is_system == other.is_system && display_name == other.display_name && metric_reference == other.metric_reference && name == other.name && metric_type == other.metric_type && is_metric_source_enabled == other.is_metric_source_enabled && operator == other.operator && sources == other.sources && entity_type == other.entity_type && time_updated == other.time_updated && unit_type == other.unit_type && is_user_customized == other.is_user_customized end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 |
# File 'lib/oci/log_analytics/models/log_analytics_metric.rb', line 408 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
388 389 390 |
# File 'lib/oci/log_analytics/models/log_analytics_metric.rb', line 388 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
397 398 399 |
# File 'lib/oci/log_analytics/models/log_analytics_metric.rb', line 397 def hash [aggregation_field, , clock_period, description, edit_version, field_name, field_values, grouping_field, is_enabled, is_system, display_name, metric_reference, name, metric_type, is_metric_source_enabled, operator, sources, entity_type, time_updated, unit_type, is_user_customized].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
441 442 443 444 445 446 447 448 449 450 |
# File 'lib/oci/log_analytics/models/log_analytics_metric.rb', line 441 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
435 436 437 |
# File 'lib/oci/log_analytics/models/log_analytics_metric.rb', line 435 def to_s to_hash.to_s end |