Class: OCI::LogAnalytics::Models::LogAnalyticsObjectCollectionRule

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb

Overview

The configuration details of an Object Storage based collection rule.

Constant Summary collapse

COLLECTION_TYPE_ENUM =
[
  COLLECTION_TYPE_LIVE = 'LIVE'.freeze,
  COLLECTION_TYPE_HISTORIC = 'HISTORIC'.freeze,
  COLLECTION_TYPE_HISTORIC_LIVE = 'HISTORIC_LIVE'.freeze,
  COLLECTION_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ LogAnalyticsObjectCollectionRule

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :name (String)

    The value to assign to the #name property

  • :description (String)

    The value to assign to the #description property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :os_namespace (String)

    The value to assign to the #os_namespace property

  • :os_bucket_name (String)

    The value to assign to the #os_bucket_name property

  • :collection_type (String)

    The value to assign to the #collection_type property

  • :poll_since (String)

    The value to assign to the #poll_since property

  • :poll_till (String)

    The value to assign to the #poll_till property

  • :log_group_id (String)

    The value to assign to the #log_group_id property

  • :log_source_name (String)

    The value to assign to the #log_source_name property

  • :entity_id (String)

    The value to assign to the #entity_id property

  • :char_encoding (String)

    The value to assign to the #char_encoding property

  • :overrides (Hash<String, Array<OCI::LogAnalytics::Models::PropertyOverride>>)

    The value to assign to the #overrides property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :lifecycle_details (String)

    The value to assign to the #lifecycle_details property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :time_updated (DateTime)

    The value to assign to the #time_updated property

  • :is_enabled (BOOLEAN)

    The value to assign to the #is_enabled property

  • :object_name_filters (Array<String>)

    The value to assign to the #object_name_filters property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property



227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 227

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.name = attributes[:'name'] if attributes[:'name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.os_namespace = attributes[:'osNamespace'] if attributes[:'osNamespace']

  raise 'You cannot provide both :osNamespace and :os_namespace' if attributes.key?(:'osNamespace') && attributes.key?(:'os_namespace')

  self.os_namespace = attributes[:'os_namespace'] if attributes[:'os_namespace']

  self.os_bucket_name = attributes[:'osBucketName'] if attributes[:'osBucketName']

  raise 'You cannot provide both :osBucketName and :os_bucket_name' if attributes.key?(:'osBucketName') && attributes.key?(:'os_bucket_name')

  self.os_bucket_name = attributes[:'os_bucket_name'] if attributes[:'os_bucket_name']

  self.collection_type = attributes[:'collectionType'] if attributes[:'collectionType']
  self.collection_type = "LIVE" if collection_type.nil? && !attributes.key?(:'collectionType') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :collectionType and :collection_type' if attributes.key?(:'collectionType') && attributes.key?(:'collection_type')

  self.collection_type = attributes[:'collection_type'] if attributes[:'collection_type']
  self.collection_type = "LIVE" if collection_type.nil? && !attributes.key?(:'collectionType') && !attributes.key?(:'collection_type') # rubocop:disable Style/StringLiterals

  self.poll_since = attributes[:'pollSince'] if attributes[:'pollSince']
  self.poll_since = "CURRENT_TIME" if poll_since.nil? && !attributes.key?(:'pollSince') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :pollSince and :poll_since' if attributes.key?(:'pollSince') && attributes.key?(:'poll_since')

  self.poll_since = attributes[:'poll_since'] if attributes[:'poll_since']
  self.poll_since = "CURRENT_TIME" if poll_since.nil? && !attributes.key?(:'pollSince') && !attributes.key?(:'poll_since') # rubocop:disable Style/StringLiterals

  self.poll_till = attributes[:'pollTill'] if attributes[:'pollTill']
  self.poll_till = "null" if poll_till.nil? && !attributes.key?(:'pollTill') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :pollTill and :poll_till' if attributes.key?(:'pollTill') && attributes.key?(:'poll_till')

  self.poll_till = attributes[:'poll_till'] if attributes[:'poll_till']
  self.poll_till = "null" if poll_till.nil? && !attributes.key?(:'pollTill') && !attributes.key?(:'poll_till') # rubocop:disable Style/StringLiterals

  self.log_group_id = attributes[:'logGroupId'] if attributes[:'logGroupId']

  raise 'You cannot provide both :logGroupId and :log_group_id' if attributes.key?(:'logGroupId') && attributes.key?(:'log_group_id')

  self.log_group_id = attributes[:'log_group_id'] if attributes[:'log_group_id']

  self.log_source_name = attributes[:'logSourceName'] if attributes[:'logSourceName']

  raise 'You cannot provide both :logSourceName and :log_source_name' if attributes.key?(:'logSourceName') && attributes.key?(:'log_source_name')

  self.log_source_name = attributes[:'log_source_name'] if attributes[:'log_source_name']

  self.entity_id = attributes[:'entityId'] if attributes[:'entityId']

  raise 'You cannot provide both :entityId and :entity_id' if attributes.key?(:'entityId') && attributes.key?(:'entity_id')

  self.entity_id = attributes[:'entity_id'] if attributes[:'entity_id']

  self.char_encoding = attributes[:'charEncoding'] if attributes[:'charEncoding']

  raise 'You cannot provide both :charEncoding and :char_encoding' if attributes.key?(:'charEncoding') && attributes.key?(:'char_encoding')

  self.char_encoding = attributes[:'char_encoding'] if attributes[:'char_encoding']

  self.overrides = attributes[:'overrides'] if attributes[:'overrides']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.is_enabled = attributes[:'isEnabled'] unless attributes[:'isEnabled'].nil?
  self.is_enabled = true if is_enabled.nil? && !attributes.key?(:'isEnabled') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isEnabled and :is_enabled' if attributes.key?(:'isEnabled') && attributes.key?(:'is_enabled')

  self.is_enabled = attributes[:'is_enabled'] unless attributes[:'is_enabled'].nil?
  self.is_enabled = true if is_enabled.nil? && !attributes.key?(:'isEnabled') && !attributes.key?(:'is_enabled') # rubocop:disable Style/StringLiterals

  self.object_name_filters = attributes[:'objectNameFilters'] if attributes[:'objectNameFilters']

  raise 'You cannot provide both :objectNameFilters and :object_name_filters' if attributes.key?(:'objectNameFilters') && attributes.key?(:'object_name_filters')

  self.object_name_filters = attributes[:'object_name_filters'] if attributes[:'object_name_filters']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']
end

Instance Attribute Details

#char_encodingString

An optional character encoding to aid in detecting the character encoding of the contents of the objects while processing. It is recommended to set this value as ISO_8859_1 when configuring content of the objects having more numeric characters, and very few alphabets. For e.g. this applies when configuring VCN Flow Logs.

Returns:

  • (String)


89
90
91
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 89

def char_encoding
  @char_encoding
end

#collection_typeString

[Required] The type of log collection.

Returns:

  • (String)


55
56
57
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 55

def collection_type
  @collection_type
end

#compartment_idString

[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment to which this rule belongs.

Returns:

  • (String)


42
43
44
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 42

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


131
132
133
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 131

def defined_tags
  @defined_tags
end

#descriptionString

A string that describes the details of the rule. It does not have to be unique, and can be changed. Avoid entering confidential information.

Returns:

  • (String)


38
39
40
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 38

def description
  @description
end

#entity_idString

Logging Analytics entity OCID to associate the processed logs with.

Returns:

  • (String)


81
82
83
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 81

def entity_id
  @entity_id
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`

Returns:

  • (Hash<String, String>)


137
138
139
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 137

def freeform_tags
  @freeform_tags
end

#idString

Returns:

  • (String)


28
29
30
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 28

def id
  @id
end

#is_enabledBOOLEAN

[Required] Whether or not this rule is currently enabled.

Returns:

  • (BOOLEAN)


118
119
120
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 118

def is_enabled
  @is_enabled
end

#lifecycle_detailsString

A detailed status of the life cycle state.

Returns:

  • (String)


105
106
107
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 105

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

[Required] The current state of the rule.

Returns:

  • (String)


101
102
103
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 101

def lifecycle_state
  @lifecycle_state
end

#log_group_idString

[Required] Logging Analytics Log group OCID to associate the processed logs with.

Returns:

  • (String)


73
74
75
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 73

def log_group_id
  @log_group_id
end

#log_source_nameString

[Required] Name of the Logging Analytics Source to use for the processing.

Returns:

  • (String)


77
78
79
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 77

def log_source_name
  @log_source_name
end

#nameString

[Required] A unique name to the rule. The name must be unique, within the tenancy, and cannot be changed.

Returns:

  • (String)


32
33
34
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 32

def name
  @name
end

#object_name_filtersArray<String>

When the filters are provided, only the objects matching the filters are picked up for processing. The matchType supported is exact match and accommodates wildcard "*". For more information on filters, see [Event Filters](docs.oracle.com/en-us/iaas/Content/Events/Concepts/filterevents.htm).

Returns:

  • (Array<String>)


125
126
127
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 125

def object_name_filters
  @object_name_filters
end

#os_bucket_nameString

[Required] Name of the Object Storage bucket.

Returns:

  • (String)


50
51
52
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 50

def os_bucket_name
  @os_bucket_name
end

#os_namespaceString

[Required] Object Storage namespace.

Returns:

  • (String)


46
47
48
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 46

def os_namespace
  @os_namespace
end

#overridesHash<String, Array<OCI::LogAnalytics::Models::PropertyOverride>>

Use this to override some property values which are defined at bucket level to the scope of object. Supported propeties for override are: logSourceName, charEncoding, entityId. Supported matchType for override are "contains".

Returns:



96
97
98
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 96

def overrides
  @overrides
end

#poll_sinceString

[Required] The oldest time of the file in the bucket to consider for collection. Accepted values are: BEGINNING or CURRENT_TIME or RFC3339 formatted datetime string. Use this for HISTORIC or HISTORIC_LIVE collection types. When collectionType is LIVE, specifying pollSince value other than CURRENT_TIME will result in error.

Returns:

  • (String)


62
63
64
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 62

def poll_since
  @poll_since
end

#poll_tillString

The newest time of the file in the bucket to consider for collection. Accepted values are: CURRENT_TIME or RFC3339 formatted datetime string. Use this for HISTORIC collection type. When collectionType is LIVE or HISTORIC_LIVE, specifying pollTill will result in error.

Returns:

  • (String)


69
70
71
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 69

def poll_till
  @poll_till
end

#time_createdDateTime

[Required] The time when this rule was created. An RFC3339 formatted datetime string.

Returns:

  • (DateTime)


109
110
111
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 109

def time_created
  @time_created
end

#time_updatedDateTime

[Required] The time when this rule was last updated. An RFC3339 formatted datetime string.

Returns:

  • (DateTime)


113
114
115
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 113

def time_updated
  @time_updated
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 140

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'name': :'name',
    'description': :'description',
    'compartment_id': :'compartmentId',
    'os_namespace': :'osNamespace',
    'os_bucket_name': :'osBucketName',
    'collection_type': :'collectionType',
    'poll_since': :'pollSince',
    'poll_till': :'pollTill',
    'log_group_id': :'logGroupId',
    'log_source_name': :'logSourceName',
    'entity_id': :'entityId',
    'char_encoding': :'charEncoding',
    'overrides': :'overrides',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'is_enabled': :'isEnabled',
    'object_name_filters': :'objectNameFilters',
    'defined_tags': :'definedTags',
    'freeform_tags': :'freeformTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 170

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'name': :'String',
    'description': :'String',
    'compartment_id': :'String',
    'os_namespace': :'String',
    'os_bucket_name': :'String',
    'collection_type': :'String',
    'poll_since': :'String',
    'poll_till': :'String',
    'log_group_id': :'String',
    'log_source_name': :'String',
    'entity_id': :'String',
    'char_encoding': :'String',
    'overrides': :'Hash<String, Array<OCI::LogAnalytics::Models::PropertyOverride>>',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'is_enabled': :'BOOLEAN',
    'object_name_filters': :'Array<String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'freeform_tags': :'Hash<String, String>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 391

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    name == other.name &&
    description == other.description &&
    compartment_id == other.compartment_id &&
    os_namespace == other.os_namespace &&
    os_bucket_name == other.os_bucket_name &&
    collection_type == other.collection_type &&
    poll_since == other.poll_since &&
    poll_till == other.poll_till &&
    log_group_id == other.log_group_id &&
    log_source_name == other.log_source_name &&
    entity_id == other.entity_id &&
    char_encoding == other.char_encoding &&
    overrides == other.overrides &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    is_enabled == other.is_enabled &&
    object_name_filters == other.object_name_filters &&
    defined_tags == other.defined_tags &&
    freeform_tags == other.freeform_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 442

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


422
423
424
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 422

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



431
432
433
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 431

def hash
  [id, name, description, compartment_id, os_namespace, os_bucket_name, collection_type, poll_since, poll_till, log_group_id, log_source_name, entity_id, char_encoding, overrides, lifecycle_state, lifecycle_details, time_created, time_updated, is_enabled, object_name_filters, defined_tags, freeform_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



475
476
477
478
479
480
481
482
483
484
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 475

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



469
470
471
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 469

def to_s
  to_hash.to_s
end