Class: OCI::LogAnalytics::Models::LogAnalyticsParameter
- Inherits:
-
Object
- Object
- OCI::LogAnalytics::Models::LogAnalyticsParameter
- Defined in:
- lib/oci/log_analytics/models/log_analytics_parameter.rb
Overview
LogAnalyticsParameter
Instance Attribute Summary collapse
-
#default_value ⇒ String
The default value of the parameter.
-
#description ⇒ String
The parameter description.
-
#is_active ⇒ BOOLEAN
A flag indicating whether or not the parameter is active.
-
#name ⇒ String
The parameter name.
-
#source_id ⇒ Integer
The source unique identifier.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LogAnalyticsParameter
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ LogAnalyticsParameter
Initializes the object
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/oci/log_analytics/models/log_analytics_parameter.rb', line 68 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.default_value = attributes[:'defaultValue'] if attributes[:'defaultValue'] raise 'You cannot provide both :defaultValue and :default_value' if attributes.key?(:'defaultValue') && attributes.key?(:'default_value') self.default_value = attributes[:'default_value'] if attributes[:'default_value'] self.description = attributes[:'description'] if attributes[:'description'] self.is_active = attributes[:'isActive'] unless attributes[:'isActive'].nil? raise 'You cannot provide both :isActive and :is_active' if attributes.key?(:'isActive') && attributes.key?(:'is_active') self.is_active = attributes[:'is_active'] unless attributes[:'is_active'].nil? self.name = attributes[:'name'] if attributes[:'name'] self.source_id = attributes[:'sourceId'] if attributes[:'sourceId'] raise 'You cannot provide both :sourceId and :source_id' if attributes.key?(:'sourceId') && attributes.key?(:'source_id') self.source_id = attributes[:'source_id'] if attributes[:'source_id'] end |
Instance Attribute Details
#default_value ⇒ String
The default value of the parameter.
12 13 14 |
# File 'lib/oci/log_analytics/models/log_analytics_parameter.rb', line 12 def default_value @default_value end |
#description ⇒ String
The parameter description.
16 17 18 |
# File 'lib/oci/log_analytics/models/log_analytics_parameter.rb', line 16 def description @description end |
#is_active ⇒ BOOLEAN
A flag indicating whether or not the parameter is active.
21 22 23 |
# File 'lib/oci/log_analytics/models/log_analytics_parameter.rb', line 21 def is_active @is_active end |
#name ⇒ String
The parameter name.
25 26 27 |
# File 'lib/oci/log_analytics/models/log_analytics_parameter.rb', line 25 def name @name end |
#source_id ⇒ Integer
The source unique identifier.
29 30 31 |
# File 'lib/oci/log_analytics/models/log_analytics_parameter.rb', line 29 def source_id @source_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 40 41 42 |
# File 'lib/oci/log_analytics/models/log_analytics_parameter.rb', line 32 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'default_value': :'defaultValue', 'description': :'description', 'is_active': :'isActive', 'name': :'name', 'source_id': :'sourceId' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/oci/log_analytics/models/log_analytics_parameter.rb', line 45 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'default_value': :'String', 'description': :'String', 'is_active': :'BOOLEAN', 'name': :'String', 'source_id': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
104 105 106 107 108 109 110 111 112 113 |
# File 'lib/oci/log_analytics/models/log_analytics_parameter.rb', line 104 def ==(other) return true if equal?(other) self.class == other.class && default_value == other.default_value && description == other.description && is_active == other.is_active && name == other.name && source_id == other.source_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/oci/log_analytics/models/log_analytics_parameter.rb', line 138 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
118 119 120 |
# File 'lib/oci/log_analytics/models/log_analytics_parameter.rb', line 118 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
127 128 129 |
# File 'lib/oci/log_analytics/models/log_analytics_parameter.rb', line 127 def hash [default_value, description, is_active, name, source_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
171 172 173 174 175 176 177 178 179 180 |
# File 'lib/oci/log_analytics/models/log_analytics_parameter.rb', line 171 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
165 166 167 |
# File 'lib/oci/log_analytics/models/log_analytics_parameter.rb', line 165 def to_s to_hash.to_s end |