Class: OCI::LogAnalytics::Models::LogAnalyticsParser

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/log_analytics/models/log_analytics_parser.rb

Overview

LogAnalyticsParser

Constant Summary collapse

TYPE_ENUM =
[
  TYPE_XML = 'XML'.freeze,
  TYPE_JSON = 'JSON'.freeze,
  TYPE_REGEX = 'REGEX'.freeze,
  TYPE_ODL = 'ODL'.freeze,
  TYPE_DELIMITED = 'DELIMITED'.freeze,
  TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ LogAnalyticsParser

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
# File 'lib/oci/log_analytics/models/log_analytics_parser.rb', line 282

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.content = attributes[:'content'] if attributes[:'content']

  self.description = attributes[:'description'] if attributes[:'description']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.edit_version = attributes[:'editVersion'] if attributes[:'editVersion']

  raise 'You cannot provide both :editVersion and :edit_version' if attributes.key?(:'editVersion') && attributes.key?(:'edit_version')

  self.edit_version = attributes[:'edit_version'] if attributes[:'edit_version']

  self.encoding = attributes[:'encoding'] if attributes[:'encoding']

  self.example_content = attributes[:'exampleContent'] if attributes[:'exampleContent']

  raise 'You cannot provide both :exampleContent and :example_content' if attributes.key?(:'exampleContent') && attributes.key?(:'example_content')

  self.example_content = attributes[:'example_content'] if attributes[:'example_content']

  self.field_maps = attributes[:'fieldMaps'] if attributes[:'fieldMaps']

  raise 'You cannot provide both :fieldMaps and :field_maps' if attributes.key?(:'fieldMaps') && attributes.key?(:'field_maps')

  self.field_maps = attributes[:'field_maps'] if attributes[:'field_maps']

  self.footer_content = attributes[:'footerContent'] if attributes[:'footerContent']

  raise 'You cannot provide both :footerContent and :footer_content' if attributes.key?(:'footerContent') && attributes.key?(:'footer_content')

  self.footer_content = attributes[:'footer_content'] if attributes[:'footer_content']

  self.header_content = attributes[:'headerContent'] if attributes[:'headerContent']

  raise 'You cannot provide both :headerContent and :header_content' if attributes.key?(:'headerContent') && attributes.key?(:'header_content')

  self.header_content = attributes[:'header_content'] if attributes[:'header_content']

  self.name = attributes[:'name'] if attributes[:'name']

  self.is_default = attributes[:'isDefault'] unless attributes[:'isDefault'].nil?

  raise 'You cannot provide both :isDefault and :is_default' if attributes.key?(:'isDefault') && attributes.key?(:'is_default')

  self.is_default = attributes[:'is_default'] unless attributes[:'is_default'].nil?

  self.is_single_line_content = attributes[:'isSingleLineContent'] unless attributes[:'isSingleLineContent'].nil?

  raise 'You cannot provide both :isSingleLineContent and :is_single_line_content' if attributes.key?(:'isSingleLineContent') && attributes.key?(:'is_single_line_content')

  self.is_single_line_content = attributes[:'is_single_line_content'] unless attributes[:'is_single_line_content'].nil?

  self.is_system = attributes[:'isSystem'] unless attributes[:'isSystem'].nil?

  raise 'You cannot provide both :isSystem and :is_system' if attributes.key?(:'isSystem') && attributes.key?(:'is_system')

  self.is_system = attributes[:'is_system'] unless attributes[:'is_system'].nil?

  self.language = attributes[:'language'] if attributes[:'language']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.log_type_test_request_version = attributes[:'logTypeTestRequestVersion'] if attributes[:'logTypeTestRequestVersion']

  raise 'You cannot provide both :logTypeTestRequestVersion and :log_type_test_request_version' if attributes.key?(:'logTypeTestRequestVersion') && attributes.key?(:'log_type_test_request_version')

  self.log_type_test_request_version = attributes[:'log_type_test_request_version'] if attributes[:'log_type_test_request_version']

  self.mapped_parsers = attributes[:'mappedParsers'] if attributes[:'mappedParsers']

  raise 'You cannot provide both :mappedParsers and :mapped_parsers' if attributes.key?(:'mappedParsers') && attributes.key?(:'mapped_parsers')

  self.mapped_parsers = attributes[:'mapped_parsers'] if attributes[:'mapped_parsers']

  self.parser_ignoreline_characters = attributes[:'parserIgnorelineCharacters'] if attributes[:'parserIgnorelineCharacters']

  raise 'You cannot provide both :parserIgnorelineCharacters and :parser_ignoreline_characters' if attributes.key?(:'parserIgnorelineCharacters') && attributes.key?(:'parser_ignoreline_characters')

  self.parser_ignoreline_characters = attributes[:'parser_ignoreline_characters'] if attributes[:'parser_ignoreline_characters']

  self.is_hidden = attributes[:'isHidden'] unless attributes[:'isHidden'].nil?

  raise 'You cannot provide both :isHidden and :is_hidden' if attributes.key?(:'isHidden') && attributes.key?(:'is_hidden')

  self.is_hidden = attributes[:'is_hidden'] unless attributes[:'is_hidden'].nil?

  self.parser_sequence = attributes[:'parserSequence'] if attributes[:'parserSequence']

  raise 'You cannot provide both :parserSequence and :parser_sequence' if attributes.key?(:'parserSequence') && attributes.key?(:'parser_sequence')

  self.parser_sequence = attributes[:'parser_sequence'] if attributes[:'parser_sequence']

  self.parser_timezone = attributes[:'parserTimezone'] if attributes[:'parserTimezone']

  raise 'You cannot provide both :parserTimezone and :parser_timezone' if attributes.key?(:'parserTimezone') && attributes.key?(:'parser_timezone')

  self.parser_timezone = attributes[:'parser_timezone'] if attributes[:'parser_timezone']

  self.parser_filter = attributes[:'parserFilter'] if attributes[:'parserFilter']

  raise 'You cannot provide both :parserFilter and :parser_filter' if attributes.key?(:'parserFilter') && attributes.key?(:'parser_filter')

  self.parser_filter = attributes[:'parser_filter'] if attributes[:'parser_filter']

  self.is_parser_written_once = attributes[:'isParserWrittenOnce'] unless attributes[:'isParserWrittenOnce'].nil?

  raise 'You cannot provide both :isParserWrittenOnce and :is_parser_written_once' if attributes.key?(:'isParserWrittenOnce') && attributes.key?(:'is_parser_written_once')

  self.is_parser_written_once = attributes[:'is_parser_written_once'] unless attributes[:'is_parser_written_once'].nil?

  self.parser_functions = attributes[:'parserFunctions'] if attributes[:'parserFunctions']

  raise 'You cannot provide both :parserFunctions and :parser_functions' if attributes.key?(:'parserFunctions') && attributes.key?(:'parser_functions')

  self.parser_functions = attributes[:'parser_functions'] if attributes[:'parser_functions']

  self.sources_count = attributes[:'sourcesCount'] if attributes[:'sourcesCount']

  raise 'You cannot provide both :sourcesCount and :sources_count' if attributes.key?(:'sourcesCount') && attributes.key?(:'sources_count')

  self.sources_count = attributes[:'sources_count'] if attributes[:'sources_count']

  self.sources = attributes[:'sources'] if attributes[:'sources']

  self.should_tokenize_original_text = attributes[:'shouldTokenizeOriginalText'] unless attributes[:'shouldTokenizeOriginalText'].nil?

  raise 'You cannot provide both :shouldTokenizeOriginalText and :should_tokenize_original_text' if attributes.key?(:'shouldTokenizeOriginalText') && attributes.key?(:'should_tokenize_original_text')

  self.should_tokenize_original_text = attributes[:'should_tokenize_original_text'] unless attributes[:'should_tokenize_original_text'].nil?

  self.field_delimiter = attributes[:'fieldDelimiter'] if attributes[:'fieldDelimiter']

  raise 'You cannot provide both :fieldDelimiter and :field_delimiter' if attributes.key?(:'fieldDelimiter') && attributes.key?(:'field_delimiter')

  self.field_delimiter = attributes[:'field_delimiter'] if attributes[:'field_delimiter']

  self.field_qualifier = attributes[:'fieldQualifier'] if attributes[:'fieldQualifier']

  raise 'You cannot provide both :fieldQualifier and :field_qualifier' if attributes.key?(:'fieldQualifier') && attributes.key?(:'field_qualifier')

  self.field_qualifier = attributes[:'field_qualifier'] if attributes[:'field_qualifier']

  self.type = attributes[:'type'] if attributes[:'type']
  self.type = "REGEX" if type.nil? && !attributes.key?(:'type') # rubocop:disable Style/StringLiterals

  self.is_user_deleted = attributes[:'isUserDeleted'] unless attributes[:'isUserDeleted'].nil?

  raise 'You cannot provide both :isUserDeleted and :is_user_deleted' if attributes.key?(:'isUserDeleted') && attributes.key?(:'is_user_deleted')

  self.is_user_deleted = attributes[:'is_user_deleted'] unless attributes[:'is_user_deleted'].nil?

  self.is_namespace_aware = attributes[:'isNamespaceAware'] unless attributes[:'isNamespaceAware'].nil?

  raise 'You cannot provide both :isNamespaceAware and :is_namespace_aware' if attributes.key?(:'isNamespaceAware') && attributes.key?(:'is_namespace_aware')

  self.is_namespace_aware = attributes[:'is_namespace_aware'] unless attributes[:'is_namespace_aware'].nil?

  self.categories = attributes[:'categories'] if attributes[:'categories']
end

Instance Attribute Details

#categoriesArray<OCI::LogAnalytics::Models::LogAnalyticsCategory>

An array of categories assigned to this parser. The isSystem flag denotes if each category assignment is user-created or Oracle-defined.



159
160
161
# File 'lib/oci/log_analytics/models/log_analytics_parser.rb', line 159

def categories
  @categories
end

#contentString

The content.

Returns:

  • (String)


22
23
24
# File 'lib/oci/log_analytics/models/log_analytics_parser.rb', line 22

def content
  @content
end

#descriptionString

The parser description.

Returns:

  • (String)


26
27
28
# File 'lib/oci/log_analytics/models/log_analytics_parser.rb', line 26

def description
  @description
end

#display_nameString

The parser display name.

Returns:

  • (String)


30
31
32
# File 'lib/oci/log_analytics/models/log_analytics_parser.rb', line 30

def display_name
  @display_name
end

#edit_versionInteger

The parser edit version.

Returns:

  • (Integer)


34
35
36
# File 'lib/oci/log_analytics/models/log_analytics_parser.rb', line 34

def edit_version
  @edit_version
end

#encodingString

The encoding.

Returns:

  • (String)


38
39
40
# File 'lib/oci/log_analytics/models/log_analytics_parser.rb', line 38

def encoding
  @encoding
end

#example_contentString

The example content.

Returns:

  • (String)


42
43
44
# File 'lib/oci/log_analytics/models/log_analytics_parser.rb', line 42

def example_content
  @example_content
end

#field_delimiterString

The parser field delimiter.

Returns:

  • (String)


135
136
137
# File 'lib/oci/log_analytics/models/log_analytics_parser.rb', line 135

def field_delimiter
  @field_delimiter
end

#field_mapsArray<OCI::LogAnalytics::Models::LogAnalyticsParserField>

The parser fields.



46
47
48
# File 'lib/oci/log_analytics/models/log_analytics_parser.rb', line 46

def field_maps
  @field_maps
end

#field_qualifierString

The parser field qualifier.

Returns:

  • (String)


139
140
141
# File 'lib/oci/log_analytics/models/log_analytics_parser.rb', line 139

def field_qualifier
  @field_qualifier
end

The footer regular expression.

Returns:

  • (String)


50
51
52
# File 'lib/oci/log_analytics/models/log_analytics_parser.rb', line 50

def footer_content
  @footer_content
end

#header_contentString

The header content.

Returns:

  • (String)


54
55
56
# File 'lib/oci/log_analytics/models/log_analytics_parser.rb', line 54

def header_content
  @header_content
end

#is_defaultBOOLEAN

A flag indicating if this is a default parser.

Returns:

  • (BOOLEAN)


63
64
65
# File 'lib/oci/log_analytics/models/log_analytics_parser.rb', line 63

def is_default
  @is_default
end

#is_hiddenBOOLEAN

A flag indicating if the parser is hidden or not.

Returns:

  • (BOOLEAN)


98
99
100
# File 'lib/oci/log_analytics/models/log_analytics_parser.rb', line 98

def is_hidden
  @is_hidden
end

#is_namespace_awareBOOLEAN

A flag indicating whether the XML parser should consider the namespace(s) while processing the log data.

Returns:

  • (BOOLEAN)


153
154
155
# File 'lib/oci/log_analytics/models/log_analytics_parser.rb', line 153

def is_namespace_aware
  @is_namespace_aware
end

#is_parser_written_onceBOOLEAN

A flag indicating whther or not the parser is write once.

Returns:

  • (BOOLEAN)


114
115
116
# File 'lib/oci/log_analytics/models/log_analytics_parser.rb', line 114

def is_parser_written_once
  @is_parser_written_once
end

#is_single_line_contentBOOLEAN

A flag indicating if this is a single line content parser.

Returns:

  • (BOOLEAN)


68
69
70
# File 'lib/oci/log_analytics/models/log_analytics_parser.rb', line 68

def is_single_line_content
  @is_single_line_content
end

#is_systemBOOLEAN

The system flag. A value of false denotes a custom, or user defined object. A value of true denotes a built in object.

Returns:

  • (BOOLEAN)


74
75
76
# File 'lib/oci/log_analytics/models/log_analytics_parser.rb', line 74

def is_system
  @is_system
end

#is_user_deletedBOOLEAN

A flag indicating whether or not the parser has been deleted.

Returns:

  • (BOOLEAN)


148
149
150
# File 'lib/oci/log_analytics/models/log_analytics_parser.rb', line 148

def is_user_deleted
  @is_user_deleted
end

#languageString

The language.

Returns:

  • (String)


78
79
80
# File 'lib/oci/log_analytics/models/log_analytics_parser.rb', line 78

def language
  @language
end

#log_type_test_request_versionInteger

The log type test request .

Returns:

  • (Integer)


86
87
88
# File 'lib/oci/log_analytics/models/log_analytics_parser.rb', line 86

def log_type_test_request_version
  @log_type_test_request_version
end

#mapped_parsersArray<OCI::LogAnalytics::Models::LogAnalyticsParser>

The mapped parser list.



90
91
92
# File 'lib/oci/log_analytics/models/log_analytics_parser.rb', line 90

def mapped_parsers
  @mapped_parsers
end

#nameString

The parser name.

Returns:

  • (String)


58
59
60
# File 'lib/oci/log_analytics/models/log_analytics_parser.rb', line 58

def name
  @name
end

#parser_filterOCI::LogAnalytics::Models::LogAnalyticsParserFilter



109
110
111
# File 'lib/oci/log_analytics/models/log_analytics_parser.rb', line 109

def parser_filter
  @parser_filter
end

#parser_functionsArray<OCI::LogAnalytics::Models::LogAnalyticsParserFunction>

The parser function list.



118
119
120
# File 'lib/oci/log_analytics/models/log_analytics_parser.rb', line 118

def parser_functions
  @parser_functions
end

#parser_ignoreline_charactersString

The line characters for the parser to ignore.

Returns:

  • (String)


94
95
96
# File 'lib/oci/log_analytics/models/log_analytics_parser.rb', line 94

def parser_ignoreline_characters
  @parser_ignoreline_characters
end

#parser_sequenceInteger

The parser sequence.

Returns:

  • (Integer)


102
103
104
# File 'lib/oci/log_analytics/models/log_analytics_parser.rb', line 102

def parser_sequence
  @parser_sequence
end

#parser_timezoneString

The time zone.

Returns:

  • (String)


106
107
108
# File 'lib/oci/log_analytics/models/log_analytics_parser.rb', line 106

def parser_timezone
  @parser_timezone
end

#should_tokenize_original_textBOOLEAN

A flag indicating whether or not to tokenize the original text.

Returns:

  • (BOOLEAN)


131
132
133
# File 'lib/oci/log_analytics/models/log_analytics_parser.rb', line 131

def should_tokenize_original_text
  @should_tokenize_original_text
end

#sourcesArray<OCI::LogAnalytics::Models::LogAnalyticsSource>

The list of sources using this parser.



126
127
128
# File 'lib/oci/log_analytics/models/log_analytics_parser.rb', line 126

def sources
  @sources
end

#sources_countInteger

The number of sources using this parser

Returns:

  • (Integer)


122
123
124
# File 'lib/oci/log_analytics/models/log_analytics_parser.rb', line 122

def sources_count
  @sources_count
end

#time_updatedDateTime

The last updated date.

Returns:

  • (DateTime)


82
83
84
# File 'lib/oci/log_analytics/models/log_analytics_parser.rb', line 82

def time_updated
  @time_updated
end

#typeString

The parser type. Default value is REGEX.

Returns:

  • (String)


143
144
145
# File 'lib/oci/log_analytics/models/log_analytics_parser.rb', line 143

def type
  @type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/oci/log_analytics/models/log_analytics_parser.rb', line 162

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'content': :'content',
    'description': :'description',
    'display_name': :'displayName',
    'edit_version': :'editVersion',
    'encoding': :'encoding',
    'example_content': :'exampleContent',
    'field_maps': :'fieldMaps',
    'footer_content': :'footerContent',
    'header_content': :'headerContent',
    'name': :'name',
    'is_default': :'isDefault',
    'is_single_line_content': :'isSingleLineContent',
    'is_system': :'isSystem',
    'language': :'language',
    'time_updated': :'timeUpdated',
    'log_type_test_request_version': :'logTypeTestRequestVersion',
    'mapped_parsers': :'mappedParsers',
    'parser_ignoreline_characters': :'parserIgnorelineCharacters',
    'is_hidden': :'isHidden',
    'parser_sequence': :'parserSequence',
    'parser_timezone': :'parserTimezone',
    'parser_filter': :'parserFilter',
    'is_parser_written_once': :'isParserWrittenOnce',
    'parser_functions': :'parserFunctions',
    'sources_count': :'sourcesCount',
    'sources': :'sources',
    'should_tokenize_original_text': :'shouldTokenizeOriginalText',
    'field_delimiter': :'fieldDelimiter',
    'field_qualifier': :'fieldQualifier',
    'type': :'type',
    'is_user_deleted': :'isUserDeleted',
    'is_namespace_aware': :'isNamespaceAware',
    'categories': :'categories'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/oci/log_analytics/models/log_analytics_parser.rb', line 203

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'content': :'String',
    'description': :'String',
    'display_name': :'String',
    'edit_version': :'Integer',
    'encoding': :'String',
    'example_content': :'String',
    'field_maps': :'Array<OCI::LogAnalytics::Models::LogAnalyticsParserField>',
    'footer_content': :'String',
    'header_content': :'String',
    'name': :'String',
    'is_default': :'BOOLEAN',
    'is_single_line_content': :'BOOLEAN',
    'is_system': :'BOOLEAN',
    'language': :'String',
    'time_updated': :'DateTime',
    'log_type_test_request_version': :'Integer',
    'mapped_parsers': :'Array<OCI::LogAnalytics::Models::LogAnalyticsParser>',
    'parser_ignoreline_characters': :'String',
    'is_hidden': :'BOOLEAN',
    'parser_sequence': :'Integer',
    'parser_timezone': :'String',
    'parser_filter': :'OCI::LogAnalytics::Models::LogAnalyticsParserFilter',
    'is_parser_written_once': :'BOOLEAN',
    'parser_functions': :'Array<OCI::LogAnalytics::Models::LogAnalyticsParserFunction>',
    'sources_count': :'Integer',
    'sources': :'Array<OCI::LogAnalytics::Models::LogAnalyticsSource>',
    'should_tokenize_original_text': :'BOOLEAN',
    'field_delimiter': :'String',
    'field_qualifier': :'String',
    'type': :'String',
    'is_user_deleted': :'BOOLEAN',
    'is_namespace_aware': :'BOOLEAN',
    'categories': :'Array<OCI::LogAnalytics::Models::LogAnalyticsCategory>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
# File 'lib/oci/log_analytics/models/log_analytics_parser.rb', line 476

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    content == other.content &&
    description == other.description &&
    display_name == other.display_name &&
    edit_version == other.edit_version &&
    encoding == other.encoding &&
    example_content == other.example_content &&
    field_maps == other.field_maps &&
    footer_content == other.footer_content &&
    header_content == other.header_content &&
    name == other.name &&
    is_default == other.is_default &&
    is_single_line_content == other.is_single_line_content &&
    is_system == other.is_system &&
    language == other.language &&
    time_updated == other.time_updated &&
    log_type_test_request_version == other.log_type_test_request_version &&
    mapped_parsers == other.mapped_parsers &&
    parser_ignoreline_characters == other.parser_ignoreline_characters &&
    is_hidden == other.is_hidden &&
    parser_sequence == other.parser_sequence &&
    parser_timezone == other.parser_timezone &&
    parser_filter == other.parser_filter &&
    is_parser_written_once == other.is_parser_written_once &&
    parser_functions == other.parser_functions &&
    sources_count == other.sources_count &&
    sources == other.sources &&
    should_tokenize_original_text == other.should_tokenize_original_text &&
    field_delimiter == other.field_delimiter &&
    field_qualifier == other.field_qualifier &&
    type == other.type &&
    is_user_deleted == other.is_user_deleted &&
    is_namespace_aware == other.is_namespace_aware &&
    categories == other.categories
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
# File 'lib/oci/log_analytics/models/log_analytics_parser.rb', line 538

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


518
519
520
# File 'lib/oci/log_analytics/models/log_analytics_parser.rb', line 518

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



527
528
529
# File 'lib/oci/log_analytics/models/log_analytics_parser.rb', line 527

def hash
  [content, description, display_name, edit_version, encoding, example_content, field_maps, footer_content, header_content, name, is_default, is_single_line_content, is_system, language, time_updated, log_type_test_request_version, mapped_parsers, parser_ignoreline_characters, is_hidden, parser_sequence, parser_timezone, parser_filter, is_parser_written_once, parser_functions, sources_count, sources, should_tokenize_original_text, field_delimiter, field_qualifier, type, is_user_deleted, is_namespace_aware, categories].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



571
572
573
574
575
576
577
578
579
580
# File 'lib/oci/log_analytics/models/log_analytics_parser.rb', line 571

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



565
566
567
# File 'lib/oci/log_analytics/models/log_analytics_parser.rb', line 565

def to_s
  to_hash.to_s
end