Class: OCI::LogAnalytics::Models::LogAnalyticsParserFilter
- Inherits:
-
Object
- Object
- OCI::LogAnalytics::Models::LogAnalyticsParserFilter
- Defined in:
- lib/oci/log_analytics/models/log_analytics_parser_filter.rb
Overview
LogAnalyticsParserFilter
Instance Attribute Summary collapse
-
#agent_version ⇒ String
The agent version.
-
#id ⇒ String
The parser filter unique identifier.
-
#is_in_use ⇒ Integer
A flag idicating whether or not hte filter is currently being used.
-
#operating_system ⇒ String
The operating system.
- #parser ⇒ OCI::LogAnalytics::Models::LogAnalyticsParser
-
#parser_id ⇒ Integer
The parser unique identifier.
-
#version ⇒ String
The version.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LogAnalyticsParserFilter
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ LogAnalyticsParserFilter
Initializes the object
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/oci/log_analytics/models/log_analytics_parser_filter.rb', line 81 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.parser = attributes[:'parser'] if attributes[:'parser'] self.agent_version = attributes[:'agentVersion'] if attributes[:'agentVersion'] raise 'You cannot provide both :agentVersion and :agent_version' if attributes.key?(:'agentVersion') && attributes.key?(:'agent_version') self.agent_version = attributes[:'agent_version'] if attributes[:'agent_version'] self.is_in_use = attributes[:'isInUse'] if attributes[:'isInUse'] raise 'You cannot provide both :isInUse and :is_in_use' if attributes.key?(:'isInUse') && attributes.key?(:'is_in_use') self.is_in_use = attributes[:'is_in_use'] if attributes[:'is_in_use'] self. = attributes[:'operatingSystem'] if attributes[:'operatingSystem'] raise 'You cannot provide both :operatingSystem and :operating_system' if attributes.key?(:'operatingSystem') && attributes.key?(:'operating_system') self. = attributes[:'operating_system'] if attributes[:'operating_system'] self.parser_id = attributes[:'parserId'] if attributes[:'parserId'] raise 'You cannot provide both :parserId and :parser_id' if attributes.key?(:'parserId') && attributes.key?(:'parser_id') self.parser_id = attributes[:'parser_id'] if attributes[:'parser_id'] self.version = attributes[:'version'] if attributes[:'version'] end |
Instance Attribute Details
#agent_version ⇒ String
The agent version.
19 20 21 |
# File 'lib/oci/log_analytics/models/log_analytics_parser_filter.rb', line 19 def agent_version @agent_version end |
#id ⇒ String
The parser filter unique identifier.
12 13 14 |
# File 'lib/oci/log_analytics/models/log_analytics_parser_filter.rb', line 12 def id @id end |
#is_in_use ⇒ Integer
A flag idicating whether or not hte filter is currently being used.
24 25 26 |
# File 'lib/oci/log_analytics/models/log_analytics_parser_filter.rb', line 24 def is_in_use @is_in_use end |
#operating_system ⇒ String
The operating system.
28 29 30 |
# File 'lib/oci/log_analytics/models/log_analytics_parser_filter.rb', line 28 def end |
#parser ⇒ OCI::LogAnalytics::Models::LogAnalyticsParser
15 16 17 |
# File 'lib/oci/log_analytics/models/log_analytics_parser_filter.rb', line 15 def parser @parser end |
#parser_id ⇒ Integer
The parser unique identifier.
32 33 34 |
# File 'lib/oci/log_analytics/models/log_analytics_parser_filter.rb', line 32 def parser_id @parser_id end |
#version ⇒ String
The version.
36 37 38 |
# File 'lib/oci/log_analytics/models/log_analytics_parser_filter.rb', line 36 def version @version end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/oci/log_analytics/models/log_analytics_parser_filter.rb', line 39 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'parser': :'parser', 'agent_version': :'agentVersion', 'is_in_use': :'isInUse', 'operating_system': :'operatingSystem', 'parser_id': :'parserId', 'version': :'version' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/oci/log_analytics/models/log_analytics_parser_filter.rb', line 54 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'parser': :'OCI::LogAnalytics::Models::LogAnalyticsParser', 'agent_version': :'String', 'is_in_use': :'Integer', 'operating_system': :'String', 'parser_id': :'Integer', 'version': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/oci/log_analytics/models/log_analytics_parser_filter.rb', line 125 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && parser == other.parser && agent_version == other.agent_version && is_in_use == other.is_in_use && == other. && parser_id == other.parser_id && version == other.version end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/oci/log_analytics/models/log_analytics_parser_filter.rb', line 161 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
141 142 143 |
# File 'lib/oci/log_analytics/models/log_analytics_parser_filter.rb', line 141 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
150 151 152 |
# File 'lib/oci/log_analytics/models/log_analytics_parser_filter.rb', line 150 def hash [id, parser, agent_version, is_in_use, , parser_id, version].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
194 195 196 197 198 199 200 201 202 203 |
# File 'lib/oci/log_analytics/models/log_analytics_parser_filter.rb', line 194 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
188 189 190 |
# File 'lib/oci/log_analytics/models/log_analytics_parser_filter.rb', line 188 def to_s to_hash.to_s end |