Class: OCI::LogAnalytics::Models::LogAnalyticsParserMetaPlugin
- Inherits:
-
Object
- Object
- OCI::LogAnalytics::Models::LogAnalyticsParserMetaPlugin
- Defined in:
- lib/oci/log_analytics/models/log_analytics_parser_meta_plugin.rb
Overview
LogAnalyticsParserMetaPlugin
Instance Attribute Summary collapse
-
#description ⇒ String
The plugin description.
-
#display_name ⇒ String
The plugin display name.
-
#meta_plugin_parameters ⇒ Array<OCI::LogAnalytics::Models::LogAnalyticsParserMetaPluginParameter>
An array of plugin parameters.
-
#name ⇒ String
The plugin internal name.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LogAnalyticsParserMetaPlugin
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ LogAnalyticsParserMetaPlugin
Initializes the object
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/oci/log_analytics/models/log_analytics_parser_meta_plugin.rb', line 60 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self. = attributes[:'metaPluginParameters'] if attributes[:'metaPluginParameters'] raise 'You cannot provide both :metaPluginParameters and :meta_plugin_parameters' if attributes.key?(:'metaPluginParameters') && attributes.key?(:'meta_plugin_parameters') self. = attributes[:'meta_plugin_parameters'] if attributes[:'meta_plugin_parameters'] self.description = attributes[:'description'] if attributes[:'description'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.name = attributes[:'name'] if attributes[:'name'] end |
Instance Attribute Details
#description ⇒ String
The plugin description.
16 17 18 |
# File 'lib/oci/log_analytics/models/log_analytics_parser_meta_plugin.rb', line 16 def description @description end |
#display_name ⇒ String
The plugin display name.
20 21 22 |
# File 'lib/oci/log_analytics/models/log_analytics_parser_meta_plugin.rb', line 20 def display_name @display_name end |
#meta_plugin_parameters ⇒ Array<OCI::LogAnalytics::Models::LogAnalyticsParserMetaPluginParameter>
An array of plugin parameters.
12 13 14 |
# File 'lib/oci/log_analytics/models/log_analytics_parser_meta_plugin.rb', line 12 def @meta_plugin_parameters end |
#name ⇒ String
The plugin internal name.
24 25 26 |
# File 'lib/oci/log_analytics/models/log_analytics_parser_meta_plugin.rb', line 24 def name @name end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
27 28 29 30 31 32 33 34 35 36 |
# File 'lib/oci/log_analytics/models/log_analytics_parser_meta_plugin.rb', line 27 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'meta_plugin_parameters': :'metaPluginParameters', 'description': :'description', 'display_name': :'displayName', 'name': :'name' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
39 40 41 42 43 44 45 46 47 48 |
# File 'lib/oci/log_analytics/models/log_analytics_parser_meta_plugin.rb', line 39 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'meta_plugin_parameters': :'Array<OCI::LogAnalytics::Models::LogAnalyticsParserMetaPluginParameter>', 'description': :'String', 'display_name': :'String', 'name': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
90 91 92 93 94 95 96 97 98 |
# File 'lib/oci/log_analytics/models/log_analytics_parser_meta_plugin.rb', line 90 def ==(other) return true if equal?(other) self.class == other.class && == other. && description == other.description && display_name == other.display_name && name == other.name end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/oci/log_analytics/models/log_analytics_parser_meta_plugin.rb', line 123 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
103 104 105 |
# File 'lib/oci/log_analytics/models/log_analytics_parser_meta_plugin.rb', line 103 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
112 113 114 |
# File 'lib/oci/log_analytics/models/log_analytics_parser_meta_plugin.rb', line 112 def hash [, description, display_name, name].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
156 157 158 159 160 161 162 163 164 165 |
# File 'lib/oci/log_analytics/models/log_analytics_parser_meta_plugin.rb', line 156 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
150 151 152 |
# File 'lib/oci/log_analytics/models/log_analytics_parser_meta_plugin.rb', line 150 def to_s to_hash.to_s end |