Class: OCI::LogAnalytics::Models::LogAnalyticsParserMetaPluginParameter

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/log_analytics/models/log_analytics_parser_meta_plugin_parameter.rb

Overview

LogAnalyticsParserMetaPluginParameter

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ LogAnalyticsParserMetaPluginParameter

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :description (String)

    The value to assign to the #description property

  • :name (String)

    The value to assign to the #name property

  • :is_mandatory (BOOLEAN)

    The value to assign to the #is_mandatory property

  • :is_repeatable (BOOLEAN)

    The value to assign to the #is_repeatable property

  • :plugin_name (String)

    The value to assign to the #plugin_name property

  • :type (String)

    The value to assign to the #type property



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/oci/log_analytics/models/log_analytics_parser_meta_plugin_parameter.rb', line 76

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.description = attributes[:'description'] if attributes[:'description']

  self.name = attributes[:'name'] if attributes[:'name']

  self.is_mandatory = attributes[:'isMandatory'] unless attributes[:'isMandatory'].nil?

  raise 'You cannot provide both :isMandatory and :is_mandatory' if attributes.key?(:'isMandatory') && attributes.key?(:'is_mandatory')

  self.is_mandatory = attributes[:'is_mandatory'] unless attributes[:'is_mandatory'].nil?

  self.is_repeatable = attributes[:'isRepeatable'] unless attributes[:'isRepeatable'].nil?

  raise 'You cannot provide both :isRepeatable and :is_repeatable' if attributes.key?(:'isRepeatable') && attributes.key?(:'is_repeatable')

  self.is_repeatable = attributes[:'is_repeatable'] unless attributes[:'is_repeatable'].nil?

  self.plugin_name = attributes[:'pluginName'] if attributes[:'pluginName']

  raise 'You cannot provide both :pluginName and :plugin_name' if attributes.key?(:'pluginName') && attributes.key?(:'plugin_name')

  self.plugin_name = attributes[:'plugin_name'] if attributes[:'plugin_name']

  self.type = attributes[:'type'] if attributes[:'type']
end

Instance Attribute Details

#descriptionString

The parameter description.

Returns:

  • (String)


12
13
14
# File 'lib/oci/log_analytics/models/log_analytics_parser_meta_plugin_parameter.rb', line 12

def description
  @description
end

#is_mandatoryBOOLEAN

A flag indicating whether or not the parameter is mandatory.

Returns:

  • (BOOLEAN)


21
22
23
# File 'lib/oci/log_analytics/models/log_analytics_parser_meta_plugin_parameter.rb', line 21

def is_mandatory
  @is_mandatory
end

#is_repeatableBOOLEAN

A flag indicating whether or not the parameter is repeatable.

Returns:

  • (BOOLEAN)


26
27
28
# File 'lib/oci/log_analytics/models/log_analytics_parser_meta_plugin_parameter.rb', line 26

def is_repeatable
  @is_repeatable
end

#nameString

The parameter internal name.

Returns:

  • (String)


16
17
18
# File 'lib/oci/log_analytics/models/log_analytics_parser_meta_plugin_parameter.rb', line 16

def name
  @name
end

#plugin_nameString

The plugin internal name.

Returns:

  • (String)


30
31
32
# File 'lib/oci/log_analytics/models/log_analytics_parser_meta_plugin_parameter.rb', line 30

def plugin_name
  @plugin_name
end

#typeString

The parameter type.

Returns:

  • (String)


34
35
36
# File 'lib/oci/log_analytics/models/log_analytics_parser_meta_plugin_parameter.rb', line 34

def type
  @type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
47
48
# File 'lib/oci/log_analytics/models/log_analytics_parser_meta_plugin_parameter.rb', line 37

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'description': :'description',
    'name': :'name',
    'is_mandatory': :'isMandatory',
    'is_repeatable': :'isRepeatable',
    'plugin_name': :'pluginName',
    'type': :'type'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/oci/log_analytics/models/log_analytics_parser_meta_plugin_parameter.rb', line 51

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'description': :'String',
    'name': :'String',
    'is_mandatory': :'BOOLEAN',
    'is_repeatable': :'BOOLEAN',
    'plugin_name': :'String',
    'type': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



114
115
116
117
118
119
120
121
122
123
124
# File 'lib/oci/log_analytics/models/log_analytics_parser_meta_plugin_parameter.rb', line 114

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    description == other.description &&
    name == other.name &&
    is_mandatory == other.is_mandatory &&
    is_repeatable == other.is_repeatable &&
    plugin_name == other.plugin_name &&
    type == other.type
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/oci/log_analytics/models/log_analytics_parser_meta_plugin_parameter.rb', line 149

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


129
130
131
# File 'lib/oci/log_analytics/models/log_analytics_parser_meta_plugin_parameter.rb', line 129

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



138
139
140
# File 'lib/oci/log_analytics/models/log_analytics_parser_meta_plugin_parameter.rb', line 138

def hash
  [description, name, is_mandatory, is_repeatable, plugin_name, type].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



182
183
184
185
186
187
188
189
190
191
# File 'lib/oci/log_analytics/models/log_analytics_parser_meta_plugin_parameter.rb', line 182

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



176
177
178
# File 'lib/oci/log_analytics/models/log_analytics_parser_meta_plugin_parameter.rb', line 176

def to_s
  to_hash.to_s
end