Class: OCI::LogAnalytics::Models::LogAnalyticsWarning
- Inherits:
-
Object
- Object
- OCI::LogAnalytics::Models::LogAnalyticsWarning
- Defined in:
- lib/oci/log_analytics/models/log_analytics_warning.rb
Overview
LogAnalyticsWarning
Instance Attribute Summary collapse
-
#agent_id ⇒ String
The unique identifier of the agent associated with the warning.
-
#compartment_id ⇒ String
The entity compartment ID.
-
#entity_id ⇒ String
The unique identifier of the entity associated with the warning.
-
#entity_name ⇒ String
The name of the entity associated with the warning.
-
#entity_type ⇒ String
The type of the entity associated with the warning.
-
#entity_type_display_name ⇒ String
The display name of the entity type associated with the warning.
-
#host_name ⇒ String
The host containing the agent associated with the warning.
-
#is_active ⇒ BOOLEAN
A flag indicating if the warning is currently active.
-
#is_suppressed ⇒ BOOLEAN
A flag indicating if the warning is currently suppressed.
-
#pattern_id ⇒ String
The unique identifier of the warning pattern.
-
#pattern_text ⇒ String
The text of the pattern used by the warning.
-
#rule_display_name ⇒ String
The display name of the rule which triggered the warning.
-
#rule_id ⇒ String
The unique identifier of the rule associated with the warning.
-
#severity ⇒ Integer
The warning severity.
-
#source_display_name ⇒ String
The display name of the source associated with the warning.
-
#source_id ⇒ String
The unique identifier of the source associated with the warning.
-
#source_name ⇒ String
The name of the source associated with the warning.
-
#suppressed_by ⇒ String
The user who suppressed the warning, or empty if the warning is not suppressed.
-
#time_collected ⇒ DateTime
The time at which the warning was most recently collected.
-
#time_of_initial_warning ⇒ DateTime
The date at which the warning was initially triggered.
-
#time_of_latest_warning ⇒ DateTime
The most recent date on which the warning was triggered.
-
#type_display_name ⇒ String
The display name of the warning type.
-
#type_name ⇒ String
The internal name of the warning.
-
#warning_id ⇒ String
The unique identifier of the warning.
-
#warning_level ⇒ String
The warning level - either pattern, rule, or source.
-
#warning_message ⇒ String
A description of the warning intended for the consumer of the warning.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LogAnalyticsWarning
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ LogAnalyticsWarning
Initializes the object
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 |
# File 'lib/oci/log_analytics/models/log_analytics_warning.rb', line 217 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.agent_id = attributes[:'agentId'] if attributes[:'agentId'] raise 'You cannot provide both :agentId and :agent_id' if attributes.key?(:'agentId') && attributes.key?(:'agent_id') self.agent_id = attributes[:'agent_id'] if attributes[:'agent_id'] self.host_name = attributes[:'hostName'] if attributes[:'hostName'] raise 'You cannot provide both :hostName and :host_name' if attributes.key?(:'hostName') && attributes.key?(:'host_name') self.host_name = attributes[:'host_name'] if attributes[:'host_name'] self.rule_display_name = attributes[:'ruleDisplayName'] if attributes[:'ruleDisplayName'] raise 'You cannot provide both :ruleDisplayName and :rule_display_name' if attributes.key?(:'ruleDisplayName') && attributes.key?(:'rule_display_name') self.rule_display_name = attributes[:'rule_display_name'] if attributes[:'rule_display_name'] self.source_name = attributes[:'sourceName'] if attributes[:'sourceName'] raise 'You cannot provide both :sourceName and :source_name' if attributes.key?(:'sourceName') && attributes.key?(:'source_name') self.source_name = attributes[:'source_name'] if attributes[:'source_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.source_display_name = attributes[:'sourceDisplayName'] if attributes[:'sourceDisplayName'] raise 'You cannot provide both :sourceDisplayName and :source_display_name' if attributes.key?(:'sourceDisplayName') && attributes.key?(:'source_display_name') self.source_display_name = attributes[:'source_display_name'] if attributes[:'source_display_name'] self.entity_name = attributes[:'entityName'] if attributes[:'entityName'] raise 'You cannot provide both :entityName and :entity_name' if attributes.key?(:'entityName') && attributes.key?(:'entity_name') self.entity_name = attributes[:'entity_name'] if attributes[:'entity_name'] self.time_collected = attributes[:'timeCollected'] if attributes[:'timeCollected'] raise 'You cannot provide both :timeCollected and :time_collected' if attributes.key?(:'timeCollected') && attributes.key?(:'time_collected') self.time_collected = attributes[:'time_collected'] if attributes[:'time_collected'] self.warning_id = attributes[:'warningId'] if attributes[:'warningId'] raise 'You cannot provide both :warningId and :warning_id' if attributes.key?(:'warningId') && attributes.key?(:'warning_id') self.warning_id = attributes[:'warning_id'] if attributes[:'warning_id'] self.time_of_initial_warning = attributes[:'timeOfInitialWarning'] if attributes[:'timeOfInitialWarning'] raise 'You cannot provide both :timeOfInitialWarning and :time_of_initial_warning' if attributes.key?(:'timeOfInitialWarning') && attributes.key?(:'time_of_initial_warning') self.time_of_initial_warning = attributes[:'time_of_initial_warning'] if attributes[:'time_of_initial_warning'] self.is_active = attributes[:'isActive'] unless attributes[:'isActive'].nil? raise 'You cannot provide both :isActive and :is_active' if attributes.key?(:'isActive') && attributes.key?(:'is_active') self.is_active = attributes[:'is_active'] unless attributes[:'is_active'].nil? self.is_suppressed = attributes[:'isSuppressed'] unless attributes[:'isSuppressed'].nil? raise 'You cannot provide both :isSuppressed and :is_suppressed' if attributes.key?(:'isSuppressed') && attributes.key?(:'is_suppressed') self.is_suppressed = attributes[:'is_suppressed'] unless attributes[:'is_suppressed'].nil? self.time_of_latest_warning = attributes[:'timeOfLatestWarning'] if attributes[:'timeOfLatestWarning'] raise 'You cannot provide both :timeOfLatestWarning and :time_of_latest_warning' if attributes.key?(:'timeOfLatestWarning') && attributes.key?(:'time_of_latest_warning') self.time_of_latest_warning = attributes[:'time_of_latest_warning'] if attributes[:'time_of_latest_warning'] self.warning_level = attributes[:'warningLevel'] if attributes[:'warningLevel'] raise 'You cannot provide both :warningLevel and :warning_level' if attributes.key?(:'warningLevel') && attributes.key?(:'warning_level') self.warning_level = attributes[:'warning_level'] if attributes[:'warning_level'] self. = attributes[:'warningMessage'] if attributes[:'warningMessage'] raise 'You cannot provide both :warningMessage and :warning_message' if attributes.key?(:'warningMessage') && attributes.key?(:'warning_message') self. = attributes[:'warning_message'] if attributes[:'warning_message'] self.pattern_id = attributes[:'patternId'] if attributes[:'patternId'] raise 'You cannot provide both :patternId and :pattern_id' if attributes.key?(:'patternId') && attributes.key?(:'pattern_id') self.pattern_id = attributes[:'pattern_id'] if attributes[:'pattern_id'] self.pattern_text = attributes[:'patternText'] if attributes[:'patternText'] raise 'You cannot provide both :patternText and :pattern_text' if attributes.key?(:'patternText') && attributes.key?(:'pattern_text') self.pattern_text = attributes[:'pattern_text'] if attributes[:'pattern_text'] self.rule_id = attributes[:'ruleId'] if attributes[:'ruleId'] raise 'You cannot provide both :ruleId and :rule_id' if attributes.key?(:'ruleId') && attributes.key?(:'rule_id') self.rule_id = attributes[:'rule_id'] if attributes[:'rule_id'] self.source_id = attributes[:'sourceId'] if attributes[:'sourceId'] raise 'You cannot provide both :sourceId and :source_id' if attributes.key?(:'sourceId') && attributes.key?(:'source_id') self.source_id = attributes[:'source_id'] if attributes[:'source_id'] self.suppressed_by = attributes[:'suppressedBy'] if attributes[:'suppressedBy'] raise 'You cannot provide both :suppressedBy and :suppressed_by' if attributes.key?(:'suppressedBy') && attributes.key?(:'suppressed_by') self.suppressed_by = attributes[:'suppressed_by'] if attributes[:'suppressed_by'] self.entity_id = attributes[:'entityId'] if attributes[:'entityId'] raise 'You cannot provide both :entityId and :entity_id' if attributes.key?(:'entityId') && attributes.key?(:'entity_id') self.entity_id = attributes[:'entity_id'] if attributes[:'entity_id'] self.entity_type = attributes[:'entityType'] if attributes[:'entityType'] raise 'You cannot provide both :entityType and :entity_type' if attributes.key?(:'entityType') && attributes.key?(:'entity_type') self.entity_type = attributes[:'entity_type'] if attributes[:'entity_type'] self.entity_type_display_name = attributes[:'entityTypeDisplayName'] if attributes[:'entityTypeDisplayName'] raise 'You cannot provide both :entityTypeDisplayName and :entity_type_display_name' if attributes.key?(:'entityTypeDisplayName') && attributes.key?(:'entity_type_display_name') self.entity_type_display_name = attributes[:'entity_type_display_name'] if attributes[:'entity_type_display_name'] self.type_display_name = attributes[:'typeDisplayName'] if attributes[:'typeDisplayName'] raise 'You cannot provide both :typeDisplayName and :type_display_name' if attributes.key?(:'typeDisplayName') && attributes.key?(:'type_display_name') self.type_display_name = attributes[:'type_display_name'] if attributes[:'type_display_name'] self.type_name = attributes[:'typeName'] if attributes[:'typeName'] raise 'You cannot provide both :typeName and :type_name' if attributes.key?(:'typeName') && attributes.key?(:'type_name') self.type_name = attributes[:'type_name'] if attributes[:'type_name'] self.severity = attributes[:'severity'] if attributes[:'severity'] end |
Instance Attribute Details
#agent_id ⇒ String
The unique identifier of the agent associated with the warning
12 13 14 |
# File 'lib/oci/log_analytics/models/log_analytics_warning.rb', line 12 def agent_id @agent_id end |
#compartment_id ⇒ String
The entity compartment ID.
28 29 30 |
# File 'lib/oci/log_analytics/models/log_analytics_warning.rb', line 28 def compartment_id @compartment_id end |
#entity_id ⇒ String
The unique identifier of the entity associated with the warning
95 96 97 |
# File 'lib/oci/log_analytics/models/log_analytics_warning.rb', line 95 def entity_id @entity_id end |
#entity_name ⇒ String
The name of the entity associated with the warning
36 37 38 |
# File 'lib/oci/log_analytics/models/log_analytics_warning.rb', line 36 def entity_name @entity_name end |
#entity_type ⇒ String
The type of the entity associated with the warning
99 100 101 |
# File 'lib/oci/log_analytics/models/log_analytics_warning.rb', line 99 def entity_type @entity_type end |
#entity_type_display_name ⇒ String
The display name of the entity type associated with the warning
103 104 105 |
# File 'lib/oci/log_analytics/models/log_analytics_warning.rb', line 103 def entity_type_display_name @entity_type_display_name end |
#host_name ⇒ String
The host containing the agent associated with the warning
16 17 18 |
# File 'lib/oci/log_analytics/models/log_analytics_warning.rb', line 16 def host_name @host_name end |
#is_active ⇒ BOOLEAN
A flag indicating if the warning is currently active
52 53 54 |
# File 'lib/oci/log_analytics/models/log_analytics_warning.rb', line 52 def is_active @is_active end |
#is_suppressed ⇒ BOOLEAN
A flag indicating if the warning is currently suppressed
56 57 58 |
# File 'lib/oci/log_analytics/models/log_analytics_warning.rb', line 56 def is_suppressed @is_suppressed end |
#pattern_id ⇒ String
The unique identifier of the warning pattern
75 76 77 |
# File 'lib/oci/log_analytics/models/log_analytics_warning.rb', line 75 def pattern_id @pattern_id end |
#pattern_text ⇒ String
The text of the pattern used by the warning
79 80 81 |
# File 'lib/oci/log_analytics/models/log_analytics_warning.rb', line 79 def pattern_text @pattern_text end |
#rule_display_name ⇒ String
The display name of the rule which triggered the warning
20 21 22 |
# File 'lib/oci/log_analytics/models/log_analytics_warning.rb', line 20 def rule_display_name @rule_display_name end |
#rule_id ⇒ String
The unique identifier of the rule associated with the warning
83 84 85 |
# File 'lib/oci/log_analytics/models/log_analytics_warning.rb', line 83 def rule_id @rule_id end |
#severity ⇒ Integer
The warning severity
115 116 117 |
# File 'lib/oci/log_analytics/models/log_analytics_warning.rb', line 115 def severity @severity end |
#source_display_name ⇒ String
The display name of the source associated with the warning
32 33 34 |
# File 'lib/oci/log_analytics/models/log_analytics_warning.rb', line 32 def source_display_name @source_display_name end |
#source_id ⇒ String
The unique identifier of the source associated with the warning
87 88 89 |
# File 'lib/oci/log_analytics/models/log_analytics_warning.rb', line 87 def source_id @source_id end |
#source_name ⇒ String
The name of the source associated with the warning
24 25 26 |
# File 'lib/oci/log_analytics/models/log_analytics_warning.rb', line 24 def source_name @source_name end |
#suppressed_by ⇒ String
The user who suppressed the warning, or empty if the warning is not suppressed
91 92 93 |
# File 'lib/oci/log_analytics/models/log_analytics_warning.rb', line 91 def suppressed_by @suppressed_by end |
#time_collected ⇒ DateTime
The time at which the warning was most recently collected
40 41 42 |
# File 'lib/oci/log_analytics/models/log_analytics_warning.rb', line 40 def time_collected @time_collected end |
#time_of_initial_warning ⇒ DateTime
The date at which the warning was initially triggered
48 49 50 |
# File 'lib/oci/log_analytics/models/log_analytics_warning.rb', line 48 def time_of_initial_warning @time_of_initial_warning end |
#time_of_latest_warning ⇒ DateTime
The most recent date on which the warning was triggered
60 61 62 |
# File 'lib/oci/log_analytics/models/log_analytics_warning.rb', line 60 def time_of_latest_warning @time_of_latest_warning end |
#type_display_name ⇒ String
The display name of the warning type
107 108 109 |
# File 'lib/oci/log_analytics/models/log_analytics_warning.rb', line 107 def type_display_name @type_display_name end |
#type_name ⇒ String
The internal name of the warning
111 112 113 |
# File 'lib/oci/log_analytics/models/log_analytics_warning.rb', line 111 def type_name @type_name end |
#warning_id ⇒ String
The unique identifier of the warning
44 45 46 |
# File 'lib/oci/log_analytics/models/log_analytics_warning.rb', line 44 def warning_id @warning_id end |
#warning_level ⇒ String
The warning level - either pattern, rule, or source.
64 65 66 |
# File 'lib/oci/log_analytics/models/log_analytics_warning.rb', line 64 def warning_level @warning_level end |
#warning_message ⇒ String
A description of the warning intended for the consumer of the warning. It will usually detail the cause of the warning, may suggest a remedy, and can contain any other relevant information the consumer might find useful
71 72 73 |
# File 'lib/oci/log_analytics/models/log_analytics_warning.rb', line 71 def @warning_message end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/oci/log_analytics/models/log_analytics_warning.rb', line 118 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'agent_id': :'agentId', 'host_name': :'hostName', 'rule_display_name': :'ruleDisplayName', 'source_name': :'sourceName', 'compartment_id': :'compartmentId', 'source_display_name': :'sourceDisplayName', 'entity_name': :'entityName', 'time_collected': :'timeCollected', 'warning_id': :'warningId', 'time_of_initial_warning': :'timeOfInitialWarning', 'is_active': :'isActive', 'is_suppressed': :'isSuppressed', 'time_of_latest_warning': :'timeOfLatestWarning', 'warning_level': :'warningLevel', 'warning_message': :'warningMessage', 'pattern_id': :'patternId', 'pattern_text': :'patternText', 'rule_id': :'ruleId', 'source_id': :'sourceId', 'suppressed_by': :'suppressedBy', 'entity_id': :'entityId', 'entity_type': :'entityType', 'entity_type_display_name': :'entityTypeDisplayName', 'type_display_name': :'typeDisplayName', 'type_name': :'typeName', 'severity': :'severity' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/oci/log_analytics/models/log_analytics_warning.rb', line 152 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'agent_id': :'String', 'host_name': :'String', 'rule_display_name': :'String', 'source_name': :'String', 'compartment_id': :'String', 'source_display_name': :'String', 'entity_name': :'String', 'time_collected': :'DateTime', 'warning_id': :'String', 'time_of_initial_warning': :'DateTime', 'is_active': :'BOOLEAN', 'is_suppressed': :'BOOLEAN', 'time_of_latest_warning': :'DateTime', 'warning_level': :'String', 'warning_message': :'String', 'pattern_id': :'String', 'pattern_text': :'String', 'rule_id': :'String', 'source_id': :'String', 'suppressed_by': :'String', 'entity_id': :'String', 'entity_type': :'String', 'entity_type_display_name': :'String', 'type_display_name': :'String', 'type_name': :'String', 'severity': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 |
# File 'lib/oci/log_analytics/models/log_analytics_warning.rb', line 383 def ==(other) return true if equal?(other) self.class == other.class && agent_id == other.agent_id && host_name == other.host_name && rule_display_name == other.rule_display_name && source_name == other.source_name && compartment_id == other.compartment_id && source_display_name == other.source_display_name && entity_name == other.entity_name && time_collected == other.time_collected && warning_id == other.warning_id && time_of_initial_warning == other.time_of_initial_warning && is_active == other.is_active && is_suppressed == other.is_suppressed && time_of_latest_warning == other.time_of_latest_warning && warning_level == other.warning_level && == other. && pattern_id == other.pattern_id && pattern_text == other.pattern_text && rule_id == other.rule_id && source_id == other.source_id && suppressed_by == other.suppressed_by && entity_id == other.entity_id && entity_type == other.entity_type && entity_type_display_name == other.entity_type_display_name && type_display_name == other.type_display_name && type_name == other.type_name && severity == other.severity end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 |
# File 'lib/oci/log_analytics/models/log_analytics_warning.rb', line 438 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
418 419 420 |
# File 'lib/oci/log_analytics/models/log_analytics_warning.rb', line 418 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
427 428 429 |
# File 'lib/oci/log_analytics/models/log_analytics_warning.rb', line 427 def hash [agent_id, host_name, rule_display_name, source_name, compartment_id, source_display_name, entity_name, time_collected, warning_id, time_of_initial_warning, is_active, is_suppressed, time_of_latest_warning, warning_level, , pattern_id, pattern_text, rule_id, source_id, suppressed_by, entity_id, entity_type, entity_type_display_name, type_display_name, type_name, severity].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
471 472 473 474 475 476 477 478 479 480 |
# File 'lib/oci/log_analytics/models/log_analytics_warning.rb', line 471 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
465 466 467 |
# File 'lib/oci/log_analytics/models/log_analytics_warning.rb', line 465 def to_s to_hash.to_s end |