Class: OCI::LogAnalytics::Models::MetricExtraction
- Inherits:
-
Object
- Object
- OCI::LogAnalytics::Models::MetricExtraction
- Defined in:
- lib/oci/log_analytics/models/metric_extraction.rb
Overview
Specify metric extraction for SAVED_SEARCH scheduled task execution to post to OCI Monitoring.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The compartment OCID (/iaas/Content/General/Concepts/identifiers.htm) of the extracted metric.
-
#metric_name ⇒ String
[Required] The metric name of the extracted metric.
-
#namespace ⇒ String
[Required] The namespace of the extracted metric.
-
#resource_group ⇒ String
The resourceGroup of the extracted metric.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MetricExtraction
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ MetricExtraction
Initializes the object
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/oci/log_analytics/models/metric_extraction.rb', line 72 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.namespace = attributes[:'namespace'] if attributes[:'namespace'] self.metric_name = attributes[:'metricName'] if attributes[:'metricName'] raise 'You cannot provide both :metricName and :metric_name' if attributes.key?(:'metricName') && attributes.key?(:'metric_name') self.metric_name = attributes[:'metric_name'] if attributes[:'metric_name'] self.resource_group = attributes[:'resourceGroup'] if attributes[:'resourceGroup'] raise 'You cannot provide both :resourceGroup and :resource_group' if attributes.key?(:'resourceGroup') && attributes.key?(:'resource_group') self.resource_group = attributes[:'resource_group'] if attributes[:'resource_group'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The compartment OCID (/iaas/Content/General/Concepts/identifiers.htm) of the extracted metric.
15 16 17 |
# File 'lib/oci/log_analytics/models/metric_extraction.rb', line 15 def compartment_id @compartment_id end |
#metric_name ⇒ String
[Required] The metric name of the extracted metric. A valid value starts with an alphabetical character and includes only alphanumeric characters, periods (.), underscores (_), hyphens (-), and dollar signs ($).
29 30 31 |
# File 'lib/oci/log_analytics/models/metric_extraction.rb', line 29 def metric_name @metric_name end |
#namespace ⇒ String
[Required] The namespace of the extracted metric. A valid value starts with an alphabetical character and includes only alphanumeric characters and underscores (_).
22 23 24 |
# File 'lib/oci/log_analytics/models/metric_extraction.rb', line 22 def namespace @namespace end |
#resource_group ⇒ String
The resourceGroup of the extracted metric. A valid value starts with an alphabetical character and includes only alphanumeric characters, periods (.), underscores (_), hyphens (-), and dollar signs ($).
36 37 38 |
# File 'lib/oci/log_analytics/models/metric_extraction.rb', line 36 def resource_group @resource_group end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 48 |
# File 'lib/oci/log_analytics/models/metric_extraction.rb', line 39 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'namespace': :'namespace', 'metric_name': :'metricName', 'resource_group': :'resourceGroup' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
51 52 53 54 55 56 57 58 59 60 |
# File 'lib/oci/log_analytics/models/metric_extraction.rb', line 51 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'namespace': :'String', 'metric_name': :'String', 'resource_group': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
106 107 108 109 110 111 112 113 114 |
# File 'lib/oci/log_analytics/models/metric_extraction.rb', line 106 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && namespace == other.namespace && metric_name == other.metric_name && resource_group == other.resource_group end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/oci/log_analytics/models/metric_extraction.rb', line 139 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
119 120 121 |
# File 'lib/oci/log_analytics/models/metric_extraction.rb', line 119 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
128 129 130 |
# File 'lib/oci/log_analytics/models/metric_extraction.rb', line 128 def hash [compartment_id, namespace, metric_name, resource_group].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
172 173 174 175 176 177 178 179 180 181 |
# File 'lib/oci/log_analytics/models/metric_extraction.rb', line 172 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
166 167 168 |
# File 'lib/oci/log_analytics/models/metric_extraction.rb', line 166 def to_s to_hash.to_s end |