Class: OCI::LogAnalytics::Models::Namespace
- Inherits:
-
Object
- Object
- OCI::LogAnalytics::Models::Namespace
- Defined in:
- lib/oci/log_analytics/models/namespace.rb
Overview
This is the namespace details of a tenancy in Logan Analytics application
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The is the tenancy ID.
-
#is_data_ever_ingested ⇒ BOOLEAN
This indicates if data has ever been ingested for the tenancy in Logging Analytics.
-
#is_log_set_enabled ⇒ BOOLEAN
This indicates if the log set feature is enabled for the tenancy.
-
#is_onboarded ⇒ BOOLEAN
[Required] This indicates if the tenancy is onboarded to Logging Analytics.
-
#namespace_name ⇒ String
[Required] This is the namespace name of a tenancy.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Namespace
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Namespace
Initializes the object
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/oci/log_analytics/models/namespace.rb', line 68 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.namespace_name = attributes[:'namespaceName'] if attributes[:'namespaceName'] raise 'You cannot provide both :namespaceName and :namespace_name' if attributes.key?(:'namespaceName') && attributes.key?(:'namespace_name') self.namespace_name = attributes[:'namespace_name'] if attributes[:'namespace_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.is_onboarded = attributes[:'isOnboarded'] unless attributes[:'isOnboarded'].nil? raise 'You cannot provide both :isOnboarded and :is_onboarded' if attributes.key?(:'isOnboarded') && attributes.key?(:'is_onboarded') self.is_onboarded = attributes[:'is_onboarded'] unless attributes[:'is_onboarded'].nil? self.is_log_set_enabled = attributes[:'isLogSetEnabled'] unless attributes[:'isLogSetEnabled'].nil? self.is_log_set_enabled = false if is_log_set_enabled.nil? && !attributes.key?(:'isLogSetEnabled') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isLogSetEnabled and :is_log_set_enabled' if attributes.key?(:'isLogSetEnabled') && attributes.key?(:'is_log_set_enabled') self.is_log_set_enabled = attributes[:'is_log_set_enabled'] unless attributes[:'is_log_set_enabled'].nil? self.is_log_set_enabled = false if is_log_set_enabled.nil? && !attributes.key?(:'isLogSetEnabled') && !attributes.key?(:'is_log_set_enabled') # rubocop:disable Style/StringLiterals self.is_data_ever_ingested = attributes[:'isDataEverIngested'] unless attributes[:'isDataEverIngested'].nil? self.is_data_ever_ingested = false if is_data_ever_ingested.nil? && !attributes.key?(:'isDataEverIngested') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isDataEverIngested and :is_data_ever_ingested' if attributes.key?(:'isDataEverIngested') && attributes.key?(:'is_data_ever_ingested') self.is_data_ever_ingested = attributes[:'is_data_ever_ingested'] unless attributes[:'is_data_ever_ingested'].nil? self.is_data_ever_ingested = false if is_data_ever_ingested.nil? && !attributes.key?(:'isDataEverIngested') && !attributes.key?(:'is_data_ever_ingested') # rubocop:disable Style/StringLiterals end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The is the tenancy ID
17 18 19 |
# File 'lib/oci/log_analytics/models/namespace.rb', line 17 def compartment_id @compartment_id end |
#is_data_ever_ingested ⇒ BOOLEAN
This indicates if data has ever been ingested for the tenancy in Logging Analytics
29 30 31 |
# File 'lib/oci/log_analytics/models/namespace.rb', line 29 def is_data_ever_ingested @is_data_ever_ingested end |
#is_log_set_enabled ⇒ BOOLEAN
This indicates if the log set feature is enabled for the tenancy
25 26 27 |
# File 'lib/oci/log_analytics/models/namespace.rb', line 25 def is_log_set_enabled @is_log_set_enabled end |
#is_onboarded ⇒ BOOLEAN
[Required] This indicates if the tenancy is onboarded to Logging Analytics
21 22 23 |
# File 'lib/oci/log_analytics/models/namespace.rb', line 21 def is_onboarded @is_onboarded end |
#namespace_name ⇒ String
[Required] This is the namespace name of a tenancy
13 14 15 |
# File 'lib/oci/log_analytics/models/namespace.rb', line 13 def namespace_name @namespace_name end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 40 41 42 |
# File 'lib/oci/log_analytics/models/namespace.rb', line 32 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'namespace_name': :'namespaceName', 'compartment_id': :'compartmentId', 'is_onboarded': :'isOnboarded', 'is_log_set_enabled': :'isLogSetEnabled', 'is_data_ever_ingested': :'isDataEverIngested' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/oci/log_analytics/models/namespace.rb', line 45 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'namespace_name': :'String', 'compartment_id': :'String', 'is_onboarded': :'BOOLEAN', 'is_log_set_enabled': :'BOOLEAN', 'is_data_ever_ingested': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
116 117 118 119 120 121 122 123 124 125 |
# File 'lib/oci/log_analytics/models/namespace.rb', line 116 def ==(other) return true if equal?(other) self.class == other.class && namespace_name == other.namespace_name && compartment_id == other.compartment_id && is_onboarded == other.is_onboarded && is_log_set_enabled == other.is_log_set_enabled && is_data_ever_ingested == other.is_data_ever_ingested end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/oci/log_analytics/models/namespace.rb', line 150 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
130 131 132 |
# File 'lib/oci/log_analytics/models/namespace.rb', line 130 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
139 140 141 |
# File 'lib/oci/log_analytics/models/namespace.rb', line 139 def hash [namespace_name, compartment_id, is_onboarded, is_log_set_enabled, is_data_ever_ingested].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
183 184 185 186 187 188 189 190 191 192 |
# File 'lib/oci/log_analytics/models/namespace.rb', line 183 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
177 178 179 |
# File 'lib/oci/log_analytics/models/namespace.rb', line 177 def to_s to_hash.to_s end |