Class: OCI::LogAnalytics::Models::NamespaceSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/log_analytics/models/namespace_summary.rb

Overview

The is the namespace summary of a tenancy in Logan Analytics application

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ NamespaceSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :namespace_name (String)

    The value to assign to the #namespace_name property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :is_onboarded (BOOLEAN)

    The value to assign to the #is_onboarded property

  • :is_log_set_enabled (BOOLEAN)

    The value to assign to the #is_log_set_enabled property

  • :is_data_ever_ingested (BOOLEAN)

    The value to assign to the #is_data_ever_ingested property



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/oci/log_analytics/models/namespace_summary.rb', line 68

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  self.namespace_name = attributes[:'namespaceName'] if attributes[:'namespaceName']

  raise 'You cannot provide both :namespaceName and :namespace_name' if attributes.key?(:'namespaceName') && attributes.key?(:'namespace_name')

  self.namespace_name = attributes[:'namespace_name'] if attributes[:'namespace_name']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.is_onboarded = attributes[:'isOnboarded'] unless attributes[:'isOnboarded'].nil?

  raise 'You cannot provide both :isOnboarded and :is_onboarded' if attributes.key?(:'isOnboarded') && attributes.key?(:'is_onboarded')

  self.is_onboarded = attributes[:'is_onboarded'] unless attributes[:'is_onboarded'].nil?

  self.is_log_set_enabled = attributes[:'isLogSetEnabled'] unless attributes[:'isLogSetEnabled'].nil?
  self.is_log_set_enabled = false if is_log_set_enabled.nil? && !attributes.key?(:'isLogSetEnabled') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isLogSetEnabled and :is_log_set_enabled' if attributes.key?(:'isLogSetEnabled') && attributes.key?(:'is_log_set_enabled')

  self.is_log_set_enabled = attributes[:'is_log_set_enabled'] unless attributes[:'is_log_set_enabled'].nil?
  self.is_log_set_enabled = false if is_log_set_enabled.nil? && !attributes.key?(:'isLogSetEnabled') && !attributes.key?(:'is_log_set_enabled') # rubocop:disable Style/StringLiterals

  self.is_data_ever_ingested = attributes[:'isDataEverIngested'] unless attributes[:'isDataEverIngested'].nil?
  self.is_data_ever_ingested = false if is_data_ever_ingested.nil? && !attributes.key?(:'isDataEverIngested') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isDataEverIngested and :is_data_ever_ingested' if attributes.key?(:'isDataEverIngested') && attributes.key?(:'is_data_ever_ingested')

  self.is_data_ever_ingested = attributes[:'is_data_ever_ingested'] unless attributes[:'is_data_ever_ingested'].nil?
  self.is_data_ever_ingested = false if is_data_ever_ingested.nil? && !attributes.key?(:'isDataEverIngested') && !attributes.key?(:'is_data_ever_ingested') # rubocop:disable Style/StringLiterals
end

Instance Attribute Details

#compartment_idString

[Required] The is the tenancy ID

Returns:

  • (String)


17
18
19
# File 'lib/oci/log_analytics/models/namespace_summary.rb', line 17

def compartment_id
  @compartment_id
end

#is_data_ever_ingestedBOOLEAN

This indicates if data has ever been ingested for the tenancy in Logging Analytics

Returns:

  • (BOOLEAN)


29
30
31
# File 'lib/oci/log_analytics/models/namespace_summary.rb', line 29

def is_data_ever_ingested
  @is_data_ever_ingested
end

#is_log_set_enabledBOOLEAN

This indicates if the log set feature is enabled for the tenancy

Returns:

  • (BOOLEAN)


25
26
27
# File 'lib/oci/log_analytics/models/namespace_summary.rb', line 25

def is_log_set_enabled
  @is_log_set_enabled
end

#is_onboardedBOOLEAN

[Required] This indicates if the tenancy is onboarded to Logging Analytics

Returns:

  • (BOOLEAN)


21
22
23
# File 'lib/oci/log_analytics/models/namespace_summary.rb', line 21

def is_onboarded
  @is_onboarded
end

#namespace_nameString

[Required] This is the namespace name of a tenancy

Returns:

  • (String)


13
14
15
# File 'lib/oci/log_analytics/models/namespace_summary.rb', line 13

def namespace_name
  @namespace_name
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



32
33
34
35
36
37
38
39
40
41
42
# File 'lib/oci/log_analytics/models/namespace_summary.rb', line 32

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'namespace_name': :'namespaceName',
    'compartment_id': :'compartmentId',
    'is_onboarded': :'isOnboarded',
    'is_log_set_enabled': :'isLogSetEnabled',
    'is_data_ever_ingested': :'isDataEverIngested'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



45
46
47
48
49
50
51
52
53
54
55
# File 'lib/oci/log_analytics/models/namespace_summary.rb', line 45

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'namespace_name': :'String',
    'compartment_id': :'String',
    'is_onboarded': :'BOOLEAN',
    'is_log_set_enabled': :'BOOLEAN',
    'is_data_ever_ingested': :'BOOLEAN'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



113
114
115
116
117
118
119
120
121
122
# File 'lib/oci/log_analytics/models/namespace_summary.rb', line 113

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    namespace_name == other.namespace_name &&
    compartment_id == other.compartment_id &&
    is_onboarded == other.is_onboarded &&
    is_log_set_enabled == other.is_log_set_enabled &&
    is_data_ever_ingested == other.is_data_ever_ingested
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/oci/log_analytics/models/namespace_summary.rb', line 147

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


127
128
129
# File 'lib/oci/log_analytics/models/namespace_summary.rb', line 127

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



136
137
138
# File 'lib/oci/log_analytics/models/namespace_summary.rb', line 136

def hash
  [namespace_name, compartment_id, is_onboarded, is_log_set_enabled, is_data_ever_ingested].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



180
181
182
183
184
185
186
187
188
189
# File 'lib/oci/log_analytics/models/namespace_summary.rb', line 180

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



174
175
176
# File 'lib/oci/log_analytics/models/namespace_summary.rb', line 174

def to_s
  to_hash.to_s
end