Class: OCI::LogAnalytics::Models::ParseQueryOutput
- Inherits:
-
Object
- Object
- OCI::LogAnalytics::Models::ParseQueryOutput
- Defined in:
- lib/oci/log_analytics/models/parse_query_output.rb
Overview
Returns a parser agnostic breakdown of a query string for client query string introspection.
Instance Attribute Summary collapse
-
#columns ⇒ Array<OCI::LogAnalytics::Models::AbstractColumn>
List of columns returned by the specified query string as result output.
-
#commands ⇒ Array<OCI::LogAnalytics::Models::AbstractCommandDescriptor>
List of querylanguage command descriptors, describing the specfied query string.
-
#display_query_string ⇒ String
[Required] Display string formatted by query builder of user specified query string.
-
#internal_query_string ⇒ String
[Required] Internal string formatted by query builder of user specified query string.
-
#response_time_in_ms ⇒ Integer
Operation response time.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ParseQueryOutput
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ParseQueryOutput
Initializes the object
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/oci/log_analytics/models/parse_query_output.rb', line 73 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_query_string = attributes[:'displayQueryString'] if attributes[:'displayQueryString'] raise 'You cannot provide both :displayQueryString and :display_query_string' if attributes.key?(:'displayQueryString') && attributes.key?(:'display_query_string') self.display_query_string = attributes[:'display_query_string'] if attributes[:'display_query_string'] self.internal_query_string = attributes[:'internalQueryString'] if attributes[:'internalQueryString'] raise 'You cannot provide both :internalQueryString and :internal_query_string' if attributes.key?(:'internalQueryString') && attributes.key?(:'internal_query_string') self.internal_query_string = attributes[:'internal_query_string'] if attributes[:'internal_query_string'] self.columns = attributes[:'columns'] if attributes[:'columns'] self.response_time_in_ms = attributes[:'responseTimeInMs'] if attributes[:'responseTimeInMs'] raise 'You cannot provide both :responseTimeInMs and :response_time_in_ms' if attributes.key?(:'responseTimeInMs') && attributes.key?(:'response_time_in_ms') self.response_time_in_ms = attributes[:'response_time_in_ms'] if attributes[:'response_time_in_ms'] self.commands = attributes[:'commands'] if attributes[:'commands'] end |
Instance Attribute Details
#columns ⇒ Array<OCI::LogAnalytics::Models::AbstractColumn>
List of columns returned by the specified query string as result output.
24 25 26 |
# File 'lib/oci/log_analytics/models/parse_query_output.rb', line 24 def columns @columns end |
#commands ⇒ Array<OCI::LogAnalytics::Models::AbstractCommandDescriptor>
List of querylanguage command descriptors, describing the specfied query string.
34 35 36 |
# File 'lib/oci/log_analytics/models/parse_query_output.rb', line 34 def commands @commands end |
#display_query_string ⇒ String
[Required] Display string formatted by query builder of user specified query string.
14 15 16 |
# File 'lib/oci/log_analytics/models/parse_query_output.rb', line 14 def display_query_string @display_query_string end |
#internal_query_string ⇒ String
[Required] Internal string formatted by query builder of user specified query string.
19 20 21 |
# File 'lib/oci/log_analytics/models/parse_query_output.rb', line 19 def internal_query_string @internal_query_string end |
#response_time_in_ms ⇒ Integer
Operation response time.
29 30 31 |
# File 'lib/oci/log_analytics/models/parse_query_output.rb', line 29 def response_time_in_ms @response_time_in_ms end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 47 |
# File 'lib/oci/log_analytics/models/parse_query_output.rb', line 37 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_query_string': :'displayQueryString', 'internal_query_string': :'internalQueryString', 'columns': :'columns', 'response_time_in_ms': :'responseTimeInMs', 'commands': :'commands' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/oci/log_analytics/models/parse_query_output.rb', line 50 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_query_string': :'String', 'internal_query_string': :'String', 'columns': :'Array<OCI::LogAnalytics::Models::AbstractColumn>', 'response_time_in_ms': :'Integer', 'commands': :'Array<OCI::LogAnalytics::Models::AbstractCommandDescriptor>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
109 110 111 112 113 114 115 116 117 118 |
# File 'lib/oci/log_analytics/models/parse_query_output.rb', line 109 def ==(other) return true if equal?(other) self.class == other.class && display_query_string == other.display_query_string && internal_query_string == other.internal_query_string && columns == other.columns && response_time_in_ms == other.response_time_in_ms && commands == other.commands end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/oci/log_analytics/models/parse_query_output.rb', line 143 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
123 124 125 |
# File 'lib/oci/log_analytics/models/parse_query_output.rb', line 123 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
132 133 134 |
# File 'lib/oci/log_analytics/models/parse_query_output.rb', line 132 def hash [display_query_string, internal_query_string, columns, response_time_in_ms, commands].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
176 177 178 179 180 181 182 183 184 185 |
# File 'lib/oci/log_analytics/models/parse_query_output.rb', line 176 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
170 171 172 |
# File 'lib/oci/log_analytics/models/parse_query_output.rb', line 170 def to_s to_hash.to_s end |