Class: OCI::LogAnalytics::Models::PurgeStorageDataDetails
- Inherits:
-
Object
- Object
- OCI::LogAnalytics::Models::PurgeStorageDataDetails
- Defined in:
- lib/oci/log_analytics/models/purge_storage_data_details.rb
Overview
This is the input used to purge data
Constant Summary collapse
- DATA_TYPE_ENUM =
[ DATA_TYPE_LOG = 'LOG'.freeze, DATA_TYPE_LOOKUP = 'LOOKUP'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] This is the compartment OCID under which the data will be purged and required permission will be checked.
-
#compartment_id_in_subtree ⇒ BOOLEAN
If true, purge child compartments data.
-
#data_type ⇒ String
This is the type of the log data to be purged.
-
#purge_query_string ⇒ String
This is the solr query used to filter data, ‘*’ means all.
-
#time_data_ended ⇒ DateTime
[Required] This is the end of the purge time interval.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PurgeStorageDataDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ PurgeStorageDataDetails
Initializes the object
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/oci/log_analytics/models/purge_storage_data_details.rb', line 73 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.compartment_id_in_subtree = attributes[:'compartmentIdInSubtree'] unless attributes[:'compartmentIdInSubtree'].nil? self.compartment_id_in_subtree = true if compartment_id_in_subtree.nil? && !attributes.key?(:'compartmentIdInSubtree') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :compartmentIdInSubtree and :compartment_id_in_subtree' if attributes.key?(:'compartmentIdInSubtree') && attributes.key?(:'compartment_id_in_subtree') self.compartment_id_in_subtree = attributes[:'compartment_id_in_subtree'] unless attributes[:'compartment_id_in_subtree'].nil? self.compartment_id_in_subtree = true if compartment_id_in_subtree.nil? && !attributes.key?(:'compartmentIdInSubtree') && !attributes.key?(:'compartment_id_in_subtree') # rubocop:disable Style/StringLiterals self.time_data_ended = attributes[:'timeDataEnded'] if attributes[:'timeDataEnded'] raise 'You cannot provide both :timeDataEnded and :time_data_ended' if attributes.key?(:'timeDataEnded') && attributes.key?(:'time_data_ended') self.time_data_ended = attributes[:'time_data_ended'] if attributes[:'time_data_ended'] self.purge_query_string = attributes[:'purgeQueryString'] if attributes[:'purgeQueryString'] raise 'You cannot provide both :purgeQueryString and :purge_query_string' if attributes.key?(:'purgeQueryString') && attributes.key?(:'purge_query_string') self.purge_query_string = attributes[:'purge_query_string'] if attributes[:'purge_query_string'] self.data_type = attributes[:'dataType'] if attributes[:'dataType'] raise 'You cannot provide both :dataType and :data_type' if attributes.key?(:'dataType') && attributes.key?(:'data_type') self.data_type = attributes[:'data_type'] if attributes[:'data_type'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] This is the compartment OCID under which the data will be purged and required permission will be checked
18 19 20 |
# File 'lib/oci/log_analytics/models/purge_storage_data_details.rb', line 18 def compartment_id @compartment_id end |
#compartment_id_in_subtree ⇒ BOOLEAN
If true, purge child compartments data
22 23 24 |
# File 'lib/oci/log_analytics/models/purge_storage_data_details.rb', line 22 def compartment_id_in_subtree @compartment_id_in_subtree end |
#data_type ⇒ String
This is the type of the log data to be purged
34 35 36 |
# File 'lib/oci/log_analytics/models/purge_storage_data_details.rb', line 34 def data_type @data_type end |
#purge_query_string ⇒ String
This is the solr query used to filter data, ‘*’ means all
30 31 32 |
# File 'lib/oci/log_analytics/models/purge_storage_data_details.rb', line 30 def purge_query_string @purge_query_string end |
#time_data_ended ⇒ DateTime
[Required] This is the end of the purge time interval
26 27 28 |
# File 'lib/oci/log_analytics/models/purge_storage_data_details.rb', line 26 def time_data_ended @time_data_ended end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 47 |
# File 'lib/oci/log_analytics/models/purge_storage_data_details.rb', line 37 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'compartment_id_in_subtree': :'compartmentIdInSubtree', 'time_data_ended': :'timeDataEnded', 'purge_query_string': :'purgeQueryString', 'data_type': :'dataType' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/oci/log_analytics/models/purge_storage_data_details.rb', line 50 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'compartment_id_in_subtree': :'BOOLEAN', 'time_data_ended': :'DateTime', 'purge_query_string': :'String', 'data_type': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
127 128 129 130 131 132 133 134 135 136 |
# File 'lib/oci/log_analytics/models/purge_storage_data_details.rb', line 127 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && compartment_id_in_subtree == other.compartment_id_in_subtree && time_data_ended == other.time_data_ended && purge_query_string == other.purge_query_string && data_type == other.data_type end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/oci/log_analytics/models/purge_storage_data_details.rb', line 161 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
141 142 143 |
# File 'lib/oci/log_analytics/models/purge_storage_data_details.rb', line 141 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
150 151 152 |
# File 'lib/oci/log_analytics/models/purge_storage_data_details.rb', line 150 def hash [compartment_id, compartment_id_in_subtree, time_data_ended, purge_query_string, data_type].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
194 195 196 197 198 199 200 201 202 203 |
# File 'lib/oci/log_analytics/models/purge_storage_data_details.rb', line 194 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
188 189 190 |
# File 'lib/oci/log_analytics/models/purge_storage_data_details.rb', line 188 def to_s to_hash.to_s end |