Class: OCI::LogAnalytics::Models::RecallArchivedDataDetails
- Inherits:
-
Object
- Object
- OCI::LogAnalytics::Models::RecallArchivedDataDetails
- Defined in:
- lib/oci/log_analytics/models/recall_archived_data_details.rb
Overview
This is the input used to recall archived data
Constant Summary collapse
- DATA_TYPE_ENUM =
[ DATA_TYPE_LOG = 'LOG'.freeze, DATA_TYPE_LOOKUP = 'LOOKUP'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] This is the compartment OCID for permission checking.
-
#data_type ⇒ String
This is the type of the log data to be recalled.
-
#time_data_ended ⇒ DateTime
[Required] This is the end of the time interval.
-
#time_data_started ⇒ DateTime
[Required] This is the start of the time interval.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RecallArchivedDataDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ RecallArchivedDataDetails
Initializes the object
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/oci/log_analytics/models/recall_archived_data_details.rb', line 66 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.time_data_ended = attributes[:'timeDataEnded'] if attributes[:'timeDataEnded'] raise 'You cannot provide both :timeDataEnded and :time_data_ended' if attributes.key?(:'timeDataEnded') && attributes.key?(:'time_data_ended') self.time_data_ended = attributes[:'time_data_ended'] if attributes[:'time_data_ended'] self.time_data_started = attributes[:'timeDataStarted'] if attributes[:'timeDataStarted'] raise 'You cannot provide both :timeDataStarted and :time_data_started' if attributes.key?(:'timeDataStarted') && attributes.key?(:'time_data_started') self.time_data_started = attributes[:'time_data_started'] if attributes[:'time_data_started'] self.data_type = attributes[:'dataType'] if attributes[:'dataType'] raise 'You cannot provide both :dataType and :data_type' if attributes.key?(:'dataType') && attributes.key?(:'data_type') self.data_type = attributes[:'data_type'] if attributes[:'data_type'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] This is the compartment OCID for permission checking
18 19 20 |
# File 'lib/oci/log_analytics/models/recall_archived_data_details.rb', line 18 def compartment_id @compartment_id end |
#data_type ⇒ String
This is the type of the log data to be recalled
30 31 32 |
# File 'lib/oci/log_analytics/models/recall_archived_data_details.rb', line 30 def data_type @data_type end |
#time_data_ended ⇒ DateTime
[Required] This is the end of the time interval
22 23 24 |
# File 'lib/oci/log_analytics/models/recall_archived_data_details.rb', line 22 def time_data_ended @time_data_ended end |
#time_data_started ⇒ DateTime
[Required] This is the start of the time interval
26 27 28 |
# File 'lib/oci/log_analytics/models/recall_archived_data_details.rb', line 26 def time_data_started @time_data_started end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 41 42 |
# File 'lib/oci/log_analytics/models/recall_archived_data_details.rb', line 33 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'time_data_ended': :'timeDataEnded', 'time_data_started': :'timeDataStarted', 'data_type': :'dataType' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
45 46 47 48 49 50 51 52 53 54 |
# File 'lib/oci/log_analytics/models/recall_archived_data_details.rb', line 45 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'time_data_ended': :'DateTime', 'time_data_started': :'DateTime', 'data_type': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
112 113 114 115 116 117 118 119 120 |
# File 'lib/oci/log_analytics/models/recall_archived_data_details.rb', line 112 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && time_data_ended == other.time_data_ended && time_data_started == other.time_data_started && data_type == other.data_type end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/oci/log_analytics/models/recall_archived_data_details.rb', line 145 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
125 126 127 |
# File 'lib/oci/log_analytics/models/recall_archived_data_details.rb', line 125 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
134 135 136 |
# File 'lib/oci/log_analytics/models/recall_archived_data_details.rb', line 134 def hash [compartment_id, time_data_ended, time_data_started, data_type].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
178 179 180 181 182 183 184 185 186 187 |
# File 'lib/oci/log_analytics/models/recall_archived_data_details.rb', line 178 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
172 173 174 |
# File 'lib/oci/log_analytics/models/recall_archived_data_details.rb', line 172 def to_s to_hash.to_s end |