Class: OCI::LogAnalytics::Models::RecalledData
- Inherits:
-
Object
- Object
- OCI::LogAnalytics::Models::RecalledData
- Defined in:
- lib/oci/log_analytics/models/recalled_data.rb
Overview
This is the information about recalled data
Constant Summary collapse
- STATUS_ENUM =
[ STATUS_RECALLED = 'RECALLED'.freeze, STATUS_PENDING = 'PENDING'.freeze, STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#recall_count ⇒ Integer
[Required] This is the number of recall operations for this recall.
-
#status ⇒ String
[Required] This is the status of the recall.
-
#storage_usage_in_bytes ⇒ Integer
[Required] This is the size in bytes.
-
#time_data_ended ⇒ DateTime
[Required] This is the end of the time range of the related data.
-
#time_data_started ⇒ DateTime
[Required] This is the start of the time range of the related data.
-
#time_started ⇒ DateTime
[Required] This is the time when the first recall operation was started for this RecalledData.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RecalledData
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ RecalledData
Initializes the object
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/oci/log_analytics/models/recalled_data.rb', line 83 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.time_data_ended = attributes[:'timeDataEnded'] if attributes[:'timeDataEnded'] raise 'You cannot provide both :timeDataEnded and :time_data_ended' if attributes.key?(:'timeDataEnded') && attributes.key?(:'time_data_ended') self.time_data_ended = attributes[:'time_data_ended'] if attributes[:'time_data_ended'] self.time_data_started = attributes[:'timeDataStarted'] if attributes[:'timeDataStarted'] raise 'You cannot provide both :timeDataStarted and :time_data_started' if attributes.key?(:'timeDataStarted') && attributes.key?(:'time_data_started') self.time_data_started = attributes[:'time_data_started'] if attributes[:'time_data_started'] self.time_started = attributes[:'timeStarted'] if attributes[:'timeStarted'] raise 'You cannot provide both :timeStarted and :time_started' if attributes.key?(:'timeStarted') && attributes.key?(:'time_started') self.time_started = attributes[:'time_started'] if attributes[:'time_started'] self.status = attributes[:'status'] if attributes[:'status'] self.recall_count = attributes[:'recallCount'] if attributes[:'recallCount'] raise 'You cannot provide both :recallCount and :recall_count' if attributes.key?(:'recallCount') && attributes.key?(:'recall_count') self.recall_count = attributes[:'recall_count'] if attributes[:'recall_count'] self.storage_usage_in_bytes = attributes[:'storageUsageInBytes'] if attributes[:'storageUsageInBytes'] raise 'You cannot provide both :storageUsageInBytes and :storage_usage_in_bytes' if attributes.key?(:'storageUsageInBytes') && attributes.key?(:'storage_usage_in_bytes') self.storage_usage_in_bytes = attributes[:'storage_usage_in_bytes'] if attributes[:'storage_usage_in_bytes'] end |
Instance Attribute Details
#recall_count ⇒ Integer
[Required] This is the number of recall operations for this recall. Note one RecalledData can be merged from the results of several recall operations if the time duration of the results of the recall operations overlap.
37 38 39 |
# File 'lib/oci/log_analytics/models/recalled_data.rb', line 37 def recall_count @recall_count end |
#status ⇒ String
[Required] This is the status of the recall
31 32 33 |
# File 'lib/oci/log_analytics/models/recalled_data.rb', line 31 def status @status end |
#storage_usage_in_bytes ⇒ Integer
[Required] This is the size in bytes
41 42 43 |
# File 'lib/oci/log_analytics/models/recalled_data.rb', line 41 def storage_usage_in_bytes @storage_usage_in_bytes end |
#time_data_ended ⇒ DateTime
[Required] This is the end of the time range of the related data
19 20 21 |
# File 'lib/oci/log_analytics/models/recalled_data.rb', line 19 def time_data_ended @time_data_ended end |
#time_data_started ⇒ DateTime
[Required] This is the start of the time range of the related data
23 24 25 |
# File 'lib/oci/log_analytics/models/recalled_data.rb', line 23 def time_data_started @time_data_started end |
#time_started ⇒ DateTime
[Required] This is the time when the first recall operation was started for this RecalledData
27 28 29 |
# File 'lib/oci/log_analytics/models/recalled_data.rb', line 27 def time_started @time_started end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/oci/log_analytics/models/recalled_data.rb', line 44 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'time_data_ended': :'timeDataEnded', 'time_data_started': :'timeDataStarted', 'time_started': :'timeStarted', 'status': :'status', 'recall_count': :'recallCount', 'storage_usage_in_bytes': :'storageUsageInBytes' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/oci/log_analytics/models/recalled_data.rb', line 58 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'time_data_ended': :'DateTime', 'time_data_started': :'DateTime', 'time_started': :'DateTime', 'status': :'String', 'recall_count': :'Integer', 'storage_usage_in_bytes': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/oci/log_analytics/models/recalled_data.rb', line 142 def ==(other) return true if equal?(other) self.class == other.class && time_data_ended == other.time_data_ended && time_data_started == other.time_data_started && time_started == other.time_started && status == other.status && recall_count == other.recall_count && storage_usage_in_bytes == other.storage_usage_in_bytes end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/oci/log_analytics/models/recalled_data.rb', line 177 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
157 158 159 |
# File 'lib/oci/log_analytics/models/recalled_data.rb', line 157 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
166 167 168 |
# File 'lib/oci/log_analytics/models/recalled_data.rb', line 166 def hash [time_data_ended, time_data_started, time_started, status, recall_count, storage_usage_in_bytes].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
210 211 212 213 214 215 216 217 218 219 |
# File 'lib/oci/log_analytics/models/recalled_data.rb', line 210 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
204 205 206 |
# File 'lib/oci/log_analytics/models/recalled_data.rb', line 204 def to_s to_hash.to_s end |