Class: OCI::LogAnalytics::Models::Schedule

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/log_analytics/models/schedule.rb

Overview

Schedule for scheduled task. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class

Direct Known Subclasses

CronSchedule, FixedFrequencySchedule

Constant Summary collapse

TYPE_ENUM =
[
  TYPE_FIXED_FREQUENCY = 'FIXED_FREQUENCY'.freeze,
  TYPE_CRON = 'CRON'.freeze,
  TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
MISFIRE_POLICY_ENUM =
[
  MISFIRE_POLICY_RETRY_ONCE = 'RETRY_ONCE'.freeze,
  MISFIRE_POLICY_RETRY_INDEFINITELY = 'RETRY_INDEFINITELY'.freeze,
  MISFIRE_POLICY_SKIP = 'SKIP'.freeze,
  MISFIRE_POLICY_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Schedule

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :type (String)

    The value to assign to the #type property

  • :misfire_policy (String)

    The value to assign to the #misfire_policy property



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/oci/log_analytics/models/schedule.rb', line 77

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.type = attributes[:'type'] if attributes[:'type']

  self.misfire_policy = attributes[:'misfirePolicy'] if attributes[:'misfirePolicy']
  self.misfire_policy = "RETRY_INDEFINITELY" if misfire_policy.nil? && !attributes.key?(:'misfirePolicy') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :misfirePolicy and :misfire_policy' if attributes.key?(:'misfirePolicy') && attributes.key?(:'misfire_policy')

  self.misfire_policy = attributes[:'misfire_policy'] if attributes[:'misfire_policy']
  self.misfire_policy = "RETRY_INDEFINITELY" if misfire_policy.nil? && !attributes.key?(:'misfirePolicy') && !attributes.key?(:'misfire_policy') # rubocop:disable Style/StringLiterals
end

Instance Attribute Details

#misfire_policyString

Schedule misfire retry policy.

Returns:

  • (String)


31
32
33
# File 'lib/oci/log_analytics/models/schedule.rb', line 31

def misfire_policy
  @misfire_policy
end

#typeString

[Required] Schedule type discriminator.

Returns:

  • (String)


27
28
29
# File 'lib/oci/log_analytics/models/schedule.rb', line 27

def type
  @type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
# File 'lib/oci/log_analytics/models/schedule.rb', line 34

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'type': :'type',
    'misfire_policy': :'misfirePolicy'
    # rubocop:enable Style/SymbolLiteral
  }
end

.get_subtype(object_hash) ⇒ Object

Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.



58
59
60
61
62
63
64
65
66
# File 'lib/oci/log_analytics/models/schedule.rb', line 58

def self.get_subtype(object_hash)
  type = object_hash[:'type'] # rubocop:disable Style/SymbolLiteral

  return 'OCI::LogAnalytics::Models::CronSchedule' if type == 'CRON'
  return 'OCI::LogAnalytics::Models::FixedFrequencySchedule' if type == 'FIXED_FREQUENCY'

  # TODO: Log a warning when the subtype is not found.
  'OCI::LogAnalytics::Models::Schedule'
end

.swagger_typesObject

Attribute type mapping.



44
45
46
47
48
49
50
51
# File 'lib/oci/log_analytics/models/schedule.rb', line 44

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'type': :'String',
    'misfire_policy': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



127
128
129
130
131
132
133
# File 'lib/oci/log_analytics/models/schedule.rb', line 127

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    type == other.type &&
    misfire_policy == other.misfire_policy
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/oci/log_analytics/models/schedule.rb', line 158

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


138
139
140
# File 'lib/oci/log_analytics/models/schedule.rb', line 138

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



147
148
149
# File 'lib/oci/log_analytics/models/schedule.rb', line 147

def hash
  [type, misfire_policy].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



191
192
193
194
195
196
197
198
199
200
# File 'lib/oci/log_analytics/models/schedule.rb', line 191

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



185
186
187
# File 'lib/oci/log_analytics/models/schedule.rb', line 185

def to_s
  to_hash.to_s
end