Class: OCI::LogAnalytics::Models::ScheduledTask

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/log_analytics/models/scheduled_task.rb

Overview

Log analytics scheduled task resource.

This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class

Direct Known Subclasses

StandardTask

Constant Summary collapse

KIND_ENUM =
[
  KIND_ACCELERATION = 'ACCELERATION'.freeze,
  KIND_STANDARD = 'STANDARD'.freeze,
  KIND_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
TASK_TYPE_ENUM =
[
  TASK_TYPE_SAVED_SEARCH = 'SAVED_SEARCH'.freeze,
  TASK_TYPE_ACCELERATION = 'ACCELERATION'.freeze,
  TASK_TYPE_PURGE = 'PURGE'.freeze,
  TASK_TYPE_ACCELERATION_MAINTENANCE = 'ACCELERATION_MAINTENANCE'.freeze,
  TASK_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
TASK_STATUS_ENUM =
[
  TASK_STATUS_READY = 'READY'.freeze,
  TASK_STATUS_PAUSED = 'PAUSED'.freeze,
  TASK_STATUS_COMPLETED = 'COMPLETED'.freeze,
  TASK_STATUS_BLOCKED = 'BLOCKED'.freeze,
  TASK_STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ScheduledTask

Initializes the object

Options Hash (attributes):

  • :kind (String)

    The value to assign to the #kind property

  • :id (String)

    The value to assign to the #id property

  • :display_name (String)

    The value to assign to the #display_name property

  • :task_type (String)

    The value to assign to the #task_type property

  • :schedules (Array<OCI::LogAnalytics::Models::Schedule>)

    The value to assign to the #schedules property

  • :action (OCI::LogAnalytics::Models::Action)

    The value to assign to the #action property

  • :task_status (String)

    The value to assign to the #task_status property

  • :work_request_id (String)

    The value to assign to the #work_request_id property

  • :num_occurrences (Integer)

    The value to assign to the #num_occurrences property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :time_updated (DateTime)

    The value to assign to the #time_updated property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property



194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'lib/oci/log_analytics/models/scheduled_task.rb', line 194

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.kind = attributes[:'kind'] if attributes[:'kind']

  self.id = attributes[:'id'] if attributes[:'id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.task_type = attributes[:'taskType'] if attributes[:'taskType']

  raise 'You cannot provide both :taskType and :task_type' if attributes.key?(:'taskType') && attributes.key?(:'task_type')

  self.task_type = attributes[:'task_type'] if attributes[:'task_type']

  self.schedules = attributes[:'schedules'] if attributes[:'schedules']

  self.action = attributes[:'action'] if attributes[:'action']

  self.task_status = attributes[:'taskStatus'] if attributes[:'taskStatus']

  raise 'You cannot provide both :taskStatus and :task_status' if attributes.key?(:'taskStatus') && attributes.key?(:'task_status')

  self.task_status = attributes[:'task_status'] if attributes[:'task_status']

  self.work_request_id = attributes[:'workRequestId'] if attributes[:'workRequestId']

  raise 'You cannot provide both :workRequestId and :work_request_id' if attributes.key?(:'workRequestId') && attributes.key?(:'work_request_id')

  self.work_request_id = attributes[:'work_request_id'] if attributes[:'work_request_id']

  self.num_occurrences = attributes[:'numOccurrences'] if attributes[:'numOccurrences']

  raise 'You cannot provide both :numOccurrences and :num_occurrences' if attributes.key?(:'numOccurrences') && attributes.key?(:'num_occurrences')

  self.num_occurrences = attributes[:'num_occurrences'] if attributes[:'num_occurrences']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#actionOCI::LogAnalytics::Models::Action

This attribute is required.



68
69
70
# File 'lib/oci/log_analytics/models/scheduled_task.rb', line 68

def action
  @action
end

#compartment_idString

[Required] Compartment Identifier [OCID] (docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).



84
85
86
# File 'lib/oci/log_analytics/models/scheduled_task.rb', line 84

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`



110
111
112
# File 'lib/oci/log_analytics/models/scheduled_task.rb', line 110

def defined_tags
  @defined_tags
end

#display_nameString

[Required] A user-friendly name that is changeable and that does not have to be unique. Format: a leading alphanumeric, followed by zero or more alphanumerics, underscores, spaces, backslashes, or hyphens in any order). No trailing spaces allowed.



56
57
58
# File 'lib/oci/log_analytics/models/scheduled_task.rb', line 56

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`



104
105
106
# File 'lib/oci/log_analytics/models/scheduled_task.rb', line 104

def freeform_tags
  @freeform_tags
end

#idString

[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the data plane resource.



48
49
50
# File 'lib/oci/log_analytics/models/scheduled_task.rb', line 48

def id
  @id
end

#kindString

[Required] Discriminator.



43
44
45
# File 'lib/oci/log_analytics/models/scheduled_task.rb', line 43

def kind
  @kind
end

#lifecycle_stateString

[Required] The current state of the scheduled task.



98
99
100
# File 'lib/oci/log_analytics/models/scheduled_task.rb', line 98

def lifecycle_state
  @lifecycle_state
end

#num_occurrencesInteger

Number of execution occurrences.



80
81
82
# File 'lib/oci/log_analytics/models/scheduled_task.rb', line 80

def num_occurrences
  @num_occurrences
end

#schedulesArray<OCI::LogAnalytics::Models::Schedule>

[Required] Schedules.



64
65
66
# File 'lib/oci/log_analytics/models/scheduled_task.rb', line 64

def schedules
  @schedules
end

#task_statusString

Status of the scheduled task.



72
73
74
# File 'lib/oci/log_analytics/models/scheduled_task.rb', line 72

def task_status
  @task_status
end

#task_typeString

[Required] Task type.



60
61
62
# File 'lib/oci/log_analytics/models/scheduled_task.rb', line 60

def task_type
  @task_type
end

#time_createdDateTime

[Required] The date and time the scheduled task was created, in the format defined by RFC3339.



89
90
91
# File 'lib/oci/log_analytics/models/scheduled_task.rb', line 89

def time_created
  @time_created
end

#time_updatedDateTime

[Required] The date and time the scheduled task was last updated, in the format defined by RFC3339.



94
95
96
# File 'lib/oci/log_analytics/models/scheduled_task.rb', line 94

def time_updated
  @time_updated
end

#work_request_idString

most recent Work Request Identifier [OCID] (docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) for the asynchronous request.



76
77
78
# File 'lib/oci/log_analytics/models/scheduled_task.rb', line 76

def work_request_id
  @work_request_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/oci/log_analytics/models/scheduled_task.rb', line 113

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'kind': :'kind',
    'id': :'id',
    'display_name': :'displayName',
    'task_type': :'taskType',
    'schedules': :'schedules',
    'action': :'action',
    'task_status': :'taskStatus',
    'work_request_id': :'workRequestId',
    'num_occurrences': :'numOccurrences',
    'compartment_id': :'compartmentId',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'lifecycle_state': :'lifecycleState',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.get_subtype(object_hash) ⇒ Object

Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.



163
164
165
166
167
168
169
170
# File 'lib/oci/log_analytics/models/scheduled_task.rb', line 163

def self.get_subtype(object_hash)
  type = object_hash[:'kind'] # rubocop:disable Style/SymbolLiteral

  return 'OCI::LogAnalytics::Models::StandardTask' if type == 'STANDARD'

  # TODO: Log a warning when the subtype is not found.
  'OCI::LogAnalytics::Models::ScheduledTask'
end

.swagger_typesObject

Attribute type mapping.



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/oci/log_analytics/models/scheduled_task.rb', line 136

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'kind': :'String',
    'id': :'String',
    'display_name': :'String',
    'task_type': :'String',
    'schedules': :'Array<OCI::LogAnalytics::Models::Schedule>',
    'action': :'OCI::LogAnalytics::Models::Action',
    'task_status': :'String',
    'work_request_id': :'String',
    'num_occurrences': :'Integer',
    'compartment_id': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'lifecycle_state': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.



334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
# File 'lib/oci/log_analytics/models/scheduled_task.rb', line 334

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    kind == other.kind &&
    id == other.id &&
    display_name == other.display_name &&
    task_type == other.task_type &&
    schedules == other.schedules &&
    action == other.action &&
    task_status == other.task_status &&
    work_request_id == other.work_request_id &&
    num_occurrences == other.num_occurrences &&
    compartment_id == other.compartment_id &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    lifecycle_state == other.lifecycle_state &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
# File 'lib/oci/log_analytics/models/scheduled_task.rb', line 378

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method


358
359
360
# File 'lib/oci/log_analytics/models/scheduled_task.rb', line 358

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.



367
368
369
# File 'lib/oci/log_analytics/models/scheduled_task.rb', line 367

def hash
  [kind, id, display_name, task_type, schedules, action, task_status, work_request_id, num_occurrences, compartment_id, time_created, time_updated, lifecycle_state, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash



411
412
413
414
415
416
417
418
419
420
# File 'lib/oci/log_analytics/models/scheduled_task.rb', line 411

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



405
406
407
# File 'lib/oci/log_analytics/models/scheduled_task.rb', line 405

def to_s
  to_hash.to_s
end