Class: OCI::LogAnalytics::Models::SearchCommandDescriptor
- Inherits:
-
AbstractCommandDescriptor
- Object
- AbstractCommandDescriptor
- OCI::LogAnalytics::Models::SearchCommandDescriptor
- Defined in:
- lib/oci/log_analytics/models/search_command_descriptor.rb
Overview
Command descriptor for querylanguage SEARCH command.
Constant Summary
Constants inherited from AbstractCommandDescriptor
AbstractCommandDescriptor::NAME_ENUM
Instance Attribute Summary collapse
-
#sub_queries ⇒ Array<OCI::LogAnalytics::Models::ParseQueryOutput>
List of sub-queries present in search command if specified.
Attributes inherited from AbstractCommandDescriptor
#category, #declared_fields, #display_query_string, #internal_query_string, #name, #referenced_fields
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SearchCommandDescriptor
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from AbstractCommandDescriptor
Constructor Details
#initialize(attributes = {}) ⇒ SearchCommandDescriptor
Initializes the object
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/oci/log_analytics/models/search_command_descriptor.rb', line 59 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['name'] = 'SEARCH' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.sub_queries = attributes[:'subQueries'] if attributes[:'subQueries'] raise 'You cannot provide both :subQueries and :sub_queries' if attributes.key?(:'subQueries') && attributes.key?(:'sub_queries') self.sub_queries = attributes[:'sub_queries'] if attributes[:'sub_queries'] end |
Instance Attribute Details
#sub_queries ⇒ Array<OCI::LogAnalytics::Models::ParseQueryOutput>
List of sub-queries present in search command if specified.
15 16 17 |
# File 'lib/oci/log_analytics/models/search_command_descriptor.rb', line 15 def sub_queries @sub_queries end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
18 19 20 21 22 23 24 25 26 27 28 29 30 |
# File 'lib/oci/log_analytics/models/search_command_descriptor.rb', line 18 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'display_query_string': :'displayQueryString', 'internal_query_string': :'internalQueryString', 'category': :'category', 'referenced_fields': :'referencedFields', 'declared_fields': :'declaredFields', 'sub_queries': :'subQueries' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
33 34 35 36 37 38 39 40 41 42 43 44 45 |
# File 'lib/oci/log_analytics/models/search_command_descriptor.rb', line 33 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'display_query_string': :'String', 'internal_query_string': :'String', 'category': :'String', 'referenced_fields': :'Array<OCI::LogAnalytics::Models::AbstractField>', 'declared_fields': :'Array<OCI::LogAnalytics::Models::AbstractField>', 'sub_queries': :'Array<OCI::LogAnalytics::Models::ParseQueryOutput>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/oci/log_analytics/models/search_command_descriptor.rb', line 83 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && display_query_string == other.display_query_string && internal_query_string == other.internal_query_string && category == other.category && referenced_fields == other.referenced_fields && declared_fields == other.declared_fields && sub_queries == other.sub_queries end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/oci/log_analytics/models/search_command_descriptor.rb', line 119 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
99 100 101 |
# File 'lib/oci/log_analytics/models/search_command_descriptor.rb', line 99 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
108 109 110 |
# File 'lib/oci/log_analytics/models/search_command_descriptor.rb', line 108 def hash [name, display_query_string, internal_query_string, category, referenced_fields, declared_fields, sub_queries].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
152 153 154 155 156 157 158 159 160 161 |
# File 'lib/oci/log_analytics/models/search_command_descriptor.rb', line 152 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
146 147 148 |
# File 'lib/oci/log_analytics/models/search_command_descriptor.rb', line 146 def to_s to_hash.to_s end |