Class: OCI::LogAnalytics::Models::StatusSummary
- Inherits:
-
Object
- Object
- OCI::LogAnalytics::Models::StatusSummary
- Defined in:
- lib/oci/log_analytics/models/status_summary.rb
Overview
StatusSummary
Instance Attribute Summary collapse
-
#chunks_processed ⇒ Integer
The number of chunks processed.
-
#failure_details ⇒ String
The failure details, if any.
-
#filename ⇒ String
The filename.
-
#status ⇒ String
The status.
-
#total_chunks ⇒ Integer
The total number of chunks.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ StatusSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ StatusSummary
Initializes the object
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/oci/log_analytics/models/status_summary.rb', line 67 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.chunks_processed = attributes[:'chunksProcessed'] if attributes[:'chunksProcessed'] raise 'You cannot provide both :chunksProcessed and :chunks_processed' if attributes.key?(:'chunksProcessed') && attributes.key?(:'chunks_processed') self.chunks_processed = attributes[:'chunks_processed'] if attributes[:'chunks_processed'] self.failure_details = attributes[:'failureDetails'] if attributes[:'failureDetails'] raise 'You cannot provide both :failureDetails and :failure_details' if attributes.key?(:'failureDetails') && attributes.key?(:'failure_details') self.failure_details = attributes[:'failure_details'] if attributes[:'failure_details'] self.filename = attributes[:'filename'] if attributes[:'filename'] self.status = attributes[:'status'] if attributes[:'status'] self.total_chunks = attributes[:'totalChunks'] if attributes[:'totalChunks'] raise 'You cannot provide both :totalChunks and :total_chunks' if attributes.key?(:'totalChunks') && attributes.key?(:'total_chunks') self.total_chunks = attributes[:'total_chunks'] if attributes[:'total_chunks'] end |
Instance Attribute Details
#chunks_processed ⇒ Integer
The number of chunks processed.
12 13 14 |
# File 'lib/oci/log_analytics/models/status_summary.rb', line 12 def chunks_processed @chunks_processed end |
#failure_details ⇒ String
The failure details, if any.
16 17 18 |
# File 'lib/oci/log_analytics/models/status_summary.rb', line 16 def failure_details @failure_details end |
#filename ⇒ String
The filename.
20 21 22 |
# File 'lib/oci/log_analytics/models/status_summary.rb', line 20 def filename @filename end |
#status ⇒ String
The status.
24 25 26 |
# File 'lib/oci/log_analytics/models/status_summary.rb', line 24 def status @status end |
#total_chunks ⇒ Integer
The total number of chunks.
28 29 30 |
# File 'lib/oci/log_analytics/models/status_summary.rb', line 28 def total_chunks @total_chunks end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 40 41 |
# File 'lib/oci/log_analytics/models/status_summary.rb', line 31 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'chunks_processed': :'chunksProcessed', 'failure_details': :'failureDetails', 'filename': :'filename', 'status': :'status', 'total_chunks': :'totalChunks' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/oci/log_analytics/models/status_summary.rb', line 44 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'chunks_processed': :'Integer', 'failure_details': :'String', 'filename': :'String', 'status': :'String', 'total_chunks': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
103 104 105 106 107 108 109 110 111 112 |
# File 'lib/oci/log_analytics/models/status_summary.rb', line 103 def ==(other) return true if equal?(other) self.class == other.class && chunks_processed == other.chunks_processed && failure_details == other.failure_details && filename == other.filename && status == other.status && total_chunks == other.total_chunks end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/oci/log_analytics/models/status_summary.rb', line 137 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
117 118 119 |
# File 'lib/oci/log_analytics/models/status_summary.rb', line 117 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
126 127 128 |
# File 'lib/oci/log_analytics/models/status_summary.rb', line 126 def hash [chunks_processed, failure_details, filename, status, total_chunks].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
170 171 172 173 174 175 176 177 178 179 |
# File 'lib/oci/log_analytics/models/status_summary.rb', line 170 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
164 165 166 |
# File 'lib/oci/log_analytics/models/status_summary.rb', line 164 def to_s to_hash.to_s end |