Class: OCI::LogAnalytics::Models::StorageUsage
- Inherits:
-
Object
- Object
- OCI::LogAnalytics::Models::StorageUsage
- Defined in:
- lib/oci/log_analytics/models/storage_usage.rb
Overview
This is the storage usage information of a tenancy in Logan Analytics application
Instance Attribute Summary collapse
-
#active_data_size_in_bytes ⇒ Integer
[Required] This is the number of bytes of active data (non-archived).
-
#archived_data_size_in_bytes ⇒ Integer
[Required] This is the number of bytes of archived data in object storage.
-
#recalled_archived_data_size_in_bytes ⇒ Integer
[Required] This is the number of bytes of recalled data from archived in object store.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ StorageUsage
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ StorageUsage
Initializes the object
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/oci/log_analytics/models/storage_usage.rb', line 53 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.active_data_size_in_bytes = attributes[:'activeDataSizeInBytes'] if attributes[:'activeDataSizeInBytes'] raise 'You cannot provide both :activeDataSizeInBytes and :active_data_size_in_bytes' if attributes.key?(:'activeDataSizeInBytes') && attributes.key?(:'active_data_size_in_bytes') self.active_data_size_in_bytes = attributes[:'active_data_size_in_bytes'] if attributes[:'active_data_size_in_bytes'] self.archived_data_size_in_bytes = attributes[:'archivedDataSizeInBytes'] if attributes[:'archivedDataSizeInBytes'] raise 'You cannot provide both :archivedDataSizeInBytes and :archived_data_size_in_bytes' if attributes.key?(:'archivedDataSizeInBytes') && attributes.key?(:'archived_data_size_in_bytes') self.archived_data_size_in_bytes = attributes[:'archived_data_size_in_bytes'] if attributes[:'archived_data_size_in_bytes'] self.recalled_archived_data_size_in_bytes = attributes[:'recalledArchivedDataSizeInBytes'] if attributes[:'recalledArchivedDataSizeInBytes'] raise 'You cannot provide both :recalledArchivedDataSizeInBytes and :recalled_archived_data_size_in_bytes' if attributes.key?(:'recalledArchivedDataSizeInBytes') && attributes.key?(:'recalled_archived_data_size_in_bytes') self.recalled_archived_data_size_in_bytes = attributes[:'recalled_archived_data_size_in_bytes'] if attributes[:'recalled_archived_data_size_in_bytes'] end |
Instance Attribute Details
#active_data_size_in_bytes ⇒ Integer
[Required] This is the number of bytes of active data (non-archived)
12 13 14 |
# File 'lib/oci/log_analytics/models/storage_usage.rb', line 12 def active_data_size_in_bytes @active_data_size_in_bytes end |
#archived_data_size_in_bytes ⇒ Integer
[Required] This is the number of bytes of archived data in object storage
16 17 18 |
# File 'lib/oci/log_analytics/models/storage_usage.rb', line 16 def archived_data_size_in_bytes @archived_data_size_in_bytes end |
#recalled_archived_data_size_in_bytes ⇒ Integer
[Required] This is the number of bytes of recalled data from archived in object store
20 21 22 |
# File 'lib/oci/log_analytics/models/storage_usage.rb', line 20 def recalled_archived_data_size_in_bytes @recalled_archived_data_size_in_bytes end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
23 24 25 26 27 28 29 30 31 |
# File 'lib/oci/log_analytics/models/storage_usage.rb', line 23 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'active_data_size_in_bytes': :'activeDataSizeInBytes', 'archived_data_size_in_bytes': :'archivedDataSizeInBytes', 'recalled_archived_data_size_in_bytes': :'recalledArchivedDataSizeInBytes' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
34 35 36 37 38 39 40 41 42 |
# File 'lib/oci/log_analytics/models/storage_usage.rb', line 34 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'active_data_size_in_bytes': :'Integer', 'archived_data_size_in_bytes': :'Integer', 'recalled_archived_data_size_in_bytes': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
85 86 87 88 89 90 91 92 |
# File 'lib/oci/log_analytics/models/storage_usage.rb', line 85 def ==(other) return true if equal?(other) self.class == other.class && active_data_size_in_bytes == other.active_data_size_in_bytes && archived_data_size_in_bytes == other.archived_data_size_in_bytes && recalled_archived_data_size_in_bytes == other.recalled_archived_data_size_in_bytes end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/oci/log_analytics/models/storage_usage.rb', line 117 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
97 98 99 |
# File 'lib/oci/log_analytics/models/storage_usage.rb', line 97 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
106 107 108 |
# File 'lib/oci/log_analytics/models/storage_usage.rb', line 106 def hash [active_data_size_in_bytes, archived_data_size_in_bytes, recalled_archived_data_size_in_bytes].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
150 151 152 153 154 155 156 157 158 159 |
# File 'lib/oci/log_analytics/models/storage_usage.rb', line 150 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
144 145 146 |
# File 'lib/oci/log_analytics/models/storage_usage.rb', line 144 def to_s to_hash.to_s end |