Class: OCI::LogAnalytics::Models::StreamAction

Inherits:
Action
  • Object
show all
Defined in:
lib/oci/log_analytics/models/stream_action.rb

Overview

Stream action for scheduled task.

Constant Summary

Constants inherited from Action

Action::TYPE_ENUM

Instance Attribute Summary collapse

Attributes inherited from Action

#type

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Action

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ StreamAction

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/oci/log_analytics/models/stream_action.rb', line 77

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['type'] = 'STREAM'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.saved_search_id = attributes[:'savedSearchId'] if attributes[:'savedSearchId']

  raise 'You cannot provide both :savedSearchId and :saved_search_id' if attributes.key?(:'savedSearchId') && attributes.key?(:'saved_search_id')

  self.saved_search_id = attributes[:'saved_search_id'] if attributes[:'saved_search_id']

  self.metric_extraction = attributes[:'metricExtraction'] if attributes[:'metricExtraction']

  raise 'You cannot provide both :metricExtraction and :metric_extraction' if attributes.key?(:'metricExtraction') && attributes.key?(:'metric_extraction')

  self.metric_extraction = attributes[:'metric_extraction'] if attributes[:'metric_extraction']

  self.saved_search_duration = attributes[:'savedSearchDuration'] if attributes[:'savedSearchDuration']

  raise 'You cannot provide both :savedSearchDuration and :saved_search_duration' if attributes.key?(:'savedSearchDuration') && attributes.key?(:'saved_search_duration')

  self.saved_search_duration = attributes[:'saved_search_duration'] if attributes[:'saved_search_duration']
end

Instance Attribute Details

#metric_extractionOCI::LogAnalytics::Models::MetricExtraction



16
17
18
# File 'lib/oci/log_analytics/models/stream_action.rb', line 16

def metric_extraction
  @metric_extraction
end

#saved_search_durationString

The duration of data to be searched for SAVED_SEARCH tasks, used when the task fires to calculate the query time range.

Duration in ISO 8601 extended format as described in en.wikipedia.org/wiki/ISO_8601#Durations. The value should be positive. The largest supported unit (as opposed to value) is D, e.g. P14D (not P2W).

There are restrictions on the maximum duration value relative to the task schedule value as specified in the following table.

Schedule Interval Range          | Maximum Duration

———————————– | —————–

 5 Minutes     to 30 Minutes       |   1 hour  \"PT60M\"
31 Minutes     to  1 Hour          |  12 hours \"PT720M\"
1 Hour+1Minute to  1 Day           |   1 day   \"P1D\"
1 Day+1Minute  to  1 Week-1Minute  |   7 days  \"P7D\"
1 Week         to  2 Weeks         |  14 days  \"P14D\"
greater than 2 Weeks               |  30 days  \"P30D\"

If not specified, the duration will be based on the schedule. For example, if the schedule is every 5 minutes then the savedSearchDuration will be "PT5M"; if the schedule is every 3 weeks then the savedSearchDuration will be "P21D".

Returns:

  • (String)


42
43
44
# File 'lib/oci/log_analytics/models/stream_action.rb', line 42

def saved_search_duration
  @saved_search_duration
end

#saved_search_idString

The ManagementSavedSearch id [OCID] utilized in the action.

Returns:

  • (String)


13
14
15
# File 'lib/oci/log_analytics/models/stream_action.rb', line 13

def saved_search_id
  @saved_search_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



45
46
47
48
49
50
51
52
53
54
# File 'lib/oci/log_analytics/models/stream_action.rb', line 45

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'type': :'type',
    'saved_search_id': :'savedSearchId',
    'metric_extraction': :'metricExtraction',
    'saved_search_duration': :'savedSearchDuration'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



57
58
59
60
61
62
63
64
65
66
# File 'lib/oci/log_analytics/models/stream_action.rb', line 57

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'type': :'String',
    'saved_search_id': :'String',
    'metric_extraction': :'OCI::LogAnalytics::Models::MetricExtraction',
    'saved_search_duration': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



113
114
115
116
117
118
119
120
121
# File 'lib/oci/log_analytics/models/stream_action.rb', line 113

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    type == other.type &&
    saved_search_id == other.saved_search_id &&
    metric_extraction == other.metric_extraction &&
    saved_search_duration == other.saved_search_duration
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
# File 'lib/oci/log_analytics/models/stream_action.rb', line 146

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


126
127
128
# File 'lib/oci/log_analytics/models/stream_action.rb', line 126

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



135
136
137
# File 'lib/oci/log_analytics/models/stream_action.rb', line 135

def hash
  [type, saved_search_id, metric_extraction, saved_search_duration].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



179
180
181
182
183
184
185
186
187
188
# File 'lib/oci/log_analytics/models/stream_action.rb', line 179

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



173
174
175
# File 'lib/oci/log_analytics/models/stream_action.rb', line 173

def to_s
  to_hash.to_s
end