Class: OCI::LogAnalytics::Models::SuggestOutput
- Inherits:
-
Object
- Object
- OCI::LogAnalytics::Models::SuggestOutput
- Defined in:
- lib/oci/log_analytics/models/suggest_output.rb
Overview
Typeahead results
Instance Attribute Summary collapse
-
#commands ⇒ Array<String>
Context specific list of querylanguage commands if input is seeking command suggestions.
-
#examples ⇒ Array<String>
Context specific list of querylanguage querystring examples if input is seeking queryString example suggestions.
-
#field_values ⇒ Array<String>
Context specific list of field values if input is seeking field value suggestions.
-
#fields ⇒ Array<String>
Context specific list of querylanguage fields / columns if input is seeking field / column suggestions.
-
#options ⇒ Array<String>
Context specific list of querylanguage command options if input is seeking command option suggestions.
-
#position ⇒ Integer
[Required] Character position suggestion should be placed in queryString provided as input.
-
#terms ⇒ Array<String>
Context specific list of terms / phrases if input is seeking terms / phrase suggestions.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SuggestOutput
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ SuggestOutput
Initializes the object
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/oci/log_analytics/models/suggest_output.rb', line 89 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.position = attributes[:'position'] if attributes[:'position'] self.commands = attributes[:'commands'] if attributes[:'commands'] self.fields = attributes[:'fields'] if attributes[:'fields'] self.field_values = attributes[:'fieldValues'] if attributes[:'fieldValues'] raise 'You cannot provide both :fieldValues and :field_values' if attributes.key?(:'fieldValues') && attributes.key?(:'field_values') self.field_values = attributes[:'field_values'] if attributes[:'field_values'] self.terms = attributes[:'terms'] if attributes[:'terms'] self. = attributes[:'options'] if attributes[:'options'] self.examples = attributes[:'examples'] if attributes[:'examples'] end |
Instance Attribute Details
#commands ⇒ Array<String>
Context specific list of querylanguage commands if input is seeking command suggestions.
19 20 21 |
# File 'lib/oci/log_analytics/models/suggest_output.rb', line 19 def commands @commands end |
#examples ⇒ Array<String>
Context specific list of querylanguage querystring examples if input is seeking queryString example suggestions.
44 45 46 |
# File 'lib/oci/log_analytics/models/suggest_output.rb', line 44 def examples @examples end |
#field_values ⇒ Array<String>
Context specific list of field values if input is seeking field value suggestions.
29 30 31 |
# File 'lib/oci/log_analytics/models/suggest_output.rb', line 29 def field_values @field_values end |
#fields ⇒ Array<String>
Context specific list of querylanguage fields / columns if input is seeking field / column suggestions.
24 25 26 |
# File 'lib/oci/log_analytics/models/suggest_output.rb', line 24 def fields @fields end |
#options ⇒ Array<String>
Context specific list of querylanguage command options if input is seeking command option suggestions.
39 40 41 |
# File 'lib/oci/log_analytics/models/suggest_output.rb', line 39 def end |
#position ⇒ Integer
[Required] Character position suggestion should be placed in queryString provided as input.
14 15 16 |
# File 'lib/oci/log_analytics/models/suggest_output.rb', line 14 def position @position end |
#terms ⇒ Array<String>
Context specific list of terms / phrases if input is seeking terms / phrase suggestions.
34 35 36 |
# File 'lib/oci/log_analytics/models/suggest_output.rb', line 34 def terms @terms end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/oci/log_analytics/models/suggest_output.rb', line 47 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'position': :'position', 'commands': :'commands', 'fields': :'fields', 'field_values': :'fieldValues', 'terms': :'terms', 'options': :'options', 'examples': :'examples' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/oci/log_analytics/models/suggest_output.rb', line 62 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'position': :'Integer', 'commands': :'Array<String>', 'fields': :'Array<String>', 'field_values': :'Array<String>', 'terms': :'Array<String>', 'options': :'Array<String>', 'examples': :'Array<String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/oci/log_analytics/models/suggest_output.rb', line 121 def ==(other) return true if equal?(other) self.class == other.class && position == other.position && commands == other.commands && fields == other.fields && field_values == other.field_values && terms == other.terms && == other. && examples == other.examples end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/oci/log_analytics/models/suggest_output.rb', line 157 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
137 138 139 |
# File 'lib/oci/log_analytics/models/suggest_output.rb', line 137 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
146 147 148 |
# File 'lib/oci/log_analytics/models/suggest_output.rb', line 146 def hash [position, commands, fields, field_values, terms, , examples].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
190 191 192 193 194 195 196 197 198 199 |
# File 'lib/oci/log_analytics/models/suggest_output.rb', line 190 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
184 185 186 |
# File 'lib/oci/log_analytics/models/suggest_output.rb', line 184 def to_s to_hash.to_s end |