Class: OCI::LogAnalytics::Models::TimeRange
- Inherits:
-
Object
- Object
- OCI::LogAnalytics::Models::TimeRange
- Defined in:
- lib/oci/log_analytics/models/time_range.rb
Overview
Specify time range. This paramter can be overwritten if time criteria is specified in the query string. If no time criteria are found in query string this time range is used.
Instance Attribute Summary collapse
-
#time_end ⇒ DateTime
[Required] Time for query to stop matching results to.
-
#time_start ⇒ DateTime
[Required] Time for query to start matching results from.
-
#time_zone ⇒ String
Time zone for query.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TimeRange
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ TimeRange
Initializes the object
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/oci/log_analytics/models/time_range.rb', line 57 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.time_start = attributes[:'timeStart'] if attributes[:'timeStart'] raise 'You cannot provide both :timeStart and :time_start' if attributes.key?(:'timeStart') && attributes.key?(:'time_start') self.time_start = attributes[:'time_start'] if attributes[:'time_start'] self.time_end = attributes[:'timeEnd'] if attributes[:'timeEnd'] raise 'You cannot provide both :timeEnd and :time_end' if attributes.key?(:'timeEnd') && attributes.key?(:'time_end') self.time_end = attributes[:'time_end'] if attributes[:'time_end'] self.time_zone = attributes[:'timeZone'] if attributes[:'timeZone'] self.time_zone = "UTC" if time_zone.nil? && !attributes.key?(:'timeZone') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :timeZone and :time_zone' if attributes.key?(:'timeZone') && attributes.key?(:'time_zone') self.time_zone = attributes[:'time_zone'] if attributes[:'time_zone'] self.time_zone = "UTC" if time_zone.nil? && !attributes.key?(:'timeZone') && !attributes.key?(:'time_zone') # rubocop:disable Style/StringLiterals end |
Instance Attribute Details
#time_end ⇒ DateTime
[Required] Time for query to stop matching results to. End Time must be greater than or equal to start time otherwise it will result in error.
19 20 21 |
# File 'lib/oci/log_analytics/models/time_range.rb', line 19 def time_end @time_end end |
#time_start ⇒ DateTime
[Required] Time for query to start matching results from. Start time must be less than end time otherwise it will result in error.
14 15 16 |
# File 'lib/oci/log_analytics/models/time_range.rb', line 14 def time_start @time_start end |
#time_zone ⇒ String
Time zone for query.
24 25 26 |
# File 'lib/oci/log_analytics/models/time_range.rb', line 24 def time_zone @time_zone end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
27 28 29 30 31 32 33 34 35 |
# File 'lib/oci/log_analytics/models/time_range.rb', line 27 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'time_start': :'timeStart', 'time_end': :'timeEnd', 'time_zone': :'timeZone' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
38 39 40 41 42 43 44 45 46 |
# File 'lib/oci/log_analytics/models/time_range.rb', line 38 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'time_start': :'DateTime', 'time_end': :'DateTime', 'time_zone': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
91 92 93 94 95 96 97 98 |
# File 'lib/oci/log_analytics/models/time_range.rb', line 91 def ==(other) return true if equal?(other) self.class == other.class && time_start == other.time_start && time_end == other.time_end && time_zone == other.time_zone end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/oci/log_analytics/models/time_range.rb', line 123 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
103 104 105 |
# File 'lib/oci/log_analytics/models/time_range.rb', line 103 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
112 113 114 |
# File 'lib/oci/log_analytics/models/time_range.rb', line 112 def hash [time_start, time_end, time_zone].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
156 157 158 159 160 161 162 163 164 165 |
# File 'lib/oci/log_analytics/models/time_range.rb', line 156 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
150 151 152 |
# File 'lib/oci/log_analytics/models/time_range.rb', line 150 def to_s to_hash.to_s end |