Class: OCI::LogAnalytics::Models::TrendColumn
- Inherits:
-
AbstractColumn
- Object
- AbstractColumn
- OCI::LogAnalytics::Models::TrendColumn
- Defined in:
- lib/oci/log_analytics/models/trend_column.rb
Overview
Result column, that contains time series data points in each row. The column includes the time stamps as additional field in column header.
Constant Summary
Constants inherited from AbstractColumn
AbstractColumn::SUB_SYSTEM_ENUM, AbstractColumn::TYPE_ENUM, AbstractColumn::VALUE_TYPE_ENUM
Instance Attribute Summary collapse
-
#interval_gap ⇒ String
Time gap between each data pont in the series.
- #interval_group_counts ⇒ Array<Integer>
- #interval_group_counts_after_filter ⇒ Array<Integer>
-
#intervals ⇒ Array<Integer>
Timestamps for each series data point.
-
#total_interval_counts ⇒ Array<Integer>
Sum across all column values for a given timestamp.
- #total_interval_counts_after_filter ⇒ Array<Integer>
Attributes inherited from AbstractColumn
#display_name, #internal_name, #is_case_sensitive, #is_evaluable, #is_groupable, #is_list_of_values, #is_multi_valued, #original_display_name, #sub_system, #type, #value_type, #values
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TrendColumn
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from AbstractColumn
Constructor Details
#initialize(attributes = {}) ⇒ TrendColumn
Initializes the object
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/oci/log_analytics/models/trend_column.rb', line 111 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['type'] = 'TREND_COLUMN' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.interval_gap = attributes[:'intervalGap'] if attributes[:'intervalGap'] raise 'You cannot provide both :intervalGap and :interval_gap' if attributes.key?(:'intervalGap') && attributes.key?(:'interval_gap') self.interval_gap = attributes[:'interval_gap'] if attributes[:'interval_gap'] self.intervals = attributes[:'intervals'] if attributes[:'intervals'] self.total_interval_counts = attributes[:'totalIntervalCounts'] if attributes[:'totalIntervalCounts'] raise 'You cannot provide both :totalIntervalCounts and :total_interval_counts' if attributes.key?(:'totalIntervalCounts') && attributes.key?(:'total_interval_counts') self.total_interval_counts = attributes[:'total_interval_counts'] if attributes[:'total_interval_counts'] self.total_interval_counts_after_filter = attributes[:'totalIntervalCountsAfterFilter'] if attributes[:'totalIntervalCountsAfterFilter'] raise 'You cannot provide both :totalIntervalCountsAfterFilter and :total_interval_counts_after_filter' if attributes.key?(:'totalIntervalCountsAfterFilter') && attributes.key?(:'total_interval_counts_after_filter') self.total_interval_counts_after_filter = attributes[:'total_interval_counts_after_filter'] if attributes[:'total_interval_counts_after_filter'] self.interval_group_counts = attributes[:'intervalGroupCounts'] if attributes[:'intervalGroupCounts'] raise 'You cannot provide both :intervalGroupCounts and :interval_group_counts' if attributes.key?(:'intervalGroupCounts') && attributes.key?(:'interval_group_counts') self.interval_group_counts = attributes[:'interval_group_counts'] if attributes[:'interval_group_counts'] self.interval_group_counts_after_filter = attributes[:'intervalGroupCountsAfterFilter'] if attributes[:'intervalGroupCountsAfterFilter'] raise 'You cannot provide both :intervalGroupCountsAfterFilter and :interval_group_counts_after_filter' if attributes.key?(:'intervalGroupCountsAfterFilter') && attributes.key?(:'interval_group_counts_after_filter') self.interval_group_counts_after_filter = attributes[:'interval_group_counts_after_filter'] if attributes[:'interval_group_counts_after_filter'] end |
Instance Attribute Details
#interval_gap ⇒ String
Time gap between each data pont in the series.
15 16 17 |
# File 'lib/oci/log_analytics/models/trend_column.rb', line 15 def interval_gap @interval_gap end |
#interval_group_counts ⇒ Array<Integer>
31 32 33 |
# File 'lib/oci/log_analytics/models/trend_column.rb', line 31 def interval_group_counts @interval_group_counts end |
#interval_group_counts_after_filter ⇒ Array<Integer>
34 35 36 |
# File 'lib/oci/log_analytics/models/trend_column.rb', line 34 def interval_group_counts_after_filter @interval_group_counts_after_filter end |
#intervals ⇒ Array<Integer>
Timestamps for each series data point
20 21 22 |
# File 'lib/oci/log_analytics/models/trend_column.rb', line 20 def intervals @intervals end |
#total_interval_counts ⇒ Array<Integer>
Sum across all column values for a given timestamp.
25 26 27 |
# File 'lib/oci/log_analytics/models/trend_column.rb', line 25 def total_interval_counts @total_interval_counts end |
#total_interval_counts_after_filter ⇒ Array<Integer>
28 29 30 |
# File 'lib/oci/log_analytics/models/trend_column.rb', line 28 def total_interval_counts_after_filter @total_interval_counts_after_filter end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/oci/log_analytics/models/trend_column.rb', line 37 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'type': :'type', 'display_name': :'displayName', 'sub_system': :'subSystem', 'values': :'values', 'is_list_of_values': :'isListOfValues', 'is_multi_valued': :'isMultiValued', 'is_case_sensitive': :'isCaseSensitive', 'is_groupable': :'isGroupable', 'is_evaluable': :'isEvaluable', 'value_type': :'valueType', 'original_display_name': :'originalDisplayName', 'internal_name': :'internalName', 'interval_gap': :'intervalGap', 'intervals': :'intervals', 'total_interval_counts': :'totalIntervalCounts', 'total_interval_counts_after_filter': :'totalIntervalCountsAfterFilter', 'interval_group_counts': :'intervalGroupCounts', 'interval_group_counts_after_filter': :'intervalGroupCountsAfterFilter' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/oci/log_analytics/models/trend_column.rb', line 63 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'type': :'String', 'display_name': :'String', 'sub_system': :'String', 'values': :'Array<OCI::LogAnalytics::Models::FieldValue>', 'is_list_of_values': :'BOOLEAN', 'is_multi_valued': :'BOOLEAN', 'is_case_sensitive': :'BOOLEAN', 'is_groupable': :'BOOLEAN', 'is_evaluable': :'BOOLEAN', 'value_type': :'String', 'original_display_name': :'String', 'internal_name': :'String', 'interval_gap': :'String', 'intervals': :'Array<Integer>', 'total_interval_counts': :'Array<Integer>', 'total_interval_counts_after_filter': :'Array<Integer>', 'interval_group_counts': :'Array<Integer>', 'interval_group_counts_after_filter': :'Array<Integer>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/oci/log_analytics/models/trend_column.rb', line 161 def ==(other) return true if equal?(other) self.class == other.class && type == other.type && display_name == other.display_name && sub_system == other.sub_system && values == other.values && is_list_of_values == other.is_list_of_values && is_multi_valued == other.is_multi_valued && is_case_sensitive == other.is_case_sensitive && is_groupable == other.is_groupable && is_evaluable == other.is_evaluable && value_type == other.value_type && original_display_name == other.original_display_name && internal_name == other.internal_name && interval_gap == other.interval_gap && intervals == other.intervals && total_interval_counts == other.total_interval_counts && total_interval_counts_after_filter == other.total_interval_counts_after_filter && interval_group_counts == other.interval_group_counts && interval_group_counts_after_filter == other.interval_group_counts_after_filter end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/oci/log_analytics/models/trend_column.rb', line 208 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
188 189 190 |
# File 'lib/oci/log_analytics/models/trend_column.rb', line 188 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
197 198 199 |
# File 'lib/oci/log_analytics/models/trend_column.rb', line 197 def hash [type, display_name, sub_system, values, is_list_of_values, is_multi_valued, is_case_sensitive, is_groupable, is_evaluable, value_type, original_display_name, internal_name, interval_gap, intervals, total_interval_counts, total_interval_counts_after_filter, interval_group_counts, interval_group_counts_after_filter].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
241 242 243 244 245 246 247 248 249 250 |
# File 'lib/oci/log_analytics/models/trend_column.rb', line 241 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
235 236 237 |
# File 'lib/oci/log_analytics/models/trend_column.rb', line 235 def to_s to_hash.to_s end |