Class: OCI::LogAnalytics::Models::UpdateLookupMetadataDetails
- Inherits:
-
Object
- Object
- OCI::LogAnalytics::Models::UpdateLookupMetadataDetails
- Defined in:
- lib/oci/log_analytics/models/update_lookup_metadata_details.rb
Overview
UpdateLookupMetadataDetails
Instance Attribute Summary collapse
-
#default_match_value ⇒ String
The default match value.
-
#description ⇒ String
The lookup description.
-
#fields ⇒ Array<OCI::LogAnalytics::Models::LogAnalyticsLookupFields>
The lookup fields.
-
#max_matches ⇒ Integer
The maximum number of matches.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateLookupMetadataDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateLookupMetadataDetails
Initializes the object
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/oci/log_analytics/models/update_lookup_metadata_details.rb', line 60 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.default_match_value = attributes[:'defaultMatchValue'] if attributes[:'defaultMatchValue'] raise 'You cannot provide both :defaultMatchValue and :default_match_value' if attributes.key?(:'defaultMatchValue') && attributes.key?(:'default_match_value') self.default_match_value = attributes[:'default_match_value'] if attributes[:'default_match_value'] self.description = attributes[:'description'] if attributes[:'description'] self.fields = attributes[:'fields'] if attributes[:'fields'] self.max_matches = attributes[:'maxMatches'] if attributes[:'maxMatches'] raise 'You cannot provide both :maxMatches and :max_matches' if attributes.key?(:'maxMatches') && attributes.key?(:'max_matches') self.max_matches = attributes[:'max_matches'] if attributes[:'max_matches'] end |
Instance Attribute Details
#default_match_value ⇒ String
The default match value.
12 13 14 |
# File 'lib/oci/log_analytics/models/update_lookup_metadata_details.rb', line 12 def default_match_value @default_match_value end |
#description ⇒ String
The lookup description.
16 17 18 |
# File 'lib/oci/log_analytics/models/update_lookup_metadata_details.rb', line 16 def description @description end |
#fields ⇒ Array<OCI::LogAnalytics::Models::LogAnalyticsLookupFields>
The lookup fields.
20 21 22 |
# File 'lib/oci/log_analytics/models/update_lookup_metadata_details.rb', line 20 def fields @fields end |
#max_matches ⇒ Integer
The maximum number of matches.
24 25 26 |
# File 'lib/oci/log_analytics/models/update_lookup_metadata_details.rb', line 24 def max_matches @max_matches end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
27 28 29 30 31 32 33 34 35 36 |
# File 'lib/oci/log_analytics/models/update_lookup_metadata_details.rb', line 27 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'default_match_value': :'defaultMatchValue', 'description': :'description', 'fields': :'fields', 'max_matches': :'maxMatches' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
39 40 41 42 43 44 45 46 47 48 |
# File 'lib/oci/log_analytics/models/update_lookup_metadata_details.rb', line 39 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'default_match_value': :'String', 'description': :'String', 'fields': :'Array<OCI::LogAnalytics::Models::LogAnalyticsLookupFields>', 'max_matches': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
90 91 92 93 94 95 96 97 98 |
# File 'lib/oci/log_analytics/models/update_lookup_metadata_details.rb', line 90 def ==(other) return true if equal?(other) self.class == other.class && default_match_value == other.default_match_value && description == other.description && fields == other.fields && max_matches == other.max_matches end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/oci/log_analytics/models/update_lookup_metadata_details.rb', line 123 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
103 104 105 |
# File 'lib/oci/log_analytics/models/update_lookup_metadata_details.rb', line 103 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
112 113 114 |
# File 'lib/oci/log_analytics/models/update_lookup_metadata_details.rb', line 112 def hash [default_match_value, description, fields, max_matches].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
156 157 158 159 160 161 162 163 164 165 |
# File 'lib/oci/log_analytics/models/update_lookup_metadata_details.rb', line 156 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
150 151 152 |
# File 'lib/oci/log_analytics/models/update_lookup_metadata_details.rb', line 150 def to_s to_hash.to_s end |