Class: OCI::LogAnalytics::Models::UpdateStandardTaskDetails

Inherits:
UpdateScheduledTaskDetails show all
Defined in:
lib/oci/log_analytics/models/update_standard_task_details.rb

Overview

The details for updating a schedule task.

Constant Summary

Constants inherited from UpdateScheduledTaskDetails

OCI::LogAnalytics::Models::UpdateScheduledTaskDetails::KIND_ENUM

Instance Attribute Summary collapse

Attributes inherited from UpdateScheduledTaskDetails

#defined_tags, #display_name, #freeform_tags, #kind, #schedules

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from UpdateScheduledTaskDetails

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ UpdateStandardTaskDetails

Initializes the object

Options Hash (attributes):



54
55
56
57
58
59
60
61
62
63
64
65
# File 'lib/oci/log_analytics/models/update_standard_task_details.rb', line 54

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['kind'] = 'STANDARD'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.action = attributes[:'action'] if attributes[:'action']
end

Instance Attribute Details

#actionOCI::LogAnalytics::Models::Action



13
14
15
# File 'lib/oci/log_analytics/models/update_standard_task_details.rb', line 13

def action
  @action
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



16
17
18
19
20
21
22
23
24
25
26
27
# File 'lib/oci/log_analytics/models/update_standard_task_details.rb', line 16

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'kind': :'kind',
    'display_name': :'displayName',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'schedules': :'schedules',
    'action': :'action'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



30
31
32
33
34
35
36
37
38
39
40
41
# File 'lib/oci/log_analytics/models/update_standard_task_details.rb', line 30

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'kind': :'String',
    'display_name': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'schedules': :'Array<OCI::LogAnalytics::Models::Schedule>',
    'action': :'OCI::LogAnalytics::Models::Action'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.



74
75
76
77
78
79
80
81
82
83
84
# File 'lib/oci/log_analytics/models/update_standard_task_details.rb', line 74

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    kind == other.kind &&
    display_name == other.display_name &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    schedules == other.schedules &&
    action == other.action
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/oci/log_analytics/models/update_standard_task_details.rb', line 109

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method


89
90
91
# File 'lib/oci/log_analytics/models/update_standard_task_details.rb', line 89

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.



98
99
100
# File 'lib/oci/log_analytics/models/update_standard_task_details.rb', line 98

def hash
  [kind, display_name, freeform_tags, defined_tags, schedules, action].hash
end

#to_hashHash

Returns the object in the form of hash



142
143
144
145
146
147
148
149
150
151
# File 'lib/oci/log_analytics/models/update_standard_task_details.rb', line 142

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



136
137
138
# File 'lib/oci/log_analytics/models/update_standard_task_details.rb', line 136

def to_s
  to_hash.to_s
end