Class: OCI::LogAnalytics::Models::UpsertLogAnalyticsAssociation
- Inherits:
-
Object
- Object
- OCI::LogAnalytics::Models::UpsertLogAnalyticsAssociation
- Defined in:
- lib/oci/log_analytics/models/upsert_log_analytics_association.rb
Overview
UpsertLogAnalyticsAssociation
Instance Attribute Summary collapse
-
#agent_id ⇒ String
The agent unique identifier.
-
#entity_id ⇒ String
The entity unique identifier.
-
#entity_name ⇒ String
The entity name.
-
#entity_type_name ⇒ String
The entity type internal name.
-
#host ⇒ String
The host name.
-
#log_group_id ⇒ String
The log group unique identifier.
-
#source_name ⇒ String
The source name.
-
#source_type_name ⇒ String
The source type internal name.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpsertLogAnalyticsAssociation
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpsertLogAnalyticsAssociation
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/oci/log_analytics/models/upsert_log_analytics_association.rb', line 88 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.agent_id = attributes[:'agentId'] if attributes[:'agentId'] raise 'You cannot provide both :agentId and :agent_id' if attributes.key?(:'agentId') && attributes.key?(:'agent_id') self.agent_id = attributes[:'agent_id'] if attributes[:'agent_id'] self.source_name = attributes[:'sourceName'] if attributes[:'sourceName'] raise 'You cannot provide both :sourceName and :source_name' if attributes.key?(:'sourceName') && attributes.key?(:'source_name') self.source_name = attributes[:'source_name'] if attributes[:'source_name'] self.source_type_name = attributes[:'sourceTypeName'] if attributes[:'sourceTypeName'] raise 'You cannot provide both :sourceTypeName and :source_type_name' if attributes.key?(:'sourceTypeName') && attributes.key?(:'source_type_name') self.source_type_name = attributes[:'source_type_name'] if attributes[:'source_type_name'] self.entity_id = attributes[:'entityId'] if attributes[:'entityId'] raise 'You cannot provide both :entityId and :entity_id' if attributes.key?(:'entityId') && attributes.key?(:'entity_id') self.entity_id = attributes[:'entity_id'] if attributes[:'entity_id'] self.entity_name = attributes[:'entityName'] if attributes[:'entityName'] raise 'You cannot provide both :entityName and :entity_name' if attributes.key?(:'entityName') && attributes.key?(:'entity_name') self.entity_name = attributes[:'entity_name'] if attributes[:'entity_name'] self.entity_type_name = attributes[:'entityTypeName'] if attributes[:'entityTypeName'] raise 'You cannot provide both :entityTypeName and :entity_type_name' if attributes.key?(:'entityTypeName') && attributes.key?(:'entity_type_name') self.entity_type_name = attributes[:'entity_type_name'] if attributes[:'entity_type_name'] self.host = attributes[:'host'] if attributes[:'host'] self.log_group_id = attributes[:'logGroupId'] if attributes[:'logGroupId'] raise 'You cannot provide both :logGroupId and :log_group_id' if attributes.key?(:'logGroupId') && attributes.key?(:'log_group_id') self.log_group_id = attributes[:'log_group_id'] if attributes[:'log_group_id'] end |
Instance Attribute Details
#agent_id ⇒ String
The agent unique identifier.
12 13 14 |
# File 'lib/oci/log_analytics/models/upsert_log_analytics_association.rb', line 12 def agent_id @agent_id end |
#entity_id ⇒ String
The entity unique identifier.
24 25 26 |
# File 'lib/oci/log_analytics/models/upsert_log_analytics_association.rb', line 24 def entity_id @entity_id end |
#entity_name ⇒ String
The entity name.
28 29 30 |
# File 'lib/oci/log_analytics/models/upsert_log_analytics_association.rb', line 28 def entity_name @entity_name end |
#entity_type_name ⇒ String
The entity type internal name.
32 33 34 |
# File 'lib/oci/log_analytics/models/upsert_log_analytics_association.rb', line 32 def entity_type_name @entity_type_name end |
#host ⇒ String
The host name.
36 37 38 |
# File 'lib/oci/log_analytics/models/upsert_log_analytics_association.rb', line 36 def host @host end |
#log_group_id ⇒ String
The log group unique identifier.
40 41 42 |
# File 'lib/oci/log_analytics/models/upsert_log_analytics_association.rb', line 40 def log_group_id @log_group_id end |
#source_name ⇒ String
The source name.
16 17 18 |
# File 'lib/oci/log_analytics/models/upsert_log_analytics_association.rb', line 16 def source_name @source_name end |
#source_type_name ⇒ String
The source type internal name.
20 21 22 |
# File 'lib/oci/log_analytics/models/upsert_log_analytics_association.rb', line 20 def source_type_name @source_type_name end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/oci/log_analytics/models/upsert_log_analytics_association.rb', line 43 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'agent_id': :'agentId', 'source_name': :'sourceName', 'source_type_name': :'sourceTypeName', 'entity_id': :'entityId', 'entity_name': :'entityName', 'entity_type_name': :'entityTypeName', 'host': :'host', 'log_group_id': :'logGroupId' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/oci/log_analytics/models/upsert_log_analytics_association.rb', line 59 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'agent_id': :'String', 'source_name': :'String', 'source_type_name': :'String', 'entity_id': :'String', 'entity_name': :'String', 'entity_type_name': :'String', 'host': :'String', 'log_group_id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/oci/log_analytics/models/upsert_log_analytics_association.rb', line 146 def ==(other) return true if equal?(other) self.class == other.class && agent_id == other.agent_id && source_name == other.source_name && source_type_name == other.source_type_name && entity_id == other.entity_id && entity_name == other.entity_name && entity_type_name == other.entity_type_name && host == other.host && log_group_id == other.log_group_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/oci/log_analytics/models/upsert_log_analytics_association.rb', line 183 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
163 164 165 |
# File 'lib/oci/log_analytics/models/upsert_log_analytics_association.rb', line 163 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
172 173 174 |
# File 'lib/oci/log_analytics/models/upsert_log_analytics_association.rb', line 172 def hash [agent_id, source_name, source_type_name, entity_id, entity_name, entity_type_name, host, log_group_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
216 217 218 219 220 221 222 223 224 225 |
# File 'lib/oci/log_analytics/models/upsert_log_analytics_association.rb', line 216 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
210 211 212 |
# File 'lib/oci/log_analytics/models/upsert_log_analytics_association.rb', line 210 def to_s to_hash.to_s end |