Class: OCI::LogAnalytics::Models::UpsertLogAnalyticsParserDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/log_analytics/models/upsert_log_analytics_parser_details.rb

Overview

UpsertLogAnalyticsParserDetails

Constant Summary collapse

TYPE_ENUM =
[
  TYPE_XML = 'XML'.freeze,
  TYPE_JSON = 'JSON'.freeze,
  TYPE_REGEX = 'REGEX'.freeze,
  TYPE_ODL = 'ODL'.freeze,
  TYPE_DELIMITED = 'DELIMITED'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpsertLogAnalyticsParserDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
# File 'lib/oci/log_analytics/models/upsert_log_analytics_parser_details.rb', line 214

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.content = attributes[:'content'] if attributes[:'content']

  self.description = attributes[:'description'] if attributes[:'description']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.edit_version = attributes[:'editVersion'] if attributes[:'editVersion']

  raise 'You cannot provide both :editVersion and :edit_version' if attributes.key?(:'editVersion') && attributes.key?(:'edit_version')

  self.edit_version = attributes[:'edit_version'] if attributes[:'edit_version']

  self.encoding = attributes[:'encoding'] if attributes[:'encoding']

  self.example_content = attributes[:'exampleContent'] if attributes[:'exampleContent']

  raise 'You cannot provide both :exampleContent and :example_content' if attributes.key?(:'exampleContent') && attributes.key?(:'example_content')

  self.example_content = attributes[:'example_content'] if attributes[:'example_content']

  self.field_maps = attributes[:'fieldMaps'] if attributes[:'fieldMaps']

  raise 'You cannot provide both :fieldMaps and :field_maps' if attributes.key?(:'fieldMaps') && attributes.key?(:'field_maps')

  self.field_maps = attributes[:'field_maps'] if attributes[:'field_maps']

  self.footer_content = attributes[:'footerContent'] if attributes[:'footerContent']

  raise 'You cannot provide both :footerContent and :footer_content' if attributes.key?(:'footerContent') && attributes.key?(:'footer_content')

  self.footer_content = attributes[:'footer_content'] if attributes[:'footer_content']

  self.header_content = attributes[:'headerContent'] if attributes[:'headerContent']

  raise 'You cannot provide both :headerContent and :header_content' if attributes.key?(:'headerContent') && attributes.key?(:'header_content')

  self.header_content = attributes[:'header_content'] if attributes[:'header_content']

  self.name = attributes[:'name'] if attributes[:'name']

  self.is_default = attributes[:'isDefault'] unless attributes[:'isDefault'].nil?

  raise 'You cannot provide both :isDefault and :is_default' if attributes.key?(:'isDefault') && attributes.key?(:'is_default')

  self.is_default = attributes[:'is_default'] unless attributes[:'is_default'].nil?

  self.is_single_line_content = attributes[:'isSingleLineContent'] unless attributes[:'isSingleLineContent'].nil?

  raise 'You cannot provide both :isSingleLineContent and :is_single_line_content' if attributes.key?(:'isSingleLineContent') && attributes.key?(:'is_single_line_content')

  self.is_single_line_content = attributes[:'is_single_line_content'] unless attributes[:'is_single_line_content'].nil?

  self.is_system = attributes[:'isSystem'] unless attributes[:'isSystem'].nil?

  raise 'You cannot provide both :isSystem and :is_system' if attributes.key?(:'isSystem') && attributes.key?(:'is_system')

  self.is_system = attributes[:'is_system'] unless attributes[:'is_system'].nil?

  self.language = attributes[:'language'] if attributes[:'language']

  self.log_type_test_request_version = attributes[:'logTypeTestRequestVersion'] if attributes[:'logTypeTestRequestVersion']

  raise 'You cannot provide both :logTypeTestRequestVersion and :log_type_test_request_version' if attributes.key?(:'logTypeTestRequestVersion') && attributes.key?(:'log_type_test_request_version')

  self.log_type_test_request_version = attributes[:'log_type_test_request_version'] if attributes[:'log_type_test_request_version']

  self.parser_ignoreline_characters = attributes[:'parserIgnorelineCharacters'] if attributes[:'parserIgnorelineCharacters']

  raise 'You cannot provide both :parserIgnorelineCharacters and :parser_ignoreline_characters' if attributes.key?(:'parserIgnorelineCharacters') && attributes.key?(:'parser_ignoreline_characters')

  self.parser_ignoreline_characters = attributes[:'parser_ignoreline_characters'] if attributes[:'parser_ignoreline_characters']

  self.parser_sequence = attributes[:'parserSequence'] if attributes[:'parserSequence']

  raise 'You cannot provide both :parserSequence and :parser_sequence' if attributes.key?(:'parserSequence') && attributes.key?(:'parser_sequence')

  self.parser_sequence = attributes[:'parser_sequence'] if attributes[:'parser_sequence']

  self.parser_timezone = attributes[:'parserTimezone'] if attributes[:'parserTimezone']

  raise 'You cannot provide both :parserTimezone and :parser_timezone' if attributes.key?(:'parserTimezone') && attributes.key?(:'parser_timezone')

  self.parser_timezone = attributes[:'parser_timezone'] if attributes[:'parser_timezone']

  self.is_parser_written_once = attributes[:'isParserWrittenOnce'] unless attributes[:'isParserWrittenOnce'].nil?

  raise 'You cannot provide both :isParserWrittenOnce and :is_parser_written_once' if attributes.key?(:'isParserWrittenOnce') && attributes.key?(:'is_parser_written_once')

  self.is_parser_written_once = attributes[:'is_parser_written_once'] unless attributes[:'is_parser_written_once'].nil?

  self.parser_functions = attributes[:'parserFunctions'] if attributes[:'parserFunctions']

  raise 'You cannot provide both :parserFunctions and :parser_functions' if attributes.key?(:'parserFunctions') && attributes.key?(:'parser_functions')

  self.parser_functions = attributes[:'parser_functions'] if attributes[:'parser_functions']

  self.should_tokenize_original_text = attributes[:'shouldTokenizeOriginalText'] unless attributes[:'shouldTokenizeOriginalText'].nil?

  raise 'You cannot provide both :shouldTokenizeOriginalText and :should_tokenize_original_text' if attributes.key?(:'shouldTokenizeOriginalText') && attributes.key?(:'should_tokenize_original_text')

  self.should_tokenize_original_text = attributes[:'should_tokenize_original_text'] unless attributes[:'should_tokenize_original_text'].nil?

  self.field_delimiter = attributes[:'fieldDelimiter'] if attributes[:'fieldDelimiter']

  raise 'You cannot provide both :fieldDelimiter and :field_delimiter' if attributes.key?(:'fieldDelimiter') && attributes.key?(:'field_delimiter')

  self.field_delimiter = attributes[:'field_delimiter'] if attributes[:'field_delimiter']

  self.field_qualifier = attributes[:'fieldQualifier'] if attributes[:'fieldQualifier']

  raise 'You cannot provide both :fieldQualifier and :field_qualifier' if attributes.key?(:'fieldQualifier') && attributes.key?(:'field_qualifier')

  self.field_qualifier = attributes[:'field_qualifier'] if attributes[:'field_qualifier']

  self.type = attributes[:'type'] if attributes[:'type']
  self.type = "REGEX" if type.nil? && !attributes.key?(:'type') # rubocop:disable Style/StringLiterals
end

Instance Attribute Details

#contentString

The content.

Returns:

  • (String)


20
21
22
# File 'lib/oci/log_analytics/models/upsert_log_analytics_parser_details.rb', line 20

def content
  @content
end

#descriptionString

The parser description.

Returns:

  • (String)


24
25
26
# File 'lib/oci/log_analytics/models/upsert_log_analytics_parser_details.rb', line 24

def description
  @description
end

#display_nameString

The parser display name.

Returns:

  • (String)


28
29
30
# File 'lib/oci/log_analytics/models/upsert_log_analytics_parser_details.rb', line 28

def display_name
  @display_name
end

#edit_versionInteger

The parser edit version.

Returns:

  • (Integer)


32
33
34
# File 'lib/oci/log_analytics/models/upsert_log_analytics_parser_details.rb', line 32

def edit_version
  @edit_version
end

#encodingString

The encoding.

Returns:

  • (String)


36
37
38
# File 'lib/oci/log_analytics/models/upsert_log_analytics_parser_details.rb', line 36

def encoding
  @encoding
end

#example_contentString

Example content.

Returns:

  • (String)


40
41
42
# File 'lib/oci/log_analytics/models/upsert_log_analytics_parser_details.rb', line 40

def example_content
  @example_content
end

#field_delimiterString

The parser field delimiter.

Returns:

  • (String)


110
111
112
# File 'lib/oci/log_analytics/models/upsert_log_analytics_parser_details.rb', line 110

def field_delimiter
  @field_delimiter
end

#field_mapsArray<OCI::LogAnalytics::Models::LogAnalyticsParserField>

The parser fields.



44
45
46
# File 'lib/oci/log_analytics/models/upsert_log_analytics_parser_details.rb', line 44

def field_maps
  @field_maps
end

#field_qualifierString

The parser field qualifier.

Returns:

  • (String)


114
115
116
# File 'lib/oci/log_analytics/models/upsert_log_analytics_parser_details.rb', line 114

def field_qualifier
  @field_qualifier
end

The footer regular expression.

Returns:

  • (String)


48
49
50
# File 'lib/oci/log_analytics/models/upsert_log_analytics_parser_details.rb', line 48

def footer_content
  @footer_content
end

#header_contentString

The header content.

Returns:

  • (String)


52
53
54
# File 'lib/oci/log_analytics/models/upsert_log_analytics_parser_details.rb', line 52

def header_content
  @header_content
end

#is_defaultBOOLEAN

A flag indicating if this is a default parser.

Returns:

  • (BOOLEAN)


61
62
63
# File 'lib/oci/log_analytics/models/upsert_log_analytics_parser_details.rb', line 61

def is_default
  @is_default
end

#is_parser_written_onceBOOLEAN

A flag indicating whther or not the parser is write once.

Returns:

  • (BOOLEAN)


97
98
99
# File 'lib/oci/log_analytics/models/upsert_log_analytics_parser_details.rb', line 97

def is_parser_written_once
  @is_parser_written_once
end

#is_single_line_contentBOOLEAN

A flag indicating if this is a single line content parser.

Returns:

  • (BOOLEAN)


66
67
68
# File 'lib/oci/log_analytics/models/upsert_log_analytics_parser_details.rb', line 66

def is_single_line_content
  @is_single_line_content
end

#is_systemBOOLEAN

The system flag. A value of false denotes a custom, or user defined object. A value of true denotes a built in object.

Returns:

  • (BOOLEAN)


72
73
74
# File 'lib/oci/log_analytics/models/upsert_log_analytics_parser_details.rb', line 72

def is_system
  @is_system
end

#languageString

The language.

Returns:

  • (String)


76
77
78
# File 'lib/oci/log_analytics/models/upsert_log_analytics_parser_details.rb', line 76

def language
  @language
end

#log_type_test_request_versionInteger

The log type test request version.

Returns:

  • (Integer)


80
81
82
# File 'lib/oci/log_analytics/models/upsert_log_analytics_parser_details.rb', line 80

def log_type_test_request_version
  @log_type_test_request_version
end

#nameString

The parser internal name.

Returns:

  • (String)


56
57
58
# File 'lib/oci/log_analytics/models/upsert_log_analytics_parser_details.rb', line 56

def name
  @name
end

#parser_functionsArray<OCI::LogAnalytics::Models::LogAnalyticsParserFunction>

The parser function list.



101
102
103
# File 'lib/oci/log_analytics/models/upsert_log_analytics_parser_details.rb', line 101

def parser_functions
  @parser_functions
end

#parser_ignoreline_charactersString

The line characters for the parser to ignore.

Returns:

  • (String)


84
85
86
# File 'lib/oci/log_analytics/models/upsert_log_analytics_parser_details.rb', line 84

def parser_ignoreline_characters
  @parser_ignoreline_characters
end

#parser_sequenceInteger

The parser sequence.

Returns:

  • (Integer)


88
89
90
# File 'lib/oci/log_analytics/models/upsert_log_analytics_parser_details.rb', line 88

def parser_sequence
  @parser_sequence
end

#parser_timezoneString

The time zone.

Returns:

  • (String)


92
93
94
# File 'lib/oci/log_analytics/models/upsert_log_analytics_parser_details.rb', line 92

def parser_timezone
  @parser_timezone
end

#should_tokenize_original_textBOOLEAN

A flag indicating whether or not to tokenize the original text.

Returns:

  • (BOOLEAN)


106
107
108
# File 'lib/oci/log_analytics/models/upsert_log_analytics_parser_details.rb', line 106

def should_tokenize_original_text
  @should_tokenize_original_text
end

#typeString

The parser type. Default value is REGEX.

Returns:

  • (String)


118
119
120
# File 'lib/oci/log_analytics/models/upsert_log_analytics_parser_details.rb', line 118

def type
  @type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/oci/log_analytics/models/upsert_log_analytics_parser_details.rb', line 121

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'content': :'content',
    'description': :'description',
    'display_name': :'displayName',
    'edit_version': :'editVersion',
    'encoding': :'encoding',
    'example_content': :'exampleContent',
    'field_maps': :'fieldMaps',
    'footer_content': :'footerContent',
    'header_content': :'headerContent',
    'name': :'name',
    'is_default': :'isDefault',
    'is_single_line_content': :'isSingleLineContent',
    'is_system': :'isSystem',
    'language': :'language',
    'log_type_test_request_version': :'logTypeTestRequestVersion',
    'parser_ignoreline_characters': :'parserIgnorelineCharacters',
    'parser_sequence': :'parserSequence',
    'parser_timezone': :'parserTimezone',
    'is_parser_written_once': :'isParserWrittenOnce',
    'parser_functions': :'parserFunctions',
    'should_tokenize_original_text': :'shouldTokenizeOriginalText',
    'field_delimiter': :'fieldDelimiter',
    'field_qualifier': :'fieldQualifier',
    'type': :'type'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/oci/log_analytics/models/upsert_log_analytics_parser_details.rb', line 153

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'content': :'String',
    'description': :'String',
    'display_name': :'String',
    'edit_version': :'Integer',
    'encoding': :'String',
    'example_content': :'String',
    'field_maps': :'Array<OCI::LogAnalytics::Models::LogAnalyticsParserField>',
    'footer_content': :'String',
    'header_content': :'String',
    'name': :'String',
    'is_default': :'BOOLEAN',
    'is_single_line_content': :'BOOLEAN',
    'is_system': :'BOOLEAN',
    'language': :'String',
    'log_type_test_request_version': :'Integer',
    'parser_ignoreline_characters': :'String',
    'parser_sequence': :'Integer',
    'parser_timezone': :'String',
    'is_parser_written_once': :'BOOLEAN',
    'parser_functions': :'Array<OCI::LogAnalytics::Models::LogAnalyticsParserFunction>',
    'should_tokenize_original_text': :'BOOLEAN',
    'field_delimiter': :'String',
    'field_qualifier': :'String',
    'type': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
# File 'lib/oci/log_analytics/models/upsert_log_analytics_parser_details.rb', line 357

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    content == other.content &&
    description == other.description &&
    display_name == other.display_name &&
    edit_version == other.edit_version &&
    encoding == other.encoding &&
    example_content == other.example_content &&
    field_maps == other.field_maps &&
    footer_content == other.footer_content &&
    header_content == other.header_content &&
    name == other.name &&
    is_default == other.is_default &&
    is_single_line_content == other.is_single_line_content &&
    is_system == other.is_system &&
    language == other.language &&
    log_type_test_request_version == other.log_type_test_request_version &&
    parser_ignoreline_characters == other.parser_ignoreline_characters &&
    parser_sequence == other.parser_sequence &&
    parser_timezone == other.parser_timezone &&
    is_parser_written_once == other.is_parser_written_once &&
    parser_functions == other.parser_functions &&
    should_tokenize_original_text == other.should_tokenize_original_text &&
    field_delimiter == other.field_delimiter &&
    field_qualifier == other.field_qualifier &&
    type == other.type
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
# File 'lib/oci/log_analytics/models/upsert_log_analytics_parser_details.rb', line 410

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


390
391
392
# File 'lib/oci/log_analytics/models/upsert_log_analytics_parser_details.rb', line 390

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



399
400
401
# File 'lib/oci/log_analytics/models/upsert_log_analytics_parser_details.rb', line 399

def hash
  [content, description, display_name, edit_version, encoding, example_content, field_maps, footer_content, header_content, name, is_default, is_single_line_content, is_system, language, log_type_test_request_version, parser_ignoreline_characters, parser_sequence, parser_timezone, is_parser_written_once, parser_functions, should_tokenize_original_text, field_delimiter, field_qualifier, type].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



443
444
445
446
447
448
449
450
451
452
# File 'lib/oci/log_analytics/models/upsert_log_analytics_parser_details.rb', line 443

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



437
438
439
# File 'lib/oci/log_analytics/models/upsert_log_analytics_parser_details.rb', line 437

def to_s
  to_hash.to_s
end