Class: OCI::LogAnalytics::Models::UpsertLogAnalyticsSourceDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/log_analytics/models/upsert_log_analytics_source_details.rb

Overview

UpsertLogAnalyticsSourceDetails

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpsertLogAnalyticsSourceDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
# File 'lib/oci/log_analytics/models/upsert_log_analytics_source_details.rb', line 242

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.label_conditions = attributes[:'labelConditions'] if attributes[:'labelConditions']

  raise 'You cannot provide both :labelConditions and :label_conditions' if attributes.key?(:'labelConditions') && attributes.key?(:'label_conditions')

  self.label_conditions = attributes[:'label_conditions'] if attributes[:'label_conditions']

  self.data_filter_definitions = attributes[:'dataFilterDefinitions'] if attributes[:'dataFilterDefinitions']

  raise 'You cannot provide both :dataFilterDefinitions and :data_filter_definitions' if attributes.key?(:'dataFilterDefinitions') && attributes.key?(:'data_filter_definitions')

  self.data_filter_definitions = attributes[:'data_filter_definitions'] if attributes[:'data_filter_definitions']

  self.database_credential = attributes[:'databaseCredential'] if attributes[:'databaseCredential']

  raise 'You cannot provide both :databaseCredential and :database_credential' if attributes.key?(:'databaseCredential') && attributes.key?(:'database_credential')

  self.database_credential = attributes[:'database_credential'] if attributes[:'database_credential']

  self.extended_field_definitions = attributes[:'extendedFieldDefinitions'] if attributes[:'extendedFieldDefinitions']

  raise 'You cannot provide both :extendedFieldDefinitions and :extended_field_definitions' if attributes.key?(:'extendedFieldDefinitions') && attributes.key?(:'extended_field_definitions')

  self.extended_field_definitions = attributes[:'extended_field_definitions'] if attributes[:'extended_field_definitions']

  self.is_for_cloud = attributes[:'isForCloud'] unless attributes[:'isForCloud'].nil?

  raise 'You cannot provide both :isForCloud and :is_for_cloud' if attributes.key?(:'isForCloud') && attributes.key?(:'is_for_cloud')

  self.is_for_cloud = attributes[:'is_for_cloud'] unless attributes[:'is_for_cloud'].nil?

  self.labels = attributes[:'labels'] if attributes[:'labels']

  self.metric_definitions = attributes[:'metricDefinitions'] if attributes[:'metricDefinitions']

  raise 'You cannot provide both :metricDefinitions and :metric_definitions' if attributes.key?(:'metricDefinitions') && attributes.key?(:'metric_definitions')

  self.metric_definitions = attributes[:'metric_definitions'] if attributes[:'metric_definitions']

  self.metrics = attributes[:'metrics'] if attributes[:'metrics']

  self.oob_parsers = attributes[:'oobParsers'] if attributes[:'oobParsers']

  raise 'You cannot provide both :oobParsers and :oob_parsers' if attributes.key?(:'oobParsers') && attributes.key?(:'oob_parsers')

  self.oob_parsers = attributes[:'oob_parsers'] if attributes[:'oob_parsers']

  self.parameters = attributes[:'parameters'] if attributes[:'parameters']

  self.patterns = attributes[:'patterns'] if attributes[:'patterns']

  self.description = attributes[:'description'] if attributes[:'description']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.edit_version = attributes[:'editVersion'] if attributes[:'editVersion']

  raise 'You cannot provide both :editVersion and :edit_version' if attributes.key?(:'editVersion') && attributes.key?(:'edit_version')

  self.edit_version = attributes[:'edit_version'] if attributes[:'edit_version']

  self.functions = attributes[:'functions'] if attributes[:'functions']

  self.source_id = attributes[:'sourceId'] if attributes[:'sourceId']

  raise 'You cannot provide both :sourceId and :source_id' if attributes.key?(:'sourceId') && attributes.key?(:'source_id')

  self.source_id = attributes[:'source_id'] if attributes[:'source_id']

  self.name = attributes[:'name'] if attributes[:'name']

  self.is_secure_content = attributes[:'isSecureContent'] unless attributes[:'isSecureContent'].nil?

  raise 'You cannot provide both :isSecureContent and :is_secure_content' if attributes.key?(:'isSecureContent') && attributes.key?(:'is_secure_content')

  self.is_secure_content = attributes[:'is_secure_content'] unless attributes[:'is_secure_content'].nil?

  self.is_system = attributes[:'isSystem'] unless attributes[:'isSystem'].nil?

  raise 'You cannot provide both :isSystem and :is_system' if attributes.key?(:'isSystem') && attributes.key?(:'is_system')

  self.is_system = attributes[:'is_system'] unless attributes[:'is_system'].nil?

  self.parsers = attributes[:'parsers'] if attributes[:'parsers']

  self.rule_id = attributes[:'ruleId'] if attributes[:'ruleId']

  raise 'You cannot provide both :ruleId and :rule_id' if attributes.key?(:'ruleId') && attributes.key?(:'rule_id')

  self.rule_id = attributes[:'rule_id'] if attributes[:'rule_id']

  self.type_name = attributes[:'typeName'] if attributes[:'typeName']

  raise 'You cannot provide both :typeName and :type_name' if attributes.key?(:'typeName') && attributes.key?(:'type_name')

  self.type_name = attributes[:'type_name'] if attributes[:'type_name']

  self.warning_config = attributes[:'warningConfig'] if attributes[:'warningConfig']

  raise 'You cannot provide both :warningConfig and :warning_config' if attributes.key?(:'warningConfig') && attributes.key?(:'warning_config')

  self.warning_config = attributes[:'warning_config'] if attributes[:'warning_config']

  self. = attributes[:'metadataFields'] if attributes[:'metadataFields']

  raise 'You cannot provide both :metadataFields and :metadata_fields' if attributes.key?(:'metadataFields') && attributes.key?(:'metadata_fields')

  self. = attributes[:'metadata_fields'] if attributes[:'metadata_fields']

  self.label_definitions = attributes[:'labelDefinitions'] if attributes[:'labelDefinitions']

  raise 'You cannot provide both :labelDefinitions and :label_definitions' if attributes.key?(:'labelDefinitions') && attributes.key?(:'label_definitions')

  self.label_definitions = attributes[:'label_definitions'] if attributes[:'label_definitions']

  self.entity_types = attributes[:'entityTypes'] if attributes[:'entityTypes']

  raise 'You cannot provide both :entityTypes and :entity_types' if attributes.key?(:'entityTypes') && attributes.key?(:'entity_types')

  self.entity_types = attributes[:'entity_types'] if attributes[:'entity_types']

  self.is_timezone_override = attributes[:'isTimezoneOverride'] unless attributes[:'isTimezoneOverride'].nil?

  raise 'You cannot provide both :isTimezoneOverride and :is_timezone_override' if attributes.key?(:'isTimezoneOverride') && attributes.key?(:'is_timezone_override')

  self.is_timezone_override = attributes[:'is_timezone_override'] unless attributes[:'is_timezone_override'].nil?

  self.user_parsers = attributes[:'userParsers'] if attributes[:'userParsers']

  raise 'You cannot provide both :userParsers and :user_parsers' if attributes.key?(:'userParsers') && attributes.key?(:'user_parsers')

  self.user_parsers = attributes[:'user_parsers'] if attributes[:'user_parsers']

  self.categories = attributes[:'categories'] if attributes[:'categories']
end

Instance Attribute Details

#categoriesArray<OCI::LogAnalytics::Models::LogAnalyticsCategory>

An array of categories to assign to the source. Specifying the name attribute for each category would suffice. Oracle-defined category assignments cannot be removed.



131
132
133
# File 'lib/oci/log_analytics/models/upsert_log_analytics_source_details.rb', line 131

def categories
  @categories
end

#data_filter_definitionsArray<OCI::LogAnalytics::Models::LogAnalyticsSourceDataFilter>

An array of data filter definitions.



16
17
18
# File 'lib/oci/log_analytics/models/upsert_log_analytics_source_details.rb', line 16

def data_filter_definitions
  @data_filter_definitions
end

#database_credentialString

The database credential name.

Returns:

  • (String)


20
21
22
# File 'lib/oci/log_analytics/models/upsert_log_analytics_source_details.rb', line 20

def database_credential
  @database_credential
end

#descriptionString

The source description.

Returns:

  • (String)


57
58
59
# File 'lib/oci/log_analytics/models/upsert_log_analytics_source_details.rb', line 57

def description
  @description
end

#display_nameString

The source display name.

Returns:

  • (String)


61
62
63
# File 'lib/oci/log_analytics/models/upsert_log_analytics_source_details.rb', line 61

def display_name
  @display_name
end

#edit_versionInteger

The source edit version.

Returns:

  • (Integer)


65
66
67
# File 'lib/oci/log_analytics/models/upsert_log_analytics_source_details.rb', line 65

def edit_version
  @edit_version
end

#entity_typesArray<OCI::LogAnalytics::Models::LogAnalyticsSourceEntityType>

An array of entity types.



116
117
118
# File 'lib/oci/log_analytics/models/upsert_log_analytics_source_details.rb', line 116

def entity_types
  @entity_types
end

#extended_field_definitionsArray<OCI::LogAnalytics::Models::LogAnalyticsSourceExtendedFieldDefinition>

An array of extended field definitions.



24
25
26
# File 'lib/oci/log_analytics/models/upsert_log_analytics_source_details.rb', line 24

def extended_field_definitions
  @extended_field_definitions
end

#functionsArray<OCI::LogAnalytics::Models::LogAnalyticsSourceFunction>

An array of source functions.



69
70
71
# File 'lib/oci/log_analytics/models/upsert_log_analytics_source_details.rb', line 69

def functions
  @functions
end

#is_for_cloudBOOLEAN

A flag indicating whether or not this is a cloud source.

Returns:

  • (BOOLEAN)


29
30
31
# File 'lib/oci/log_analytics/models/upsert_log_analytics_source_details.rb', line 29

def is_for_cloud
  @is_for_cloud
end

#is_secure_contentBOOLEAN

A flag indicating whether or not the source content is secure.

Returns:

  • (BOOLEAN)


82
83
84
# File 'lib/oci/log_analytics/models/upsert_log_analytics_source_details.rb', line 82

def is_secure_content
  @is_secure_content
end

#is_systemBOOLEAN

The system flag. A value of false denotes a custom, or user defined object. A value of true denotes a built in object.

Returns:

  • (BOOLEAN)


88
89
90
# File 'lib/oci/log_analytics/models/upsert_log_analytics_source_details.rb', line 88

def is_system
  @is_system
end

#is_timezone_overrideBOOLEAN

A flag indicating whether or not the source has a time zone override.

Returns:

  • (BOOLEAN)


121
122
123
# File 'lib/oci/log_analytics/models/upsert_log_analytics_source_details.rb', line 121

def is_timezone_override
  @is_timezone_override
end

#label_conditionsArray<OCI::LogAnalytics::Models::LogAnalyticsSourceLabelCondition>

An array of source label conditions.



12
13
14
# File 'lib/oci/log_analytics/models/upsert_log_analytics_source_details.rb', line 12

def label_conditions
  @label_conditions
end

#label_definitionsArray<OCI::LogAnalytics::Models::LogAnalyticsLabelDefinition>

An array of labels.



112
113
114
# File 'lib/oci/log_analytics/models/upsert_log_analytics_source_details.rb', line 112

def label_definitions
  @label_definitions
end

#labelsArray<OCI::LogAnalytics::Models::LogAnalyticsLabelView>

An array of labels.



33
34
35
# File 'lib/oci/log_analytics/models/upsert_log_analytics_source_details.rb', line 33

def labels
  @labels
end

#metadata_fieldsArray<OCI::LogAnalytics::Models::LogAnalyticsSourceMetadataField>

An array of source metadata fields.



108
109
110
# File 'lib/oci/log_analytics/models/upsert_log_analytics_source_details.rb', line 108

def 
  @metadata_fields
end

#metric_definitionsArray<OCI::LogAnalytics::Models::LogAnalyticsMetric>

An array of metric definitions.



37
38
39
# File 'lib/oci/log_analytics/models/upsert_log_analytics_source_details.rb', line 37

def metric_definitions
  @metric_definitions
end

#metricsArray<OCI::LogAnalytics::Models::LogAnalyticsSourceMetric>

An array of metrics.



41
42
43
# File 'lib/oci/log_analytics/models/upsert_log_analytics_source_details.rb', line 41

def metrics
  @metrics
end

#nameString

The source internal name.

Returns:

  • (String)


77
78
79
# File 'lib/oci/log_analytics/models/upsert_log_analytics_source_details.rb', line 77

def name
  @name
end

#oob_parsersArray<OCI::LogAnalytics::Models::LogAnalyticsParser>

An array of built in source parsers.



45
46
47
# File 'lib/oci/log_analytics/models/upsert_log_analytics_source_details.rb', line 45

def oob_parsers
  @oob_parsers
end

#parametersArray<OCI::LogAnalytics::Models::LogAnalyticsParameter>

An array of parameters.



49
50
51
# File 'lib/oci/log_analytics/models/upsert_log_analytics_source_details.rb', line 49

def parameters
  @parameters
end

#parsersArray<OCI::LogAnalytics::Models::LogAnalyticsParser>

An array of parser.



92
93
94
# File 'lib/oci/log_analytics/models/upsert_log_analytics_source_details.rb', line 92

def parsers
  @parsers
end

#patternsArray<OCI::LogAnalytics::Models::LogAnalyticsSourcePattern>

An array of patterns.



53
54
55
# File 'lib/oci/log_analytics/models/upsert_log_analytics_source_details.rb', line 53

def patterns
  @patterns
end

#rule_idInteger

The rule unique identifier.

Returns:

  • (Integer)


96
97
98
# File 'lib/oci/log_analytics/models/upsert_log_analytics_source_details.rb', line 96

def rule_id
  @rule_id
end

#source_idInteger

The source unique identifier.

Returns:

  • (Integer)


73
74
75
# File 'lib/oci/log_analytics/models/upsert_log_analytics_source_details.rb', line 73

def source_id
  @source_id
end

#type_nameString

The source type internal name.

Returns:

  • (String)


100
101
102
# File 'lib/oci/log_analytics/models/upsert_log_analytics_source_details.rb', line 100

def type_name
  @type_name
end

#user_parsersArray<OCI::LogAnalytics::Models::LogAnalyticsParser>

An array of custom parsers.



125
126
127
# File 'lib/oci/log_analytics/models/upsert_log_analytics_source_details.rb', line 125

def user_parsers
  @user_parsers
end

#warning_configInteger

The source warning configuration.

Returns:

  • (Integer)


104
105
106
# File 'lib/oci/log_analytics/models/upsert_log_analytics_source_details.rb', line 104

def warning_config
  @warning_config
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
# File 'lib/oci/log_analytics/models/upsert_log_analytics_source_details.rb', line 134

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'label_conditions': :'labelConditions',
    'data_filter_definitions': :'dataFilterDefinitions',
    'database_credential': :'databaseCredential',
    'extended_field_definitions': :'extendedFieldDefinitions',
    'is_for_cloud': :'isForCloud',
    'labels': :'labels',
    'metric_definitions': :'metricDefinitions',
    'metrics': :'metrics',
    'oob_parsers': :'oobParsers',
    'parameters': :'parameters',
    'patterns': :'patterns',
    'description': :'description',
    'display_name': :'displayName',
    'edit_version': :'editVersion',
    'functions': :'functions',
    'source_id': :'sourceId',
    'name': :'name',
    'is_secure_content': :'isSecureContent',
    'is_system': :'isSystem',
    'parsers': :'parsers',
    'rule_id': :'ruleId',
    'type_name': :'typeName',
    'warning_config': :'warningConfig',
    'metadata_fields': :'metadataFields',
    'label_definitions': :'labelDefinitions',
    'entity_types': :'entityTypes',
    'is_timezone_override': :'isTimezoneOverride',
    'user_parsers': :'userParsers',
    'categories': :'categories'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/oci/log_analytics/models/upsert_log_analytics_source_details.rb', line 171

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'label_conditions': :'Array<OCI::LogAnalytics::Models::LogAnalyticsSourceLabelCondition>',
    'data_filter_definitions': :'Array<OCI::LogAnalytics::Models::LogAnalyticsSourceDataFilter>',
    'database_credential': :'String',
    'extended_field_definitions': :'Array<OCI::LogAnalytics::Models::LogAnalyticsSourceExtendedFieldDefinition>',
    'is_for_cloud': :'BOOLEAN',
    'labels': :'Array<OCI::LogAnalytics::Models::LogAnalyticsLabelView>',
    'metric_definitions': :'Array<OCI::LogAnalytics::Models::LogAnalyticsMetric>',
    'metrics': :'Array<OCI::LogAnalytics::Models::LogAnalyticsSourceMetric>',
    'oob_parsers': :'Array<OCI::LogAnalytics::Models::LogAnalyticsParser>',
    'parameters': :'Array<OCI::LogAnalytics::Models::LogAnalyticsParameter>',
    'patterns': :'Array<OCI::LogAnalytics::Models::LogAnalyticsSourcePattern>',
    'description': :'String',
    'display_name': :'String',
    'edit_version': :'Integer',
    'functions': :'Array<OCI::LogAnalytics::Models::LogAnalyticsSourceFunction>',
    'source_id': :'Integer',
    'name': :'String',
    'is_secure_content': :'BOOLEAN',
    'is_system': :'BOOLEAN',
    'parsers': :'Array<OCI::LogAnalytics::Models::LogAnalyticsParser>',
    'rule_id': :'Integer',
    'type_name': :'String',
    'warning_config': :'Integer',
    'metadata_fields': :'Array<OCI::LogAnalytics::Models::LogAnalyticsSourceMetadataField>',
    'label_definitions': :'Array<OCI::LogAnalytics::Models::LogAnalyticsLabelDefinition>',
    'entity_types': :'Array<OCI::LogAnalytics::Models::LogAnalyticsSourceEntityType>',
    'is_timezone_override': :'BOOLEAN',
    'user_parsers': :'Array<OCI::LogAnalytics::Models::LogAnalyticsParser>',
    'categories': :'Array<OCI::LogAnalytics::Models::LogAnalyticsCategory>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
# File 'lib/oci/log_analytics/models/upsert_log_analytics_source_details.rb', line 394

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    label_conditions == other.label_conditions &&
    data_filter_definitions == other.data_filter_definitions &&
    database_credential == other.database_credential &&
    extended_field_definitions == other.extended_field_definitions &&
    is_for_cloud == other.is_for_cloud &&
    labels == other.labels &&
    metric_definitions == other.metric_definitions &&
    metrics == other.metrics &&
    oob_parsers == other.oob_parsers &&
    parameters == other.parameters &&
    patterns == other.patterns &&
    description == other.description &&
    display_name == other.display_name &&
    edit_version == other.edit_version &&
    functions == other.functions &&
    source_id == other.source_id &&
    name == other.name &&
    is_secure_content == other.is_secure_content &&
    is_system == other.is_system &&
    parsers == other.parsers &&
    rule_id == other.rule_id &&
    type_name == other.type_name &&
    warning_config == other.warning_config &&
     == other. &&
    label_definitions == other.label_definitions &&
    entity_types == other.entity_types &&
    is_timezone_override == other.is_timezone_override &&
    user_parsers == other.user_parsers &&
    categories == other.categories
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
# File 'lib/oci/log_analytics/models/upsert_log_analytics_source_details.rb', line 452

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


432
433
434
# File 'lib/oci/log_analytics/models/upsert_log_analytics_source_details.rb', line 432

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



441
442
443
# File 'lib/oci/log_analytics/models/upsert_log_analytics_source_details.rb', line 441

def hash
  [label_conditions, data_filter_definitions, database_credential, extended_field_definitions, is_for_cloud, labels, metric_definitions, metrics, oob_parsers, parameters, patterns, description, display_name, edit_version, functions, source_id, name, is_secure_content, is_system, parsers, rule_id, type_name, warning_config, , label_definitions, entity_types, is_timezone_override, user_parsers, categories].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



485
486
487
488
489
490
491
492
493
494
# File 'lib/oci/log_analytics/models/upsert_log_analytics_source_details.rb', line 485

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



479
480
481
# File 'lib/oci/log_analytics/models/upsert_log_analytics_source_details.rb', line 479

def to_s
  to_hash.to_s
end