Class: OCI::LogAnalytics::Models::Violation
- Inherits:
-
Object
- Object
- OCI::LogAnalytics::Models::Violation
- Defined in:
- lib/oci/log_analytics/models/violation.rb
Overview
Violation
Constant Summary collapse
- RULE_TYPE_ENUM =
[ RULE_TYPE_WARN = 'WARN'.freeze, RULE_TYPE_ERROR = 'ERROR'.freeze, RULE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#indexes ⇒ Array<OCI::LogAnalytics::Models::Indexes>
The indices associated with regular expression violations.
-
#rule_description ⇒ String
The rule description.
-
#rule_name ⇒ String
The rule name.
-
#rule_remediation ⇒ String
The rule remediation.
-
#rule_type ⇒ String
The rule type.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Violation
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Violation
Initializes the object
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/oci/log_analytics/models/violation.rb', line 74 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.indexes = attributes[:'indexes'] if attributes[:'indexes'] self.rule_description = attributes[:'ruleDescription'] if attributes[:'ruleDescription'] raise 'You cannot provide both :ruleDescription and :rule_description' if attributes.key?(:'ruleDescription') && attributes.key?(:'rule_description') self.rule_description = attributes[:'rule_description'] if attributes[:'rule_description'] self.rule_name = attributes[:'ruleName'] if attributes[:'ruleName'] raise 'You cannot provide both :ruleName and :rule_name' if attributes.key?(:'ruleName') && attributes.key?(:'rule_name') self.rule_name = attributes[:'rule_name'] if attributes[:'rule_name'] self.rule_remediation = attributes[:'ruleRemediation'] if attributes[:'ruleRemediation'] raise 'You cannot provide both :ruleRemediation and :rule_remediation' if attributes.key?(:'ruleRemediation') && attributes.key?(:'rule_remediation') self.rule_remediation = attributes[:'rule_remediation'] if attributes[:'rule_remediation'] self.rule_type = attributes[:'ruleType'] if attributes[:'ruleType'] raise 'You cannot provide both :ruleType and :rule_type' if attributes.key?(:'ruleType') && attributes.key?(:'rule_type') self.rule_type = attributes[:'rule_type'] if attributes[:'rule_type'] end |
Instance Attribute Details
#indexes ⇒ Array<OCI::LogAnalytics::Models::Indexes>
The indices associated with regular expression violations.
19 20 21 |
# File 'lib/oci/log_analytics/models/violation.rb', line 19 def indexes @indexes end |
#rule_description ⇒ String
The rule description.
23 24 25 |
# File 'lib/oci/log_analytics/models/violation.rb', line 23 def rule_description @rule_description end |
#rule_name ⇒ String
The rule name.
27 28 29 |
# File 'lib/oci/log_analytics/models/violation.rb', line 27 def rule_name @rule_name end |
#rule_remediation ⇒ String
The rule remediation.
31 32 33 |
# File 'lib/oci/log_analytics/models/violation.rb', line 31 def rule_remediation @rule_remediation end |
#rule_type ⇒ String
The rule type. Either WARN or ERROR.
35 36 37 |
# File 'lib/oci/log_analytics/models/violation.rb', line 35 def rule_type @rule_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
38 39 40 41 42 43 44 45 46 47 48 |
# File 'lib/oci/log_analytics/models/violation.rb', line 38 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'indexes': :'indexes', 'rule_description': :'ruleDescription', 'rule_name': :'ruleName', 'rule_remediation': :'ruleRemediation', 'rule_type': :'ruleType' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/oci/log_analytics/models/violation.rb', line 51 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'indexes': :'Array<OCI::LogAnalytics::Models::Indexes>', 'rule_description': :'String', 'rule_name': :'String', 'rule_remediation': :'String', 'rule_type': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
127 128 129 130 131 132 133 134 135 136 |
# File 'lib/oci/log_analytics/models/violation.rb', line 127 def ==(other) return true if equal?(other) self.class == other.class && indexes == other.indexes && rule_description == other.rule_description && rule_name == other.rule_name && rule_remediation == other.rule_remediation && rule_type == other.rule_type end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/oci/log_analytics/models/violation.rb', line 161 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
141 142 143 |
# File 'lib/oci/log_analytics/models/violation.rb', line 141 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
150 151 152 |
# File 'lib/oci/log_analytics/models/violation.rb', line 150 def hash [indexes, rule_description, rule_name, rule_remediation, rule_type].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
194 195 196 197 198 199 200 201 202 203 |
# File 'lib/oci/log_analytics/models/violation.rb', line 194 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
188 189 190 |
# File 'lib/oci/log_analytics/models/violation.rb', line 188 def to_s to_hash.to_s end |