Class: OCI::LogAnalytics::Models::WorkRequestSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/log_analytics/models/work_request_summary.rb

Overview

High level summary of control plane job work request.

Constant Summary collapse

STATUS_ENUM =
[
  STATUS_ACCEPTED = 'ACCEPTED'.freeze,
  STATUS_CANCELED = 'CANCELED'.freeze,
  STATUS_FAILED = 'FAILED'.freeze,
  STATUS_IN_PROGRESS = 'IN_PROGRESS'.freeze,
  STATUS_SUCCEEDED = 'SUCCEEDED'.freeze,
  STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ WorkRequestSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :time_started (DateTime)

    The value to assign to the #time_started property

  • :time_accepted (DateTime)

    The value to assign to the #time_accepted property

  • :time_finished (DateTime)

    The value to assign to the #time_finished property

  • :percent_complete (Integer)

    The value to assign to the #percent_complete property

  • :status (String)

    The value to assign to the #status property



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/oci/log_analytics/models/work_request_summary.rb', line 96

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.time_started = attributes[:'timeStarted'] if attributes[:'timeStarted']

  raise 'You cannot provide both :timeStarted and :time_started' if attributes.key?(:'timeStarted') && attributes.key?(:'time_started')

  self.time_started = attributes[:'time_started'] if attributes[:'time_started']

  self.time_accepted = attributes[:'timeAccepted'] if attributes[:'timeAccepted']

  raise 'You cannot provide both :timeAccepted and :time_accepted' if attributes.key?(:'timeAccepted') && attributes.key?(:'time_accepted')

  self.time_accepted = attributes[:'time_accepted'] if attributes[:'time_accepted']

  self.time_finished = attributes[:'timeFinished'] if attributes[:'timeFinished']

  raise 'You cannot provide both :timeFinished and :time_finished' if attributes.key?(:'timeFinished') && attributes.key?(:'time_finished')

  self.time_finished = attributes[:'time_finished'] if attributes[:'time_finished']

  self.percent_complete = attributes[:'percentComplete'] if attributes[:'percentComplete']

  raise 'You cannot provide both :percentComplete and :percent_complete' if attributes.key?(:'percentComplete') && attributes.key?(:'percent_complete')

  self.percent_complete = attributes[:'percent_complete'] if attributes[:'percent_complete']

  self.status = attributes[:'status'] if attributes[:'status']
end

Instance Attribute Details

#compartment_idString

Returns:

  • (String)


28
29
30
# File 'lib/oci/log_analytics/models/work_request_summary.rb', line 28

def compartment_id
  @compartment_id
end

#idString

[Required] Unique OCID identifier to reference this query job work Request.

Returns:

  • (String)


24
25
26
# File 'lib/oci/log_analytics/models/work_request_summary.rb', line 24

def id
  @id
end

#percent_completeInteger

Percentage progress completion of the query.

Returns:

  • (Integer)


46
47
48
# File 'lib/oci/log_analytics/models/work_request_summary.rb', line 46

def percent_complete
  @percent_complete
end

#statusString

Work request status.

Returns:

  • (String)


51
52
53
# File 'lib/oci/log_analytics/models/work_request_summary.rb', line 51

def status
  @status
end

#time_acceptedDateTime

When the work request was accepted. Should match timeStarted in all cases.

Returns:

  • (DateTime)


37
38
39
# File 'lib/oci/log_analytics/models/work_request_summary.rb', line 37

def time_accepted
  @time_accepted
end

#time_finishedDateTime

When the work request finished execution.

Returns:

  • (DateTime)


41
42
43
# File 'lib/oci/log_analytics/models/work_request_summary.rb', line 41

def time_finished
  @time_finished
end

#time_startedDateTime

[Required] When the work request started.

Returns:

  • (DateTime)


32
33
34
# File 'lib/oci/log_analytics/models/work_request_summary.rb', line 32

def time_started
  @time_started
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/oci/log_analytics/models/work_request_summary.rb', line 54

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'compartment_id': :'compartmentId',
    'time_started': :'timeStarted',
    'time_accepted': :'timeAccepted',
    'time_finished': :'timeFinished',
    'percent_complete': :'percentComplete',
    'status': :'status'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/oci/log_analytics/models/work_request_summary.rb', line 69

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'compartment_id': :'String',
    'time_started': :'DateTime',
    'time_accepted': :'DateTime',
    'time_finished': :'DateTime',
    'percent_complete': :'Integer',
    'status': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



157
158
159
160
161
162
163
164
165
166
167
168
# File 'lib/oci/log_analytics/models/work_request_summary.rb', line 157

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    time_started == other.time_started &&
    time_accepted == other.time_accepted &&
    time_finished == other.time_finished &&
    percent_complete == other.percent_complete &&
    status == other.status
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/oci/log_analytics/models/work_request_summary.rb', line 193

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


173
174
175
# File 'lib/oci/log_analytics/models/work_request_summary.rb', line 173

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



182
183
184
# File 'lib/oci/log_analytics/models/work_request_summary.rb', line 182

def hash
  [id, compartment_id, time_started, time_accepted, time_finished, percent_complete, status].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



226
227
228
229
230
231
232
233
234
235
# File 'lib/oci/log_analytics/models/work_request_summary.rb', line 226

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



220
221
222
# File 'lib/oci/log_analytics/models/work_request_summary.rb', line 220

def to_s
  to_hash.to_s
end