Class: OCI::Logging::Models::CreateLogDetails
- Inherits:
-
Object
- Object
- OCI::Logging::Models::CreateLogDetails
- Defined in:
- lib/oci/logging/models/create_log_details.rb
Overview
The details to create a log object.
Constant Summary collapse
- LOG_TYPE_ENUM =
[ LOG_TYPE_CUSTOM = 'CUSTOM'.freeze, LOG_TYPE_SERVICE = 'SERVICE'.freeze ].freeze
Instance Attribute Summary collapse
- #configuration ⇒ OCI::Logging::Models::Configuration
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
[Required] The user-friendly display name.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#is_enabled ⇒ BOOLEAN
Whether or not this resource is currently enabled.
-
#log_type ⇒ String
[Required] The logType that the log object is for, whether custom or service.
-
#retention_duration ⇒ Integer
Log retention duration in 30-day increments (30, 60, 90 and so on).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateLogDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateLogDetails
Initializes the object
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/oci/logging/models/create_log_details.rb', line 94 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.log_type = attributes[:'logType'] if attributes[:'logType'] self.log_type = "CUSTOM" if log_type.nil? && !attributes.key?(:'logType') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :logType and :log_type' if attributes.key?(:'logType') && attributes.key?(:'log_type') self.log_type = attributes[:'log_type'] if attributes[:'log_type'] self.log_type = "CUSTOM" if log_type.nil? && !attributes.key?(:'logType') && !attributes.key?(:'log_type') # rubocop:disable Style/StringLiterals self.is_enabled = attributes[:'isEnabled'] unless attributes[:'isEnabled'].nil? self.is_enabled = true if is_enabled.nil? && !attributes.key?(:'isEnabled') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isEnabled and :is_enabled' if attributes.key?(:'isEnabled') && attributes.key?(:'is_enabled') self.is_enabled = attributes[:'is_enabled'] unless attributes[:'is_enabled'].nil? self.is_enabled = true if is_enabled.nil? && !attributes.key?(:'isEnabled') && !attributes.key?(:'is_enabled') # rubocop:disable Style/StringLiterals self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.configuration = attributes[:'configuration'] if attributes[:'configuration'] self.retention_duration = attributes[:'retentionDuration'] if attributes[:'retentionDuration'] raise 'You cannot provide both :retentionDuration and :retention_duration' if attributes.key?(:'retentionDuration') && attributes.key?(:'retention_duration') self.retention_duration = attributes[:'retention_duration'] if attributes[:'retention_duration'] end |
Instance Attribute Details
#configuration ⇒ OCI::Logging::Models::Configuration
45 46 47 |
# File 'lib/oci/logging/models/create_log_details.rb', line 45 def configuration @configuration end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
35 36 37 |
# File 'lib/oci/logging/models/create_log_details.rb', line 35 def end |
#display_name ⇒ String
[Required] The user-friendly display name. This must be unique within the enclosing resource, and it’s changeable. Avoid entering confidential information.
19 20 21 |
# File 'lib/oci/logging/models/create_log_details.rb', line 19 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"Finance"`
42 43 44 |
# File 'lib/oci/logging/models/create_log_details.rb', line 42 def end |
#is_enabled ⇒ BOOLEAN
Whether or not this resource is currently enabled.
27 28 29 |
# File 'lib/oci/logging/models/create_log_details.rb', line 27 def is_enabled @is_enabled end |
#log_type ⇒ String
[Required] The logType that the log object is for, whether custom or service.
23 24 25 |
# File 'lib/oci/logging/models/create_log_details.rb', line 23 def log_type @log_type end |
#retention_duration ⇒ Integer
Log retention duration in 30-day increments (30, 60, 90 and so on).
49 50 51 |
# File 'lib/oci/logging/models/create_log_details.rb', line 49 def retention_duration @retention_duration end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/oci/logging/models/create_log_details.rb', line 52 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'log_type': :'logType', 'is_enabled': :'isEnabled', 'defined_tags': :'definedTags', 'freeform_tags': :'freeformTags', 'configuration': :'configuration', 'retention_duration': :'retentionDuration' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/oci/logging/models/create_log_details.rb', line 67 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'log_type': :'String', 'is_enabled': :'BOOLEAN', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'freeform_tags': :'Hash<String, String>', 'configuration': :'OCI::Logging::Models::Configuration', 'retention_duration': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/oci/logging/models/create_log_details.rb', line 158 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && log_type == other.log_type && is_enabled == other.is_enabled && == other. && == other. && configuration == other.configuration && retention_duration == other.retention_duration end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/oci/logging/models/create_log_details.rb', line 194 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
174 175 176 |
# File 'lib/oci/logging/models/create_log_details.rb', line 174 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
183 184 185 |
# File 'lib/oci/logging/models/create_log_details.rb', line 183 def hash [display_name, log_type, is_enabled, , , configuration, retention_duration].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
227 228 229 230 231 232 233 234 235 236 |
# File 'lib/oci/logging/models/create_log_details.rb', line 227 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
221 222 223 |
# File 'lib/oci/logging/models/create_log_details.rb', line 221 def to_s to_hash.to_s end |