Class: OCI::Logging::Models::CreateLogSavedSearchDetails
- Inherits:
-
Object
- Object
- OCI::Logging::Models::CreateLogSavedSearchDetails
- Defined in:
- lib/oci/logging/models/create_log_saved_search_details.rb
Overview
A log saved search that can be used to save and share a given search result.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The OCID of the compartment that the resource belongs to.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
Description for this resource.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#name ⇒ String
[Required] The user-friendly display name.
-
#query ⇒ String
[Required] The search query that is saved.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateLogSavedSearchDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateLogSavedSearchDetails
Initializes the object
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/oci/logging/models/create_log_saved_search_details.rb', line 85 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.query = attributes[:'query'] if attributes[:'query'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The OCID of the compartment that the resource belongs to.
13 14 15 |
# File 'lib/oci/logging/models/create_log_saved_search_details.rb', line 13 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
36 37 38 |
# File 'lib/oci/logging/models/create_log_saved_search_details.rb', line 36 def end |
#description ⇒ String
Description for this resource.
23 24 25 |
# File 'lib/oci/logging/models/create_log_saved_search_details.rb', line 23 def description @description end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"Finance"`
43 44 45 |
# File 'lib/oci/logging/models/create_log_saved_search_details.rb', line 43 def end |
#name ⇒ String
[Required] The user-friendly display name. This must be unique within the enclosing resource, and it’s changeable. Avoid entering confidential information.
19 20 21 |
# File 'lib/oci/logging/models/create_log_saved_search_details.rb', line 19 def name @name end |
#query ⇒ String
[Required] The search query that is saved.
28 29 30 |
# File 'lib/oci/logging/models/create_log_saved_search_details.rb', line 28 def query @query end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/oci/logging/models/create_log_saved_search_details.rb', line 46 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'name': :'name', 'description': :'description', 'query': :'query', 'defined_tags': :'definedTags', 'freeform_tags': :'freeformTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/oci/logging/models/create_log_saved_search_details.rb', line 60 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'name': :'String', 'description': :'String', 'query': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'freeform_tags': :'Hash<String, String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/oci/logging/models/create_log_saved_search_details.rb', line 123 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && name == other.name && description == other.description && query == other.query && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/oci/logging/models/create_log_saved_search_details.rb', line 158 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
138 139 140 |
# File 'lib/oci/logging/models/create_log_saved_search_details.rb', line 138 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
147 148 149 |
# File 'lib/oci/logging/models/create_log_saved_search_details.rb', line 147 def hash [compartment_id, name, description, query, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
191 192 193 194 195 196 197 198 199 200 |
# File 'lib/oci/logging/models/create_log_saved_search_details.rb', line 191 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
185 186 187 |
# File 'lib/oci/logging/models/create_log_saved_search_details.rb', line 185 def to_s to_hash.to_s end |