Class: OCI::Logging::Models::Log
- Inherits:
-
Object
- Object
- OCI::Logging::Models::Log
- Defined in:
- lib/oci/logging/models/log.rb
Overview
Represents a log object.
Constant Summary collapse
- LOG_TYPE_ENUM =
[ LOG_TYPE_CUSTOM = 'CUSTOM'.freeze, LOG_TYPE_SERVICE = 'SERVICE'.freeze, LOG_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
The OCID of the compartment that the resource belongs to.
- #configuration ⇒ OCI::Logging::Models::Configuration
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
[Required] The user-friendly display name.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] The OCID of the resource.
-
#is_enabled ⇒ BOOLEAN
Whether or not this resource is currently enabled.
-
#lifecycle_state ⇒ String
[Required] The pipeline state.
-
#log_group_id ⇒ String
[Required] Log group OCID.
-
#log_type ⇒ String
[Required] The logType that the log object is for, whether custom or service.
-
#retention_duration ⇒ Integer
Log retention duration in 30-day increments (30, 60, 90 and so on).
-
#tenancy_id ⇒ String
The OCID of the tenancy.
-
#time_created ⇒ DateTime
Time the resource was created.
-
#time_last_modified ⇒ DateTime
Time the resource was last modified.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Log
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Log
Initializes the object
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/oci/logging/models/log.rb', line 155 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.tenancy_id = attributes[:'tenancyId'] if attributes[:'tenancyId'] raise 'You cannot provide both :tenancyId and :tenancy_id' if attributes.key?(:'tenancyId') && attributes.key?(:'tenancy_id') self.tenancy_id = attributes[:'tenancy_id'] if attributes[:'tenancy_id'] self.log_group_id = attributes[:'logGroupId'] if attributes[:'logGroupId'] raise 'You cannot provide both :logGroupId and :log_group_id' if attributes.key?(:'logGroupId') && attributes.key?(:'log_group_id') self.log_group_id = attributes[:'log_group_id'] if attributes[:'log_group_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.log_type = attributes[:'logType'] if attributes[:'logType'] self.log_type = "CUSTOM" if log_type.nil? && !attributes.key?(:'logType') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :logType and :log_type' if attributes.key?(:'logType') && attributes.key?(:'log_type') self.log_type = attributes[:'log_type'] if attributes[:'log_type'] self.log_type = "CUSTOM" if log_type.nil? && !attributes.key?(:'logType') && !attributes.key?(:'log_type') # rubocop:disable Style/StringLiterals self.is_enabled = attributes[:'isEnabled'] unless attributes[:'isEnabled'].nil? self.is_enabled = true if is_enabled.nil? && !attributes.key?(:'isEnabled') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isEnabled and :is_enabled' if attributes.key?(:'isEnabled') && attributes.key?(:'is_enabled') self.is_enabled = attributes[:'is_enabled'] unless attributes[:'is_enabled'].nil? self.is_enabled = true if is_enabled.nil? && !attributes.key?(:'isEnabled') && !attributes.key?(:'is_enabled') # rubocop:disable Style/StringLiterals self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.configuration = attributes[:'configuration'] if attributes[:'configuration'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_last_modified = attributes[:'timeLastModified'] if attributes[:'timeLastModified'] raise 'You cannot provide both :timeLastModified and :time_last_modified' if attributes.key?(:'timeLastModified') && attributes.key?(:'time_last_modified') self.time_last_modified = attributes[:'time_last_modified'] if attributes[:'time_last_modified'] self.retention_duration = attributes[:'retentionDuration'] if attributes[:'retentionDuration'] raise 'You cannot provide both :retentionDuration and :retention_duration' if attributes.key?(:'retentionDuration') && attributes.key?(:'retention_duration') self.retention_duration = attributes[:'retention_duration'] if attributes[:'retention_duration'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] end |
Instance Attribute Details
#compartment_id ⇒ String
The OCID of the compartment that the resource belongs to.
89 90 91 |
# File 'lib/oci/logging/models/log.rb', line 89 def compartment_id @compartment_id end |
#configuration ⇒ OCI::Logging::Models::Configuration
69 70 71 |
# File 'lib/oci/logging/models/log.rb', line 69 def configuration @configuration end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
59 60 61 |
# File 'lib/oci/logging/models/log.rb', line 59 def end |
#display_name ⇒ String
[Required] The user-friendly display name. This must be unique within the enclosing resource, and it’s changeable. Avoid entering confidential information.
43 44 45 |
# File 'lib/oci/logging/models/log.rb', line 43 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"Finance"`
66 67 68 |
# File 'lib/oci/logging/models/log.rb', line 66 def end |
#id ⇒ String
[Required] The OCID of the resource.
29 30 31 |
# File 'lib/oci/logging/models/log.rb', line 29 def id @id end |
#is_enabled ⇒ BOOLEAN
Whether or not this resource is currently enabled.
51 52 53 |
# File 'lib/oci/logging/models/log.rb', line 51 def is_enabled @is_enabled end |
#lifecycle_state ⇒ String
[Required] The pipeline state.
73 74 75 |
# File 'lib/oci/logging/models/log.rb', line 73 def lifecycle_state @lifecycle_state end |
#log_group_id ⇒ String
[Required] Log group OCID.
37 38 39 |
# File 'lib/oci/logging/models/log.rb', line 37 def log_group_id @log_group_id end |
#log_type ⇒ String
[Required] The logType that the log object is for, whether custom or service.
47 48 49 |
# File 'lib/oci/logging/models/log.rb', line 47 def log_type @log_type end |
#retention_duration ⇒ Integer
Log retention duration in 30-day increments (30, 60, 90 and so on).
85 86 87 |
# File 'lib/oci/logging/models/log.rb', line 85 def retention_duration @retention_duration end |
#tenancy_id ⇒ String
The OCID of the tenancy.
33 34 35 |
# File 'lib/oci/logging/models/log.rb', line 33 def tenancy_id @tenancy_id end |
#time_created ⇒ DateTime
Time the resource was created.
77 78 79 |
# File 'lib/oci/logging/models/log.rb', line 77 def time_created @time_created end |
#time_last_modified ⇒ DateTime
Time the resource was last modified.
81 82 83 |
# File 'lib/oci/logging/models/log.rb', line 81 def time_last_modified @time_last_modified end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/oci/logging/models/log.rb', line 92 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'tenancy_id': :'tenancyId', 'log_group_id': :'logGroupId', 'display_name': :'displayName', 'log_type': :'logType', 'is_enabled': :'isEnabled', 'defined_tags': :'definedTags', 'freeform_tags': :'freeformTags', 'configuration': :'configuration', 'lifecycle_state': :'lifecycleState', 'time_created': :'timeCreated', 'time_last_modified': :'timeLastModified', 'retention_duration': :'retentionDuration', 'compartment_id': :'compartmentId' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/oci/logging/models/log.rb', line 114 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'tenancy_id': :'String', 'log_group_id': :'String', 'display_name': :'String', 'log_type': :'String', 'is_enabled': :'BOOLEAN', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'freeform_tags': :'Hash<String, String>', 'configuration': :'OCI::Logging::Models::Configuration', 'lifecycle_state': :'String', 'time_created': :'DateTime', 'time_last_modified': :'DateTime', 'retention_duration': :'Integer', 'compartment_id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'lib/oci/logging/models/log.rb', line 275 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && tenancy_id == other.tenancy_id && log_group_id == other.log_group_id && display_name == other.display_name && log_type == other.log_type && is_enabled == other.is_enabled && == other. && == other. && configuration == other.configuration && lifecycle_state == other.lifecycle_state && time_created == other.time_created && time_last_modified == other.time_last_modified && retention_duration == other.retention_duration && compartment_id == other.compartment_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 |
# File 'lib/oci/logging/models/log.rb', line 318 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
298 299 300 |
# File 'lib/oci/logging/models/log.rb', line 298 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
307 308 309 |
# File 'lib/oci/logging/models/log.rb', line 307 def hash [id, tenancy_id, log_group_id, display_name, log_type, is_enabled, , , configuration, lifecycle_state, time_created, time_last_modified, retention_duration, compartment_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
351 352 353 354 355 356 357 358 359 360 |
# File 'lib/oci/logging/models/log.rb', line 351 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
345 346 347 |
# File 'lib/oci/logging/models/log.rb', line 345 def to_s to_hash.to_s end |