Class: OCI::Logging::Models::LogGroup
- Inherits:
-
Object
- Object
- OCI::Logging::Models::LogGroup
- Defined in:
- lib/oci/logging/models/log_group.rb
Overview
Represents a LogGroup object.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The OCID of the compartment that the resource belongs to.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
Description for this resource.
-
#display_name ⇒ String
[Required] The user-friendly display name.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] The OCID of the resource.
-
#lifecycle_state ⇒ String
The log group object state.
-
#time_created ⇒ DateTime
Time the resource was created.
-
#time_last_modified ⇒ DateTime
Time the resource was last modified.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LogGroup
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ LogGroup
Initializes the object
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/oci/logging/models/log_group.rb', line 115 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_last_modified = attributes[:'timeLastModified'] if attributes[:'timeLastModified'] raise 'You cannot provide both :timeLastModified and :time_last_modified' if attributes.key?(:'timeLastModified') && attributes.key?(:'time_last_modified') self.time_last_modified = attributes[:'time_last_modified'] if attributes[:'time_last_modified'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The OCID of the compartment that the resource belongs to.
27 28 29 |
# File 'lib/oci/logging/models/log_group.rb', line 27 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
49 50 51 |
# File 'lib/oci/logging/models/log_group.rb', line 49 def end |
#description ⇒ String
Description for this resource.
37 38 39 |
# File 'lib/oci/logging/models/log_group.rb', line 37 def description @description end |
#display_name ⇒ String
[Required] The user-friendly display name. This must be unique within the enclosing resource, and it’s changeable. Avoid entering confidential information.
33 34 35 |
# File 'lib/oci/logging/models/log_group.rb', line 33 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"Finance"`
56 57 58 |
# File 'lib/oci/logging/models/log_group.rb', line 56 def end |
#id ⇒ String
[Required] The OCID of the resource.
23 24 25 |
# File 'lib/oci/logging/models/log_group.rb', line 23 def id @id end |
#lifecycle_state ⇒ String
The log group object state.
41 42 43 |
# File 'lib/oci/logging/models/log_group.rb', line 41 def lifecycle_state @lifecycle_state end |
#time_created ⇒ DateTime
Time the resource was created.
60 61 62 |
# File 'lib/oci/logging/models/log_group.rb', line 60 def time_created @time_created end |
#time_last_modified ⇒ DateTime
Time the resource was last modified.
64 65 66 |
# File 'lib/oci/logging/models/log_group.rb', line 64 def time_last_modified @time_last_modified end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/oci/logging/models/log_group.rb', line 67 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'description': :'description', 'lifecycle_state': :'lifecycleState', 'defined_tags': :'definedTags', 'freeform_tags': :'freeformTags', 'time_created': :'timeCreated', 'time_last_modified': :'timeLastModified' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/oci/logging/models/log_group.rb', line 84 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'display_name': :'String', 'description': :'String', 'lifecycle_state': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'freeform_tags': :'Hash<String, String>', 'time_created': :'DateTime', 'time_last_modified': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/oci/logging/models/log_group.rb', line 188 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && display_name == other.display_name && description == other.description && lifecycle_state == other.lifecycle_state && == other. && == other. && time_created == other.time_created && time_last_modified == other.time_last_modified end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/oci/logging/models/log_group.rb', line 226 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
206 207 208 |
# File 'lib/oci/logging/models/log_group.rb', line 206 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
215 216 217 |
# File 'lib/oci/logging/models/log_group.rb', line 215 def hash [id, compartment_id, display_name, description, lifecycle_state, , , time_created, time_last_modified].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
259 260 261 262 263 264 265 266 267 268 |
# File 'lib/oci/logging/models/log_group.rb', line 259 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
253 254 255 |
# File 'lib/oci/logging/models/log_group.rb', line 253 def to_s to_hash.to_s end |