Class: OCI::Logging::Models::LogSavedSearch

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/logging/models/log_saved_search.rb

Overview

A log saved search that can be used to save and share a given search result.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ LogSavedSearch

Initializes the object

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :name (String)

    The value to assign to the #name property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :time_last_modified (DateTime)

    The value to assign to the #time_last_modified property

  • :description (String)

    The value to assign to the #description property

  • :query (String)

    The value to assign to the #query property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property



125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/oci/logging/models/log_saved_search.rb', line 125

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.name = attributes[:'name'] if attributes[:'name']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_last_modified = attributes[:'timeLastModified'] if attributes[:'timeLastModified']

  raise 'You cannot provide both :timeLastModified and :time_last_modified' if attributes.key?(:'timeLastModified') && attributes.key?(:'time_last_modified')

  self.time_last_modified = attributes[:'time_last_modified'] if attributes[:'time_last_modified']

  self.description = attributes[:'description'] if attributes[:'description']

  self.query = attributes[:'query'] if attributes[:'query']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']
end

Instance Attribute Details

#compartment_idString

[Required] The OCID of the compartment that the resource belongs to.



28
29
30
# File 'lib/oci/logging/models/log_saved_search.rb', line 28

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: ‘{"CostCenter": "42"}`



59
60
61
# File 'lib/oci/logging/models/log_saved_search.rb', line 59

def defined_tags
  @defined_tags
end

#descriptionString

Description for this resource.



46
47
48
# File 'lib/oci/logging/models/log_saved_search.rb', line 46

def description
  @description
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"Finance"`



66
67
68
# File 'lib/oci/logging/models/log_saved_search.rb', line 66

def freeform_tags
  @freeform_tags
end

#idString

[Required] The OCID of the resource.



24
25
26
# File 'lib/oci/logging/models/log_saved_search.rb', line 24

def id
  @id
end

#lifecycle_stateString

The state of the LogSavedSearch



71
72
73
# File 'lib/oci/logging/models/log_saved_search.rb', line 71

def lifecycle_state
  @lifecycle_state
end

#nameString

[Required] The user-friendly display name. This must be unique within the enclosing resource, and it’s changeable. Avoid entering confidential information.



34
35
36
# File 'lib/oci/logging/models/log_saved_search.rb', line 34

def name
  @name
end

#queryString

[Required] The search query that is saved.



51
52
53
# File 'lib/oci/logging/models/log_saved_search.rb', line 51

def query
  @query
end

#time_createdDateTime

Time the resource was created.



38
39
40
# File 'lib/oci/logging/models/log_saved_search.rb', line 38

def time_created
  @time_created
end

#time_last_modifiedDateTime

Time the resource was last modified.



42
43
44
# File 'lib/oci/logging/models/log_saved_search.rb', line 42

def time_last_modified
  @time_last_modified
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/oci/logging/models/log_saved_search.rb', line 74

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'compartment_id': :'compartmentId',
    'name': :'name',
    'time_created': :'timeCreated',
    'time_last_modified': :'timeLastModified',
    'description': :'description',
    'query': :'query',
    'defined_tags': :'definedTags',
    'freeform_tags': :'freeformTags',
    'lifecycle_state': :'lifecycleState'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/oci/logging/models/log_saved_search.rb', line 92

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'compartment_id': :'String',
    'name': :'String',
    'time_created': :'DateTime',
    'time_last_modified': :'DateTime',
    'description': :'String',
    'query': :'String',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'freeform_tags': :'Hash<String, String>',
    'lifecycle_state': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.



196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/oci/logging/models/log_saved_search.rb', line 196

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    name == other.name &&
    time_created == other.time_created &&
    time_last_modified == other.time_last_modified &&
    description == other.description &&
    query == other.query &&
    defined_tags == other.defined_tags &&
    freeform_tags == other.freeform_tags &&
    lifecycle_state == other.lifecycle_state
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/oci/logging/models/log_saved_search.rb', line 235

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method


215
216
217
# File 'lib/oci/logging/models/log_saved_search.rb', line 215

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.



224
225
226
# File 'lib/oci/logging/models/log_saved_search.rb', line 224

def hash
  [id, compartment_id, name, time_created, time_last_modified, description, query, defined_tags, freeform_tags, lifecycle_state].hash
end

#to_hashHash

Returns the object in the form of hash



268
269
270
271
272
273
274
275
276
277
# File 'lib/oci/logging/models/log_saved_search.rb', line 268

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



262
263
264
# File 'lib/oci/logging/models/log_saved_search.rb', line 262

def to_s
  to_hash.to_s
end