Class: OCI::Logging::Models::UnifiedAgentConfiguration

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/logging/models/unified_agent_configuration.rb

Overview

Top Unified Agent configuration object.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
CONFIGURATION_STATE_ENUM =
[
  CONFIGURATION_STATE_VALID = 'VALID'.freeze,
  CONFIGURATION_STATE_INVALID = 'INVALID'.freeze,
  CONFIGURATION_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UnifiedAgentConfiguration

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/oci/logging/models/unified_agent_configuration.rb', line 149

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_last_modified = attributes[:'timeLastModified'] if attributes[:'timeLastModified']

  raise 'You cannot provide both :timeLastModified and :time_last_modified' if attributes.key?(:'timeLastModified') && attributes.key?(:'time_last_modified')

  self.time_last_modified = attributes[:'time_last_modified'] if attributes[:'time_last_modified']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.is_enabled = attributes[:'isEnabled'] unless attributes[:'isEnabled'].nil?
  self.is_enabled = true if is_enabled.nil? && !attributes.key?(:'isEnabled') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isEnabled and :is_enabled' if attributes.key?(:'isEnabled') && attributes.key?(:'is_enabled')

  self.is_enabled = attributes[:'is_enabled'] unless attributes[:'is_enabled'].nil?
  self.is_enabled = true if is_enabled.nil? && !attributes.key?(:'isEnabled') && !attributes.key?(:'is_enabled') # rubocop:disable Style/StringLiterals

  self.configuration_state = attributes[:'configurationState'] if attributes[:'configurationState']

  raise 'You cannot provide both :configurationState and :configuration_state' if attributes.key?(:'configurationState') && attributes.key?(:'configuration_state')

  self.configuration_state = attributes[:'configuration_state'] if attributes[:'configuration_state']

  self.service_configuration = attributes[:'serviceConfiguration'] if attributes[:'serviceConfiguration']

  raise 'You cannot provide both :serviceConfiguration and :service_configuration' if attributes.key?(:'serviceConfiguration') && attributes.key?(:'service_configuration')

  self.service_configuration = attributes[:'service_configuration'] if attributes[:'service_configuration']

  self.group_association = attributes[:'groupAssociation'] if attributes[:'groupAssociation']

  raise 'You cannot provide both :groupAssociation and :group_association' if attributes.key?(:'groupAssociation') && attributes.key?(:'group_association')

  self.group_association = attributes[:'group_association'] if attributes[:'group_association']
end

Instance Attribute Details

#compartment_idString

[Required] The OCID of the compartment that the resource belongs to.

Returns:

  • (String)


33
34
35
# File 'lib/oci/logging/models/unified_agent_configuration.rb', line 33

def compartment_id
  @compartment_id
end

#configuration_stateString

[Required] State of unified agent service configuration.

Returns:

  • (String)


78
79
80
# File 'lib/oci/logging/models/unified_agent_configuration.rb', line 78

def configuration_state
  @configuration_state
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: ‘{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


51
52
53
# File 'lib/oci/logging/models/unified_agent_configuration.rb', line 51

def defined_tags
  @defined_tags
end

#descriptionString

Description for this resource.

Returns:

  • (String)


43
44
45
# File 'lib/oci/logging/models/unified_agent_configuration.rb', line 43

def description
  @description
end

#display_nameString

[Required] The user-friendly display name. This must be unique within the enclosing resource, and it’s changeable. Avoid entering confidential information.

Returns:

  • (String)


39
40
41
# File 'lib/oci/logging/models/unified_agent_configuration.rb', line 39

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"Finance"`

Returns:

  • (Hash<String, String>)


58
59
60
# File 'lib/oci/logging/models/unified_agent_configuration.rb', line 58

def freeform_tags
  @freeform_tags
end

#group_associationOCI::Logging::Models::GroupAssociationDetails

This attribute is required.



86
87
88
# File 'lib/oci/logging/models/unified_agent_configuration.rb', line 86

def group_association
  @group_association
end

#idString

[Required] The OCID of the resource.

Returns:

  • (String)


29
30
31
# File 'lib/oci/logging/models/unified_agent_configuration.rb', line 29

def id
  @id
end

#is_enabledBOOLEAN

[Required] Whether or not this resource is currently enabled.

Returns:

  • (BOOLEAN)


74
75
76
# File 'lib/oci/logging/models/unified_agent_configuration.rb', line 74

def is_enabled
  @is_enabled
end

#lifecycle_stateString

[Required] The pipeline state.

Returns:

  • (String)


70
71
72
# File 'lib/oci/logging/models/unified_agent_configuration.rb', line 70

def lifecycle_state
  @lifecycle_state
end

#service_configurationOCI::Logging::Models::UnifiedAgentServiceConfigurationDetails

This attribute is required.



82
83
84
# File 'lib/oci/logging/models/unified_agent_configuration.rb', line 82

def service_configuration
  @service_configuration
end

#time_createdDateTime

Time the resource was created.

Returns:

  • (DateTime)


62
63
64
# File 'lib/oci/logging/models/unified_agent_configuration.rb', line 62

def time_created
  @time_created
end

#time_last_modifiedDateTime

Time the resource was last modified.

Returns:

  • (DateTime)


66
67
68
# File 'lib/oci/logging/models/unified_agent_configuration.rb', line 66

def time_last_modified
  @time_last_modified
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/oci/logging/models/unified_agent_configuration.rb', line 89

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'compartment_id': :'compartmentId',
    'display_name': :'displayName',
    'description': :'description',
    'defined_tags': :'definedTags',
    'freeform_tags': :'freeformTags',
    'time_created': :'timeCreated',
    'time_last_modified': :'timeLastModified',
    'lifecycle_state': :'lifecycleState',
    'is_enabled': :'isEnabled',
    'configuration_state': :'configurationState',
    'service_configuration': :'serviceConfiguration',
    'group_association': :'groupAssociation'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/oci/logging/models/unified_agent_configuration.rb', line 110

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'compartment_id': :'String',
    'display_name': :'String',
    'description': :'String',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'freeform_tags': :'Hash<String, String>',
    'time_created': :'DateTime',
    'time_last_modified': :'DateTime',
    'lifecycle_state': :'String',
    'is_enabled': :'BOOLEAN',
    'configuration_state': :'String',
    'service_configuration': :'OCI::Logging::Models::UnifiedAgentServiceConfigurationDetails',
    'group_association': :'OCI::Logging::Models::GroupAssociationDetails'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/oci/logging/models/unified_agent_configuration.rb', line 261

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    display_name == other.display_name &&
    description == other.description &&
    defined_tags == other.defined_tags &&
    freeform_tags == other.freeform_tags &&
    time_created == other.time_created &&
    time_last_modified == other.time_last_modified &&
    lifecycle_state == other.lifecycle_state &&
    is_enabled == other.is_enabled &&
    configuration_state == other.configuration_state &&
    service_configuration == other.service_configuration &&
    group_association == other.group_association
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
# File 'lib/oci/logging/models/unified_agent_configuration.rb', line 303

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


283
284
285
# File 'lib/oci/logging/models/unified_agent_configuration.rb', line 283

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



292
293
294
# File 'lib/oci/logging/models/unified_agent_configuration.rb', line 292

def hash
  [id, compartment_id, display_name, description, defined_tags, freeform_tags, time_created, time_last_modified, lifecycle_state, is_enabled, configuration_state, service_configuration, group_association].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



336
337
338
339
340
341
342
343
344
345
# File 'lib/oci/logging/models/unified_agent_configuration.rb', line 336

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



330
331
332
# File 'lib/oci/logging/models/unified_agent_configuration.rb', line 330

def to_s
  to_hash.to_s
end