Class: OCI::Logging::Models::UnifiedAgentTailLogSource

Inherits:
UnifiedAgentLoggingSource show all
Defined in:
lib/oci/logging/models/unified_agent_tail_log_source.rb

Overview

Tail log source object.

Constant Summary

Constants inherited from UnifiedAgentLoggingSource

OCI::Logging::Models::UnifiedAgentLoggingSource::SOURCE_TYPE_ENUM

Instance Attribute Summary collapse

Attributes inherited from UnifiedAgentLoggingSource

#name, #source_type

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from UnifiedAgentLoggingSource

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ UnifiedAgentTailLogSource

Initializes the object

Options Hash (attributes):



50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/oci/logging/models/unified_agent_tail_log_source.rb', line 50

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['sourceType'] = 'LOG_TAIL'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.paths = attributes[:'paths'] if attributes[:'paths']

  self.parser = attributes[:'parser'] if attributes[:'parser']
end

Instance Attribute Details

#parserOCI::Logging::Models::UnifiedAgentParser



15
16
17
# File 'lib/oci/logging/models/unified_agent_tail_log_source.rb', line 15

def parser
  @parser
end

#pathsArray<String>



12
13
14
# File 'lib/oci/logging/models/unified_agent_tail_log_source.rb', line 12

def paths
  @paths
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



18
19
20
21
22
23
24
25
26
27
# File 'lib/oci/logging/models/unified_agent_tail_log_source.rb', line 18

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'name': :'name',
    'source_type': :'sourceType',
    'paths': :'paths',
    'parser': :'parser'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



30
31
32
33
34
35
36
37
38
39
# File 'lib/oci/logging/models/unified_agent_tail_log_source.rb', line 30

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'name': :'String',
    'source_type': :'String',
    'paths': :'Array<String>',
    'parser': :'OCI::Logging::Models::UnifiedAgentParser'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.



72
73
74
75
76
77
78
79
80
# File 'lib/oci/logging/models/unified_agent_tail_log_source.rb', line 72

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    name == other.name &&
    source_type == other.source_type &&
    paths == other.paths &&
    parser == other.parser
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/oci/logging/models/unified_agent_tail_log_source.rb', line 105

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method


85
86
87
# File 'lib/oci/logging/models/unified_agent_tail_log_source.rb', line 85

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.



94
95
96
# File 'lib/oci/logging/models/unified_agent_tail_log_source.rb', line 94

def hash
  [name, source_type, paths, parser].hash
end

#to_hashHash

Returns the object in the form of hash



138
139
140
141
142
143
144
145
146
147
# File 'lib/oci/logging/models/unified_agent_tail_log_source.rb', line 138

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



132
133
134
# File 'lib/oci/logging/models/unified_agent_tail_log_source.rb', line 132

def to_s
  to_hash.to_s
end