Class: OCI::Loggingsearch::Models::FieldInfo
- Inherits:
-
Object
- Object
- OCI::Loggingsearch::Models::FieldInfo
- Defined in:
- lib/oci/loggingsearch/models/field_info.rb
Overview
Contains field schema information.
Constant Summary collapse
- FIELD_TYPE_ENUM =
[ FIELD_TYPE_STRING = 'STRING'.freeze, FIELD_TYPE_NUMBER = 'NUMBER'.freeze, FIELD_TYPE_BOOLEAN = 'BOOLEAN'.freeze, FIELD_TYPE_ARRAY = 'ARRAY'.freeze, FIELD_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#field_name ⇒ String
**[Required]** Field name.
-
#field_type ⇒ String
**[Required]** Field type - * `STRING`: A sequence of characters.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ FieldInfo
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ FieldInfo
Initializes the object
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/oci/loggingsearch/models/field_info.rb', line 60 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.field_name = attributes[:'fieldName'] if attributes[:'fieldName'] raise 'You cannot provide both :fieldName and :field_name' if attributes.key?(:'fieldName') && attributes.key?(:'field_name') self.field_name = attributes[:'field_name'] if attributes[:'field_name'] self.field_type = attributes[:'fieldType'] if attributes[:'fieldType'] raise 'You cannot provide both :fieldType and :field_type' if attributes.key?(:'fieldType') && attributes.key?(:'field_type') self.field_type = attributes[:'field_type'] if attributes[:'field_type'] end |
Instance Attribute Details
#field_name ⇒ String
**[Required]** Field name
21 22 23 |
# File 'lib/oci/loggingsearch/models/field_info.rb', line 21 def field_name @field_name end |
#field_type ⇒ String
**[Required]** Field type -
-
`STRING`: A sequence of characters.
-
`NUMBER`: Numeric type which can be an integer or floating point.
-
`BOOLEAN`: Either true or false.
-
`ARRAY`: An ordered collection of values.
30 31 32 |
# File 'lib/oci/loggingsearch/models/field_info.rb', line 30 def field_type @field_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 |
# File 'lib/oci/loggingsearch/models/field_info.rb', line 33 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'field_name': :'fieldName', 'field_type': :'fieldType' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
43 44 45 46 47 48 49 50 |
# File 'lib/oci/loggingsearch/models/field_info.rb', line 43 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'field_name': :'String', 'field_type': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
99 100 101 102 103 104 105 |
# File 'lib/oci/loggingsearch/models/field_info.rb', line 99 def ==(other) return true if equal?(other) self.class == other.class && field_name == other.field_name && field_type == other.field_type end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/oci/loggingsearch/models/field_info.rb', line 130 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
110 111 112 |
# File 'lib/oci/loggingsearch/models/field_info.rb', line 110 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
119 120 121 |
# File 'lib/oci/loggingsearch/models/field_info.rb', line 119 def hash [field_name, field_type].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
163 164 165 166 167 168 169 170 171 172 |
# File 'lib/oci/loggingsearch/models/field_info.rb', line 163 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
157 158 159 |
# File 'lib/oci/loggingsearch/models/field_info.rb', line 157 def to_s to_hash.to_s end |