Class: OCI::ManagementAgent::ManagementAgentClient
- Inherits:
-
Object
- Object
- OCI::ManagementAgent::ManagementAgentClient
- Defined in:
- lib/oci/management_agent/management_agent_client.rb
Overview
API for Management Agent Cloud Service
Instance Attribute Summary collapse
-
#api_client ⇒ OCI::ApiClient
readonly
Client used to make HTTP requests.
-
#endpoint ⇒ String
readonly
Fully qualified endpoint URL.
-
#region ⇒ String
The region, which will usually correspond to a value in Regions::REGION_ENUM.
-
#retry_config ⇒ OCI::Retry::RetryConfig
readonly
The default retry configuration to apply to all operations in this service client.
Instance Method Summary collapse
-
#create_management_agent_install_key(create_management_agent_install_key_details, opts = {}) ⇒ Response
User creates a new install key as part of this API.
-
#delete_management_agent(management_agent_id, opts = {}) ⇒ Response
Deletes a Management Agent resource by identifier.
-
#delete_management_agent_install_key(management_agent_install_key_id, opts = {}) ⇒ Response
Deletes a Management Agent install Key resource by identifier.
-
#delete_work_request(work_request_id, opts = {}) ⇒ Response
Cancel the work request with the given ID.
-
#deploy_plugins(deploy_plugins_details, opts = {}) ⇒ Response
Deploys Plugins to a given list of agentIds.
-
#get_management_agent(management_agent_id, opts = {}) ⇒ Response
Gets complete details of the inventory of a given agent id.
-
#get_management_agent_install_key(management_agent_install_key_id, opts = {}) ⇒ Response
Gets complete details of the Agent install Key for a given key id.
-
#get_management_agent_install_key_content(management_agent_install_key_id, opts = {}, &block) ⇒ Response
Returns a file with Management Agent install Key in it.
-
#get_work_request(work_request_id, opts = {}) ⇒ Response
Gets the status of the work request with the given ID.
-
#initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) ⇒ ManagementAgentClient
constructor
Creates a new ManagementAgentClient.
-
#list_availability_histories(management_agent_id, opts = {}) ⇒ Response
Lists the availability history records of Management Agent Allowed values are: timeAvailabilityStatusStarted.
-
#list_management_agent_images(compartment_id, opts = {}) ⇒ Response
Get supported agent image information.
-
#list_management_agent_install_keys(compartment_id, opts = {}) ⇒ Response
Returns a list of Management Agent installed Keys.
-
#list_management_agent_plugins(compartment_id, opts = {}) ⇒ Response
Returns a list of managementAgentPlugins.
-
#list_management_agents(compartment_id, opts = {}) ⇒ Response
Returns a list of Management Agent.
-
#list_work_request_errors(work_request_id, opts = {}) ⇒ Response
Return a (paginated) list of errors for a given work request.
-
#list_work_request_logs(work_request_id, opts = {}) ⇒ Response
Return a (paginated) list of logs for a given work request.
-
#list_work_requests(compartment_id, opts = {}) ⇒ Response
Lists the work requests in a compartment.
-
#logger ⇒ Logger
The logger for this client.
-
#update_management_agent(management_agent_id, update_management_agent_details, opts = {}) ⇒ Response
API to update the console managed properties of the Management Agent.
-
#update_management_agent_install_key(management_agent_install_key_id, update_management_agent_install_key_details, opts = {}) ⇒ Response
API to update the modifiable properties of the Management Agent install key.
Constructor Details
#initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) ⇒ ManagementAgentClient
Creates a new ManagementAgentClient. Notes:
If a config is not specified, then the global OCI.config will be used.
This client is not thread-safe
Either a region or an endpoint must be specified. If an endpoint is specified, it will be used instead of the
region. A region may be specified in the config or via or the region parameter. If specified in both, then the
region parameter will be used.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/oci/management_agent/management_agent_client.rb', line 53 def initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) # If the signer is an InstancePrincipalsSecurityTokenSigner or SecurityTokenSigner and no config was supplied (they are self-sufficient signers) # then create a dummy config to pass to the ApiClient constructor. If customers wish to create a client which uses instance principals # and has config (either populated programmatically or loaded from a file), they must construct that config themselves and then # pass it to this constructor. # # If there is no signer (or the signer is not an instance principals signer) and no config was supplied, this is not valid # so try and load the config from the default file. config = OCI::Config.validate_and_build_config_with_signer(config, signer) signer = OCI::Signer.config_file_auth_builder(config) if signer.nil? @api_client = OCI::ApiClient.new(config, signer, proxy_settings: proxy_settings) @retry_config = retry_config if endpoint @endpoint = endpoint + '/20200202' else region ||= config.region region ||= signer.region if signer.respond_to?(:region) self.region = region end logger.info "ManagementAgentClient endpoint set to '#{@endpoint}'." if logger end |
Instance Attribute Details
#api_client ⇒ OCI::ApiClient (readonly)
Client used to make HTTP requests.
13 14 15 |
# File 'lib/oci/management_agent/management_agent_client.rb', line 13 def api_client @api_client end |
#endpoint ⇒ String (readonly)
Fully qualified endpoint URL
17 18 19 |
# File 'lib/oci/management_agent/management_agent_client.rb', line 17 def endpoint @endpoint end |
#region ⇒ String
The region, which will usually correspond to a value in Regions::REGION_ENUM.
27 28 29 |
# File 'lib/oci/management_agent/management_agent_client.rb', line 27 def region @region end |
#retry_config ⇒ OCI::Retry::RetryConfig (readonly)
The default retry configuration to apply to all operations in this service client. This can be overridden on a per-operation basis. The default retry configuration value is nil, which means that an operation will not perform any retries
23 24 25 |
# File 'lib/oci/management_agent/management_agent_client.rb', line 23 def retry_config @retry_config end |
Instance Method Details
#create_management_agent_install_key(create_management_agent_install_key_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/managementagent/create_management_agent_install_key.rb.html) to see an example of how to use create_management_agent_install_key API.
User creates a new install key as part of this API.
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/oci/management_agent/management_agent_client.rb', line 116 def create_management_agent_install_key(create_management_agent_install_key_details, opts = {}) logger.debug 'Calling operation ManagementAgentClient#create_management_agent_install_key.' if logger raise "Missing the required parameter 'create_management_agent_install_key_details' when calling create_management_agent_install_key." if create_management_agent_install_key_details.nil? path = '/managementAgentInstallKeys' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = @api_client.object_to_http_body(create_management_agent_install_key_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ManagementAgentClient#create_management_agent_install_key') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::ManagementAgent::Models::ManagementAgentInstallKey' ) end # rubocop:enable Metrics/BlockLength end |
#delete_management_agent(management_agent_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/managementagent/delete_management_agent.rb.html) to see an example of how to use delete_management_agent API.
Deletes a Management Agent resource by identifier
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/oci/management_agent/management_agent_client.rb', line 177 def delete_management_agent(management_agent_id, opts = {}) logger.debug 'Calling operation ManagementAgentClient#delete_management_agent.' if logger raise "Missing the required parameter 'management_agent_id' when calling delete_management_agent." if management_agent_id.nil? raise "Parameter value for 'management_agent_id' must not be blank" if OCI::Internal::Util.blank_string?(management_agent_id) path = '/managementAgents/{managementAgentId}'.sub('{managementAgentId}', management_agent_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ManagementAgentClient#delete_management_agent') do @api_client.call_api( :DELETE, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#delete_management_agent_install_key(management_agent_install_key_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/managementagent/delete_management_agent_install_key.rb.html) to see an example of how to use delete_management_agent_install_key API.
Deletes a Management Agent install Key resource by identifier
237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/oci/management_agent/management_agent_client.rb', line 237 def delete_management_agent_install_key(management_agent_install_key_id, opts = {}) logger.debug 'Calling operation ManagementAgentClient#delete_management_agent_install_key.' if logger raise "Missing the required parameter 'management_agent_install_key_id' when calling delete_management_agent_install_key." if management_agent_install_key_id.nil? raise "Parameter value for 'management_agent_install_key_id' must not be blank" if OCI::Internal::Util.blank_string?(management_agent_install_key_id) path = '/managementAgentInstallKeys/{managementAgentInstallKeyId}'.sub('{managementAgentInstallKeyId}', management_agent_install_key_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ManagementAgentClient#delete_management_agent_install_key') do @api_client.call_api( :DELETE, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#delete_work_request(work_request_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/managementagent/delete_work_request.rb.html) to see an example of how to use delete_work_request API.
Cancel the work request with the given ID.
297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 |
# File 'lib/oci/management_agent/management_agent_client.rb', line 297 def delete_work_request(work_request_id, opts = {}) logger.debug 'Calling operation ManagementAgentClient#delete_work_request.' if logger raise "Missing the required parameter 'work_request_id' when calling delete_work_request." if work_request_id.nil? raise "Parameter value for 'work_request_id' must not be blank" if OCI::Internal::Util.blank_string?(work_request_id) path = '/workRequests/{workRequestId}'.sub('{workRequestId}', work_request_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'if-match'] = opts[:if_match] if opts[:if_match] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ManagementAgentClient#delete_work_request') do @api_client.call_api( :DELETE, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#deploy_plugins(deploy_plugins_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/managementagent/deploy_plugins.rb.html) to see an example of how to use deploy_plugins API.
Deploys Plugins to a given list of agentIds.
358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 |
# File 'lib/oci/management_agent/management_agent_client.rb', line 358 def deploy_plugins(deploy_plugins_details, opts = {}) logger.debug 'Calling operation ManagementAgentClient#deploy_plugins.' if logger raise "Missing the required parameter 'deploy_plugins_details' when calling deploy_plugins." if deploy_plugins_details.nil? path = '/managementAgents/actions/deployPlugins' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = @api_client.object_to_http_body(deploy_plugins_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ManagementAgentClient#deploy_plugins') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#get_management_agent(management_agent_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/managementagent/get_management_agent.rb.html) to see an example of how to use get_management_agent API.
Gets complete details of the inventory of a given agent id
412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 |
# File 'lib/oci/management_agent/management_agent_client.rb', line 412 def get_management_agent(management_agent_id, opts = {}) logger.debug 'Calling operation ManagementAgentClient#get_management_agent.' if logger raise "Missing the required parameter 'management_agent_id' when calling get_management_agent." if management_agent_id.nil? raise "Parameter value for 'management_agent_id' must not be blank" if OCI::Internal::Util.blank_string?(management_agent_id) path = '/managementAgents/{managementAgentId}'.sub('{managementAgentId}', management_agent_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ManagementAgentClient#get_management_agent') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::ManagementAgent::Models::ManagementAgent' ) end # rubocop:enable Metrics/BlockLength end |
#get_management_agent_install_key(management_agent_install_key_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/managementagent/get_management_agent_install_key.rb.html) to see an example of how to use get_management_agent_install_key API.
Gets complete details of the Agent install Key for a given key id
466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 |
# File 'lib/oci/management_agent/management_agent_client.rb', line 466 def get_management_agent_install_key(management_agent_install_key_id, opts = {}) logger.debug 'Calling operation ManagementAgentClient#get_management_agent_install_key.' if logger raise "Missing the required parameter 'management_agent_install_key_id' when calling get_management_agent_install_key." if management_agent_install_key_id.nil? raise "Parameter value for 'management_agent_install_key_id' must not be blank" if OCI::Internal::Util.blank_string?(management_agent_install_key_id) path = '/managementAgentInstallKeys/{managementAgentInstallKeyId}'.sub('{managementAgentInstallKeyId}', management_agent_install_key_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ManagementAgentClient#get_management_agent_install_key') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::ManagementAgent::Models::ManagementAgentInstallKey' ) end # rubocop:enable Metrics/BlockLength end |
#get_management_agent_install_key_content(management_agent_install_key_id, opts = {}, &block) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/managementagent/get_management_agent_install_key_content.rb.html) to see an example of how to use get_management_agent_install_key_content API.
Returns a file with Management Agent install Key in it
524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 |
# File 'lib/oci/management_agent/management_agent_client.rb', line 524 def get_management_agent_install_key_content(management_agent_install_key_id, opts = {}, &block) logger.debug 'Calling operation ManagementAgentClient#get_management_agent_install_key_content.' if logger raise "Missing the required parameter 'management_agent_install_key_id' when calling get_management_agent_install_key_content." if management_agent_install_key_id.nil? raise "Parameter value for 'management_agent_install_key_id' must not be blank" if OCI::Internal::Util.blank_string?(management_agent_install_key_id) path = '/managementAgentInstallKeys/{managementAgentInstallKeyId}/content'.sub('{managementAgentInstallKeyId}', management_agent_install_key_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:pluginName] = OCI::ApiClient.build_collection_params(opts[:plugin_name], :multi) if opts[:plugin_name] && !opts[:plugin_name].empty? # Header Params header_params = {} header_params[:accept] = opts[:accept] if opts[:accept] header_params[:accept] ||= 'application/octet-stream' header_params[:'accept-encoding'] = opts[:accept_encoding] if opts[:accept_encoding] header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ManagementAgentClient#get_management_agent_install_key_content') do if !block.nil? @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'Stream', &block ) elsif opts[:response_target] if opts[:response_target].respond_to? :write @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'Stream', &proc { |chunk, _response| opts[:response_target].write(chunk) } ) elsif opts[:response_target].is_a?(String) File.open(opts[:response_target], 'wb') do |output| return @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'Stream', &proc { |chunk, _response| output.write(chunk) } ) end end else @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'String' ) end end # rubocop:enable Metrics/BlockLength end |
#get_work_request(work_request_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/managementagent/get_work_request.rb.html) to see an example of how to use get_work_request API.
Gets the status of the work request with the given ID.
623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 |
# File 'lib/oci/management_agent/management_agent_client.rb', line 623 def get_work_request(work_request_id, opts = {}) logger.debug 'Calling operation ManagementAgentClient#get_work_request.' if logger raise "Missing the required parameter 'work_request_id' when calling get_work_request." if work_request_id.nil? raise "Parameter value for 'work_request_id' must not be blank" if OCI::Internal::Util.blank_string?(work_request_id) path = '/workRequests/{workRequestId}'.sub('{workRequestId}', work_request_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ManagementAgentClient#get_work_request') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::ManagementAgent::Models::WorkRequest' ) end # rubocop:enable Metrics/BlockLength end |
#list_availability_histories(management_agent_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/managementagent/list_availability_histories.rb.html) to see an example of how to use list_availability_histories API.
Lists the availability history records of Management Agent
Allowed values are: timeAvailabilityStatusStarted
692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 |
# File 'lib/oci/management_agent/management_agent_client.rb', line 692 def list_availability_histories(management_agent_id, opts = {}) logger.debug 'Calling operation ManagementAgentClient#list_availability_histories.' if logger raise "Missing the required parameter 'management_agent_id' when calling list_availability_histories." if management_agent_id.nil? if opts[:sort_order] && !%w[ASC DESC].include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of ASC, DESC.' end if opts[:sort_by] && !%w[timeAvailabilityStatusStarted].include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of timeAvailabilityStatusStarted.' end raise "Parameter value for 'management_agent_id' must not be blank" if OCI::Internal::Util.blank_string?(management_agent_id) path = '/managementAgents/{managementAgentId}/availabilityHistories'.sub('{managementAgentId}', management_agent_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:timeAvailabilityStatusEndedGreaterThan] = opts[:time_availability_status_ended_greater_than] if opts[:time_availability_status_ended_greater_than] query_params[:timeAvailabilityStatusStartedLessThan] = opts[:time_availability_status_started_less_than] if opts[:time_availability_status_started_less_than] query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ManagementAgentClient#list_availability_histories') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'Array<OCI::ManagementAgent::Models::AvailabilityHistorySummary>' ) end # rubocop:enable Metrics/BlockLength end |
#list_management_agent_images(compartment_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/managementagent/list_management_agent_images.rb.html) to see an example of how to use list_management_agent_images API.
Get supported agent image information
Allowed values are: platformType, version
776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 |
# File 'lib/oci/management_agent/management_agent_client.rb', line 776 def list_management_agent_images(compartment_id, opts = {}) logger.debug 'Calling operation ManagementAgentClient#list_management_agent_images.' if logger raise "Missing the required parameter 'compartment_id' when calling list_management_agent_images." if compartment_id.nil? if opts[:sort_order] && !%w[ASC DESC].include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of ASC, DESC.' end if opts[:sort_by] && !%w[platformType version].include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of platformType, version.' end if opts[:lifecycle_state] && !OCI::ManagementAgent::Models::LIFECYCLE_STATES_ENUM.include?(opts[:lifecycle_state]) raise 'Invalid value for "lifecycle_state", must be one of the values in OCI::ManagementAgent::Models::LIFECYCLE_STATES_ENUM.' end path = '/managementAgentImages' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:compartmentId] = compartment_id query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] query_params[:name] = opts[:name] if opts[:name] query_params[:lifecycleState] = opts[:lifecycle_state] if opts[:lifecycle_state] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ManagementAgentClient#list_management_agent_images') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'Array<OCI::ManagementAgent::Models::ManagementAgentImageSummary>' ) end # rubocop:enable Metrics/BlockLength end |
#list_management_agent_install_keys(compartment_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/managementagent/list_management_agent_install_keys.rb.html) to see an example of how to use list_management_agent_install_keys API.
Returns a list of Management Agent installed Keys.
Allowed values are: timeCreated, displayName
861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 |
# File 'lib/oci/management_agent/management_agent_client.rb', line 861 def list_management_agent_install_keys(compartment_id, opts = {}) logger.debug 'Calling operation ManagementAgentClient#list_management_agent_install_keys.' if logger raise "Missing the required parameter 'compartment_id' when calling list_management_agent_install_keys." if compartment_id.nil? if opts[:lifecycle_state] && !OCI::ManagementAgent::Models::LIFECYCLE_STATES_ENUM.include?(opts[:lifecycle_state]) raise 'Invalid value for "lifecycle_state", must be one of the values in OCI::ManagementAgent::Models::LIFECYCLE_STATES_ENUM.' end if opts[:sort_order] && !%w[ASC DESC].include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of ASC, DESC.' end if opts[:sort_by] && !%w[timeCreated displayName].include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of timeCreated, displayName.' end path = '/managementAgentInstallKeys' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:compartmentId] = compartment_id query_params[:compartmentIdInSubtree] = opts[:compartment_id_in_subtree] if !opts[:compartment_id_in_subtree].nil? query_params[:accessLevel] = opts[:access_level] if opts[:access_level] query_params[:lifecycleState] = opts[:lifecycle_state] if opts[:lifecycle_state] query_params[:displayName] = opts[:display_name] if opts[:display_name] query_params[:page] = opts[:page] if opts[:page] query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ManagementAgentClient#list_management_agent_install_keys') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'Array<OCI::ManagementAgent::Models::ManagementAgentInstallKeySummary>' ) end # rubocop:enable Metrics/BlockLength end |
#list_management_agent_plugins(compartment_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/managementagent/list_management_agent_plugins.rb.html) to see an example of how to use list_management_agent_plugins API.
Returns a list of managementAgentPlugins.
Allowed values are: displayName
944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 |
# File 'lib/oci/management_agent/management_agent_client.rb', line 944 def list_management_agent_plugins(compartment_id, opts = {}) logger.debug 'Calling operation ManagementAgentClient#list_management_agent_plugins.' if logger raise "Missing the required parameter 'compartment_id' when calling list_management_agent_plugins." if compartment_id.nil? if opts[:sort_order] && !%w[ASC DESC].include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of ASC, DESC.' end if opts[:sort_by] && !%w[displayName].include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of displayName.' end if opts[:lifecycle_state] && !OCI::ManagementAgent::Models::LIFECYCLE_STATES_ENUM.include?(opts[:lifecycle_state]) raise 'Invalid value for "lifecycle_state", must be one of the values in OCI::ManagementAgent::Models::LIFECYCLE_STATES_ENUM.' end path = '/managementAgentPlugins' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:compartmentId] = compartment_id query_params[:displayName] = opts[:display_name] if opts[:display_name] query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] query_params[:lifecycleState] = opts[:lifecycle_state] if opts[:lifecycle_state] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ManagementAgentClient#list_management_agent_plugins') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'Array<OCI::ManagementAgent::Models::ManagementAgentPluginSummary>' ) end # rubocop:enable Metrics/BlockLength end |
#list_management_agents(compartment_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/managementagent/list_management_agents.rb.html) to see an example of how to use list_management_agents API.
Returns a list of Management Agent.
Allowed values are: timeCreated, displayName
1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 |
# File 'lib/oci/management_agent/management_agent_client.rb', line 1029 def list_management_agents(compartment_id, opts = {}) logger.debug 'Calling operation ManagementAgentClient#list_management_agents.' if logger raise "Missing the required parameter 'compartment_id' when calling list_management_agents." if compartment_id.nil? if opts[:lifecycle_state] && !OCI::ManagementAgent::Models::LIFECYCLE_STATES_ENUM.include?(opts[:lifecycle_state]) raise 'Invalid value for "lifecycle_state", must be one of the values in OCI::ManagementAgent::Models::LIFECYCLE_STATES_ENUM.' end if opts[:platform_type] && !OCI::ManagementAgent::Models::PLATFORM_TYPES_ENUM.include?(opts[:platform_type]) raise 'Invalid value for "platform_type", must be one of the values in OCI::ManagementAgent::Models::PLATFORM_TYPES_ENUM.' end if opts[:sort_order] && !%w[ASC DESC].include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of ASC, DESC.' end if opts[:sort_by] && !%w[timeCreated displayName].include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of timeCreated, displayName.' end path = '/managementAgents' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:compartmentId] = compartment_id query_params[:pluginName] = opts[:plugin_name] if opts[:plugin_name] query_params[:version] = opts[:version] if opts[:version] query_params[:displayName] = opts[:display_name] if opts[:display_name] query_params[:lifecycleState] = opts[:lifecycle_state] if opts[:lifecycle_state] query_params[:platformType] = opts[:platform_type] if opts[:platform_type] query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ManagementAgentClient#list_management_agents') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'Array<OCI::ManagementAgent::Models::ManagementAgentSummary>' ) end # rubocop:enable Metrics/BlockLength end |
#list_work_request_errors(work_request_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/managementagent/list_work_request_errors.rb.html) to see an example of how to use list_work_request_errors API.
Return a (paginated) list of errors for a given work request.
Allowed values are:
1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 |
# File 'lib/oci/management_agent/management_agent_client.rb', line 1116 def list_work_request_errors(work_request_id, opts = {}) logger.debug 'Calling operation ManagementAgentClient#list_work_request_errors.' if logger raise "Missing the required parameter 'work_request_id' when calling list_work_request_errors." if work_request_id.nil? if opts[:sort_order] && !%w[ASC DESC].include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of ASC, DESC.' end if opts[:sort_by] && !%w[timestamp].include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of timestamp.' end raise "Parameter value for 'work_request_id' must not be blank" if OCI::Internal::Util.blank_string?(work_request_id) path = '/workRequests/{workRequestId}/errors'.sub('{workRequestId}', work_request_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:page] = opts[:page] if opts[:page] query_params[:limit] = opts[:limit] if opts[:limit] query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ManagementAgentClient#list_work_request_errors') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'Array<OCI::ManagementAgent::Models::WorkRequestError>' ) end # rubocop:enable Metrics/BlockLength end |
#list_work_request_logs(work_request_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/managementagent/list_work_request_logs.rb.html) to see an example of how to use list_work_request_logs API.
Return a (paginated) list of logs for a given work request.
Allowed values are:
1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 1238 |
# File 'lib/oci/management_agent/management_agent_client.rb', line 1190 def list_work_request_logs(work_request_id, opts = {}) logger.debug 'Calling operation ManagementAgentClient#list_work_request_logs.' if logger raise "Missing the required parameter 'work_request_id' when calling list_work_request_logs." if work_request_id.nil? if opts[:sort_order] && !%w[ASC DESC].include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of ASC, DESC.' end if opts[:sort_by] && !%w[timestamp].include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of timestamp.' end raise "Parameter value for 'work_request_id' must not be blank" if OCI::Internal::Util.blank_string?(work_request_id) path = '/workRequests/{workRequestId}/logs'.sub('{workRequestId}', work_request_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:page] = opts[:page] if opts[:page] query_params[:limit] = opts[:limit] if opts[:limit] query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ManagementAgentClient#list_work_request_logs') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'Array<OCI::ManagementAgent::Models::WorkRequestLogEntry>' ) end # rubocop:enable Metrics/BlockLength end |
#list_work_requests(compartment_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/managementagent/list_work_requests.rb.html) to see an example of how to use list_work_requests API.
Lists the work requests in a compartment.
Allowed values are: timeAccepted
1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 1294 1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 |
# File 'lib/oci/management_agent/management_agent_client.rb', line 1270 def list_work_requests(compartment_id, opts = {}) logger.debug 'Calling operation ManagementAgentClient#list_work_requests.' if logger raise "Missing the required parameter 'compartment_id' when calling list_work_requests." if compartment_id.nil? if opts[:status] && !OCI::ManagementAgent::Models::OPERATION_STATUS_ENUM.include?(opts[:status]) raise 'Invalid value for "status", must be one of the values in OCI::ManagementAgent::Models::OPERATION_STATUS_ENUM.' end if opts[:sort_order] && !%w[ASC DESC].include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of ASC, DESC.' end if opts[:sort_by] && !%w[timeAccepted].include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of timeAccepted.' end path = '/workRequests' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:compartmentId] = compartment_id query_params[:agentId] = opts[:agent_id] if opts[:agent_id] query_params[:page] = opts[:page] if opts[:page] query_params[:limit] = opts[:limit] if opts[:limit] query_params[:status] = opts[:status] if opts[:status] query_params[:timeCreatedGreaterThanOrEqualTo] = opts[:time_created_greater_than_or_equal_to] if opts[:time_created_greater_than_or_equal_to] query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ManagementAgentClient#list_work_requests') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'Array<OCI::ManagementAgent::Models::WorkRequestSummary>' ) end # rubocop:enable Metrics/BlockLength end |
#logger ⇒ Logger
Returns The logger for this client. May be nil.
92 93 94 |
# File 'lib/oci/management_agent/management_agent_client.rb', line 92 def logger @api_client.config.logger end |
#update_management_agent(management_agent_id, update_management_agent_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/managementagent/update_management_agent.rb.html) to see an example of how to use update_management_agent API.
API to update the console managed properties of the Management Agent.
1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 |
# File 'lib/oci/management_agent/management_agent_client.rb', line 1357 def update_management_agent(management_agent_id, update_management_agent_details, opts = {}) logger.debug 'Calling operation ManagementAgentClient#update_management_agent.' if logger raise "Missing the required parameter 'management_agent_id' when calling update_management_agent." if management_agent_id.nil? raise "Missing the required parameter 'update_management_agent_details' when calling update_management_agent." if update_management_agent_details.nil? raise "Parameter value for 'management_agent_id' must not be blank" if OCI::Internal::Util.blank_string?(management_agent_id) path = '/managementAgents/{managementAgentId}'.sub('{managementAgentId}', management_agent_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'if-match'] = opts[:if_match] if opts[:if_match] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = @api_client.object_to_http_body(update_management_agent_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ManagementAgentClient#update_management_agent') do @api_client.call_api( :PUT, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::ManagementAgent::Models::ManagementAgent' ) end # rubocop:enable Metrics/BlockLength end |
#update_management_agent_install_key(management_agent_install_key_id, update_management_agent_install_key_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/managementagent/update_management_agent_install_key.rb.html) to see an example of how to use update_management_agent_install_key API.
API to update the modifiable properties of the Management Agent install key.
1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 1468 1469 |
# File 'lib/oci/management_agent/management_agent_client.rb', line 1429 def update_management_agent_install_key(management_agent_install_key_id, update_management_agent_install_key_details, opts = {}) logger.debug 'Calling operation ManagementAgentClient#update_management_agent_install_key.' if logger raise "Missing the required parameter 'management_agent_install_key_id' when calling update_management_agent_install_key." if management_agent_install_key_id.nil? raise "Missing the required parameter 'update_management_agent_install_key_details' when calling update_management_agent_install_key." if update_management_agent_install_key_details.nil? raise "Parameter value for 'management_agent_install_key_id' must not be blank" if OCI::Internal::Util.blank_string?(management_agent_install_key_id) path = '/managementAgentInstallKeys/{managementAgentInstallKeyId}'.sub('{managementAgentInstallKeyId}', management_agent_install_key_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'if-match'] = opts[:if_match] if opts[:if_match] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = @api_client.object_to_http_body(update_management_agent_install_key_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ManagementAgentClient#update_management_agent_install_key') do @api_client.call_api( :PUT, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::ManagementAgent::Models::ManagementAgentInstallKey' ) end # rubocop:enable Metrics/BlockLength end |