Class: OCI::ManagementAgent::Models::ManagementAgentAggregationDimensions

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/management_agent/models/management_agent_aggregation_dimensions.rb

Overview

The Aggregation of Management Agent Dimensions

Constant Summary collapse

AVAILABILITY_STATUS_ENUM =
[
  AVAILABILITY_STATUS_ACTIVE = 'ACTIVE'.freeze,
  AVAILABILITY_STATUS_SILENT = 'SILENT'.freeze,
  AVAILABILITY_STATUS_NOT_AVAILABLE = 'NOT_AVAILABLE'.freeze,
  AVAILABILITY_STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
PLATFORM_TYPE_ENUM =
[
  PLATFORM_TYPE_LINUX = 'LINUX'.freeze,
  PLATFORM_TYPE_WINDOWS = 'WINDOWS'.freeze,
  PLATFORM_TYPE_SOLARIS = 'SOLARIS'.freeze,
  PLATFORM_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
INSTALL_TYPE_ENUM =
[
  INSTALL_TYPE_AGENT = 'AGENT'.freeze,
  INSTALL_TYPE_GATEWAY = 'GATEWAY'.freeze,
  INSTALL_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ManagementAgentAggregationDimensions

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :availability_status (String)

    The value to assign to the #availability_status property

  • :platform_type (String)

    The value to assign to the #platform_type property

  • :version (String)

    The value to assign to the #version property

  • :has_plugins (BOOLEAN)

    The value to assign to the #has_plugins property

  • :install_type (String)

    The value to assign to the #install_type property



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/oci/management_agent/models/management_agent_aggregation_dimensions.rb', line 88

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.availability_status = attributes[:'availabilityStatus'] if attributes[:'availabilityStatus']

  raise 'You cannot provide both :availabilityStatus and :availability_status' if attributes.key?(:'availabilityStatus') && attributes.key?(:'availability_status')

  self.availability_status = attributes[:'availability_status'] if attributes[:'availability_status']

  self.platform_type = attributes[:'platformType'] if attributes[:'platformType']

  raise 'You cannot provide both :platformType and :platform_type' if attributes.key?(:'platformType') && attributes.key?(:'platform_type')

  self.platform_type = attributes[:'platform_type'] if attributes[:'platform_type']

  self.version = attributes[:'version'] if attributes[:'version']

  self.has_plugins = attributes[:'hasPlugins'] unless attributes[:'hasPlugins'].nil?

  raise 'You cannot provide both :hasPlugins and :has_plugins' if attributes.key?(:'hasPlugins') && attributes.key?(:'has_plugins')

  self.has_plugins = attributes[:'has_plugins'] unless attributes[:'has_plugins'].nil?

  self.install_type = attributes[:'installType'] if attributes[:'installType']

  raise 'You cannot provide both :installType and :install_type' if attributes.key?(:'installType') && attributes.key?(:'install_type')

  self.install_type = attributes[:'install_type'] if attributes[:'install_type']
end

Instance Attribute Details

#availability_statusString

The availability status of managementAgent

Returns:

  • (String)


33
34
35
# File 'lib/oci/management_agent/models/management_agent_aggregation_dimensions.rb', line 33

def availability_status
  @availability_status
end

#has_pluginsBOOLEAN

Whether or not a managementAgent has at least one plugin

Returns:

  • (BOOLEAN)


45
46
47
# File 'lib/oci/management_agent/models/management_agent_aggregation_dimensions.rb', line 45

def has_plugins
  @has_plugins
end

#install_typeString

The install type, either AGENT or GATEWAY

Returns:

  • (String)


49
50
51
# File 'lib/oci/management_agent/models/management_agent_aggregation_dimensions.rb', line 49

def install_type
  @install_type
end

#platform_typeString

Platform Type

Returns:

  • (String)


37
38
39
# File 'lib/oci/management_agent/models/management_agent_aggregation_dimensions.rb', line 37

def platform_type
  @platform_type
end

#versionString

Agent image version

Returns:

  • (String)


41
42
43
# File 'lib/oci/management_agent/models/management_agent_aggregation_dimensions.rb', line 41

def version
  @version
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



52
53
54
55
56
57
58
59
60
61
62
# File 'lib/oci/management_agent/models/management_agent_aggregation_dimensions.rb', line 52

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'availability_status': :'availabilityStatus',
    'platform_type': :'platformType',
    'version': :'version',
    'has_plugins': :'hasPlugins',
    'install_type': :'installType'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



65
66
67
68
69
70
71
72
73
74
75
# File 'lib/oci/management_agent/models/management_agent_aggregation_dimensions.rb', line 65

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'availability_status': :'String',
    'platform_type': :'String',
    'version': :'String',
    'has_plugins': :'BOOLEAN',
    'install_type': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



167
168
169
170
171
172
173
174
175
176
# File 'lib/oci/management_agent/models/management_agent_aggregation_dimensions.rb', line 167

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    availability_status == other.availability_status &&
    platform_type == other.platform_type &&
    version == other.version &&
    has_plugins == other.has_plugins &&
    install_type == other.install_type
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/oci/management_agent/models/management_agent_aggregation_dimensions.rb', line 201

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


181
182
183
# File 'lib/oci/management_agent/models/management_agent_aggregation_dimensions.rb', line 181

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



190
191
192
# File 'lib/oci/management_agent/models/management_agent_aggregation_dimensions.rb', line 190

def hash
  [availability_status, platform_type, version, has_plugins, install_type].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



234
235
236
237
238
239
240
241
242
243
# File 'lib/oci/management_agent/models/management_agent_aggregation_dimensions.rb', line 234

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



228
229
230
# File 'lib/oci/management_agent/models/management_agent_aggregation_dimensions.rb', line 228

def to_s
  to_hash.to_s
end