Class: OCI::ManagementAgent::Models::ManagementAgentInstallKey
- Inherits:
-
Object
- Object
- OCI::ManagementAgent::Models::ManagementAgentInstallKey
- Defined in:
- lib/oci/management_agent/models/management_agent_install_key.rb
Overview
The details of the Agent install Key
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#allowed_key_install_count ⇒ Integer
Total number of install for this keys.
-
#compartment_id ⇒ String
**[Required]** Compartment Identifier.
-
#created_by_principal_id ⇒ String
Principal id of user who created the Agent Install key.
-
#current_key_install_count ⇒ Integer
Total number of install for this keys.
-
#display_name ⇒ String
Management Agent Install Key Name.
-
#id ⇒ String
**[Required]** Agent install Key identifier.
-
#is_unlimited ⇒ BOOLEAN
If set to true, the install key has no expiration date or usage limit.
-
#key ⇒ String
Management Agent Install Key.
-
#lifecycle_details ⇒ String
A message describing the current state in more detail.
-
#lifecycle_state ⇒ String
Status of Key.
-
#time_created ⇒ DateTime
The time when Management Agent install Key was created.
-
#time_expires ⇒ DateTime
date after which key would expire after creation.
-
#time_updated ⇒ DateTime
The time when Management Agent install Key was updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ManagementAgentInstallKey
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ManagementAgentInstallKey
Initializes the object
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/oci/management_agent/models/management_agent_install_key.rb', line 136 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.key = attributes[:'key'] if attributes[:'key'] self.created_by_principal_id = attributes[:'createdByPrincipalId'] if attributes[:'createdByPrincipalId'] raise 'You cannot provide both :createdByPrincipalId and :created_by_principal_id' if attributes.key?(:'createdByPrincipalId') && attributes.key?(:'created_by_principal_id') self.created_by_principal_id = attributes[:'created_by_principal_id'] if attributes[:'created_by_principal_id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.allowed_key_install_count = attributes[:'allowedKeyInstallCount'] if attributes[:'allowedKeyInstallCount'] raise 'You cannot provide both :allowedKeyInstallCount and :allowed_key_install_count' if attributes.key?(:'allowedKeyInstallCount') && attributes.key?(:'allowed_key_install_count') self.allowed_key_install_count = attributes[:'allowed_key_install_count'] if attributes[:'allowed_key_install_count'] self.current_key_install_count = attributes[:'currentKeyInstallCount'] if attributes[:'currentKeyInstallCount'] raise 'You cannot provide both :currentKeyInstallCount and :current_key_install_count' if attributes.key?(:'currentKeyInstallCount') && attributes.key?(:'current_key_install_count') self.current_key_install_count = attributes[:'current_key_install_count'] if attributes[:'current_key_install_count'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.time_expires = attributes[:'timeExpires'] if attributes[:'timeExpires'] raise 'You cannot provide both :timeExpires and :time_expires' if attributes.key?(:'timeExpires') && attributes.key?(:'time_expires') self.time_expires = attributes[:'time_expires'] if attributes[:'time_expires'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.is_unlimited = attributes[:'isUnlimited'] unless attributes[:'isUnlimited'].nil? self.is_unlimited = false if is_unlimited.nil? && !attributes.key?(:'isUnlimited') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isUnlimited and :is_unlimited' if attributes.key?(:'isUnlimited') && attributes.key?(:'is_unlimited') self.is_unlimited = attributes[:'is_unlimited'] unless attributes[:'is_unlimited'].nil? self.is_unlimited = false if is_unlimited.nil? && !attributes.key?(:'isUnlimited') && !attributes.key?(:'is_unlimited') # rubocop:disable Style/StringLiterals end |
Instance Attribute Details
#allowed_key_install_count ⇒ Integer
Total number of install for this keys
45 46 47 |
# File 'lib/oci/management_agent/models/management_agent_install_key.rb', line 45 def allowed_key_install_count @allowed_key_install_count end |
#compartment_id ⇒ String
**[Required]** Compartment Identifier
41 42 43 |
# File 'lib/oci/management_agent/models/management_agent_install_key.rb', line 41 def compartment_id @compartment_id end |
#created_by_principal_id ⇒ String
Principal id of user who created the Agent Install key
37 38 39 |
# File 'lib/oci/management_agent/models/management_agent_install_key.rb', line 37 def created_by_principal_id @created_by_principal_id end |
#current_key_install_count ⇒ Integer
Total number of install for this keys
49 50 51 |
# File 'lib/oci/management_agent/models/management_agent_install_key.rb', line 49 def current_key_install_count @current_key_install_count end |
#display_name ⇒ String
Management Agent Install Key Name
29 30 31 |
# File 'lib/oci/management_agent/models/management_agent_install_key.rb', line 29 def display_name @display_name end |
#id ⇒ String
**[Required]** Agent install Key identifier
25 26 27 |
# File 'lib/oci/management_agent/models/management_agent_install_key.rb', line 25 def id @id end |
#is_unlimited ⇒ BOOLEAN
If set to true, the install key has no expiration date or usage limit. Defaults to false
73 74 75 |
# File 'lib/oci/management_agent/models/management_agent_install_key.rb', line 73 def is_unlimited @is_unlimited end |
#key ⇒ String
Management Agent Install Key
33 34 35 |
# File 'lib/oci/management_agent/models/management_agent_install_key.rb', line 33 def key @key end |
#lifecycle_details ⇒ String
A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
57 58 59 |
# File 'lib/oci/management_agent/models/management_agent_install_key.rb', line 57 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
Status of Key
53 54 55 |
# File 'lib/oci/management_agent/models/management_agent_install_key.rb', line 53 def lifecycle_state @lifecycle_state end |
#time_created ⇒ DateTime
The time when Management Agent install Key was created. An RFC3339 formatted date time string
65 66 67 |
# File 'lib/oci/management_agent/models/management_agent_install_key.rb', line 65 def time_created @time_created end |
#time_expires ⇒ DateTime
date after which key would expire after creation
61 62 63 |
# File 'lib/oci/management_agent/models/management_agent_install_key.rb', line 61 def time_expires @time_expires end |
#time_updated ⇒ DateTime
The time when Management Agent install Key was updated. An RFC3339 formatted date time string
69 70 71 |
# File 'lib/oci/management_agent/models/management_agent_install_key.rb', line 69 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/oci/management_agent/models/management_agent_install_key.rb', line 76 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'key': :'key', 'created_by_principal_id': :'createdByPrincipalId', 'compartment_id': :'compartmentId', 'allowed_key_install_count': :'allowedKeyInstallCount', 'current_key_install_count': :'currentKeyInstallCount', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'time_expires': :'timeExpires', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'is_unlimited': :'isUnlimited' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/oci/management_agent/models/management_agent_install_key.rb', line 97 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'key': :'String', 'created_by_principal_id': :'String', 'compartment_id': :'String', 'allowed_key_install_count': :'Integer', 'current_key_install_count': :'Integer', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'time_expires': :'DateTime', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'is_unlimited': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/oci/management_agent/models/management_agent_install_key.rb', line 235 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && key == other.key && created_by_principal_id == other.created_by_principal_id && compartment_id == other.compartment_id && allowed_key_install_count == other.allowed_key_install_count && current_key_install_count == other.current_key_install_count && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && time_expires == other.time_expires && time_created == other.time_created && time_updated == other.time_updated && is_unlimited == other.is_unlimited end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/oci/management_agent/models/management_agent_install_key.rb', line 277 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
257 258 259 |
# File 'lib/oci/management_agent/models/management_agent_install_key.rb', line 257 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
266 267 268 |
# File 'lib/oci/management_agent/models/management_agent_install_key.rb', line 266 def hash [id, display_name, key, created_by_principal_id, compartment_id, allowed_key_install_count, current_key_install_count, lifecycle_state, lifecycle_details, time_expires, time_created, time_updated, is_unlimited].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
310 311 312 313 314 315 316 317 318 319 |
# File 'lib/oci/management_agent/models/management_agent_install_key.rb', line 310 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
304 305 306 |
# File 'lib/oci/management_agent/models/management_agent_install_key.rb', line 304 def to_s to_hash.to_s end |