Class: OCI::ManagementAgent::Models::ManagementAgentInstallKeySummary
- Inherits:
-
Object
- Object
- OCI::ManagementAgent::Models::ManagementAgentInstallKeySummary
- Defined in:
- lib/oci/management_agent/models/management_agent_install_key_summary.rb
Overview
The summary of the Agent Install Key details.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#allowed_key_install_count ⇒ Integer
Total number of install for this keys.
-
#compartment_id ⇒ String
**[Required]** Compartment Identifier.
-
#created_by_principal_id ⇒ String
Principal id of user who created the Agent Install key.
-
#current_key_install_count ⇒ Integer
Total number of install for this keys.
-
#display_name ⇒ String
Management Agent Install Key Name.
-
#id ⇒ String
**[Required]** Agent Install Key identifier.
-
#is_unlimited ⇒ BOOLEAN
If set to true, the install key has no expiration date or usage limit.
-
#lifecycle_details ⇒ String
A message describing the current state in more detail.
-
#lifecycle_state ⇒ String
Status of Key.
-
#time_created ⇒ DateTime
The time when Management Agent install Key was created.
-
#time_expires ⇒ DateTime
date after which key would expire after creation.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ManagementAgentInstallKeySummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ManagementAgentInstallKeySummary
Initializes the object
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/oci/management_agent/models/management_agent_install_key_summary.rb', line 122 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.created_by_principal_id = attributes[:'createdByPrincipalId'] if attributes[:'createdByPrincipalId'] raise 'You cannot provide both :createdByPrincipalId and :created_by_principal_id' if attributes.key?(:'createdByPrincipalId') && attributes.key?(:'created_by_principal_id') self.created_by_principal_id = attributes[:'created_by_principal_id'] if attributes[:'created_by_principal_id'] self.allowed_key_install_count = attributes[:'allowedKeyInstallCount'] if attributes[:'allowedKeyInstallCount'] raise 'You cannot provide both :allowedKeyInstallCount and :allowed_key_install_count' if attributes.key?(:'allowedKeyInstallCount') && attributes.key?(:'allowed_key_install_count') self.allowed_key_install_count = attributes[:'allowed_key_install_count'] if attributes[:'allowed_key_install_count'] self.current_key_install_count = attributes[:'currentKeyInstallCount'] if attributes[:'currentKeyInstallCount'] raise 'You cannot provide both :currentKeyInstallCount and :current_key_install_count' if attributes.key?(:'currentKeyInstallCount') && attributes.key?(:'current_key_install_count') self.current_key_install_count = attributes[:'current_key_install_count'] if attributes[:'current_key_install_count'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_expires = attributes[:'timeExpires'] if attributes[:'timeExpires'] raise 'You cannot provide both :timeExpires and :time_expires' if attributes.key?(:'timeExpires') && attributes.key?(:'time_expires') self.time_expires = attributes[:'time_expires'] if attributes[:'time_expires'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.is_unlimited = attributes[:'isUnlimited'] unless attributes[:'isUnlimited'].nil? self.is_unlimited = false if is_unlimited.nil? && !attributes.key?(:'isUnlimited') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isUnlimited and :is_unlimited' if attributes.key?(:'isUnlimited') && attributes.key?(:'is_unlimited') self.is_unlimited = attributes[:'is_unlimited'] unless attributes[:'is_unlimited'].nil? self.is_unlimited = false if is_unlimited.nil? && !attributes.key?(:'isUnlimited') && !attributes.key?(:'is_unlimited') # rubocop:disable Style/StringLiterals end |
Instance Attribute Details
#allowed_key_install_count ⇒ Integer
Total number of install for this keys
37 38 39 |
# File 'lib/oci/management_agent/models/management_agent_install_key_summary.rb', line 37 def allowed_key_install_count @allowed_key_install_count end |
#compartment_id ⇒ String
**[Required]** Compartment Identifier
61 62 63 |
# File 'lib/oci/management_agent/models/management_agent_install_key_summary.rb', line 61 def compartment_id @compartment_id end |
#created_by_principal_id ⇒ String
Principal id of user who created the Agent Install key
33 34 35 |
# File 'lib/oci/management_agent/models/management_agent_install_key_summary.rb', line 33 def created_by_principal_id @created_by_principal_id end |
#current_key_install_count ⇒ Integer
Total number of install for this keys
41 42 43 |
# File 'lib/oci/management_agent/models/management_agent_install_key_summary.rb', line 41 def current_key_install_count @current_key_install_count end |
#display_name ⇒ String
Management Agent Install Key Name
29 30 31 |
# File 'lib/oci/management_agent/models/management_agent_install_key_summary.rb', line 29 def display_name @display_name end |
#id ⇒ String
**[Required]** Agent Install Key identifier
25 26 27 |
# File 'lib/oci/management_agent/models/management_agent_install_key_summary.rb', line 25 def id @id end |
#is_unlimited ⇒ BOOLEAN
If set to true, the install key has no expiration date or usage limit. Properties allowedKeyInstallCount and timeExpires are ignored if set to true. Defaults to false.
65 66 67 |
# File 'lib/oci/management_agent/models/management_agent_install_key_summary.rb', line 65 def is_unlimited @is_unlimited end |
#lifecycle_details ⇒ String
A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
49 50 51 |
# File 'lib/oci/management_agent/models/management_agent_install_key_summary.rb', line 49 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
Status of Key
45 46 47 |
# File 'lib/oci/management_agent/models/management_agent_install_key_summary.rb', line 45 def lifecycle_state @lifecycle_state end |
#time_created ⇒ DateTime
The time when Management Agent install Key was created. An RFC3339 formatted date time string
53 54 55 |
# File 'lib/oci/management_agent/models/management_agent_install_key_summary.rb', line 53 def time_created @time_created end |
#time_expires ⇒ DateTime
date after which key would expire after creation
57 58 59 |
# File 'lib/oci/management_agent/models/management_agent_install_key_summary.rb', line 57 def time_expires @time_expires end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/oci/management_agent/models/management_agent_install_key_summary.rb', line 68 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'created_by_principal_id': :'createdByPrincipalId', 'allowed_key_install_count': :'allowedKeyInstallCount', 'current_key_install_count': :'currentKeyInstallCount', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'time_created': :'timeCreated', 'time_expires': :'timeExpires', 'compartment_id': :'compartmentId', 'is_unlimited': :'isUnlimited' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/oci/management_agent/models/management_agent_install_key_summary.rb', line 87 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'created_by_principal_id': :'String', 'allowed_key_install_count': :'Integer', 'current_key_install_count': :'Integer', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'time_created': :'DateTime', 'time_expires': :'DateTime', 'compartment_id': :'String', 'is_unlimited': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/oci/management_agent/models/management_agent_install_key_summary.rb', line 213 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && created_by_principal_id == other.created_by_principal_id && allowed_key_install_count == other.allowed_key_install_count && current_key_install_count == other.current_key_install_count && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && time_created == other.time_created && time_expires == other.time_expires && compartment_id == other.compartment_id && is_unlimited == other.is_unlimited end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/oci/management_agent/models/management_agent_install_key_summary.rb', line 253 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
233 234 235 |
# File 'lib/oci/management_agent/models/management_agent_install_key_summary.rb', line 233 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
242 243 244 |
# File 'lib/oci/management_agent/models/management_agent_install_key_summary.rb', line 242 def hash [id, display_name, created_by_principal_id, allowed_key_install_count, current_key_install_count, lifecycle_state, lifecycle_details, time_created, time_expires, compartment_id, is_unlimited].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
286 287 288 289 290 291 292 293 294 295 |
# File 'lib/oci/management_agent/models/management_agent_install_key_summary.rb', line 286 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
280 281 282 |
# File 'lib/oci/management_agent/models/management_agent_install_key_summary.rb', line 280 def to_s to_hash.to_s end |