Class: OCI::ManagementAgent::Models::ManagementAgentPluginSummary
- Inherits:
-
Object
- Object
- OCI::ManagementAgent::Models::ManagementAgentPluginSummary
- Defined in:
- lib/oci/management_agent/models/management_agent_plugin_summary.rb
Overview
Summary of the ManagementAgentPlugin.
Constant Summary collapse
- SUPPORTED_PLATFORM_TYPES_ENUM =
[ SUPPORTED_PLATFORM_TYPES_LINUX = 'LINUX'.freeze, SUPPORTED_PLATFORM_TYPES_WINDOWS = 'WINDOWS'.freeze, SUPPORTED_PLATFORM_TYPES_SOLARIS = 'SOLARIS'.freeze, SUPPORTED_PLATFORM_TYPES_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#description ⇒ String
Management Agent Plugin description.
-
#display_name ⇒ String
Management Agent Plugin Display Name.
-
#id ⇒ String
**[Required]** Management Agent Plugin Id.
-
#is_console_deployable ⇒ BOOLEAN
A flag to indicate whether a given plugin can be deployed from Agent Console UI or not.
-
#lifecycle_state ⇒ String
**[Required]** The current state of Management Agent Plugin.
-
#name ⇒ String
**[Required]** Management Agent Plugin Name.
-
#supported_platform_types ⇒ Array<String>
Supported Platform Types.
-
#version ⇒ Integer
Management Agent Plugin Version.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ManagementAgentPluginSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ManagementAgentPluginSummary
Initializes the object
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/oci/management_agent/models/management_agent_plugin_summary.rb', line 108 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.name = attributes[:'name'] if attributes[:'name'] self.version = attributes[:'version'] if attributes[:'version'] self.supported_platform_types = attributes[:'supportedPlatformTypes'] if attributes[:'supportedPlatformTypes'] raise 'You cannot provide both :supportedPlatformTypes and :supported_platform_types' if attributes.key?(:'supportedPlatformTypes') && attributes.key?(:'supported_platform_types') self.supported_platform_types = attributes[:'supported_platform_types'] if attributes[:'supported_platform_types'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.is_console_deployable = attributes[:'isConsoleDeployable'] unless attributes[:'isConsoleDeployable'].nil? self.is_console_deployable = true if is_console_deployable.nil? && !attributes.key?(:'isConsoleDeployable') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isConsoleDeployable and :is_console_deployable' if attributes.key?(:'isConsoleDeployable') && attributes.key?(:'is_console_deployable') self.is_console_deployable = attributes[:'is_console_deployable'] unless attributes[:'is_console_deployable'].nil? self.is_console_deployable = true if is_console_deployable.nil? && !attributes.key?(:'isConsoleDeployable') && !attributes.key?(:'is_console_deployable') # rubocop:disable Style/StringLiterals self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] end |
Instance Attribute Details
#description ⇒ String
Management Agent Plugin description
52 53 54 |
# File 'lib/oci/management_agent/models/management_agent_plugin_summary.rb', line 52 def description @description end |
#display_name ⇒ String
Management Agent Plugin Display Name
48 49 50 |
# File 'lib/oci/management_agent/models/management_agent_plugin_summary.rb', line 48 def display_name @display_name end |
#id ⇒ String
**[Required]** Management Agent Plugin Id
32 33 34 |
# File 'lib/oci/management_agent/models/management_agent_plugin_summary.rb', line 32 def id @id end |
#is_console_deployable ⇒ BOOLEAN
A flag to indicate whether a given plugin can be deployed from Agent Console UI or not.
56 57 58 |
# File 'lib/oci/management_agent/models/management_agent_plugin_summary.rb', line 56 def is_console_deployable @is_console_deployable end |
#lifecycle_state ⇒ String
**[Required]** The current state of Management Agent Plugin
60 61 62 |
# File 'lib/oci/management_agent/models/management_agent_plugin_summary.rb', line 60 def lifecycle_state @lifecycle_state end |
#name ⇒ String
**[Required]** Management Agent Plugin Name
36 37 38 |
# File 'lib/oci/management_agent/models/management_agent_plugin_summary.rb', line 36 def name @name end |
#supported_platform_types ⇒ Array<String>
Supported Platform Types
44 45 46 |
# File 'lib/oci/management_agent/models/management_agent_plugin_summary.rb', line 44 def supported_platform_types @supported_platform_types end |
#version ⇒ Integer
Management Agent Plugin Version
40 41 42 |
# File 'lib/oci/management_agent/models/management_agent_plugin_summary.rb', line 40 def version @version end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/oci/management_agent/models/management_agent_plugin_summary.rb', line 63 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'name': :'name', 'version': :'version', 'supported_platform_types': :'supportedPlatformTypes', 'display_name': :'displayName', 'description': :'description', 'is_console_deployable': :'isConsoleDeployable', 'lifecycle_state': :'lifecycleState' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/oci/management_agent/models/management_agent_plugin_summary.rb', line 79 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'name': :'String', 'version': :'Integer', 'supported_platform_types': :'Array<String>', 'display_name': :'String', 'description': :'String', 'is_console_deployable': :'BOOLEAN', 'lifecycle_state': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/oci/management_agent/models/management_agent_plugin_summary.rb', line 189 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && name == other.name && version == other.version && supported_platform_types == other.supported_platform_types && display_name == other.display_name && description == other.description && is_console_deployable == other.is_console_deployable && lifecycle_state == other.lifecycle_state end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/oci/management_agent/models/management_agent_plugin_summary.rb', line 226 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
206 207 208 |
# File 'lib/oci/management_agent/models/management_agent_plugin_summary.rb', line 206 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
215 216 217 |
# File 'lib/oci/management_agent/models/management_agent_plugin_summary.rb', line 215 def hash [id, name, version, supported_platform_types, display_name, description, is_console_deployable, lifecycle_state].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
259 260 261 262 263 264 265 266 267 268 |
# File 'lib/oci/management_agent/models/management_agent_plugin_summary.rb', line 259 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
253 254 255 |
# File 'lib/oci/management_agent/models/management_agent_plugin_summary.rb', line 253 def to_s to_hash.to_s end |