Class: OCI::ManagementAgent::Models::WorkRequestResource
- Inherits:
-
Object
- Object
- OCI::ManagementAgent::Models::WorkRequestResource
- Defined in:
- lib/oci/management_agent/models/work_request_resource.rb
Overview
A resource created or operated on by a work request.
Constant Summary collapse
- ACTION_TYPE_ENUM =
[ ACTION_TYPE_CREATED = 'CREATED'.freeze, ACTION_TYPE_UPDATED = 'UPDATED'.freeze, ACTION_TYPE_DELETED = 'DELETED'.freeze, ACTION_TYPE_IN_PROGRESS = 'IN_PROGRESS'.freeze, ACTION_TYPE_RELATED = 'RELATED'.freeze, ACTION_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#action_type ⇒ String
[Required] The way in which this resource is affected by the work tracked in the work request.
-
#entity_type ⇒ String
[Required] The resource type the work request affects.
-
#entity_uri ⇒ String
The URI path that the user can do a GET on to access the resource metadata.
-
#identifier ⇒ String
[Required] The identifier of the resource the work request affects.
-
#metadata ⇒ Object
Additional metadata about the resource that has been operated upon by this work request.
-
#time_accepted ⇒ DateTime
The date and time the request was created, as described in [RFC 3339](tools.ietf.org/rfc/rfc3339), section 14.29.
-
#time_finished ⇒ DateTime
The date and time the request was finished, as described in [RFC 3339](tools.ietf.org/rfc/rfc3339), section 14.29.
-
#time_started ⇒ DateTime
The date and time the request was started, as described in [RFC 3339](tools.ietf.org/rfc/rfc3339), section 14.29.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WorkRequestResource
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ WorkRequestResource
Initializes the object
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/oci/management_agent/models/work_request_resource.rb', line 112 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.entity_type = attributes[:'entityType'] if attributes[:'entityType'] raise 'You cannot provide both :entityType and :entity_type' if attributes.key?(:'entityType') && attributes.key?(:'entity_type') self.entity_type = attributes[:'entity_type'] if attributes[:'entity_type'] self.action_type = attributes[:'actionType'] if attributes[:'actionType'] raise 'You cannot provide both :actionType and :action_type' if attributes.key?(:'actionType') && attributes.key?(:'action_type') self.action_type = attributes[:'action_type'] if attributes[:'action_type'] self.identifier = attributes[:'identifier'] if attributes[:'identifier'] self.entity_uri = attributes[:'entityUri'] if attributes[:'entityUri'] raise 'You cannot provide both :entityUri and :entity_uri' if attributes.key?(:'entityUri') && attributes.key?(:'entity_uri') self.entity_uri = attributes[:'entity_uri'] if attributes[:'entity_uri'] self.time_accepted = attributes[:'timeAccepted'] if attributes[:'timeAccepted'] raise 'You cannot provide both :timeAccepted and :time_accepted' if attributes.key?(:'timeAccepted') && attributes.key?(:'time_accepted') self.time_accepted = attributes[:'time_accepted'] if attributes[:'time_accepted'] self.time_started = attributes[:'timeStarted'] if attributes[:'timeStarted'] raise 'You cannot provide both :timeStarted and :time_started' if attributes.key?(:'timeStarted') && attributes.key?(:'time_started') self.time_started = attributes[:'time_started'] if attributes[:'time_started'] self.time_finished = attributes[:'timeFinished'] if attributes[:'timeFinished'] raise 'You cannot provide both :timeFinished and :time_finished' if attributes.key?(:'timeFinished') && attributes.key?(:'time_finished') self.time_finished = attributes[:'time_finished'] if attributes[:'time_finished'] self. = attributes[:'metadata'] if attributes[:'metadata'] end |
Instance Attribute Details
#action_type ⇒ String
[Required] The way in which this resource is affected by the work tracked in the work request. A resource being created, updated, or deleted will remain in the IN_PROGRESS state until work is complete for that resource at which point it will transition to CREATED, UPDATED, or DELETED, respectively.
30 31 32 |
# File 'lib/oci/management_agent/models/work_request_resource.rb', line 30 def action_type @action_type end |
#entity_type ⇒ String
[Required] The resource type the work request affects.
22 23 24 |
# File 'lib/oci/management_agent/models/work_request_resource.rb', line 22 def entity_type @entity_type end |
#entity_uri ⇒ String
The URI path that the user can do a GET on to access the resource metadata
38 39 40 |
# File 'lib/oci/management_agent/models/work_request_resource.rb', line 38 def entity_uri @entity_uri end |
#identifier ⇒ String
[Required] The identifier of the resource the work request affects.
34 35 36 |
# File 'lib/oci/management_agent/models/work_request_resource.rb', line 34 def identifier @identifier end |
#metadata ⇒ Object
Additional metadata about the resource that has been operated upon by this work request. For WorkRequests operationType WORK_DELIVERY the metadata will contain: workDeliveryStatus indicating the status of the work delivery item &WORKDELIVERYSTATUS, workSubmissionKey the WorkSubmission request id,
and workSubmissionDetails containing any details of result
64 65 66 |
# File 'lib/oci/management_agent/models/work_request_resource.rb', line 64 def end |
#time_accepted ⇒ DateTime
The date and time the request was created, as described in [RFC 3339](tools.ietf.org/rfc/rfc3339), section 14.29.
44 45 46 |
# File 'lib/oci/management_agent/models/work_request_resource.rb', line 44 def time_accepted @time_accepted end |
#time_finished ⇒ DateTime
The date and time the request was finished, as described in [RFC 3339](tools.ietf.org/rfc/rfc3339), section 14.29.
56 57 58 |
# File 'lib/oci/management_agent/models/work_request_resource.rb', line 56 def time_finished @time_finished end |
#time_started ⇒ DateTime
The date and time the request was started, as described in [RFC 3339](tools.ietf.org/rfc/rfc3339), section 14.29.
50 51 52 |
# File 'lib/oci/management_agent/models/work_request_resource.rb', line 50 def time_started @time_started end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/oci/management_agent/models/work_request_resource.rb', line 67 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'entity_type': :'entityType', 'action_type': :'actionType', 'identifier': :'identifier', 'entity_uri': :'entityUri', 'time_accepted': :'timeAccepted', 'time_started': :'timeStarted', 'time_finished': :'timeFinished', 'metadata': :'metadata' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/oci/management_agent/models/work_request_resource.rb', line 83 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'entity_type': :'String', 'action_type': :'String', 'identifier': :'String', 'entity_uri': :'String', 'time_accepted': :'DateTime', 'time_started': :'DateTime', 'time_finished': :'DateTime', 'metadata': :'Object' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/oci/management_agent/models/work_request_resource.rb', line 179 def ==(other) return true if equal?(other) self.class == other.class && entity_type == other.entity_type && action_type == other.action_type && identifier == other.identifier && entity_uri == other.entity_uri && time_accepted == other.time_accepted && time_started == other.time_started && time_finished == other.time_finished && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/oci/management_agent/models/work_request_resource.rb', line 216 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
196 197 198 |
# File 'lib/oci/management_agent/models/work_request_resource.rb', line 196 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
205 206 207 |
# File 'lib/oci/management_agent/models/work_request_resource.rb', line 205 def hash [entity_type, action_type, identifier, entity_uri, time_accepted, time_started, time_finished, ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
249 250 251 252 253 254 255 256 257 258 |
# File 'lib/oci/management_agent/models/work_request_resource.rb', line 249 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
243 244 245 |
# File 'lib/oci/management_agent/models/work_request_resource.rb', line 243 def to_s to_hash.to_s end |