Class: OCI::ManagementDashboard::DashxApisClientCompositeOperations

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/management_dashboard/dashx_apis_client_composite_operations.rb

Overview

This class provides a wrapper around DashxApisClient and offers convenience methods for operations that would otherwise need to be chained together. For example, instead of performing an action on a resource (e.g. launching an instance, creating a load balancer) and then using a waiter to wait for the resource to enter a given state, you can call a single method in this class to accomplish the same functionality

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(service_client = OCI::ManagementDashboard::DashxApisClient.new) ⇒ DashxApisClientCompositeOperations

Initializes a new DashxApisClientCompositeOperations

Parameters:

  • service_client (OCI::ManagementDashboard::DashxApisClient) (defaults to: OCI::ManagementDashboard::DashxApisClient.new)

    The client used to communicate with the service. Defaults to a new service client created via OCI::ManagementDashboard::DashxApisClient#initialize with no arguments



20
21
22
# File 'lib/oci/management_dashboard/dashx_apis_client_composite_operations.rb', line 20

def initialize(service_client = OCI::ManagementDashboard::DashxApisClient.new)
  @service_client = service_client
end

Instance Attribute Details

#service_clientOCI::ManagementDashboard::DashxApisClient (readonly)

The OCI::ManagementDashboard::DashxApisClient used to communicate with the service_client

Returns:

  • (OCI::ManagementDashboard::DashxApisClient)


14
15
16
# File 'lib/oci/management_dashboard/dashx_apis_client_composite_operations.rb', line 14

def service_client
  @service_client
end

Instance Method Details

#change_management_dashboards_compartment_and_wait_for_state(management_dashboard_id, change_management_dashboards_compartment_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response

Calls OCI::ManagementDashboard::DashxApisClient#change_management_dashboards_compartment and then waits for the Models::ManagementDashboard acted upon to enter the given state(s).

Parameters:

  • management_dashboard_id (String)

    A unique dashboard identifier.

  • change_management_dashboards_compartment_details (OCI::ManagementDashboard::Models::ChangeManagementDashboardsCompartmentDetails)

    ID of the dashboard that is being moved.

  • wait_for_states (Array<String>) (defaults to: [])

    An array of states to wait on. These should be valid values for Models::ManagementDashboard#lifecycle_state

  • base_operation_opts (Hash) (defaults to: {})

    Any optional arguments accepted by OCI::ManagementDashboard::DashxApisClient#change_management_dashboards_compartment

  • waiter_opts (Hash) (defaults to: {})

    Optional arguments for the waiter. Keys should be symbols, and the following keys are supported:

    • max_interval_seconds: The maximum interval between queries, in seconds.

    • max_wait_seconds The maximum time to wait, in seconds

Returns:



40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
# File 'lib/oci/management_dashboard/dashx_apis_client_composite_operations.rb', line 40

def change_management_dashboards_compartment_and_wait_for_state(management_dashboard_id, change_management_dashboards_compartment_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {})
  operation_result = @service_client.change_management_dashboards_compartment(management_dashboard_id, change_management_dashboards_compartment_details, base_operation_opts)

  return operation_result if wait_for_states.empty?

  lowered_wait_for_states = wait_for_states.map(&:downcase)
  wait_for_resource_id = operation_result.data.id

  begin
    waiter_result = @service_client.get_management_dashboard(wait_for_resource_id).wait_until(
      eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) },
      max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30,
      max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200
    )
    result_to_return = waiter_result

    return result_to_return
  rescue StandardError
    raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result])
  end
end

#change_management_saved_searches_compartment_and_wait_for_state(management_saved_search_id, change_management_saved_searches_compartment_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response

Calls OCI::ManagementDashboard::DashxApisClient#change_management_saved_searches_compartment and then waits for the Models::ManagementSavedSearch acted upon to enter the given state(s).

Parameters:

  • management_saved_search_id (String)

    A unique saved search identifier.

  • change_management_saved_searches_compartment_details (OCI::ManagementDashboard::Models::ChangeManagementSavedSearchesCompartmentDetails)

    ID of the saved search that is being moved.

  • wait_for_states (Array<String>) (defaults to: [])

    An array of states to wait on. These should be valid values for Models::ManagementSavedSearch#lifecycle_state

  • base_operation_opts (Hash) (defaults to: {})

    Any optional arguments accepted by OCI::ManagementDashboard::DashxApisClient#change_management_saved_searches_compartment

  • waiter_opts (Hash) (defaults to: {})

    Optional arguments for the waiter. Keys should be symbols, and the following keys are supported:

    • max_interval_seconds: The maximum interval between queries, in seconds.

    • max_wait_seconds The maximum time to wait, in seconds

Returns:



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/oci/management_dashboard/dashx_apis_client_composite_operations.rb', line 80

def change_management_saved_searches_compartment_and_wait_for_state(management_saved_search_id, change_management_saved_searches_compartment_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {})
  operation_result = @service_client.change_management_saved_searches_compartment(management_saved_search_id, change_management_saved_searches_compartment_details, base_operation_opts)

  return operation_result if wait_for_states.empty?

  lowered_wait_for_states = wait_for_states.map(&:downcase)
  wait_for_resource_id = operation_result.data.id

  begin
    waiter_result = @service_client.get_management_saved_search(wait_for_resource_id).wait_until(
      eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) },
      max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30,
      max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200
    )
    result_to_return = waiter_result

    return result_to_return
  rescue StandardError
    raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result])
  end
end

#create_management_dashboard_and_wait_for_state(create_management_dashboard_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response

Calls OCI::ManagementDashboard::DashxApisClient#create_management_dashboard and then waits for the Models::ManagementDashboard acted upon to enter the given state(s).

Parameters:

  • create_management_dashboard_details (OCI::ManagementDashboard::Models::CreateManagementDashboardDetails)

    JSON metadata for creating a new dashboard.

  • wait_for_states (Array<String>) (defaults to: [])

    An array of states to wait on. These should be valid values for Models::ManagementDashboard#lifecycle_state

  • base_operation_opts (Hash) (defaults to: {})

    Any optional arguments accepted by OCI::ManagementDashboard::DashxApisClient#create_management_dashboard

  • waiter_opts (Hash) (defaults to: {})

    Optional arguments for the waiter. Keys should be symbols, and the following keys are supported:

    • max_interval_seconds: The maximum interval between queries, in seconds.

    • max_wait_seconds The maximum time to wait, in seconds

Returns:



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/oci/management_dashboard/dashx_apis_client_composite_operations.rb', line 119

def create_management_dashboard_and_wait_for_state(create_management_dashboard_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {})
  operation_result = @service_client.create_management_dashboard(create_management_dashboard_details, base_operation_opts)

  return operation_result if wait_for_states.empty?

  lowered_wait_for_states = wait_for_states.map(&:downcase)
  wait_for_resource_id = operation_result.data.id

  begin
    waiter_result = @service_client.get_management_dashboard(wait_for_resource_id).wait_until(
      eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) },
      max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30,
      max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200
    )
    result_to_return = waiter_result

    return result_to_return
  rescue StandardError
    raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result])
  end
end

#create_management_saved_search_and_wait_for_state(create_management_saved_search_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response

Calls OCI::ManagementDashboard::DashxApisClient#create_management_saved_search and then waits for the Models::ManagementSavedSearch acted upon to enter the given state(s).

Parameters:

  • create_management_saved_search_details (OCI::ManagementDashboard::Models::CreateManagementSavedSearchDetails)

    JSON metadata for the saved search.

  • wait_for_states (Array<String>) (defaults to: [])

    An array of states to wait on. These should be valid values for Models::ManagementSavedSearch#lifecycle_state

  • base_operation_opts (Hash) (defaults to: {})

    Any optional arguments accepted by OCI::ManagementDashboard::DashxApisClient#create_management_saved_search

  • waiter_opts (Hash) (defaults to: {})

    Optional arguments for the waiter. Keys should be symbols, and the following keys are supported:

    • max_interval_seconds: The maximum interval between queries, in seconds.

    • max_wait_seconds The maximum time to wait, in seconds

Returns:



158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/oci/management_dashboard/dashx_apis_client_composite_operations.rb', line 158

def create_management_saved_search_and_wait_for_state(create_management_saved_search_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {})
  operation_result = @service_client.create_management_saved_search(create_management_saved_search_details, base_operation_opts)

  return operation_result if wait_for_states.empty?

  lowered_wait_for_states = wait_for_states.map(&:downcase)
  wait_for_resource_id = operation_result.data.id

  begin
    waiter_result = @service_client.get_management_saved_search(wait_for_resource_id).wait_until(
      eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) },
      max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30,
      max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200
    )
    result_to_return = waiter_result

    return result_to_return
  rescue StandardError
    raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result])
  end
end

#delete_management_dashboard_and_wait_for_state(management_dashboard_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response

Calls OCI::ManagementDashboard::DashxApisClient#delete_management_dashboard and then waits for the Models::ManagementDashboard acted upon to enter the given state(s).

Parameters:

  • management_dashboard_id (String)

    A unique dashboard identifier.

  • wait_for_states (Array<String>) (defaults to: [])

    An array of states to wait on. These should be valid values for Models::ManagementDashboard#lifecycle_state

  • base_operation_opts (Hash) (defaults to: {})

    Any optional arguments accepted by OCI::ManagementDashboard::DashxApisClient#delete_management_dashboard

  • waiter_opts (Hash) (defaults to: {})

    Optional arguments for the waiter. Keys should be symbols, and the following keys are supported:

    • max_interval_seconds: The maximum interval between queries, in seconds.

    • max_wait_seconds The maximum time to wait, in seconds

Returns:



197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/oci/management_dashboard/dashx_apis_client_composite_operations.rb', line 197

def delete_management_dashboard_and_wait_for_state(management_dashboard_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {})
  initial_get_result = @service_client.get_management_dashboard(management_dashboard_id)
  operation_result = @service_client.delete_management_dashboard(management_dashboard_id, base_operation_opts)

  return operation_result if wait_for_states.empty?

  lowered_wait_for_states = wait_for_states.map(&:downcase)

  begin
    waiter_result = initial_get_result.wait_until(
      eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) },
      max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30,
      max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200,
      succeed_on_not_found: true
    )
    result_to_return = waiter_result

    return result_to_return
  rescue StandardError
    raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result])
  end
end

#delete_management_saved_search_and_wait_for_state(management_saved_search_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response

Calls OCI::ManagementDashboard::DashxApisClient#delete_management_saved_search and then waits for the Models::ManagementSavedSearch acted upon to enter the given state(s).

Parameters:

  • management_saved_search_id (String)

    A unique saved search identifier.

  • wait_for_states (Array<String>) (defaults to: [])

    An array of states to wait on. These should be valid values for Models::ManagementSavedSearch#lifecycle_state

  • base_operation_opts (Hash) (defaults to: {})

    Any optional arguments accepted by OCI::ManagementDashboard::DashxApisClient#delete_management_saved_search

  • waiter_opts (Hash) (defaults to: {})

    Optional arguments for the waiter. Keys should be symbols, and the following keys are supported:

    • max_interval_seconds: The maximum interval between queries, in seconds.

    • max_wait_seconds The maximum time to wait, in seconds

Returns:



237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/oci/management_dashboard/dashx_apis_client_composite_operations.rb', line 237

def delete_management_saved_search_and_wait_for_state(management_saved_search_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {})
  initial_get_result = @service_client.get_management_saved_search(management_saved_search_id)
  operation_result = @service_client.delete_management_saved_search(management_saved_search_id, base_operation_opts)

  return operation_result if wait_for_states.empty?

  lowered_wait_for_states = wait_for_states.map(&:downcase)

  begin
    waiter_result = initial_get_result.wait_until(
      eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) },
      max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30,
      max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200,
      succeed_on_not_found: true
    )
    result_to_return = waiter_result

    return result_to_return
  rescue StandardError
    raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result])
  end
end

#update_management_dashboard_and_wait_for_state(management_dashboard_id, update_management_dashboard_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response

Calls OCI::ManagementDashboard::DashxApisClient#update_management_dashboard and then waits for the Models::ManagementDashboard acted upon to enter the given state(s).

Parameters:

  • management_dashboard_id (String)

    A unique dashboard identifier.

  • update_management_dashboard_details (OCI::ManagementDashboard::Models::UpdateManagementDashboardDetails)

    JSON metadata for changed dashboard properties.

  • wait_for_states (Array<String>) (defaults to: [])

    An array of states to wait on. These should be valid values for Models::ManagementDashboard#lifecycle_state

  • base_operation_opts (Hash) (defaults to: {})

    Any optional arguments accepted by OCI::ManagementDashboard::DashxApisClient#update_management_dashboard

  • waiter_opts (Hash) (defaults to: {})

    Optional arguments for the waiter. Keys should be symbols, and the following keys are supported:

    • max_interval_seconds: The maximum interval between queries, in seconds.

    • max_wait_seconds The maximum time to wait, in seconds

Returns:



278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
# File 'lib/oci/management_dashboard/dashx_apis_client_composite_operations.rb', line 278

def update_management_dashboard_and_wait_for_state(management_dashboard_id, update_management_dashboard_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {})
  operation_result = @service_client.update_management_dashboard(management_dashboard_id, update_management_dashboard_details, base_operation_opts)

  return operation_result if wait_for_states.empty?

  lowered_wait_for_states = wait_for_states.map(&:downcase)
  wait_for_resource_id = operation_result.data.id

  begin
    waiter_result = @service_client.get_management_dashboard(wait_for_resource_id).wait_until(
      eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) },
      max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30,
      max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200
    )
    result_to_return = waiter_result

    return result_to_return
  rescue StandardError
    raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result])
  end
end

#update_management_saved_search_and_wait_for_state(management_saved_search_id, update_management_saved_search_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response

Calls OCI::ManagementDashboard::DashxApisClient#update_management_saved_search and then waits for the Models::ManagementSavedSearch acted upon to enter the given state(s).

Parameters:

  • management_saved_search_id (String)

    A unique saved search identifier.

  • update_management_saved_search_details (OCI::ManagementDashboard::Models::UpdateManagementSavedSearchDetails)

    JSON metadata for changed saved search properties.

  • wait_for_states (Array<String>) (defaults to: [])

    An array of states to wait on. These should be valid values for Models::ManagementSavedSearch#lifecycle_state

  • base_operation_opts (Hash) (defaults to: {})

    Any optional arguments accepted by OCI::ManagementDashboard::DashxApisClient#update_management_saved_search

  • waiter_opts (Hash) (defaults to: {})

    Optional arguments for the waiter. Keys should be symbols, and the following keys are supported:

    • max_interval_seconds: The maximum interval between queries, in seconds.

    • max_wait_seconds The maximum time to wait, in seconds

Returns:



318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
# File 'lib/oci/management_dashboard/dashx_apis_client_composite_operations.rb', line 318

def update_management_saved_search_and_wait_for_state(management_saved_search_id, update_management_saved_search_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {})
  operation_result = @service_client.update_management_saved_search(management_saved_search_id, update_management_saved_search_details, base_operation_opts)

  return operation_result if wait_for_states.empty?

  lowered_wait_for_states = wait_for_states.map(&:downcase)
  wait_for_resource_id = operation_result.data.id

  begin
    waiter_result = @service_client.get_management_saved_search(wait_for_resource_id).wait_until(
      eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) },
      max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30,
      max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200
    )
    result_to_return = waiter_result

    return result_to_return
  rescue StandardError
    raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result])
  end
end