Class: OCI::ManagementDashboard::Models::CreateManagementSavedSearchDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/management_dashboard/models/create_management_saved_search_details.rb

Overview

Properties of a saved search.

Constant Summary collapse

TYPE_ENUM =
[
  TYPE_SEARCH_SHOW_IN_DASHBOARD = 'SEARCH_SHOW_IN_DASHBOARD'.freeze,
  TYPE_SEARCH_DONT_SHOW_IN_DASHBOARD = 'SEARCH_DONT_SHOW_IN_DASHBOARD'.freeze,
  TYPE_WIDGET_SHOW_IN_DASHBOARD = 'WIDGET_SHOW_IN_DASHBOARD'.freeze,
  TYPE_WIDGET_DONT_SHOW_IN_DASHBOARD = 'WIDGET_DONT_SHOW_IN_DASHBOARD'.freeze,
  TYPE_FILTER_SHOW_IN_DASHBOARD = 'FILTER_SHOW_IN_DASHBOARD'.freeze,
  TYPE_FILTER_DONT_SHOW_IN_DASHBOARD = 'FILTER_DONT_SHOW_IN_DASHBOARD'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateManagementSavedSearchDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :display_name (String)

    The value to assign to the #display_name property

  • :provider_id (String)

    The value to assign to the #provider_id property

  • :provider_version (String)

    The value to assign to the #provider_version property

  • :provider_name (String)

    The value to assign to the #provider_name property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :is_oob_saved_search (BOOLEAN)

    The value to assign to the #is_oob_saved_search property

  • :description (String)

    The value to assign to the #description property

  • :nls (Object)

    The value to assign to the #nls property

  • :type (String)

    The value to assign to the #type property

  • :ui_config (Object)

    The value to assign to the #ui_config property

  • :data_config (Array<Object>)

    The value to assign to the #data_config property

  • :screen_image (String)

    The value to assign to the #screen_image property

  • :metadata_version (String)

    The value to assign to the #metadata_version property

  • :widget_template (String)

    The value to assign to the #widget_template property

  • :widget_vm (String)

    The value to assign to the #widget_vm property

  • :parameters_config (Array<Object>)

    The value to assign to the #parameters_config property

  • :drilldown_config (Array<Object>)

    The value to assign to the #drilldown_config property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property



185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/oci/management_dashboard/models/create_management_saved_search_details.rb', line 185

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.provider_id = attributes[:'providerId'] if attributes[:'providerId']

  raise 'You cannot provide both :providerId and :provider_id' if attributes.key?(:'providerId') && attributes.key?(:'provider_id')

  self.provider_id = attributes[:'provider_id'] if attributes[:'provider_id']

  self.provider_version = attributes[:'providerVersion'] if attributes[:'providerVersion']

  raise 'You cannot provide both :providerVersion and :provider_version' if attributes.key?(:'providerVersion') && attributes.key?(:'provider_version')

  self.provider_version = attributes[:'provider_version'] if attributes[:'provider_version']

  self.provider_name = attributes[:'providerName'] if attributes[:'providerName']

  raise 'You cannot provide both :providerName and :provider_name' if attributes.key?(:'providerName') && attributes.key?(:'provider_name')

  self.provider_name = attributes[:'provider_name'] if attributes[:'provider_name']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.is_oob_saved_search = attributes[:'isOobSavedSearch'] unless attributes[:'isOobSavedSearch'].nil?

  raise 'You cannot provide both :isOobSavedSearch and :is_oob_saved_search' if attributes.key?(:'isOobSavedSearch') && attributes.key?(:'is_oob_saved_search')

  self.is_oob_saved_search = attributes[:'is_oob_saved_search'] unless attributes[:'is_oob_saved_search'].nil?

  self.description = attributes[:'description'] if attributes[:'description']

  self.nls = attributes[:'nls'] if attributes[:'nls']

  self.type = attributes[:'type'] if attributes[:'type']

  self.ui_config = attributes[:'uiConfig'] if attributes[:'uiConfig']

  raise 'You cannot provide both :uiConfig and :ui_config' if attributes.key?(:'uiConfig') && attributes.key?(:'ui_config')

  self.ui_config = attributes[:'ui_config'] if attributes[:'ui_config']

  self.data_config = attributes[:'dataConfig'] if attributes[:'dataConfig']

  raise 'You cannot provide both :dataConfig and :data_config' if attributes.key?(:'dataConfig') && attributes.key?(:'data_config')

  self.data_config = attributes[:'data_config'] if attributes[:'data_config']

  self.screen_image = attributes[:'screenImage'] if attributes[:'screenImage']

  raise 'You cannot provide both :screenImage and :screen_image' if attributes.key?(:'screenImage') && attributes.key?(:'screen_image')

  self.screen_image = attributes[:'screen_image'] if attributes[:'screen_image']

  self. = attributes[:'metadataVersion'] if attributes[:'metadataVersion']

  raise 'You cannot provide both :metadataVersion and :metadata_version' if attributes.key?(:'metadataVersion') && attributes.key?(:'metadata_version')

  self. = attributes[:'metadata_version'] if attributes[:'metadata_version']

  self.widget_template = attributes[:'widgetTemplate'] if attributes[:'widgetTemplate']

  raise 'You cannot provide both :widgetTemplate and :widget_template' if attributes.key?(:'widgetTemplate') && attributes.key?(:'widget_template')

  self.widget_template = attributes[:'widget_template'] if attributes[:'widget_template']

  self.widget_vm = attributes[:'widgetVM'] if attributes[:'widgetVM']

  raise 'You cannot provide both :widgetVM and :widget_vm' if attributes.key?(:'widgetVM') && attributes.key?(:'widget_vm')

  self.widget_vm = attributes[:'widget_vm'] if attributes[:'widget_vm']

  self.parameters_config = attributes[:'parametersConfig'] if attributes[:'parametersConfig']

  raise 'You cannot provide both :parametersConfig and :parameters_config' if attributes.key?(:'parametersConfig') && attributes.key?(:'parameters_config')

  self.parameters_config = attributes[:'parameters_config'] if attributes[:'parameters_config']

  self.drilldown_config = attributes[:'drilldownConfig'] if attributes[:'drilldownConfig']

  raise 'You cannot provide both :drilldownConfig and :drilldown_config' if attributes.key?(:'drilldownConfig') && attributes.key?(:'drilldown_config')

  self.drilldown_config = attributes[:'drilldown_config'] if attributes[:'drilldown_config']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#compartment_idString

**[Required]** OCID of the compartment in which the saved search resides.

Returns:

  • (String)


41
42
43
# File 'lib/oci/management_dashboard/models/create_management_saved_search_details.rb', line 41

def compartment_id
  @compartment_id
end

#data_configArray<Object>

**[Required]** Array of JSON that contain data source options.

Returns:

  • (Array<Object>)


65
66
67
# File 'lib/oci/management_dashboard/models/create_management_saved_search_details.rb', line 65

def data_config
  @data_config
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


101
102
103
# File 'lib/oci/management_dashboard/models/create_management_saved_search_details.rb', line 101

def defined_tags
  @defined_tags
end

#descriptionString

**[Required]** Description of the saved search.

Returns:

  • (String)


49
50
51
# File 'lib/oci/management_dashboard/models/create_management_saved_search_details.rb', line 49

def description
  @description
end

#display_nameString

**[Required]** Display name of the saved search.

Returns:

  • (String)


25
26
27
# File 'lib/oci/management_dashboard/models/create_management_saved_search_details.rb', line 25

def display_name
  @display_name
end

#drilldown_configArray<Object>

Drill-down configuration to define the destination of a drill-down action.

Returns:

  • (Array<Object>)


89
90
91
# File 'lib/oci/management_dashboard/models/create_management_saved_search_details.rb', line 89

def drilldown_config
  @drilldown_config
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`

Returns:

  • (Hash<String, String>)


95
96
97
# File 'lib/oci/management_dashboard/models/create_management_saved_search_details.rb', line 95

def freeform_tags
  @freeform_tags
end

#idString

ID of the saved search, which must only be provided for Out-of-the-Box (OOB) saved search.

Returns:

  • (String)


21
22
23
# File 'lib/oci/management_dashboard/models/create_management_saved_search_details.rb', line 21

def id
  @id
end

#is_oob_saved_searchBOOLEAN

**[Required]** Determines whether the saved search is an Out-of-the-Box (OOB) saved search. Note that OOB saved searches are only provided by Oracle and cannot be modified.

Returns:

  • (BOOLEAN)


45
46
47
# File 'lib/oci/management_dashboard/models/create_management_saved_search_details.rb', line 45

def is_oob_saved_search
  @is_oob_saved_search
end

#metadata_versionString

**[Required]** Version of the metadata.

Returns:

  • (String)


73
74
75
# File 'lib/oci/management_dashboard/models/create_management_saved_search_details.rb', line 73

def 
  @metadata_version
end

#nlsObject

**[Required]** JSON that contains internationalization options.

Returns:

  • (Object)


53
54
55
# File 'lib/oci/management_dashboard/models/create_management_saved_search_details.rb', line 53

def nls
  @nls
end

#parameters_configArray<Object>

Defines parameters for the saved search.

Returns:

  • (Array<Object>)


85
86
87
# File 'lib/oci/management_dashboard/models/create_management_saved_search_details.rb', line 85

def parameters_config
  @parameters_config
end

#provider_idString

**[Required]** ID of the service (for example log-analytics) that owns the saved search. Each service has a unique ID.

Returns:

  • (String)


29
30
31
# File 'lib/oci/management_dashboard/models/create_management_saved_search_details.rb', line 29

def provider_id
  @provider_id
end

#provider_nameString

**[Required]** Name of the service (for example, Logging Analytics) that owns the saved search.

Returns:

  • (String)


37
38
39
# File 'lib/oci/management_dashboard/models/create_management_saved_search_details.rb', line 37

def provider_name
  @provider_name
end

#provider_versionString

**[Required]** Version of the service that owns this saved search.

Returns:

  • (String)


33
34
35
# File 'lib/oci/management_dashboard/models/create_management_saved_search_details.rb', line 33

def provider_version
  @provider_version
end

#screen_imageString

**[Required]** Screen image of the saved search.

Returns:

  • (String)


69
70
71
# File 'lib/oci/management_dashboard/models/create_management_saved_search_details.rb', line 69

def screen_image
  @screen_image
end

#typeString

**[Required]** Determines how the saved search is displayed in a dashboard.

Returns:

  • (String)


57
58
59
# File 'lib/oci/management_dashboard/models/create_management_saved_search_details.rb', line 57

def type
  @type
end

#ui_configObject

**[Required]** JSON that contains user interface options.

Returns:

  • (Object)


61
62
63
# File 'lib/oci/management_dashboard/models/create_management_saved_search_details.rb', line 61

def ui_config
  @ui_config
end

#widget_templateString

**[Required]** Reference to the HTML file of the widget.

Returns:

  • (String)


77
78
79
# File 'lib/oci/management_dashboard/models/create_management_saved_search_details.rb', line 77

def widget_template
  @widget_template
end

#widget_vmString

**[Required]** Reference to the view model of the widget.

Returns:

  • (String)


81
82
83
# File 'lib/oci/management_dashboard/models/create_management_saved_search_details.rb', line 81

def widget_vm
  @widget_vm
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/oci/management_dashboard/models/create_management_saved_search_details.rb', line 104

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'display_name': :'displayName',
    'provider_id': :'providerId',
    'provider_version': :'providerVersion',
    'provider_name': :'providerName',
    'compartment_id': :'compartmentId',
    'is_oob_saved_search': :'isOobSavedSearch',
    'description': :'description',
    'nls': :'nls',
    'type': :'type',
    'ui_config': :'uiConfig',
    'data_config': :'dataConfig',
    'screen_image': :'screenImage',
    'metadata_version': :'metadataVersion',
    'widget_template': :'widgetTemplate',
    'widget_vm': :'widgetVM',
    'parameters_config': :'parametersConfig',
    'drilldown_config': :'drilldownConfig',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/oci/management_dashboard/models/create_management_saved_search_details.rb', line 132

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'display_name': :'String',
    'provider_id': :'String',
    'provider_version': :'String',
    'provider_name': :'String',
    'compartment_id': :'String',
    'is_oob_saved_search': :'BOOLEAN',
    'description': :'String',
    'nls': :'Object',
    'type': :'String',
    'ui_config': :'Object',
    'data_config': :'Array<Object>',
    'screen_image': :'String',
    'metadata_version': :'String',
    'widget_template': :'String',
    'widget_vm': :'String',
    'parameters_config': :'Array<Object>',
    'drilldown_config': :'Array<Object>',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'lib/oci/management_dashboard/models/create_management_saved_search_details.rb', line 311

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    display_name == other.display_name &&
    provider_id == other.provider_id &&
    provider_version == other.provider_version &&
    provider_name == other.provider_name &&
    compartment_id == other.compartment_id &&
    is_oob_saved_search == other.is_oob_saved_search &&
    description == other.description &&
    nls == other.nls &&
    type == other.type &&
    ui_config == other.ui_config &&
    data_config == other.data_config &&
    screen_image == other.screen_image &&
     == other. &&
    widget_template == other.widget_template &&
    widget_vm == other.widget_vm &&
    parameters_config == other.parameters_config &&
    drilldown_config == other.drilldown_config &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
# File 'lib/oci/management_dashboard/models/create_management_saved_search_details.rb', line 360

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


340
341
342
# File 'lib/oci/management_dashboard/models/create_management_saved_search_details.rb', line 340

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



349
350
351
# File 'lib/oci/management_dashboard/models/create_management_saved_search_details.rb', line 349

def hash
  [id, display_name, provider_id, provider_version, provider_name, compartment_id, is_oob_saved_search, description, nls, type, ui_config, data_config, screen_image, , widget_template, widget_vm, parameters_config, drilldown_config, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



393
394
395
396
397
398
399
400
401
402
# File 'lib/oci/management_dashboard/models/create_management_saved_search_details.rb', line 393

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



387
388
389
# File 'lib/oci/management_dashboard/models/create_management_saved_search_details.rb', line 387

def to_s
  to_hash.to_s
end