Class: OCI::ManagementDashboard::Models::ManagementDashboardSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/management_dashboard/models/management_dashboard_summary.rb

Overview

Summary of the properties of a dashboard.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ManagementDashboardSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :dashboard_id (String)

    The value to assign to the #dashboard_id property

  • :id (String)

    The value to assign to the #id property

  • :display_name (String)

    The value to assign to the #display_name property

  • :description (String)

    The value to assign to the #description property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :provider_id (String)

    The value to assign to the #provider_id property

  • :provider_name (String)

    The value to assign to the #provider_name property

  • :provider_version (String)

    The value to assign to the #provider_version property

  • :is_oob_dashboard (BOOLEAN)

    The value to assign to the #is_oob_dashboard property

  • :created_by (String)

    The value to assign to the #created_by property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :updated_by (String)

    The value to assign to the #updated_by property

  • :time_updated (DateTime)

    The value to assign to the #time_updated property

  • :metadata_version (String)

    The value to assign to the #metadata_version property

  • :screen_image (String)

    The value to assign to the #screen_image property

  • :nls (Object)

    The value to assign to the #nls property

  • :type (String)

    The value to assign to the #type property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property



182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
# File 'lib/oci/management_dashboard/models/management_dashboard_summary.rb', line 182

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.dashboard_id = attributes[:'dashboardId'] if attributes[:'dashboardId']

  raise 'You cannot provide both :dashboardId and :dashboard_id' if attributes.key?(:'dashboardId') && attributes.key?(:'dashboard_id')

  self.dashboard_id = attributes[:'dashboard_id'] if attributes[:'dashboard_id']

  self.id = attributes[:'id'] if attributes[:'id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.provider_id = attributes[:'providerId'] if attributes[:'providerId']

  raise 'You cannot provide both :providerId and :provider_id' if attributes.key?(:'providerId') && attributes.key?(:'provider_id')

  self.provider_id = attributes[:'provider_id'] if attributes[:'provider_id']

  self.provider_name = attributes[:'providerName'] if attributes[:'providerName']

  raise 'You cannot provide both :providerName and :provider_name' if attributes.key?(:'providerName') && attributes.key?(:'provider_name')

  self.provider_name = attributes[:'provider_name'] if attributes[:'provider_name']

  self.provider_version = attributes[:'providerVersion'] if attributes[:'providerVersion']

  raise 'You cannot provide both :providerVersion and :provider_version' if attributes.key?(:'providerVersion') && attributes.key?(:'provider_version')

  self.provider_version = attributes[:'provider_version'] if attributes[:'provider_version']

  self.is_oob_dashboard = attributes[:'isOobDashboard'] unless attributes[:'isOobDashboard'].nil?

  raise 'You cannot provide both :isOobDashboard and :is_oob_dashboard' if attributes.key?(:'isOobDashboard') && attributes.key?(:'is_oob_dashboard')

  self.is_oob_dashboard = attributes[:'is_oob_dashboard'] unless attributes[:'is_oob_dashboard'].nil?

  self.created_by = attributes[:'createdBy'] if attributes[:'createdBy']

  raise 'You cannot provide both :createdBy and :created_by' if attributes.key?(:'createdBy') && attributes.key?(:'created_by')

  self.created_by = attributes[:'created_by'] if attributes[:'created_by']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.updated_by = attributes[:'updatedBy'] if attributes[:'updatedBy']

  raise 'You cannot provide both :updatedBy and :updated_by' if attributes.key?(:'updatedBy') && attributes.key?(:'updated_by')

  self.updated_by = attributes[:'updated_by'] if attributes[:'updated_by']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self. = attributes[:'metadataVersion'] if attributes[:'metadataVersion']

  raise 'You cannot provide both :metadataVersion and :metadata_version' if attributes.key?(:'metadataVersion') && attributes.key?(:'metadata_version')

  self. = attributes[:'metadata_version'] if attributes[:'metadata_version']

  self.screen_image = attributes[:'screenImage'] if attributes[:'screenImage']

  raise 'You cannot provide both :screenImage and :screen_image' if attributes.key?(:'screenImage') && attributes.key?(:'screen_image')

  self.screen_image = attributes[:'screen_image'] if attributes[:'screen_image']

  self.nls = attributes[:'nls'] if attributes[:'nls']

  self.type = attributes[:'type'] if attributes[:'type']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#compartment_idString

**[Required]** OCID of the compartment in which the dashboard resides.

Returns:

  • (String)


34
35
36
# File 'lib/oci/management_dashboard/models/management_dashboard_summary.rb', line 34

def compartment_id
  @compartment_id
end

#created_byString

**[Required]** User who created the dashboard.

Returns:

  • (String)


54
55
56
# File 'lib/oci/management_dashboard/models/management_dashboard_summary.rb', line 54

def created_by
  @created_by
end

#dashboard_idString

**[Required]** ID of the dashboard. Same as id.

Returns:

  • (String)


18
19
20
# File 'lib/oci/management_dashboard/models/management_dashboard_summary.rb', line 18

def dashboard_id
  @dashboard_id
end

#defined_tagsHash<String, Hash<String, Object>>

**[Required]** Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


98
99
100
# File 'lib/oci/management_dashboard/models/management_dashboard_summary.rb', line 98

def defined_tags
  @defined_tags
end

#descriptionString

**[Required]** Description of the dashboard.

Returns:

  • (String)


30
31
32
# File 'lib/oci/management_dashboard/models/management_dashboard_summary.rb', line 30

def description
  @description
end

#display_nameString

**[Required]** Display name of the dashboard.

Returns:

  • (String)


26
27
28
# File 'lib/oci/management_dashboard/models/management_dashboard_summary.rb', line 26

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

**[Required]** Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`

Returns:

  • (Hash<String, String>)


92
93
94
# File 'lib/oci/management_dashboard/models/management_dashboard_summary.rb', line 92

def freeform_tags
  @freeform_tags
end

#idString

**[Required]** ID of the dashboard. Same as dashboardId.

Returns:

  • (String)


22
23
24
# File 'lib/oci/management_dashboard/models/management_dashboard_summary.rb', line 22

def id
  @id
end

#is_oob_dashboardBOOLEAN

**[Required]** Determines whether the dashboard is an Out-of-the-Box (OOB) dashboard. Note that OOB dashboards are only provided by Oracle and cannot be modified.

Returns:

  • (BOOLEAN)


50
51
52
# File 'lib/oci/management_dashboard/models/management_dashboard_summary.rb', line 50

def is_oob_dashboard
  @is_oob_dashboard
end

#lifecycle_stateString

**[Required]** Current lifecycle state of the dashboard.

Returns:

  • (String)


86
87
88
# File 'lib/oci/management_dashboard/models/management_dashboard_summary.rb', line 86

def lifecycle_state
  @lifecycle_state
end

#metadata_versionString

**[Required]** Version of the metadata.

Returns:

  • (String)


70
71
72
# File 'lib/oci/management_dashboard/models/management_dashboard_summary.rb', line 70

def 
  @metadata_version
end

#nlsObject

**[Required]** JSON that contains internationalization options.

Returns:

  • (Object)


78
79
80
# File 'lib/oci/management_dashboard/models/management_dashboard_summary.rb', line 78

def nls
  @nls
end

#provider_idString

**[Required]** ID of the service (for example, log-analytics) that owns the dashboard. Each service has a unique ID.

Returns:

  • (String)


38
39
40
# File 'lib/oci/management_dashboard/models/management_dashboard_summary.rb', line 38

def provider_id
  @provider_id
end

#provider_nameString

**[Required]** Name of the service (for example, Logging Analytics) that owns the dashboard.

Returns:

  • (String)


42
43
44
# File 'lib/oci/management_dashboard/models/management_dashboard_summary.rb', line 42

def provider_name
  @provider_name
end

#provider_versionString

**[Required]** Version of the service that owns the dashboard.

Returns:

  • (String)


46
47
48
# File 'lib/oci/management_dashboard/models/management_dashboard_summary.rb', line 46

def provider_version
  @provider_version
end

#screen_imageString

**[Required]** Screen image of the dashboard.

Returns:

  • (String)


74
75
76
# File 'lib/oci/management_dashboard/models/management_dashboard_summary.rb', line 74

def screen_image
  @screen_image
end

#time_createdDateTime

**[Required]** Date and time the dashboard was created.

Returns:

  • (DateTime)


58
59
60
# File 'lib/oci/management_dashboard/models/management_dashboard_summary.rb', line 58

def time_created
  @time_created
end

#time_updatedDateTime

**[Required]** Date and time the dashboard was updated.

Returns:

  • (DateTime)


66
67
68
# File 'lib/oci/management_dashboard/models/management_dashboard_summary.rb', line 66

def time_updated
  @time_updated
end

#typeString

**[Required]** Type of dashboard. NORMAL denotes a single dashboard and SET denotes a dashboard set.

Returns:

  • (String)


82
83
84
# File 'lib/oci/management_dashboard/models/management_dashboard_summary.rb', line 82

def type
  @type
end

#updated_byString

**[Required]** User who updated the dashboard.

Returns:

  • (String)


62
63
64
# File 'lib/oci/management_dashboard/models/management_dashboard_summary.rb', line 62

def updated_by
  @updated_by
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/oci/management_dashboard/models/management_dashboard_summary.rb', line 101

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'dashboard_id': :'dashboardId',
    'id': :'id',
    'display_name': :'displayName',
    'description': :'description',
    'compartment_id': :'compartmentId',
    'provider_id': :'providerId',
    'provider_name': :'providerName',
    'provider_version': :'providerVersion',
    'is_oob_dashboard': :'isOobDashboard',
    'created_by': :'createdBy',
    'time_created': :'timeCreated',
    'updated_by': :'updatedBy',
    'time_updated': :'timeUpdated',
    'metadata_version': :'metadataVersion',
    'screen_image': :'screenImage',
    'nls': :'nls',
    'type': :'type',
    'lifecycle_state': :'lifecycleState',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/oci/management_dashboard/models/management_dashboard_summary.rb', line 129

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'dashboard_id': :'String',
    'id': :'String',
    'display_name': :'String',
    'description': :'String',
    'compartment_id': :'String',
    'provider_id': :'String',
    'provider_name': :'String',
    'provider_version': :'String',
    'is_oob_dashboard': :'BOOLEAN',
    'created_by': :'String',
    'time_created': :'DateTime',
    'updated_by': :'String',
    'time_updated': :'DateTime',
    'metadata_version': :'String',
    'screen_image': :'String',
    'nls': :'Object',
    'type': :'String',
    'lifecycle_state': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
# File 'lib/oci/management_dashboard/models/management_dashboard_summary.rb', line 313

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    dashboard_id == other.dashboard_id &&
    id == other.id &&
    display_name == other.display_name &&
    description == other.description &&
    compartment_id == other.compartment_id &&
    provider_id == other.provider_id &&
    provider_name == other.provider_name &&
    provider_version == other.provider_version &&
    is_oob_dashboard == other.is_oob_dashboard &&
    created_by == other.created_by &&
    time_created == other.time_created &&
    updated_by == other.updated_by &&
    time_updated == other.time_updated &&
     == other. &&
    screen_image == other.screen_image &&
    nls == other.nls &&
    type == other.type &&
    lifecycle_state == other.lifecycle_state &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
# File 'lib/oci/management_dashboard/models/management_dashboard_summary.rb', line 362

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


342
343
344
# File 'lib/oci/management_dashboard/models/management_dashboard_summary.rb', line 342

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



351
352
353
# File 'lib/oci/management_dashboard/models/management_dashboard_summary.rb', line 351

def hash
  [dashboard_id, id, display_name, description, compartment_id, provider_id, provider_name, provider_version, is_oob_dashboard, created_by, time_created, updated_by, time_updated, , screen_image, nls, type, lifecycle_state, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



395
396
397
398
399
400
401
402
403
404
# File 'lib/oci/management_dashboard/models/management_dashboard_summary.rb', line 395

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



389
390
391
# File 'lib/oci/management_dashboard/models/management_dashboard_summary.rb', line 389

def to_s
  to_hash.to_s
end