Class: OCI::ManagementDashboard::Models::ManagementSavedSearchSummary
- Inherits:
-
Object
- Object
- OCI::ManagementDashboard::Models::ManagementSavedSearchSummary
- Defined in:
- lib/oci/management_dashboard/models/management_saved_search_summary.rb
Overview
Summary of the properties of a saved search.
Constant Summary collapse
- TYPE_ENUM =
[ TYPE_SEARCH_SHOW_IN_DASHBOARD = 'SEARCH_SHOW_IN_DASHBOARD'.freeze, TYPE_SEARCH_DONT_SHOW_IN_DASHBOARD = 'SEARCH_DONT_SHOW_IN_DASHBOARD'.freeze, TYPE_WIDGET_SHOW_IN_DASHBOARD = 'WIDGET_SHOW_IN_DASHBOARD'.freeze, TYPE_WIDGET_DONT_SHOW_IN_DASHBOARD = 'WIDGET_DONT_SHOW_IN_DASHBOARD'.freeze, TYPE_FILTER_SHOW_IN_DASHBOARD = 'FILTER_SHOW_IN_DASHBOARD'.freeze, TYPE_FILTER_DONT_SHOW_IN_DASHBOARD = 'FILTER_DONT_SHOW_IN_DASHBOARD'.freeze, TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** OCID of the compartment in which the saved search resides.
-
#created_by ⇒ String
**[Required]** User who created the saved search.
-
#data_config ⇒ Array<Object>
**[Required]** Array of JSON that contain data source options.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
**[Required]** Description of the saved search.
-
#display_name ⇒ String
**[Required]** Display name of the saved search.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
**[Required]** ID of the saved search.
-
#is_oob_saved_search ⇒ BOOLEAN
**[Required]** Determines whether the saved search is an Out-of-the-Box (OOB) saved search.
-
#lifecycle_state ⇒ String
**[Required]** Current lifecycle state of the saved search.
-
#metadata_version ⇒ String
**[Required]** Version of the metadata.
-
#nls ⇒ Object
**[Required]** JSON that contains internationalization options.
-
#parameters_config ⇒ Array<Object>
Defines parameters for the saved search.
-
#provider_id ⇒ String
**[Required]** ID of the service (for example log-analytics) that owns the saved search.
-
#provider_name ⇒ String
**[Required]** Name of the service (for example, Logging Analytics) that owns the saved search.
-
#provider_version ⇒ String
**[Required]** Version of the service that owns this saved search.
-
#screen_image ⇒ String
**[Required]** Screen image of the saved search.
-
#time_created ⇒ DateTime
**[Required]** Date and time the saved search was created.
-
#time_updated ⇒ DateTime
**[Required]** Date and time the saved search was updated.
-
#type ⇒ String
**[Required]** Determines how the saved search is displayed in a dashboard.
-
#ui_config ⇒ Object
**[Required]** JSON that contains user interface options.
-
#updated_by ⇒ String
**[Required]** User who updated the saved search.
-
#widget_template ⇒ String
**[Required]** Reference to the HTML file of the widget.
-
#widget_vm ⇒ String
**[Required]** Reference to the view model of the widget.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ManagementSavedSearchSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ManagementSavedSearchSummary
Initializes the object
220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 |
# File 'lib/oci/management_dashboard/models/management_saved_search_summary.rb', line 220 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.is_oob_saved_search = attributes[:'isOobSavedSearch'] unless attributes[:'isOobSavedSearch'].nil? raise 'You cannot provide both :isOobSavedSearch and :is_oob_saved_search' if attributes.key?(:'isOobSavedSearch') && attributes.key?(:'is_oob_saved_search') self.is_oob_saved_search = attributes[:'is_oob_saved_search'] unless attributes[:'is_oob_saved_search'].nil? self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.provider_id = attributes[:'providerId'] if attributes[:'providerId'] raise 'You cannot provide both :providerId and :provider_id' if attributes.key?(:'providerId') && attributes.key?(:'provider_id') self.provider_id = attributes[:'provider_id'] if attributes[:'provider_id'] self.provider_version = attributes[:'providerVersion'] if attributes[:'providerVersion'] raise 'You cannot provide both :providerVersion and :provider_version' if attributes.key?(:'providerVersion') && attributes.key?(:'provider_version') self.provider_version = attributes[:'provider_version'] if attributes[:'provider_version'] self.provider_name = attributes[:'providerName'] if attributes[:'providerName'] raise 'You cannot provide both :providerName and :provider_name' if attributes.key?(:'providerName') && attributes.key?(:'provider_name') self.provider_name = attributes[:'provider_name'] if attributes[:'provider_name'] self.description = attributes[:'description'] if attributes[:'description'] self.nls = attributes[:'nls'] if attributes[:'nls'] self.type = attributes[:'type'] if attributes[:'type'] self.ui_config = attributes[:'uiConfig'] if attributes[:'uiConfig'] raise 'You cannot provide both :uiConfig and :ui_config' if attributes.key?(:'uiConfig') && attributes.key?(:'ui_config') self.ui_config = attributes[:'ui_config'] if attributes[:'ui_config'] self.data_config = attributes[:'dataConfig'] if attributes[:'dataConfig'] raise 'You cannot provide both :dataConfig and :data_config' if attributes.key?(:'dataConfig') && attributes.key?(:'data_config') self.data_config = attributes[:'data_config'] if attributes[:'data_config'] self.created_by = attributes[:'createdBy'] if attributes[:'createdBy'] raise 'You cannot provide both :createdBy and :created_by' if attributes.key?(:'createdBy') && attributes.key?(:'created_by') self.created_by = attributes[:'created_by'] if attributes[:'created_by'] self.updated_by = attributes[:'updatedBy'] if attributes[:'updatedBy'] raise 'You cannot provide both :updatedBy and :updated_by' if attributes.key?(:'updatedBy') && attributes.key?(:'updated_by') self.updated_by = attributes[:'updated_by'] if attributes[:'updated_by'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.screen_image = attributes[:'screenImage'] if attributes[:'screenImage'] raise 'You cannot provide both :screenImage and :screen_image' if attributes.key?(:'screenImage') && attributes.key?(:'screen_image') self.screen_image = attributes[:'screen_image'] if attributes[:'screen_image'] self. = attributes[:'metadataVersion'] if attributes[:'metadataVersion'] raise 'You cannot provide both :metadataVersion and :metadata_version' if attributes.key?(:'metadataVersion') && attributes.key?(:'metadata_version') self. = attributes[:'metadata_version'] if attributes[:'metadata_version'] self. = attributes[:'widgetTemplate'] if attributes[:'widgetTemplate'] raise 'You cannot provide both :widgetTemplate and :widget_template' if attributes.key?(:'widgetTemplate') && attributes.key?(:'widget_template') self. = attributes[:'widget_template'] if attributes[:'widget_template'] self. = attributes[:'widgetVM'] if attributes[:'widgetVM'] raise 'You cannot provide both :widgetVM and :widget_vm' if attributes.key?(:'widgetVM') && attributes.key?(:'widget_vm') self. = attributes[:'widget_vm'] if attributes[:'widget_vm'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.parameters_config = attributes[:'parametersConfig'] if attributes[:'parametersConfig'] raise 'You cannot provide both :parametersConfig and :parameters_config' if attributes.key?(:'parametersConfig') && attributes.key?(:'parameters_config') self.parameters_config = attributes[:'parameters_config'] if attributes[:'parameters_config'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** OCID of the compartment in which the saved search resides.
40 41 42 |
# File 'lib/oci/management_dashboard/models/management_saved_search_summary.rb', line 40 def compartment_id @compartment_id end |
#created_by ⇒ String
**[Required]** User who created the saved search.
76 77 78 |
# File 'lib/oci/management_dashboard/models/management_saved_search_summary.rb', line 76 def created_by @created_by end |
#data_config ⇒ Array<Object>
**[Required]** Array of JSON that contain data source options.
72 73 74 |
# File 'lib/oci/management_dashboard/models/management_saved_search_summary.rb', line 72 def data_config @data_config end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
124 125 126 |
# File 'lib/oci/management_dashboard/models/management_saved_search_summary.rb', line 124 def @defined_tags end |
#description ⇒ String
**[Required]** Description of the saved search.
56 57 58 |
# File 'lib/oci/management_dashboard/models/management_saved_search_summary.rb', line 56 def description @description end |
#display_name ⇒ String
**[Required]** Display name of the saved search.
32 33 34 |
# File 'lib/oci/management_dashboard/models/management_saved_search_summary.rb', line 32 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
118 119 120 |
# File 'lib/oci/management_dashboard/models/management_saved_search_summary.rb', line 118 def @freeform_tags end |
#id ⇒ String
**[Required]** ID of the saved search.
28 29 30 |
# File 'lib/oci/management_dashboard/models/management_saved_search_summary.rb', line 28 def id @id end |
#is_oob_saved_search ⇒ BOOLEAN
**[Required]** Determines whether the saved search is an Out-of-the-Box (OOB) saved search. Note that OOB saved searches are only provided by Oracle and cannot be modified.
36 37 38 |
# File 'lib/oci/management_dashboard/models/management_saved_search_summary.rb', line 36 def is_oob_saved_search @is_oob_saved_search end |
#lifecycle_state ⇒ String
**[Required]** Current lifecycle state of the saved search.
108 109 110 |
# File 'lib/oci/management_dashboard/models/management_saved_search_summary.rb', line 108 def lifecycle_state @lifecycle_state end |
#metadata_version ⇒ String
**[Required]** Version of the metadata.
96 97 98 |
# File 'lib/oci/management_dashboard/models/management_saved_search_summary.rb', line 96 def @metadata_version end |
#nls ⇒ Object
**[Required]** JSON that contains internationalization options.
60 61 62 |
# File 'lib/oci/management_dashboard/models/management_saved_search_summary.rb', line 60 def nls @nls end |
#parameters_config ⇒ Array<Object>
Defines parameters for the saved search.
112 113 114 |
# File 'lib/oci/management_dashboard/models/management_saved_search_summary.rb', line 112 def parameters_config @parameters_config end |
#provider_id ⇒ String
**[Required]** ID of the service (for example log-analytics) that owns the saved search. Each service has a unique ID.
44 45 46 |
# File 'lib/oci/management_dashboard/models/management_saved_search_summary.rb', line 44 def provider_id @provider_id end |
#provider_name ⇒ String
**[Required]** Name of the service (for example, Logging Analytics) that owns the saved search.
52 53 54 |
# File 'lib/oci/management_dashboard/models/management_saved_search_summary.rb', line 52 def provider_name @provider_name end |
#provider_version ⇒ String
**[Required]** Version of the service that owns this saved search.
48 49 50 |
# File 'lib/oci/management_dashboard/models/management_saved_search_summary.rb', line 48 def provider_version @provider_version end |
#screen_image ⇒ String
**[Required]** Screen image of the saved search.
92 93 94 |
# File 'lib/oci/management_dashboard/models/management_saved_search_summary.rb', line 92 def screen_image @screen_image end |
#time_created ⇒ DateTime
**[Required]** Date and time the saved search was created.
84 85 86 |
# File 'lib/oci/management_dashboard/models/management_saved_search_summary.rb', line 84 def time_created @time_created end |
#time_updated ⇒ DateTime
**[Required]** Date and time the saved search was updated.
88 89 90 |
# File 'lib/oci/management_dashboard/models/management_saved_search_summary.rb', line 88 def time_updated @time_updated end |
#type ⇒ String
**[Required]** Determines how the saved search is displayed in a dashboard.
64 65 66 |
# File 'lib/oci/management_dashboard/models/management_saved_search_summary.rb', line 64 def type @type end |
#ui_config ⇒ Object
**[Required]** JSON that contains user interface options.
68 69 70 |
# File 'lib/oci/management_dashboard/models/management_saved_search_summary.rb', line 68 def ui_config @ui_config end |
#updated_by ⇒ String
**[Required]** User who updated the saved search.
80 81 82 |
# File 'lib/oci/management_dashboard/models/management_saved_search_summary.rb', line 80 def updated_by @updated_by end |
#widget_template ⇒ String
**[Required]** Reference to the HTML file of the widget.
100 101 102 |
# File 'lib/oci/management_dashboard/models/management_saved_search_summary.rb', line 100 def @widget_template end |
#widget_vm ⇒ String
**[Required]** Reference to the view model of the widget.
104 105 106 |
# File 'lib/oci/management_dashboard/models/management_saved_search_summary.rb', line 104 def @widget_vm end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/oci/management_dashboard/models/management_saved_search_summary.rb', line 127 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'is_oob_saved_search': :'isOobSavedSearch', 'compartment_id': :'compartmentId', 'provider_id': :'providerId', 'provider_version': :'providerVersion', 'provider_name': :'providerName', 'description': :'description', 'nls': :'nls', 'type': :'type', 'ui_config': :'uiConfig', 'data_config': :'dataConfig', 'created_by': :'createdBy', 'updated_by': :'updatedBy', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'screen_image': :'screenImage', 'metadata_version': :'metadataVersion', 'widget_template': :'widgetTemplate', 'widget_vm': :'widgetVM', 'lifecycle_state': :'lifecycleState', 'parameters_config': :'parametersConfig', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/oci/management_dashboard/models/management_saved_search_summary.rb', line 159 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'is_oob_saved_search': :'BOOLEAN', 'compartment_id': :'String', 'provider_id': :'String', 'provider_version': :'String', 'provider_name': :'String', 'description': :'String', 'nls': :'Object', 'type': :'String', 'ui_config': :'Object', 'data_config': :'Array<Object>', 'created_by': :'String', 'updated_by': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'screen_image': :'String', 'metadata_version': :'String', 'widget_template': :'String', 'widget_vm': :'String', 'lifecycle_state': :'String', 'parameters_config': :'Array<Object>', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 |
# File 'lib/oci/management_dashboard/models/management_saved_search_summary.rb', line 388 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && is_oob_saved_search == other.is_oob_saved_search && compartment_id == other.compartment_id && provider_id == other.provider_id && provider_version == other.provider_version && provider_name == other.provider_name && description == other.description && nls == other.nls && type == other.type && ui_config == other.ui_config && data_config == other.data_config && created_by == other.created_by && updated_by == other.updated_by && time_created == other.time_created && time_updated == other.time_updated && screen_image == other.screen_image && == other. && == other. && == other. && lifecycle_state == other.lifecycle_state && parameters_config == other.parameters_config && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/oci/management_dashboard/models/management_saved_search_summary.rb', line 441 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
421 422 423 |
# File 'lib/oci/management_dashboard/models/management_saved_search_summary.rb', line 421 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
430 431 432 |
# File 'lib/oci/management_dashboard/models/management_saved_search_summary.rb', line 430 def hash [id, display_name, is_oob_saved_search, compartment_id, provider_id, provider_version, provider_name, description, nls, type, ui_config, data_config, created_by, updated_by, time_created, time_updated, screen_image, , , , lifecycle_state, parameters_config, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
474 475 476 477 478 479 480 481 482 483 |
# File 'lib/oci/management_dashboard/models/management_saved_search_summary.rb', line 474 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
468 469 470 |
# File 'lib/oci/management_dashboard/models/management_saved_search_summary.rb', line 468 def to_s to_hash.to_s end |