Class: OCI::Marketplace::Models::CreatePublicationDetails
- Inherits:
-
Object
- Object
- OCI::Marketplace::Models::CreatePublicationDetails
- Defined in:
- lib/oci/marketplace/models/create_publication_details.rb
Overview
The model for the parameters needed to create a publication.
Constant Summary collapse
- LISTING_TYPE_ENUM =
[ LISTING_TYPE_COMMUNITY = 'COMMUNITY'.freeze, LISTING_TYPE_PARTNER = 'PARTNER'.freeze, LISTING_TYPE_PRIVATE = 'PRIVATE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment where you want to create the publication.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
The defined tags associated with this resource, if any.
-
#freeform_tags ⇒ Hash<String, String>
The freeform tags associated with this resource, if any.
-
#is_agreement_acknowledged ⇒ BOOLEAN
**[Required]** Whether the publisher acknowledged that they have the right and authority to share the contents of the publication and that they accepted the Oracle terms of use agreements required to create a publication.
-
#listing_type ⇒ String
**[Required]** The publisher category to which the publication belongs.
-
#long_description ⇒ String
A long description of the publication to use in the listing.
-
#name ⇒ String
**[Required]** The name of the publication, which is also used in the listing.
-
#package_details ⇒ OCI::Marketplace::Models::CreatePublicationPackage
This attribute is required.
-
#short_description ⇒ String
**[Required]** A short description of the publication to use in the listing.
-
#support_contacts ⇒ Array<OCI::Marketplace::Models::SupportContact>
**[Required]** Contact information for getting support from the publisher for the listing.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreatePublicationDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreatePublicationDetails
Initializes the object
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/oci/marketplace/models/create_publication_details.rb', line 116 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.listing_type = attributes[:'listingType'] if attributes[:'listingType'] raise 'You cannot provide both :listingType and :listing_type' if attributes.key?(:'listingType') && attributes.key?(:'listing_type') self.listing_type = attributes[:'listing_type'] if attributes[:'listing_type'] self.name = attributes[:'name'] if attributes[:'name'] self.short_description = attributes[:'shortDescription'] if attributes[:'shortDescription'] raise 'You cannot provide both :shortDescription and :short_description' if attributes.key?(:'shortDescription') && attributes.key?(:'short_description') self.short_description = attributes[:'short_description'] if attributes[:'short_description'] self.long_description = attributes[:'longDescription'] if attributes[:'longDescription'] raise 'You cannot provide both :longDescription and :long_description' if attributes.key?(:'longDescription') && attributes.key?(:'long_description') self.long_description = attributes[:'long_description'] if attributes[:'long_description'] self.support_contacts = attributes[:'supportContacts'] if attributes[:'supportContacts'] raise 'You cannot provide both :supportContacts and :support_contacts' if attributes.key?(:'supportContacts') && attributes.key?(:'support_contacts') self.support_contacts = attributes[:'support_contacts'] if attributes[:'support_contacts'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.package_details = attributes[:'packageDetails'] if attributes[:'packageDetails'] raise 'You cannot provide both :packageDetails and :package_details' if attributes.key?(:'packageDetails') && attributes.key?(:'package_details') self.package_details = attributes[:'package_details'] if attributes[:'package_details'] self.is_agreement_acknowledged = attributes[:'isAgreementAcknowledged'] unless attributes[:'isAgreementAcknowledged'].nil? raise 'You cannot provide both :isAgreementAcknowledged and :is_agreement_acknowledged' if attributes.key?(:'isAgreementAcknowledged') && attributes.key?(:'is_agreement_acknowledged') self.is_agreement_acknowledged = attributes[:'is_agreement_acknowledged'] unless attributes[:'is_agreement_acknowledged'].nil? self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment where you want to create the publication.
39 40 41 |
# File 'lib/oci/marketplace/models/create_publication_details.rb', line 39 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"CostCenter": "42"}`
55 56 57 |
# File 'lib/oci/marketplace/models/create_publication_details.rb', line 55 def @defined_tags end |
#freeform_tags ⇒ Hash<String, String>
The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `"Finance"`
62 63 64 |
# File 'lib/oci/marketplace/models/create_publication_details.rb', line 62 def @freeform_tags end |
#is_agreement_acknowledged ⇒ BOOLEAN
**[Required]** Whether the publisher acknowledged that they have the right and authority to share the contents of the publication and that they accepted the Oracle terms of use agreements required to create a publication.
48 49 50 |
# File 'lib/oci/marketplace/models/create_publication_details.rb', line 48 def is_agreement_acknowledged @is_agreement_acknowledged end |
#listing_type ⇒ String
**[Required]** The publisher category to which the publication belongs. The publisher category informs where the listing appears for use.
19 20 21 |
# File 'lib/oci/marketplace/models/create_publication_details.rb', line 19 def listing_type @listing_type end |
#long_description ⇒ String
A long description of the publication to use in the listing.
31 32 33 |
# File 'lib/oci/marketplace/models/create_publication_details.rb', line 31 def long_description @long_description end |
#name ⇒ String
**[Required]** The name of the publication, which is also used in the listing.
23 24 25 |
# File 'lib/oci/marketplace/models/create_publication_details.rb', line 23 def name @name end |
#package_details ⇒ OCI::Marketplace::Models::CreatePublicationPackage
This attribute is required.
43 44 45 |
# File 'lib/oci/marketplace/models/create_publication_details.rb', line 43 def package_details @package_details end |
#short_description ⇒ String
**[Required]** A short description of the publication to use in the listing.
27 28 29 |
# File 'lib/oci/marketplace/models/create_publication_details.rb', line 27 def short_description @short_description end |
#support_contacts ⇒ Array<OCI::Marketplace::Models::SupportContact>
**[Required]** Contact information for getting support from the publisher for the listing.
35 36 37 |
# File 'lib/oci/marketplace/models/create_publication_details.rb', line 35 def support_contacts @support_contacts end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/oci/marketplace/models/create_publication_details.rb', line 65 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'listing_type': :'listingType', 'name': :'name', 'short_description': :'shortDescription', 'long_description': :'longDescription', 'support_contacts': :'supportContacts', 'compartment_id': :'compartmentId', 'package_details': :'packageDetails', 'is_agreement_acknowledged': :'isAgreementAcknowledged', 'defined_tags': :'definedTags', 'freeform_tags': :'freeformTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/oci/marketplace/models/create_publication_details.rb', line 83 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'listing_type': :'String', 'name': :'String', 'short_description': :'String', 'long_description': :'String', 'support_contacts': :'Array<OCI::Marketplace::Models::SupportContact>', 'compartment_id': :'String', 'package_details': :'OCI::Marketplace::Models::CreatePublicationPackage', 'is_agreement_acknowledged': :'BOOLEAN', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'freeform_tags': :'Hash<String, String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/oci/marketplace/models/create_publication_details.rb', line 194 def ==(other) return true if equal?(other) self.class == other.class && listing_type == other.listing_type && name == other.name && short_description == other.short_description && long_description == other.long_description && support_contacts == other.support_contacts && compartment_id == other.compartment_id && package_details == other.package_details && is_agreement_acknowledged == other.is_agreement_acknowledged && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/oci/marketplace/models/create_publication_details.rb', line 233 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
213 214 215 |
# File 'lib/oci/marketplace/models/create_publication_details.rb', line 213 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
222 223 224 |
# File 'lib/oci/marketplace/models/create_publication_details.rb', line 222 def hash [listing_type, name, short_description, long_description, support_contacts, compartment_id, package_details, is_agreement_acknowledged, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
266 267 268 269 270 271 272 273 274 275 |
# File 'lib/oci/marketplace/models/create_publication_details.rb', line 266 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
260 261 262 |
# File 'lib/oci/marketplace/models/create_publication_details.rb', line 260 def to_s to_hash.to_s end |