Class: OCI::Marketplace::Models::ImageListingPackage
- Inherits:
-
ListingPackage
- Object
- ListingPackage
- OCI::Marketplace::Models::ImageListingPackage
- Defined in:
- lib/oci/marketplace/models/image_listing_package.rb
Overview
A package for image listings.
Constant Summary
Constants inherited from ListingPackage
ListingPackage::PACKAGE_TYPE_ENUM
Instance Attribute Summary collapse
-
#app_catalog_listing_id ⇒ String
The ID of the listing resource associated with this listing package.
-
#app_catalog_listing_resource_version ⇒ String
The resource version of the listing resource associated with this listing package.
-
#image_id ⇒ String
The ID of the image corresponding to the package.
-
#regions ⇒ Array<OCI::Marketplace::Models::Region>
The regions where you can deploy the listing package.
Attributes inherited from ListingPackage
#description, #listing_id, #operating_system, #package_type, #pricing, #resource_id, #time_created, #version
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ImageListingPackage
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from ListingPackage
Constructor Details
#initialize(attributes = {}) ⇒ ImageListingPackage
Initializes the object
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/oci/marketplace/models/image_listing_package.rb', line 86 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['packageType'] = 'IMAGE' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.app_catalog_listing_id = attributes[:'appCatalogListingId'] if attributes[:'appCatalogListingId'] raise 'You cannot provide both :appCatalogListingId and :app_catalog_listing_id' if attributes.key?(:'appCatalogListingId') && attributes.key?(:'app_catalog_listing_id') self.app_catalog_listing_id = attributes[:'app_catalog_listing_id'] if attributes[:'app_catalog_listing_id'] self.app_catalog_listing_resource_version = attributes[:'appCatalogListingResourceVersion'] if attributes[:'appCatalogListingResourceVersion'] raise 'You cannot provide both :appCatalogListingResourceVersion and :app_catalog_listing_resource_version' if attributes.key?(:'appCatalogListingResourceVersion') && attributes.key?(:'app_catalog_listing_resource_version') self.app_catalog_listing_resource_version = attributes[:'app_catalog_listing_resource_version'] if attributes[:'app_catalog_listing_resource_version'] self.image_id = attributes[:'imageId'] if attributes[:'imageId'] raise 'You cannot provide both :imageId and :image_id' if attributes.key?(:'imageId') && attributes.key?(:'image_id') self.image_id = attributes[:'image_id'] if attributes[:'image_id'] self.regions = attributes[:'regions'] if attributes[:'regions'] end |
Instance Attribute Details
#app_catalog_listing_id ⇒ String
The ID of the listing resource associated with this listing package. For more information, see [AppCatalogListing](docs.cloud.oracle.com/en-us/iaas/api/#/en/iaas/latest/AppCatalogListing/) in the Core Services API.
14 15 16 |
# File 'lib/oci/marketplace/models/image_listing_package.rb', line 14 def app_catalog_listing_id @app_catalog_listing_id end |
#app_catalog_listing_resource_version ⇒ String
The resource version of the listing resource associated with this listing package.
18 19 20 |
# File 'lib/oci/marketplace/models/image_listing_package.rb', line 18 def app_catalog_listing_resource_version @app_catalog_listing_resource_version end |
#image_id ⇒ String
The ID of the image corresponding to the package.
22 23 24 |
# File 'lib/oci/marketplace/models/image_listing_package.rb', line 22 def image_id @image_id end |
#regions ⇒ Array<OCI::Marketplace::Models::Region>
The regions where you can deploy the listing package. (Some packages have restrictions that limit their deployment to United States regions only.)
27 28 29 |
# File 'lib/oci/marketplace/models/image_listing_package.rb', line 27 def regions @regions end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 |
# File 'lib/oci/marketplace/models/image_listing_package.rb', line 30 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'description': :'description', 'listing_id': :'listingId', 'version': :'version', 'package_type': :'packageType', 'pricing': :'pricing', 'resource_id': :'resourceId', 'time_created': :'timeCreated', 'operating_system': :'operatingSystem', 'app_catalog_listing_id': :'appCatalogListingId', 'app_catalog_listing_resource_version': :'appCatalogListingResourceVersion', 'image_id': :'imageId', 'regions': :'regions' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/oci/marketplace/models/image_listing_package.rb', line 50 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'description': :'String', 'listing_id': :'String', 'version': :'String', 'package_type': :'String', 'pricing': :'OCI::Marketplace::Models::PricingModel', 'resource_id': :'String', 'time_created': :'DateTime', 'operating_system': :'OCI::Marketplace::Models::OperatingSystem', 'app_catalog_listing_id': :'String', 'app_catalog_listing_resource_version': :'String', 'image_id': :'String', 'regions': :'Array<OCI::Marketplace::Models::Region>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/oci/marketplace/models/image_listing_package.rb', line 124 def ==(other) return true if equal?(other) self.class == other.class && description == other.description && listing_id == other.listing_id && version == other.version && package_type == other.package_type && pricing == other.pricing && resource_id == other.resource_id && time_created == other.time_created && == other. && app_catalog_listing_id == other.app_catalog_listing_id && app_catalog_listing_resource_version == other.app_catalog_listing_resource_version && image_id == other.image_id && regions == other.regions end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/oci/marketplace/models/image_listing_package.rb', line 165 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
145 146 147 |
# File 'lib/oci/marketplace/models/image_listing_package.rb', line 145 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
154 155 156 |
# File 'lib/oci/marketplace/models/image_listing_package.rb', line 154 def hash [description, listing_id, version, package_type, pricing, resource_id, time_created, , app_catalog_listing_id, app_catalog_listing_resource_version, image_id, regions].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
198 199 200 201 202 203 204 205 206 207 |
# File 'lib/oci/marketplace/models/image_listing_package.rb', line 198 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
192 193 194 |
# File 'lib/oci/marketplace/models/image_listing_package.rb', line 192 def to_s to_hash.to_s end |