Class: OCI::Marketplace::Models::ImagePublicationPackage
- Inherits:
-
PublicationPackage
- Object
- PublicationPackage
- OCI::Marketplace::Models::ImagePublicationPackage
- Defined in:
- lib/oci/marketplace/models/image_publication_package.rb
Overview
A publication package for image publications.
Constant Summary
Constants inherited from PublicationPackage
PublicationPackage::PACKAGE_TYPE_ENUM
Instance Attribute Summary collapse
-
#app_catalog_listing_id ⇒ String
The ID of the listing resource associated with this publication package.
-
#app_catalog_listing_resource_version ⇒ String
The resource version of the listing resource associated with this publication package.
-
#image_id ⇒ String
The ID of the image that corresponds to the package.
Attributes inherited from PublicationPackage
#description, #listing_id, #operating_system, #package_type, #resource_id, #time_created, #version
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ImagePublicationPackage
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from PublicationPackage
Constructor Details
#initialize(attributes = {}) ⇒ ImagePublicationPackage
Initializes the object
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/oci/marketplace/models/image_publication_package.rb', line 75 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['packageType'] = 'IMAGE' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.app_catalog_listing_id = attributes[:'appCatalogListingId'] if attributes[:'appCatalogListingId'] raise 'You cannot provide both :appCatalogListingId and :app_catalog_listing_id' if attributes.key?(:'appCatalogListingId') && attributes.key?(:'app_catalog_listing_id') self.app_catalog_listing_id = attributes[:'app_catalog_listing_id'] if attributes[:'app_catalog_listing_id'] self.app_catalog_listing_resource_version = attributes[:'appCatalogListingResourceVersion'] if attributes[:'appCatalogListingResourceVersion'] raise 'You cannot provide both :appCatalogListingResourceVersion and :app_catalog_listing_resource_version' if attributes.key?(:'appCatalogListingResourceVersion') && attributes.key?(:'app_catalog_listing_resource_version') self.app_catalog_listing_resource_version = attributes[:'app_catalog_listing_resource_version'] if attributes[:'app_catalog_listing_resource_version'] self.image_id = attributes[:'imageId'] if attributes[:'imageId'] raise 'You cannot provide both :imageId and :image_id' if attributes.key?(:'imageId') && attributes.key?(:'image_id') self.image_id = attributes[:'image_id'] if attributes[:'image_id'] end |
Instance Attribute Details
#app_catalog_listing_id ⇒ String
The ID of the listing resource associated with this publication package. For more information, see [AppCatalogListing](docs.cloud.oracle.com/en-us/iaas/api/#/en/iaas/latest/AppCatalogListing/) in the Core Services API.
14 15 16 |
# File 'lib/oci/marketplace/models/image_publication_package.rb', line 14 def app_catalog_listing_id @app_catalog_listing_id end |
#app_catalog_listing_resource_version ⇒ String
The resource version of the listing resource associated with this publication package.
18 19 20 |
# File 'lib/oci/marketplace/models/image_publication_package.rb', line 18 def app_catalog_listing_resource_version @app_catalog_listing_resource_version end |
#image_id ⇒ String
The ID of the image that corresponds to the package.
22 23 24 |
# File 'lib/oci/marketplace/models/image_publication_package.rb', line 22 def image_id @image_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 |
# File 'lib/oci/marketplace/models/image_publication_package.rb', line 25 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'description': :'description', 'listing_id': :'listingId', 'version': :'version', 'package_type': :'packageType', 'resource_id': :'resourceId', 'time_created': :'timeCreated', 'operating_system': :'operatingSystem', 'app_catalog_listing_id': :'appCatalogListingId', 'app_catalog_listing_resource_version': :'appCatalogListingResourceVersion', 'image_id': :'imageId' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/oci/marketplace/models/image_publication_package.rb', line 43 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'description': :'String', 'listing_id': :'String', 'version': :'String', 'package_type': :'String', 'resource_id': :'String', 'time_created': :'DateTime', 'operating_system': :'OCI::Marketplace::Models::OperatingSystem', 'app_catalog_listing_id': :'String', 'app_catalog_listing_resource_version': :'String', 'image_id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/oci/marketplace/models/image_publication_package.rb', line 111 def ==(other) return true if equal?(other) self.class == other.class && description == other.description && listing_id == other.listing_id && version == other.version && package_type == other.package_type && resource_id == other.resource_id && time_created == other.time_created && == other. && app_catalog_listing_id == other.app_catalog_listing_id && app_catalog_listing_resource_version == other.app_catalog_listing_resource_version && image_id == other.image_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/oci/marketplace/models/image_publication_package.rb', line 150 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
130 131 132 |
# File 'lib/oci/marketplace/models/image_publication_package.rb', line 130 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
139 140 141 |
# File 'lib/oci/marketplace/models/image_publication_package.rb', line 139 def hash [description, listing_id, version, package_type, resource_id, time_created, , app_catalog_listing_id, app_catalog_listing_resource_version, image_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
183 184 185 186 187 188 189 190 191 192 |
# File 'lib/oci/marketplace/models/image_publication_package.rb', line 183 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
177 178 179 |
# File 'lib/oci/marketplace/models/image_publication_package.rb', line 177 def to_s to_hash.to_s end |