Class: OCI::Marketplace::Models::InternationalMarketPrice

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/marketplace/models/international_market_price.rb

Overview

The model for international market pricing.

Constant Summary collapse

CURRENCY_CODE_ENUM =
[
  CURRENCY_CODE_USD = 'USD'.freeze,
  CURRENCY_CODE_CAD = 'CAD'.freeze,
  CURRENCY_CODE_INR = 'INR'.freeze,
  CURRENCY_CODE_GBP = 'GBP'.freeze,
  CURRENCY_CODE_BRL = 'BRL'.freeze,
  CURRENCY_CODE_JPY = 'JPY'.freeze,
  CURRENCY_CODE_OMR = 'OMR'.freeze,
  CURRENCY_CODE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ InternationalMarketPrice

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :currency_code (String)

    The value to assign to the #currency_code property

  • :currency_symbol (String)

    The value to assign to the #currency_symbol property

  • :rate (Float)

    The value to assign to the #rate property



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/oci/marketplace/models/international_market_price.rb', line 65

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.currency_code = attributes[:'currencyCode'] if attributes[:'currencyCode']

  raise 'You cannot provide both :currencyCode and :currency_code' if attributes.key?(:'currencyCode') && attributes.key?(:'currency_code')

  self.currency_code = attributes[:'currency_code'] if attributes[:'currency_code']

  self.currency_symbol = attributes[:'currencySymbol'] if attributes[:'currencySymbol']

  raise 'You cannot provide both :currencySymbol and :currency_symbol' if attributes.key?(:'currencySymbol') && attributes.key?(:'currency_symbol')

  self.currency_symbol = attributes[:'currency_symbol'] if attributes[:'currency_symbol']

  self.rate = attributes[:'rate'] if attributes[:'rate']
end

Instance Attribute Details

#currency_codeString

**[Required]** The currency of the pricing model.

Returns:

  • (String)


24
25
26
# File 'lib/oci/marketplace/models/international_market_price.rb', line 24

def currency_code
  @currency_code
end

#currency_symbolString

The symbol of the currency

Returns:

  • (String)


28
29
30
# File 'lib/oci/marketplace/models/international_market_price.rb', line 28

def currency_symbol
  @currency_symbol
end

#rateFloat

**[Required]** The pricing rate.

Returns:

  • (Float)


32
33
34
# File 'lib/oci/marketplace/models/international_market_price.rb', line 32

def rate
  @rate
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
# File 'lib/oci/marketplace/models/international_market_price.rb', line 35

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'currency_code': :'currencyCode',
    'currency_symbol': :'currencySymbol',
    'rate': :'rate'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



46
47
48
49
50
51
52
53
54
# File 'lib/oci/marketplace/models/international_market_price.rb', line 46

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'currency_code': :'String',
    'currency_symbol': :'String',
    'rate': :'Float'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



106
107
108
109
110
111
112
113
# File 'lib/oci/marketplace/models/international_market_price.rb', line 106

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    currency_code == other.currency_code &&
    currency_symbol == other.currency_symbol &&
    rate == other.rate
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/oci/marketplace/models/international_market_price.rb', line 138

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


118
119
120
# File 'lib/oci/marketplace/models/international_market_price.rb', line 118

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



127
128
129
# File 'lib/oci/marketplace/models/international_market_price.rb', line 127

def hash
  [currency_code, currency_symbol, rate].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



171
172
173
174
175
176
177
178
179
180
# File 'lib/oci/marketplace/models/international_market_price.rb', line 171

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



165
166
167
# File 'lib/oci/marketplace/models/international_market_price.rb', line 165

def to_s
  to_hash.to_s
end