Class: OCI::Marketplace::Models::LaunchEligibility

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/marketplace/models/launch_eligibility.rb

Overview

Tenant eligibility and other information for launching a PIC image

Constant Summary collapse

INELIGIBILITY_REASON_ENUM =
[
  INELIGIBILITY_REASON_INELIGIBLE_ACCOUNT_COUNTRY = 'INELIGIBLE_ACCOUNT_COUNTRY'.freeze,
  INELIGIBILITY_REASON_INELIGIBLE_REGION = 'INELIGIBLE_REGION'.freeze,
  INELIGIBILITY_REASON_INELIGIBLE_ACCOUNT_BLACKLISTED = 'INELIGIBLE_ACCOUNT_BLACKLISTED'.freeze,
  INELIGIBILITY_REASON_INELIGIBLE_ACCOUNT_FEATURE_DISABLED = 'INELIGIBLE_ACCOUNT_FEATURE_DISABLED'.freeze,
  INELIGIBILITY_REASON_INELIGIBLE_ACCOUNT_CURRENCY = 'INELIGIBLE_ACCOUNT_CURRENCY'.freeze,
  INELIGIBILITY_REASON_INELIGIBLE_ACCOUNT_NOT_PAID = 'INELIGIBLE_ACCOUNT_NOT_PAID'.freeze,
  INELIGIBILITY_REASON_INELIGIBLE_ACCOUNT_INTERNAL = 'INELIGIBLE_ACCOUNT_INTERNAL'.freeze,
  INELIGIBILITY_REASON_INELIGIBLE_ACCOUNT_GOV_SUBSCRIPTION = 'INELIGIBLE_ACCOUNT_GOV_SUBSCRIPTION'.freeze,
  INELIGIBILITY_REASON_INELIGIBLE_PAID_LISTING_THROTTLED = 'INELIGIBLE_PAID_LISTING_THROTTLED'.freeze,
  INELIGIBILITY_REASON_NOT_AUTHORIZED = 'NOT_AUTHORIZED'.freeze,
  INELIGIBILITY_REASON_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ LaunchEligibility

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :image_id (String)

    The value to assign to the #image_id property

  • :is_launch_allowed (BOOLEAN)

    The value to assign to the #is_launch_allowed property

  • :meters (String)

    The value to assign to the #meters property

  • :ineligibility_reason (String)

    The value to assign to the #ineligibility_reason property



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/oci/marketplace/models/launch_eligibility.rb', line 75

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.image_id = attributes[:'imageId'] if attributes[:'imageId']

  raise 'You cannot provide both :imageId and :image_id' if attributes.key?(:'imageId') && attributes.key?(:'image_id')

  self.image_id = attributes[:'image_id'] if attributes[:'image_id']

  self.is_launch_allowed = attributes[:'isLaunchAllowed'] unless attributes[:'isLaunchAllowed'].nil?

  raise 'You cannot provide both :isLaunchAllowed and :is_launch_allowed' if attributes.key?(:'isLaunchAllowed') && attributes.key?(:'is_launch_allowed')

  self.is_launch_allowed = attributes[:'is_launch_allowed'] unless attributes[:'is_launch_allowed'].nil?

  self.meters = attributes[:'meters'] if attributes[:'meters']

  self.ineligibility_reason = attributes[:'ineligibilityReason'] if attributes[:'ineligibilityReason']

  raise 'You cannot provide both :ineligibilityReason and :ineligibility_reason' if attributes.key?(:'ineligibilityReason') && attributes.key?(:'ineligibility_reason')

  self.ineligibility_reason = attributes[:'ineligibility_reason'] if attributes[:'ineligibility_reason']
end

Instance Attribute Details

#image_idString

**[Required]** PIC Image ID

Returns:

  • (String)


27
28
29
# File 'lib/oci/marketplace/models/launch_eligibility.rb', line 27

def image_id
  @image_id
end

#ineligibility_reasonString

Reason the account is ineligible to launch paid listings

Returns:

  • (String)


39
40
41
# File 'lib/oci/marketplace/models/launch_eligibility.rb', line 39

def ineligibility_reason
  @ineligibility_reason
end

#is_launch_allowedBOOLEAN

**[Required]** Is the tenant permitted to launch the PIC image

Returns:

  • (BOOLEAN)


31
32
33
# File 'lib/oci/marketplace/models/launch_eligibility.rb', line 31

def is_launch_allowed
  @is_launch_allowed
end

#metersString

related meters for the PIC image

Returns:

  • (String)


35
36
37
# File 'lib/oci/marketplace/models/launch_eligibility.rb', line 35

def meters
  @meters
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



42
43
44
45
46
47
48
49
50
51
# File 'lib/oci/marketplace/models/launch_eligibility.rb', line 42

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'image_id': :'imageId',
    'is_launch_allowed': :'isLaunchAllowed',
    'meters': :'meters',
    'ineligibility_reason': :'ineligibilityReason'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



54
55
56
57
58
59
60
61
62
63
# File 'lib/oci/marketplace/models/launch_eligibility.rb', line 54

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'image_id': :'String',
    'is_launch_allowed': :'BOOLEAN',
    'meters': :'String',
    'ineligibility_reason': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



122
123
124
125
126
127
128
129
130
# File 'lib/oci/marketplace/models/launch_eligibility.rb', line 122

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    image_id == other.image_id &&
    is_launch_allowed == other.is_launch_allowed &&
    meters == other.meters &&
    ineligibility_reason == other.ineligibility_reason
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/oci/marketplace/models/launch_eligibility.rb', line 155

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


135
136
137
# File 'lib/oci/marketplace/models/launch_eligibility.rb', line 135

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



144
145
146
# File 'lib/oci/marketplace/models/launch_eligibility.rb', line 144

def hash
  [image_id, is_launch_allowed, meters, ineligibility_reason].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



188
189
190
191
192
193
194
195
196
197
# File 'lib/oci/marketplace/models/launch_eligibility.rb', line 188

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



182
183
184
# File 'lib/oci/marketplace/models/launch_eligibility.rb', line 182

def to_s
  to_hash.to_s
end