Class: OCI::Marketplace::Models::ListingPackage

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/marketplace/models/listing_package.rb

Overview

A base object for all types of listing packages. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class

Constant Summary collapse

PACKAGE_TYPE_ENUM =
[
  PACKAGE_TYPE_ORCHESTRATION = 'ORCHESTRATION'.freeze,
  PACKAGE_TYPE_IMAGE = 'IMAGE'.freeze,
  PACKAGE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ListingPackage

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/oci/marketplace/models/listing_package.rb', line 114

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.description = attributes[:'description'] if attributes[:'description']

  self.listing_id = attributes[:'listingId'] if attributes[:'listingId']

  raise 'You cannot provide both :listingId and :listing_id' if attributes.key?(:'listingId') && attributes.key?(:'listing_id')

  self.listing_id = attributes[:'listing_id'] if attributes[:'listing_id']

  self.version = attributes[:'version'] if attributes[:'version']

  self.package_type = attributes[:'packageType'] if attributes[:'packageType']

  raise 'You cannot provide both :packageType and :package_type' if attributes.key?(:'packageType') && attributes.key?(:'package_type')

  self.package_type = attributes[:'package_type'] if attributes[:'package_type']

  self.pricing = attributes[:'pricing'] if attributes[:'pricing']

  self.resource_id = attributes[:'resourceId'] if attributes[:'resourceId']

  raise 'You cannot provide both :resourceId and :resource_id' if attributes.key?(:'resourceId') && attributes.key?(:'resource_id')

  self.resource_id = attributes[:'resource_id'] if attributes[:'resource_id']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.operating_system = attributes[:'operatingSystem'] if attributes[:'operatingSystem']

  raise 'You cannot provide both :operatingSystem and :operating_system' if attributes.key?(:'operatingSystem') && attributes.key?(:'operating_system')

  self.operating_system = attributes[:'operating_system'] if attributes[:'operating_system']
end

Instance Attribute Details

#descriptionString

Description of this package.

Returns:

  • (String)


20
21
22
# File 'lib/oci/marketplace/models/listing_package.rb', line 20

def description
  @description
end

#listing_idString

**[Required]** The ID of the listing this package belongs to.

Returns:

  • (String)


24
25
26
# File 'lib/oci/marketplace/models/listing_package.rb', line 24

def listing_id
  @listing_id
end

#operating_systemOCI::Marketplace::Models::OperatingSystem



50
51
52
# File 'lib/oci/marketplace/models/listing_package.rb', line 50

def operating_system
  @operating_system
end

#package_typeString

**[Required]** The specified package's type.

Returns:

  • (String)


32
33
34
# File 'lib/oci/marketplace/models/listing_package.rb', line 32

def package_type
  @package_type
end

#pricingOCI::Marketplace::Models::PricingModel



35
36
37
# File 'lib/oci/marketplace/models/listing_package.rb', line 35

def pricing
  @pricing
end

#resource_idString

The unique identifier for the package resource.

Returns:

  • (String)


39
40
41
# File 'lib/oci/marketplace/models/listing_package.rb', line 39

def resource_id
  @resource_id
end

#time_createdDateTime

The date and time this listing package was created, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.

Example: `2016-08-25T21:10:29.600Z`

Returns:

  • (DateTime)


47
48
49
# File 'lib/oci/marketplace/models/listing_package.rb', line 47

def time_created
  @time_created
end

#versionString

**[Required]** The package version.

Returns:

  • (String)


28
29
30
# File 'lib/oci/marketplace/models/listing_package.rb', line 28

def version
  @version
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/oci/marketplace/models/listing_package.rb', line 53

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'description': :'description',
    'listing_id': :'listingId',
    'version': :'version',
    'package_type': :'packageType',
    'pricing': :'pricing',
    'resource_id': :'resourceId',
    'time_created': :'timeCreated',
    'operating_system': :'operatingSystem'
    # rubocop:enable Style/SymbolLiteral
  }
end

.get_subtype(object_hash) ⇒ Object

Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.



89
90
91
92
93
94
95
96
97
# File 'lib/oci/marketplace/models/listing_package.rb', line 89

def self.get_subtype(object_hash)
  type = object_hash[:'packageType'] # rubocop:disable Style/SymbolLiteral

  return 'OCI::Marketplace::Models::OrchestrationListingPackage' if type == 'ORCHESTRATION'
  return 'OCI::Marketplace::Models::ImageListingPackage' if type == 'IMAGE'

  # TODO: Log a warning when the subtype is not found.
  'OCI::Marketplace::Models::ListingPackage'
end

.swagger_typesObject

Attribute type mapping.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/oci/marketplace/models/listing_package.rb', line 69

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'description': :'String',
    'listing_id': :'String',
    'version': :'String',
    'package_type': :'String',
    'pricing': :'OCI::Marketplace::Models::PricingModel',
    'resource_id': :'String',
    'time_created': :'DateTime',
    'operating_system': :'OCI::Marketplace::Models::OperatingSystem'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/oci/marketplace/models/listing_package.rb', line 177

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    description == other.description &&
    listing_id == other.listing_id &&
    version == other.version &&
    package_type == other.package_type &&
    pricing == other.pricing &&
    resource_id == other.resource_id &&
    time_created == other.time_created &&
    operating_system == other.operating_system
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/oci/marketplace/models/listing_package.rb', line 214

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


194
195
196
# File 'lib/oci/marketplace/models/listing_package.rb', line 194

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



203
204
205
# File 'lib/oci/marketplace/models/listing_package.rb', line 203

def hash
  [description, listing_id, version, package_type, pricing, resource_id, time_created, operating_system].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



247
248
249
250
251
252
253
254
255
256
# File 'lib/oci/marketplace/models/listing_package.rb', line 247

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



241
242
243
# File 'lib/oci/marketplace/models/listing_package.rb', line 241

def to_s
  to_hash.to_s
end