Class: OCI::Marketplace::Models::Publication

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/marketplace/models/publication.rb

Overview

The model for an Oracle Cloud Infrastructure Marketplace publication.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
PACKAGE_TYPE_ENUM =
[
  PACKAGE_TYPE_ORCHESTRATION = 'ORCHESTRATION'.freeze,
  PACKAGE_TYPE_IMAGE = 'IMAGE'.freeze,
  PACKAGE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LISTING_TYPE_ENUM =
[
  LISTING_TYPE_COMMUNITY = 'COMMUNITY'.freeze,
  LISTING_TYPE_PARTNER = 'PARTNER'.freeze,
  LISTING_TYPE_PRIVATE = 'PRIVATE'.freeze,
  LISTING_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Publication

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/oci/marketplace/models/publication.rb', line 162

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.id = attributes[:'id'] if attributes[:'id']

  self.name = attributes[:'name'] if attributes[:'name']

  self.short_description = attributes[:'shortDescription'] if attributes[:'shortDescription']

  raise 'You cannot provide both :shortDescription and :short_description' if attributes.key?(:'shortDescription') && attributes.key?(:'short_description')

  self.short_description = attributes[:'short_description'] if attributes[:'short_description']

  self.long_description = attributes[:'longDescription'] if attributes[:'longDescription']

  raise 'You cannot provide both :longDescription and :long_description' if attributes.key?(:'longDescription') && attributes.key?(:'long_description')

  self.long_description = attributes[:'long_description'] if attributes[:'long_description']

  self.support_contacts = attributes[:'supportContacts'] if attributes[:'supportContacts']

  raise 'You cannot provide both :supportContacts and :support_contacts' if attributes.key?(:'supportContacts') && attributes.key?(:'support_contacts')

  self.support_contacts = attributes[:'support_contacts'] if attributes[:'support_contacts']

  self.icon = attributes[:'icon'] if attributes[:'icon']

  self.package_type = attributes[:'packageType'] if attributes[:'packageType']

  raise 'You cannot provide both :packageType and :package_type' if attributes.key?(:'packageType') && attributes.key?(:'package_type')

  self.package_type = attributes[:'package_type'] if attributes[:'package_type']

  self.listing_type = attributes[:'listingType'] if attributes[:'listingType']

  raise 'You cannot provide both :listingType and :listing_type' if attributes.key?(:'listingType') && attributes.key?(:'listing_type')

  self.listing_type = attributes[:'listing_type'] if attributes[:'listing_type']

  self.supported_operating_systems = attributes[:'supportedOperatingSystems'] if attributes[:'supportedOperatingSystems']

  raise 'You cannot provide both :supportedOperatingSystems and :supported_operating_systems' if attributes.key?(:'supportedOperatingSystems') && attributes.key?(:'supported_operating_systems')

  self.supported_operating_systems = attributes[:'supported_operating_systems'] if attributes[:'supported_operating_systems']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']
end

Instance Attribute Details

#compartment_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment where the publication exists.

Returns:

  • (String)


39
40
41
# File 'lib/oci/marketplace/models/publication.rb', line 39

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


89
90
91
# File 'lib/oci/marketplace/models/publication.rb', line 89

def defined_tags
  @defined_tags
end

#freeform_tagsHash<String, String>

The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `"Finance"`

Returns:

  • (Hash<String, String>)


96
97
98
# File 'lib/oci/marketplace/models/publication.rb', line 96

def freeform_tags
  @freeform_tags
end

#iconOCI::Marketplace::Models::UploadData



62
63
64
# File 'lib/oci/marketplace/models/publication.rb', line 62

def icon
  @icon
end

#idString

**[Required]** The unique identifier for the publication in Marketplace.

Returns:

  • (String)


43
44
45
# File 'lib/oci/marketplace/models/publication.rb', line 43

def id
  @id
end

#lifecycle_stateString

The lifecycle state of the publication.

Returns:

  • (String)


35
36
37
# File 'lib/oci/marketplace/models/publication.rb', line 35

def lifecycle_state
  @lifecycle_state
end

#listing_typeString

**[Required]** The publisher category to which the publication belongs. The publisher category informs where the listing appears for use.

Returns:

  • (String)


70
71
72
# File 'lib/oci/marketplace/models/publication.rb', line 70

def listing_type
  @listing_type
end

#long_descriptionString

A long description of the publication to use in the listing.

Returns:

  • (String)


55
56
57
# File 'lib/oci/marketplace/models/publication.rb', line 55

def long_description
  @long_description
end

#nameString

**[Required]** The name of the publication, which is also used in the listing.

Returns:

  • (String)


47
48
49
# File 'lib/oci/marketplace/models/publication.rb', line 47

def name
  @name
end

#package_typeString

The listing's package type.

Returns:

  • (String)


66
67
68
# File 'lib/oci/marketplace/models/publication.rb', line 66

def package_type
  @package_type
end

#short_descriptionString

A short description of the publication to use in the listing.

Returns:

  • (String)


51
52
53
# File 'lib/oci/marketplace/models/publication.rb', line 51

def short_description
  @short_description
end

#support_contactsArray<OCI::Marketplace::Models::SupportContact>

Contact information for getting support from the publisher for the listing.



59
60
61
# File 'lib/oci/marketplace/models/publication.rb', line 59

def support_contacts
  @support_contacts
end

#supported_operating_systemsArray<OCI::Marketplace::Models::OperatingSystem>

The list of operating systems supprted by the listing.



74
75
76
# File 'lib/oci/marketplace/models/publication.rb', line 74

def supported_operating_systems
  @supported_operating_systems
end

#time_createdDateTime

The date and time the publication was created, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.

Example: `2016-08-25T21:10:29.600Z`

Returns:

  • (DateTime)


82
83
84
# File 'lib/oci/marketplace/models/publication.rb', line 82

def time_created
  @time_created
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/oci/marketplace/models/publication.rb', line 99

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'lifecycle_state': :'lifecycleState',
    'compartment_id': :'compartmentId',
    'id': :'id',
    'name': :'name',
    'short_description': :'shortDescription',
    'long_description': :'longDescription',
    'support_contacts': :'supportContacts',
    'icon': :'icon',
    'package_type': :'packageType',
    'listing_type': :'listingType',
    'supported_operating_systems': :'supportedOperatingSystems',
    'time_created': :'timeCreated',
    'defined_tags': :'definedTags',
    'freeform_tags': :'freeformTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/oci/marketplace/models/publication.rb', line 121

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'lifecycle_state': :'String',
    'compartment_id': :'String',
    'id': :'String',
    'name': :'String',
    'short_description': :'String',
    'long_description': :'String',
    'support_contacts': :'Array<OCI::Marketplace::Models::SupportContact>',
    'icon': :'OCI::Marketplace::Models::UploadData',
    'package_type': :'String',
    'listing_type': :'String',
    'supported_operating_systems': :'Array<OCI::Marketplace::Models::OperatingSystem>',
    'time_created': :'DateTime',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'freeform_tags': :'Hash<String, String>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
# File 'lib/oci/marketplace/models/publication.rb', line 287

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    lifecycle_state == other.lifecycle_state &&
    compartment_id == other.compartment_id &&
    id == other.id &&
    name == other.name &&
    short_description == other.short_description &&
    long_description == other.long_description &&
    support_contacts == other.support_contacts &&
    icon == other.icon &&
    package_type == other.package_type &&
    listing_type == other.listing_type &&
    supported_operating_systems == other.supported_operating_systems &&
    time_created == other.time_created &&
    defined_tags == other.defined_tags &&
    freeform_tags == other.freeform_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
# File 'lib/oci/marketplace/models/publication.rb', line 330

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


310
311
312
# File 'lib/oci/marketplace/models/publication.rb', line 310

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



319
320
321
# File 'lib/oci/marketplace/models/publication.rb', line 319

def hash
  [lifecycle_state, compartment_id, id, name, short_description, long_description, support_contacts, icon, package_type, listing_type, supported_operating_systems, time_created, defined_tags, freeform_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



363
364
365
366
367
368
369
370
371
372
# File 'lib/oci/marketplace/models/publication.rb', line 363

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



357
358
359
# File 'lib/oci/marketplace/models/publication.rb', line 357

def to_s
  to_hash.to_s
end