Class: OCI::Marketplace::Models::UpdatePublicationDetails
- Inherits:
-
Object
- Object
- OCI::Marketplace::Models::UpdatePublicationDetails
- Defined in:
- lib/oci/marketplace/models/update_publication_details.rb
Overview
The model for the parameters needed to update a publication.
Instance Attribute Summary collapse
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
The defined tags associated with this resource, if any.
-
#freeform_tags ⇒ Hash<String, String>
The freeform tags associated with this resource, if any.
-
#long_description ⇒ String
A long description of the publication to use in the listing.
-
#name ⇒ String
The name of the publication, which is also used in the listing.
-
#short_description ⇒ String
A short description of the publication to use in the listing.
-
#support_contacts ⇒ Array<OCI::Marketplace::Models::SupportContact>
Contact information for getting support from the publisher for the listing.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdatePublicationDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdatePublicationDetails
Initializes the object
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/oci/marketplace/models/update_publication_details.rb', line 80 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.short_description = attributes[:'shortDescription'] if attributes[:'shortDescription'] raise 'You cannot provide both :shortDescription and :short_description' if attributes.key?(:'shortDescription') && attributes.key?(:'short_description') self.short_description = attributes[:'short_description'] if attributes[:'short_description'] self.long_description = attributes[:'longDescription'] if attributes[:'longDescription'] raise 'You cannot provide both :longDescription and :long_description' if attributes.key?(:'longDescription') && attributes.key?(:'long_description') self.long_description = attributes[:'long_description'] if attributes[:'long_description'] self.support_contacts = attributes[:'supportContacts'] if attributes[:'supportContacts'] raise 'You cannot provide both :supportContacts and :support_contacts' if attributes.key?(:'supportContacts') && attributes.key?(:'support_contacts') self.support_contacts = attributes[:'support_contacts'] if attributes[:'support_contacts'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] end |
Instance Attribute Details
#defined_tags ⇒ Hash<String, Hash<String, Object>>
The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"CostCenter": "42"}`
31 32 33 |
# File 'lib/oci/marketplace/models/update_publication_details.rb', line 31 def @defined_tags end |
#freeform_tags ⇒ Hash<String, String>
The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `"Finance"`
38 39 40 |
# File 'lib/oci/marketplace/models/update_publication_details.rb', line 38 def @freeform_tags end |
#long_description ⇒ String
A long description of the publication to use in the listing.
20 21 22 |
# File 'lib/oci/marketplace/models/update_publication_details.rb', line 20 def long_description @long_description end |
#name ⇒ String
The name of the publication, which is also used in the listing.
12 13 14 |
# File 'lib/oci/marketplace/models/update_publication_details.rb', line 12 def name @name end |
#short_description ⇒ String
A short description of the publication to use in the listing.
16 17 18 |
# File 'lib/oci/marketplace/models/update_publication_details.rb', line 16 def short_description @short_description end |
#support_contacts ⇒ Array<OCI::Marketplace::Models::SupportContact>
Contact information for getting support from the publisher for the listing.
24 25 26 |
# File 'lib/oci/marketplace/models/update_publication_details.rb', line 24 def support_contacts @support_contacts end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/oci/marketplace/models/update_publication_details.rb', line 41 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'short_description': :'shortDescription', 'long_description': :'longDescription', 'support_contacts': :'supportContacts', 'defined_tags': :'definedTags', 'freeform_tags': :'freeformTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/oci/marketplace/models/update_publication_details.rb', line 55 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'short_description': :'String', 'long_description': :'String', 'support_contacts': :'Array<OCI::Marketplace::Models::SupportContact>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'freeform_tags': :'Hash<String, String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/oci/marketplace/models/update_publication_details.rb', line 126 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && short_description == other.short_description && long_description == other.long_description && support_contacts == other.support_contacts && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/oci/marketplace/models/update_publication_details.rb', line 161 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
141 142 143 |
# File 'lib/oci/marketplace/models/update_publication_details.rb', line 141 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
150 151 152 |
# File 'lib/oci/marketplace/models/update_publication_details.rb', line 150 def hash [name, short_description, long_description, support_contacts, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
194 195 196 197 198 199 200 201 202 203 |
# File 'lib/oci/marketplace/models/update_publication_details.rb', line 194 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
188 189 190 |
# File 'lib/oci/marketplace/models/update_publication_details.rb', line 188 def to_s to_hash.to_s end |