Class: OCI::Monitoring::Models::AlarmStatusSummary
- Inherits:
-
Object
- Object
- OCI::Monitoring::Models::AlarmStatusSummary
- Defined in:
- lib/oci/monitoring/models/alarm_status_summary.rb
Overview
A summary of properties for the specified alarm and its current evaluation status. For information about alarms, see [Alarms Overview](docs.cloud.oracle.com/iaas/Content/Monitoring/Concepts/monitoringoverview.htm#AlarmsOverview).
To use any of the API operations, you must be authorized in an IAM policy. If you’re not authorized, talk to an administrator. If you’re an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/iaas/Content/Identity/Concepts/policygetstarted.htm).
For information about endpoints and signing API requests, see [About the API](docs.cloud.oracle.com/iaas/Content/API/Concepts/usingapi.htm). For information about available SDKs and tools, see [SDKS and Other Tools](docs.cloud.oracle.com/iaas/Content/API/Concepts/sdks.htm).
Constant Summary collapse
- SEVERITY_ENUM =
[ SEVERITY_CRITICAL = 'CRITICAL'.freeze, SEVERITY_ERROR = 'ERROR'.freeze, SEVERITY_WARNING = 'WARNING'.freeze, SEVERITY_INFO = 'INFO'.freeze, SEVERITY_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- STATUS_ENUM =
[ STATUS_FIRING = 'FIRING'.freeze, STATUS_OK = 'OK'.freeze, STATUS_SUSPENDED = 'SUSPENDED'.freeze, STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#display_name ⇒ String
[Required] The configured name of the alarm.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the alarm.
-
#severity ⇒ String
[Required] The configured severity of the alarm.
-
#status ⇒ String
[Required] The status of this alarm.
-
#suppression ⇒ OCI::Monitoring::Models::Suppression
The configuration details for suppressing an alarm.
-
#timestamp_triggered ⇒ DateTime
[Required] Timestamp for the transition of the alarm state.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AlarmStatusSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ AlarmStatusSummary
Initializes the object
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/oci/monitoring/models/alarm_status_summary.rb', line 115 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.severity = attributes[:'severity'] if attributes[:'severity'] self. = attributes[:'timestampTriggered'] if attributes[:'timestampTriggered'] raise 'You cannot provide both :timestampTriggered and :timestamp_triggered' if attributes.key?(:'timestampTriggered') && attributes.key?(:'timestamp_triggered') self. = attributes[:'timestamp_triggered'] if attributes[:'timestamp_triggered'] self.status = attributes[:'status'] if attributes[:'status'] self.suppression = attributes[:'suppression'] if attributes[:'suppression'] end |
Instance Attribute Details
#display_name ⇒ String
[Required] The configured name of the alarm.
Example: ‘High CPU Utilization`
46 47 48 |
# File 'lib/oci/monitoring/models/alarm_status_summary.rb', line 46 def display_name @display_name end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the alarm.
39 40 41 |
# File 'lib/oci/monitoring/models/alarm_status_summary.rb', line 39 def id @id end |
#severity ⇒ String
[Required] The configured severity of the alarm.
Example: CRITICAL
53 54 55 |
# File 'lib/oci/monitoring/models/alarm_status_summary.rb', line 53 def severity @severity end |
#status ⇒ String
[Required] The status of this alarm.
Example: FIRING
68 69 70 |
# File 'lib/oci/monitoring/models/alarm_status_summary.rb', line 68 def status @status end |
#suppression ⇒ OCI::Monitoring::Models::Suppression
The configuration details for suppressing an alarm.
73 74 75 |
# File 'lib/oci/monitoring/models/alarm_status_summary.rb', line 73 def suppression @suppression end |
#timestamp_triggered ⇒ DateTime
[Required] Timestamp for the transition of the alarm state. For example, the time when the alarm transitioned from OK to Firing. Note: A three-minute lag for this value accounts for any late-arriving metrics.
Example: 2019-02-01T01:02:29.600Z
61 62 63 |
# File 'lib/oci/monitoring/models/alarm_status_summary.rb', line 61 def end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/oci/monitoring/models/alarm_status_summary.rb', line 76 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'severity': :'severity', 'timestamp_triggered': :'timestampTriggered', 'status': :'status', 'suppression': :'suppression' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/oci/monitoring/models/alarm_status_summary.rb', line 90 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'severity': :'String', 'timestamp_triggered': :'DateTime', 'status': :'String', 'suppression': :'OCI::Monitoring::Models::Suppression' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/oci/monitoring/models/alarm_status_summary.rb', line 175 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && severity == other.severity && == other. && status == other.status && suppression == other.suppression end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/oci/monitoring/models/alarm_status_summary.rb', line 210 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
190 191 192 |
# File 'lib/oci/monitoring/models/alarm_status_summary.rb', line 190 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
199 200 201 |
# File 'lib/oci/monitoring/models/alarm_status_summary.rb', line 199 def hash [id, display_name, severity, , status, suppression].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
243 244 245 246 247 248 249 250 251 252 |
# File 'lib/oci/monitoring/models/alarm_status_summary.rb', line 243 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
237 238 239 |
# File 'lib/oci/monitoring/models/alarm_status_summary.rb', line 237 def to_s to_hash.to_s end |