Method: OCI::Monitoring::MonitoringClient#delete_alarm

Defined in:
lib/oci/monitoring/monitoring_client.rb

#delete_alarm(alarm_id, opts = {}) ⇒ Response

Deletes the specified alarm.

Parameters:

Options Hash (opts):

  • :retry_config (OCI::Retry::RetryConfig)

    The retry configuration to apply to this operation. If no key is provided then the service-level retry configuration defined by #retry_config will be used. If an explicit nil value is provided then the operation will not retry

  • :opc_request_id (String)

    Customer part of the request identifier token. If you need to contact Oracle about a particular request, please provide the complete request ID.

Returns:

  • (Response)

    A Response object with data of type nil



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/oci/monitoring/monitoring_client.rb', line 186

def delete_alarm(alarm_id, opts = {})
  logger.debug 'Calling operation MonitoringClient#delete_alarm.' if logger

  raise "Missing the required parameter 'alarm_id' when calling delete_alarm." if alarm_id.nil?
  raise "Parameter value for 'alarm_id' must not be blank" if OCI::Internal::Util.blank_string?(alarm_id)

  path = '/alarms/{alarmId}'.sub('{alarmId}', alarm_id.to_s)
  operation_signing_strategy = :standard

  # rubocop:disable Style/NegatedIf
  # Query Params
  query_params = {}

  # Header Params
  header_params = {}
  header_params[:accept] = 'application/json'
  header_params[:'content-type'] = 'application/json'
  header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
  # rubocop:enable Style/NegatedIf

  post_body = nil

  # rubocop:disable Metrics/BlockLength
  OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'MonitoringClient#delete_alarm') do
    @api_client.call_api(
      :DELETE,
      path,
      endpoint,
      header_params: header_params,
      query_params: query_params,
      operation_signing_strategy: operation_signing_strategy,
      body: post_body
    )
  end
  # rubocop:enable Metrics/BlockLength
end