Method: OCI::Monitoring::MonitoringClient#update_alarm

Defined in:
lib/oci/monitoring/monitoring_client.rb

#update_alarm(alarm_id, update_alarm_details, opts = {}) ⇒ Response

Updates the specified alarm.

Parameters:

Options Hash (opts):

  • :retry_config (OCI::Retry::RetryConfig)

    The retry configuration to apply to this operation. If no key is provided then the service-level retry configuration defined by #retry_config will be used. If an explicit nil value is provided then the operation will not retry

  • :opc_request_id (String)

    Customer part of the request identifier token. If you need to contact Oracle about a particular request, please provide the complete request ID.

Returns:



872
873
874
875
876
877
878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
# File 'lib/oci/monitoring/monitoring_client.rb', line 872

def update_alarm(alarm_id, update_alarm_details, opts = {})
  logger.debug 'Calling operation MonitoringClient#update_alarm.' if logger

  raise "Missing the required parameter 'alarm_id' when calling update_alarm." if alarm_id.nil?
  raise "Missing the required parameter 'update_alarm_details' when calling update_alarm." if update_alarm_details.nil?
  raise "Parameter value for 'alarm_id' must not be blank" if OCI::Internal::Util.blank_string?(alarm_id)

  path = '/alarms/{alarmId}'.sub('{alarmId}', alarm_id.to_s)
  operation_signing_strategy = :standard

  # rubocop:disable Style/NegatedIf
  # Query Params
  query_params = {}

  # Header Params
  header_params = {}
  header_params[:accept] = 'application/json'
  header_params[:'content-type'] = 'application/json'
  header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
  # rubocop:enable Style/NegatedIf

  post_body = @api_client.object_to_http_body(update_alarm_details)

  # rubocop:disable Metrics/BlockLength
  OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'MonitoringClient#update_alarm') do
    @api_client.call_api(
      :PUT,
      path,
      endpoint,
      header_params: header_params,
      query_params: query_params,
      operation_signing_strategy: operation_signing_strategy,
      body: post_body,
      return_type: 'OCI::Monitoring::Models::Alarm'
    )
  end
  # rubocop:enable Metrics/BlockLength
end