Class: OCI::Mysql::DbSystemClient
- Inherits:
-
Object
- Object
- OCI::Mysql::DbSystemClient
- Defined in:
- lib/oci/mysql/db_system_client.rb
Overview
The API for the MySQL Database Service
Instance Attribute Summary collapse
-
#api_client ⇒ OCI::ApiClient
readonly
Client used to make HTTP requests.
-
#endpoint ⇒ String
readonly
Fully qualified endpoint URL.
-
#region ⇒ String
The region, which will usually correspond to a value in Regions::REGION_ENUM.
-
#retry_config ⇒ OCI::Retry::RetryConfig
readonly
The default retry configuration to apply to all operations in this service client.
Instance Method Summary collapse
-
#add_analytics_cluster(db_system_id, add_analytics_cluster_details, opts = {}) ⇒ Response
DEPRECATED – please use HeatWave API instead.
-
#add_heat_wave_cluster(db_system_id, add_heat_wave_cluster_details, opts = {}) ⇒ Response
Adds a HeatWave cluster to the DB System.
-
#create_db_system(create_db_system_details, opts = {}) ⇒ Response
Creates and launches a DB System.
-
#delete_analytics_cluster(db_system_id, opts = {}) ⇒ Response
DEPRECATED – please use HeatWave API instead.
-
#delete_db_system(db_system_id, opts = {}) ⇒ Response
Delete a DB System, including terminating, detaching, removing, finalizing and otherwise deleting all related resources.
-
#delete_heat_wave_cluster(db_system_id, opts = {}) ⇒ Response
Deletes the HeatWave cluster including terminating, detaching, removing, finalizing and otherwise deleting all related resources.
-
#generate_analytics_cluster_memory_estimate(db_system_id, opts = {}) ⇒ Response
DEPRECATED – please use HeatWave API instead.
-
#generate_heat_wave_cluster_memory_estimate(db_system_id, opts = {}) ⇒ Response
Sends a request to estimate the memory footprints of user tables when loaded to HeatWave cluster memory.
-
#get_analytics_cluster(db_system_id, opts = {}) ⇒ Response
DEPRECATED – please use HeatWave API instead.
-
#get_analytics_cluster_memory_estimate(db_system_id, opts = {}) ⇒ Response
DEPRECATED – please use HeatWave API instead.
-
#get_db_system(db_system_id, opts = {}) ⇒ Response
Get information about the specified DB System.
-
#get_heat_wave_cluster(db_system_id, opts = {}) ⇒ Response
Gets information about the HeatWave cluster.
-
#get_heat_wave_cluster_memory_estimate(db_system_id, opts = {}) ⇒ Response
Gets the most recent HeatWave cluster memory estimate that can be used to determine a suitable HeatWave cluster size.
-
#initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) ⇒ DbSystemClient
constructor
Creates a new DbSystemClient.
-
#list_db_systems(compartment_id, opts = {}) ⇒ Response
Get a list of DB Systems in the specified compartment.
-
#logger ⇒ Logger
The logger for this client.
-
#restart_analytics_cluster(db_system_id, opts = {}) ⇒ Response
DEPRECATED – please use HeatWave API instead.
-
#restart_db_system(db_system_id, restart_db_system_details, opts = {}) ⇒ Response
Restarts the specified DB System.
-
#restart_heat_wave_cluster(db_system_id, opts = {}) ⇒ Response
Restarts the HeatWave cluster.
-
#start_analytics_cluster(db_system_id, opts = {}) ⇒ Response
DEPRECATED – please use HeatWave API instead.
-
#start_db_system(db_system_id, opts = {}) ⇒ Response
Start the specified DB System.
-
#start_heat_wave_cluster(db_system_id, opts = {}) ⇒ Response
Starts the HeatWave cluster.
-
#stop_analytics_cluster(db_system_id, opts = {}) ⇒ Response
DEPRECATED – please use HeatWave API instead.
-
#stop_db_system(db_system_id, stop_db_system_details, opts = {}) ⇒ Response
Stops the specified DB System.
-
#stop_heat_wave_cluster(db_system_id, opts = {}) ⇒ Response
Stops the HeatWave cluster.
-
#update_analytics_cluster(db_system_id, update_analytics_cluster_details, opts = {}) ⇒ Response
DEPRECATED – please use HeatWave API instead.
-
#update_db_system(db_system_id, update_db_system_details, opts = {}) ⇒ Response
Update the configuration of a DB System.
-
#update_heat_wave_cluster(db_system_id, update_heat_wave_cluster_details, opts = {}) ⇒ Response
Updates the HeatWave cluster.
Constructor Details
#initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) ⇒ DbSystemClient
Creates a new DbSystemClient. Notes:
If a config is not specified, then the global OCI.config will be used.
This client is not thread-safe
Either a region or an endpoint must be specified. If an endpoint is specified, it will be used instead of the
region. A region may be specified in the config or via or the region parameter. If specified in both, then the
region parameter will be used.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/oci/mysql/db_system_client.rb', line 53 def initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) # If the signer is an InstancePrincipalsSecurityTokenSigner or SecurityTokenSigner and no config was supplied (they are self-sufficient signers) # then create a dummy config to pass to the ApiClient constructor. If customers wish to create a client which uses instance principals # and has config (either populated programmatically or loaded from a file), they must construct that config themselves and then # pass it to this constructor. # # If there is no signer (or the signer is not an instance principals signer) and no config was supplied, this is not valid # so try and load the config from the default file. config = OCI::Config.validate_and_build_config_with_signer(config, signer) signer = OCI::Signer.config_file_auth_builder(config) if signer.nil? @api_client = OCI::ApiClient.new(config, signer, proxy_settings: proxy_settings) @retry_config = retry_config if endpoint @endpoint = endpoint + '/20190415' else region ||= config.region region ||= signer.region if signer.respond_to?(:region) self.region = region end logger.info "DbSystemClient endpoint set to '#{@endpoint}'." if logger end |
Instance Attribute Details
#api_client ⇒ OCI::ApiClient (readonly)
Client used to make HTTP requests.
13 14 15 |
# File 'lib/oci/mysql/db_system_client.rb', line 13 def api_client @api_client end |
#endpoint ⇒ String (readonly)
Fully qualified endpoint URL
17 18 19 |
# File 'lib/oci/mysql/db_system_client.rb', line 17 def endpoint @endpoint end |
#region ⇒ String
The region, which will usually correspond to a value in Regions::REGION_ENUM.
27 28 29 |
# File 'lib/oci/mysql/db_system_client.rb', line 27 def region @region end |
#retry_config ⇒ OCI::Retry::RetryConfig (readonly)
The default retry configuration to apply to all operations in this service client. This can be overridden on a per-operation basis. The default retry configuration value is nil, which means that an operation will not perform any retries
23 24 25 |
# File 'lib/oci/mysql/db_system_client.rb', line 23 def retry_config @retry_config end |
Instance Method Details
#add_analytics_cluster(db_system_id, add_analytics_cluster_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/mysql/add_analytics_cluster.rb.html) to see an example of how to use add_analytics_cluster API.
DEPRECATED – please use HeatWave API instead. Adds an Analytics Cluster to the DB System.
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/oci/mysql/db_system_client.rb', line 128 def add_analytics_cluster(db_system_id, add_analytics_cluster_details, opts = {}) logger.debug 'Calling operation DbSystemClient#add_analytics_cluster.' if logger raise "Missing the required parameter 'db_system_id' when calling add_analytics_cluster." if db_system_id.nil? raise "Missing the required parameter 'add_analytics_cluster_details' when calling add_analytics_cluster." if add_analytics_cluster_details.nil? raise "Parameter value for 'db_system_id' must not be blank" if OCI::Internal::Util.blank_string?(db_system_id) path = '/dbSystems/{dbSystemId}/analyticsCluster/actions/add'.sub('{dbSystemId}', db_system_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = @api_client.object_to_http_body(add_analytics_cluster_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DbSystemClient#add_analytics_cluster') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Mysql::Models::AnalyticsCluster' ) end # rubocop:enable Metrics/BlockLength end |
#add_heat_wave_cluster(db_system_id, add_heat_wave_cluster_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/mysql/add_heat_wave_cluster.rb.html) to see an example of how to use add_heat_wave_cluster API.
Adds a HeatWave cluster to the DB System.
204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/oci/mysql/db_system_client.rb', line 204 def add_heat_wave_cluster(db_system_id, add_heat_wave_cluster_details, opts = {}) logger.debug 'Calling operation DbSystemClient#add_heat_wave_cluster.' if logger raise "Missing the required parameter 'db_system_id' when calling add_heat_wave_cluster." if db_system_id.nil? raise "Missing the required parameter 'add_heat_wave_cluster_details' when calling add_heat_wave_cluster." if add_heat_wave_cluster_details.nil? raise "Parameter value for 'db_system_id' must not be blank" if OCI::Internal::Util.blank_string?(db_system_id) path = '/dbSystems/{dbSystemId}/heatWaveCluster/actions/add'.sub('{dbSystemId}', db_system_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = @api_client.object_to_http_body(add_heat_wave_cluster_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DbSystemClient#add_heat_wave_cluster') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Mysql::Models::HeatWaveCluster' ) end # rubocop:enable Metrics/BlockLength end |
#create_db_system(create_db_system_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/mysql/create_db_system.rb.html) to see an example of how to use create_db_system API.
Creates and launches a DB System.
273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 |
# File 'lib/oci/mysql/db_system_client.rb', line 273 def create_db_system(create_db_system_details, opts = {}) logger.debug 'Calling operation DbSystemClient#create_db_system.' if logger raise "Missing the required parameter 'create_db_system_details' when calling create_db_system." if create_db_system_details.nil? path = '/dbSystems' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = @api_client.object_to_http_body(create_db_system_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DbSystemClient#create_db_system') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Mysql::Models::DbSystem' ) end # rubocop:enable Metrics/BlockLength end |
#delete_analytics_cluster(db_system_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/mysql/delete_analytics_cluster.rb.html) to see an example of how to use delete_analytics_cluster API.
DEPRECATED – please use HeatWave API instead. Deletes the Analytics Cluster including terminating, detaching, removing, finalizing and otherwise deleting all related resources.
340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 |
# File 'lib/oci/mysql/db_system_client.rb', line 340 def delete_analytics_cluster(db_system_id, opts = {}) logger.debug 'Calling operation DbSystemClient#delete_analytics_cluster.' if logger raise "Missing the required parameter 'db_system_id' when calling delete_analytics_cluster." if db_system_id.nil? raise "Parameter value for 'db_system_id' must not be blank" if OCI::Internal::Util.blank_string?(db_system_id) path = '/dbSystems/{dbSystemId}/analyticsCluster'.sub('{dbSystemId}', db_system_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DbSystemClient#delete_analytics_cluster') do @api_client.call_api( :DELETE, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#delete_db_system(db_system_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/mysql/delete_db_system.rb.html) to see an example of how to use delete_db_system API.
Delete a DB System, including terminating, detaching, removing, finalizing and otherwise deleting all related resources.
405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 |
# File 'lib/oci/mysql/db_system_client.rb', line 405 def delete_db_system(db_system_id, opts = {}) logger.debug 'Calling operation DbSystemClient#delete_db_system.' if logger raise "Missing the required parameter 'db_system_id' when calling delete_db_system." if db_system_id.nil? raise "Parameter value for 'db_system_id' must not be blank" if OCI::Internal::Util.blank_string?(db_system_id) path = '/dbSystems/{dbSystemId}'.sub('{dbSystemId}', db_system_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DbSystemClient#delete_db_system') do @api_client.call_api( :DELETE, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#delete_heat_wave_cluster(db_system_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/mysql/delete_heat_wave_cluster.rb.html) to see an example of how to use delete_heat_wave_cluster API.
Deletes the HeatWave cluster including terminating, detaching, removing, finalizing and otherwise deleting all related resources.
470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 |
# File 'lib/oci/mysql/db_system_client.rb', line 470 def delete_heat_wave_cluster(db_system_id, opts = {}) logger.debug 'Calling operation DbSystemClient#delete_heat_wave_cluster.' if logger raise "Missing the required parameter 'db_system_id' when calling delete_heat_wave_cluster." if db_system_id.nil? raise "Parameter value for 'db_system_id' must not be blank" if OCI::Internal::Util.blank_string?(db_system_id) path = '/dbSystems/{dbSystemId}/heatWaveCluster'.sub('{dbSystemId}', db_system_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DbSystemClient#delete_heat_wave_cluster') do @api_client.call_api( :DELETE, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#generate_analytics_cluster_memory_estimate(db_system_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/mysql/generate_analytics_cluster_memory_estimate.rb.html) to see an example of how to use generate_analytics_cluster_memory_estimate API.
DEPRECATED – please use HeatWave API instead. Sends a request to estimate the memory footprints of user tables when loaded to Analytics Cluster memory.
536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 |
# File 'lib/oci/mysql/db_system_client.rb', line 536 def generate_analytics_cluster_memory_estimate(db_system_id, opts = {}) logger.debug 'Calling operation DbSystemClient#generate_analytics_cluster_memory_estimate.' if logger raise "Missing the required parameter 'db_system_id' when calling generate_analytics_cluster_memory_estimate." if db_system_id.nil? raise "Parameter value for 'db_system_id' must not be blank" if OCI::Internal::Util.blank_string?(db_system_id) path = '/dbSystems/{dbSystemId}/analyticsClusterMemoryEstimate/actions/generate'.sub('{dbSystemId}', db_system_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DbSystemClient#generate_analytics_cluster_memory_estimate') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Mysql::Models::AnalyticsClusterMemoryEstimate' ) end # rubocop:enable Metrics/BlockLength end |
#generate_heat_wave_cluster_memory_estimate(db_system_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/mysql/generate_heat_wave_cluster_memory_estimate.rb.html) to see an example of how to use generate_heat_wave_cluster_memory_estimate API.
Sends a request to estimate the memory footprints of user tables when loaded to HeatWave cluster memory.
603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'lib/oci/mysql/db_system_client.rb', line 603 def generate_heat_wave_cluster_memory_estimate(db_system_id, opts = {}) logger.debug 'Calling operation DbSystemClient#generate_heat_wave_cluster_memory_estimate.' if logger raise "Missing the required parameter 'db_system_id' when calling generate_heat_wave_cluster_memory_estimate." if db_system_id.nil? raise "Parameter value for 'db_system_id' must not be blank" if OCI::Internal::Util.blank_string?(db_system_id) path = '/dbSystems/{dbSystemId}/heatWaveClusterMemoryEstimate/actions/generate'.sub('{dbSystemId}', db_system_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DbSystemClient#generate_heat_wave_cluster_memory_estimate') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Mysql::Models::HeatWaveClusterMemoryEstimate' ) end # rubocop:enable Metrics/BlockLength end |
#get_analytics_cluster(db_system_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/mysql/get_analytics_cluster.rb.html) to see an example of how to use get_analytics_cluster API.
DEPRECATED – please use HeatWave API instead. Gets information about the Analytics Cluster.
670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 |
# File 'lib/oci/mysql/db_system_client.rb', line 670 def get_analytics_cluster(db_system_id, opts = {}) logger.debug 'Calling operation DbSystemClient#get_analytics_cluster.' if logger raise "Missing the required parameter 'db_system_id' when calling get_analytics_cluster." if db_system_id.nil? raise "Parameter value for 'db_system_id' must not be blank" if OCI::Internal::Util.blank_string?(db_system_id) path = '/dbSystems/{dbSystemId}/analyticsCluster'.sub('{dbSystemId}', db_system_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'if-none-match'] = opts[:if_none_match] if opts[:if_none_match] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DbSystemClient#get_analytics_cluster') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Mysql::Models::AnalyticsCluster' ) end # rubocop:enable Metrics/BlockLength end |
#get_analytics_cluster_memory_estimate(db_system_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/mysql/get_analytics_cluster_memory_estimate.rb.html) to see an example of how to use get_analytics_cluster_memory_estimate API.
DEPRECATED – please use HeatWave API instead. Gets the most recent Analytics Cluster memory estimate that can be used to determine a suitable Analytics Cluster size.
731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 |
# File 'lib/oci/mysql/db_system_client.rb', line 731 def get_analytics_cluster_memory_estimate(db_system_id, opts = {}) logger.debug 'Calling operation DbSystemClient#get_analytics_cluster_memory_estimate.' if logger raise "Missing the required parameter 'db_system_id' when calling get_analytics_cluster_memory_estimate." if db_system_id.nil? raise "Parameter value for 'db_system_id' must not be blank" if OCI::Internal::Util.blank_string?(db_system_id) path = '/dbSystems/{dbSystemId}/analyticsClusterMemoryEstimate'.sub('{dbSystemId}', db_system_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DbSystemClient#get_analytics_cluster_memory_estimate') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Mysql::Models::AnalyticsClusterMemoryEstimate' ) end # rubocop:enable Metrics/BlockLength end |
#get_db_system(db_system_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/mysql/get_db_system.rb.html) to see an example of how to use get_db_system API.
Get information about the specified DB System.
794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 |
# File 'lib/oci/mysql/db_system_client.rb', line 794 def get_db_system(db_system_id, opts = {}) logger.debug 'Calling operation DbSystemClient#get_db_system.' if logger raise "Missing the required parameter 'db_system_id' when calling get_db_system." if db_system_id.nil? raise "Parameter value for 'db_system_id' must not be blank" if OCI::Internal::Util.blank_string?(db_system_id) path = '/dbSystems/{dbSystemId}'.sub('{dbSystemId}', db_system_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'if-none-match'] = opts[:if_none_match] if opts[:if_none_match] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DbSystemClient#get_db_system') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Mysql::Models::DbSystem' ) end # rubocop:enable Metrics/BlockLength end |
#get_heat_wave_cluster(db_system_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/mysql/get_heat_wave_cluster.rb.html) to see an example of how to use get_heat_wave_cluster API.
Gets information about the HeatWave cluster.
858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 |
# File 'lib/oci/mysql/db_system_client.rb', line 858 def get_heat_wave_cluster(db_system_id, opts = {}) logger.debug 'Calling operation DbSystemClient#get_heat_wave_cluster.' if logger raise "Missing the required parameter 'db_system_id' when calling get_heat_wave_cluster." if db_system_id.nil? raise "Parameter value for 'db_system_id' must not be blank" if OCI::Internal::Util.blank_string?(db_system_id) path = '/dbSystems/{dbSystemId}/heatWaveCluster'.sub('{dbSystemId}', db_system_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'if-none-match'] = opts[:if_none_match] if opts[:if_none_match] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DbSystemClient#get_heat_wave_cluster') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Mysql::Models::HeatWaveCluster' ) end # rubocop:enable Metrics/BlockLength end |
#get_heat_wave_cluster_memory_estimate(db_system_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/mysql/get_heat_wave_cluster_memory_estimate.rb.html) to see an example of how to use get_heat_wave_cluster_memory_estimate API.
Gets the most recent HeatWave cluster memory estimate that can be used to determine a suitable HeatWave cluster size.
918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 |
# File 'lib/oci/mysql/db_system_client.rb', line 918 def get_heat_wave_cluster_memory_estimate(db_system_id, opts = {}) logger.debug 'Calling operation DbSystemClient#get_heat_wave_cluster_memory_estimate.' if logger raise "Missing the required parameter 'db_system_id' when calling get_heat_wave_cluster_memory_estimate." if db_system_id.nil? raise "Parameter value for 'db_system_id' must not be blank" if OCI::Internal::Util.blank_string?(db_system_id) path = '/dbSystems/{dbSystemId}/heatWaveClusterMemoryEstimate'.sub('{dbSystemId}', db_system_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DbSystemClient#get_heat_wave_cluster_memory_estimate') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Mysql::Models::HeatWaveClusterMemoryEstimate' ) end # rubocop:enable Metrics/BlockLength end |
#list_db_systems(compartment_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/mysql/list_db_systems.rb.html) to see an example of how to use list_db_systems API.
Get a list of DB Systems in the specified compartment. The default sort order is by timeUpdated, descending.
Allowed values are: displayName, timeCreated
1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 |
# File 'lib/oci/mysql/db_system_client.rb', line 1005 def list_db_systems(compartment_id, opts = {}) logger.debug 'Calling operation DbSystemClient#list_db_systems.' if logger raise "Missing the required parameter 'compartment_id' when calling list_db_systems." if compartment_id.nil? if opts[:lifecycle_state] && !OCI::Mysql::Models::DbSystem::LIFECYCLE_STATE_ENUM.include?(opts[:lifecycle_state]) raise 'Invalid value for "lifecycle_state", must be one of the values in OCI::Mysql::Models::DbSystem::LIFECYCLE_STATE_ENUM.' end if opts[:sort_by] && !%w[displayName timeCreated].include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of displayName, timeCreated.' end if opts[:sort_order] && !%w[ASC DESC].include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of ASC, DESC.' end path = '/dbSystems' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:compartmentId] = compartment_id query_params[:isAnalyticsClusterAttached] = opts[:is_analytics_cluster_attached] if !opts[:is_analytics_cluster_attached].nil? query_params[:isHeatWaveClusterAttached] = opts[:is_heat_wave_cluster_attached] if !opts[:is_heat_wave_cluster_attached].nil? query_params[:dbSystemId] = opts[:db_system_id] if opts[:db_system_id] query_params[:displayName] = opts[:display_name] if opts[:display_name] query_params[:lifecycleState] = opts[:lifecycle_state] if opts[:lifecycle_state] query_params[:configurationId] = opts[:configuration_id] if opts[:configuration_id] query_params[:isUpToDate] = opts[:is_up_to_date] if !opts[:is_up_to_date].nil? query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DbSystemClient#list_db_systems') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'Array<OCI::Mysql::Models::DbSystemSummary>' ) end # rubocop:enable Metrics/BlockLength end |
#logger ⇒ Logger
Returns The logger for this client. May be nil.
92 93 94 |
# File 'lib/oci/mysql/db_system_client.rb', line 92 def logger @api_client.config.logger end |
#restart_analytics_cluster(db_system_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/mysql/restart_analytics_cluster.rb.html) to see an example of how to use restart_analytics_cluster API.
DEPRECATED – please use HeatWave API instead. Restarts the Analytics Cluster.
1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 |
# File 'lib/oci/mysql/db_system_client.rb', line 1100 def restart_analytics_cluster(db_system_id, opts = {}) logger.debug 'Calling operation DbSystemClient#restart_analytics_cluster.' if logger raise "Missing the required parameter 'db_system_id' when calling restart_analytics_cluster." if db_system_id.nil? raise "Parameter value for 'db_system_id' must not be blank" if OCI::Internal::Util.blank_string?(db_system_id) path = '/dbSystems/{dbSystemId}/analyticsCluster/actions/restart'.sub('{dbSystemId}', db_system_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DbSystemClient#restart_analytics_cluster') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#restart_db_system(db_system_id, restart_db_system_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/mysql/restart_db_system.rb.html) to see an example of how to use restart_db_system API.
Restarts the specified DB System.
1173 1174 1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 |
# File 'lib/oci/mysql/db_system_client.rb', line 1173 def restart_db_system(db_system_id, restart_db_system_details, opts = {}) logger.debug 'Calling operation DbSystemClient#restart_db_system.' if logger raise "Missing the required parameter 'db_system_id' when calling restart_db_system." if db_system_id.nil? raise "Missing the required parameter 'restart_db_system_details' when calling restart_db_system." if restart_db_system_details.nil? raise "Parameter value for 'db_system_id' must not be blank" if OCI::Internal::Util.blank_string?(db_system_id) path = '/dbSystems/{dbSystemId}/actions/restart'.sub('{dbSystemId}', db_system_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = @api_client.object_to_http_body(restart_db_system_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DbSystemClient#restart_db_system') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#restart_heat_wave_cluster(db_system_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/mysql/restart_heat_wave_cluster.rb.html) to see an example of how to use restart_heat_wave_cluster API.
Restarts the HeatWave cluster.
1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 1267 1268 1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 1284 |
# File 'lib/oci/mysql/db_system_client.rb', line 1246 def restart_heat_wave_cluster(db_system_id, opts = {}) logger.debug 'Calling operation DbSystemClient#restart_heat_wave_cluster.' if logger raise "Missing the required parameter 'db_system_id' when calling restart_heat_wave_cluster." if db_system_id.nil? raise "Parameter value for 'db_system_id' must not be blank" if OCI::Internal::Util.blank_string?(db_system_id) path = '/dbSystems/{dbSystemId}/heatWaveCluster/actions/restart'.sub('{dbSystemId}', db_system_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DbSystemClient#restart_heat_wave_cluster') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#start_analytics_cluster(db_system_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/mysql/start_analytics_cluster.rb.html) to see an example of how to use start_analytics_cluster API.
DEPRECATED – please use HeatWave API instead. Starts the Analytics Cluster.
1320 1321 1322 1323 1324 1325 1326 1327 1328 1329 1330 1331 1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 |
# File 'lib/oci/mysql/db_system_client.rb', line 1320 def start_analytics_cluster(db_system_id, opts = {}) logger.debug 'Calling operation DbSystemClient#start_analytics_cluster.' if logger raise "Missing the required parameter 'db_system_id' when calling start_analytics_cluster." if db_system_id.nil? raise "Parameter value for 'db_system_id' must not be blank" if OCI::Internal::Util.blank_string?(db_system_id) path = '/dbSystems/{dbSystemId}/analyticsCluster/actions/start'.sub('{dbSystemId}', db_system_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DbSystemClient#start_analytics_cluster') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#start_db_system(db_system_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/mysql/start_db_system.rb.html) to see an example of how to use start_db_system API.
Start the specified DB System.
1392 1393 1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 |
# File 'lib/oci/mysql/db_system_client.rb', line 1392 def start_db_system(db_system_id, opts = {}) logger.debug 'Calling operation DbSystemClient#start_db_system.' if logger raise "Missing the required parameter 'db_system_id' when calling start_db_system." if db_system_id.nil? raise "Parameter value for 'db_system_id' must not be blank" if OCI::Internal::Util.blank_string?(db_system_id) path = '/dbSystems/{dbSystemId}/actions/start'.sub('{dbSystemId}', db_system_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DbSystemClient#start_db_system') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#start_heat_wave_cluster(db_system_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/mysql/start_heat_wave_cluster.rb.html) to see an example of how to use start_heat_wave_cluster API.
Starts the HeatWave cluster.
1464 1465 1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 1480 1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 |
# File 'lib/oci/mysql/db_system_client.rb', line 1464 def start_heat_wave_cluster(db_system_id, opts = {}) logger.debug 'Calling operation DbSystemClient#start_heat_wave_cluster.' if logger raise "Missing the required parameter 'db_system_id' when calling start_heat_wave_cluster." if db_system_id.nil? raise "Parameter value for 'db_system_id' must not be blank" if OCI::Internal::Util.blank_string?(db_system_id) path = '/dbSystems/{dbSystemId}/heatWaveCluster/actions/start'.sub('{dbSystemId}', db_system_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DbSystemClient#start_heat_wave_cluster') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#stop_analytics_cluster(db_system_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/mysql/stop_analytics_cluster.rb.html) to see an example of how to use stop_analytics_cluster API.
DEPRECATED – please use HeatWave API instead. Stops the Analytics Cluster.
1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 |
# File 'lib/oci/mysql/db_system_client.rb', line 1538 def stop_analytics_cluster(db_system_id, opts = {}) logger.debug 'Calling operation DbSystemClient#stop_analytics_cluster.' if logger raise "Missing the required parameter 'db_system_id' when calling stop_analytics_cluster." if db_system_id.nil? raise "Parameter value for 'db_system_id' must not be blank" if OCI::Internal::Util.blank_string?(db_system_id) path = '/dbSystems/{dbSystemId}/analyticsCluster/actions/stop'.sub('{dbSystemId}', db_system_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DbSystemClient#stop_analytics_cluster') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#stop_db_system(db_system_id, stop_db_system_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/mysql/stop_db_system.rb.html) to see an example of how to use stop_db_system API.
Stops the specified DB System.
A stopped DB System is not billed.
1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 1652 1653 |
# File 'lib/oci/mysql/db_system_client.rb', line 1614 def stop_db_system(db_system_id, stop_db_system_details, opts = {}) logger.debug 'Calling operation DbSystemClient#stop_db_system.' if logger raise "Missing the required parameter 'db_system_id' when calling stop_db_system." if db_system_id.nil? raise "Missing the required parameter 'stop_db_system_details' when calling stop_db_system." if stop_db_system_details.nil? raise "Parameter value for 'db_system_id' must not be blank" if OCI::Internal::Util.blank_string?(db_system_id) path = '/dbSystems/{dbSystemId}/actions/stop'.sub('{dbSystemId}', db_system_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = @api_client.object_to_http_body(stop_db_system_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DbSystemClient#stop_db_system') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#stop_heat_wave_cluster(db_system_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/mysql/stop_heat_wave_cluster.rb.html) to see an example of how to use stop_heat_wave_cluster API.
Stops the HeatWave cluster.
1687 1688 1689 1690 1691 1692 1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 |
# File 'lib/oci/mysql/db_system_client.rb', line 1687 def stop_heat_wave_cluster(db_system_id, opts = {}) logger.debug 'Calling operation DbSystemClient#stop_heat_wave_cluster.' if logger raise "Missing the required parameter 'db_system_id' when calling stop_heat_wave_cluster." if db_system_id.nil? raise "Parameter value for 'db_system_id' must not be blank" if OCI::Internal::Util.blank_string?(db_system_id) path = '/dbSystems/{dbSystemId}/heatWaveCluster/actions/stop'.sub('{dbSystemId}', db_system_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DbSystemClient#stop_heat_wave_cluster') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#update_analytics_cluster(db_system_id, update_analytics_cluster_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/mysql/update_analytics_cluster.rb.html) to see an example of how to use update_analytics_cluster API.
DEPRECATED – please use HeatWave API instead. Updates the Analytics Cluster.
1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 1770 1771 1772 1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 |
# File 'lib/oci/mysql/db_system_client.rb', line 1755 def update_analytics_cluster(db_system_id, update_analytics_cluster_details, opts = {}) logger.debug 'Calling operation DbSystemClient#update_analytics_cluster.' if logger raise "Missing the required parameter 'db_system_id' when calling update_analytics_cluster." if db_system_id.nil? raise "Missing the required parameter 'update_analytics_cluster_details' when calling update_analytics_cluster." if update_analytics_cluster_details.nil? raise "Parameter value for 'db_system_id' must not be blank" if OCI::Internal::Util.blank_string?(db_system_id) path = '/dbSystems/{dbSystemId}/analyticsCluster'.sub('{dbSystemId}', db_system_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(update_analytics_cluster_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DbSystemClient#update_analytics_cluster') do @api_client.call_api( :PUT, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#update_db_system(db_system_id, update_db_system_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/mysql/update_db_system.rb.html) to see an example of how to use update_db_system API.
Update the configuration of a DB System.
Updating different fields in the DB System will have different results on the uptime of the DB System. For example, changing the displayName of a DB System will take effect immediately, but changing the shape of a DB System is an asynchronous operation that involves provisioning new Compute resources, pausing the DB System and migrating storage before making the DB System available again.
1828 1829 1830 1831 1832 1833 1834 1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 1846 1847 1848 1849 1850 1851 1852 1853 1854 1855 1856 1857 1858 1859 1860 1861 1862 1863 1864 1865 |
# File 'lib/oci/mysql/db_system_client.rb', line 1828 def update_db_system(db_system_id, update_db_system_details, opts = {}) logger.debug 'Calling operation DbSystemClient#update_db_system.' if logger raise "Missing the required parameter 'db_system_id' when calling update_db_system." if db_system_id.nil? raise "Missing the required parameter 'update_db_system_details' when calling update_db_system." if update_db_system_details.nil? raise "Parameter value for 'db_system_id' must not be blank" if OCI::Internal::Util.blank_string?(db_system_id) path = '/dbSystems/{dbSystemId}'.sub('{dbSystemId}', db_system_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(update_db_system_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DbSystemClient#update_db_system') do @api_client.call_api( :PUT, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#update_heat_wave_cluster(db_system_id, update_heat_wave_cluster_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/mysql/update_heat_wave_cluster.rb.html) to see an example of how to use update_heat_wave_cluster API.
Updates the HeatWave cluster.
1894 1895 1896 1897 1898 1899 1900 1901 1902 1903 1904 1905 1906 1907 1908 1909 1910 1911 1912 1913 1914 1915 1916 1917 1918 1919 1920 1921 1922 1923 1924 1925 1926 1927 1928 1929 1930 1931 |
# File 'lib/oci/mysql/db_system_client.rb', line 1894 def update_heat_wave_cluster(db_system_id, update_heat_wave_cluster_details, opts = {}) logger.debug 'Calling operation DbSystemClient#update_heat_wave_cluster.' if logger raise "Missing the required parameter 'db_system_id' when calling update_heat_wave_cluster." if db_system_id.nil? raise "Missing the required parameter 'update_heat_wave_cluster_details' when calling update_heat_wave_cluster." if update_heat_wave_cluster_details.nil? raise "Parameter value for 'db_system_id' must not be blank" if OCI::Internal::Util.blank_string?(db_system_id) path = '/dbSystems/{dbSystemId}/heatWaveCluster'.sub('{dbSystemId}', db_system_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(update_heat_wave_cluster_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DbSystemClient#update_heat_wave_cluster') do @api_client.call_api( :PUT, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |