Class: OCI::Mysql::Models::AnalyticsCluster

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/mysql/models/analytics_cluster.rb

Overview

DEPRECATED – please use HeatWave API instead. An Analytics Cluster is a database accelerator for a DB System.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ AnalyticsCluster

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/oci/mysql/models/analytics_cluster.rb', line 106

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.db_system_id = attributes[:'dbSystemId'] if attributes[:'dbSystemId']

  raise 'You cannot provide both :dbSystemId and :db_system_id' if attributes.key?(:'dbSystemId') && attributes.key?(:'db_system_id')

  self.db_system_id = attributes[:'db_system_id'] if attributes[:'db_system_id']

  self.shape_name = attributes[:'shapeName'] if attributes[:'shapeName']

  raise 'You cannot provide both :shapeName and :shape_name' if attributes.key?(:'shapeName') && attributes.key?(:'shape_name')

  self.shape_name = attributes[:'shape_name'] if attributes[:'shape_name']

  self.cluster_size = attributes[:'clusterSize'] if attributes[:'clusterSize']

  raise 'You cannot provide both :clusterSize and :cluster_size' if attributes.key?(:'clusterSize') && attributes.key?(:'cluster_size')

  self.cluster_size = attributes[:'cluster_size'] if attributes[:'cluster_size']

  self.cluster_nodes = attributes[:'clusterNodes'] if attributes[:'clusterNodes']

  raise 'You cannot provide both :clusterNodes and :cluster_nodes' if attributes.key?(:'clusterNodes') && attributes.key?(:'cluster_nodes')

  self.cluster_nodes = attributes[:'cluster_nodes'] if attributes[:'cluster_nodes']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']
end

Instance Attribute Details

#cluster_nodesArray<OCI::Mysql::Models::AnalyticsClusterNode>

[Required] An Analytics Cluster Node is a compute host that is part of an Analytics Cluster.

Returns:



42
43
44
# File 'lib/oci/mysql/models/analytics_cluster.rb', line 42

def cluster_nodes
  @cluster_nodes
end

#cluster_sizeInteger

[Required] The number of analytics-processing compute instances, of the specified shape, in the Analytics Cluster.

Returns:



38
39
40
# File 'lib/oci/mysql/models/analytics_cluster.rb', line 38

def cluster_size
  @cluster_size
end

#db_system_idString

[Required] The OCID of the parent DB System this Analytics Cluster is attached to.

Returns:



26
27
28
# File 'lib/oci/mysql/models/analytics_cluster.rb', line 26

def db_system_id
  @db_system_id
end

#lifecycle_detailsString

Additional information about the current lifecycleState.

Returns:



50
51
52
# File 'lib/oci/mysql/models/analytics_cluster.rb', line 50

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

[Required] The current state of the Analytics Cluster.

Returns:



46
47
48
# File 'lib/oci/mysql/models/analytics_cluster.rb', line 46

def lifecycle_state
  @lifecycle_state
end

#shape_nameString

[Required] The shape determines resources to allocate to the Analytics Cluster nodes - CPU cores, memory.

Returns:



32
33
34
# File 'lib/oci/mysql/models/analytics_cluster.rb', line 32

def shape_name
  @shape_name
end

#time_createdDateTime

[Required] The date and time the Analytics Cluster was created, as described by [RFC 3339](tools.ietf.org/rfc/rfc3339).

Returns:



54
55
56
# File 'lib/oci/mysql/models/analytics_cluster.rb', line 54

def time_created
  @time_created
end

#time_updatedDateTime

[Required] The time the Analytics Cluster was last updated, as described by [RFC 3339](tools.ietf.org/rfc/rfc3339).

Returns:



58
59
60
# File 'lib/oci/mysql/models/analytics_cluster.rb', line 58

def time_updated
  @time_updated
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/oci/mysql/models/analytics_cluster.rb', line 61

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'db_system_id': :'dbSystemId',
    'shape_name': :'shapeName',
    'cluster_size': :'clusterSize',
    'cluster_nodes': :'clusterNodes',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/oci/mysql/models/analytics_cluster.rb', line 77

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'db_system_id': :'String',
    'shape_name': :'String',
    'cluster_size': :'Integer',
    'cluster_nodes': :'Array<OCI::Mysql::Models::AnalyticsClusterNode>',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • the other object to be compared



181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/oci/mysql/models/analytics_cluster.rb', line 181

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    db_system_id == other.db_system_id &&
    shape_name == other.shape_name &&
    cluster_size == other.cluster_size &&
    cluster_nodes == other.cluster_nodes &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    time_created == other.time_created &&
    time_updated == other.time_updated
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/oci/mysql/models/analytics_cluster.rb', line 218

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • the other object to be compared

Returns:

See Also:

  • `==` method


198
199
200
# File 'lib/oci/mysql/models/analytics_cluster.rb', line 198

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • Hash code



207
208
209
# File 'lib/oci/mysql/models/analytics_cluster.rb', line 207

def hash
  [db_system_id, shape_name, cluster_size, cluster_nodes, lifecycle_state, lifecycle_details, time_created, time_updated].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



251
252
253
254
255
256
257
258
259
260
# File 'lib/oci/mysql/models/analytics_cluster.rb', line 251

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



245
246
247
# File 'lib/oci/mysql/models/analytics_cluster.rb', line 245

def to_s
  to_hash.to_s
end