Class: OCI::Mysql::Models::Backup

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/mysql/models/backup.rb

Overview

A full or incremental copy of a DB System which can be used to create a new DB System or recover a DB System.

To use any of the API operations, you must be authorized in an IAM policy. If you're not authorized, talk to an administrator. If you're an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm).

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
BACKUP_TYPE_ENUM =
[
  BACKUP_TYPE_FULL = 'FULL'.freeze,
  BACKUP_TYPE_INCREMENTAL = 'INCREMENTAL'.freeze,
  BACKUP_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
CREATION_TYPE_ENUM =
[
  CREATION_TYPE_MANUAL = 'MANUAL'.freeze,
  CREATION_TYPE_AUTOMATIC = 'AUTOMATIC'.freeze,
  CREATION_TYPE_OPERATOR = 'OPERATOR'.freeze,
  CREATION_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Backup

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :display_name (String)

    The value to assign to the #display_name property

  • :description (String)

    The value to assign to the #description property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :time_updated (DateTime)

    The value to assign to the #time_updated property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :lifecycle_details (String)

    The value to assign to the #lifecycle_details property

  • :backup_type (String)

    The value to assign to the #backup_type property

  • :creation_type (String)

    The value to assign to the #creation_type property

  • :db_system_id (String)

    The value to assign to the #db_system_id property

  • :db_system_snapshot (OCI::Mysql::Models::DbSystemSnapshot)

    The value to assign to the #db_system_snapshot property

  • :backup_size_in_gbs (Integer)

    The value to assign to the #backup_size_in_gbs property

  • :retention_in_days (Integer)

    The value to assign to the #retention_in_days property

  • :data_storage_size_in_gbs (Integer)

    The value to assign to the #data_storage_size_in_gbs property

  • :mysql_version (String)

    The value to assign to the #mysql_version property

  • :shape_name (String)

    The value to assign to the #shape_name property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property



203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/oci/mysql/models/backup.rb', line 203

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.backup_type = attributes[:'backupType'] if attributes[:'backupType']

  raise 'You cannot provide both :backupType and :backup_type' if attributes.key?(:'backupType') && attributes.key?(:'backup_type')

  self.backup_type = attributes[:'backup_type'] if attributes[:'backup_type']

  self.creation_type = attributes[:'creationType'] if attributes[:'creationType']

  raise 'You cannot provide both :creationType and :creation_type' if attributes.key?(:'creationType') && attributes.key?(:'creation_type')

  self.creation_type = attributes[:'creation_type'] if attributes[:'creation_type']

  self.db_system_id = attributes[:'dbSystemId'] if attributes[:'dbSystemId']

  raise 'You cannot provide both :dbSystemId and :db_system_id' if attributes.key?(:'dbSystemId') && attributes.key?(:'db_system_id')

  self.db_system_id = attributes[:'db_system_id'] if attributes[:'db_system_id']

  self.db_system_snapshot = attributes[:'dbSystemSnapshot'] if attributes[:'dbSystemSnapshot']

  raise 'You cannot provide both :dbSystemSnapshot and :db_system_snapshot' if attributes.key?(:'dbSystemSnapshot') && attributes.key?(:'db_system_snapshot')

  self.db_system_snapshot = attributes[:'db_system_snapshot'] if attributes[:'db_system_snapshot']

  self.backup_size_in_gbs = attributes[:'backupSizeInGBs'] if attributes[:'backupSizeInGBs']

  raise 'You cannot provide both :backupSizeInGBs and :backup_size_in_gbs' if attributes.key?(:'backupSizeInGBs') && attributes.key?(:'backup_size_in_gbs')

  self.backup_size_in_gbs = attributes[:'backup_size_in_gbs'] if attributes[:'backup_size_in_gbs']

  self.retention_in_days = attributes[:'retentionInDays'] if attributes[:'retentionInDays']

  raise 'You cannot provide both :retentionInDays and :retention_in_days' if attributes.key?(:'retentionInDays') && attributes.key?(:'retention_in_days')

  self.retention_in_days = attributes[:'retention_in_days'] if attributes[:'retention_in_days']

  self.data_storage_size_in_gbs = attributes[:'dataStorageSizeInGBs'] if attributes[:'dataStorageSizeInGBs']

  raise 'You cannot provide both :dataStorageSizeInGBs and :data_storage_size_in_gbs' if attributes.key?(:'dataStorageSizeInGBs') && attributes.key?(:'data_storage_size_in_gbs')

  self.data_storage_size_in_gbs = attributes[:'data_storage_size_in_gbs'] if attributes[:'data_storage_size_in_gbs']

  self.mysql_version = attributes[:'mysqlVersion'] if attributes[:'mysqlVersion']

  raise 'You cannot provide both :mysqlVersion and :mysql_version' if attributes.key?(:'mysqlVersion') && attributes.key?(:'mysql_version')

  self.mysql_version = attributes[:'mysql_version'] if attributes[:'mysql_version']

  self.shape_name = attributes[:'shapeName'] if attributes[:'shapeName']

  raise 'You cannot provide both :shapeName and :shape_name' if attributes.key?(:'shapeName') && attributes.key?(:'shape_name')

  self.shape_name = attributes[:'shape_name'] if attributes[:'shape_name']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#backup_size_in_gbsInteger

The size of the backup in base-2 (IEC) gibibytes. (GiB).

Returns:

  • (Integer)


93
94
95
# File 'lib/oci/mysql/models/backup.rb', line 93

def backup_size_in_gbs
  @backup_size_in_gbs
end

#backup_typeString

**[Required]** The type of backup.

Returns:

  • (String)


77
78
79
# File 'lib/oci/mysql/models/backup.rb', line 77

def backup_type
  @backup_type
end

#compartment_idString

**[Required]** The OCID of the compartment.

Returns:

  • (String)


57
58
59
# File 'lib/oci/mysql/models/backup.rb', line 57

def compartment_id
  @compartment_id
end

#creation_typeString

**[Required]** Indicates how the backup was created: manually, automatic, or by an Operator.

Returns:

  • (String)


82
83
84
# File 'lib/oci/mysql/models/backup.rb', line 82

def creation_type
  @creation_type
end

#data_storage_size_in_gbsInteger

Initial size of the data volume in GiBs.

Returns:

  • (Integer)


102
103
104
# File 'lib/oci/mysql/models/backup.rb', line 102

def data_storage_size_in_gbs
  @data_storage_size_in_gbs
end

#db_system_idString

**[Required]** The OCID of the DB System the backup is associated with.

Returns:

  • (String)


86
87
88
# File 'lib/oci/mysql/models/backup.rb', line 86

def db_system_id
  @db_system_id
end

#db_system_snapshotOCI::Mysql::Models::DbSystemSnapshot



89
90
91
# File 'lib/oci/mysql/models/backup.rb', line 89

def db_system_snapshot
  @db_system_snapshot
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


122
123
124
# File 'lib/oci/mysql/models/backup.rb', line 122

def defined_tags
  @defined_tags
end

#descriptionString

A user-supplied description for the backup.

Returns:

  • (String)


53
54
55
# File 'lib/oci/mysql/models/backup.rb', line 53

def description
  @description
end

#display_nameString

A user-supplied display name for the backup.

Returns:

  • (String)


49
50
51
# File 'lib/oci/mysql/models/backup.rb', line 49

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`

Returns:

  • (Hash<String, String>)


116
117
118
# File 'lib/oci/mysql/models/backup.rb', line 116

def freeform_tags
  @freeform_tags
end

#idString

**[Required]** OCID of the backup itself

Returns:

  • (String)


45
46
47
# File 'lib/oci/mysql/models/backup.rb', line 45

def id
  @id
end

#lifecycle_detailsString

**[Required]** Additional information about the current lifecycleState.

Returns:

  • (String)


73
74
75
# File 'lib/oci/mysql/models/backup.rb', line 73

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

**[Required]** The state of the backup.

Returns:

  • (String)


69
70
71
# File 'lib/oci/mysql/models/backup.rb', line 69

def lifecycle_state
  @lifecycle_state
end

#mysql_versionString

The MySQL server version of the DB System used for backup.

Returns:

  • (String)


106
107
108
# File 'lib/oci/mysql/models/backup.rb', line 106

def mysql_version
  @mysql_version
end

#retention_in_daysInteger

Number of days to retain this backup.

Returns:

  • (Integer)


97
98
99
# File 'lib/oci/mysql/models/backup.rb', line 97

def retention_in_days
  @retention_in_days
end

#shape_nameString

The shape of the DB System used for backup.

Returns:

  • (String)


110
111
112
# File 'lib/oci/mysql/models/backup.rb', line 110

def shape_name
  @shape_name
end

#time_createdDateTime

**[Required]** The time the backup record was created.

Returns:

  • (DateTime)


61
62
63
# File 'lib/oci/mysql/models/backup.rb', line 61

def time_created
  @time_created
end

#time_updatedDateTime

**[Required]** The time at which the backup was updated.

Returns:

  • (DateTime)


65
66
67
# File 'lib/oci/mysql/models/backup.rb', line 65

def time_updated
  @time_updated
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/oci/mysql/models/backup.rb', line 125

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'display_name': :'displayName',
    'description': :'description',
    'compartment_id': :'compartmentId',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'backup_type': :'backupType',
    'creation_type': :'creationType',
    'db_system_id': :'dbSystemId',
    'db_system_snapshot': :'dbSystemSnapshot',
    'backup_size_in_gbs': :'backupSizeInGBs',
    'retention_in_days': :'retentionInDays',
    'data_storage_size_in_gbs': :'dataStorageSizeInGBs',
    'mysql_version': :'mysqlVersion',
    'shape_name': :'shapeName',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
# File 'lib/oci/mysql/models/backup.rb', line 152

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'display_name': :'String',
    'description': :'String',
    'compartment_id': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'backup_type': :'String',
    'creation_type': :'String',
    'db_system_id': :'String',
    'db_system_snapshot': :'OCI::Mysql::Models::DbSystemSnapshot',
    'backup_size_in_gbs': :'Integer',
    'retention_in_days': :'Integer',
    'data_storage_size_in_gbs': :'Integer',
    'mysql_version': :'String',
    'shape_name': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
# File 'lib/oci/mysql/models/backup.rb', line 362

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    display_name == other.display_name &&
    description == other.description &&
    compartment_id == other.compartment_id &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    backup_type == other.backup_type &&
    creation_type == other.creation_type &&
    db_system_id == other.db_system_id &&
    db_system_snapshot == other.db_system_snapshot &&
    backup_size_in_gbs == other.backup_size_in_gbs &&
    retention_in_days == other.retention_in_days &&
    data_storage_size_in_gbs == other.data_storage_size_in_gbs &&
    mysql_version == other.mysql_version &&
    shape_name == other.shape_name &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
# File 'lib/oci/mysql/models/backup.rb', line 410

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


390
391
392
# File 'lib/oci/mysql/models/backup.rb', line 390

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



399
400
401
# File 'lib/oci/mysql/models/backup.rb', line 399

def hash
  [id, display_name, description, compartment_id, time_created, time_updated, lifecycle_state, lifecycle_details, backup_type, creation_type, db_system_id, db_system_snapshot, backup_size_in_gbs, retention_in_days, data_storage_size_in_gbs, mysql_version, shape_name, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



443
444
445
446
447
448
449
450
451
452
# File 'lib/oci/mysql/models/backup.rb', line 443

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



437
438
439
# File 'lib/oci/mysql/models/backup.rb', line 437

def to_s
  to_hash.to_s
end