Class: OCI::Mysql::Models::ChannelSummary
- Inherits:
-
Object
- Object
- OCI::Mysql::Models::ChannelSummary
- Defined in:
- lib/oci/mysql/models/channel_summary.rb
Overview
Summary of a Channel.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The OCID of the compartment.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Usage of predefined tag keys.
-
#display_name ⇒ String
**[Required]** The user-friendly name for the Channel.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair applied without any predefined name, type or scope.
-
#id ⇒ String
**[Required]** The OCID of the Channel.
-
#is_enabled ⇒ BOOLEAN
**[Required]** Whether the Channel has been enabled by the user.
-
#lifecycle_details ⇒ String
A message describing the state of the Channel.
-
#lifecycle_state ⇒ String
**[Required]** The state of the Channel.
-
#source ⇒ OCI::Mysql::Models::ChannelSource
This attribute is required.
-
#target ⇒ OCI::Mysql::Models::ChannelTarget
This attribute is required.
-
#time_created ⇒ DateTime
**[Required]** The date and time the Channel was created, as described by [RFC 3339](tools.ietf.org/rfc/rfc3339).
-
#time_updated ⇒ DateTime
**[Required]** The time the Channel was last updated, as described by [RFC 3339](tools.ietf.org/rfc/rfc3339).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ChannelSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ChannelSummary
Initializes the object
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/oci/mysql/models/channel_summary.rb', line 123 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.is_enabled = attributes[:'isEnabled'] unless attributes[:'isEnabled'].nil? self.is_enabled = true if is_enabled.nil? && !attributes.key?(:'isEnabled') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isEnabled and :is_enabled' if attributes.key?(:'isEnabled') && attributes.key?(:'is_enabled') self.is_enabled = attributes[:'is_enabled'] unless attributes[:'is_enabled'].nil? self.is_enabled = true if is_enabled.nil? && !attributes.key?(:'isEnabled') && !attributes.key?(:'is_enabled') # rubocop:disable Style/StringLiterals self.source = attributes[:'source'] if attributes[:'source'] self.target = attributes[:'target'] if attributes[:'target'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The OCID of the compartment.
17 18 19 |
# File 'lib/oci/mysql/models/channel_summary.rb', line 17 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Usage of predefined tag keys. These predefined keys are scoped to namespaces. Example: `{"bar-key": "value"}`
63 64 65 |
# File 'lib/oci/mysql/models/channel_summary.rb', line 63 def @defined_tags end |
#display_name ⇒ String
**[Required]** The user-friendly name for the Channel. It does not have to be unique.
41 42 43 |
# File 'lib/oci/mysql/models/channel_summary.rb', line 41 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
57 58 59 |
# File 'lib/oci/mysql/models/channel_summary.rb', line 57 def @freeform_tags end |
#id ⇒ String
**[Required]** The OCID of the Channel.
13 14 15 |
# File 'lib/oci/mysql/models/channel_summary.rb', line 13 def id @id end |
#is_enabled ⇒ BOOLEAN
**[Required]** Whether the Channel has been enabled by the user.
21 22 23 |
# File 'lib/oci/mysql/models/channel_summary.rb', line 21 def is_enabled @is_enabled end |
#lifecycle_details ⇒ String
A message describing the state of the Channel.
37 38 39 |
# File 'lib/oci/mysql/models/channel_summary.rb', line 37 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
**[Required]** The state of the Channel.
33 34 35 |
# File 'lib/oci/mysql/models/channel_summary.rb', line 33 def lifecycle_state @lifecycle_state end |
#source ⇒ OCI::Mysql::Models::ChannelSource
This attribute is required.
25 26 27 |
# File 'lib/oci/mysql/models/channel_summary.rb', line 25 def source @source end |
#target ⇒ OCI::Mysql::Models::ChannelTarget
This attribute is required.
29 30 31 |
# File 'lib/oci/mysql/models/channel_summary.rb', line 29 def target @target end |
#time_created ⇒ DateTime
**[Required]** The date and time the Channel was created, as described by [RFC 3339](tools.ietf.org/rfc/rfc3339).
46 47 48 |
# File 'lib/oci/mysql/models/channel_summary.rb', line 46 def time_created @time_created end |
#time_updated ⇒ DateTime
**[Required]** The time the Channel was last updated, as described by [RFC 3339](tools.ietf.org/rfc/rfc3339).
51 52 53 |
# File 'lib/oci/mysql/models/channel_summary.rb', line 51 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/oci/mysql/models/channel_summary.rb', line 66 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'is_enabled': :'isEnabled', 'source': :'source', 'target': :'target', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'display_name': :'displayName', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/oci/mysql/models/channel_summary.rb', line 86 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'is_enabled': :'BOOLEAN', 'source': :'OCI::Mysql::Models::ChannelSource', 'target': :'OCI::Mysql::Models::ChannelTarget', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'display_name': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/oci/mysql/models/channel_summary.rb', line 199 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && is_enabled == other.is_enabled && source == other.source && target == other.target && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && display_name == other.display_name && time_created == other.time_created && time_updated == other.time_updated && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 |
# File 'lib/oci/mysql/models/channel_summary.rb', line 240 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
220 221 222 |
# File 'lib/oci/mysql/models/channel_summary.rb', line 220 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
229 230 231 |
# File 'lib/oci/mysql/models/channel_summary.rb', line 229 def hash [id, compartment_id, is_enabled, source, target, lifecycle_state, lifecycle_details, display_name, time_created, time_updated, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
273 274 275 276 277 278 279 280 281 282 |
# File 'lib/oci/mysql/models/channel_summary.rb', line 273 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
267 268 269 |
# File 'lib/oci/mysql/models/channel_summary.rb', line 267 def to_s to_hash.to_s end |