Class: OCI::Mysql::Models::ChannelTargetDbSystem
- Inherits:
-
ChannelTarget
- Object
- ChannelTarget
- OCI::Mysql::Models::ChannelTargetDbSystem
- Defined in:
- lib/oci/mysql/models/channel_target_db_system.rb
Overview
Core properties of a DB System Channel target.
Constant Summary
Constants inherited from ChannelTarget
OCI::Mysql::Models::ChannelTarget::TARGET_TYPE_ENUM
Instance Attribute Summary collapse
-
#applier_username ⇒ String
[Required] The username for the replication applier of the target MySQL DB System.
-
#channel_name ⇒ String
[Required] The case-insensitive name that identifies the replication channel.
-
#db_system_id ⇒ String
[Required] The OCID of the source DB System.
Attributes inherited from ChannelTarget
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ChannelTargetDbSystem
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from ChannelTarget
Constructor Details
#initialize(attributes = {}) ⇒ ChannelTargetDbSystem
Initializes the object
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/oci/mysql/models/channel_target_db_system.rb', line 59 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['targetType'] = 'DBSYSTEM' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.db_system_id = attributes[:'dbSystemId'] if attributes[:'dbSystemId'] raise 'You cannot provide both :dbSystemId and :db_system_id' if attributes.key?(:'dbSystemId') && attributes.key?(:'db_system_id') self.db_system_id = attributes[:'db_system_id'] if attributes[:'db_system_id'] self.channel_name = attributes[:'channelName'] if attributes[:'channelName'] raise 'You cannot provide both :channelName and :channel_name' if attributes.key?(:'channelName') && attributes.key?(:'channel_name') self.channel_name = attributes[:'channel_name'] if attributes[:'channel_name'] self.applier_username = attributes[:'applierUsername'] if attributes[:'applierUsername'] raise 'You cannot provide both :applierUsername and :applier_username' if attributes.key?(:'applierUsername') && attributes.key?(:'applier_username') self.applier_username = attributes[:'applier_username'] if attributes[:'applier_username'] end |
Instance Attribute Details
#applier_username ⇒ String
[Required] The username for the replication applier of the target MySQL DB System.
24 25 26 |
# File 'lib/oci/mysql/models/channel_target_db_system.rb', line 24 def applier_username @applier_username end |
#channel_name ⇒ String
[Required] The case-insensitive name that identifies the replication channel. Channel names must follow the rules defined for [MySQL identifiers](dev.mysql.com/doc/refman/8.0/en/identifiers.html). The names of non-Deleted Channels must be unique for each DB System.
20 21 22 |
# File 'lib/oci/mysql/models/channel_target_db_system.rb', line 20 def channel_name @channel_name end |
#db_system_id ⇒ String
[Required] The OCID of the source DB System.
13 14 15 |
# File 'lib/oci/mysql/models/channel_target_db_system.rb', line 13 def db_system_id @db_system_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
27 28 29 30 31 32 33 34 35 36 |
# File 'lib/oci/mysql/models/channel_target_db_system.rb', line 27 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'target_type': :'targetType', 'db_system_id': :'dbSystemId', 'channel_name': :'channelName', 'applier_username': :'applierUsername' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
39 40 41 42 43 44 45 46 47 48 |
# File 'lib/oci/mysql/models/channel_target_db_system.rb', line 39 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'target_type': :'String', 'db_system_id': :'String', 'channel_name': :'String', 'applier_username': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
95 96 97 98 99 100 101 102 103 |
# File 'lib/oci/mysql/models/channel_target_db_system.rb', line 95 def ==(other) return true if equal?(other) self.class == other.class && target_type == other.target_type && db_system_id == other.db_system_id && channel_name == other.channel_name && applier_username == other.applier_username end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/oci/mysql/models/channel_target_db_system.rb', line 128 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
108 109 110 |
# File 'lib/oci/mysql/models/channel_target_db_system.rb', line 108 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
117 118 119 |
# File 'lib/oci/mysql/models/channel_target_db_system.rb', line 117 def hash [target_type, db_system_id, channel_name, applier_username].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
161 162 163 164 165 166 167 168 169 170 |
# File 'lib/oci/mysql/models/channel_target_db_system.rb', line 161 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
155 156 157 |
# File 'lib/oci/mysql/models/channel_target_db_system.rb', line 155 def to_s to_hash.to_s end |