Class: OCI::Mysql::Models::CreateConfigurationDetails
- Inherits:
-
Object
- Object
- OCI::Mysql::Models::CreateConfigurationDetails
- Defined in:
- lib/oci/mysql/models/create_configuration_details.rb
Overview
The details required to create a new Configuration.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The OCID of the compartment.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
User-provided data about the Configuration.
-
#display_name ⇒ String
The display name of the Configuration.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#parent_configuration_id ⇒ String
The OCID of the Configuration from which the new Configuration is derived.
-
#shape_name ⇒ String
[Required] The name of the associated Shape.
- #variables ⇒ OCI::Mysql::Models::ConfigurationVariables
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateConfigurationDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateConfigurationDetails
Initializes the object
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/oci/mysql/models/create_configuration_details.rb', line 93 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.description = attributes[:'description'] if attributes[:'description'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.shape_name = attributes[:'shapeName'] if attributes[:'shapeName'] raise 'You cannot provide both :shapeName and :shape_name' if attributes.key?(:'shapeName') && attributes.key?(:'shape_name') self.shape_name = attributes[:'shape_name'] if attributes[:'shape_name'] self.variables = attributes[:'variables'] if attributes[:'variables'] self.parent_configuration_id = attributes[:'parentConfigurationId'] if attributes[:'parentConfigurationId'] raise 'You cannot provide both :parentConfigurationId and :parent_configuration_id' if attributes.key?(:'parentConfigurationId') && attributes.key?(:'parent_configuration_id') self.parent_configuration_id = attributes[:'parent_configuration_id'] if attributes[:'parent_configuration_id'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The OCID of the compartment.
13 14 15 |
# File 'lib/oci/mysql/models/create_configuration_details.rb', line 13 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
45 46 47 |
# File 'lib/oci/mysql/models/create_configuration_details.rb', line 45 def end |
#description ⇒ String
User-provided data about the Configuration.
17 18 19 |
# File 'lib/oci/mysql/models/create_configuration_details.rb', line 17 def description @description end |
#display_name ⇒ String
The display name of the Configuration.
21 22 23 |
# File 'lib/oci/mysql/models/create_configuration_details.rb', line 21 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`
39 40 41 |
# File 'lib/oci/mysql/models/create_configuration_details.rb', line 39 def end |
#parent_configuration_id ⇒ String
The OCID of the Configuration from which the new Configuration is derived. The values in CreateConfigurationDetails.variables supersede the variables of the parent Configuration.
33 34 35 |
# File 'lib/oci/mysql/models/create_configuration_details.rb', line 33 def parent_configuration_id @parent_configuration_id end |
#shape_name ⇒ String
[Required] The name of the associated Shape.
25 26 27 |
# File 'lib/oci/mysql/models/create_configuration_details.rb', line 25 def shape_name @shape_name end |
#variables ⇒ OCI::Mysql::Models::ConfigurationVariables
28 29 30 |
# File 'lib/oci/mysql/models/create_configuration_details.rb', line 28 def variables @variables end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/oci/mysql/models/create_configuration_details.rb', line 48 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'description': :'description', 'display_name': :'displayName', 'shape_name': :'shapeName', 'variables': :'variables', 'parent_configuration_id': :'parentConfigurationId', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/oci/mysql/models/create_configuration_details.rb', line 64 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'description': :'String', 'display_name': :'String', 'shape_name': :'String', 'variables': :'OCI::Mysql::Models::ConfigurationVariables', 'parent_configuration_id': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/oci/mysql/models/create_configuration_details.rb', line 147 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && description == other.description && display_name == other.display_name && shape_name == other.shape_name && variables == other.variables && parent_configuration_id == other.parent_configuration_id && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/oci/mysql/models/create_configuration_details.rb', line 184 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
164 165 166 |
# File 'lib/oci/mysql/models/create_configuration_details.rb', line 164 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
173 174 175 |
# File 'lib/oci/mysql/models/create_configuration_details.rb', line 173 def hash [compartment_id, description, display_name, shape_name, variables, parent_configuration_id, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
217 218 219 220 221 222 223 224 225 226 |
# File 'lib/oci/mysql/models/create_configuration_details.rb', line 217 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
211 212 213 |
# File 'lib/oci/mysql/models/create_configuration_details.rb', line 211 def to_s to_hash.to_s end |