Class: OCI::Mysql::Models::CreateDeletionPolicyDetails
- Inherits:
-
Object
- Object
- OCI::Mysql::Models::CreateDeletionPolicyDetails
- Defined in:
- lib/oci/mysql/models/create_deletion_policy_details.rb
Overview
Policy for how the DB System and related resources should be handled at the time of its deletion.
Constant Summary collapse
- AUTOMATIC_BACKUP_RETENTION_ENUM =
[ AUTOMATIC_BACKUP_RETENTION_DELETE = 'DELETE'.freeze, AUTOMATIC_BACKUP_RETENTION_RETAIN = 'RETAIN'.freeze ].freeze
- FINAL_BACKUP_ENUM =
[ FINAL_BACKUP_SKIP_FINAL_BACKUP = 'SKIP_FINAL_BACKUP'.freeze, FINAL_BACKUP_REQUIRE_FINAL_BACKUP = 'REQUIRE_FINAL_BACKUP'.freeze ].freeze
Instance Attribute Summary collapse
-
#automatic_backup_retention ⇒ String
Specifies if any automatic backups created for a DB System should be retained or deleted when the DB System is deleted.
-
#final_backup ⇒ String
Specifies whether or not a backup is taken when the DB System is deleted.
-
#is_delete_protected ⇒ BOOLEAN
Specifies whether the DB System can be deleted.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateDeletionPolicyDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateDeletionPolicyDetails
Initializes the object
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/oci/mysql/models/create_deletion_policy_details.rb', line 69 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.automatic_backup_retention = attributes[:'automaticBackupRetention'] if attributes[:'automaticBackupRetention'] self.automatic_backup_retention = "DELETE" if automatic_backup_retention.nil? && !attributes.key?(:'automaticBackupRetention') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :automaticBackupRetention and :automatic_backup_retention' if attributes.key?(:'automaticBackupRetention') && attributes.key?(:'automatic_backup_retention') self.automatic_backup_retention = attributes[:'automatic_backup_retention'] if attributes[:'automatic_backup_retention'] self.automatic_backup_retention = "DELETE" if automatic_backup_retention.nil? && !attributes.key?(:'automaticBackupRetention') && !attributes.key?(:'automatic_backup_retention') # rubocop:disable Style/StringLiterals self.final_backup = attributes[:'finalBackup'] if attributes[:'finalBackup'] self.final_backup = "SKIP_FINAL_BACKUP" if final_backup.nil? && !attributes.key?(:'finalBackup') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :finalBackup and :final_backup' if attributes.key?(:'finalBackup') && attributes.key?(:'final_backup') self.final_backup = attributes[:'final_backup'] if attributes[:'final_backup'] self.final_backup = "SKIP_FINAL_BACKUP" if final_backup.nil? && !attributes.key?(:'finalBackup') && !attributes.key?(:'final_backup') # rubocop:disable Style/StringLiterals self.is_delete_protected = attributes[:'isDeleteProtected'] unless attributes[:'isDeleteProtected'].nil? self.is_delete_protected = false if is_delete_protected.nil? && !attributes.key?(:'isDeleteProtected') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isDeleteProtected and :is_delete_protected' if attributes.key?(:'isDeleteProtected') && attributes.key?(:'is_delete_protected') self.is_delete_protected = attributes[:'is_delete_protected'] unless attributes[:'is_delete_protected'].nil? self.is_delete_protected = false if is_delete_protected.nil? && !attributes.key?(:'isDeleteProtected') && !attributes.key?(:'is_delete_protected') # rubocop:disable Style/StringLiterals end |
Instance Attribute Details
#automatic_backup_retention ⇒ String
Specifies if any automatic backups created for a DB System should be retained or deleted when the DB System is deleted.
24 25 26 |
# File 'lib/oci/mysql/models/create_deletion_policy_details.rb', line 24 def automatic_backup_retention @automatic_backup_retention end |
#final_backup ⇒ String
Specifies whether or not a backup is taken when the DB System is deleted.
REQUIRE_FINAL_BACKUP: a backup is taken if the DB System is deleted.
SKIP_FINAL_BACKUP: a backup is not taken if the DB System is deleted.
31 32 33 |
# File 'lib/oci/mysql/models/create_deletion_policy_details.rb', line 31 def final_backup @final_backup end |
#is_delete_protected ⇒ BOOLEAN
Specifies whether the DB System can be deleted. Set to true to prevent deletion, false (default) to allow.
36 37 38 |
# File 'lib/oci/mysql/models/create_deletion_policy_details.rb', line 36 def is_delete_protected @is_delete_protected end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 |
# File 'lib/oci/mysql/models/create_deletion_policy_details.rb', line 39 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'automatic_backup_retention': :'automaticBackupRetention', 'final_backup': :'finalBackup', 'is_delete_protected': :'isDeleteProtected' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
50 51 52 53 54 55 56 57 58 |
# File 'lib/oci/mysql/models/create_deletion_policy_details.rb', line 50 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'automatic_backup_retention': :'String', 'final_backup': :'String', 'is_delete_protected': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
123 124 125 126 127 128 129 130 |
# File 'lib/oci/mysql/models/create_deletion_policy_details.rb', line 123 def ==(other) return true if equal?(other) self.class == other.class && automatic_backup_retention == other.automatic_backup_retention && final_backup == other.final_backup && is_delete_protected == other.is_delete_protected end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/oci/mysql/models/create_deletion_policy_details.rb', line 155 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
135 136 137 |
# File 'lib/oci/mysql/models/create_deletion_policy_details.rb', line 135 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
144 145 146 |
# File 'lib/oci/mysql/models/create_deletion_policy_details.rb', line 144 def hash [automatic_backup_retention, final_backup, is_delete_protected].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
188 189 190 191 192 193 194 195 196 197 |
# File 'lib/oci/mysql/models/create_deletion_policy_details.rb', line 188 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
182 183 184 |
# File 'lib/oci/mysql/models/create_deletion_policy_details.rb', line 182 def to_s to_hash.to_s end |