Class: OCI::Mysql::Models::DbSystem
- Inherits:
-
Object
- Object
- OCI::Mysql::Models::DbSystem
- Defined in:
- lib/oci/mysql/models/db_system.rb
Overview
A DB System is the core logical unit of MySQL Database Service.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- CRASH_RECOVERY_ENUM =
[ CRASH_RECOVERY_ENABLED = 'ENABLED'.freeze, CRASH_RECOVERY_DISABLED = 'DISABLED'.freeze, CRASH_RECOVERY_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
- #analytics_cluster ⇒ OCI::Mysql::Models::AnalyticsClusterSummary
-
#availability_domain ⇒ String
The availability domain on which to deploy the Read/Write endpoint.
- #backup_policy ⇒ OCI::Mysql::Models::BackupPolicy
-
#channels ⇒ Array<OCI::Mysql::Models::ChannelSummary>
A list with a summary of all the Channels attached to the DB System.
-
#compartment_id ⇒ String
**[Required]** The OCID of the compartment the DB System belongs in.
-
#configuration_id ⇒ String
The OCID of the Configuration to be used for Instances in this DB System.
-
#crash_recovery ⇒ String
Whether to run the DB System with InnoDB Redo Logs and the Double Write Buffer enabled or disabled, and whether to enable or disable syncing of the Binary Logs.
- #current_placement ⇒ OCI::Mysql::Models::DbSystemPlacement
-
#data_storage_size_in_gbs ⇒ Integer
**[Required]** Initial size of the data volume in GiBs that will be created and attached.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#deletion_policy ⇒ OCI::Mysql::Models::DeletionPolicyDetails
This attribute is required.
-
#description ⇒ String
User-provided data about the DB System.
-
#display_name ⇒ String
**[Required]** The user-friendly name for the DB System.
-
#endpoints ⇒ Array<OCI::Mysql::Models::DbSystemEndpoint>
The network endpoints available for this DB System.
-
#fault_domain ⇒ String
The fault domain on which to deploy the Read/Write endpoint.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
- #heat_wave_cluster ⇒ OCI::Mysql::Models::HeatWaveClusterSummary
-
#hostname_label ⇒ String
The hostname for the primary endpoint of the DB System.
-
#id ⇒ String
**[Required]** The OCID of the DB System.
-
#ip_address ⇒ String
The IP address the DB System is configured to listen on.
-
#is_analytics_cluster_attached ⇒ BOOLEAN
DEPRECATED – please use `isHeatWaveClusterAttached` instead.
-
#is_heat_wave_cluster_attached ⇒ BOOLEAN
If the DB System has a HeatWave Cluster attached.
-
#is_highly_available ⇒ BOOLEAN
Specifies if the DB System is highly available.
-
#lifecycle_details ⇒ String
Additional information about the current lifecycleState.
-
#lifecycle_state ⇒ String
**[Required]** The current state of the DB System.
-
#maintenance ⇒ OCI::Mysql::Models::MaintenanceDetails
This attribute is required.
-
#mysql_version ⇒ String
**[Required]** Name of the MySQL Version in use for the DB System.
- #point_in_time_recovery_details ⇒ OCI::Mysql::Models::PointInTimeRecoveryDetails
-
#port ⇒ Integer
The port for primary endpoint of the DB System to listen on.
-
#port_x ⇒ Integer
The network port on which X Plugin listens for TCP/IP connections.
-
#shape_name ⇒ String
The shape of the primary instances of the DB System.
- #source ⇒ OCI::Mysql::Models::DbSystemSource
-
#subnet_id ⇒ String
**[Required]** The OCID of the subnet the DB System is associated with.
-
#time_created ⇒ DateTime
**[Required]** The date and time the DB System was created.
-
#time_updated ⇒ DateTime
**[Required]** The time the DB System was last updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DbSystem
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DbSystem
Initializes the object
331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 |
# File 'lib/oci/mysql/models/db_system.rb', line 331 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId'] raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id') self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id'] self.is_highly_available = attributes[:'isHighlyAvailable'] unless attributes[:'isHighlyAvailable'].nil? self.is_highly_available = true if is_highly_available.nil? && !attributes.key?(:'isHighlyAvailable') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isHighlyAvailable and :is_highly_available' if attributes.key?(:'isHighlyAvailable') && attributes.key?(:'is_highly_available') self.is_highly_available = attributes[:'is_highly_available'] unless attributes[:'is_highly_available'].nil? self.is_highly_available = true if is_highly_available.nil? && !attributes.key?(:'isHighlyAvailable') && !attributes.key?(:'is_highly_available') # rubocop:disable Style/StringLiterals self.current_placement = attributes[:'currentPlacement'] if attributes[:'currentPlacement'] raise 'You cannot provide both :currentPlacement and :current_placement' if attributes.key?(:'currentPlacement') && attributes.key?(:'current_placement') self.current_placement = attributes[:'current_placement'] if attributes[:'current_placement'] self.is_analytics_cluster_attached = attributes[:'isAnalyticsClusterAttached'] unless attributes[:'isAnalyticsClusterAttached'].nil? self.is_analytics_cluster_attached = false if is_analytics_cluster_attached.nil? && !attributes.key?(:'isAnalyticsClusterAttached') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isAnalyticsClusterAttached and :is_analytics_cluster_attached' if attributes.key?(:'isAnalyticsClusterAttached') && attributes.key?(:'is_analytics_cluster_attached') self.is_analytics_cluster_attached = attributes[:'is_analytics_cluster_attached'] unless attributes[:'is_analytics_cluster_attached'].nil? self.is_analytics_cluster_attached = false if is_analytics_cluster_attached.nil? && !attributes.key?(:'isAnalyticsClusterAttached') && !attributes.key?(:'is_analytics_cluster_attached') # rubocop:disable Style/StringLiterals self.analytics_cluster = attributes[:'analyticsCluster'] if attributes[:'analyticsCluster'] raise 'You cannot provide both :analyticsCluster and :analytics_cluster' if attributes.key?(:'analyticsCluster') && attributes.key?(:'analytics_cluster') self.analytics_cluster = attributes[:'analytics_cluster'] if attributes[:'analytics_cluster'] self.is_heat_wave_cluster_attached = attributes[:'isHeatWaveClusterAttached'] unless attributes[:'isHeatWaveClusterAttached'].nil? self.is_heat_wave_cluster_attached = false if is_heat_wave_cluster_attached.nil? && !attributes.key?(:'isHeatWaveClusterAttached') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isHeatWaveClusterAttached and :is_heat_wave_cluster_attached' if attributes.key?(:'isHeatWaveClusterAttached') && attributes.key?(:'is_heat_wave_cluster_attached') self.is_heat_wave_cluster_attached = attributes[:'is_heat_wave_cluster_attached'] unless attributes[:'is_heat_wave_cluster_attached'].nil? self.is_heat_wave_cluster_attached = false if is_heat_wave_cluster_attached.nil? && !attributes.key?(:'isHeatWaveClusterAttached') && !attributes.key?(:'is_heat_wave_cluster_attached') # rubocop:disable Style/StringLiterals self.heat_wave_cluster = attributes[:'heatWaveCluster'] if attributes[:'heatWaveCluster'] raise 'You cannot provide both :heatWaveCluster and :heat_wave_cluster' if attributes.key?(:'heatWaveCluster') && attributes.key?(:'heat_wave_cluster') self.heat_wave_cluster = attributes[:'heat_wave_cluster'] if attributes[:'heat_wave_cluster'] self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain'] raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain') self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain'] self.fault_domain = attributes[:'faultDomain'] if attributes[:'faultDomain'] raise 'You cannot provide both :faultDomain and :fault_domain' if attributes.key?(:'faultDomain') && attributes.key?(:'fault_domain') self.fault_domain = attributes[:'fault_domain'] if attributes[:'fault_domain'] self.shape_name = attributes[:'shapeName'] if attributes[:'shapeName'] raise 'You cannot provide both :shapeName and :shape_name' if attributes.key?(:'shapeName') && attributes.key?(:'shape_name') self.shape_name = attributes[:'shape_name'] if attributes[:'shape_name'] self.mysql_version = attributes[:'mysqlVersion'] if attributes[:'mysqlVersion'] raise 'You cannot provide both :mysqlVersion and :mysql_version' if attributes.key?(:'mysqlVersion') && attributes.key?(:'mysql_version') self.mysql_version = attributes[:'mysql_version'] if attributes[:'mysql_version'] self.backup_policy = attributes[:'backupPolicy'] if attributes[:'backupPolicy'] raise 'You cannot provide both :backupPolicy and :backup_policy' if attributes.key?(:'backupPolicy') && attributes.key?(:'backup_policy') self.backup_policy = attributes[:'backup_policy'] if attributes[:'backup_policy'] self.source = attributes[:'source'] if attributes[:'source'] self.configuration_id = attributes[:'configurationId'] if attributes[:'configurationId'] raise 'You cannot provide both :configurationId and :configuration_id' if attributes.key?(:'configurationId') && attributes.key?(:'configuration_id') self.configuration_id = attributes[:'configuration_id'] if attributes[:'configuration_id'] self.data_storage_size_in_gbs = attributes[:'dataStorageSizeInGBs'] if attributes[:'dataStorageSizeInGBs'] raise 'You cannot provide both :dataStorageSizeInGBs and :data_storage_size_in_gbs' if attributes.key?(:'dataStorageSizeInGBs') && attributes.key?(:'data_storage_size_in_gbs') self.data_storage_size_in_gbs = attributes[:'data_storage_size_in_gbs'] if attributes[:'data_storage_size_in_gbs'] self.hostname_label = attributes[:'hostnameLabel'] if attributes[:'hostnameLabel'] raise 'You cannot provide both :hostnameLabel and :hostname_label' if attributes.key?(:'hostnameLabel') && attributes.key?(:'hostname_label') self.hostname_label = attributes[:'hostname_label'] if attributes[:'hostname_label'] self.ip_address = attributes[:'ipAddress'] if attributes[:'ipAddress'] raise 'You cannot provide both :ipAddress and :ip_address' if attributes.key?(:'ipAddress') && attributes.key?(:'ip_address') self.ip_address = attributes[:'ip_address'] if attributes[:'ip_address'] self.port = attributes[:'port'] if attributes[:'port'] self.port_x = attributes[:'portX'] if attributes[:'portX'] raise 'You cannot provide both :portX and :port_x' if attributes.key?(:'portX') && attributes.key?(:'port_x') self.port_x = attributes[:'port_x'] if attributes[:'port_x'] self.endpoints = attributes[:'endpoints'] if attributes[:'endpoints'] self.channels = attributes[:'channels'] if attributes[:'channels'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.maintenance = attributes[:'maintenance'] if attributes[:'maintenance'] self.deletion_policy = attributes[:'deletionPolicy'] if attributes[:'deletionPolicy'] raise 'You cannot provide both :deletionPolicy and :deletion_policy' if attributes.key?(:'deletionPolicy') && attributes.key?(:'deletion_policy') self.deletion_policy = attributes[:'deletion_policy'] if attributes[:'deletion_policy'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.crash_recovery = attributes[:'crashRecovery'] if attributes[:'crashRecovery'] self.crash_recovery = "ENABLED" if crash_recovery.nil? && !attributes.key?(:'crashRecovery') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :crashRecovery and :crash_recovery' if attributes.key?(:'crashRecovery') && attributes.key?(:'crash_recovery') self.crash_recovery = attributes[:'crash_recovery'] if attributes[:'crash_recovery'] self.crash_recovery = "ENABLED" if crash_recovery.nil? && !attributes.key?(:'crashRecovery') && !attributes.key?(:'crash_recovery') # rubocop:disable Style/StringLiterals self.point_in_time_recovery_details = attributes[:'pointInTimeRecoveryDetails'] if attributes[:'pointInTimeRecoveryDetails'] raise 'You cannot provide both :pointInTimeRecoveryDetails and :point_in_time_recovery_details' if attributes.key?(:'pointInTimeRecoveryDetails') && attributes.key?(:'point_in_time_recovery_details') self.point_in_time_recovery_details = attributes[:'point_in_time_recovery_details'] if attributes[:'point_in_time_recovery_details'] end |
Instance Attribute Details
#analytics_cluster ⇒ OCI::Mysql::Models::AnalyticsClusterSummary
65 66 67 |
# File 'lib/oci/mysql/models/db_system.rb', line 65 def analytics_cluster @analytics_cluster end |
#availability_domain ⇒ String
The availability domain on which to deploy the Read/Write endpoint. This defines the preferred primary instance.
In a failover scenario, the Read/Write endpoint is redirected to one of the other availability domains and the MySQL instance in that domain is promoted to the primary instance. This redirection does not affect the IP address of the DB System in any way.
For a standalone DB System, this defines the availability domain in which the DB System is placed.
84 85 86 |
# File 'lib/oci/mysql/models/db_system.rb', line 84 def availability_domain @availability_domain end |
#backup_policy ⇒ OCI::Mysql::Models::BackupPolicy
111 112 113 |
# File 'lib/oci/mysql/models/db_system.rb', line 111 def backup_policy @backup_policy end |
#channels ⇒ Array<OCI::Mysql::Models::ChannelSummary>
A list with a summary of all the Channels attached to the DB System.
157 158 159 |
# File 'lib/oci/mysql/models/db_system.rb', line 157 def channels @channels end |
#compartment_id ⇒ String
**[Required]** The OCID of the compartment the DB System belongs in.
43 44 45 |
# File 'lib/oci/mysql/models/db_system.rb', line 43 def compartment_id @compartment_id end |
#configuration_id ⇒ String
The OCID of the Configuration to be used for Instances in this DB System.
118 119 120 |
# File 'lib/oci/mysql/models/db_system.rb', line 118 def configuration_id @configuration_id end |
#crash_recovery ⇒ String
Whether to run the DB System with InnoDB Redo Logs and the Double Write Buffer enabled or disabled, and whether to enable or disable syncing of the Binary Logs.
199 200 201 |
# File 'lib/oci/mysql/models/db_system.rb', line 199 def crash_recovery @crash_recovery end |
#current_placement ⇒ OCI::Mysql::Models::DbSystemPlacement
56 57 58 |
# File 'lib/oci/mysql/models/db_system.rb', line 56 def current_placement @current_placement end |
#data_storage_size_in_gbs ⇒ Integer
**[Required]** Initial size of the data volume in GiBs that will be created and attached.
123 124 125 |
# File 'lib/oci/mysql/models/db_system.rb', line 123 def data_storage_size_in_gbs @data_storage_size_in_gbs end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
193 194 195 |
# File 'lib/oci/mysql/models/db_system.rb', line 193 def @defined_tags end |
#deletion_policy ⇒ OCI::Mysql::Models::DeletionPolicyDetails
This attribute is required.
173 174 175 |
# File 'lib/oci/mysql/models/db_system.rb', line 173 def deletion_policy @deletion_policy end |
#description ⇒ String
User-provided data about the DB System.
39 40 41 |
# File 'lib/oci/mysql/models/db_system.rb', line 39 def description @description end |
#display_name ⇒ String
**[Required]** The user-friendly name for the DB System. It does not have to be unique.
35 36 37 |
# File 'lib/oci/mysql/models/db_system.rb', line 35 def display_name @display_name end |
#endpoints ⇒ Array<OCI::Mysql::Models::DbSystemEndpoint>
The network endpoints available for this DB System.
153 154 155 |
# File 'lib/oci/mysql/models/db_system.rb', line 153 def endpoints @endpoints end |
#fault_domain ⇒ String
The fault domain on which to deploy the Read/Write endpoint. This defines the preferred primary instance.
In a failover scenario, the Read/Write endpoint is redirected to one of the other fault domains and the MySQL instance in that domain is promoted to the primary instance. This redirection does not affect the IP address of the DB System in any way.
For a standalone DB System, this defines the fault domain in which the DB System is placed.
95 96 97 |
# File 'lib/oci/mysql/models/db_system.rb', line 95 def fault_domain @fault_domain end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
187 188 189 |
# File 'lib/oci/mysql/models/db_system.rb', line 187 def @freeform_tags end |
#heat_wave_cluster ⇒ OCI::Mysql::Models::HeatWaveClusterSummary
73 74 75 |
# File 'lib/oci/mysql/models/db_system.rb', line 73 def heat_wave_cluster @heat_wave_cluster end |
#hostname_label ⇒ String
The hostname for the primary endpoint of the DB System. Used for DNS. The value is the hostname portion of the primary private IP's fully qualified domain name (FQDN) (for example, "dbsystem-1" in FQDN "dbsystem-1.subnet123.vcn1.oraclevcn.com"). Must be unique across all VNICs in the subnet and comply with RFC 952 and RFC 1123.
131 132 133 |
# File 'lib/oci/mysql/models/db_system.rb', line 131 def hostname_label @hostname_label end |
#id ⇒ String
**[Required]** The OCID of the DB System.
31 32 33 |
# File 'lib/oci/mysql/models/db_system.rb', line 31 def id @id end |
#ip_address ⇒ String
The IP address the DB System is configured to listen on. A private IP address of the primary endpoint of the DB System. Must be an available IP address within the subnet's CIDR. This will be a "dotted-quad" style IPv4 address.
139 140 141 |
# File 'lib/oci/mysql/models/db_system.rb', line 139 def ip_address @ip_address end |
#is_analytics_cluster_attached ⇒ BOOLEAN
DEPRECATED – please use `isHeatWaveClusterAttached` instead. If the DB System has an Analytics Cluster attached.
62 63 64 |
# File 'lib/oci/mysql/models/db_system.rb', line 62 def is_analytics_cluster_attached @is_analytics_cluster_attached end |
#is_heat_wave_cluster_attached ⇒ BOOLEAN
If the DB System has a HeatWave Cluster attached.
70 71 72 |
# File 'lib/oci/mysql/models/db_system.rb', line 70 def is_heat_wave_cluster_attached @is_heat_wave_cluster_attached end |
#is_highly_available ⇒ BOOLEAN
Specifies if the DB System is highly available.
53 54 55 |
# File 'lib/oci/mysql/models/db_system.rb', line 53 def is_highly_available @is_highly_available end |
#lifecycle_details ⇒ String
Additional information about the current lifecycleState.
165 166 167 |
# File 'lib/oci/mysql/models/db_system.rb', line 165 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
**[Required]** The current state of the DB System.
161 162 163 |
# File 'lib/oci/mysql/models/db_system.rb', line 161 def lifecycle_state @lifecycle_state end |
#maintenance ⇒ OCI::Mysql::Models::MaintenanceDetails
This attribute is required.
169 170 171 |
# File 'lib/oci/mysql/models/db_system.rb', line 169 def maintenance @maintenance end |
#mysql_version ⇒ String
**[Required]** Name of the MySQL Version in use for the DB System.
108 109 110 |
# File 'lib/oci/mysql/models/db_system.rb', line 108 def mysql_version @mysql_version end |
#point_in_time_recovery_details ⇒ OCI::Mysql::Models::PointInTimeRecoveryDetails
202 203 204 |
# File 'lib/oci/mysql/models/db_system.rb', line 202 def point_in_time_recovery_details @point_in_time_recovery_details end |
#port ⇒ Integer
The port for primary endpoint of the DB System to listen on.
143 144 145 |
# File 'lib/oci/mysql/models/db_system.rb', line 143 def port @port end |
#port_x ⇒ Integer
The network port on which X Plugin listens for TCP/IP connections. This is the X Plugin equivalent of port.
148 149 150 |
# File 'lib/oci/mysql/models/db_system.rb', line 148 def port_x @port_x end |
#shape_name ⇒ String
The shape of the primary instances of the DB System. The shape determines resources allocated to a DB System - CPU cores and memory for VM shapes; CPU cores, memory and storage for non-VM (or bare metal) shapes. To get a list of shapes, use (the list_shapes operation.
104 105 106 |
# File 'lib/oci/mysql/models/db_system.rb', line 104 def shape_name @shape_name end |
#source ⇒ OCI::Mysql::Models::DbSystemSource
114 115 116 |
# File 'lib/oci/mysql/models/db_system.rb', line 114 def source @source end |
#subnet_id ⇒ String
**[Required]** The OCID of the subnet the DB System is associated with.
48 49 50 |
# File 'lib/oci/mysql/models/db_system.rb', line 48 def subnet_id @subnet_id end |
#time_created ⇒ DateTime
**[Required]** The date and time the DB System was created.
177 178 179 |
# File 'lib/oci/mysql/models/db_system.rb', line 177 def time_created @time_created end |
#time_updated ⇒ DateTime
**[Required]** The time the DB System was last updated.
181 182 183 |
# File 'lib/oci/mysql/models/db_system.rb', line 181 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/oci/mysql/models/db_system.rb', line 205 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'description': :'description', 'compartment_id': :'compartmentId', 'subnet_id': :'subnetId', 'is_highly_available': :'isHighlyAvailable', 'current_placement': :'currentPlacement', 'is_analytics_cluster_attached': :'isAnalyticsClusterAttached', 'analytics_cluster': :'analyticsCluster', 'is_heat_wave_cluster_attached': :'isHeatWaveClusterAttached', 'heat_wave_cluster': :'heatWaveCluster', 'availability_domain': :'availabilityDomain', 'fault_domain': :'faultDomain', 'shape_name': :'shapeName', 'mysql_version': :'mysqlVersion', 'backup_policy': :'backupPolicy', 'source': :'source', 'configuration_id': :'configurationId', 'data_storage_size_in_gbs': :'dataStorageSizeInGBs', 'hostname_label': :'hostnameLabel', 'ip_address': :'ipAddress', 'port': :'port', 'port_x': :'portX', 'endpoints': :'endpoints', 'channels': :'channels', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'maintenance': :'maintenance', 'deletion_policy': :'deletionPolicy', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'crash_recovery': :'crashRecovery', 'point_in_time_recovery_details': :'pointInTimeRecoveryDetails' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/oci/mysql/models/db_system.rb', line 248 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'description': :'String', 'compartment_id': :'String', 'subnet_id': :'String', 'is_highly_available': :'BOOLEAN', 'current_placement': :'OCI::Mysql::Models::DbSystemPlacement', 'is_analytics_cluster_attached': :'BOOLEAN', 'analytics_cluster': :'OCI::Mysql::Models::AnalyticsClusterSummary', 'is_heat_wave_cluster_attached': :'BOOLEAN', 'heat_wave_cluster': :'OCI::Mysql::Models::HeatWaveClusterSummary', 'availability_domain': :'String', 'fault_domain': :'String', 'shape_name': :'String', 'mysql_version': :'String', 'backup_policy': :'OCI::Mysql::Models::BackupPolicy', 'source': :'OCI::Mysql::Models::DbSystemSource', 'configuration_id': :'String', 'data_storage_size_in_gbs': :'Integer', 'hostname_label': :'String', 'ip_address': :'String', 'port': :'Integer', 'port_x': :'Integer', 'endpoints': :'Array<OCI::Mysql::Models::DbSystemEndpoint>', 'channels': :'Array<OCI::Mysql::Models::ChannelSummary>', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'maintenance': :'OCI::Mysql::Models::MaintenanceDetails', 'deletion_policy': :'OCI::Mysql::Models::DeletionPolicyDetails', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'crash_recovery': :'String', 'point_in_time_recovery_details': :'OCI::Mysql::Models::PointInTimeRecoveryDetails' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 |
# File 'lib/oci/mysql/models/db_system.rb', line 561 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && description == other.description && compartment_id == other.compartment_id && subnet_id == other.subnet_id && is_highly_available == other.is_highly_available && current_placement == other.current_placement && is_analytics_cluster_attached == other.is_analytics_cluster_attached && analytics_cluster == other.analytics_cluster && is_heat_wave_cluster_attached == other.is_heat_wave_cluster_attached && heat_wave_cluster == other.heat_wave_cluster && availability_domain == other.availability_domain && fault_domain == other.fault_domain && shape_name == other.shape_name && mysql_version == other.mysql_version && backup_policy == other.backup_policy && source == other.source && configuration_id == other.configuration_id && data_storage_size_in_gbs == other.data_storage_size_in_gbs && hostname_label == other.hostname_label && ip_address == other.ip_address && port == other.port && port_x == other.port_x && endpoints == other.endpoints && channels == other.channels && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && maintenance == other.maintenance && deletion_policy == other.deletion_policy && time_created == other.time_created && time_updated == other.time_updated && == other. && == other. && crash_recovery == other.crash_recovery && point_in_time_recovery_details == other.point_in_time_recovery_details end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 |
# File 'lib/oci/mysql/models/db_system.rb', line 625 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
605 606 607 |
# File 'lib/oci/mysql/models/db_system.rb', line 605 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
614 615 616 |
# File 'lib/oci/mysql/models/db_system.rb', line 614 def hash [id, display_name, description, compartment_id, subnet_id, is_highly_available, current_placement, is_analytics_cluster_attached, analytics_cluster, is_heat_wave_cluster_attached, heat_wave_cluster, availability_domain, fault_domain, shape_name, mysql_version, backup_policy, source, configuration_id, data_storage_size_in_gbs, hostname_label, ip_address, port, port_x, endpoints, channels, lifecycle_state, lifecycle_details, maintenance, deletion_policy, time_created, time_updated, , , crash_recovery, point_in_time_recovery_details].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
658 659 660 661 662 663 664 665 666 667 |
# File 'lib/oci/mysql/models/db_system.rb', line 658 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
652 653 654 |
# File 'lib/oci/mysql/models/db_system.rb', line 652 def to_s to_hash.to_s end |