Class: OCI::Mysql::Models::DbSystemSnapshot
- Inherits:
-
Object
- Object
- OCI::Mysql::Models::DbSystemSnapshot
- Defined in:
- lib/oci/mysql/models/db_system_snapshot.rb
Overview
Snapshot of the DbSystem details at the time of the backup
Constant Summary collapse
- CRASH_RECOVERY_ENUM =
[ CRASH_RECOVERY_ENABLED = 'ENABLED'.freeze, CRASH_RECOVERY_DISABLED = 'DISABLED'.freeze, CRASH_RECOVERY_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#admin_username ⇒ String
The username for the administrative user.
-
#availability_domain ⇒ String
The Availability Domain where the primary DB System should be located.
- #backup_policy ⇒ OCI::Mysql::Models::BackupPolicy
-
#compartment_id ⇒ String
**[Required]** The OCID of the compartment the DB System belongs in.
-
#configuration_id ⇒ String
The OCID of the Configuration to be used for Instances in this DB System.
-
#crash_recovery ⇒ String
Whether to run the DB System with InnoDB Redo Logs and the Double Write Buffer enabled or disabled, and whether to enable or disable syncing of the Binary Logs.
-
#data_storage_size_in_gbs ⇒ Integer
**[Required]** Initial size of the data volume in GiBs that will be created and attached.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#deletion_policy ⇒ OCI::Mysql::Models::DeletionPolicyDetails
This attribute is required.
-
#description ⇒ String
User-provided data about the DB System.
-
#display_name ⇒ String
**[Required]** The user-friendly name for the DB System.
-
#endpoints ⇒ Array<OCI::Mysql::Models::DbSystemEndpoint>
The network endpoints available for this DB System.
-
#fault_domain ⇒ String
The name of the Fault Domain the DB System is located in.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#hostname_label ⇒ String
The hostname for the primary endpoint of the DB System.
-
#id ⇒ String
**[Required]** The OCID of the DB System.
-
#ip_address ⇒ String
The IP address the DB System is configured to listen on.
-
#is_highly_available ⇒ BOOLEAN
Specifies if the DB System is highly available.
-
#maintenance ⇒ OCI::Mysql::Models::MaintenanceDetails
This attribute is required.
-
#mysql_version ⇒ String
**[Required]** Name of the MySQL Version in use for the DB System.
-
#port ⇒ Integer
The port for primary endpoint of the DB System to listen on.
-
#port_x ⇒ Integer
The network port on which X Plugin listens for TCP/IP connections.
-
#shape_name ⇒ String
The shape of the primary instances of the DB System.
-
#subnet_id ⇒ String
**[Required]** The OCID of the subnet the DB System is associated with.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DbSystemSnapshot
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DbSystemSnapshot
Initializes the object
233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 |
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 233 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId'] raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id') self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id'] self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain'] raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain') self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain'] self.fault_domain = attributes[:'faultDomain'] if attributes[:'faultDomain'] raise 'You cannot provide both :faultDomain and :fault_domain' if attributes.key?(:'faultDomain') && attributes.key?(:'fault_domain') self.fault_domain = attributes[:'fault_domain'] if attributes[:'fault_domain'] self.shape_name = attributes[:'shapeName'] if attributes[:'shapeName'] raise 'You cannot provide both :shapeName and :shape_name' if attributes.key?(:'shapeName') && attributes.key?(:'shape_name') self.shape_name = attributes[:'shape_name'] if attributes[:'shape_name'] self.mysql_version = attributes[:'mysqlVersion'] if attributes[:'mysqlVersion'] raise 'You cannot provide both :mysqlVersion and :mysql_version' if attributes.key?(:'mysqlVersion') && attributes.key?(:'mysql_version') self.mysql_version = attributes[:'mysql_version'] if attributes[:'mysql_version'] self.admin_username = attributes[:'adminUsername'] if attributes[:'adminUsername'] raise 'You cannot provide both :adminUsername and :admin_username' if attributes.key?(:'adminUsername') && attributes.key?(:'admin_username') self.admin_username = attributes[:'admin_username'] if attributes[:'admin_username'] self.backup_policy = attributes[:'backupPolicy'] if attributes[:'backupPolicy'] raise 'You cannot provide both :backupPolicy and :backup_policy' if attributes.key?(:'backupPolicy') && attributes.key?(:'backup_policy') self.backup_policy = attributes[:'backup_policy'] if attributes[:'backup_policy'] self.configuration_id = attributes[:'configurationId'] if attributes[:'configurationId'] raise 'You cannot provide both :configurationId and :configuration_id' if attributes.key?(:'configurationId') && attributes.key?(:'configuration_id') self.configuration_id = attributes[:'configuration_id'] if attributes[:'configuration_id'] self.data_storage_size_in_gbs = attributes[:'dataStorageSizeInGBs'] if attributes[:'dataStorageSizeInGBs'] raise 'You cannot provide both :dataStorageSizeInGBs and :data_storage_size_in_gbs' if attributes.key?(:'dataStorageSizeInGBs') && attributes.key?(:'data_storage_size_in_gbs') self.data_storage_size_in_gbs = attributes[:'data_storage_size_in_gbs'] if attributes[:'data_storage_size_in_gbs'] self.hostname_label = attributes[:'hostnameLabel'] if attributes[:'hostnameLabel'] raise 'You cannot provide both :hostnameLabel and :hostname_label' if attributes.key?(:'hostnameLabel') && attributes.key?(:'hostname_label') self.hostname_label = attributes[:'hostname_label'] if attributes[:'hostname_label'] self.ip_address = attributes[:'ipAddress'] if attributes[:'ipAddress'] raise 'You cannot provide both :ipAddress and :ip_address' if attributes.key?(:'ipAddress') && attributes.key?(:'ip_address') self.ip_address = attributes[:'ip_address'] if attributes[:'ip_address'] self.port = attributes[:'port'] if attributes[:'port'] self.port_x = attributes[:'portX'] if attributes[:'portX'] raise 'You cannot provide both :portX and :port_x' if attributes.key?(:'portX') && attributes.key?(:'port_x') self.port_x = attributes[:'port_x'] if attributes[:'port_x'] self.is_highly_available = attributes[:'isHighlyAvailable'] unless attributes[:'isHighlyAvailable'].nil? self.is_highly_available = true if is_highly_available.nil? && !attributes.key?(:'isHighlyAvailable') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isHighlyAvailable and :is_highly_available' if attributes.key?(:'isHighlyAvailable') && attributes.key?(:'is_highly_available') self.is_highly_available = attributes[:'is_highly_available'] unless attributes[:'is_highly_available'].nil? self.is_highly_available = true if is_highly_available.nil? && !attributes.key?(:'isHighlyAvailable') && !attributes.key?(:'is_highly_available') # rubocop:disable Style/StringLiterals self.endpoints = attributes[:'endpoints'] if attributes[:'endpoints'] self.maintenance = attributes[:'maintenance'] if attributes[:'maintenance'] self.deletion_policy = attributes[:'deletionPolicy'] if attributes[:'deletionPolicy'] raise 'You cannot provide both :deletionPolicy and :deletion_policy' if attributes.key?(:'deletionPolicy') && attributes.key?(:'deletion_policy') self.deletion_policy = attributes[:'deletion_policy'] if attributes[:'deletion_policy'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.crash_recovery = attributes[:'crashRecovery'] if attributes[:'crashRecovery'] self.crash_recovery = "ENABLED" if crash_recovery.nil? && !attributes.key?(:'crashRecovery') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :crashRecovery and :crash_recovery' if attributes.key?(:'crashRecovery') && attributes.key?(:'crash_recovery') self.crash_recovery = attributes[:'crash_recovery'] if attributes[:'crash_recovery'] self.crash_recovery = "ENABLED" if crash_recovery.nil? && !attributes.key?(:'crashRecovery') && !attributes.key?(:'crash_recovery') # rubocop:disable Style/StringLiterals end |
Instance Attribute Details
#admin_username ⇒ String
The username for the administrative user.
64 65 66 |
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 64 def admin_username @admin_username end |
#availability_domain ⇒ String
The Availability Domain where the primary DB System should be located.
42 43 44 |
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 42 def availability_domain @availability_domain end |
#backup_policy ⇒ OCI::Mysql::Models::BackupPolicy
67 68 69 |
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 67 def backup_policy @backup_policy end |
#compartment_id ⇒ String
**[Required]** The OCID of the compartment the DB System belongs in.
32 33 34 |
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 32 def compartment_id @compartment_id end |
#configuration_id ⇒ String
The OCID of the Configuration to be used for Instances in this DB System.
71 72 73 |
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 71 def configuration_id @configuration_id end |
#crash_recovery ⇒ String
Whether to run the DB System with InnoDB Redo Logs and the Double Write Buffer enabled or disabled, and whether to enable or disable syncing of the Binary Logs.
137 138 139 |
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 137 def crash_recovery @crash_recovery end |
#data_storage_size_in_gbs ⇒ Integer
**[Required]** Initial size of the data volume in GiBs that will be created and attached.
76 77 78 |
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 76 def data_storage_size_in_gbs @data_storage_size_in_gbs end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
131 132 133 |
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 131 def @defined_tags end |
#deletion_policy ⇒ OCI::Mysql::Models::DeletionPolicyDetails
This attribute is required.
119 120 121 |
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 119 def deletion_policy @deletion_policy end |
#description ⇒ String
User-provided data about the DB System.
28 29 30 |
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 28 def description @description end |
#display_name ⇒ String
**[Required]** The user-friendly name for the DB System. It does not have to be unique.
24 25 26 |
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 24 def display_name @display_name end |
#endpoints ⇒ Array<OCI::Mysql::Models::DbSystemEndpoint>
The network endpoints available for this DB System.
111 112 113 |
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 111 def endpoints @endpoints end |
#fault_domain ⇒ String
The name of the Fault Domain the DB System is located in.
47 48 49 |
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 47 def fault_domain @fault_domain end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
125 126 127 |
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 125 def @freeform_tags end |
#hostname_label ⇒ String
The hostname for the primary endpoint of the DB System. Used for DNS. The value is the hostname portion of the primary private IP's fully qualified domain name (FQDN) (for example, "dbsystem-1" in FQDN "dbsystem-1.subnet123.vcn1.oraclevcn.com"). Must be unique across all VNICs in the subnet and comply with RFC 952 and RFC 1123.
84 85 86 |
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 84 def hostname_label @hostname_label end |
#id ⇒ String
**[Required]** The OCID of the DB System.
20 21 22 |
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 20 def id @id end |
#ip_address ⇒ String
The IP address the DB System is configured to listen on. A private IP address of the primary endpoint of the DB System. Must be an available IP address within the subnet's CIDR. This will be a "dotted-quad" style IPv4 address.
92 93 94 |
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 92 def ip_address @ip_address end |
#is_highly_available ⇒ BOOLEAN
Specifies if the DB System is highly available.
106 107 108 |
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 106 def is_highly_available @is_highly_available end |
#maintenance ⇒ OCI::Mysql::Models::MaintenanceDetails
This attribute is required.
115 116 117 |
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 115 def maintenance @maintenance end |
#mysql_version ⇒ String
**[Required]** Name of the MySQL Version in use for the DB System.
60 61 62 |
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 60 def mysql_version @mysql_version end |
#port ⇒ Integer
The port for primary endpoint of the DB System to listen on.
96 97 98 |
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 96 def port @port end |
#port_x ⇒ Integer
The network port on which X Plugin listens for TCP/IP connections. This is the X Plugin equivalent of port.
101 102 103 |
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 101 def port_x @port_x end |
#shape_name ⇒ String
The shape of the primary instances of the DB System. The shape determines resources allocated to a DB System - CPU cores and memory for VM shapes; CPU cores, memory and storage for non-VM (or bare metal) shapes. To get a list of shapes, use (the list_shapes operation.
56 57 58 |
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 56 def shape_name @shape_name end |
#subnet_id ⇒ String
**[Required]** The OCID of the subnet the DB System is associated with.
37 38 39 |
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 37 def subnet_id @subnet_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 140 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'description': :'description', 'compartment_id': :'compartmentId', 'subnet_id': :'subnetId', 'availability_domain': :'availabilityDomain', 'fault_domain': :'faultDomain', 'shape_name': :'shapeName', 'mysql_version': :'mysqlVersion', 'admin_username': :'adminUsername', 'backup_policy': :'backupPolicy', 'configuration_id': :'configurationId', 'data_storage_size_in_gbs': :'dataStorageSizeInGBs', 'hostname_label': :'hostnameLabel', 'ip_address': :'ipAddress', 'port': :'port', 'port_x': :'portX', 'is_highly_available': :'isHighlyAvailable', 'endpoints': :'endpoints', 'maintenance': :'maintenance', 'deletion_policy': :'deletionPolicy', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'crash_recovery': :'crashRecovery' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 172 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'description': :'String', 'compartment_id': :'String', 'subnet_id': :'String', 'availability_domain': :'String', 'fault_domain': :'String', 'shape_name': :'String', 'mysql_version': :'String', 'admin_username': :'String', 'backup_policy': :'OCI::Mysql::Models::BackupPolicy', 'configuration_id': :'String', 'data_storage_size_in_gbs': :'Integer', 'hostname_label': :'String', 'ip_address': :'String', 'port': :'Integer', 'port_x': :'Integer', 'is_highly_available': :'BOOLEAN', 'endpoints': :'Array<OCI::Mysql::Models::DbSystemEndpoint>', 'maintenance': :'OCI::Mysql::Models::MaintenanceDetails', 'deletion_policy': :'OCI::Mysql::Models::DeletionPolicyDetails', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'crash_recovery': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 |
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 388 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && description == other.description && compartment_id == other.compartment_id && subnet_id == other.subnet_id && availability_domain == other.availability_domain && fault_domain == other.fault_domain && shape_name == other.shape_name && mysql_version == other.mysql_version && admin_username == other.admin_username && backup_policy == other.backup_policy && configuration_id == other.configuration_id && data_storage_size_in_gbs == other.data_storage_size_in_gbs && hostname_label == other.hostname_label && ip_address == other.ip_address && port == other.port && port_x == other.port_x && is_highly_available == other.is_highly_available && endpoints == other.endpoints && maintenance == other.maintenance && deletion_policy == other.deletion_policy && == other. && == other. && crash_recovery == other.crash_recovery end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 441 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
421 422 423 |
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 421 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
430 431 432 |
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 430 def hash [id, display_name, description, compartment_id, subnet_id, availability_domain, fault_domain, shape_name, mysql_version, admin_username, backup_policy, configuration_id, data_storage_size_in_gbs, hostname_label, ip_address, port, port_x, is_highly_available, endpoints, maintenance, deletion_policy, , , crash_recovery].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
474 475 476 477 478 479 480 481 482 483 |
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 474 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
468 469 470 |
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 468 def to_s to_hash.to_s end |