Class: OCI::Mysql::Models::HeatWaveClusterTableMemoryEstimate
- Inherits:
-
Object
- Object
- OCI::Mysql::Models::HeatWaveClusterTableMemoryEstimate
- Defined in:
- lib/oci/mysql/models/heat_wave_cluster_table_memory_estimate.rb
Overview
Estimated memory footprint for a MySQL user table when loaded to the HeatWave cluster memory.
Instance Attribute Summary collapse
-
#analytical_footprint_in_mbs ⇒ Integer
[Required] The estimated memory footprint of the table in MBs when loaded to HeatWave cluster memory (null if the table cannot be loaded to the HeatWave cluster).
-
#error_comment ⇒ String
[Required] Error comment (empty string if no errors occured).
-
#estimated_row_count ⇒ Integer
[Required] The estimated number of rows in the table.
-
#table_name ⇒ String
[Required] The table name.
-
#to_load_column_count ⇒ Integer
[Required] The number of columns to be loaded to HeatWave cluster memory.
-
#varlen_column_count ⇒ Integer
[Required] The number of variable-length columns to be loaded to HeatWave cluster memory.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ HeatWaveClusterTableMemoryEstimate
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ HeatWaveClusterTableMemoryEstimate
Initializes the object
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/oci/mysql/models/heat_wave_cluster_table_memory_estimate.rb', line 86 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.table_name = attributes[:'tableName'] if attributes[:'tableName'] raise 'You cannot provide both :tableName and :table_name' if attributes.key?(:'tableName') && attributes.key?(:'table_name') self.table_name = attributes[:'table_name'] if attributes[:'table_name'] self.to_load_column_count = attributes[:'toLoadColumnCount'] if attributes[:'toLoadColumnCount'] raise 'You cannot provide both :toLoadColumnCount and :to_load_column_count' if attributes.key?(:'toLoadColumnCount') && attributes.key?(:'to_load_column_count') self.to_load_column_count = attributes[:'to_load_column_count'] if attributes[:'to_load_column_count'] self.varlen_column_count = attributes[:'varlenColumnCount'] if attributes[:'varlenColumnCount'] raise 'You cannot provide both :varlenColumnCount and :varlen_column_count' if attributes.key?(:'varlenColumnCount') && attributes.key?(:'varlen_column_count') self.varlen_column_count = attributes[:'varlen_column_count'] if attributes[:'varlen_column_count'] self.estimated_row_count = attributes[:'estimatedRowCount'] if attributes[:'estimatedRowCount'] raise 'You cannot provide both :estimatedRowCount and :estimated_row_count' if attributes.key?(:'estimatedRowCount') && attributes.key?(:'estimated_row_count') self.estimated_row_count = attributes[:'estimated_row_count'] if attributes[:'estimated_row_count'] self.analytical_footprint_in_mbs = attributes[:'analyticalFootprintInMbs'] if attributes[:'analyticalFootprintInMbs'] raise 'You cannot provide both :analyticalFootprintInMbs and :analytical_footprint_in_mbs' if attributes.key?(:'analyticalFootprintInMbs') && attributes.key?(:'analytical_footprint_in_mbs') self.analytical_footprint_in_mbs = attributes[:'analytical_footprint_in_mbs'] if attributes[:'analytical_footprint_in_mbs'] self.error_comment = attributes[:'errorComment'] if attributes[:'errorComment'] raise 'You cannot provide both :errorComment and :error_comment' if attributes.key?(:'errorComment') && attributes.key?(:'error_comment') self.error_comment = attributes[:'error_comment'] if attributes[:'error_comment'] end |
Instance Attribute Details
#analytical_footprint_in_mbs ⇒ Integer
[Required] The estimated memory footprint of the table in MBs when loaded to HeatWave cluster memory (null if the table cannot be loaded to the HeatWave cluster).
39 40 41 |
# File 'lib/oci/mysql/models/heat_wave_cluster_table_memory_estimate.rb', line 39 def analytical_footprint_in_mbs @analytical_footprint_in_mbs end |
#error_comment ⇒ String
[Required] Error comment (empty string if no errors occured).
44 45 46 |
# File 'lib/oci/mysql/models/heat_wave_cluster_table_memory_estimate.rb', line 44 def error_comment @error_comment end |
#estimated_row_count ⇒ Integer
[Required] The estimated number of rows in the table. This number was used to derive the analytical memory footprint.
32 33 34 |
# File 'lib/oci/mysql/models/heat_wave_cluster_table_memory_estimate.rb', line 32 def estimated_row_count @estimated_row_count end |
#table_name ⇒ String
[Required] The table name.
14 15 16 |
# File 'lib/oci/mysql/models/heat_wave_cluster_table_memory_estimate.rb', line 14 def table_name @table_name end |
#to_load_column_count ⇒ Integer
[Required] The number of columns to be loaded to HeatWave cluster memory. These columns contribute to the analytical memory footprint.
20 21 22 |
# File 'lib/oci/mysql/models/heat_wave_cluster_table_memory_estimate.rb', line 20 def to_load_column_count @to_load_column_count end |
#varlen_column_count ⇒ Integer
[Required] The number of variable-length columns to be loaded to HeatWave cluster memory. These columns contribute to the analytical memory footprint.
26 27 28 |
# File 'lib/oci/mysql/models/heat_wave_cluster_table_memory_estimate.rb', line 26 def varlen_column_count @varlen_column_count end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/oci/mysql/models/heat_wave_cluster_table_memory_estimate.rb', line 47 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'table_name': :'tableName', 'to_load_column_count': :'toLoadColumnCount', 'varlen_column_count': :'varlenColumnCount', 'estimated_row_count': :'estimatedRowCount', 'analytical_footprint_in_mbs': :'analyticalFootprintInMbs', 'error_comment': :'errorComment' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/oci/mysql/models/heat_wave_cluster_table_memory_estimate.rb', line 61 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'table_name': :'String', 'to_load_column_count': :'Integer', 'varlen_column_count': :'Integer', 'estimated_row_count': :'Integer', 'analytical_footprint_in_mbs': :'Integer', 'error_comment': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/oci/mysql/models/heat_wave_cluster_table_memory_estimate.rb', line 136 def ==(other) return true if equal?(other) self.class == other.class && table_name == other.table_name && to_load_column_count == other.to_load_column_count && varlen_column_count == other.varlen_column_count && estimated_row_count == other.estimated_row_count && analytical_footprint_in_mbs == other.analytical_footprint_in_mbs && error_comment == other.error_comment end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/oci/mysql/models/heat_wave_cluster_table_memory_estimate.rb', line 171 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
151 152 153 |
# File 'lib/oci/mysql/models/heat_wave_cluster_table_memory_estimate.rb', line 151 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
160 161 162 |
# File 'lib/oci/mysql/models/heat_wave_cluster_table_memory_estimate.rb', line 160 def hash [table_name, to_load_column_count, varlen_column_count, estimated_row_count, analytical_footprint_in_mbs, error_comment].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
204 205 206 207 208 209 210 211 212 213 |
# File 'lib/oci/mysql/models/heat_wave_cluster_table_memory_estimate.rb', line 204 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
198 199 200 |
# File 'lib/oci/mysql/models/heat_wave_cluster_table_memory_estimate.rb', line 198 def to_s to_hash.to_s end |