Class: OCI::Mysql::Models::PointInTimeRecoveryDetails
- Inherits:
-
Object
- Object
- OCI::Mysql::Models::PointInTimeRecoveryDetails
- Defined in:
- lib/oci/mysql/models/point_in_time_recovery_details.rb
Overview
Point-in-time Recovery details like earliest and latest recovery time point for the DB System.
Instance Attribute Summary collapse
-
#time_earliest_recovery_point ⇒ DateTime
**[Required]** Earliest recovery time point for the DB System, as described by [RFC 3339](tools.ietf.org/rfc/rfc3339).
-
#time_latest_recovery_point ⇒ DateTime
**[Required]** Latest recovery time point for the DB System, as described by [RFC 3339](tools.ietf.org/rfc/rfc3339).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PointInTimeRecoveryDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ PointInTimeRecoveryDetails
Initializes the object
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/oci/mysql/models/point_in_time_recovery_details.rb', line 49 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.time_earliest_recovery_point = attributes[:'timeEarliestRecoveryPoint'] if attributes[:'timeEarliestRecoveryPoint'] raise 'You cannot provide both :timeEarliestRecoveryPoint and :time_earliest_recovery_point' if attributes.key?(:'timeEarliestRecoveryPoint') && attributes.key?(:'time_earliest_recovery_point') self.time_earliest_recovery_point = attributes[:'time_earliest_recovery_point'] if attributes[:'time_earliest_recovery_point'] self.time_latest_recovery_point = attributes[:'timeLatestRecoveryPoint'] if attributes[:'timeLatestRecoveryPoint'] raise 'You cannot provide both :timeLatestRecoveryPoint and :time_latest_recovery_point' if attributes.key?(:'timeLatestRecoveryPoint') && attributes.key?(:'time_latest_recovery_point') self.time_latest_recovery_point = attributes[:'time_latest_recovery_point'] if attributes[:'time_latest_recovery_point'] end |
Instance Attribute Details
#time_earliest_recovery_point ⇒ DateTime
**[Required]** Earliest recovery time point for the DB System, as described by [RFC 3339](tools.ietf.org/rfc/rfc3339).
14 15 16 |
# File 'lib/oci/mysql/models/point_in_time_recovery_details.rb', line 14 def time_earliest_recovery_point @time_earliest_recovery_point end |
#time_latest_recovery_point ⇒ DateTime
**[Required]** Latest recovery time point for the DB System, as described by [RFC 3339](tools.ietf.org/rfc/rfc3339).
19 20 21 |
# File 'lib/oci/mysql/models/point_in_time_recovery_details.rb', line 19 def time_latest_recovery_point @time_latest_recovery_point end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
22 23 24 25 26 27 28 29 |
# File 'lib/oci/mysql/models/point_in_time_recovery_details.rb', line 22 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'time_earliest_recovery_point': :'timeEarliestRecoveryPoint', 'time_latest_recovery_point': :'timeLatestRecoveryPoint' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
32 33 34 35 36 37 38 39 |
# File 'lib/oci/mysql/models/point_in_time_recovery_details.rb', line 32 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'time_earliest_recovery_point': :'DateTime', 'time_latest_recovery_point': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
75 76 77 78 79 80 81 |
# File 'lib/oci/mysql/models/point_in_time_recovery_details.rb', line 75 def ==(other) return true if equal?(other) self.class == other.class && time_earliest_recovery_point == other.time_earliest_recovery_point && time_latest_recovery_point == other.time_latest_recovery_point end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/oci/mysql/models/point_in_time_recovery_details.rb', line 106 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
86 87 88 |
# File 'lib/oci/mysql/models/point_in_time_recovery_details.rb', line 86 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
95 96 97 |
# File 'lib/oci/mysql/models/point_in_time_recovery_details.rb', line 95 def hash [time_earliest_recovery_point, time_latest_recovery_point].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
139 140 141 142 143 144 145 146 147 148 |
# File 'lib/oci/mysql/models/point_in_time_recovery_details.rb', line 139 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
133 134 135 |
# File 'lib/oci/mysql/models/point_in_time_recovery_details.rb', line 133 def to_s to_hash.to_s end |