Class: OCI::Mysql::Models::UpdateBackupPolicyDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/mysql/models/update_backup_policy_details.rb

Overview

Backup Policy as optionally used for DB System update.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateBackupPolicyDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/oci/mysql/models/update_backup_policy_details.rb', line 90

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.is_enabled = attributes[:'isEnabled'] unless attributes[:'isEnabled'].nil?
  self.is_enabled = true if is_enabled.nil? && !attributes.key?(:'isEnabled') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isEnabled and :is_enabled' if attributes.key?(:'isEnabled') && attributes.key?(:'is_enabled')

  self.is_enabled = attributes[:'is_enabled'] unless attributes[:'is_enabled'].nil?
  self.is_enabled = true if is_enabled.nil? && !attributes.key?(:'isEnabled') && !attributes.key?(:'is_enabled') # rubocop:disable Style/StringLiterals

  self.window_start_time = attributes[:'windowStartTime'] if attributes[:'windowStartTime']

  raise 'You cannot provide both :windowStartTime and :window_start_time' if attributes.key?(:'windowStartTime') && attributes.key?(:'window_start_time')

  self.window_start_time = attributes[:'window_start_time'] if attributes[:'window_start_time']

  self.retention_in_days = attributes[:'retentionInDays'] if attributes[:'retentionInDays']

  raise 'You cannot provide both :retentionInDays and :retention_in_days' if attributes.key?(:'retentionInDays') && attributes.key?(:'retention_in_days')

  self.retention_in_days = attributes[:'retention_in_days'] if attributes[:'retention_in_days']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.pitr_policy = attributes[:'pitrPolicy'] if attributes[:'pitrPolicy']

  raise 'You cannot provide both :pitrPolicy and :pitr_policy' if attributes.key?(:'pitrPolicy') && attributes.key?(:'pitr_policy')

  self.pitr_policy = attributes[:'pitr_policy'] if attributes[:'pitr_policy']
end

Instance Attribute Details

#defined_tagsHash<String, Hash<String, Object>>

Usage of predefined tag keys. These predefined keys are scoped to namespaces.

Tags defined here will be copied verbatim as tags on the Backup resource created by this BackupPolicy.

Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


45
46
47
# File 'lib/oci/mysql/models/update_backup_policy_details.rb', line 45

def defined_tags
  @defined_tags
end

#freeform_tagsHash<String, String>

Simple key-value pair applied without any predefined name, type or scope. Exists for cross-compatibility only.

Tags defined here will be copied verbatim as tags on the Backup resource created by this BackupPolicy.

Example: `"value"`

Returns:

  • (Hash<String, String>)


36
37
38
# File 'lib/oci/mysql/models/update_backup_policy_details.rb', line 36

def freeform_tags
  @freeform_tags
end

#is_enabledBOOLEAN

Specifies if automatic backups are enabled.

Returns:

  • (BOOLEAN)


14
15
16
# File 'lib/oci/mysql/models/update_backup_policy_details.rb', line 14

def is_enabled
  @is_enabled
end

#pitr_policyOCI::Mysql::Models::PitrPolicy



48
49
50
# File 'lib/oci/mysql/models/update_backup_policy_details.rb', line 48

def pitr_policy
  @pitr_policy
end

#retention_in_daysInteger

Number of days to retain an automatic backup.

Returns:

  • (Integer)


27
28
29
# File 'lib/oci/mysql/models/update_backup_policy_details.rb', line 27

def retention_in_days
  @retention_in_days
end

#window_start_timeString

The start of a 30-minute window of time in which daily, automated backups occur.

This should be in the format of the "Time" portion of an RFC3339-formatted timestamp. Any second or sub-second time data will be truncated to zero.

At some point in the window, the system may incur a brief service disruption as the backup is performed.

Returns:

  • (String)


23
24
25
# File 'lib/oci/mysql/models/update_backup_policy_details.rb', line 23

def window_start_time
  @window_start_time
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/oci/mysql/models/update_backup_policy_details.rb', line 51

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'is_enabled': :'isEnabled',
    'window_start_time': :'windowStartTime',
    'retention_in_days': :'retentionInDays',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'pitr_policy': :'pitrPolicy'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/oci/mysql/models/update_backup_policy_details.rb', line 65

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'is_enabled': :'BOOLEAN',
    'window_start_time': :'String',
    'retention_in_days': :'Integer',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'pitr_policy': :'OCI::Mysql::Models::PitrPolicy'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



142
143
144
145
146
147
148
149
150
151
152
# File 'lib/oci/mysql/models/update_backup_policy_details.rb', line 142

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    is_enabled == other.is_enabled &&
    window_start_time == other.window_start_time &&
    retention_in_days == other.retention_in_days &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    pitr_policy == other.pitr_policy
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/oci/mysql/models/update_backup_policy_details.rb', line 177

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


157
158
159
# File 'lib/oci/mysql/models/update_backup_policy_details.rb', line 157

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



166
167
168
# File 'lib/oci/mysql/models/update_backup_policy_details.rb', line 166

def hash
  [is_enabled, window_start_time, retention_in_days, freeform_tags, defined_tags, pitr_policy].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



210
211
212
213
214
215
216
217
218
219
# File 'lib/oci/mysql/models/update_backup_policy_details.rb', line 210

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



204
205
206
# File 'lib/oci/mysql/models/update_backup_policy_details.rb', line 204

def to_s
  to_hash.to_s
end