Class: OCI::NetworkFirewall::Models::CreateNetworkFirewallDetails
- Inherits:
-
Object
- Object
- OCI::NetworkFirewall::Models::CreateNetworkFirewallDetails
- Defined in:
- lib/oci/network_firewall/models/create_network_firewall_details.rb
Overview
The information about new Network Firewall.
Instance Attribute Summary collapse
-
#availability_domain ⇒ String
Availability Domain where Network Firewall instance is created.
-
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the Network Firewall.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
A user-friendly name for the Network Firewall.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#ipv4_address ⇒ String
IPv4 address for the Network Firewall.
-
#ipv6_address ⇒ String
IPv6 address for the Network Firewall.
-
#network_firewall_policy_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Network Firewall Policy.
-
#network_security_group_ids ⇒ Array<String>
An array of network security groups [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) associated with the Network Firewall.
-
#subnet_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the subnet associated with the Network Firewall.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateNetworkFirewallDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateNetworkFirewallDetails
Initializes the object
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/oci/network_firewall/models/create_network_firewall_details.rb', line 109 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId'] raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id') self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id'] self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain'] raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain') self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain'] self.network_firewall_policy_id = attributes[:'networkFirewallPolicyId'] if attributes[:'networkFirewallPolicyId'] raise 'You cannot provide both :networkFirewallPolicyId and :network_firewall_policy_id' if attributes.key?(:'networkFirewallPolicyId') && attributes.key?(:'network_firewall_policy_id') self.network_firewall_policy_id = attributes[:'network_firewall_policy_id'] if attributes[:'network_firewall_policy_id'] self.ipv4_address = attributes[:'ipv4Address'] if attributes[:'ipv4Address'] raise 'You cannot provide both :ipv4Address and :ipv4_address' if attributes.key?(:'ipv4Address') && attributes.key?(:'ipv4_address') self.ipv4_address = attributes[:'ipv4_address'] if attributes[:'ipv4_address'] self.ipv6_address = attributes[:'ipv6Address'] if attributes[:'ipv6Address'] raise 'You cannot provide both :ipv6Address and :ipv6_address' if attributes.key?(:'ipv6Address') && attributes.key?(:'ipv6_address') self.ipv6_address = attributes[:'ipv6_address'] if attributes[:'ipv6_address'] self.network_security_group_ids = attributes[:'networkSecurityGroupIds'] if attributes[:'networkSecurityGroupIds'] raise 'You cannot provide both :networkSecurityGroupIds and :network_security_group_ids' if attributes.key?(:'networkSecurityGroupIds') && attributes.key?(:'network_security_group_ids') self.network_security_group_ids = attributes[:'network_security_group_ids'] if attributes[:'network_security_group_ids'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#availability_domain ⇒ String
Availability Domain where Network Firewall instance is created. To get a list of availability domains for a tenancy, use list_availability_domains operation. Example: `kIdk:PHX-AD-1`
27 28 29 |
# File 'lib/oci/network_firewall/models/create_network_firewall_details.rb', line 27 def availability_domain @availability_domain end |
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the Network Firewall.
16 17 18 |
# File 'lib/oci/network_firewall/models/create_network_firewall_details.rb', line 16 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
55 56 57 |
# File 'lib/oci/network_firewall/models/create_network_firewall_details.rb', line 55 def @defined_tags end |
#display_name ⇒ String
A user-friendly name for the Network Firewall. Does not have to be unique, and it's changeable. Avoid entering confidential information.
12 13 14 |
# File 'lib/oci/network_firewall/models/create_network_firewall_details.rb', line 12 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
49 50 51 |
# File 'lib/oci/network_firewall/models/create_network_firewall_details.rb', line 49 def @freeform_tags end |
#ipv4_address ⇒ String
IPv4 address for the Network Firewall.
35 36 37 |
# File 'lib/oci/network_firewall/models/create_network_firewall_details.rb', line 35 def ipv4_address @ipv4_address end |
#ipv6_address ⇒ String
IPv6 address for the Network Firewall.
39 40 41 |
# File 'lib/oci/network_firewall/models/create_network_firewall_details.rb', line 39 def ipv6_address @ipv6_address end |
#network_firewall_policy_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Network Firewall Policy.
31 32 33 |
# File 'lib/oci/network_firewall/models/create_network_firewall_details.rb', line 31 def network_firewall_policy_id @network_firewall_policy_id end |
#network_security_group_ids ⇒ Array<String>
An array of network security groups [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) associated with the Network Firewall.
43 44 45 |
# File 'lib/oci/network_firewall/models/create_network_firewall_details.rb', line 43 def network_security_group_ids @network_security_group_ids end |
#subnet_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the subnet associated with the Network Firewall.
20 21 22 |
# File 'lib/oci/network_firewall/models/create_network_firewall_details.rb', line 20 def subnet_id @subnet_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/oci/network_firewall/models/create_network_firewall_details.rb', line 58 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'subnet_id': :'subnetId', 'availability_domain': :'availabilityDomain', 'network_firewall_policy_id': :'networkFirewallPolicyId', 'ipv4_address': :'ipv4Address', 'ipv6_address': :'ipv6Address', 'network_security_group_ids': :'networkSecurityGroupIds', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/oci/network_firewall/models/create_network_firewall_details.rb', line 76 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'compartment_id': :'String', 'subnet_id': :'String', 'availability_domain': :'String', 'network_firewall_policy_id': :'String', 'ipv4_address': :'String', 'ipv6_address': :'String', 'network_security_group_ids': :'Array<String>', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/oci/network_firewall/models/create_network_firewall_details.rb', line 183 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && compartment_id == other.compartment_id && subnet_id == other.subnet_id && availability_domain == other.availability_domain && network_firewall_policy_id == other.network_firewall_policy_id && ipv4_address == other.ipv4_address && ipv6_address == other.ipv6_address && network_security_group_ids == other.network_security_group_ids && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/oci/network_firewall/models/create_network_firewall_details.rb', line 222 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
202 203 204 |
# File 'lib/oci/network_firewall/models/create_network_firewall_details.rb', line 202 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
211 212 213 |
# File 'lib/oci/network_firewall/models/create_network_firewall_details.rb', line 211 def hash [display_name, compartment_id, subnet_id, availability_domain, network_firewall_policy_id, ipv4_address, ipv6_address, network_security_group_ids, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
255 256 257 258 259 260 261 262 263 264 |
# File 'lib/oci/network_firewall/models/create_network_firewall_details.rb', line 255 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
249 250 251 |
# File 'lib/oci/network_firewall/models/create_network_firewall_details.rb', line 249 def to_s to_hash.to_s end |