Class: OCI::NetworkFirewall::Models::NetworkFirewallSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/network_firewall/models/network_firewall_summary.rb

Overview

Summary of the Network Firewall.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ NetworkFirewallSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :display_name (String)

    The value to assign to the #display_name property

  • :subnet_id (String)

    The value to assign to the #subnet_id property

  • :availability_domain (String)

    The value to assign to the #availability_domain property

  • :ipv4_address (String)

    The value to assign to the #ipv4_address property

  • :ipv6_address (String)

    The value to assign to the #ipv6_address property

  • :network_firewall_policy_id (String)

    The value to assign to the #network_firewall_policy_id property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :time_updated (DateTime)

    The value to assign to the #time_updated property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :lifecycle_details (String)

    The value to assign to the #lifecycle_details property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property

  • :system_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #system_tags property



161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
# File 'lib/oci/network_firewall/models/network_firewall_summary.rb', line 161

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId']

  raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id')

  self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id']

  self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain']

  raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain')

  self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain']

  self.ipv4_address = attributes[:'ipv4Address'] if attributes[:'ipv4Address']

  raise 'You cannot provide both :ipv4Address and :ipv4_address' if attributes.key?(:'ipv4Address') && attributes.key?(:'ipv4_address')

  self.ipv4_address = attributes[:'ipv4_address'] if attributes[:'ipv4_address']

  self.ipv6_address = attributes[:'ipv6Address'] if attributes[:'ipv6Address']

  raise 'You cannot provide both :ipv6Address and :ipv6_address' if attributes.key?(:'ipv6Address') && attributes.key?(:'ipv6_address')

  self.ipv6_address = attributes[:'ipv6_address'] if attributes[:'ipv6_address']

  self.network_firewall_policy_id = attributes[:'networkFirewallPolicyId'] if attributes[:'networkFirewallPolicyId']

  raise 'You cannot provide both :networkFirewallPolicyId and :network_firewall_policy_id' if attributes.key?(:'networkFirewallPolicyId') && attributes.key?(:'network_firewall_policy_id')

  self.network_firewall_policy_id = attributes[:'network_firewall_policy_id'] if attributes[:'network_firewall_policy_id']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

  raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

  self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']
end

Instance Attribute Details

#availability_domainString

Availability Domain where Network Firewall instance is created. To get a list of availability domains for a tenancy, use list_availability_domains operation. Example: `kIdk:PHX-AD-1`

Returns:

  • (String)


42
43
44
# File 'lib/oci/network_firewall/models/network_firewall_summary.rb', line 42

def availability_domain
  @availability_domain
end

#compartment_idString

**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the Network Firewall.

Returns:

  • (String)


27
28
29
# File 'lib/oci/network_firewall/models/network_firewall_summary.rb', line 27

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

**[Required]** Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


86
87
88
# File 'lib/oci/network_firewall/models/network_firewall_summary.rb', line 86

def defined_tags
  @defined_tags
end

#display_nameString

**[Required]** A user-friendly name for the Network Firewall. Does not have to be unique, and it's changeable. Avoid entering confidential information.

Returns:

  • (String)


31
32
33
# File 'lib/oci/network_firewall/models/network_firewall_summary.rb', line 31

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

**[Required]** Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`

Returns:

  • (Hash<String, String>)


80
81
82
# File 'lib/oci/network_firewall/models/network_firewall_summary.rb', line 80

def freeform_tags
  @freeform_tags
end

#idString

**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Network Firewall resource.

Returns:

  • (String)


23
24
25
# File 'lib/oci/network_firewall/models/network_firewall_summary.rb', line 23

def id
  @id
end

#ipv4_addressString

IPv4 address for the Network Firewall.

Returns:

  • (String)


46
47
48
# File 'lib/oci/network_firewall/models/network_firewall_summary.rb', line 46

def ipv4_address
  @ipv4_address
end

#ipv6_addressString

IPv6 address for the Network Firewall.

Returns:

  • (String)


50
51
52
# File 'lib/oci/network_firewall/models/network_firewall_summary.rb', line 50

def ipv6_address
  @ipv6_address
end

#lifecycle_detailsString

A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.

Returns:

  • (String)


74
75
76
# File 'lib/oci/network_firewall/models/network_firewall_summary.rb', line 74

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

**[Required]** The current state of the Network Firewall.

Returns:

  • (String)


70
71
72
# File 'lib/oci/network_firewall/models/network_firewall_summary.rb', line 70

def lifecycle_state
  @lifecycle_state
end

#network_firewall_policy_idString

**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Network Firewall Policy.

Returns:

  • (String)


54
55
56
# File 'lib/oci/network_firewall/models/network_firewall_summary.rb', line 54

def network_firewall_policy_id
  @network_firewall_policy_id
end

#subnet_idString

**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the subnet associated with the Network Firewall.

Returns:

  • (String)


35
36
37
# File 'lib/oci/network_firewall/models/network_firewall_summary.rb', line 35

def subnet_id
  @subnet_id
end

#system_tagsHash<String, Hash<String, Object>>

Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"free-tier-retained": "true"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


92
93
94
# File 'lib/oci/network_firewall/models/network_firewall_summary.rb', line 92

def system_tags
  @system_tags
end

#time_createdDateTime

**[Required]** The time instant at which the Network Firewall was created in the format defined by [RFC3339](tools.ietf.org/html/rfc3339). Example: `2016-08-25T21:10:29.600Z`

Returns:

  • (DateTime)


60
61
62
# File 'lib/oci/network_firewall/models/network_firewall_summary.rb', line 60

def time_created
  @time_created
end

#time_updatedDateTime

The time instant at which the Network Firewall was updated in the format defined by [RFC3339](tools.ietf.org/html/rfc3339). Example: `2016-08-25T21:10:29.600Z`

Returns:

  • (DateTime)


66
67
68
# File 'lib/oci/network_firewall/models/network_firewall_summary.rb', line 66

def time_updated
  @time_updated
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/oci/network_firewall/models/network_firewall_summary.rb', line 95

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'compartment_id': :'compartmentId',
    'display_name': :'displayName',
    'subnet_id': :'subnetId',
    'availability_domain': :'availabilityDomain',
    'ipv4_address': :'ipv4Address',
    'ipv6_address': :'ipv6Address',
    'network_firewall_policy_id': :'networkFirewallPolicyId',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/oci/network_firewall/models/network_firewall_summary.rb', line 118

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'compartment_id': :'String',
    'display_name': :'String',
    'subnet_id': :'String',
    'availability_domain': :'String',
    'ipv4_address': :'String',
    'ipv6_address': :'String',
    'network_firewall_policy_id': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'lib/oci/network_firewall/models/network_firewall_summary.rb', line 274

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    display_name == other.display_name &&
    subnet_id == other.subnet_id &&
    availability_domain == other.availability_domain &&
    ipv4_address == other.ipv4_address &&
    ipv6_address == other.ipv6_address &&
    network_firewall_policy_id == other.network_firewall_policy_id &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
# File 'lib/oci/network_firewall/models/network_firewall_summary.rb', line 318

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


298
299
300
# File 'lib/oci/network_firewall/models/network_firewall_summary.rb', line 298

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



307
308
309
# File 'lib/oci/network_firewall/models/network_firewall_summary.rb', line 307

def hash
  [id, compartment_id, display_name, subnet_id, availability_domain, ipv4_address, ipv6_address, network_firewall_policy_id, time_created, time_updated, lifecycle_state, lifecycle_details, freeform_tags, defined_tags, system_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



351
352
353
354
355
356
357
358
359
360
# File 'lib/oci/network_firewall/models/network_firewall_summary.rb', line 351

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



345
346
347
# File 'lib/oci/network_firewall/models/network_firewall_summary.rb', line 345

def to_s
  to_hash.to_s
end