Class: OCI::NetworkFirewall::Models::SecurityRule
- Inherits:
-
Object
- Object
- OCI::NetworkFirewall::Models::SecurityRule
- Defined in:
- lib/oci/network_firewall/models/security_rule.rb
Overview
Security Rule used in the firewall policy rules. Security Rules determine whether to block or allow a session based on traffic attributes, such as the source and destination IP address, protocol/port, and the HTTP(S) target URL.
Constant Summary collapse
- ACTION_ENUM =
[ ACTION_ALLOW = 'ALLOW'.freeze, ACTION_DROP = 'DROP'.freeze, ACTION_REJECT = 'REJECT'.freeze, ACTION_INSPECT = 'INSPECT'.freeze, ACTION_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- INSPECTION_ENUM =
[ INSPECTION_INTRUSION_DETECTION = 'INTRUSION_DETECTION'.freeze, INSPECTION_INTRUSION_PREVENTION = 'INTRUSION_PREVENTION'.freeze, INSPECTION_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#action ⇒ String
**[Required]** Types of Action on the Traffic flow.
-
#condition ⇒ OCI::NetworkFirewall::Models::SecurityRuleMatchCriteria
This attribute is required.
-
#inspection ⇒ String
Type of inspection to affect the Traffic flow.
-
#name ⇒ String
**[Required]** Name for the Security rule, must be unique within the policy.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SecurityRule
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ SecurityRule
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/oci/network_firewall/models/security_rule.rb', line 88 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.condition = attributes[:'condition'] if attributes[:'condition'] self.action = attributes[:'action'] if attributes[:'action'] self.inspection = attributes[:'inspection'] if attributes[:'inspection'] end |
Instance Attribute Details
#action ⇒ String
**[Required]** Types of Action on the Traffic flow.
* ALLOW - Allows the traffic.
* DROP - Silently drops the traffic, e.g. without sending a TCP reset.
* REJECT - Rejects the traffic, sending a TCP reset to client and/or server as applicable.
* INSPECT - Inspects traffic for vulnerability as specified in `inspection`, which may result in rejection.
44 45 46 |
# File 'lib/oci/network_firewall/models/security_rule.rb', line 44 def action @action end |
#condition ⇒ OCI::NetworkFirewall::Models::SecurityRuleMatchCriteria
This attribute is required.
34 35 36 |
# File 'lib/oci/network_firewall/models/security_rule.rb', line 34 def condition @condition end |
#inspection ⇒ String
Type of inspection to affect the Traffic flow. This is only applicable if action is INSPECT.
* INTRUSION_DETECTION - Intrusion Detection.
* INTRUSION_PREVENTION - Intrusion Detection and Prevention. Traffic classified as potentially malicious will be rejected as described in `type`.
52 53 54 |
# File 'lib/oci/network_firewall/models/security_rule.rb', line 52 def inspection @inspection end |
#name ⇒ String
**[Required]** Name for the Security rule, must be unique within the policy.
30 31 32 |
# File 'lib/oci/network_firewall/models/security_rule.rb', line 30 def name @name end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 64 |
# File 'lib/oci/network_firewall/models/security_rule.rb', line 55 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'condition': :'condition', 'action': :'action', 'inspection': :'inspection' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
67 68 69 70 71 72 73 74 75 76 |
# File 'lib/oci/network_firewall/models/security_rule.rb', line 67 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'condition': :'OCI::NetworkFirewall::Models::SecurityRuleMatchCriteria', 'action': :'String', 'inspection': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
136 137 138 139 140 141 142 143 144 |
# File 'lib/oci/network_firewall/models/security_rule.rb', line 136 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && condition == other.condition && action == other.action && inspection == other.inspection end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/oci/network_firewall/models/security_rule.rb', line 169 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
149 150 151 |
# File 'lib/oci/network_firewall/models/security_rule.rb', line 149 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
158 159 160 |
# File 'lib/oci/network_firewall/models/security_rule.rb', line 158 def hash [name, condition, action, inspection].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
202 203 204 205 206 207 208 209 210 211 |
# File 'lib/oci/network_firewall/models/security_rule.rb', line 202 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
196 197 198 |
# File 'lib/oci/network_firewall/models/security_rule.rb', line 196 def to_s to_hash.to_s end |