Class: OCI::NetworkFirewall::Models::SecurityRuleMatchCriteria

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/network_firewall/models/security_rule_match_criteria.rb

Overview

Criteria to evaluate against network traffic. A match occurs when at least one item in the array associated with each specified property corresponds with the relevant aspect of the traffic.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ SecurityRuleMatchCriteria

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :sources (Array<String>)

    The value to assign to the #sources property

  • :destinations (Array<String>)

    The value to assign to the #destinations property

  • :applications (Array<String>)

    The value to assign to the #applications property

  • :urls (Array<String>)

    The value to assign to the #urls property



62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/oci/network_firewall/models/security_rule_match_criteria.rb', line 62

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.sources = attributes[:'sources'] if attributes[:'sources']

  self.destinations = attributes[:'destinations'] if attributes[:'destinations']

  self.applications = attributes[:'applications'] if attributes[:'applications']

  self.urls = attributes[:'urls'] if attributes[:'urls']
end

Instance Attribute Details

#applicationsArray<String>

An array of application list names to be evaluated against the traffic protocol and protocol-specific parameters.

Returns:

  • (Array<String>)


22
23
24
# File 'lib/oci/network_firewall/models/security_rule_match_criteria.rb', line 22

def applications
  @applications
end

#destinationsArray<String>

An array of IP address list names to be evaluated against the traffic destination address.

Returns:

  • (Array<String>)


18
19
20
# File 'lib/oci/network_firewall/models/security_rule_match_criteria.rb', line 18

def destinations
  @destinations
end

#sourcesArray<String>

An array of IP address list names to be evaluated against the traffic source address.

Returns:

  • (Array<String>)


14
15
16
# File 'lib/oci/network_firewall/models/security_rule_match_criteria.rb', line 14

def sources
  @sources
end

#urlsArray<String>

An array of URL pattern list names to be evaluated against the HTTP(S) request target.

Returns:

  • (Array<String>)


26
27
28
# File 'lib/oci/network_firewall/models/security_rule_match_criteria.rb', line 26

def urls
  @urls
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



29
30
31
32
33
34
35
36
37
38
# File 'lib/oci/network_firewall/models/security_rule_match_criteria.rb', line 29

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'sources': :'sources',
    'destinations': :'destinations',
    'applications': :'applications',
    'urls': :'urls'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



41
42
43
44
45
46
47
48
49
50
# File 'lib/oci/network_firewall/models/security_rule_match_criteria.rb', line 41

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'sources': :'Array<String>',
    'destinations': :'Array<String>',
    'applications': :'Array<String>',
    'urls': :'Array<String>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



84
85
86
87
88
89
90
91
92
# File 'lib/oci/network_firewall/models/security_rule_match_criteria.rb', line 84

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    sources == other.sources &&
    destinations == other.destinations &&
    applications == other.applications &&
    urls == other.urls
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/oci/network_firewall/models/security_rule_match_criteria.rb', line 117

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


97
98
99
# File 'lib/oci/network_firewall/models/security_rule_match_criteria.rb', line 97

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



106
107
108
# File 'lib/oci/network_firewall/models/security_rule_match_criteria.rb', line 106

def hash
  [sources, destinations, applications, urls].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



150
151
152
153
154
155
156
157
158
159
# File 'lib/oci/network_firewall/models/security_rule_match_criteria.rb', line 150

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



144
145
146
# File 'lib/oci/network_firewall/models/security_rule_match_criteria.rb', line 144

def to_s
  to_hash.to_s
end