Class: OCI::NetworkFirewall::Models::SslInboundInspectionProfile
- Inherits:
-
DecryptionProfile
- Object
- DecryptionProfile
- OCI::NetworkFirewall::Models::SslInboundInspectionProfile
- Defined in:
- lib/oci/network_firewall/models/ssl_inbound_inspection_profile.rb
Overview
SSLInboundInspection used on the firewall policy rules.
Constant Summary
Constants inherited from DecryptionProfile
Instance Attribute Summary collapse
-
#is_out_of_capacity_blocked ⇒ BOOLEAN
**[Required]** Whether to block sessions if the firewall is temporarily unable to decrypt their traffic.
-
#is_unsupported_cipher_blocked ⇒ BOOLEAN
**[Required]** Whether to block sessions if SSL cipher suite is not supported.
-
#is_unsupported_version_blocked ⇒ BOOLEAN
**[Required]** Whether to block sessions if SSL version is not supported.
Attributes inherited from DecryptionProfile
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SslInboundInspectionProfile
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from DecryptionProfile
Constructor Details
#initialize(attributes = {}) ⇒ SslInboundInspectionProfile
Initializes the object
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/oci/network_firewall/models/ssl_inbound_inspection_profile.rb', line 56 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['type'] = 'SSL_INBOUND_INSPECTION' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.is_unsupported_version_blocked = attributes[:'isUnsupportedVersionBlocked'] unless attributes[:'isUnsupportedVersionBlocked'].nil? raise 'You cannot provide both :isUnsupportedVersionBlocked and :is_unsupported_version_blocked' if attributes.key?(:'isUnsupportedVersionBlocked') && attributes.key?(:'is_unsupported_version_blocked') self.is_unsupported_version_blocked = attributes[:'is_unsupported_version_blocked'] unless attributes[:'is_unsupported_version_blocked'].nil? self.is_unsupported_cipher_blocked = attributes[:'isUnsupportedCipherBlocked'] unless attributes[:'isUnsupportedCipherBlocked'].nil? raise 'You cannot provide both :isUnsupportedCipherBlocked and :is_unsupported_cipher_blocked' if attributes.key?(:'isUnsupportedCipherBlocked') && attributes.key?(:'is_unsupported_cipher_blocked') self.is_unsupported_cipher_blocked = attributes[:'is_unsupported_cipher_blocked'] unless attributes[:'is_unsupported_cipher_blocked'].nil? self.is_out_of_capacity_blocked = attributes[:'isOutOfCapacityBlocked'] unless attributes[:'isOutOfCapacityBlocked'].nil? raise 'You cannot provide both :isOutOfCapacityBlocked and :is_out_of_capacity_blocked' if attributes.key?(:'isOutOfCapacityBlocked') && attributes.key?(:'is_out_of_capacity_blocked') self.is_out_of_capacity_blocked = attributes[:'is_out_of_capacity_blocked'] unless attributes[:'is_out_of_capacity_blocked'].nil? end |
Instance Attribute Details
#is_out_of_capacity_blocked ⇒ BOOLEAN
**[Required]** Whether to block sessions if the firewall is temporarily unable to decrypt their traffic.
21 22 23 |
# File 'lib/oci/network_firewall/models/ssl_inbound_inspection_profile.rb', line 21 def is_out_of_capacity_blocked @is_out_of_capacity_blocked end |
#is_unsupported_cipher_blocked ⇒ BOOLEAN
**[Required]** Whether to block sessions if SSL cipher suite is not supported.
17 18 19 |
# File 'lib/oci/network_firewall/models/ssl_inbound_inspection_profile.rb', line 17 def is_unsupported_cipher_blocked @is_unsupported_cipher_blocked end |
#is_unsupported_version_blocked ⇒ BOOLEAN
**[Required]** Whether to block sessions if SSL version is not supported.
13 14 15 |
# File 'lib/oci/network_firewall/models/ssl_inbound_inspection_profile.rb', line 13 def is_unsupported_version_blocked @is_unsupported_version_blocked end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
24 25 26 27 28 29 30 31 32 33 |
# File 'lib/oci/network_firewall/models/ssl_inbound_inspection_profile.rb', line 24 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'type': :'type', 'is_unsupported_version_blocked': :'isUnsupportedVersionBlocked', 'is_unsupported_cipher_blocked': :'isUnsupportedCipherBlocked', 'is_out_of_capacity_blocked': :'isOutOfCapacityBlocked' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
36 37 38 39 40 41 42 43 44 45 |
# File 'lib/oci/network_firewall/models/ssl_inbound_inspection_profile.rb', line 36 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'type': :'String', 'is_unsupported_version_blocked': :'BOOLEAN', 'is_unsupported_cipher_blocked': :'BOOLEAN', 'is_out_of_capacity_blocked': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
92 93 94 95 96 97 98 99 100 |
# File 'lib/oci/network_firewall/models/ssl_inbound_inspection_profile.rb', line 92 def ==(other) return true if equal?(other) self.class == other.class && type == other.type && is_unsupported_version_blocked == other.is_unsupported_version_blocked && is_unsupported_cipher_blocked == other.is_unsupported_cipher_blocked && is_out_of_capacity_blocked == other.is_out_of_capacity_blocked end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/oci/network_firewall/models/ssl_inbound_inspection_profile.rb', line 125 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
105 106 107 |
# File 'lib/oci/network_firewall/models/ssl_inbound_inspection_profile.rb', line 105 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
114 115 116 |
# File 'lib/oci/network_firewall/models/ssl_inbound_inspection_profile.rb', line 114 def hash [type, is_unsupported_version_blocked, is_unsupported_cipher_blocked, is_out_of_capacity_blocked].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
158 159 160 161 162 163 164 165 166 167 |
# File 'lib/oci/network_firewall/models/ssl_inbound_inspection_profile.rb', line 158 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
152 153 154 |
# File 'lib/oci/network_firewall/models/ssl_inbound_inspection_profile.rb', line 152 def to_s to_hash.to_s end |