Class: OCI::NetworkFirewall::Models::TcpApplication
- Inherits:
-
Application
- Object
- Application
- OCI::NetworkFirewall::Models::TcpApplication
- Defined in:
- lib/oci/network_firewall/models/tcp_application.rb
Overview
TCP Application used on the firewall policy rules.
Instance Attribute Summary collapse
-
#maximum_port ⇒ Integer
The maximum port in the range (inclusive), which may be absent for a single-port range.
-
#minimum_port ⇒ Integer
**[Required]** The minimum port in the range (inclusive), or the sole port of a single-port range.
Attributes inherited from Application
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TcpApplication
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from Application
Constructor Details
#initialize(attributes = {}) ⇒ TcpApplication
Initializes the object
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/oci/network_firewall/models/tcp_application.rb', line 49 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['type'] = 'TCP' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.minimum_port = attributes[:'minimumPort'] if attributes[:'minimumPort'] raise 'You cannot provide both :minimumPort and :minimum_port' if attributes.key?(:'minimumPort') && attributes.key?(:'minimum_port') self.minimum_port = attributes[:'minimum_port'] if attributes[:'minimum_port'] self.maximum_port = attributes[:'maximumPort'] if attributes[:'maximumPort'] raise 'You cannot provide both :maximumPort and :maximum_port' if attributes.key?(:'maximumPort') && attributes.key?(:'maximum_port') self.maximum_port = attributes[:'maximum_port'] if attributes[:'maximum_port'] end |
Instance Attribute Details
#maximum_port ⇒ Integer
The maximum port in the range (inclusive), which may be absent for a single-port range.
17 18 19 |
# File 'lib/oci/network_firewall/models/tcp_application.rb', line 17 def maximum_port @maximum_port end |
#minimum_port ⇒ Integer
**[Required]** The minimum port in the range (inclusive), or the sole port of a single-port range.
13 14 15 |
# File 'lib/oci/network_firewall/models/tcp_application.rb', line 13 def minimum_port @minimum_port end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
20 21 22 23 24 25 26 27 28 |
# File 'lib/oci/network_firewall/models/tcp_application.rb', line 20 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'type': :'type', 'minimum_port': :'minimumPort', 'maximum_port': :'maximumPort' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
31 32 33 34 35 36 37 38 39 |
# File 'lib/oci/network_firewall/models/tcp_application.rb', line 31 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'type': :'String', 'minimum_port': :'Integer', 'maximum_port': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
79 80 81 82 83 84 85 86 |
# File 'lib/oci/network_firewall/models/tcp_application.rb', line 79 def ==(other) return true if equal?(other) self.class == other.class && type == other.type && minimum_port == other.minimum_port && maximum_port == other.maximum_port end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/oci/network_firewall/models/tcp_application.rb', line 111 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
91 92 93 |
# File 'lib/oci/network_firewall/models/tcp_application.rb', line 91 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
100 101 102 |
# File 'lib/oci/network_firewall/models/tcp_application.rb', line 100 def hash [type, minimum_port, maximum_port].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
144 145 146 147 148 149 150 151 152 153 |
# File 'lib/oci/network_firewall/models/tcp_application.rb', line 144 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
138 139 140 |
# File 'lib/oci/network_firewall/models/tcp_application.rb', line 138 def to_s to_hash.to_s end |