Class: OCI::NetworkFirewall::Models::VaultMappedSecret

Inherits:
MappedSecret
  • Object
show all
Defined in:
lib/oci/network_firewall/models/vault_mapped_secret.rb

Overview

Mapped secret stored in OCI vault used in the firewall policy rules.

Constant Summary

Constants inherited from MappedSecret

MappedSecret::TYPE_ENUM

Instance Attribute Summary collapse

Attributes inherited from MappedSecret

#source, #type

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from MappedSecret

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ VaultMappedSecret

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :type (String)

    The value to assign to the #type proprety

  • :vault_secret_id (String)

    The value to assign to the #vault_secret_id property

  • :version_number (Integer)

    The value to assign to the #version_number property



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/oci/network_firewall/models/vault_mapped_secret.rb', line 52

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['source'] = 'OCI_VAULT'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.vault_secret_id = attributes[:'vaultSecretId'] if attributes[:'vaultSecretId']

  raise 'You cannot provide both :vaultSecretId and :vault_secret_id' if attributes.key?(:'vaultSecretId') && attributes.key?(:'vault_secret_id')

  self.vault_secret_id = attributes[:'vault_secret_id'] if attributes[:'vault_secret_id']

  self.version_number = attributes[:'versionNumber'] if attributes[:'versionNumber']

  raise 'You cannot provide both :versionNumber and :version_number' if attributes.key?(:'versionNumber') && attributes.key?(:'version_number')

  self.version_number = attributes[:'version_number'] if attributes[:'version_number']
end

Instance Attribute Details

#vault_secret_idString

**[Required]** OCID for the Vault Secret to be used.

Returns:

  • (String)


13
14
15
# File 'lib/oci/network_firewall/models/vault_mapped_secret.rb', line 13

def vault_secret_id
  @vault_secret_id
end

#version_numberInteger

**[Required]** Version number of the secret to be used.

Returns:

  • (Integer)


17
18
19
# File 'lib/oci/network_firewall/models/vault_mapped_secret.rb', line 17

def version_number
  @version_number
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



20
21
22
23
24
25
26
27
28
29
# File 'lib/oci/network_firewall/models/vault_mapped_secret.rb', line 20

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'source': :'source',
    'type': :'type',
    'vault_secret_id': :'vaultSecretId',
    'version_number': :'versionNumber'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



32
33
34
35
36
37
38
39
40
41
# File 'lib/oci/network_firewall/models/vault_mapped_secret.rb', line 32

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'source': :'String',
    'type': :'String',
    'vault_secret_id': :'String',
    'version_number': :'Integer'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



82
83
84
85
86
87
88
89
90
# File 'lib/oci/network_firewall/models/vault_mapped_secret.rb', line 82

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    source == other.source &&
    type == other.type &&
    vault_secret_id == other.vault_secret_id &&
    version_number == other.version_number
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/oci/network_firewall/models/vault_mapped_secret.rb', line 115

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


95
96
97
# File 'lib/oci/network_firewall/models/vault_mapped_secret.rb', line 95

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



104
105
106
# File 'lib/oci/network_firewall/models/vault_mapped_secret.rb', line 104

def hash
  [source, type, vault_secret_id, version_number].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



148
149
150
151
152
153
154
155
156
157
# File 'lib/oci/network_firewall/models/vault_mapped_secret.rb', line 148

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



142
143
144
# File 'lib/oci/network_firewall/models/vault_mapped_secret.rb', line 142

def to_s
  to_hash.to_s
end