Class: OCI::NetworkLoadBalancer::Models::BackendSetDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/network_load_balancer/models/backend_set_details.rb

Overview

The configuration of a network load balancer backend set. For more information about backend set configuration, see [Managing Backend Sets](docs.cloud.oracle.com/Content/Balance/Tasks/managingbackendsets.htm).

Caution: Oracle recommends that you avoid using any confidential information when you supply string values using the API.

Constant Summary collapse

POLICY_ENUM =
[
  POLICY_TWO_TUPLE = 'TWO_TUPLE'.freeze,
  POLICY_THREE_TUPLE = 'THREE_TUPLE'.freeze,
  POLICY_FIVE_TUPLE = 'FIVE_TUPLE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ BackendSetDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :policy (String)

    The value to assign to the #policy property

  • :is_preserve_source (BOOLEAN)

    The value to assign to the #is_preserve_source property

  • :backends (Array<OCI::NetworkLoadBalancer::Models::Backend>)

    The value to assign to the #backends property

  • :health_checker (OCI::NetworkLoadBalancer::Models::HealthChecker)

    The value to assign to the #health_checker property



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/oci/network_load_balancer/models/backend_set_details.rb', line 78

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.policy = attributes[:'policy'] if attributes[:'policy']
  self.policy = "FIVE_TUPLE" if policy.nil? && !attributes.key?(:'policy') # rubocop:disable Style/StringLiterals

  self.is_preserve_source = attributes[:'isPreserveSource'] unless attributes[:'isPreserveSource'].nil?
  self.is_preserve_source = true if is_preserve_source.nil? && !attributes.key?(:'isPreserveSource') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isPreserveSource and :is_preserve_source' if attributes.key?(:'isPreserveSource') && attributes.key?(:'is_preserve_source')

  self.is_preserve_source = attributes[:'is_preserve_source'] unless attributes[:'is_preserve_source'].nil?
  self.is_preserve_source = true if is_preserve_source.nil? && !attributes.key?(:'isPreserveSource') && !attributes.key?(:'is_preserve_source') # rubocop:disable Style/StringLiterals

  self.backends = attributes[:'backends'] if attributes[:'backends']

  self.health_checker = attributes[:'healthChecker'] if attributes[:'healthChecker']

  raise 'You cannot provide both :healthChecker and :health_checker' if attributes.key?(:'healthChecker') && attributes.key?(:'health_checker')

  self.health_checker = attributes[:'health_checker'] if attributes[:'health_checker']
end

Instance Attribute Details

#backendsArray<OCI::NetworkLoadBalancer::Models::Backend>

An array of backends.

Returns:

  • (Array<OCI::NetworkLoadBalancer::Models::Backend>)


38
39
40
# File 'lib/oci/network_load_balancer/models/backend_set_details.rb', line 38

def backends
  @backends
end

#health_checkerOCI::NetworkLoadBalancer::Models::HealthChecker

This attribute is required.

Returns:

  • (OCI::NetworkLoadBalancer::Models::HealthChecker)


42
43
44
# File 'lib/oci/network_load_balancer/models/backend_set_details.rb', line 42

def health_checker
  @health_checker
end

#is_preserve_sourceBOOLEAN

If this parameter is enabled, then the network load balancer preserves the source IP of the packet when it is forwarded to backends. Backends see the original source IP. If the isPreserveSourceDestination parameter is enabled for the network load balancer resource, then this parameter cannot be disabled. The value is true by default.

Returns:

  • (BOOLEAN)


33
34
35
# File 'lib/oci/network_load_balancer/models/backend_set_details.rb', line 33

def is_preserve_source
  @is_preserve_source
end

#policyString

The network load balancer policy for the backend set.

Example: FIVE_TUPLE

Returns:

  • (String)


26
27
28
# File 'lib/oci/network_load_balancer/models/backend_set_details.rb', line 26

def policy
  @policy
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



45
46
47
48
49
50
51
52
53
54
# File 'lib/oci/network_load_balancer/models/backend_set_details.rb', line 45

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'policy': :'policy',
    'is_preserve_source': :'isPreserveSource',
    'backends': :'backends',
    'health_checker': :'healthChecker'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



57
58
59
60
61
62
63
64
65
66
# File 'lib/oci/network_load_balancer/models/backend_set_details.rb', line 57

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'policy': :'String',
    'is_preserve_source': :'BOOLEAN',
    'backends': :'Array<OCI::NetworkLoadBalancer::Models::Backend>',
    'health_checker': :'OCI::NetworkLoadBalancer::Models::HealthChecker'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



119
120
121
122
123
124
125
126
127
# File 'lib/oci/network_load_balancer/models/backend_set_details.rb', line 119

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    policy == other.policy &&
    is_preserve_source == other.is_preserve_source &&
    backends == other.backends &&
    health_checker == other.health_checker
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/oci/network_load_balancer/models/backend_set_details.rb', line 152

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


132
133
134
# File 'lib/oci/network_load_balancer/models/backend_set_details.rb', line 132

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



141
142
143
# File 'lib/oci/network_load_balancer/models/backend_set_details.rb', line 141

def hash
  [policy, is_preserve_source, backends, health_checker].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



185
186
187
188
189
190
191
192
193
194
# File 'lib/oci/network_load_balancer/models/backend_set_details.rb', line 185

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



179
180
181
# File 'lib/oci/network_load_balancer/models/backend_set_details.rb', line 179

def to_s
  to_hash.to_s
end