Class: OCI::NetworkLoadBalancer::Models::CreateNetworkLoadBalancerDetails
- Inherits:
-
Object
- Object
- OCI::NetworkLoadBalancer::Models::CreateNetworkLoadBalancerDetails
- Defined in:
- lib/oci/network_load_balancer/models/create_network_load_balancer_details.rb
Overview
The properties that define a network load balancer. For more information, see [Managing a network load balancer](docs.cloud.oracle.com/Content/Balance/Tasks/managingloadbalancer.htm).
To use any of the API operations, you must be authorized in an IAM policy. If you are not authorized, then contact an administrator. If you are an administrator who writes policies to give users access, then see [Getting Started with Policies](docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm).
For information about endpoints and signing API requests, see [About the API](docs.cloud.oracle.com/Content/API/Concepts/usingapi.htm). For information about available SDKs and tools, see [SDKS and Other Tools](docs.cloud.oracle.com/Content/API/Concepts/sdks.htm).
Constant Summary collapse
- NLB_IP_VERSION_ENUM =
[ NLB_IP_VERSION_IPV4 = 'IPV4'.freeze, NLB_IP_VERSION_IPV4_AND_IPV6 = 'IPV4_AND_IPV6'.freeze ].freeze
Instance Attribute Summary collapse
-
#backend_sets ⇒ Hash<String, OCI::NetworkLoadBalancer::Models::BackendSetDetails>
Backend sets associated with the network load balancer.
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment containing the network load balancer.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
[Required] Network load balancer identifier, which can be renamed.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type, or scope.
-
#is_preserve_source_destination ⇒ BOOLEAN
This parameter can be enabled only if backends are compute OCIDs.
-
#is_private ⇒ BOOLEAN
Whether the network load balancer has a virtual cloud network-local (private) IP address.
-
#listeners ⇒ Hash<String, OCI::NetworkLoadBalancer::Models::ListenerDetails>
Listeners associated with the network load balancer.
-
#network_security_group_ids ⇒ Array<String>
An array of network security groups [OCIDs](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) associated with the network load balancer.
-
#nlb_ip_version ⇒ String
IP version associated with the NLB.
-
#reserved_ips ⇒ Array<OCI::NetworkLoadBalancer::Models::ReservedIP>
An array of reserved Ips.
-
#subnet_id ⇒ String
[Required] The subnet in which the network load balancer is spawned [OCIDs](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateNetworkLoadBalancerDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateNetworkLoadBalancerDetails
Initializes the object
164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/oci/network_load_balancer/models/create_network_load_balancer_details.rb', line 164 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.is_preserve_source_destination = attributes[:'isPreserveSourceDestination'] unless attributes[:'isPreserveSourceDestination'].nil? self.is_preserve_source_destination = false if is_preserve_source_destination.nil? && !attributes.key?(:'isPreserveSourceDestination') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isPreserveSourceDestination and :is_preserve_source_destination' if attributes.key?(:'isPreserveSourceDestination') && attributes.key?(:'is_preserve_source_destination') self.is_preserve_source_destination = attributes[:'is_preserve_source_destination'] unless attributes[:'is_preserve_source_destination'].nil? self.is_preserve_source_destination = false if is_preserve_source_destination.nil? && !attributes.key?(:'isPreserveSourceDestination') && !attributes.key?(:'is_preserve_source_destination') # rubocop:disable Style/StringLiterals self.reserved_ips = attributes[:'reservedIps'] if attributes[:'reservedIps'] raise 'You cannot provide both :reservedIps and :reserved_ips' if attributes.key?(:'reservedIps') && attributes.key?(:'reserved_ips') self.reserved_ips = attributes[:'reserved_ips'] if attributes[:'reserved_ips'] self.is_private = attributes[:'isPrivate'] unless attributes[:'isPrivate'].nil? self.is_private = true if is_private.nil? && !attributes.key?(:'isPrivate') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isPrivate and :is_private' if attributes.key?(:'isPrivate') && attributes.key?(:'is_private') self.is_private = attributes[:'is_private'] unless attributes[:'is_private'].nil? self.is_private = true if is_private.nil? && !attributes.key?(:'isPrivate') && !attributes.key?(:'is_private') # rubocop:disable Style/StringLiterals self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId'] raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id') self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id'] self.network_security_group_ids = attributes[:'networkSecurityGroupIds'] if attributes[:'networkSecurityGroupIds'] raise 'You cannot provide both :networkSecurityGroupIds and :network_security_group_ids' if attributes.key?(:'networkSecurityGroupIds') && attributes.key?(:'network_security_group_ids') self.network_security_group_ids = attributes[:'network_security_group_ids'] if attributes[:'network_security_group_ids'] self.nlb_ip_version = attributes[:'nlbIpVersion'] if attributes[:'nlbIpVersion'] self.nlb_ip_version = "IPV4" if nlb_ip_version.nil? && !attributes.key?(:'nlbIpVersion') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :nlbIpVersion and :nlb_ip_version' if attributes.key?(:'nlbIpVersion') && attributes.key?(:'nlb_ip_version') self.nlb_ip_version = attributes[:'nlb_ip_version'] if attributes[:'nlb_ip_version'] self.nlb_ip_version = "IPV4" if nlb_ip_version.nil? && !attributes.key?(:'nlbIpVersion') && !attributes.key?(:'nlb_ip_version') # rubocop:disable Style/StringLiterals self.listeners = attributes[:'listeners'] if attributes[:'listeners'] self.backend_sets = attributes[:'backendSets'] if attributes[:'backendSets'] raise 'You cannot provide both :backendSets and :backend_sets' if attributes.key?(:'backendSets') && attributes.key?(:'backend_sets') self.backend_sets = attributes[:'backend_sets'] if attributes[:'backend_sets'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#backend_sets ⇒ Hash<String, OCI::NetworkLoadBalancer::Models::BackendSetDetails>
Backend sets associated with the network load balancer.
92 93 94 |
# File 'lib/oci/network_load_balancer/models/create_network_load_balancer_details.rb', line 92 def backend_sets @backend_sets end |
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment containing the network load balancer.
27 28 29 |
# File 'lib/oci/network_load_balancer/models/create_network_load_balancer_details.rb', line 27 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
104 105 106 |
# File 'lib/oci/network_load_balancer/models/create_network_load_balancer_details.rb', line 104 def @defined_tags end |
#display_name ⇒ String
[Required] Network load balancer identifier, which can be renamed.
31 32 33 |
# File 'lib/oci/network_load_balancer/models/create_network_load_balancer_details.rb', line 31 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type, or scope. Exists for cross-compatibility only. Example: ‘"value"`
98 99 100 |
# File 'lib/oci/network_load_balancer/models/create_network_load_balancer_details.rb', line 98 def @freeform_tags end |
#is_preserve_source_destination ⇒ BOOLEAN
This parameter can be enabled only if backends are compute OCIDs. When enabled, the skipSourceDestinationCheck parameter is automatically enabled on the load balancer VNIC, and packets are sent to the backend with the entire IP header intact.
37 38 39 |
# File 'lib/oci/network_load_balancer/models/create_network_load_balancer_details.rb', line 37 def is_preserve_source_destination @is_preserve_source_destination end |
#is_private ⇒ BOOLEAN
Whether the network load balancer has a virtual cloud network-local (private) IP address.
If "true", then the service assigns a private IP address to the network load balancer.
If "false", then the service assigns a public IP address to the network load balancer.
A public network load balancer is accessible from the internet, depending on the [security list rules](docs.cloud.oracle.com/Content/network/Concepts/securitylists.htm) for your virtual cloud network. For more information about public and private network load balancers, see [How Network Load Balancing Works](docs.cloud.oracle.com/Content/Balance/Concepts/balanceoverview.htm#how-network-load-balancing-works). This value is true by default.
Example: true
59 60 61 |
# File 'lib/oci/network_load_balancer/models/create_network_load_balancer_details.rb', line 59 def is_private @is_private end |
#listeners ⇒ Hash<String, OCI::NetworkLoadBalancer::Models::ListenerDetails>
Listeners associated with the network load balancer.
88 89 90 |
# File 'lib/oci/network_load_balancer/models/create_network_load_balancer_details.rb', line 88 def listeners @listeners end |
#network_security_group_ids ⇒ Array<String>
An array of network security groups [OCIDs](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) associated with the network load balancer.
During the creation of the network load balancer, the service adds the new load balancer to the specified network security groups.
The benefits of associating the network load balancer with network security groups include:
-
Network security groups define network security rules to govern ingress and egress traffic for the network load balancer.
-
The network security rules of other resources can reference the network security groups associated with the network load balancer to ensure access.
Example: ["ocid1.nsg.oc1.phx.unique_ID"]
80 81 82 |
# File 'lib/oci/network_load_balancer/models/create_network_load_balancer_details.rb', line 80 def network_security_group_ids @network_security_group_ids end |
#nlb_ip_version ⇒ String
IP version associated with the NLB.
84 85 86 |
# File 'lib/oci/network_load_balancer/models/create_network_load_balancer_details.rb', line 84 def nlb_ip_version @nlb_ip_version end |
#reserved_ips ⇒ Array<OCI::NetworkLoadBalancer::Models::ReservedIP>
An array of reserved Ips.
42 43 44 |
# File 'lib/oci/network_load_balancer/models/create_network_load_balancer_details.rb', line 42 def reserved_ips @reserved_ips end |
#subnet_id ⇒ String
[Required] The subnet in which the network load balancer is spawned [OCIDs](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm).
63 64 65 |
# File 'lib/oci/network_load_balancer/models/create_network_load_balancer_details.rb', line 63 def subnet_id @subnet_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/oci/network_load_balancer/models/create_network_load_balancer_details.rb', line 107 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'is_preserve_source_destination': :'isPreserveSourceDestination', 'reserved_ips': :'reservedIps', 'is_private': :'isPrivate', 'subnet_id': :'subnetId', 'network_security_group_ids': :'networkSecurityGroupIds', 'nlb_ip_version': :'nlbIpVersion', 'listeners': :'listeners', 'backend_sets': :'backendSets', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/oci/network_load_balancer/models/create_network_load_balancer_details.rb', line 127 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'display_name': :'String', 'is_preserve_source_destination': :'BOOLEAN', 'reserved_ips': :'Array<OCI::NetworkLoadBalancer::Models::ReservedIP>', 'is_private': :'BOOLEAN', 'subnet_id': :'String', 'network_security_group_ids': :'Array<String>', 'nlb_ip_version': :'String', 'listeners': :'Hash<String, OCI::NetworkLoadBalancer::Models::ListenerDetails>', 'backend_sets': :'Hash<String, OCI::NetworkLoadBalancer::Models::BackendSetDetails>', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/oci/network_load_balancer/models/create_network_load_balancer_details.rb', line 260 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && display_name == other.display_name && is_preserve_source_destination == other.is_preserve_source_destination && reserved_ips == other.reserved_ips && is_private == other.is_private && subnet_id == other.subnet_id && network_security_group_ids == other.network_security_group_ids && nlb_ip_version == other.nlb_ip_version && listeners == other.listeners && backend_sets == other.backend_sets && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 |
# File 'lib/oci/network_load_balancer/models/create_network_load_balancer_details.rb', line 301 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
281 282 283 |
# File 'lib/oci/network_load_balancer/models/create_network_load_balancer_details.rb', line 281 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
290 291 292 |
# File 'lib/oci/network_load_balancer/models/create_network_load_balancer_details.rb', line 290 def hash [compartment_id, display_name, is_preserve_source_destination, reserved_ips, is_private, subnet_id, network_security_group_ids, nlb_ip_version, listeners, backend_sets, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
334 335 336 337 338 339 340 341 342 343 |
# File 'lib/oci/network_load_balancer/models/create_network_load_balancer_details.rb', line 334 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
328 329 330 |
# File 'lib/oci/network_load_balancer/models/create_network_load_balancer_details.rb', line 328 def to_s to_hash.to_s end |