Class: OCI::NetworkLoadBalancer::Models::HealthCheckerDetails
- Inherits:
-
Object
- Object
- OCI::NetworkLoadBalancer::Models::HealthCheckerDetails
- Defined in:
- lib/oci/network_load_balancer/models/health_checker_details.rb
Overview
The health check policy configuration. For more information, see [Editing Health Check Policies](docs.cloud.oracle.com/Content/Balance/Tasks/editinghealthcheck.htm).
Constant Summary collapse
- PROTOCOL_ENUM =
[ PROTOCOL_HTTP = 'HTTP'.freeze, PROTOCOL_HTTPS = 'HTTPS'.freeze, PROTOCOL_TCP = 'TCP'.freeze, PROTOCOL_UDP = 'UDP'.freeze ].freeze
Instance Attribute Summary collapse
-
#interval_in_millis ⇒ Integer
The interval between health checks, in milliseconds.
-
#port ⇒ Integer
The backend server port against which to run the health check.
-
#protocol ⇒ String
[Required] The protocol the health check must use; either HTTP or HTTPS, or UDP or TCP.
-
#request_data ⇒ String
Base64 encoded pattern to be sent as UDP or TCP health check probe.
-
#response_body_regex ⇒ String
A regular expression for parsing the response body from the backend server.
-
#response_data ⇒ String
Base64 encoded pattern to be validated as UDP or TCP health check probe response.
-
#retries ⇒ Integer
The number of retries to attempt before a backend server is considered "unhealthy".
-
#return_code ⇒ Integer
The status code a healthy backend server should return.
-
#timeout_in_millis ⇒ Integer
The maximum time, in milliseconds, to wait for a reply to a health check.
-
#url_path ⇒ String
The path against which to run the health check.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ HealthCheckerDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ HealthCheckerDetails
Initializes the object
139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/oci/network_load_balancer/models/health_checker_details.rb', line 139 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.protocol = attributes[:'protocol'] if attributes[:'protocol'] self.port = attributes[:'port'] if attributes[:'port'] self.retries = attributes[:'retries'] if attributes[:'retries'] self.retries = 3 if retries.nil? && !attributes.key?(:'retries') # rubocop:disable Style/StringLiterals self.timeout_in_millis = attributes[:'timeoutInMillis'] if attributes[:'timeoutInMillis'] self.timeout_in_millis = 3000 if timeout_in_millis.nil? && !attributes.key?(:'timeoutInMillis') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :timeoutInMillis and :timeout_in_millis' if attributes.key?(:'timeoutInMillis') && attributes.key?(:'timeout_in_millis') self.timeout_in_millis = attributes[:'timeout_in_millis'] if attributes[:'timeout_in_millis'] self.timeout_in_millis = 3000 if timeout_in_millis.nil? && !attributes.key?(:'timeoutInMillis') && !attributes.key?(:'timeout_in_millis') # rubocop:disable Style/StringLiterals self.interval_in_millis = attributes[:'intervalInMillis'] if attributes[:'intervalInMillis'] self.interval_in_millis = 10000 if interval_in_millis.nil? && !attributes.key?(:'intervalInMillis') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :intervalInMillis and :interval_in_millis' if attributes.key?(:'intervalInMillis') && attributes.key?(:'interval_in_millis') self.interval_in_millis = attributes[:'interval_in_millis'] if attributes[:'interval_in_millis'] self.interval_in_millis = 10000 if interval_in_millis.nil? && !attributes.key?(:'intervalInMillis') && !attributes.key?(:'interval_in_millis') # rubocop:disable Style/StringLiterals self.url_path = attributes[:'urlPath'] if attributes[:'urlPath'] raise 'You cannot provide both :urlPath and :url_path' if attributes.key?(:'urlPath') && attributes.key?(:'url_path') self.url_path = attributes[:'url_path'] if attributes[:'url_path'] self.response_body_regex = attributes[:'responseBodyRegex'] if attributes[:'responseBodyRegex'] raise 'You cannot provide both :responseBodyRegex and :response_body_regex' if attributes.key?(:'responseBodyRegex') && attributes.key?(:'response_body_regex') self.response_body_regex = attributes[:'response_body_regex'] if attributes[:'response_body_regex'] self.return_code = attributes[:'returnCode'] if attributes[:'returnCode'] raise 'You cannot provide both :returnCode and :return_code' if attributes.key?(:'returnCode') && attributes.key?(:'return_code') self.return_code = attributes[:'return_code'] if attributes[:'return_code'] self.request_data = attributes[:'requestData'] if attributes[:'requestData'] raise 'You cannot provide both :requestData and :request_data' if attributes.key?(:'requestData') && attributes.key?(:'request_data') self.request_data = attributes[:'request_data'] if attributes[:'request_data'] self.response_data = attributes[:'responseData'] if attributes[:'responseData'] raise 'You cannot provide both :responseData and :response_data' if attributes.key?(:'responseData') && attributes.key?(:'response_data') self.response_data = attributes[:'response_data'] if attributes[:'response_data'] end |
Instance Attribute Details
#interval_in_millis ⇒ Integer
The interval between health checks, in milliseconds. The default value is 10000 (10 seconds).
Example: 10000
55 56 57 |
# File 'lib/oci/network_load_balancer/models/health_checker_details.rb', line 55 def interval_in_millis @interval_in_millis end |
#port ⇒ Integer
The backend server port against which to run the health check. If the port is not specified, then the network load balancer uses the port information from the Backend object. The port must be specified if the backend port is 0.
Example: 8080
32 33 34 |
# File 'lib/oci/network_load_balancer/models/health_checker_details.rb', line 32 def port @port end |
#protocol ⇒ String
[Required] The protocol the health check must use; either HTTP or HTTPS, or UDP or TCP.
Example: HTTP
24 25 26 |
# File 'lib/oci/network_load_balancer/models/health_checker_details.rb', line 24 def protocol @protocol end |
#request_data ⇒ String
Base64 encoded pattern to be sent as UDP or TCP health check probe.
81 82 83 |
# File 'lib/oci/network_load_balancer/models/health_checker_details.rb', line 81 def request_data @request_data end |
#response_body_regex ⇒ String
A regular expression for parsing the response body from the backend server.
Example: ‘^((?!false).|\s)*$`
69 70 71 |
# File 'lib/oci/network_load_balancer/models/health_checker_details.rb', line 69 def response_body_regex @response_body_regex end |
#response_data ⇒ String
Base64 encoded pattern to be validated as UDP or TCP health check probe response.
85 86 87 |
# File 'lib/oci/network_load_balancer/models/health_checker_details.rb', line 85 def response_data @response_data end |
#retries ⇒ Integer
The number of retries to attempt before a backend server is considered "unhealthy". This number also applies when recovering a server to the "healthy" state. The default value is 3.
Example: 3
40 41 42 |
# File 'lib/oci/network_load_balancer/models/health_checker_details.rb', line 40 def retries @retries end |
#return_code ⇒ Integer
The status code a healthy backend server should return. If you configure the health check policy to use the HTTP protocol, then you can use common HTTP status codes such as "200".
Example: 200
77 78 79 |
# File 'lib/oci/network_load_balancer/models/health_checker_details.rb', line 77 def return_code @return_code end |
#timeout_in_millis ⇒ Integer
The maximum time, in milliseconds, to wait for a reply to a health check. A health check is successful only if a reply returns within this timeout period. The default value is 3000 (3 seconds).
Example: 3000
48 49 50 |
# File 'lib/oci/network_load_balancer/models/health_checker_details.rb', line 48 def timeout_in_millis @timeout_in_millis end |
#url_path ⇒ String
The path against which to run the health check.
Example: /healthcheck
62 63 64 |
# File 'lib/oci/network_load_balancer/models/health_checker_details.rb', line 62 def url_path @url_path end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/oci/network_load_balancer/models/health_checker_details.rb', line 88 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'protocol': :'protocol', 'port': :'port', 'retries': :'retries', 'timeout_in_millis': :'timeoutInMillis', 'interval_in_millis': :'intervalInMillis', 'url_path': :'urlPath', 'response_body_regex': :'responseBodyRegex', 'return_code': :'returnCode', 'request_data': :'requestData', 'response_data': :'responseData' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/oci/network_load_balancer/models/health_checker_details.rb', line 106 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'protocol': :'String', 'port': :'Integer', 'retries': :'Integer', 'timeout_in_millis': :'Integer', 'interval_in_millis': :'Integer', 'url_path': :'String', 'response_body_regex': :'String', 'return_code': :'Integer', 'request_data': :'String', 'response_data': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/oci/network_load_balancer/models/health_checker_details.rb', line 214 def ==(other) return true if equal?(other) self.class == other.class && protocol == other.protocol && port == other.port && retries == other.retries && timeout_in_millis == other.timeout_in_millis && interval_in_millis == other.interval_in_millis && url_path == other.url_path && response_body_regex == other.response_body_regex && return_code == other.return_code && request_data == other.request_data && response_data == other.response_data end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/oci/network_load_balancer/models/health_checker_details.rb', line 253 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
233 234 235 |
# File 'lib/oci/network_load_balancer/models/health_checker_details.rb', line 233 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
242 243 244 |
# File 'lib/oci/network_load_balancer/models/health_checker_details.rb', line 242 def hash [protocol, port, retries, timeout_in_millis, interval_in_millis, url_path, response_body_regex, return_code, request_data, response_data].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
286 287 288 289 290 291 292 293 294 295 |
# File 'lib/oci/network_load_balancer/models/health_checker_details.rb', line 286 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
280 281 282 |
# File 'lib/oci/network_load_balancer/models/health_checker_details.rb', line 280 def to_s to_hash.to_s end |