Class: OCI::NetworkLoadBalancer::Models::NetworkLoadBalancerHealth
- Inherits:
-
Object
- Object
- OCI::NetworkLoadBalancer::Models::NetworkLoadBalancerHealth
- Defined in:
- lib/oci/network_load_balancer/models/network_load_balancer_health.rb
Overview
The health status details for the specified network load balancer.
This object does not explicitly enumerate backend sets with a status of OK. However, the backend sets are included in the totalBackendSetCount sum.
Constant Summary collapse
- STATUS_ENUM =
[ STATUS_OK = 'OK'.freeze, STATUS_WARNING = 'WARNING'.freeze, STATUS_CRITICAL = 'CRITICAL'.freeze, STATUS_UNKNOWN = 'UNKNOWN'.freeze, STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#critical_state_backend_set_names ⇒ Array<String>
[Required] A list of backend sets that are currently in the
CRITICALhealth state. -
#status ⇒ String
[Required] The overall health status of the network load balancer.
-
#total_backend_set_count ⇒ Integer
[Required] The total number of backend sets associated with this network load balancer.
-
#unknown_state_backend_set_names ⇒ Array<String>
[Required] A list of backend sets that are currently in the
UNKNOWNhealth state. -
#warning_state_backend_set_names ⇒ Array<String>
[Required] A list of backend sets that are currently in the
WARNINGhealth state.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NetworkLoadBalancerHealth
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ NetworkLoadBalancerHealth
Initializes the object
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/oci/network_load_balancer/models/network_load_balancer_health.rb', line 114 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.status = attributes[:'status'] if attributes[:'status'] self.warning_state_backend_set_names = attributes[:'warningStateBackendSetNames'] if attributes[:'warningStateBackendSetNames'] raise 'You cannot provide both :warningStateBackendSetNames and :warning_state_backend_set_names' if attributes.key?(:'warningStateBackendSetNames') && attributes.key?(:'warning_state_backend_set_names') self.warning_state_backend_set_names = attributes[:'warning_state_backend_set_names'] if attributes[:'warning_state_backend_set_names'] self.critical_state_backend_set_names = attributes[:'criticalStateBackendSetNames'] if attributes[:'criticalStateBackendSetNames'] raise 'You cannot provide both :criticalStateBackendSetNames and :critical_state_backend_set_names' if attributes.key?(:'criticalStateBackendSetNames') && attributes.key?(:'critical_state_backend_set_names') self.critical_state_backend_set_names = attributes[:'critical_state_backend_set_names'] if attributes[:'critical_state_backend_set_names'] self.unknown_state_backend_set_names = attributes[:'unknownStateBackendSetNames'] if attributes[:'unknownStateBackendSetNames'] raise 'You cannot provide both :unknownStateBackendSetNames and :unknown_state_backend_set_names' if attributes.key?(:'unknownStateBackendSetNames') && attributes.key?(:'unknown_state_backend_set_names') self.unknown_state_backend_set_names = attributes[:'unknown_state_backend_set_names'] if attributes[:'unknown_state_backend_set_names'] self.total_backend_set_count = attributes[:'totalBackendSetCount'] if attributes[:'totalBackendSetCount'] raise 'You cannot provide both :totalBackendSetCount and :total_backend_set_count' if attributes.key?(:'totalBackendSetCount') && attributes.key?(:'total_backend_set_count') self.total_backend_set_count = attributes[:'total_backend_set_count'] if attributes[:'total_backend_set_count'] end |
Instance Attribute Details
#critical_state_backend_set_names ⇒ Array<String>
[Required] A list of backend sets that are currently in the CRITICAL health state. The list identifies each backend set by the user-friendly name you assigned when you created the backend set.
Example: example_backend_set
60 61 62 |
# File 'lib/oci/network_load_balancer/models/network_load_balancer_health.rb', line 60 def critical_state_backend_set_names @critical_state_backend_set_names end |
#status ⇒ String
[Required] The overall health status of the network load balancer.
-
OK: All backend sets associated with the network load balancer return a status of
OK. -
WARNING: At least one of the backend sets associated with the network load balancer returns a status of
WARNING,
no backend sets return a status of CRITICAL, and the network load balancer life cycle state is ACTIVE.
-
CRITICAL: One or more of the backend sets associated with the network load balancer return a status of
CRITICAL. -
UNKNOWN: If any one of the following conditions is true:
* The network load balancer life cycle state is not `ACTIVE`. * No backend sets are defined for the network load balancer. * More than half of the backend sets associated with the network load balancer return a status of `UNKNOWN`, none of the backend sets return a status of `WARNING` or `CRITICAL`, and the network load balancer life cycle state is `ACTIVE`. * The system could not retrieve metrics for any reason.
44 45 46 |
# File 'lib/oci/network_load_balancer/models/network_load_balancer_health.rb', line 44 def status @status end |
#total_backend_set_count ⇒ Integer
[Required] The total number of backend sets associated with this network load balancer.
Example: 4
75 76 77 |
# File 'lib/oci/network_load_balancer/models/network_load_balancer_health.rb', line 75 def total_backend_set_count @total_backend_set_count end |
#unknown_state_backend_set_names ⇒ Array<String>
[Required] A list of backend sets that are currently in the UNKNOWN health state. The list identifies each backend set by the user-friendly name you assigned when you created the backend set.
Example: example_backend_set2
68 69 70 |
# File 'lib/oci/network_load_balancer/models/network_load_balancer_health.rb', line 68 def unknown_state_backend_set_names @unknown_state_backend_set_names end |
#warning_state_backend_set_names ⇒ Array<String>
[Required] A list of backend sets that are currently in the WARNING health state. The list identifies each backend set by the user-friendly name you assigned when you created the backend set.
Example: example_backend_set3
52 53 54 |
# File 'lib/oci/network_load_balancer/models/network_load_balancer_health.rb', line 52 def warning_state_backend_set_names @warning_state_backend_set_names end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/oci/network_load_balancer/models/network_load_balancer_health.rb', line 78 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'status': :'status', 'warning_state_backend_set_names': :'warningStateBackendSetNames', 'critical_state_backend_set_names': :'criticalStateBackendSetNames', 'unknown_state_backend_set_names': :'unknownStateBackendSetNames', 'total_backend_set_count': :'totalBackendSetCount' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/oci/network_load_balancer/models/network_load_balancer_health.rb', line 91 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'status': :'String', 'warning_state_backend_set_names': :'Array<String>', 'critical_state_backend_set_names': :'Array<String>', 'unknown_state_backend_set_names': :'Array<String>', 'total_backend_set_count': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
167 168 169 170 171 172 173 174 175 176 |
# File 'lib/oci/network_load_balancer/models/network_load_balancer_health.rb', line 167 def ==(other) return true if equal?(other) self.class == other.class && status == other.status && warning_state_backend_set_names == other.warning_state_backend_set_names && critical_state_backend_set_names == other.critical_state_backend_set_names && unknown_state_backend_set_names == other.unknown_state_backend_set_names && total_backend_set_count == other.total_backend_set_count end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/oci/network_load_balancer/models/network_load_balancer_health.rb', line 201 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
181 182 183 |
# File 'lib/oci/network_load_balancer/models/network_load_balancer_health.rb', line 181 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
190 191 192 |
# File 'lib/oci/network_load_balancer/models/network_load_balancer_health.rb', line 190 def hash [status, warning_state_backend_set_names, critical_state_backend_set_names, unknown_state_backend_set_names, total_backend_set_count].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
234 235 236 237 238 239 240 241 242 243 |
# File 'lib/oci/network_load_balancer/models/network_load_balancer_health.rb', line 234 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
228 229 230 |
# File 'lib/oci/network_load_balancer/models/network_load_balancer_health.rb', line 228 def to_s to_hash.to_s end |