Class: OCI::NetworkLoadBalancer::Models::UpdateBackendDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/network_load_balancer/models/update_backend_details.rb

Overview

The configuration details for updating a backend server.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateBackendDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :weight (Integer)

    The value to assign to the #weight property

  • :is_backup (BOOLEAN)

    The value to assign to the #is_backup property

  • :is_drain (BOOLEAN)

    The value to assign to the #is_drain property

  • :is_offline (BOOLEAN)

    The value to assign to the #is_offline property



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/oci/network_load_balancer/models/update_backend_details.rb', line 79

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.weight = attributes[:'weight'] if attributes[:'weight']

  self.is_backup = attributes[:'isBackup'] unless attributes[:'isBackup'].nil?
  self.is_backup = false if is_backup.nil? && !attributes.key?(:'isBackup') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isBackup and :is_backup' if attributes.key?(:'isBackup') && attributes.key?(:'is_backup')

  self.is_backup = attributes[:'is_backup'] unless attributes[:'is_backup'].nil?
  self.is_backup = false if is_backup.nil? && !attributes.key?(:'isBackup') && !attributes.key?(:'is_backup') # rubocop:disable Style/StringLiterals

  self.is_drain = attributes[:'isDrain'] unless attributes[:'isDrain'].nil?
  self.is_drain = false if is_drain.nil? && !attributes.key?(:'isDrain') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isDrain and :is_drain' if attributes.key?(:'isDrain') && attributes.key?(:'is_drain')

  self.is_drain = attributes[:'is_drain'] unless attributes[:'is_drain'].nil?
  self.is_drain = false if is_drain.nil? && !attributes.key?(:'isDrain') && !attributes.key?(:'is_drain') # rubocop:disable Style/StringLiterals

  self.is_offline = attributes[:'isOffline'] unless attributes[:'isOffline'].nil?
  self.is_offline = false if is_offline.nil? && !attributes.key?(:'isOffline') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isOffline and :is_offline' if attributes.key?(:'isOffline') && attributes.key?(:'is_offline')

  self.is_offline = attributes[:'is_offline'] unless attributes[:'is_offline'].nil?
  self.is_offline = false if is_offline.nil? && !attributes.key?(:'isOffline') && !attributes.key?(:'is_offline') # rubocop:disable Style/StringLiterals
end

Instance Attribute Details

#is_backupBOOLEAN

Whether the network load balancer should treat this server as a backup unit. If true, then the network load balancer forwards no ingress traffic to this backend server unless all other backend servers not marked as "isBackup" fail the health check policy.

Example: false

Returns:

  • (BOOLEAN)


27
28
29
# File 'lib/oci/network_load_balancer/models/update_backend_details.rb', line 27

def is_backup
  @is_backup
end

#is_drainBOOLEAN

Whether the network load balancer should drain this server. Servers marked "isDrain" receive no incoming traffic.

Example: false

Returns:

  • (BOOLEAN)


35
36
37
# File 'lib/oci/network_load_balancer/models/update_backend_details.rb', line 35

def is_drain
  @is_drain
end

#is_offlineBOOLEAN

Whether the network load balancer should treat this server as offline. Offline servers receive no incoming traffic.

Example: false

Returns:

  • (BOOLEAN)


43
44
45
# File 'lib/oci/network_load_balancer/models/update_backend_details.rb', line 43

def is_offline
  @is_offline
end

#weightInteger

The load balancing policy weight assigned to the server. Backend servers with a higher weight receive a larger proportion of incoming traffic. For example, a server weighted ‘3’ receives three times the number of new connections as a server weighted ‘1’. For more information about load balancing policies, see [How Load Balancing Policies Work](docs.cloud.oracle.com/Content/Balance/Reference/lbpolicies.htm).

Example: 3

Returns:

  • (Integer)


19
20
21
# File 'lib/oci/network_load_balancer/models/update_backend_details.rb', line 19

def weight
  @weight
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



46
47
48
49
50
51
52
53
54
55
# File 'lib/oci/network_load_balancer/models/update_backend_details.rb', line 46

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'weight': :'weight',
    'is_backup': :'isBackup',
    'is_drain': :'isDrain',
    'is_offline': :'isOffline'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



58
59
60
61
62
63
64
65
66
67
# File 'lib/oci/network_load_balancer/models/update_backend_details.rb', line 58

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'weight': :'Integer',
    'is_backup': :'BOOLEAN',
    'is_drain': :'BOOLEAN',
    'is_offline': :'BOOLEAN'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



119
120
121
122
123
124
125
126
127
# File 'lib/oci/network_load_balancer/models/update_backend_details.rb', line 119

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    weight == other.weight &&
    is_backup == other.is_backup &&
    is_drain == other.is_drain &&
    is_offline == other.is_offline
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/oci/network_load_balancer/models/update_backend_details.rb', line 152

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


132
133
134
# File 'lib/oci/network_load_balancer/models/update_backend_details.rb', line 132

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



141
142
143
# File 'lib/oci/network_load_balancer/models/update_backend_details.rb', line 141

def hash
  [weight, is_backup, is_drain, is_offline].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



185
186
187
188
189
190
191
192
193
194
# File 'lib/oci/network_load_balancer/models/update_backend_details.rb', line 185

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



179
180
181
# File 'lib/oci/network_load_balancer/models/update_backend_details.rb', line 179

def to_s
  to_hash.to_s
end