Class: OCI::NetworkLoadBalancer::Models::UpdateHealthCheckerDetails
- Inherits:
-
Object
- Object
- OCI::NetworkLoadBalancer::Models::UpdateHealthCheckerDetails
- Defined in:
- lib/oci/network_load_balancer/models/update_health_checker_details.rb
Overview
The configuration details of the health checker.
Constant Summary collapse
- PROTOCOL_ENUM =
[ PROTOCOL_HTTP = 'HTTP'.freeze, PROTOCOL_HTTPS = 'HTTPS'.freeze, PROTOCOL_TCP = 'TCP'.freeze, PROTOCOL_UDP = 'UDP'.freeze ].freeze
Instance Attribute Summary collapse
-
#interval_in_millis ⇒ Integer
The interval between health checks, in milliseconds.
-
#port ⇒ Integer
The backend server port against which to run the health check.
-
#protocol ⇒ String
The protocol that the health check must use; either HTTP, UDP, or TCP.
-
#request_data ⇒ String
Base64 encoded pattern to be sent as UDP or TCP health check probe.
-
#response_body_regex ⇒ String
A regular expression for parsing the response body from the backend server.
-
#response_data ⇒ String
Base64 encoded pattern to be validated as UDP or TCP health check probe response.
-
#retries ⇒ Integer
The number of retries to attempt before a backend server is considered "unhealthy".
-
#return_code ⇒ Integer
The status code a healthy backend server should return.
-
#timeout_in_millis ⇒ Integer
The maximum time, in milliseconds, to wait for a reply to a health check.
-
#url_path ⇒ String
The path against which to run the health check.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateHealthCheckerDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateHealthCheckerDetails
Initializes the object
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/oci/network_load_balancer/models/update_health_checker_details.rb', line 136 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.protocol = attributes[:'protocol'] if attributes[:'protocol'] self.port = attributes[:'port'] if attributes[:'port'] self.retries = attributes[:'retries'] if attributes[:'retries'] self.timeout_in_millis = attributes[:'timeoutInMillis'] if attributes[:'timeoutInMillis'] raise 'You cannot provide both :timeoutInMillis and :timeout_in_millis' if attributes.key?(:'timeoutInMillis') && attributes.key?(:'timeout_in_millis') self.timeout_in_millis = attributes[:'timeout_in_millis'] if attributes[:'timeout_in_millis'] self.interval_in_millis = attributes[:'intervalInMillis'] if attributes[:'intervalInMillis'] raise 'You cannot provide both :intervalInMillis and :interval_in_millis' if attributes.key?(:'intervalInMillis') && attributes.key?(:'interval_in_millis') self.interval_in_millis = attributes[:'interval_in_millis'] if attributes[:'interval_in_millis'] self.url_path = attributes[:'urlPath'] if attributes[:'urlPath'] raise 'You cannot provide both :urlPath and :url_path' if attributes.key?(:'urlPath') && attributes.key?(:'url_path') self.url_path = attributes[:'url_path'] if attributes[:'url_path'] self.response_body_regex = attributes[:'responseBodyRegex'] if attributes[:'responseBodyRegex'] raise 'You cannot provide both :responseBodyRegex and :response_body_regex' if attributes.key?(:'responseBodyRegex') && attributes.key?(:'response_body_regex') self.response_body_regex = attributes[:'response_body_regex'] if attributes[:'response_body_regex'] self.return_code = attributes[:'returnCode'] if attributes[:'returnCode'] raise 'You cannot provide both :returnCode and :return_code' if attributes.key?(:'returnCode') && attributes.key?(:'return_code') self.return_code = attributes[:'return_code'] if attributes[:'return_code'] self.request_data = attributes[:'requestData'] if attributes[:'requestData'] raise 'You cannot provide both :requestData and :request_data' if attributes.key?(:'requestData') && attributes.key?(:'request_data') self.request_data = attributes[:'request_data'] if attributes[:'request_data'] self.response_data = attributes[:'responseData'] if attributes[:'responseData'] raise 'You cannot provide both :responseData and :response_data' if attributes.key?(:'responseData') && attributes.key?(:'response_data') self.response_data = attributes[:'response_data'] if attributes[:'response_data'] end |
Instance Attribute Details
#interval_in_millis ⇒ Integer
The interval between health checks, in milliseconds.
Example: 10000
52 53 54 |
# File 'lib/oci/network_load_balancer/models/update_health_checker_details.rb', line 52 def interval_in_millis @interval_in_millis end |
#port ⇒ Integer
The backend server port against which to run the health check.
Example: 8080
29 30 31 |
# File 'lib/oci/network_load_balancer/models/update_health_checker_details.rb', line 29 def port @port end |
#protocol ⇒ String
The protocol that the health check must use; either HTTP, UDP, or TCP.
Example: HTTP
22 23 24 |
# File 'lib/oci/network_load_balancer/models/update_health_checker_details.rb', line 22 def protocol @protocol end |
#request_data ⇒ String
Base64 encoded pattern to be sent as UDP or TCP health check probe.
78 79 80 |
# File 'lib/oci/network_load_balancer/models/update_health_checker_details.rb', line 78 def request_data @request_data end |
#response_body_regex ⇒ String
A regular expression for parsing the response body from the backend server.
Example: ‘^((?!false).|\s)*$`
66 67 68 |
# File 'lib/oci/network_load_balancer/models/update_health_checker_details.rb', line 66 def response_body_regex @response_body_regex end |
#response_data ⇒ String
Base64 encoded pattern to be validated as UDP or TCP health check probe response.
82 83 84 |
# File 'lib/oci/network_load_balancer/models/update_health_checker_details.rb', line 82 def response_data @response_data end |
#retries ⇒ Integer
The number of retries to attempt before a backend server is considered "unhealthy". This number also applies when recovering a server to the "healthy" state.
Example: 3
37 38 39 |
# File 'lib/oci/network_load_balancer/models/update_health_checker_details.rb', line 37 def retries @retries end |
#return_code ⇒ Integer
The status code a healthy backend server should return. If you configure the health check policy to use the HTTP protocol, then you can use common HTTP status codes such as "200".
Example: 200
74 75 76 |
# File 'lib/oci/network_load_balancer/models/update_health_checker_details.rb', line 74 def return_code @return_code end |
#timeout_in_millis ⇒ Integer
The maximum time, in milliseconds, to wait for a reply to a health check. A health check is successful only if a reply returns within this timeout period.
Example: 3000
45 46 47 |
# File 'lib/oci/network_load_balancer/models/update_health_checker_details.rb', line 45 def timeout_in_millis @timeout_in_millis end |
#url_path ⇒ String
The path against which to run the health check.
Example: /healthcheck
59 60 61 |
# File 'lib/oci/network_load_balancer/models/update_health_checker_details.rb', line 59 def url_path @url_path end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/oci/network_load_balancer/models/update_health_checker_details.rb', line 85 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'protocol': :'protocol', 'port': :'port', 'retries': :'retries', 'timeout_in_millis': :'timeoutInMillis', 'interval_in_millis': :'intervalInMillis', 'url_path': :'urlPath', 'response_body_regex': :'responseBodyRegex', 'return_code': :'returnCode', 'request_data': :'requestData', 'response_data': :'responseData' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/oci/network_load_balancer/models/update_health_checker_details.rb', line 103 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'protocol': :'String', 'port': :'Integer', 'retries': :'Integer', 'timeout_in_millis': :'Integer', 'interval_in_millis': :'Integer', 'url_path': :'String', 'response_body_regex': :'String', 'return_code': :'Integer', 'request_data': :'String', 'response_data': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/oci/network_load_balancer/models/update_health_checker_details.rb', line 206 def ==(other) return true if equal?(other) self.class == other.class && protocol == other.protocol && port == other.port && retries == other.retries && timeout_in_millis == other.timeout_in_millis && interval_in_millis == other.interval_in_millis && url_path == other.url_path && response_body_regex == other.response_body_regex && return_code == other.return_code && request_data == other.request_data && response_data == other.response_data end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'lib/oci/network_load_balancer/models/update_health_checker_details.rb', line 245 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
225 226 227 |
# File 'lib/oci/network_load_balancer/models/update_health_checker_details.rb', line 225 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
234 235 236 |
# File 'lib/oci/network_load_balancer/models/update_health_checker_details.rb', line 234 def hash [protocol, port, retries, timeout_in_millis, interval_in_millis, url_path, response_body_regex, return_code, request_data, response_data].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
278 279 280 281 282 283 284 285 286 287 |
# File 'lib/oci/network_load_balancer/models/update_health_checker_details.rb', line 278 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
272 273 274 |
# File 'lib/oci/network_load_balancer/models/update_health_checker_details.rb', line 272 def to_s to_hash.to_s end |