Class: OCI::NetworkLoadBalancer::Models::UpdateNetworkLoadBalancerDetails
- Inherits:
-
Object
- Object
- OCI::NetworkLoadBalancer::Models::UpdateNetworkLoadBalancerDetails
- Defined in:
- lib/oci/network_load_balancer/models/update_network_load_balancer_details.rb
Overview
Configuration details to update a network load balancer.
Caution: Oracle recommends that you avoid using any confidential information when you supply string values using the API.
Constant Summary collapse
- NLB_IP_VERSION_ENUM =
[ NLB_IP_VERSION_IPV4 = 'IPV4'.freeze, NLB_IP_VERSION_IPV4_AND_IPV6 = 'IPV4_AND_IPV6'.freeze ].freeze
Instance Attribute Summary collapse
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
The user-friendly display name for the network load balancer, which does not have to be unique and can be changed.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#is_preserve_source_destination ⇒ BOOLEAN
This parameter can be enabled only if backends are compute OCIDs.
-
#nlb_ip_version ⇒ String
IP version associated with the NLB.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateNetworkLoadBalancerDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateNetworkLoadBalancerDetails
Initializes the object
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/oci/network_load_balancer/models/update_network_load_balancer_details.rb', line 89 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.is_preserve_source_destination = attributes[:'isPreserveSourceDestination'] unless attributes[:'isPreserveSourceDestination'].nil? self.is_preserve_source_destination = false if is_preserve_source_destination.nil? && !attributes.key?(:'isPreserveSourceDestination') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isPreserveSourceDestination and :is_preserve_source_destination' if attributes.key?(:'isPreserveSourceDestination') && attributes.key?(:'is_preserve_source_destination') self.is_preserve_source_destination = attributes[:'is_preserve_source_destination'] unless attributes[:'is_preserve_source_destination'].nil? self.is_preserve_source_destination = false if is_preserve_source_destination.nil? && !attributes.key?(:'isPreserveSourceDestination') && !attributes.key?(:'is_preserve_source_destination') # rubocop:disable Style/StringLiterals self.nlb_ip_version = attributes[:'nlbIpVersion'] if attributes[:'nlbIpVersion'] self.nlb_ip_version = "IPV4" if nlb_ip_version.nil? && !attributes.key?(:'nlbIpVersion') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :nlbIpVersion and :nlb_ip_version' if attributes.key?(:'nlbIpVersion') && attributes.key?(:'nlb_ip_version') self.nlb_ip_version = attributes[:'nlb_ip_version'] if attributes[:'nlb_ip_version'] self.nlb_ip_version = "IPV4" if nlb_ip_version.nil? && !attributes.key?(:'nlbIpVersion') && !attributes.key?(:'nlb_ip_version') # rubocop:disable Style/StringLiterals self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
50 51 52 |
# File 'lib/oci/network_load_balancer/models/update_network_load_balancer_details.rb', line 50 def end |
#display_name ⇒ String
The user-friendly display name for the network load balancer, which does not have to be unique and can be changed. Avoid entering confidential information.
Example: example_network_load_balancer
24 25 26 |
# File 'lib/oci/network_load_balancer/models/update_network_load_balancer_details.rb', line 24 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
42 43 44 |
# File 'lib/oci/network_load_balancer/models/update_network_load_balancer_details.rb', line 42 def end |
#is_preserve_source_destination ⇒ BOOLEAN
This parameter can be enabled only if backends are compute OCIDs. When enabled, the skipSourceDestinationCheck parameter is automatically enabled on the load balancer VNIC, and packets are sent to the backend with the entire IP header intact.
30 31 32 |
# File 'lib/oci/network_load_balancer/models/update_network_load_balancer_details.rb', line 30 def is_preserve_source_destination @is_preserve_source_destination end |
#nlb_ip_version ⇒ String
IP version associated with the NLB.
34 35 36 |
# File 'lib/oci/network_load_balancer/models/update_network_load_balancer_details.rb', line 34 def nlb_ip_version @nlb_ip_version end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/oci/network_load_balancer/models/update_network_load_balancer_details.rb', line 53 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'is_preserve_source_destination': :'isPreserveSourceDestination', 'nlb_ip_version': :'nlbIpVersion', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/oci/network_load_balancer/models/update_network_load_balancer_details.rb', line 66 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'is_preserve_source_destination': :'BOOLEAN', 'nlb_ip_version': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
145 146 147 148 149 150 151 152 153 154 |
# File 'lib/oci/network_load_balancer/models/update_network_load_balancer_details.rb', line 145 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && is_preserve_source_destination == other.is_preserve_source_destination && nlb_ip_version == other.nlb_ip_version && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/oci/network_load_balancer/models/update_network_load_balancer_details.rb', line 179 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
159 160 161 |
# File 'lib/oci/network_load_balancer/models/update_network_load_balancer_details.rb', line 159 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
168 169 170 |
# File 'lib/oci/network_load_balancer/models/update_network_load_balancer_details.rb', line 168 def hash [display_name, is_preserve_source_destination, nlb_ip_version, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
212 213 214 215 216 217 218 219 220 221 |
# File 'lib/oci/network_load_balancer/models/update_network_load_balancer_details.rb', line 212 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
206 207 208 |
# File 'lib/oci/network_load_balancer/models/update_network_load_balancer_details.rb', line 206 def to_s to_hash.to_s end |