Class: OCI::Nosql::Models::TableCollection
- Inherits:
-
Object
- Object
- OCI::Nosql::Models::TableCollection
- Defined in:
- lib/oci/nosql/models/table_collection.rb
Overview
Results of ListTables.
Instance Attribute Summary collapse
-
#auto_reclaimable_tables ⇒ Integer
The current number of reclaimable tables in the tenancy.
-
#items ⇒ Array<OCI::Nosql::Models::TableSummary>
A page of TableSummary objects.
-
#max_auto_reclaimable_tables ⇒ Integer
The maximum number of reclaimable tables allowed in the tenancy.
-
#max_on_demand_capacity_tables ⇒ Integer
The maximum number of on demand capacity tables allowed in the tenancy.
-
#on_demand_capacity_tables ⇒ Integer
The current number of on demand capacity tables in the tenancy.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TableCollection
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ TableCollection
Initializes the object
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/oci/nosql/models/table_collection.rb', line 67 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.items = attributes[:'items'] if attributes[:'items'] self.max_auto_reclaimable_tables = attributes[:'maxAutoReclaimableTables'] if attributes[:'maxAutoReclaimableTables'] raise 'You cannot provide both :maxAutoReclaimableTables and :max_auto_reclaimable_tables' if attributes.key?(:'maxAutoReclaimableTables') && attributes.key?(:'max_auto_reclaimable_tables') self.max_auto_reclaimable_tables = attributes[:'max_auto_reclaimable_tables'] if attributes[:'max_auto_reclaimable_tables'] self.auto_reclaimable_tables = attributes[:'autoReclaimableTables'] if attributes[:'autoReclaimableTables'] raise 'You cannot provide both :autoReclaimableTables and :auto_reclaimable_tables' if attributes.key?(:'autoReclaimableTables') && attributes.key?(:'auto_reclaimable_tables') self.auto_reclaimable_tables = attributes[:'auto_reclaimable_tables'] if attributes[:'auto_reclaimable_tables'] self.on_demand_capacity_tables = attributes[:'onDemandCapacityTables'] if attributes[:'onDemandCapacityTables'] raise 'You cannot provide both :onDemandCapacityTables and :on_demand_capacity_tables' if attributes.key?(:'onDemandCapacityTables') && attributes.key?(:'on_demand_capacity_tables') self.on_demand_capacity_tables = attributes[:'on_demand_capacity_tables'] if attributes[:'on_demand_capacity_tables'] self.max_on_demand_capacity_tables = attributes[:'maxOnDemandCapacityTables'] if attributes[:'maxOnDemandCapacityTables'] raise 'You cannot provide both :maxOnDemandCapacityTables and :max_on_demand_capacity_tables' if attributes.key?(:'maxOnDemandCapacityTables') && attributes.key?(:'max_on_demand_capacity_tables') self.max_on_demand_capacity_tables = attributes[:'max_on_demand_capacity_tables'] if attributes[:'max_on_demand_capacity_tables'] end |
Instance Attribute Details
#auto_reclaimable_tables ⇒ Integer
The current number of reclaimable tables in the tenancy.
20 21 22 |
# File 'lib/oci/nosql/models/table_collection.rb', line 20 def auto_reclaimable_tables @auto_reclaimable_tables end |
#items ⇒ Array<OCI::Nosql::Models::TableSummary>
A page of TableSummary objects.
12 13 14 |
# File 'lib/oci/nosql/models/table_collection.rb', line 12 def items @items end |
#max_auto_reclaimable_tables ⇒ Integer
The maximum number of reclaimable tables allowed in the tenancy.
16 17 18 |
# File 'lib/oci/nosql/models/table_collection.rb', line 16 def max_auto_reclaimable_tables @max_auto_reclaimable_tables end |
#max_on_demand_capacity_tables ⇒ Integer
The maximum number of on demand capacity tables allowed in the tenancy.
28 29 30 |
# File 'lib/oci/nosql/models/table_collection.rb', line 28 def max_on_demand_capacity_tables @max_on_demand_capacity_tables end |
#on_demand_capacity_tables ⇒ Integer
The current number of on demand capacity tables in the tenancy.
24 25 26 |
# File 'lib/oci/nosql/models/table_collection.rb', line 24 def on_demand_capacity_tables @on_demand_capacity_tables end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 40 41 |
# File 'lib/oci/nosql/models/table_collection.rb', line 31 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'items': :'items', 'max_auto_reclaimable_tables': :'maxAutoReclaimableTables', 'auto_reclaimable_tables': :'autoReclaimableTables', 'on_demand_capacity_tables': :'onDemandCapacityTables', 'max_on_demand_capacity_tables': :'maxOnDemandCapacityTables' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/oci/nosql/models/table_collection.rb', line 44 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'items': :'Array<OCI::Nosql::Models::TableSummary>', 'max_auto_reclaimable_tables': :'Integer', 'auto_reclaimable_tables': :'Integer', 'on_demand_capacity_tables': :'Integer', 'max_on_demand_capacity_tables': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
107 108 109 110 111 112 113 114 115 116 |
# File 'lib/oci/nosql/models/table_collection.rb', line 107 def ==(other) return true if equal?(other) self.class == other.class && items == other.items && max_auto_reclaimable_tables == other.max_auto_reclaimable_tables && auto_reclaimable_tables == other.auto_reclaimable_tables && on_demand_capacity_tables == other.on_demand_capacity_tables && max_on_demand_capacity_tables == other.max_on_demand_capacity_tables end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/oci/nosql/models/table_collection.rb', line 141 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
121 122 123 |
# File 'lib/oci/nosql/models/table_collection.rb', line 121 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
130 131 132 |
# File 'lib/oci/nosql/models/table_collection.rb', line 130 def hash [items, max_auto_reclaimable_tables, auto_reclaimable_tables, on_demand_capacity_tables, max_on_demand_capacity_tables].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
174 175 176 177 178 179 180 181 182 183 |
# File 'lib/oci/nosql/models/table_collection.rb', line 174 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
168 169 170 |
# File 'lib/oci/nosql/models/table_collection.rb', line 168 def to_s to_hash.to_s end |