Class: ObjectStorage::Models::Bucket

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/object_storage/models/bucket.rb

Overview

A bucket is a container for storing objects in a compartment within a namespace. A bucket is associated with a single compartment. The compartment has policies that indicate what actions a user can perform on a bucket and all the objects in the bucket. For more information, see [Managing Buckets](docs.cloud.oracle.com/Content/Object/Tasks/managingbuckets.htm).

To use any of the API operations, you must be authorized in an IAM policy. If you are not authorized, talk to an administrator. If you are an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm).

Constant Summary collapse

PUBLIC_ACCESS_TYPE_ENUM =
[
  PUBLIC_ACCESS_TYPE_NO_PUBLIC_ACCESS = 'NoPublicAccess'.freeze,
  PUBLIC_ACCESS_TYPE_OBJECT_READ = 'ObjectRead'.freeze,
  PUBLIC_ACCESS_TYPE_OBJECT_READ_WITHOUT_LIST = 'ObjectReadWithoutList'.freeze,
  PUBLIC_ACCESS_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
STORAGE_TIER_ENUM =
[
  STORAGE_TIER_STANDARD = 'Standard'.freeze,
  STORAGE_TIER_ARCHIVE = 'Archive'.freeze,
  STORAGE_TIER_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
VERSIONING_ENUM =
[
  VERSIONING_ENABLED = 'Enabled'.freeze,
  VERSIONING_SUSPENDED = 'Suspended'.freeze,
  VERSIONING_DISABLED = 'Disabled'.freeze,
  VERSIONING_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
AUTO_TIERING_ENUM =
[
  AUTO_TIERING_DISABLED = 'Disabled'.freeze,
  AUTO_TIERING_INFREQUENT_ACCESS = 'InfrequentAccess'.freeze,
  AUTO_TIERING_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Bucket

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :namespace (String)

    The value to assign to the #namespace property

  • :name (String)

    The value to assign to the #name property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :metadata (Hash<String, String>)

    The value to assign to the #metadata property

  • :created_by (String)

    The value to assign to the #created_by property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :etag (String)

    The value to assign to the #etag property

  • :public_access_type (String)

    The value to assign to the #public_access_type property

  • :storage_tier (String)

    The value to assign to the #storage_tier property

  • :object_events_enabled (BOOLEAN)

    The value to assign to the #object_events_enabled property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property

  • :kms_key_id (String)

    The value to assign to the #kms_key_id property

  • :object_lifecycle_policy_etag (String)

    The value to assign to the #object_lifecycle_policy_etag property

  • :approximate_count (Integer)

    The value to assign to the #approximate_count property

  • :approximate_size (Integer)

    The value to assign to the #approximate_size property

  • :replication_enabled (BOOLEAN)

    The value to assign to the #replication_enabled property

  • :is_read_only (BOOLEAN)

    The value to assign to the #is_read_only property

  • :id (String)

    The value to assign to the #id property

  • :versioning (String)

    The value to assign to the #versioning property

  • :auto_tiering (String)

    The value to assign to the #auto_tiering property



249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'lib/oci/object_storage/models/bucket.rb', line 249

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.namespace = attributes[:'namespace'] if attributes[:'namespace']

  self.name = attributes[:'name'] if attributes[:'name']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self. = attributes[:'metadata'] if attributes[:'metadata']

  self.created_by = attributes[:'createdBy'] if attributes[:'createdBy']

  raise 'You cannot provide both :createdBy and :created_by' if attributes.key?(:'createdBy') && attributes.key?(:'created_by')

  self.created_by = attributes[:'created_by'] if attributes[:'created_by']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.etag = attributes[:'etag'] if attributes[:'etag']

  self.public_access_type = attributes[:'publicAccessType'] if attributes[:'publicAccessType']

  raise 'You cannot provide both :publicAccessType and :public_access_type' if attributes.key?(:'publicAccessType') && attributes.key?(:'public_access_type')

  self.public_access_type = attributes[:'public_access_type'] if attributes[:'public_access_type']

  self.storage_tier = attributes[:'storageTier'] if attributes[:'storageTier']

  raise 'You cannot provide both :storageTier and :storage_tier' if attributes.key?(:'storageTier') && attributes.key?(:'storage_tier')

  self.storage_tier = attributes[:'storage_tier'] if attributes[:'storage_tier']

  self.object_events_enabled = attributes[:'objectEventsEnabled'] unless attributes[:'objectEventsEnabled'].nil?

  raise 'You cannot provide both :objectEventsEnabled and :object_events_enabled' if attributes.key?(:'objectEventsEnabled') && attributes.key?(:'object_events_enabled')

  self.object_events_enabled = attributes[:'object_events_enabled'] unless attributes[:'object_events_enabled'].nil?

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.kms_key_id = attributes[:'kmsKeyId'] if attributes[:'kmsKeyId']

  raise 'You cannot provide both :kmsKeyId and :kms_key_id' if attributes.key?(:'kmsKeyId') && attributes.key?(:'kms_key_id')

  self.kms_key_id = attributes[:'kms_key_id'] if attributes[:'kms_key_id']

  self.object_lifecycle_policy_etag = attributes[:'objectLifecyclePolicyEtag'] if attributes[:'objectLifecyclePolicyEtag']

  raise 'You cannot provide both :objectLifecyclePolicyEtag and :object_lifecycle_policy_etag' if attributes.key?(:'objectLifecyclePolicyEtag') && attributes.key?(:'object_lifecycle_policy_etag')

  self.object_lifecycle_policy_etag = attributes[:'object_lifecycle_policy_etag'] if attributes[:'object_lifecycle_policy_etag']

  self.approximate_count = attributes[:'approximateCount'] if attributes[:'approximateCount']

  raise 'You cannot provide both :approximateCount and :approximate_count' if attributes.key?(:'approximateCount') && attributes.key?(:'approximate_count')

  self.approximate_count = attributes[:'approximate_count'] if attributes[:'approximate_count']

  self.approximate_size = attributes[:'approximateSize'] if attributes[:'approximateSize']

  raise 'You cannot provide both :approximateSize and :approximate_size' if attributes.key?(:'approximateSize') && attributes.key?(:'approximate_size')

  self.approximate_size = attributes[:'approximate_size'] if attributes[:'approximate_size']

  self.replication_enabled = attributes[:'replicationEnabled'] unless attributes[:'replicationEnabled'].nil?

  raise 'You cannot provide both :replicationEnabled and :replication_enabled' if attributes.key?(:'replicationEnabled') && attributes.key?(:'replication_enabled')

  self.replication_enabled = attributes[:'replication_enabled'] unless attributes[:'replication_enabled'].nil?

  self.is_read_only = attributes[:'isReadOnly'] unless attributes[:'isReadOnly'].nil?

  raise 'You cannot provide both :isReadOnly and :is_read_only' if attributes.key?(:'isReadOnly') && attributes.key?(:'is_read_only')

  self.is_read_only = attributes[:'is_read_only'] unless attributes[:'is_read_only'].nil?

  self.id = attributes[:'id'] if attributes[:'id']

  self.versioning = attributes[:'versioning'] if attributes[:'versioning']

  self.auto_tiering = attributes[:'autoTiering'] if attributes[:'autoTiering']

  raise 'You cannot provide both :autoTiering and :auto_tiering' if attributes.key?(:'autoTiering') && attributes.key?(:'auto_tiering')

  self.auto_tiering = attributes[:'auto_tiering'] if attributes[:'auto_tiering']
end

Instance Attribute Details

#approximate_countInteger

The approximate number of objects in the bucket. Count statistics are reported periodically. You will see a lag between what is displayed and the actual object count.

Returns:

  • (Integer)


126
127
128
# File 'lib/oci/object_storage/models/bucket.rb', line 126

def approximate_count
  @approximate_count
end

#approximate_sizeInteger

The approximate total size in bytes of all objects in the bucket. Size statistics are reported periodically. You will see a lag between what is displayed and the actual size of the bucket.

Returns:

  • (Integer)


132
133
134
# File 'lib/oci/object_storage/models/bucket.rb', line 132

def approximate_size
  @approximate_size
end

#auto_tieringString

The auto tiering status on the bucket. A bucket is created with auto tiering `Disabled` by default. For auto tiering `InfrequentAccess`, objects are transitioned automatically between the 'Standard' and 'InfrequentAccess' tiers based on the access pattern of the objects.

Returns:

  • (String)


162
163
164
# File 'lib/oci/object_storage/models/bucket.rb', line 162

def auto_tiering
  @auto_tiering
end

#compartment_idString

**[Required]** The compartment ID in which the bucket is authorized.

Returns:

  • (String)


56
57
58
# File 'lib/oci/object_storage/models/bucket.rb', line 56

def compartment_id
  @compartment_id
end

#created_byString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the user who created the bucket.

Returns:

  • (String)


64
65
66
# File 'lib/oci/object_storage/models/bucket.rb', line 64

def created_by
  @created_by
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


110
111
112
# File 'lib/oci/object_storage/models/bucket.rb', line 110

def defined_tags
  @defined_tags
end

#etagString

**[Required]** The entity tag (ETag) for the bucket.

Returns:

  • (String)


72
73
74
# File 'lib/oci/object_storage/models/bucket.rb', line 72

def etag
  @etag
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `"Finance"`

Returns:

  • (Hash<String, String>)


103
104
105
# File 'lib/oci/object_storage/models/bucket.rb', line 103

def freeform_tags
  @freeform_tags
end

#idString

Returns:

  • (String)


149
150
151
# File 'lib/oci/object_storage/models/bucket.rb', line 149

def id
  @id
end

#is_read_onlyBOOLEAN

Whether or not this bucket is read only. By default, `isReadOnly` is set to `false`. This will be set to 'true' when this bucket is configured as a destination in a replication policy.

Returns:

  • (BOOLEAN)


144
145
146
# File 'lib/oci/object_storage/models/bucket.rb', line 144

def is_read_only
  @is_read_only
end

#kms_key_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of a master encryption key used to call the Key Management service to generate a data encryption key or to encrypt or decrypt a data encryption key.

Returns:

  • (String)


116
117
118
# File 'lib/oci/object_storage/models/bucket.rb', line 116

def kms_key_id
  @kms_key_id
end

#metadataHash<String, String>

**[Required]** Arbitrary string keys and values for user-defined metadata.

Returns:

  • (Hash<String, String>)


60
61
62
# File 'lib/oci/object_storage/models/bucket.rb', line 60

def 
  @metadata
end

#nameString

**[Required]** The name of the bucket. Avoid entering confidential information. Example: my-new-bucket1

Returns:

  • (String)


52
53
54
# File 'lib/oci/object_storage/models/bucket.rb', line 52

def name
  @name
end

#namespaceString

**[Required]** The Object Storage namespace in which the bucket resides.

Returns:

  • (String)


46
47
48
# File 'lib/oci/object_storage/models/bucket.rb', line 46

def namespace
  @namespace
end

#object_events_enabledBOOLEAN

Whether or not events are emitted for object state changes in this bucket. By default, `objectEventsEnabled` is set to `false`. Set `objectEventsEnabled` to `true` to emit events for object state changes. For more information about events, see [Overview of Events](docs.cloud.oracle.com/Content/Events/Concepts/eventsoverview.htm).

Returns:

  • (BOOLEAN)


96
97
98
# File 'lib/oci/object_storage/models/bucket.rb', line 96

def object_events_enabled
  @object_events_enabled
end

#object_lifecycle_policy_etagString

The entity tag (ETag) for the live object lifecycle policy on the bucket.

Returns:

  • (String)


120
121
122
# File 'lib/oci/object_storage/models/bucket.rb', line 120

def object_lifecycle_policy_etag
  @object_lifecycle_policy_etag
end

#public_access_typeString

The type of public access enabled on this bucket. A bucket is set to `NoPublicAccess` by default, which only allows an authenticated caller to access the bucket and its contents. When `ObjectRead` is enabled on the bucket, public access is allowed for the `GetObject`, `HeadObject`, and `ListObjects` operations. When `ObjectReadWithoutList` is enabled on the bucket, public access is allowed for the `GetObject` and `HeadObject` operations.

Returns:

  • (String)


81
82
83
# File 'lib/oci/object_storage/models/bucket.rb', line 81

def public_access_type
  @public_access_type
end

#replication_enabledBOOLEAN

Whether or not this bucket is a replication source. By default, `replicationEnabled` is set to `false`. This will be set to 'true' when you create a replication policy for the bucket.

Returns:

  • (BOOLEAN)


138
139
140
# File 'lib/oci/object_storage/models/bucket.rb', line 138

def replication_enabled
  @replication_enabled
end

#storage_tierString

The storage tier type assigned to the bucket. A bucket is set to `Standard` tier by default, which means objects uploaded or copied to the bucket will be in the standard storage tier. When the `Archive` tier type is set explicitly for a bucket, objects uploaded or copied to the bucket will be stored in archive storage. The `storageTier` property is immutable after bucket is created.

Returns:

  • (String)


89
90
91
# File 'lib/oci/object_storage/models/bucket.rb', line 89

def storage_tier
  @storage_tier
end

#time_createdDateTime

**[Required]** The date and time the bucket was created, as described in [RFC 2616](tools.ietf.org/html/rfc2616#section-14.29).

Returns:

  • (DateTime)


68
69
70
# File 'lib/oci/object_storage/models/bucket.rb', line 68

def time_created
  @time_created
end

#versioningString

The versioning status on the bucket. A bucket is created with versioning `Disabled` by default. For versioning `Enabled`, objects are protected from overwrites and deletes, by maintaining their version history. When versioning is `Suspended`, the previous versions will still remain but new versions will no longer be created when overwitten or deleted.

Returns:

  • (String)


155
156
157
# File 'lib/oci/object_storage/models/bucket.rb', line 155

def versioning
  @versioning
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/oci/object_storage/models/bucket.rb', line 165

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'namespace': :'namespace',
    'name': :'name',
    'compartment_id': :'compartmentId',
    'metadata': :'metadata',
    'created_by': :'createdBy',
    'time_created': :'timeCreated',
    'etag': :'etag',
    'public_access_type': :'publicAccessType',
    'storage_tier': :'storageTier',
    'object_events_enabled': :'objectEventsEnabled',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'kms_key_id': :'kmsKeyId',
    'object_lifecycle_policy_etag': :'objectLifecyclePolicyEtag',
    'approximate_count': :'approximateCount',
    'approximate_size': :'approximateSize',
    'replication_enabled': :'replicationEnabled',
    'is_read_only': :'isReadOnly',
    'id': :'id',
    'versioning': :'versioning',
    'auto_tiering': :'autoTiering'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/oci/object_storage/models/bucket.rb', line 194

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'namespace': :'String',
    'name': :'String',
    'compartment_id': :'String',
    'metadata': :'Hash<String, String>',
    'created_by': :'String',
    'time_created': :'DateTime',
    'etag': :'String',
    'public_access_type': :'String',
    'storage_tier': :'String',
    'object_events_enabled': :'BOOLEAN',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'kms_key_id': :'String',
    'object_lifecycle_policy_etag': :'String',
    'approximate_count': :'Integer',
    'approximate_size': :'Integer',
    'replication_enabled': :'BOOLEAN',
    'is_read_only': :'BOOLEAN',
    'id': :'String',
    'versioning': :'String',
    'auto_tiering': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
# File 'lib/oci/object_storage/models/bucket.rb', line 417

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    namespace == other.namespace &&
    name == other.name &&
    compartment_id == other.compartment_id &&
     == other. &&
    created_by == other.created_by &&
    time_created == other.time_created &&
    etag == other.etag &&
    public_access_type == other.public_access_type &&
    storage_tier == other.storage_tier &&
    object_events_enabled == other.object_events_enabled &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    kms_key_id == other.kms_key_id &&
    object_lifecycle_policy_etag == other.object_lifecycle_policy_etag &&
    approximate_count == other.approximate_count &&
    approximate_size == other.approximate_size &&
    replication_enabled == other.replication_enabled &&
    is_read_only == other.is_read_only &&
    id == other.id &&
    versioning == other.versioning &&
    auto_tiering == other.auto_tiering
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
# File 'lib/oci/object_storage/models/bucket.rb', line 467

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


447
448
449
# File 'lib/oci/object_storage/models/bucket.rb', line 447

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



456
457
458
# File 'lib/oci/object_storage/models/bucket.rb', line 456

def hash
  [namespace, name, compartment_id, , created_by, time_created, etag, public_access_type, storage_tier, object_events_enabled, freeform_tags, defined_tags, kms_key_id, object_lifecycle_policy_etag, approximate_count, approximate_size, replication_enabled, is_read_only, id, versioning, auto_tiering].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



500
501
502
503
504
505
506
507
508
509
# File 'lib/oci/object_storage/models/bucket.rb', line 500

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



494
495
496
# File 'lib/oci/object_storage/models/bucket.rb', line 494

def to_s
  to_hash.to_s
end