Class: OCI::ObjectStorage::Models::CopyObjectDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/object_storage/models/copy_object_details.rb

Overview

To use any of the API operations, you must be authorized in an IAM policy. If you’re not authorized, talk to an administrator. If you’re an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.us-phoenix-1.oraclecloud.com/Content/Identity/Concepts/policygetstarted.htm).

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CopyObjectDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/oci/object_storage/models/copy_object_details.rb', line 101

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.source_object_name = attributes[:'sourceObjectName'] if attributes[:'sourceObjectName']

  raise 'You cannot provide both :sourceObjectName and :source_object_name' if attributes.key?(:'sourceObjectName') && attributes.key?(:'source_object_name')

  self.source_object_name = attributes[:'source_object_name'] if attributes[:'source_object_name']

  self.source_object_if_match_e_tag = attributes[:'sourceObjectIfMatchETag'] if attributes[:'sourceObjectIfMatchETag']

  raise 'You cannot provide both :sourceObjectIfMatchETag and :source_object_if_match_e_tag' if attributes.key?(:'sourceObjectIfMatchETag') && attributes.key?(:'source_object_if_match_e_tag')

  self.source_object_if_match_e_tag = attributes[:'source_object_if_match_e_tag'] if attributes[:'source_object_if_match_e_tag']

  self.destination_region = attributes[:'destinationRegion'] if attributes[:'destinationRegion']

  raise 'You cannot provide both :destinationRegion and :destination_region' if attributes.key?(:'destinationRegion') && attributes.key?(:'destination_region')

  self.destination_region = attributes[:'destination_region'] if attributes[:'destination_region']

  self.destination_namespace = attributes[:'destinationNamespace'] if attributes[:'destinationNamespace']

  raise 'You cannot provide both :destinationNamespace and :destination_namespace' if attributes.key?(:'destinationNamespace') && attributes.key?(:'destination_namespace')

  self.destination_namespace = attributes[:'destination_namespace'] if attributes[:'destination_namespace']

  self.destination_bucket = attributes[:'destinationBucket'] if attributes[:'destinationBucket']

  raise 'You cannot provide both :destinationBucket and :destination_bucket' if attributes.key?(:'destinationBucket') && attributes.key?(:'destination_bucket')

  self.destination_bucket = attributes[:'destination_bucket'] if attributes[:'destination_bucket']

  self.destination_object_name = attributes[:'destinationObjectName'] if attributes[:'destinationObjectName']

  raise 'You cannot provide both :destinationObjectName and :destination_object_name' if attributes.key?(:'destinationObjectName') && attributes.key?(:'destination_object_name')

  self.destination_object_name = attributes[:'destination_object_name'] if attributes[:'destination_object_name']

  self.destination_object_if_match_e_tag = attributes[:'destinationObjectIfMatchETag'] if attributes[:'destinationObjectIfMatchETag']

  raise 'You cannot provide both :destinationObjectIfMatchETag and :destination_object_if_match_e_tag' if attributes.key?(:'destinationObjectIfMatchETag') && attributes.key?(:'destination_object_if_match_e_tag')

  self.destination_object_if_match_e_tag = attributes[:'destination_object_if_match_e_tag'] if attributes[:'destination_object_if_match_e_tag']

  self.destination_object_if_none_match_e_tag = attributes[:'destinationObjectIfNoneMatchETag'] if attributes[:'destinationObjectIfNoneMatchETag']

  raise 'You cannot provide both :destinationObjectIfNoneMatchETag and :destination_object_if_none_match_e_tag' if attributes.key?(:'destinationObjectIfNoneMatchETag') && attributes.key?(:'destination_object_if_none_match_e_tag')

  self.destination_object_if_none_match_e_tag = attributes[:'destination_object_if_none_match_e_tag'] if attributes[:'destination_object_if_none_match_e_tag']

  self. = attributes[:'destinationObjectMetadata'] if attributes[:'destinationObjectMetadata']

  raise 'You cannot provide both :destinationObjectMetadata and :destination_object_metadata' if attributes.key?(:'destinationObjectMetadata') && attributes.key?(:'destination_object_metadata')

  self. = attributes[:'destination_object_metadata'] if attributes[:'destination_object_metadata']
end

Instance Attribute Details

#destination_bucketString

[Required] The destination bucket object will be copied to.

Returns:

  • (String)


30
31
32
# File 'lib/oci/object_storage/models/copy_object_details.rb', line 30

def destination_bucket
  @destination_bucket
end

#destination_namespaceString

[Required] The destination namespace object will be copied to.

Returns:

  • (String)


26
27
28
# File 'lib/oci/object_storage/models/copy_object_details.rb', line 26

def destination_namespace
  @destination_namespace
end

#destination_object_if_match_e_tagString

The entity tag to match the target object.

Returns:

  • (String)


38
39
40
# File 'lib/oci/object_storage/models/copy_object_details.rb', line 38

def destination_object_if_match_e_tag
  @destination_object_if_match_e_tag
end

#destination_object_if_none_match_e_tagString

The entity tag to not match the target object.

Returns:

  • (String)


42
43
44
# File 'lib/oci/object_storage/models/copy_object_details.rb', line 42

def destination_object_if_none_match_e_tag
  @destination_object_if_none_match_e_tag
end

#destination_object_metadataHash<String, String>

Arbitrary string keys and values for the user-defined metadata for the object. Keys must be in "opc-meta-*" format. Avoid entering confidential information. If user enter value in this field, the value will become the object metadata for destination Object. If no value pass in, the destination object will have the exact object metadata as source object.

Returns:

  • (Hash<String, String>)


50
51
52
# File 'lib/oci/object_storage/models/copy_object_details.rb', line 50

def 
  
end

#destination_object_nameString

[Required] The destination name for the copy object.

Returns:

  • (String)


34
35
36
# File 'lib/oci/object_storage/models/copy_object_details.rb', line 34

def destination_object_name
  @destination_object_name
end

#destination_regionString

[Required] The destination region object will be copied to. Please specify name of the region, for example "us-ashburn-1".

Returns:

  • (String)


22
23
24
# File 'lib/oci/object_storage/models/copy_object_details.rb', line 22

def destination_region
  @destination_region
end

#source_object_if_match_e_tagString

The entity tag to match the target object.

Returns:

  • (String)


18
19
20
# File 'lib/oci/object_storage/models/copy_object_details.rb', line 18

def source_object_if_match_e_tag
  @source_object_if_match_e_tag
end

#source_object_nameString

[Required] The name of the object to be copied

Returns:

  • (String)


14
15
16
# File 'lib/oci/object_storage/models/copy_object_details.rb', line 14

def source_object_name
  @source_object_name
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/oci/object_storage/models/copy_object_details.rb', line 53

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'source_object_name': :'sourceObjectName',
    'source_object_if_match_e_tag': :'sourceObjectIfMatchETag',
    'destination_region': :'destinationRegion',
    'destination_namespace': :'destinationNamespace',
    'destination_bucket': :'destinationBucket',
    'destination_object_name': :'destinationObjectName',
    'destination_object_if_match_e_tag': :'destinationObjectIfMatchETag',
    'destination_object_if_none_match_e_tag': :'destinationObjectIfNoneMatchETag',
    'destination_object_metadata': :'destinationObjectMetadata'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/oci/object_storage/models/copy_object_details.rb', line 70

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'source_object_name': :'String',
    'source_object_if_match_e_tag': :'String',
    'destination_region': :'String',
    'destination_namespace': :'String',
    'destination_bucket': :'String',
    'destination_object_name': :'String',
    'destination_object_if_match_e_tag': :'String',
    'destination_object_if_none_match_e_tag': :'String',
    'destination_object_metadata': :'Hash<String, String>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



169
170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/oci/object_storage/models/copy_object_details.rb', line 169

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    source_object_name == other.source_object_name &&
    source_object_if_match_e_tag == other.source_object_if_match_e_tag &&
    destination_region == other.destination_region &&
    destination_namespace == other.destination_namespace &&
    destination_bucket == other.destination_bucket &&
    destination_object_name == other.destination_object_name &&
    destination_object_if_match_e_tag == other.destination_object_if_match_e_tag &&
    destination_object_if_none_match_e_tag == other.destination_object_if_none_match_e_tag &&
     == other.
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/oci/object_storage/models/copy_object_details.rb', line 207

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


187
188
189
# File 'lib/oci/object_storage/models/copy_object_details.rb', line 187

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



196
197
198
# File 'lib/oci/object_storage/models/copy_object_details.rb', line 196

def hash
  [source_object_name, source_object_if_match_e_tag, destination_region, destination_namespace, destination_bucket, destination_object_name, destination_object_if_match_e_tag, destination_object_if_none_match_e_tag, ].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



240
241
242
243
244
245
246
247
248
249
# File 'lib/oci/object_storage/models/copy_object_details.rb', line 240

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



234
235
236
# File 'lib/oci/object_storage/models/copy_object_details.rb', line 234

def to_s
  to_hash.to_s
end