Method: OCI::ObjectStorage::Models::CopyObjectDetails#destination_object_metadata
- Defined in:
- lib/oci/object_storage/models/copy_object_details.rb
#destination_object_metadata ⇒ Hash<String, String>
Arbitrary string keys and values for the user-defined metadata for the object. Keys must be in "opc-meta-*" format. Avoid entering confidential information. Metadata key-value pairs entered in this field are assigned to the destination object. If you enter no metadata values, the destination object will inherit any existing metadata values associated with the source object.
70 71 72 |
# File 'lib/oci/object_storage/models/copy_object_details.rb', line 70 def end |