Class: OCI::ObjectStorage::Models::CreateBucketDetails
- Inherits:
-
Object
- Object
- OCI::ObjectStorage::Models::CreateBucketDetails
- Defined in:
- lib/oci/object_storage/models/create_bucket_details.rb
Overview
To use any of the API operations, you must be authorized in an IAM policy. If you are not authorized, talk to an administrator. If you are an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm).
Constant Summary collapse
- PUBLIC_ACCESS_TYPE_ENUM =
[ PUBLIC_ACCESS_TYPE_NO_PUBLIC_ACCESS = 'NoPublicAccess'.freeze, PUBLIC_ACCESS_TYPE_OBJECT_READ = 'ObjectRead'.freeze, PUBLIC_ACCESS_TYPE_OBJECT_READ_WITHOUT_LIST = 'ObjectReadWithoutList'.freeze ].freeze
- STORAGE_TIER_ENUM =
[ STORAGE_TIER_STANDARD = 'Standard'.freeze, STORAGE_TIER_ARCHIVE = 'Archive'.freeze ].freeze
- VERSIONING_ENUM =
[ VERSIONING_ENABLED = 'Enabled'.freeze, VERSIONING_DISABLED = 'Disabled'.freeze ].freeze
Instance Attribute Summary collapse
-
#auto_tiering ⇒ String
Set the auto tiering status on the bucket.
-
#compartment_id ⇒ String
[Required] The ID of the compartment in which to create the bucket.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#kms_key_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of a master encryption key used to call the Key Management service to generate a data encryption key or to encrypt or decrypt a data encryption key.
-
#metadata ⇒ Hash<String, String>
Arbitrary string, up to 4KB, of keys and values for user-defined metadata.
-
#name ⇒ String
[Required] The name of the bucket.
-
#object_events_enabled ⇒ BOOLEAN
Whether or not events are emitted for object state changes in this bucket.
-
#public_access_type ⇒ String
The type of public access enabled on this bucket.
-
#storage_tier ⇒ String
The type of storage tier of this bucket.
-
#versioning ⇒ String
Set the versioning status on the bucket.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateBucketDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateBucketDetails
Initializes the object
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/oci/object_storage/models/create_bucket_details.rb', line 156 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self. = attributes[:'metadata'] if attributes[:'metadata'] self.public_access_type = attributes[:'publicAccessType'] if attributes[:'publicAccessType'] raise 'You cannot provide both :publicAccessType and :public_access_type' if attributes.key?(:'publicAccessType') && attributes.key?(:'public_access_type') self.public_access_type = attributes[:'public_access_type'] if attributes[:'public_access_type'] self.storage_tier = attributes[:'storageTier'] if attributes[:'storageTier'] raise 'You cannot provide both :storageTier and :storage_tier' if attributes.key?(:'storageTier') && attributes.key?(:'storage_tier') self.storage_tier = attributes[:'storage_tier'] if attributes[:'storage_tier'] self.object_events_enabled = attributes[:'objectEventsEnabled'] unless attributes[:'objectEventsEnabled'].nil? raise 'You cannot provide both :objectEventsEnabled and :object_events_enabled' if attributes.key?(:'objectEventsEnabled') && attributes.key?(:'object_events_enabled') self.object_events_enabled = attributes[:'object_events_enabled'] unless attributes[:'object_events_enabled'].nil? self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.kms_key_id = attributes[:'kmsKeyId'] if attributes[:'kmsKeyId'] raise 'You cannot provide both :kmsKeyId and :kms_key_id' if attributes.key?(:'kmsKeyId') && attributes.key?(:'kms_key_id') self.kms_key_id = attributes[:'kms_key_id'] if attributes[:'kms_key_id'] self.versioning = attributes[:'versioning'] if attributes[:'versioning'] self.auto_tiering = attributes[:'autoTiering'] if attributes[:'autoTiering'] raise 'You cannot provide both :autoTiering and :auto_tiering' if attributes.key?(:'autoTiering') && attributes.key?(:'auto_tiering') self.auto_tiering = attributes[:'auto_tiering'] if attributes[:'auto_tiering'] end |
Instance Attribute Details
#auto_tiering ⇒ String
Set the auto tiering status on the bucket. By default, a bucket is created with auto tiering Disabled. Use this option to enable auto tiering during bucket creation. Objects in a bucket with auto tiering set to InfrequentAccess are transitioned automatically between the ‘Standard’ and ‘InfrequentAccess’ tiers based on the access pattern of the objects.
99 100 101 |
# File 'lib/oci/object_storage/models/create_bucket_details.rb', line 99 def auto_tiering @auto_tiering end |
#compartment_id ⇒ String
[Required] The ID of the compartment in which to create the bucket.
38 39 40 |
# File 'lib/oci/object_storage/models/create_bucket_details.rb', line 38 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"CostCenter": "42"}`
80 81 82 |
# File 'lib/oci/object_storage/models/create_bucket_details.rb', line 80 def @defined_tags end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"Finance"`
73 74 75 |
# File 'lib/oci/object_storage/models/create_bucket_details.rb', line 73 def @freeform_tags end |
#kms_key_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of a master encryption key used to call the Key Management service to generate a data encryption key or to encrypt or decrypt a data encryption key.
86 87 88 |
# File 'lib/oci/object_storage/models/create_bucket_details.rb', line 86 def kms_key_id @kms_key_id end |
#metadata ⇒ Hash<String, String>
Arbitrary string, up to 4KB, of keys and values for user-defined metadata.
42 43 44 |
# File 'lib/oci/object_storage/models/create_bucket_details.rb', line 42 def @metadata end |
#name ⇒ String
[Required] The name of the bucket. Valid characters are uppercase or lowercase letters, numbers, hyphens, underscores, and periods. Bucket names must be unique within an Object Storage namespace. Avoid entering confidential information. example: Example: my-new-bucket1
34 35 36 |
# File 'lib/oci/object_storage/models/create_bucket_details.rb', line 34 def name @name end |
#object_events_enabled ⇒ BOOLEAN
Whether or not events are emitted for object state changes in this bucket. By default, objectEventsEnabled is set to false. Set objectEventsEnabled to true to emit events for object state changes. For more information about events, see [Overview of Events](docs.cloud.oracle.com/Content/Events/Concepts/eventsoverview.htm).
66 67 68 |
# File 'lib/oci/object_storage/models/create_bucket_details.rb', line 66 def object_events_enabled @object_events_enabled end |
#public_access_type ⇒ String
The type of public access enabled on this bucket. A bucket is set to NoPublicAccess by default, which only allows an authenticated caller to access the bucket and its contents. When ObjectRead is enabled on the bucket, public access is allowed for the GetObject, HeadObject, and ListObjects operations. When ObjectReadWithoutList is enabled on the bucket, public access is allowed for the GetObject and HeadObject operations.
51 52 53 |
# File 'lib/oci/object_storage/models/create_bucket_details.rb', line 51 def public_access_type @public_access_type end |
#storage_tier ⇒ String
The type of storage tier of this bucket. A bucket is set to ‘Standard’ tier by default, which means the bucket will be put in the standard storage tier. When ‘Archive’ tier type is set explicitly, the bucket is put in the Archive Storage tier. The ‘storageTier’ property is immutable after bucket is created.
59 60 61 |
# File 'lib/oci/object_storage/models/create_bucket_details.rb', line 59 def storage_tier @storage_tier end |
#versioning ⇒ String
Set the versioning status on the bucket. By default, a bucket is created with versioning Disabled. Use this option to enable versioning during bucket creation. Objects in a version enabled bucket are protected from overwrites and deletions. Previous versions of the same object will be available in the bucket.
91 92 93 |
# File 'lib/oci/object_storage/models/create_bucket_details.rb', line 91 def versioning @versioning end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/oci/object_storage/models/create_bucket_details.rb', line 102 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'compartment_id': :'compartmentId', 'metadata': :'metadata', 'public_access_type': :'publicAccessType', 'storage_tier': :'storageTier', 'object_events_enabled': :'objectEventsEnabled', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'kms_key_id': :'kmsKeyId', 'versioning': :'versioning', 'auto_tiering': :'autoTiering' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/oci/object_storage/models/create_bucket_details.rb', line 121 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'compartment_id': :'String', 'metadata': :'Hash<String, String>', 'public_access_type': :'String', 'storage_tier': :'String', 'object_events_enabled': :'BOOLEAN', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'kms_key_id': :'String', 'versioning': :'String', 'auto_tiering': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 |
# File 'lib/oci/object_storage/models/create_bucket_details.rb', line 248 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && compartment_id == other.compartment_id && == other. && public_access_type == other.public_access_type && storage_tier == other.storage_tier && object_events_enabled == other.object_events_enabled && == other. && == other. && kms_key_id == other.kms_key_id && versioning == other.versioning && auto_tiering == other.auto_tiering end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 |
# File 'lib/oci/object_storage/models/create_bucket_details.rb', line 288 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
268 269 270 |
# File 'lib/oci/object_storage/models/create_bucket_details.rb', line 268 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
277 278 279 |
# File 'lib/oci/object_storage/models/create_bucket_details.rb', line 277 def hash [name, compartment_id, , public_access_type, storage_tier, object_events_enabled, , , kms_key_id, versioning, auto_tiering].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
321 322 323 324 325 326 327 328 329 330 |
# File 'lib/oci/object_storage/models/create_bucket_details.rb', line 321 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
315 316 317 |
# File 'lib/oci/object_storage/models/create_bucket_details.rb', line 315 def to_s to_hash.to_s end |