Class: OCI::ObjectStorage::Models::CreateMultipartUploadDetails
- Inherits:
-
Object
- Object
- OCI::ObjectStorage::Models::CreateMultipartUploadDetails
- Defined in:
- lib/oci/object_storage/models/create_multipart_upload_details.rb
Overview
To use any of the API operations, you must be authorized in an IAM policy. If you are not authorized, talk to an administrator. If you are an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm).
Constant Summary collapse
- STORAGE_TIER_ENUM =
[ STORAGE_TIER_STANDARD = 'Standard'.freeze, STORAGE_TIER_INFREQUENT_ACCESS = 'InfrequentAccess'.freeze, STORAGE_TIER_ARCHIVE = 'Archive'.freeze ].freeze
Instance Attribute Summary collapse
-
#cache_control ⇒ String
The optional Cache-Control header that defines the caching behavior value to be returned in GetObject and HeadObject responses.
-
#content_disposition ⇒ String
The optional Content-Disposition header that defines presentational information for the object to be returned in GetObject and HeadObject responses.
-
#content_encoding ⇒ String
The optional Content-Encoding header that defines the content encodings that were applied to the object to upload.
-
#content_language ⇒ String
The optional Content-Language header that defines the content language of the object to upload.
-
#content_type ⇒ String
The optional Content-Type header that defines the standard MIME type format of the object to upload.
-
#metadata ⇒ Hash<String, String>
Arbitrary string keys and values for the user-defined metadata for the object.
-
#object ⇒ String
[Required] The name of the object to which this multi-part upload is targeted.
-
#storage_tier ⇒ String
The storage tier that the object should be stored in.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateMultipartUploadDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateMultipartUploadDetails
Initializes the object
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/oci/object_storage/models/create_multipart_upload_details.rb', line 124 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.object = attributes[:'object'] if attributes[:'object'] self.content_type = attributes[:'contentType'] if attributes[:'contentType'] raise 'You cannot provide both :contentType and :content_type' if attributes.key?(:'contentType') && attributes.key?(:'content_type') self.content_type = attributes[:'content_type'] if attributes[:'content_type'] self.content_language = attributes[:'contentLanguage'] if attributes[:'contentLanguage'] raise 'You cannot provide both :contentLanguage and :content_language' if attributes.key?(:'contentLanguage') && attributes.key?(:'content_language') self.content_language = attributes[:'content_language'] if attributes[:'content_language'] self.content_encoding = attributes[:'contentEncoding'] if attributes[:'contentEncoding'] raise 'You cannot provide both :contentEncoding and :content_encoding' if attributes.key?(:'contentEncoding') && attributes.key?(:'content_encoding') self.content_encoding = attributes[:'content_encoding'] if attributes[:'content_encoding'] self.content_disposition = attributes[:'contentDisposition'] if attributes[:'contentDisposition'] raise 'You cannot provide both :contentDisposition and :content_disposition' if attributes.key?(:'contentDisposition') && attributes.key?(:'content_disposition') self.content_disposition = attributes[:'content_disposition'] if attributes[:'content_disposition'] self.cache_control = attributes[:'cacheControl'] if attributes[:'cacheControl'] raise 'You cannot provide both :cacheControl and :cache_control' if attributes.key?(:'cacheControl') && attributes.key?(:'cache_control') self.cache_control = attributes[:'cache_control'] if attributes[:'cache_control'] self.storage_tier = attributes[:'storageTier'] if attributes[:'storageTier'] raise 'You cannot provide both :storageTier and :storage_tier' if attributes.key?(:'storageTier') && attributes.key?(:'storage_tier') self.storage_tier = attributes[:'storage_tier'] if attributes[:'storage_tier'] self. = attributes[:'metadata'] if attributes[:'metadata'] end |
Instance Attribute Details
#cache_control ⇒ String
The optional Cache-Control header that defines the caching behavior value to be returned in GetObject and HeadObject responses. Specifying values for this header has no effect on Object Storage behavior. Programs that read the object determine what to do based on the value provided. For example, you could use this header to identify objects that require caching restrictions.
64 65 66 |
# File 'lib/oci/object_storage/models/create_multipart_upload_details.rb', line 64 def cache_control @cache_control end |
#content_disposition ⇒ String
The optional Content-Disposition header that defines presentational information for the object to be returned in GetObject and HeadObject responses. Specifying values for this header has no effect on Object Storage behavior. Programs that read the object determine what to do based on the value provided. For example, you could use this header to let users download objects with custom filenames in a browser.
56 57 58 |
# File 'lib/oci/object_storage/models/create_multipart_upload_details.rb', line 56 def content_disposition @content_disposition end |
#content_encoding ⇒ String
The optional Content-Encoding header that defines the content encodings that were applied to the object to upload. Specifying values for this header has no effect on Object Storage behavior. Programs that read the object determine what to do based on the value provided. For example, you could use this header to determine what decoding mechanisms need to be applied to obtain the media-type specified by the Content-Type header of the object.
48 49 50 |
# File 'lib/oci/object_storage/models/create_multipart_upload_details.rb', line 48 def content_encoding @content_encoding end |
#content_language ⇒ String
The optional Content-Language header that defines the content language of the object to upload. Specifying values for this header has no effect on Object Storage behavior. Programs that read the object determine what to do based on the value provided. For example, you could use this header to identify and differentiate objects based on a particular language.
39 40 41 |
# File 'lib/oci/object_storage/models/create_multipart_upload_details.rb', line 39 def content_language @content_language end |
#content_type ⇒ String
The optional Content-Type header that defines the standard MIME type format of the object to upload. Specifying values for this header has no effect on Object Storage behavior. Programs that read the object determine what to do based on the value provided. For example, you could use this header to identify and perform special operations on text only objects.
31 32 33 |
# File 'lib/oci/object_storage/models/create_multipart_upload_details.rb', line 31 def content_type @content_type end |
#metadata ⇒ Hash<String, String>
Arbitrary string keys and values for the user-defined metadata for the object. Keys must be in "opc-meta-*" format. Avoid entering confidential information.
76 77 78 |
# File 'lib/oci/object_storage/models/create_multipart_upload_details.rb', line 76 def end |
#object ⇒ String
[Required] The name of the object to which this multi-part upload is targeted. Avoid entering confidential information. Example: test/object1.log
23 24 25 |
# File 'lib/oci/object_storage/models/create_multipart_upload_details.rb', line 23 def object @object end |
#storage_tier ⇒ String
The storage tier that the object should be stored in. If not specified, the object will be stored in the same storage tier as the bucket.
70 71 72 |
# File 'lib/oci/object_storage/models/create_multipart_upload_details.rb', line 70 def storage_tier @storage_tier end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/oci/object_storage/models/create_multipart_upload_details.rb', line 79 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'object': :'object', 'content_type': :'contentType', 'content_language': :'contentLanguage', 'content_encoding': :'contentEncoding', 'content_disposition': :'contentDisposition', 'cache_control': :'cacheControl', 'storage_tier': :'storageTier', 'metadata': :'metadata' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/oci/object_storage/models/create_multipart_upload_details.rb', line 95 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'object': :'String', 'content_type': :'String', 'content_language': :'String', 'content_encoding': :'String', 'content_disposition': :'String', 'cache_control': :'String', 'storage_tier': :'String', 'metadata': :'Hash<String, String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/oci/object_storage/models/create_multipart_upload_details.rb', line 186 def ==(other) return true if equal?(other) self.class == other.class && object == other.object && content_type == other.content_type && content_language == other.content_language && content_encoding == other.content_encoding && content_disposition == other.content_disposition && cache_control == other.cache_control && storage_tier == other.storage_tier && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/oci/object_storage/models/create_multipart_upload_details.rb', line 223 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
203 204 205 |
# File 'lib/oci/object_storage/models/create_multipart_upload_details.rb', line 203 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
212 213 214 |
# File 'lib/oci/object_storage/models/create_multipart_upload_details.rb', line 212 def hash [object, content_type, content_language, content_encoding, content_disposition, cache_control, storage_tier, ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
256 257 258 259 260 261 262 263 264 265 |
# File 'lib/oci/object_storage/models/create_multipart_upload_details.rb', line 256 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
250 251 252 |
# File 'lib/oci/object_storage/models/create_multipart_upload_details.rb', line 250 def to_s to_hash.to_s end |