Class: OCI::ObjectStorage::Models::CreatePreauthenticatedRequestDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/object_storage/models/create_preauthenticated_request_details.rb

Overview

CreatePreauthenticatedRequestDetails model.

Constant Summary collapse

ACCESS_TYPE_ENUM =
[
  ACCESS_TYPE_OBJECT_READ = 'ObjectRead'.freeze,
  ACCESS_TYPE_OBJECT_WRITE = 'ObjectWrite'.freeze,
  ACCESS_TYPE_OBJECT_READ_WRITE = 'ObjectReadWrite'.freeze,
  ACCESS_TYPE_ANY_OBJECT_WRITE = 'AnyObjectWrite'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreatePreauthenticatedRequestDetails

Initializes the object

Options Hash (attributes):

  • :name (String)

    The value to assign to the #name property

  • :object_name (String)

    The value to assign to the #object_name property

  • :access_type (String)

    The value to assign to the #access_type property

  • :time_expires (DateTime)

    The value to assign to the #time_expires property

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/oci/object_storage/models/create_preauthenticated_request_details.rb', line 71

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.name = attributes[:'name'] if attributes[:'name']

  self.object_name = attributes[:'objectName'] if attributes[:'objectName']

  raise 'You cannot provide both :objectName and :object_name' if attributes.key?(:'objectName') && attributes.key?(:'object_name')

  self.object_name = attributes[:'object_name'] if attributes[:'object_name']

  self.access_type = attributes[:'accessType'] if attributes[:'accessType']

  raise 'You cannot provide both :accessType and :access_type' if attributes.key?(:'accessType') && attributes.key?(:'access_type')

  self.access_type = attributes[:'access_type'] if attributes[:'access_type']

  self.time_expires = attributes[:'timeExpires'] if attributes[:'timeExpires']

  raise 'You cannot provide both :timeExpires and :time_expires' if attributes.key?(:'timeExpires') && attributes.key?(:'time_expires')

  self.time_expires = attributes[:'time_expires'] if attributes[:'time_expires']
end

Instance Attribute Details

#access_typeString

[Required] The operation that can be performed on this resource.

Returns:



29
30
31
# File 'lib/oci/object_storage/models/create_preauthenticated_request_details.rb', line 29

def access_type
  @access_type
end

#nameString

[Required] A user-specified name for the pre-authenticated request. Names can be helpful in managing pre-authenticated requests.

Returns:



19
20
21
# File 'lib/oci/object_storage/models/create_preauthenticated_request_details.rb', line 19

def name
  @name
end

#object_nameString

The name of the object that is being granted access to by the pre-authenticated request. Avoid entering confidential information. The object name can be null and if so, the pre-authenticated request grants access to the entire bucket.

Returns:



25
26
27
# File 'lib/oci/object_storage/models/create_preauthenticated_request_details.rb', line 25

def object_name
  @object_name
end

#time_expiresDateTime

[Required] The expiration date for the pre-authenticated request as per [RFC 3339](tools.ietf.org/html/rfc3339). After this date the pre-authenticated request will no longer be valid.

Returns:



35
36
37
# File 'lib/oci/object_storage/models/create_preauthenticated_request_details.rb', line 35

def time_expires
  @time_expires
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
# File 'lib/oci/object_storage/models/create_preauthenticated_request_details.rb', line 38

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'name': :'name',
    'object_name': :'objectName',
    'access_type': :'accessType',
    'time_expires': :'timeExpires'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



50
51
52
53
54
55
56
57
58
59
# File 'lib/oci/object_storage/models/create_preauthenticated_request_details.rb', line 50

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'name': :'String',
    'object_name': :'String',
    'access_type': :'String',
    'time_expires': :'DateTime'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • the other object to be compared



113
114
115
116
117
118
119
120
121
# File 'lib/oci/object_storage/models/create_preauthenticated_request_details.rb', line 113

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    name == other.name &&
    object_name == other.object_name &&
    access_type == other.access_type &&
    time_expires == other.time_expires
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
# File 'lib/oci/object_storage/models/create_preauthenticated_request_details.rb', line 146

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method

Parameters:

  • the other object to be compared

Returns:



126
127
128
# File 'lib/oci/object_storage/models/create_preauthenticated_request_details.rb', line 126

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • Hash code



135
136
137
# File 'lib/oci/object_storage/models/create_preauthenticated_request_details.rb', line 135

def hash
  [name, object_name, access_type, time_expires].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



179
180
181
182
183
184
185
186
187
188
# File 'lib/oci/object_storage/models/create_preauthenticated_request_details.rb', line 179

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



173
174
175
# File 'lib/oci/object_storage/models/create_preauthenticated_request_details.rb', line 173

def to_s
  to_hash.to_s
end