Class: OCI::ObjectStorage::Models::MultipartUpload

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/object_storage/models/multipart_upload.rb

Overview

Multipart uploads provide efficient and resilient uploads, especially for large objects. Multipart uploads also accommodate objects that are too large for a single upload operation. With multipart uploads, individual parts of an object can be uploaded in parallel to reduce the amount of time you spend uploading. Multipart uploads can also minimize the impact of network failures by letting you retry a failed part upload instead of requiring you to retry an entire object upload. See [Using Multipart Uploads](docs.cloud.oracle.com/Content/Object/Tasks/usingmultipartuploads.htm).

To use any of the API operations, you must be authorized in an IAM policy. If you are not authorized, talk to an administrator. If you are an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm).

Constant Summary collapse

STORAGE_TIER_ENUM =
[
  STORAGE_TIER_STANDARD = 'Standard'.freeze,
  STORAGE_TIER_INFREQUENT_ACCESS = 'InfrequentAccess'.freeze,
  STORAGE_TIER_ARCHIVE = 'Archive'.freeze,
  STORAGE_TIER_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ MultipartUpload

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :namespace (String)

    The value to assign to the #namespace property

  • :bucket (String)

    The value to assign to the #bucket property

  • :object (String)

    The value to assign to the #object property

  • :upload_id (String)

    The value to assign to the #upload_id property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :storage_tier (String)

    The value to assign to the #storage_tier property



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/oci/object_storage/models/multipart_upload.rb', line 91

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.namespace = attributes[:'namespace'] if attributes[:'namespace']

  self.bucket = attributes[:'bucket'] if attributes[:'bucket']

  self.object = attributes[:'object'] if attributes[:'object']

  self.upload_id = attributes[:'uploadId'] if attributes[:'uploadId']

  raise 'You cannot provide both :uploadId and :upload_id' if attributes.key?(:'uploadId') && attributes.key?(:'upload_id')

  self.upload_id = attributes[:'upload_id'] if attributes[:'upload_id']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.storage_tier = attributes[:'storageTier'] if attributes[:'storageTier']

  raise 'You cannot provide both :storageTier and :storage_tier' if attributes.key?(:'storageTier') && attributes.key?(:'storage_tier')

  self.storage_tier = attributes[:'storage_tier'] if attributes[:'storage_tier']
end

Instance Attribute Details

#bucketString

[Required] The bucket in which the in-progress multipart upload is stored.

Returns:

  • (String)


33
34
35
# File 'lib/oci/object_storage/models/multipart_upload.rb', line 33

def bucket
  @bucket
end

#namespaceString

[Required] The Object Storage namespace in which the in-progress multipart upload is stored.

Returns:

  • (String)


29
30
31
# File 'lib/oci/object_storage/models/multipart_upload.rb', line 29

def namespace
  @namespace
end

#objectString

[Required] The object name of the in-progress multipart upload.

Returns:

  • (String)


37
38
39
# File 'lib/oci/object_storage/models/multipart_upload.rb', line 37

def object
  @object
end

#storage_tierString

The storage tier that the object is stored in.

Returns:

  • (String)


49
50
51
# File 'lib/oci/object_storage/models/multipart_upload.rb', line 49

def storage_tier
  @storage_tier
end

#time_createdDateTime

[Required] The date and time the upload was created, as described in [RFC 2616](tools.ietf.org/html/rfc2616#section-14.29).

Returns:

  • (DateTime)


45
46
47
# File 'lib/oci/object_storage/models/multipart_upload.rb', line 45

def time_created
  @time_created
end

#upload_idString

[Required] The unique identifier for the in-progress multipart upload.

Returns:

  • (String)


41
42
43
# File 'lib/oci/object_storage/models/multipart_upload.rb', line 41

def upload_id
  @upload_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/oci/object_storage/models/multipart_upload.rb', line 52

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'namespace': :'namespace',
    'bucket': :'bucket',
    'object': :'object',
    'upload_id': :'uploadId',
    'time_created': :'timeCreated',
    'storage_tier': :'storageTier'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/oci/object_storage/models/multipart_upload.rb', line 66

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'namespace': :'String',
    'bucket': :'String',
    'object': :'String',
    'upload_id': :'String',
    'time_created': :'DateTime',
    'storage_tier': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



142
143
144
145
146
147
148
149
150
151
152
# File 'lib/oci/object_storage/models/multipart_upload.rb', line 142

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    namespace == other.namespace &&
    bucket == other.bucket &&
    object == other.object &&
    upload_id == other.upload_id &&
    time_created == other.time_created &&
    storage_tier == other.storage_tier
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/oci/object_storage/models/multipart_upload.rb', line 177

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


157
158
159
# File 'lib/oci/object_storage/models/multipart_upload.rb', line 157

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



166
167
168
# File 'lib/oci/object_storage/models/multipart_upload.rb', line 166

def hash
  [namespace, bucket, object, upload_id, time_created, storage_tier].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



210
211
212
213
214
215
216
217
218
219
# File 'lib/oci/object_storage/models/multipart_upload.rb', line 210

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



204
205
206
# File 'lib/oci/object_storage/models/multipart_upload.rb', line 204

def to_s
  to_hash.to_s
end