Class: OCI::ObjectStorage::Models::MultipartUploadPartSummary
- Inherits:
-
Object
- Object
- OCI::ObjectStorage::Models::MultipartUploadPartSummary
- Defined in:
- lib/oci/object_storage/models/multipart_upload_part_summary.rb
Overview
Get summary information about multipart uploads. To use any of the API operations, you must be authorized in an IAM policy. If you’re not authorized, talk to an administrator. If you’re an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.us-phoenix-1.oraclecloud.com/Content/Identity/Concepts/policygetstarted.htm).
Instance Attribute Summary collapse
-
#etag ⇒ String
[Required] The current entity tag for the part.
-
#md5 ⇒ String
[Required] The MD5 hash of the bytes of the part.
-
#part_number ⇒ Integer
[Required] The part number for this part.
-
#size ⇒ Integer
[Required] The size of the part in bytes.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MultipartUploadPartSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ MultipartUploadPartSummary
Initializes the object
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/oci/object_storage/models/multipart_upload_part_summary.rb', line 63 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.etag = attributes[:'etag'] if attributes[:'etag'] self.md5 = attributes[:'md5'] if attributes[:'md5'] self.size = attributes[:'size'] if attributes[:'size'] self.part_number = attributes[:'partNumber'] if attributes[:'partNumber'] raise 'You cannot provide both :partNumber and :part_number' if attributes.key?(:'partNumber') && attributes.key?(:'part_number') self.part_number = attributes[:'part_number'] if attributes[:'part_number'] end |
Instance Attribute Details
#etag ⇒ String
[Required] The current entity tag for the part.
15 16 17 |
# File 'lib/oci/object_storage/models/multipart_upload_part_summary.rb', line 15 def etag @etag end |
#md5 ⇒ String
[Required] The MD5 hash of the bytes of the part.
19 20 21 |
# File 'lib/oci/object_storage/models/multipart_upload_part_summary.rb', line 19 def md5 @md5 end |
#part_number ⇒ Integer
[Required] The part number for this part.
27 28 29 |
# File 'lib/oci/object_storage/models/multipart_upload_part_summary.rb', line 27 def part_number @part_number end |
#size ⇒ Integer
[Required] The size of the part in bytes.
23 24 25 |
# File 'lib/oci/object_storage/models/multipart_upload_part_summary.rb', line 23 def size @size end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
30 31 32 33 34 35 36 37 38 39 |
# File 'lib/oci/object_storage/models/multipart_upload_part_summary.rb', line 30 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'etag': :'etag', 'md5': :'md5', 'size': :'size', 'part_number': :'partNumber' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
42 43 44 45 46 47 48 49 50 51 |
# File 'lib/oci/object_storage/models/multipart_upload_part_summary.rb', line 42 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'etag': :'String', 'md5': :'String', 'size': :'Integer', 'part_number': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
89 90 91 92 93 94 95 96 97 |
# File 'lib/oci/object_storage/models/multipart_upload_part_summary.rb', line 89 def ==(other) return true if equal?(other) self.class == other.class && etag == other.etag && md5 == other.md5 && size == other.size && part_number == other.part_number end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/oci/object_storage/models/multipart_upload_part_summary.rb', line 122 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
102 103 104 |
# File 'lib/oci/object_storage/models/multipart_upload_part_summary.rb', line 102 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
111 112 113 |
# File 'lib/oci/object_storage/models/multipart_upload_part_summary.rb', line 111 def hash [etag, md5, size, part_number].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
155 156 157 158 159 160 161 162 163 164 |
# File 'lib/oci/object_storage/models/multipart_upload_part_summary.rb', line 155 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
149 150 151 |
# File 'lib/oci/object_storage/models/multipart_upload_part_summary.rb', line 149 def to_s to_hash.to_s end |