Class: OCI::ObjectStorage::Models::ObjectSummary
- Inherits:
-
Object
- Object
- OCI::ObjectStorage::Models::ObjectSummary
- Defined in:
- lib/oci/object_storage/models/object_summary.rb
Overview
To use any of the API operations, you must be authorized in an IAM policy. If you are not authorized, talk to an administrator. If you are an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm).
Constant Summary collapse
- STORAGE_TIER_ENUM =
[ STORAGE_TIER_STANDARD = 'Standard'.freeze, STORAGE_TIER_INFREQUENT_ACCESS = 'InfrequentAccess'.freeze, STORAGE_TIER_ARCHIVE = 'Archive'.freeze, STORAGE_TIER_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- ARCHIVAL_STATE_ENUM =
[ ARCHIVAL_STATE_ARCHIVED = 'Archived'.freeze, ARCHIVAL_STATE_RESTORING = 'Restoring'.freeze, ARCHIVAL_STATE_RESTORED = 'Restored'.freeze, ARCHIVAL_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#archival_state ⇒ String
Archival state of an object.
-
#etag ⇒ String
The current entity tag (ETag) for the object.
-
#md5 ⇒ String
Base64-encoded MD5 hash of the object data.
-
#name ⇒ String
[Required] The name of the object.
-
#size ⇒ Integer
Size of the object in bytes.
-
#storage_tier ⇒ String
The storage tier that the object is stored in.
-
#time_created ⇒ DateTime
The date and time the object was created, as described in [RFC 2616](tools.ietf.org/html/rfc2616#section-14.29).
-
#time_modified ⇒ DateTime
The date and time the object was modified, as described in [RFC 2616](tools.ietf.org/rfc/rfc2616), section 14.29.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ObjectSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ObjectSummary
Initializes the object
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/oci/object_storage/models/object_summary.rb', line 108 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.size = attributes[:'size'] if attributes[:'size'] self.md5 = attributes[:'md5'] if attributes[:'md5'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.etag = attributes[:'etag'] if attributes[:'etag'] self.storage_tier = attributes[:'storageTier'] if attributes[:'storageTier'] raise 'You cannot provide both :storageTier and :storage_tier' if attributes.key?(:'storageTier') && attributes.key?(:'storage_tier') self.storage_tier = attributes[:'storage_tier'] if attributes[:'storage_tier'] self.archival_state = attributes[:'archivalState'] if attributes[:'archivalState'] raise 'You cannot provide both :archivalState and :archival_state' if attributes.key?(:'archivalState') && attributes.key?(:'archival_state') self.archival_state = attributes[:'archival_state'] if attributes[:'archival_state'] self.time_modified = attributes[:'timeModified'] if attributes[:'timeModified'] raise 'You cannot provide both :timeModified and :time_modified' if attributes.key?(:'timeModified') && attributes.key?(:'time_modified') self.time_modified = attributes[:'time_modified'] if attributes[:'time_modified'] end |
Instance Attribute Details
#archival_state ⇒ String
Archival state of an object. This field is set only for objects in Archive tier.
56 57 58 |
# File 'lib/oci/object_storage/models/object_summary.rb', line 56 def archival_state @archival_state end |
#etag ⇒ String
The current entity tag (ETag) for the object.
48 49 50 |
# File 'lib/oci/object_storage/models/object_summary.rb', line 48 def etag @etag end |
#md5 ⇒ String
Base64-encoded MD5 hash of the object data.
40 41 42 |
# File 'lib/oci/object_storage/models/object_summary.rb', line 40 def md5 @md5 end |
#name ⇒ String
[Required] The name of the object. Avoid entering confidential information. Example: test/object1.log
32 33 34 |
# File 'lib/oci/object_storage/models/object_summary.rb', line 32 def name @name end |
#size ⇒ Integer
Size of the object in bytes.
36 37 38 |
# File 'lib/oci/object_storage/models/object_summary.rb', line 36 def size @size end |
#storage_tier ⇒ String
The storage tier that the object is stored in.
52 53 54 |
# File 'lib/oci/object_storage/models/object_summary.rb', line 52 def storage_tier @storage_tier end |
#time_created ⇒ DateTime
The date and time the object was created, as described in [RFC 2616](tools.ietf.org/html/rfc2616#section-14.29).
44 45 46 |
# File 'lib/oci/object_storage/models/object_summary.rb', line 44 def time_created @time_created end |
#time_modified ⇒ DateTime
The date and time the object was modified, as described in [RFC 2616](tools.ietf.org/rfc/rfc2616), section 14.29.
60 61 62 |
# File 'lib/oci/object_storage/models/object_summary.rb', line 60 def time_modified @time_modified end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/oci/object_storage/models/object_summary.rb', line 63 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'size': :'size', 'md5': :'md5', 'time_created': :'timeCreated', 'etag': :'etag', 'storage_tier': :'storageTier', 'archival_state': :'archivalState', 'time_modified': :'timeModified' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/oci/object_storage/models/object_summary.rb', line 79 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'size': :'Integer', 'md5': :'String', 'time_created': :'DateTime', 'etag': :'String', 'storage_tier': :'String', 'archival_state': :'String', 'time_modified': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/oci/object_storage/models/object_summary.rb', line 180 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && size == other.size && md5 == other.md5 && time_created == other.time_created && etag == other.etag && storage_tier == other.storage_tier && archival_state == other.archival_state && time_modified == other.time_modified end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/oci/object_storage/models/object_summary.rb', line 217 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
197 198 199 |
# File 'lib/oci/object_storage/models/object_summary.rb', line 197 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
206 207 208 |
# File 'lib/oci/object_storage/models/object_summary.rb', line 206 def hash [name, size, md5, time_created, etag, storage_tier, archival_state, time_modified].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
250 251 252 253 254 255 256 257 258 259 |
# File 'lib/oci/object_storage/models/object_summary.rb', line 250 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
244 245 246 |
# File 'lib/oci/object_storage/models/object_summary.rb', line 244 def to_s to_hash.to_s end |