Class: OCI::ObjectStorage::Models::PreauthenticatedRequestSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/object_storage/models/preauthenticated_request_summary.rb

Overview

Get summary information about pre-authenticated requests.

Constant Summary collapse

ACCESS_TYPE_ENUM =
[
  ACCESS_TYPE_OBJECT_READ = 'ObjectRead'.freeze,
  ACCESS_TYPE_OBJECT_WRITE = 'ObjectWrite'.freeze,
  ACCESS_TYPE_OBJECT_READ_WRITE = 'ObjectReadWrite'.freeze,
  ACCESS_TYPE_ANY_OBJECT_WRITE = 'AnyObjectWrite'.freeze,
  ACCESS_TYPE_ANY_OBJECT_READ = 'AnyObjectRead'.freeze,
  ACCESS_TYPE_ANY_OBJECT_READ_WRITE = 'AnyObjectReadWrite'.freeze,
  ACCESS_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PreauthenticatedRequestSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :name (String)

    The value to assign to the #name property

  • :object_name (String)

    The value to assign to the #object_name property

  • :bucket_listing_action (String)

    The value to assign to the #bucket_listing_action property

  • :access_type (String)

    The value to assign to the #access_type property

  • :time_expires (DateTime)

    The value to assign to the #time_expires property

  • :time_created (DateTime)

    The value to assign to the #time_created property



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/oci/object_storage/models/preauthenticated_request_summary.rb', line 100

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.name = attributes[:'name'] if attributes[:'name']

  self.object_name = attributes[:'objectName'] if attributes[:'objectName']

  raise 'You cannot provide both :objectName and :object_name' if attributes.key?(:'objectName') && attributes.key?(:'object_name')

  self.object_name = attributes[:'object_name'] if attributes[:'object_name']

  self.bucket_listing_action = attributes[:'bucketListingAction'] if attributes[:'bucketListingAction']

  raise 'You cannot provide both :bucketListingAction and :bucket_listing_action' if attributes.key?(:'bucketListingAction') && attributes.key?(:'bucket_listing_action')

  self.bucket_listing_action = attributes[:'bucket_listing_action'] if attributes[:'bucket_listing_action']

  self.access_type = attributes[:'accessType'] if attributes[:'accessType']

  raise 'You cannot provide both :accessType and :access_type' if attributes.key?(:'accessType') && attributes.key?(:'access_type')

  self.access_type = attributes[:'access_type'] if attributes[:'access_type']

  self.time_expires = attributes[:'timeExpires'] if attributes[:'timeExpires']

  raise 'You cannot provide both :timeExpires and :time_expires' if attributes.key?(:'timeExpires') && attributes.key?(:'time_expires')

  self.time_expires = attributes[:'time_expires'] if attributes[:'time_expires']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']
end

Instance Attribute Details

#access_typeString

[Required] The operation that can be performed on this resource.

Returns:

  • (String)


45
46
47
# File 'lib/oci/object_storage/models/preauthenticated_request_summary.rb', line 45

def access_type
  @access_type
end

#bucket_listing_actionString

Specifies whether a list operation is allowed on a PAR with accessType "AnyObjectRead" or "AnyObjectReadWrite". Deny: Prevents the user from performing a list operation. ListObjects: Authorizes the user to perform a list operation.

Returns:

  • (String)


41
42
43
# File 'lib/oci/object_storage/models/preauthenticated_request_summary.rb', line 41

def bucket_listing_action
  @bucket_listing_action
end

#idString

[Required] The unique identifier to use when directly addressing the pre-authenticated request.

Returns:

  • (String)


24
25
26
# File 'lib/oci/object_storage/models/preauthenticated_request_summary.rb', line 24

def id
  @id
end

#nameString

[Required] The user-provided name of the pre-authenticated request.

Returns:

  • (String)


28
29
30
# File 'lib/oci/object_storage/models/preauthenticated_request_summary.rb', line 28

def name
  @name
end

#object_nameString

The name of object that is being granted access to by the pre-authenticated request. This can be null and if it is, the pre-authenticated request grants access to the entire bucket.

Returns:

  • (String)


34
35
36
# File 'lib/oci/object_storage/models/preauthenticated_request_summary.rb', line 34

def object_name
  @object_name
end

#time_createdDateTime

[Required] The date when the pre-authenticated request was created as per [RFC 3339](tools.ietf.org/html/rfc3339).

Returns:

  • (DateTime)


55
56
57
# File 'lib/oci/object_storage/models/preauthenticated_request_summary.rb', line 55

def time_created
  @time_created
end

#time_expiresDateTime

[Required] The expiration date for the pre-authenticated request as per [RFC 3339](tools.ietf.org/html/rfc3339). After this date the pre-authenticated request will no longer be valid.

Returns:

  • (DateTime)


50
51
52
# File 'lib/oci/object_storage/models/preauthenticated_request_summary.rb', line 50

def time_expires
  @time_expires
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/oci/object_storage/models/preauthenticated_request_summary.rb', line 58

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'name': :'name',
    'object_name': :'objectName',
    'bucket_listing_action': :'bucketListingAction',
    'access_type': :'accessType',
    'time_expires': :'timeExpires',
    'time_created': :'timeCreated'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/oci/object_storage/models/preauthenticated_request_summary.rb', line 73

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'name': :'String',
    'object_name': :'String',
    'bucket_listing_action': :'String',
    'access_type': :'String',
    'time_expires': :'DateTime',
    'time_created': :'DateTime'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/oci/object_storage/models/preauthenticated_request_summary.rb', line 161

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    name == other.name &&
    object_name == other.object_name &&
    bucket_listing_action == other.bucket_listing_action &&
    access_type == other.access_type &&
    time_expires == other.time_expires &&
    time_created == other.time_created
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/oci/object_storage/models/preauthenticated_request_summary.rb', line 197

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


177
178
179
# File 'lib/oci/object_storage/models/preauthenticated_request_summary.rb', line 177

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



186
187
188
# File 'lib/oci/object_storage/models/preauthenticated_request_summary.rb', line 186

def hash
  [id, name, object_name, bucket_listing_action, access_type, time_expires, time_created].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



230
231
232
233
234
235
236
237
238
239
# File 'lib/oci/object_storage/models/preauthenticated_request_summary.rb', line 230

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



224
225
226
# File 'lib/oci/object_storage/models/preauthenticated_request_summary.rb', line 224

def to_s
  to_hash.to_s
end