Class: OCI::ObjectStorage::Models::ReencryptObjectDetails
- Inherits:
-
Object
- Object
- OCI::ObjectStorage::Models::ReencryptObjectDetails
- Defined in:
- lib/oci/object_storage/models/reencrypt_object_details.rb
Overview
The details used to re-encrypt the data encryption keys associated with an object. You can only specify either a kmsKeyId or an sseCustomerKey in the request payload, not both. If the request payload is empty, the object is encrypted using the encryption key assigned to the bucket. The bucket encryption mechanism can either be a master encryption key managed by Oracle or the Vault service.
-
The sseCustomerKey field specifies the customer-provided encryption key (SSE-C) that will be used to re-encrypt the data encryption keys of the object and its chunks.
-
The sourceSSECustomerKey field specifies information about the customer-provided encryption key that is currently associated with the object source. Specify a value for the sourceSSECustomerKey only if the object is encrypted with a customer-provided encryption key.
Instance Attribute Summary collapse
-
#kms_key_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the master encryption key used to call the Vault service to re-encrypt the data encryption keys associated with the object and its chunks.
- #source_sse_customer_key ⇒ OCI::ObjectStorage::Models::SSECustomerKeyDetails
- #sse_customer_key ⇒ OCI::ObjectStorage::Models::SSECustomerKeyDetails
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ReencryptObjectDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ReencryptObjectDetails
Initializes the object
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/oci/object_storage/models/reencrypt_object_details.rb', line 66 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.kms_key_id = attributes[:'kmsKeyId'] if attributes[:'kmsKeyId'] raise 'You cannot provide both :kmsKeyId and :kms_key_id' if attributes.key?(:'kmsKeyId') && attributes.key?(:'kms_key_id') self.kms_key_id = attributes[:'kms_key_id'] if attributes[:'kms_key_id'] self.sse_customer_key = attributes[:'sseCustomerKey'] if attributes[:'sseCustomerKey'] raise 'You cannot provide both :sseCustomerKey and :sse_customer_key' if attributes.key?(:'sseCustomerKey') && attributes.key?(:'sse_customer_key') self.sse_customer_key = attributes[:'sse_customer_key'] if attributes[:'sse_customer_key'] self.source_sse_customer_key = attributes[:'sourceSseCustomerKey'] if attributes[:'sourceSseCustomerKey'] raise 'You cannot provide both :sourceSseCustomerKey and :source_sse_customer_key' if attributes.key?(:'sourceSseCustomerKey') && attributes.key?(:'source_sse_customer_key') self.source_sse_customer_key = attributes[:'source_sse_customer_key'] if attributes[:'source_sse_customer_key'] end |
Instance Attribute Details
#kms_key_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the master encryption key used to call the Vault service to re-encrypt the data encryption keys associated with the object and its chunks. If the kmsKeyId value is empty, whether null or an empty string, the API will perform re-encryption by using the kmsKeyId associated with the bucket or the master encryption key managed by Oracle, depending on the bucket encryption mechanism.
27 28 29 |
# File 'lib/oci/object_storage/models/reencrypt_object_details.rb', line 27 def kms_key_id @kms_key_id end |
#source_sse_customer_key ⇒ OCI::ObjectStorage::Models::SSECustomerKeyDetails
33 34 35 |
# File 'lib/oci/object_storage/models/reencrypt_object_details.rb', line 33 def source_sse_customer_key @source_sse_customer_key end |
#sse_customer_key ⇒ OCI::ObjectStorage::Models::SSECustomerKeyDetails
30 31 32 |
# File 'lib/oci/object_storage/models/reencrypt_object_details.rb', line 30 def sse_customer_key @sse_customer_key end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
36 37 38 39 40 41 42 43 44 |
# File 'lib/oci/object_storage/models/reencrypt_object_details.rb', line 36 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'kms_key_id': :'kmsKeyId', 'sse_customer_key': :'sseCustomerKey', 'source_sse_customer_key': :'sourceSseCustomerKey' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
47 48 49 50 51 52 53 54 55 |
# File 'lib/oci/object_storage/models/reencrypt_object_details.rb', line 47 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'kms_key_id': :'String', 'sse_customer_key': :'OCI::ObjectStorage::Models::SSECustomerKeyDetails', 'source_sse_customer_key': :'OCI::ObjectStorage::Models::SSECustomerKeyDetails' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
98 99 100 101 102 103 104 105 |
# File 'lib/oci/object_storage/models/reencrypt_object_details.rb', line 98 def ==(other) return true if equal?(other) self.class == other.class && kms_key_id == other.kms_key_id && sse_customer_key == other.sse_customer_key && source_sse_customer_key == other.source_sse_customer_key end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/oci/object_storage/models/reencrypt_object_details.rb', line 130 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
110 111 112 |
# File 'lib/oci/object_storage/models/reencrypt_object_details.rb', line 110 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
119 120 121 |
# File 'lib/oci/object_storage/models/reencrypt_object_details.rb', line 119 def hash [kms_key_id, sse_customer_key, source_sse_customer_key].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
163 164 165 166 167 168 169 170 171 172 |
# File 'lib/oci/object_storage/models/reencrypt_object_details.rb', line 163 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
157 158 159 |
# File 'lib/oci/object_storage/models/reencrypt_object_details.rb', line 157 def to_s to_hash.to_s end |