Class: OCI::ObjectStorage::Models::RenameObjectDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/object_storage/models/rename_object_details.rb

Overview

To use any of the API operations, you must be authorized in an IAM policy. If you are not authorized, talk to an administrator. If you are an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm).

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ RenameObjectDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/oci/object_storage/models/rename_object_details.rb', line 72

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.source_name = attributes[:'sourceName'] if attributes[:'sourceName']

  raise 'You cannot provide both :sourceName and :source_name' if attributes.key?(:'sourceName') && attributes.key?(:'source_name')

  self.source_name = attributes[:'source_name'] if attributes[:'source_name']

  self.new_name = attributes[:'newName'] if attributes[:'newName']

  raise 'You cannot provide both :newName and :new_name' if attributes.key?(:'newName') && attributes.key?(:'new_name')

  self.new_name = attributes[:'new_name'] if attributes[:'new_name']

  self.src_obj_if_match_e_tag = attributes[:'srcObjIfMatchETag'] if attributes[:'srcObjIfMatchETag']

  raise 'You cannot provide both :srcObjIfMatchETag and :src_obj_if_match_e_tag' if attributes.key?(:'srcObjIfMatchETag') && attributes.key?(:'src_obj_if_match_e_tag')

  self.src_obj_if_match_e_tag = attributes[:'src_obj_if_match_e_tag'] if attributes[:'src_obj_if_match_e_tag']

  self.new_obj_if_match_e_tag = attributes[:'newObjIfMatchETag'] if attributes[:'newObjIfMatchETag']

  raise 'You cannot provide both :newObjIfMatchETag and :new_obj_if_match_e_tag' if attributes.key?(:'newObjIfMatchETag') && attributes.key?(:'new_obj_if_match_e_tag')

  self.new_obj_if_match_e_tag = attributes[:'new_obj_if_match_e_tag'] if attributes[:'new_obj_if_match_e_tag']

  self.new_obj_if_none_match_e_tag = attributes[:'newObjIfNoneMatchETag'] if attributes[:'newObjIfNoneMatchETag']

  raise 'You cannot provide both :newObjIfNoneMatchETag and :new_obj_if_none_match_e_tag' if attributes.key?(:'newObjIfNoneMatchETag') && attributes.key?(:'new_obj_if_none_match_e_tag')

  self.new_obj_if_none_match_e_tag = attributes[:'new_obj_if_none_match_e_tag'] if attributes[:'new_obj_if_none_match_e_tag']
end

Instance Attribute Details

#new_nameString

[Required] The new name of the source object. Avoid entering confidential information.

Returns:

  • (String)


19
20
21
# File 'lib/oci/object_storage/models/rename_object_details.rb', line 19

def new_name
  @new_name
end

#new_obj_if_match_e_tagString

The if-match entity tag (ETag) of the new object.

Returns:

  • (String)


27
28
29
# File 'lib/oci/object_storage/models/rename_object_details.rb', line 27

def new_obj_if_match_e_tag
  @new_obj_if_match_e_tag
end

#new_obj_if_none_match_e_tagString

The if-none-match entity tag (ETag) of the new object. The only valid value is ‘*’, which indicates request should fail if the new object already exists.

Returns:

  • (String)


33
34
35
# File 'lib/oci/object_storage/models/rename_object_details.rb', line 33

def new_obj_if_none_match_e_tag
  @new_obj_if_none_match_e_tag
end

#source_nameString

[Required] The name of the source object to be renamed.

Returns:

  • (String)


15
16
17
# File 'lib/oci/object_storage/models/rename_object_details.rb', line 15

def source_name
  @source_name
end

#src_obj_if_match_e_tagString

The if-match entity tag (ETag) of the source object.

Returns:

  • (String)


23
24
25
# File 'lib/oci/object_storage/models/rename_object_details.rb', line 23

def src_obj_if_match_e_tag
  @src_obj_if_match_e_tag
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



36
37
38
39
40
41
42
43
44
45
46
# File 'lib/oci/object_storage/models/rename_object_details.rb', line 36

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'source_name': :'sourceName',
    'new_name': :'newName',
    'src_obj_if_match_e_tag': :'srcObjIfMatchETag',
    'new_obj_if_match_e_tag': :'newObjIfMatchETag',
    'new_obj_if_none_match_e_tag': :'newObjIfNoneMatchETag'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



49
50
51
52
53
54
55
56
57
58
59
# File 'lib/oci/object_storage/models/rename_object_details.rb', line 49

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'source_name': :'String',
    'new_name': :'String',
    'src_obj_if_match_e_tag': :'String',
    'new_obj_if_match_e_tag': :'String',
    'new_obj_if_none_match_e_tag': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



116
117
118
119
120
121
122
123
124
125
# File 'lib/oci/object_storage/models/rename_object_details.rb', line 116

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    source_name == other.source_name &&
    new_name == other.new_name &&
    src_obj_if_match_e_tag == other.src_obj_if_match_e_tag &&
    new_obj_if_match_e_tag == other.new_obj_if_match_e_tag &&
    new_obj_if_none_match_e_tag == other.new_obj_if_none_match_e_tag
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/oci/object_storage/models/rename_object_details.rb', line 150

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


130
131
132
# File 'lib/oci/object_storage/models/rename_object_details.rb', line 130

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



139
140
141
# File 'lib/oci/object_storage/models/rename_object_details.rb', line 139

def hash
  [source_name, new_name, src_obj_if_match_e_tag, new_obj_if_match_e_tag, new_obj_if_none_match_e_tag].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



183
184
185
186
187
188
189
190
191
192
# File 'lib/oci/object_storage/models/rename_object_details.rb', line 183

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



177
178
179
# File 'lib/oci/object_storage/models/rename_object_details.rb', line 177

def to_s
  to_hash.to_s
end