Class: OCI::ObjectStorage::Models::ReplicationPolicy

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/object_storage/models/replication_policy.rb

Overview

The details of a replication policy.

Constant Summary collapse

STATUS_ENUM =
[
  STATUS_ACTIVE = 'ACTIVE'.freeze,
  STATUS_CLIENT_ERROR = 'CLIENT_ERROR'.freeze,
  STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ReplicationPolicy

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :name (String)

    The value to assign to the #name property

  • :destination_region_name (String)

    The value to assign to the #destination_region_name property

  • :destination_bucket_name (String)

    The value to assign to the #destination_bucket_name property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :time_last_sync (DateTime)

    The value to assign to the #time_last_sync property

  • :status (String)

    The value to assign to the #status property

  • :status_message (String)

    The value to assign to the #status_message property



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/oci/object_storage/models/replication_policy.rb', line 100

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  self.id = attributes[:'id'] if attributes[:'id']

  self.name = attributes[:'name'] if attributes[:'name']

  self.destination_region_name = attributes[:'destinationRegionName'] if attributes[:'destinationRegionName']

  raise 'You cannot provide both :destinationRegionName and :destination_region_name' if attributes.key?(:'destinationRegionName') && attributes.key?(:'destination_region_name')

  self.destination_region_name = attributes[:'destination_region_name'] if attributes[:'destination_region_name']

  self.destination_bucket_name = attributes[:'destinationBucketName'] if attributes[:'destinationBucketName']

  raise 'You cannot provide both :destinationBucketName and :destination_bucket_name' if attributes.key?(:'destinationBucketName') && attributes.key?(:'destination_bucket_name')

  self.destination_bucket_name = attributes[:'destination_bucket_name'] if attributes[:'destination_bucket_name']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_last_sync = attributes[:'timeLastSync'] if attributes[:'timeLastSync']

  raise 'You cannot provide both :timeLastSync and :time_last_sync' if attributes.key?(:'timeLastSync') && attributes.key?(:'time_last_sync')

  self.time_last_sync = attributes[:'time_last_sync'] if attributes[:'time_last_sync']

  self.status = attributes[:'status'] if attributes[:'status']

  self.status_message = attributes[:'statusMessage'] if attributes[:'statusMessage']

  raise 'You cannot provide both :statusMessage and :status_message' if attributes.key?(:'statusMessage') && attributes.key?(:'status_message')

  self.status_message = attributes[:'status_message'] if attributes[:'status_message']
end

Instance Attribute Details

#destination_bucket_nameString

[Required] The bucket to replicate to in the destination region. Replication policy creation does not automatically create a destination bucket. Create the destination bucket before creating the policy.

Returns:

  • (String)


32
33
34
# File 'lib/oci/object_storage/models/replication_policy.rb', line 32

def destination_bucket_name
  @destination_bucket_name
end

#destination_region_nameString

[Required] The destination region to replicate to, for example "us-ashburn-1".

Returns:

  • (String)


26
27
28
# File 'lib/oci/object_storage/models/replication_policy.rb', line 26

def destination_region_name
  @destination_region_name
end

#idString

[Required] The id of the replication policy.

Returns:

  • (String)


18
19
20
# File 'lib/oci/object_storage/models/replication_policy.rb', line 18

def id
  @id
end

#nameString

[Required] The name of the policy.

Returns:

  • (String)


22
23
24
# File 'lib/oci/object_storage/models/replication_policy.rb', line 22

def name
  @name
end

#statusString

[Required] The replication status of the policy. If the status is CLIENT_ERROR, once the user fixes the issue described in the status message, the status will become ACTIVE.

Returns:

  • (String)


48
49
50
# File 'lib/oci/object_storage/models/replication_policy.rb', line 48

def status
  @status
end

#status_messageString

[Required] A human-readable description of the status.

Returns:

  • (String)


52
53
54
# File 'lib/oci/object_storage/models/replication_policy.rb', line 52

def status_message
  @status_message
end

#time_createdDateTime

[Required] The date when the replication policy was created as per [RFC 3339](tools.ietf.org/html/rfc3339).

Returns:

  • (DateTime)


37
38
39
# File 'lib/oci/object_storage/models/replication_policy.rb', line 37

def time_created
  @time_created
end

#time_last_syncDateTime

[Required] Changes made to the source bucket before this time has been replicated.

Returns:

  • (DateTime)


42
43
44
# File 'lib/oci/object_storage/models/replication_policy.rb', line 42

def time_last_sync
  @time_last_sync
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/oci/object_storage/models/replication_policy.rb', line 55

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'name': :'name',
    'destination_region_name': :'destinationRegionName',
    'destination_bucket_name': :'destinationBucketName',
    'time_created': :'timeCreated',
    'time_last_sync': :'timeLastSync',
    'status': :'status',
    'status_message': :'statusMessage'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/oci/object_storage/models/replication_policy.rb', line 71

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'name': :'String',
    'destination_region_name': :'String',
    'destination_bucket_name': :'String',
    'time_created': :'DateTime',
    'time_last_sync': :'DateTime',
    'status': :'String',
    'status_message': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/oci/object_storage/models/replication_policy.rb', line 160

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    name == other.name &&
    destination_region_name == other.destination_region_name &&
    destination_bucket_name == other.destination_bucket_name &&
    time_created == other.time_created &&
    time_last_sync == other.time_last_sync &&
    status == other.status &&
    status_message == other.status_message
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/oci/object_storage/models/replication_policy.rb', line 197

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


177
178
179
# File 'lib/oci/object_storage/models/replication_policy.rb', line 177

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



186
187
188
# File 'lib/oci/object_storage/models/replication_policy.rb', line 186

def hash
  [id, name, destination_region_name, destination_bucket_name, time_created, time_last_sync, status, status_message].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



230
231
232
233
234
235
236
237
238
239
# File 'lib/oci/object_storage/models/replication_policy.rb', line 230

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



224
225
226
# File 'lib/oci/object_storage/models/replication_policy.rb', line 224

def to_s
  to_hash.to_s
end