Class: OCI::ObjectStorage::Models::ReplicationSource

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/object_storage/models/replication_source.rb

Overview

The details of a replication source bucket that replicates to a target destination bucket.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ReplicationSource

Initializes the object

Options Hash (attributes):

  • :policy_name (String)

    The value to assign to the #policy_name property

  • :source_region_name (String)

    The value to assign to the #source_region_name property

  • :source_bucket_name (String)

    The value to assign to the #source_bucket_name property

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/oci/object_storage/models/replication_source.rb', line 53

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.policy_name = attributes[:'policyName'] if attributes[:'policyName']

  raise 'You cannot provide both :policyName and :policy_name' if attributes.key?(:'policyName') && attributes.key?(:'policy_name')

  self.policy_name = attributes[:'policy_name'] if attributes[:'policy_name']

  self.source_region_name = attributes[:'sourceRegionName'] if attributes[:'sourceRegionName']

  raise 'You cannot provide both :sourceRegionName and :source_region_name' if attributes.key?(:'sourceRegionName') && attributes.key?(:'source_region_name')

  self.source_region_name = attributes[:'source_region_name'] if attributes[:'source_region_name']

  self.source_bucket_name = attributes[:'sourceBucketName'] if attributes[:'sourceBucketName']

  raise 'You cannot provide both :sourceBucketName and :source_bucket_name' if attributes.key?(:'sourceBucketName') && attributes.key?(:'source_bucket_name')

  self.source_bucket_name = attributes[:'source_bucket_name'] if attributes[:'source_bucket_name']
end

Instance Attribute Details

#policy_nameString

[Required] The name of the policy.

Returns:



12
13
14
# File 'lib/oci/object_storage/models/replication_source.rb', line 12

def policy_name
  @policy_name
end

#source_bucket_nameString

[Required] The source bucket replicating data from.

Returns:



20
21
22
# File 'lib/oci/object_storage/models/replication_source.rb', line 20

def source_bucket_name
  @source_bucket_name
end

#source_region_nameString

[Required] The source region replicating data from, for example "us-ashburn-1".

Returns:



16
17
18
# File 'lib/oci/object_storage/models/replication_source.rb', line 16

def source_region_name
  @source_region_name
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



23
24
25
26
27
28
29
30
31
# File 'lib/oci/object_storage/models/replication_source.rb', line 23

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'policy_name': :'policyName',
    'source_region_name': :'sourceRegionName',
    'source_bucket_name': :'sourceBucketName'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



34
35
36
37
38
39
40
41
42
# File 'lib/oci/object_storage/models/replication_source.rb', line 34

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'policy_name': :'String',
    'source_region_name': :'String',
    'source_bucket_name': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • the other object to be compared



85
86
87
88
89
90
91
92
# File 'lib/oci/object_storage/models/replication_source.rb', line 85

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    policy_name == other.policy_name &&
    source_region_name == other.source_region_name &&
    source_bucket_name == other.source_bucket_name
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/oci/object_storage/models/replication_source.rb', line 117

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method

Parameters:

  • the other object to be compared

Returns:



97
98
99
# File 'lib/oci/object_storage/models/replication_source.rb', line 97

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • Hash code



106
107
108
# File 'lib/oci/object_storage/models/replication_source.rb', line 106

def hash
  [policy_name, source_region_name, source_bucket_name].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



150
151
152
153
154
155
156
157
158
159
# File 'lib/oci/object_storage/models/replication_source.rb', line 150

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



144
145
146
# File 'lib/oci/object_storage/models/replication_source.rb', line 144

def to_s
  to_hash.to_s
end