Class: OCI::ObjectStorage::Models::RestoreObjectsDetails
- Inherits:
-
Object
- Object
- OCI::ObjectStorage::Models::RestoreObjectsDetails
- Defined in:
- lib/oci/object_storage/models/restore_objects_details.rb
Overview
RestoreObjectsDetails model.
Instance Attribute Summary collapse
-
#hours ⇒ Integer
The number of hours for which this object will be restored.
-
#object_name ⇒ String
[Required] An object which is in archive-tier storage and needs to be restored.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RestoreObjectsDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ RestoreObjectsDetails
Initializes the object
47 48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/oci/object_storage/models/restore_objects_details.rb', line 47 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.object_name = attributes[:'objectName'] if attributes[:'objectName'] raise 'You cannot provide both :objectName and :object_name' if attributes.key?(:'objectName') && attributes.key?(:'object_name') self.object_name = attributes[:'object_name'] if attributes[:'object_name'] self.hours = attributes[:'hours'] if attributes[:'hours'] end |
Instance Attribute Details
#hours ⇒ Integer
The number of hours for which this object will be restored. By default objects will be restored for 24 hours. Duration can be configured using the hours parameter.
17 18 19 |
# File 'lib/oci/object_storage/models/restore_objects_details.rb', line 17 def hours @hours end |
#object_name ⇒ String
[Required] An object which is in archive-tier storage and needs to be restored.
11 12 13 |
# File 'lib/oci/object_storage/models/restore_objects_details.rb', line 11 def object_name @object_name end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
20 21 22 23 24 25 26 27 |
# File 'lib/oci/object_storage/models/restore_objects_details.rb', line 20 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'object_name': :'objectName', 'hours': :'hours' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
30 31 32 33 34 35 36 37 |
# File 'lib/oci/object_storage/models/restore_objects_details.rb', line 30 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'object_name': :'String', 'hours': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
69 70 71 72 73 74 |
# File 'lib/oci/object_storage/models/restore_objects_details.rb', line 69 def ==(other) return true if equal?(other) self.class == other.class && object_name == other.object_name && hours == other.hours end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/oci/object_storage/models/restore_objects_details.rb', line 99 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
79 80 81 |
# File 'lib/oci/object_storage/models/restore_objects_details.rb', line 79 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
88 89 90 |
# File 'lib/oci/object_storage/models/restore_objects_details.rb', line 88 def hash [object_name, hours].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
131 132 133 134 135 136 137 138 139 |
# File 'lib/oci/object_storage/models/restore_objects_details.rb', line 131 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
125 126 127 |
# File 'lib/oci/object_storage/models/restore_objects_details.rb', line 125 def to_s to_hash.to_s end |