Class: OCI::ObjectStorage::Models::RetentionRule

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/object_storage/models/retention_rule.rb

Overview

The details of a retention rule.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ RetentionRule

Initializes the object

Options Hash (attributes):

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/oci/object_storage/models/retention_rule.rb', line 82

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.duration = attributes[:'duration'] if attributes[:'duration']

  self.etag = attributes[:'etag'] if attributes[:'etag']

  self.time_rule_locked = attributes[:'timeRuleLocked'] if attributes[:'timeRuleLocked']

  raise 'You cannot provide both :timeRuleLocked and :time_rule_locked' if attributes.key?(:'timeRuleLocked') && attributes.key?(:'time_rule_locked')

  self.time_rule_locked = attributes[:'time_rule_locked'] if attributes[:'time_rule_locked']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_modified = attributes[:'timeModified'] if attributes[:'timeModified']

  raise 'You cannot provide both :timeModified and :time_modified' if attributes.key?(:'timeModified') && attributes.key?(:'time_modified')

  self.time_modified = attributes[:'time_modified'] if attributes[:'time_modified']
end

Instance Attribute Details

#display_nameString

[Required] User specified name for the retention rule.

Returns:



16
17
18
# File 'lib/oci/object_storage/models/retention_rule.rb', line 16

def display_name
  @display_name
end

#durationOCI::ObjectStorage::Models::Duration

Returns:



19
20
21
# File 'lib/oci/object_storage/models/retention_rule.rb', line 19

def duration
  @duration
end

#etagString

[Required] The entity tag (ETag) for the retention rule.

Returns:



23
24
25
# File 'lib/oci/object_storage/models/retention_rule.rb', line 23

def etag
  @etag
end

#idString

[Required] Unique identifier for the retention rule.

Returns:



12
13
14
# File 'lib/oci/object_storage/models/retention_rule.rb', line 12

def id
  @id
end

#time_createdDateTime

[Required] The date and time that the retention rule was created as per [RFC3339](tools.ietf.org/html/rfc3339).

Returns:



33
34
35
# File 'lib/oci/object_storage/models/retention_rule.rb', line 33

def time_created
  @time_created
end

#time_modifiedDateTime

[Required] The date and time that the retention rule was modified as per [RFC3339](tools.ietf.org/html/rfc3339).

Returns:



37
38
39
# File 'lib/oci/object_storage/models/retention_rule.rb', line 37

def time_modified
  @time_modified
end

#time_rule_lockedDateTime

The date and time as per [RFC 3339](tools.ietf.org/html/rfc3339) after which this rule becomes locked. and can only be deleted by deleting the bucket.

Returns:



29
30
31
# File 'lib/oci/object_storage/models/retention_rule.rb', line 29

def time_rule_locked
  @time_rule_locked
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
51
52
# File 'lib/oci/object_storage/models/retention_rule.rb', line 40

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'display_name': :'displayName',
    'duration': :'duration',
    'etag': :'etag',
    'time_rule_locked': :'timeRuleLocked',
    'time_created': :'timeCreated',
    'time_modified': :'timeModified'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/oci/object_storage/models/retention_rule.rb', line 55

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'display_name': :'String',
    'duration': :'OCI::ObjectStorage::Models::Duration',
    'etag': :'String',
    'time_rule_locked': :'DateTime',
    'time_created': :'DateTime',
    'time_modified': :'DateTime'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • the other object to be compared



126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/oci/object_storage/models/retention_rule.rb', line 126

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    display_name == other.display_name &&
    duration == other.duration &&
    etag == other.etag &&
    time_rule_locked == other.time_rule_locked &&
    time_created == other.time_created &&
    time_modified == other.time_modified
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/oci/object_storage/models/retention_rule.rb', line 162

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method

Parameters:

  • the other object to be compared

Returns:



142
143
144
# File 'lib/oci/object_storage/models/retention_rule.rb', line 142

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • Hash code



151
152
153
# File 'lib/oci/object_storage/models/retention_rule.rb', line 151

def hash
  [id, display_name, duration, etag, time_rule_locked, time_created, time_modified].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



195
196
197
198
199
200
201
202
203
204
# File 'lib/oci/object_storage/models/retention_rule.rb', line 195

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



189
190
191
# File 'lib/oci/object_storage/models/retention_rule.rb', line 189

def to_s
  to_hash.to_s
end